-- --------------------------------------------------------
-- Host:                         127.0.0.1
-- Server version:               10.2.6-MariaDB - mariadb.org binary distribution
-- Server OS:                    Win64
-- HeidiSQL Version:             9.4.0.5173
-- --------------------------------------------------------

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET NAMES utf8 */;
/*!50503 SET NAMES utf8mb4 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;


-- Dumping database structure for emcor
CREATE DATABASE IF NOT EXISTS `emcor` /*!40100 DEFAULT CHARACTER SET utf8 COLLATE utf8_bin */;
USE `emcor`;

-- Dumping structure for table emcor.act
CREATE TABLE IF NOT EXISTS `act` (
  `act_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Akto identifikatorius',
  `act_type_id` mediumint(9) NOT NULL COMMENT 'Aktų tipo identifikatorius',
  `ignore_read_data` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Pakeičiančio nuskaitytus duomenis akto požymis',
  `act_number` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'Akto numeris',
  `act_month` date NOT NULL COMMENT 'Akto mėnuo',
  `act_desc` varchar(1024) COLLATE utf8_bin DEFAULT NULL COMMENT 'Akto aprašymas',
  `user_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Vartotojo identifikatorius',
  `point_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo taško identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `act_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Akto galiojimo požymis',
  PRIMARY KEY (`act_id`),
  UNIQUE KEY `act_number_u` (`act_number`),
  KEY `act_act_type_i` (`act_type_id`),
  KEY `act_db_time_i` (`db_time`),
  KEY `act_month_i` (`act_month`),
  KEY `act_point_i` (`point_id`),
  KEY `act_user_i` (`user_id`),
  CONSTRAINT `act_act_type_fk` FOREIGN KEY (`act_type_id`) REFERENCES `act_type` (`act_type_id`),
  CONSTRAINT `act_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `act_user_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Aktai';

-- Dumping data for table emcor.act: ~0 rows (approximately)
/*!40000 ALTER TABLE `act` DISABLE KEYS */;
/*!40000 ALTER TABLE `act` ENABLE KEYS */;

-- Dumping structure for table emcor.act_auto_inc
CREATE TABLE IF NOT EXISTS `act_auto_inc` (
  `act_month` date NOT NULL DEFAULT (curdate() - interval (dayofmonth(curdate()) - 1) day) COMMENT 'Akto mėnuo',
  `act_count` double NOT NULL DEFAULT 0 COMMENT 'Akto mėnesio aktų skaičius',
  PRIMARY KEY (`act_month`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Aktų mėnesio aktų skaičius';

-- Dumping data for table emcor.act_auto_inc: ~0 rows (approximately)
/*!40000 ALTER TABLE `act_auto_inc` DISABLE KEYS */;
/*!40000 ALTER TABLE `act_auto_inc` ENABLE KEYS */;

-- Dumping structure for table emcor.act_data
CREATE TABLE IF NOT EXISTS `act_data` (
  `act_id` int(10) unsigned NOT NULL COMMENT 'Akto identifikatorius',
  `pl_id` int(10) unsigned NOT NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
  `pl_t` datetime NOT NULL COMMENT 'Matavimo linijos matavimo taške duomenų laikas',
  `act_value` double DEFAULT NULL COMMENT 'Akto reikšmė',
  `db_time` datetime DEFAULT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `aggs_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  PRIMARY KEY (`act_id`,`pl_id`,`pl_t`),
  KEY `act_data_db_time_i` (`db_time`),
  KEY `act_data_pl_i` (`pl_id`,`pl_t`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Aktų duomenys'
 PARTITION BY RANGE (
   to_days(pl_t))
(PARTITION par_201701 VALUES LESS THAN (736726) ENGINE = InnoDB,
 PARTITION par_201702 VALUES LESS THAN (736754) ENGINE = InnoDB,
 PARTITION par_201703 VALUES LESS THAN (736785) ENGINE = InnoDB,
 PARTITION par_201704 VALUES LESS THAN (736815) ENGINE = InnoDB,
 PARTITION par_201705 VALUES LESS THAN (736846) ENGINE = InnoDB);

-- Dumping data for table emcor.act_data: ~5 rows (approximately)
/*!40000 ALTER TABLE `act_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `act_data` ENABLE KEYS */;

-- Dumping structure for table emcor.act_type
CREATE TABLE IF NOT EXISTS `act_type` (
  `act_type_id` mediumint(9) NOT NULL AUTO_INCREMENT COMMENT 'Aktų tipo identifikatorius',
  `act_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Aktų tipo pavadinimas',
  PRIMARY KEY (`act_type_id`),
  UNIQUE KEY `act_type_name_u` (`act_type_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Aktų tipai';

-- Dumping data for table emcor.act_type: ~7 rows (approximately)
/*!40000 ALTER TABLE `act_type` DISABLE KEYS */;
INSERT INTO `act_type` (`act_type_id`, `act_type_name`) VALUES
	(-4, 'Automatiniai maskuojantys duomenis aktai dėl monitoringo'),
	(-5, 'Automatiniai maskuojantys duomenis aktai dėl statusų'),
	(-6, 'Automatiškai suformuojami išskaičiavimo aktai'),
	(-7, 'Importuoti aktai'),
	(-1, 'Paskutinės vasaros laiko valandos aktai'),
	(-3, 'Vartotojo sprendimu atmetamų abejotinos kokybės duomenų aktai'),
	(-2, 'Vartotojo sprendimu priimamų abejotinos kokybės duomenų aktai');
/*!40000 ALTER TABLE `act_type` ENABLE KEYS */;

-- Dumping structure for table emcor.act_type_80020
CREATE TABLE IF NOT EXISTS `act_type_80020` (
  `act_type_id` mediumint(9) NOT NULL COMMENT 'Aktų tipo identifikatorius',
  PRIMARY KEY (`act_type_id`),
  CONSTRAINT `act_type_80020_act_type_fk` FOREIGN KEY (`act_type_id`) REFERENCES `act_type` (`act_type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Aktų, kuriais pažymėti rodmenys laikomi nekomerciniais 80020 dokumentuose, tipai';

-- Dumping data for table emcor.act_type_80020: ~0 rows (approximately)
/*!40000 ALTER TABLE `act_type_80020` DISABLE KEYS */;
/*!40000 ALTER TABLE `act_type_80020` ENABLE KEYS */;

-- Dumping structure for table emcor.ae
CREATE TABLE IF NOT EXISTS `ae` (
  `ae_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Audito tekstinio elemento identifikatorius',
  `ae_hash` smallint(5) unsigned NOT NULL COMMENT 'Audito tekstinio elemento HASH',
  `text` varchar(4000) COLLATE utf8_bin NOT NULL COMMENT 'Tekstas',
  PRIMARY KEY (`ae_id`),
  KEY `ae_ae_hash_i` (`ae_hash`)
) ENGINE=InnoDB AUTO_INCREMENT=3590 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Audito tekstiniai elementai';

-- Dumping data for table emcor.ae: ~4 226 rows (approximately)
/*!40000 ALTER TABLE `ae` DISABLE KEYS */;
INSERT INTO `ae` (`ae_id`, `ae_hash`, `text`) VALUES
	(1, 1023, 'AUTO_DELETE_ALL_FROM_PL_DATA_MINUTE'),
	(2, 1915, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_TOTAL\';\r\nstep number := 0;\r\nst date;\r\npPL_ID T7.IRR;\r\npPL_T T7.DRR;\r\npAGGS_TYPE_ID T7.IRR;'),
	(3, 3963, 'Periodo pabaiga'),
	(4, 7026, 'AUTO_DELETE_ALL_FROM_PL_DATA_MONTH'),
	(5, 2802, 'Daugiau nei kelių parametrų grupė'),
	(6, 799, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nselect md_cnt,aggf_id into cnt1,gf1 from st_ml where ml_id=:1;\r\nselect md_cnt into cnt2 from st_ml where ml_id=:2;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT da+Trunc(Round((bt-da)*cnt2,6))/cnt2 t,c1,c2,c3,point_id, sum(val*Decode(gf1,3,24/cnt1,1)) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0 and count(*)*cnt2=cnt1\r\nthen \'1\' else \'14\'||decode(count(*)*cnt2,cnt1,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,point_id,da,da+Trunc(Round((bt-da)*cnt2,6))/cnt2 )r\r\nWHERE Nvl(:7,0)=1 OR NOT EXISTS (SELECT 0 FROM pl_data_valid\r\nWHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0);\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(7, 4107, '8'),
	(8, 9608, 'Daugiau nei %1 parametrų grupė'),
	(9, 9176, 'AUTO_DELETE_BGA_AUD_DATA'),
	(10, 9448, 'C:=:SAM_CODE'),
	(11, 249, 'lmt:=nvl(:4,10000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n  SELECT --1//*+ FULL*/\r\n  PL_ID,PL_T,AGGS_TYPE_ID\r\n  BULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA\r\n  WHERE pl_t<=CURRTMST+nvl(:1,1440)/1440+decode(aggs_type_id,4,31,1)\r\n  --5/and pl_t>=CURRTMST+decode(aggs_type_id,4,31,1)\r\n  AND ROWNUM<=lmt AND AGGS_TYPE_ID=4 ;\r\n if pPL_ID.count<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_NV WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n  commit;\r\nend loop;'),
	(12, 7534, 'select TRUNC(sysdate-1) dt, count(*) val from (\r\nselect distinct ses_time,das_id,ses_nr from sta_ph_data where ses_time >= TRUNC(sysdate-1) and ses_time < TRUNC(sysdate))'),
	(13, 1761, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))FROM spty WHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF FROM dual;\r\nselect b.ml_id into m1 from st_ml a , st_ml b where a.ml_id=:1 and\r\na.MS_ID=b.ms_id and a.DIR_ID=b.dir_id and a.tff_id=b.TFF_ID and a.AGGF_ID=b.aggf_id\r\nand b.aggs_id=8 and a.aggs_id=5 and a.md_id=5 and b.MD_ID=7;\r\nOPEN c_ROWS;\r\nLOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1 LIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,v,Decode(s,0,\'1\',\'14\') s FROM\r\n(SELECT c1,c2,c3,da,bt,read_time, val,ml_id,read_time_day,count(*) over (partition by da) cnt\r\n,max(decode(ml_id,m1,val))over(partition by da)-max(decode(ml_id,:1,val))over(partition by da) v,s\r\nfrom(SELECT c1,c2,c3,da,bt,read_time,val,ml_id,read_time_day,rank() over (partition by da,ml_id order by s,bt) rnk,s\r\nfrom(SELECT c1,c2,c3,da,bt,read_time,val,ml_id,max(decode(ml_id,:1,read_time)) over (partition by da) read_time_day\r\n,decode(ml_id,m1,HAS_SPECIFIC_DSTATUS) s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,m1))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL)\r\nwhere abs(decode(ml_id,m1,bt,read_time)-read_time_day)<=nvl(:8,5)/86400\r\nand read_time_day-da>=nvl(:9,0)/1440) where rnk=1) where cnt=2 AND ml_id=m1)r\r\nWHERE Nvl(:7,0)=1 OR NOT EXISTS (SELECT 0 FROM pl_data_valid\r\nWHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0);\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(14, 4518, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 date;\r\ns2 date;\r\nL NUMBER;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 AND (:6 IS NULL OR point_id=:6);'),
	(15, 9431, 'Diskretinio signalo tipo kodas, neprivalomas'),
	(16, 6291, 'Int'),
	(17, 8064, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nSELECT ML_ID\r\nINTO L\r\nFROM ML\r\nWHERE (MS_ID,DIR_ID,AGGS_ID,AGGF_ID,TFF_ID,MD_ID)\r\nIN (SELECT MS_ID,DIR_ID,AGGS_ID,AGGF_ID,TFF_ID,6\r\nFROM ML\r\nWHERE ML_ID = :2);\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM(SELECT c1,c2,c3,t,v\r\n,Decode(z,0,\'1\',\'14\') s FROM\r\n(SELECT c1,c2,c3,Decode(i,1,da,da+1) t\r\n,Max(Decode(i,1,val)) over (PARTITION BY point_id,m)+Decode(i,1,0,Sum(Decode(i,1,NULL,val)) over (PARTITION BY point_id,m ORDER BY da)) v\r\n,Decode(i,1,s,Max(s) over (PARTITION BY point_id,m ORDER BY da)) z,m,da from\r\n(SELECT a.*,Decode(val,NULL,2,has_specific_dstatus) s,Trunc(da,\'MM\') m,Decode(ml_id,L,1) i\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id, column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,L))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1,\'MM\'),s2))\r\n a )\r\n) WHERE z<2 AND m=Trunc(da+1,\'MM\'))r\r\nWHERE Nvl(:7,0)=1 OR NOT EXISTS (SELECT 0 FROM pl_data_valid\r\nWHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0);\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(18, 4575, 'a varchar2(250);\r\nhit number(1):=0;\r\nP1 T7.IRR;\r\nA1 T7.CRR;\r\norn number;'),
	(19, 6582, 'Diskretinių signalų generavimas iš šablono reikšmių'),
	(20, 6511, 'AUTO_DELETE_ALL_FROM_PL_DATA_INSTANT'),
	(21, 679, 'SELECT Nvl((SELECT amp FROM tmst WHERE tmst_code = \'AUTO_DELETE_BGA_AUD_DATA\'),DATE\'2000-01-01\'),Least(SYSDATE-Nvl(:1,10),SYSDATE-1/48) INTO a,b FROM dual;\r\ndelete aud_data where table_name in (\'GRP\',\'POINT_PPTY\',\'GR_GPTY\',\'GRC\') and ses_id is null and db_time>=a and db_time<b and rownum<=2000000;\r\nIF SQL%ROWCOUNT<2000000 THEN\r\nMERGE INTO tmst y\r\nUSING (SELECT \'AUTO_DELETE_BGA_AUD_DATA\' tmst_code,b amp FROM dual) u\r\n   ON (y.tmst_code = u.tmst_code)\r\nWHEN MATCHED THEN UPDATE SET\r\n y.amp= u.amp\r\nWHERE NOT y.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n (\r\n y.tmst_code\r\n,y.amp\r\n) values (\r\n u.tmst_code\r\n,u.amp\r\n);\r\nEND IF;'),
	(22, 1570, 'Energijos profilio rodmenų generavimas iš profilio reikšmių ir paros reikšmių'),
	(23, 7880, 'Automatinis visų naikinančios grupės duomenų įrašų trynimas'),
	(24, 2662, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n             FROM spty\r\n            WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nOPEN c_ROWS ( s0, s2);\r\nLOOP\r\n  FETCH c_ROWS\r\n  BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1\r\n  LIMIT pGF;\r\n  EXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n    (select c1,c2,c3,d t,v,\'1\' s\r\n    FROM (select b.*\r\n    ,Rank() over (PARTITION BY d ORDER BY i)r from\r\n    (select c1,c2,c3,i,d,Sum(v)v FROM\r\n    (select c1,c2,c3,i,da+Decode(i,2,Decode(ml_id,:1,0,-1),1) d,\r\n    case when ml_id=:1 and i=2 then -1 else 1 end*val v\r\n     from\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,:2))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1)-1,s2))\r\n     v,(SELECT LEVEL i FROM dual CONNECT BY LEVEL<=2),\r\n         (SELECT DISTINCT point_id, Trunc(mou_bt) m FROM mou) u\r\n    WHERE v.point_id = u.point_id(+)\r\n      AND v.da = u.m (+)\r\n      AND u.point_id IS NULL\r\n      AND v.has_specific_dstatus=0\r\n    ) GROUP BY c1,c2,c3,i,d having Count(*)=2\r\n    ) b\r\n    ) WHERE r=1)r\r\nWHERE Nvl(:7,0)=1 OR NOT EXISTS (SELECT 0 FROM pl_data_valid\r\nWHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0);\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(25, 6410, 'Float'),
	(26, 8479, 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_PL_DATA_MONTH\')\r\n, TRUNC ((SYSDATE-interval \'11\' year), \'Y\')) INTO CURRTMST FROM DUAL;\r\nLIMIT_FOR_SELECT:=nvl(:4,10000);\r\nTS := SYSDATE;\r\nDELETED_ROWS_COUNTF := 0;\r\nwhile (not (CURRTMST + nvl(:1,5) / 1440 > ADD_MONTHS(SYSDATE, -nvl(:2,120)) OR SYSDATE > TS + nvl(:3,45) / 86400)) LOOP\r\nSELECT /*+ FIRST_ROWS(10000) */ A.PL_ID,A.PL_T,A.AGGS_TYPE_ID\r\nBULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA A\r\nWHERE A.DB_TIME >= CURRTMST AND A.DB_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND A.AGGS_TYPE_ID=4 AND ROWNUM<= LIMIT_FOR_SELECT;\r\nIF (SQL%FOUND) then\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J) ;\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_NV     WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA        WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nDELETED_ROWS_COUNTF := pPL_ID.COUNT;\r\nelse DELETED_ROWS_COUNTF:=0;END IF;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then\r\nCURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_MONTH\' ;\r\nIF (SQL%ROWCOUNT = 0)THEN\r\nINSERT INTO TMST (TMST_CODE,AMP) select \'AUTO_DELETE_ALL_FROM_PL_DATA_MONTH\',CURRTMST from dual\r\nwhere not exists (select 0 from tmst where TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_MONTH\');\r\nEND IF;END IF;END LOOP;COMMIT;\r\n'),
	(27, 6462, 'CURRTMST DATE;\r\npPL_ID T7.IRR;\r\npPL_T T7.DRR;\r\npAGGS_TYPE_ID T7.IRR;\r\npDB_TIME T7.DRR;\r\nI NUMBER;\r\nJ NUMBER;\r\nTS DATE;\r\nDELETED_ROWS_COUNTF NUMBER;\r\nDELETED_ROWS_COUNT_ALL NUMBER;\r\nANS VARCHAR2(250);\r\nmaximum number;\r\nlimit_for_select number;\r\n'),
	(28, 1209, 'BY_METER_TYPE'),
	(29, 842, 'DAY_FIXED_TOTALS_FROM_DAY_FIXED_AND_DAY_DATA'),
	(30, 1964, '10'),
	(31, 4972, 'N:=:DAY_COUNT'),
	(32, 2881, 'C:=:GR_CODE'),
	(33, 1900, 'Pagal nuskaitymo tašką'),
	(34, 9880, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n             FROM spty\r\n            WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nOPEN c_ROWS ( s0, s2);\r\nLOOP\r\n  FETCH c_ROWS\r\n  BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1\r\n  LIMIT pGF;\r\n  EXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n    (select c1,c2,c3,d t,v,\'1\' s\r\n    FROM (select b.*\r\n    ,Rank() over (PARTITION BY point_id,d ORDER BY i)r from\r\n    (select point_id,c1,c2,c3,i,d,Sum(v)v FROM\r\n    (select v.point_id,c1,c2,c3,i,da+Decode(i,2,Decode(ml_id,:1,0,-1),1) d,\r\n    case when ml_id=:1 and i=2 then -1 else 1 end*val v\r\n     from\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,:2))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1)-1,s2))\r\n     v,(SELECT LEVEL i FROM dual CONNECT BY LEVEL<=2),\r\n         (SELECT DISTINCT point_id, Trunc(mou_bt) m FROM mou) u\r\n    WHERE v.point_id = u.point_id(+)\r\n      AND v.da = u.m (+)\r\n      AND u.point_id IS NULL\r\n      AND v.has_specific_dstatus=0\r\n    ) GROUP BY point_id,c1,c2,c3,i,d having Count(*)=2\r\n    ) b\r\n    ) WHERE r=1)r\r\nWHERE Nvl(:7,0)=1 OR NOT EXISTS (SELECT 0 FROM pl_data_valid\r\nWHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0);\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(35, 838, 'XFAU_EMPTY_CN_CHK'),
	(36, 1411, 'C:=:DS_TYPE_CODE'),
	(37, 5708, 'Skylių išdavimas'),
	(38, 9115, 'Saugojant į buferį įjungti jau turimų importuojamų rodmenų atmetimo rėžimą'),
	(39, 3085, 'doom_gr_code:=:1;\r\nSELECT COUNT(*) INTO CNT FROM GR where GR_CODE=doom_gr_code;\r\nIF CNT = 1 THEN BEGIN\r\nSELECT gr_id into doom_gr_id FROM GR where gr_code=doom_gr_code;\r\nCURRSYSDATE:=sysdate;\r\nselect count(*) INTO gr_cnt from grp where gr_id=doom_gr_id;\r\nIF gr_cnt > 0 then\r\nBEGIN\r\ndelete gtts;\r\ninsert into gtts (id1, id2)\r\nwith a as (select /*+ MATERIALIZE */ c.ml_id ml_id from mlset_data c left join mlset b on (b.mlset_id=c.mlset_id) where b.mlset_code=:4)\r\nselect distinct pl_id, p.point_id from pl p, a where point_id in (select point_id from grp where gr_id=doom_gr_id) and (exists (select 0 from pl_data where pl_id=p.pl_id and (:5 IS NULL OR PL_T>=:5) and (:6 IS NULL OR PL_T<:6)) or\r\nexists (select 0 from pl_data_nv where pl_id=p.pl_id and (:5 IS NULL OR PL_T>=:5) and (:6 IS NULL OR PL_T<:6))) and p.ml_id = a.ml_id\r\nUNION ALL\r\nselect distinct pl_id, p.point_id from pl p where point_id in (select point_id from grp where gr_id=doom_gr_id) and (exists (select 0 from pl_data where pl_id=p.pl_id and (:5 IS NULL OR PL_T>=:5) and (:6 IS NULL OR PL_T<:6)) or\r\nexists (select 0 from pl_data_nv where pl_id=p.pl_id and (:5 IS NULL OR PL_T>=:5) and (:6 IS NULL OR PL_T<:6))) and NOT EXISTS (SELECT 0 FROM MLSET WHERE mlset_code=:4);\r\nfor x in (select point_id from grp where gr_id=doom_gr_id and point_id not in (select id2 from gtts)) LOOP\r\nans := GRP_D(PGR_ID => doom_gr_id, PPOINT_ID => x.point_id, PGRP_BT => null, WOC => 1);\r\nFOR j IN (with a as (select /*+ MATERIALIZE */ c.ml_id ml_id from mlset_data c left join mlset b on (b.mlset_id=c.mlset_id) where b.mlset_code=:4) select pl_id from pl p, a where point_id=x.point_id and p.ml_id=a.ml_id\r\nUNION ALL select pl_id from pl p where point_id=x.point_id AND NOT EXISTS (SELECT 0 FROM MLSET WHERE mlset_code=:4)) LOOP\r\nMERGE INTO plu y\r\nUSING (SELECT j.pl_id pl_id, 1 harder FROM dual) u\r\nON (y.pl_id = u.pl_id)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.harder = u.harder\r\nWHERE NOT y.harder = u.harder\r\nWHEN NOT MATCHED THEN INSERT\r\n(y.pl_id,y.harder) values (u.pl_id,u.harder);\r\nEND LOOP; --j\r\ncommit;\r\nEND LOOP; --x\r\nSELECT count(*) INTO cnt from gtts;\r\nIF cnt > 0\r\nTHEN\r\nBEGIN\r\n  FOR i in (select distinct id2 from gtts order by id2)\r\n  LOOP\r\n    BEGIN\r\n      WHILE sysdate < CURRSYSDATE + nvl(:2,45)/(60*60*24)\r\n      LOOP\r\n        delete pl_data a where a.pl_id IN (select id1 from gtts where id2=i.id2) and rownum<=nvl(:3,10000) and (:5 IS NULL OR PL_T>=:5) and (:6 IS NULL OR PL_T<:6);\r\n        IF SQL%ROWCOUNT = 0\r\n        THEN\r\n          delete pl_data_nv a where a.pl_id IN (select id1 from gtts where id2=i.id2) and rownum<=nvl(:3,10000) and (:5 IS NULL OR PL_T>=:5) and (:6 IS NULL OR PL_T<:6);\r\n          IF SQL%ROWCOUNT = 0\r\n          THEN\r\n            EXIT;\r\n          END IF;\r\n        END IF;\r\n        commit;\r\n      END LOOP;\r\n    END;\r\n  END LOOP;\r\nEND;\r\nEND IF;\r\nEND;\r\nEND IF; END; END IF;'),
	(40, 1032, 'LogoScreenAddressingType'),
	(41, 3117, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nselect md_cnt,aggf_id into cnt1,gf1 from st_ml where ml_id=:1;\r\nselect md_cnt into cnt2 from st_ml where ml_id=:2;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT /*da*/trunc(bt-(nvl(:8,0)/1440))+Trunc(Round((/*bt*/bt-(nvl(:8,0)/1440)-/*da*/trunc(bt-(nvl(:8,0)/1440)))*cnt2,6))/cnt2 t,c1,c2,c3,point_id, sum(val*Decode(gf1,3,24/cnt1,1)) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0 and count(*)*cnt2=cnt1\r\nthen \'1\' else \'14\'||decode(count(*)*cnt2,cnt1,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1)+(nvl(:8,0)/1440),s2+(nvl(:8,0)/1440)))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,point_id,/*da*/trunc(bt-(nvl(:8,0)/1440)),/*da*/trunc(bt-(nvl(:8,0)/1440))+Trunc(Round((/*bt*/bt-(nvl(:8,0)/1440)-/*da*/trunc(bt-(nvl(:8,0)/1440)))*cnt2,6))/cnt2 )r\r\nWHERE Nvl(:7,0)=1 OR NOT EXISTS (SELECT 0 FROM pl_data_valid\r\nWHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0);\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(42, 4712, 'Automatinis visų matavimo taškų matavimo linijų suminių fiksuotų iki mėn. uomenų įrašų trynimas'),
	(43, 3831, '19'),
	(44, 2651, 'N:=:DEPTH2'),
	(45, 6772, 'Registrų adresacijos tipas'),
	(46, 6504, 'Parų kiekis į ateitį, nusakantis periodo pradžią'),
	(47, 161, '3'),
	(48, 6237, 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))FROM spty WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF FROM dual;\r\nselect b.ml_id into m1 from st_ml a , st_ml b where a.ml_id=:1 and\r\na.MS_ID=b.ms_id and a.DIR_ID=b.dir_id and a.tff_id=b.TFF_ID and a.AGGF_ID=b.aggf_id\r\nand b.aggs_id=8 and a.aggs_id=6 and a.md_id=6 and b.MD_ID=7;\r\nOPEN c_ROWS; LOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1 LIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,mo t,v,Decode(s,0,\'1\',\'14\') s FROM\r\n(SELECT c1,c2,c3,bt,read_time, val,ml_id,read_time_mon,count(*) over (partition by mo) cnt\r\n,max(decode(ml_id,m1,val))over(partition by mo)-max(decode(ml_id,:1,val))over(partition by mo) v,s,mo\r\nfrom(SELECT c1,c2,c3,bt,read_time,val,ml_id,read_time_mon,rank() over (partition by mo,ml_id order by s,bt) rnk,s,mo\r\nfrom(SELECT c1,c2,c3,bt,read_time,val,ml_id,max(decode(ml_id,:1,read_time)) over (partition by trunc(da,\'MM\')) read_time_mon\r\n,decode(ml_id,m1,HAS_SPECIFIC_DSTATUS) s,trunc(da,\'MM\') mo\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,m1))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL)\r\nwhere abs(decode(ml_id,m1,bt,read_time)-read_time_mon)<=nvl(:8,5)/86400\r\nand read_time_mon-mo>=nvl(:9,0)/1440) where rnk=1) where cnt=2 AND ml_id=m1)r\r\nWHERE Nvl(:7,0)=1 OR NOT EXISTS (SELECT 0 FROM pl_data_valid\r\nWHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0);\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(49, 161, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\ngf1 NUMBER(2);\r\ncnt1 NUMBER(5);\r\ncnt2 NUMBER(5);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nCURSOR c_ROWS ( s0 DATE, s2 DATE) IS\r\nWITH a AS\r\n(SELECT /*+ materialize*/\r\n        SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\n   FROM GEN_IDs\r\n  WHERE ml_id=:2 AND bga_id=:0 AND point_id=Nvl(:6,point_id)\r\n)\r\nSELECT /*+ use_nl(a b c) index(c plep_pk)*/ SEP_ID,a.PL_ID,POINT_ID ,aggs_type_id\r\n  ,Add_Months(CASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\n  Min(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\n  ELSE s0 END ,-1)\r\n  FROM a\r\n  LEFT JOIN plu b ON (a.pl_id=b.pl_id AND Nvl(:7,0)=0)\r\n  LEFT JOIN plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\n GROUP BY SEP_ID,a.PL_ID,POINT_ID,aggs_type_id;'),
	(50, 3803, 'ANS VARCHAR2(250);\r\nvGR number;\r\nvNOW DATE;'),
	(51, 285, 'Parų kiekis į ateitį, nusakantis periodo pabaigą'),
	(52, 1327, 'User Mir_S'),
	(53, 5638, 'Tolesnis nuskaitytų skaitiklio parametrų apdorojimas'),
	(54, 1548, 'Automatinis visų matavimo taškų matavimo linijų duomenų įrašų trynimas'),
	(55, 9542, 'User_Mir_S'),
	(56, 4726, 'Int16'),
	(57, 1205, 'STORE_PL_BUF_REJECTION'),
	(58, 8926, ' SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_PL_DATA\')\r\n , TRUNC ((SYSDATE-interval \'5\' year), \'Y\')) INTO CURRTMST FROM DUAL;\r\nLIMIT_FOR_SELECT:=nvl(:4,10000);\r\nTS := SYSDATE;\r\nDELETED_ROWS_COUNTF := 0;\r\nwhile (not (CURRTMST + nvl(:1,5) / 1440 > ADD_MONTHS(SYSDATE, -nvl(:2,36)) OR SYSDATE > TS + nvl(:3,45) / 86400))\r\nLOOP\r\nSELECT /*+ FIRST_ROWS(10000) */ A.PL_ID,A.PL_T,A.AGGS_TYPE_ID\r\nBULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA A\r\nWHERE A.DB_TIME >= CURRTMST AND A.DB_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND ROWNUM<= LIMIT_FOR_SELECT;\r\nIF (SQL%FOUND) then\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J) ;\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_NV     WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA        WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nDELETED_ROWS_COUNTF := pPL_ID.COUNT;\r\nelse\r\nDELETED_ROWS_COUNTF:=0;\r\nEND IF;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then\r\nCURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA\' ;\r\nIF (SQL%ROWCOUNT = 0)\r\nTHEN\r\nINSERT INTO TMST(TMST_CODE,AMP) select \'AUTO_DELETE_ALL_FROM_PL_DATA\',CURRTMST from dual\r\nwhere not exists (select 0 from tmst where TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA\');\r\nEND IF;\r\nEND IF;\r\nEND LOOP;\r\nCOMMIT;\r\n'),
	(59, 6219, 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS (s0, s2);\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(select c1,c2,c3,d t,v,\'1\' s\r\nFROM (select b.*\r\n,Rank() over (PARTITION BY d ORDER BY i)r from\r\n(select c1,c2,c3,i,d,Sum(v)v FROM\r\n(select c1,c2,c3,i, ADD_MONTHS(da,Decode(i,2,Decode(ml_id,:1,0,-1),1)) d,\r\ncase when ml_id=:1 and i=2 then -1 else 1 end*val v\r\nfrom\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,:2))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1)-1,s2))\r\n v,(select level i from dual connect by level<=2)\r\n,(SELECT DISTINCT point_id, Trunc(mou_bt,\'MM\') m FROM mou) u\r\nwhere v.point_id = u.point_id(+)\r\nAND v.da = u.m (+)\r\nAND u.point_id IS NULL\r\nAND v.has_specific_dstatus=0\r\n) GROUP BY c1,c2,c3,i,d having Count(*)=2\r\n) b\r\n) where r=1)r\r\nWHERE Nvl(:7,0)=1 OR NOT EXISTS (SELECT 0 FROM pl_data_valid\r\nWHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0);\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(60, 2936, 'N:=:LOWER_LIMIT'),
	(61, 1081, 'Automatinis visų matavimo taškų matavimo linijų sekundinių duomenų įrašų trynimas'),
	(62, 1494, '17'),
	(63, 2678, 'Suminių, fiksuotų kas parą, generavimas iš ankstesnių reikšmių ir parų energijos'),
	(64, 7909, 'Ļī ņčļąģ ńšåäńņā čēģåšåķč˙'),
	(65, 9643, 'Grupės kodas, neprivalomas'),
	(66, 7335, '24'),
	(67, 321, ' SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_PL_DATA_MINUTE\')\r\n, TRUNC ((SYSDATE-interval \'5\' year), \'Y\')) INTO CURRTMST FROM DUAL;\r\nLIMIT_FOR_SELECT:=nvl(:4,10000);\r\nTS := SYSDATE;\r\nDELETED_ROWS_COUNTF := 0;\r\nwhile (not (CURRTMST + nvl(:1,5) / 1440 > SYSDATE-nvl(:2,31) OR SYSDATE > TS + nvl(:3,45) / 86400)) LOOP\r\nSELECT /*+ FIRST_ROWS(10000) */ A.PL_ID,A.PL_T,A.AGGS_TYPE_ID\r\nBULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA A\r\nWHERE A.DB_TIME >= CURRTMST AND A.DB_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND A.AGGS_TYPE_ID=1 AND ROWNUM<= LIMIT_FOR_SELECT;\r\nIF (SQL%FOUND) then\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J) ;\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_NV     WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA        WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nDELETED_ROWS_COUNTF := pPL_ID.COUNT;\r\nelse DELETED_ROWS_COUNTF:=0;END IF;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then\r\nCURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_MINUTE\' ;\r\nIF (SQL%ROWCOUNT = 0)THEN\r\nINSERT INTO TMST (TMST_CODE,AMP) select \'AUTO_DELETE_ALL_FROM_PL_DATA_MINUTE\',CURRTMST from dual\r\nwhere not exists (select 0 from tmst where TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_MINUTE\');\r\nEND IF;END IF;END LOOP;COMMIT;\r\n'),
	(68, 6986, 'lmt:=nvl(:4,10000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n  SELECT --1//*+ FULL*/\r\n  PL_ID,PL_T,AGGS_TYPE_ID\r\n  BULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA\r\n  WHERE pl_t<=CURRTMST+nvl(:1,1440)/1440+decode(aggs_type_id,4,31,1)\r\n  --5/and pl_t>=CURRTMST+decode(aggs_type_id,4,31,1)\r\n  AND ROWNUM<=lmt;\r\n if pPL_ID.count<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_NV WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n  commit;\r\nend loop;'),
	(69, 8658, 'Nuėmus kodo ir pavadinimo paveldėjimo požymį, nenurodytas nei kodas, nei pavadinimas'),
	(70, 4382, 'vNOW:=sysdate;\r\nselect gr_id into vGR from gr where gr_code=:1;\r\nif vGR is not null then\r\n delete gtts;\r\n insert /*+ append*/ into gtts(id1,id2)\r\n with a as (select /*+ MATERIALIZE*/ c.ml_id\r\n from mlset_data c left join mlset b on(b.mlset_id=c.mlset_id) where b.mlset_code=:4)\r\n select p.pl_id,p.point_id from grp g join pl p on(p.point_id=g.point_id) join a on(a.ml_id=p.ml_id)\r\n where g.gr_id=vGR\r\n union all\r\n select p.pl_id,p.point_id from grp g join pl p on(p.point_id=g.point_id)\r\n where g.gr_id=vGR and :4 is null;\r\n commit;\r\n for i in(select distinct id2 from gtts)loop\r\n  delete pl_data a where a.pl_id IN (select id1 from gtts where id2=i.id2)\r\n   and rownum<=nvl(:3,10000) and (:5 IS NULL OR PL_T>=:5) and (:6 IS NULL OR PL_T<:6);\r\n  IF SQL%ROWCOUNT<nvl(:3,10000) THEN\r\n   delete pl_data_nv a where a.pl_id IN (select id1 from gtts where id2=i.id2)\r\n    and rownum<=nvl(:3,10000) and (:5 IS NULL OR PL_T>=:5) and (:6 IS NULL OR PL_T<:6);\r\n   IF SQL%ROWCOUNT<nvl(:3,10000) THEN\r\n    merge into PLU y using (select g.id1 pl_id,1 harder from gtts g where g.id2=i.id2) u\r\n    on(y.pl_id=u.pl_id)\r\n    WHEN MATCHED THEN UPDATE SET y.harder = u.harder WHERE NOT y.harder=u.harder\r\n    WHEN NOT MATCHED THEN INSERT(y.pl_id,y.harder)values(u.pl_id,u.harder);\r\n    ans:=GRP_D(PGR_ID=>vGR,PPOINT_ID=>i.id2,WOC=>1);\r\n   end if;\r\n  end if;\r\n  commit;\r\n  if sysdate<vNOW+nvl(:2,45)/86400 then exit; end if;\r\n end loop;\r\nend if;\r\nexception when no_data_found then null;'),
	(71, 1414, 'Automatinis visų matavimo taškų matavimo linijų suminių nefiksuotų duomenų įrašų trynimas'),
	(72, 2218, 'lmt:=nvl(:4,10000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=SYSDATE-nvl(:2,31)\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n  SELECT --1//*+ FULL*/\r\n  PL_ID,PL_T,AGGS_TYPE_ID\r\n BULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA\r\n  WHERE pl_t<=CURRTMST+nvl(:1,1440)/1440+decode(aggs_type_id,4,31,1)\r\n  --5/and pl_t>=CURRTMST+decode(aggs_type_id,4,31,1)\r\n AND ROWNUM<=lmt AND AGGS_TYPE_ID=6;\r\n if pPL_ID.count<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_NV WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n  commit;\r\nend loop;'),
	(73, 3044, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_TMONFIX\';\r\nstep number := 0;\r\nst date;\r\npPL_ID T7.IRR;\r\npPL_T T7.DRR;\r\npAGGS_TYPE_ID T7.IRR;'),
	(74, 4301, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\ngf1 NUMBER(2);\r\ncnt1 NUMBER(5);\r\ncnt2 NUMBER(5);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nCURSOR c_ROWS ( s0 DATE, s2 DATE) IS\r\nWITH a AS\r\n(SELECT /*+ materialize*/\r\n        SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\n   FROM GEN_IDs\r\n  WHERE ml_id=:2 AND bga_id=:0 AND point_id=Nvl(:6,point_id)\r\n)\r\nSELECT /*+ use_nl(a b c) index(c plep_pk)*/ SEP_ID,a.PL_ID,POINT_ID ,aggs_type_id\r\n  ,CASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\n  Min(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\n  ELSE s0 END\r\n  FROM a\r\n  LEFT JOIN plu b ON (a.pl_id=b.pl_id AND Nvl(:7,0)=0)\r\n  LEFT JOIN plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\n GROUP BY SEP_ID,a.PL_ID,POINT_ID,aggs_type_id;'),
	(75, 7706, '21'),
	(76, 6152, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))FROM spty WHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF FROM dual;\r\nselect b.ml_id into m1 from st_ml a , st_ml b where a.ml_id=:1 and\r\na.MS_ID=b.ms_id and a.DIR_ID=b.dir_id and a.tff_id=b.TFF_ID and a.AGGF_ID=b.aggf_id\r\nand b.aggs_id=8 and a.aggs_id=5 and a.md_id=5 and b.MD_ID=7;\r\nOPEN c_ROWS;\r\nLOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1 LIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,v,Decode(s,0,\'1\',\'14\') s FROM\r\n(SELECT c1,c2,c3,da,bt,read_time, val,ml_id,read_time_day,count(*) over (partition by point_id,da) cnt\r\n,max(decode(ml_id,m1,val))over(partition by point_id,da)-max(decode(ml_id,:1,val))over(partition by point_id,da) v,s\r\nfrom(SELECT point_id,c1,c2,c3,da,bt,read_time,val,ml_id,read_time_day,rank() over (partition by point_id,da,ml_id order by s,bt) rnk,s\r\nfrom(SELECT point_id,c1,c2,c3,da,bt,read_time,val,ml_id,max(decode(ml_id,:1,read_time)) over (partition by point_id,da) read_time_day\r\n,decode(ml_id,m1,HAS_SPECIFIC_DSTATUS) s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,m1))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL)\r\nwhere abs(decode(ml_id,m1,bt,read_time)-read_time_day)<=nvl(:8,5)/86400\r\nand read_time_day-da>=nvl(:9,0)/1440) where rnk=1) where cnt=2 AND ml_id=m1)r\r\nWHERE Nvl(:7,0)=1 OR NOT EXISTS (SELECT 0 FROM pl_data_valid\r\nWHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0);\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(77, 1368, '9'),
	(78, 7242, 'N:=:SHIFT'),
	(79, 9779, 'Suminių reikšmių, fiksuotų kas parą, generavimas iš suminių ir einamųjų paros reikšmių'),
	(80, 1575, 'lmt:=nvl(:4,10000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n  SELECT --1//*+ FULL*/\r\n  PL_ID,PL_T,AGGS_TYPE_ID\r\n  BULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA\r\n  WHERE pl_t<=CURRTMST+nvl(:1,1440)/1440+decode(aggs_type_id,4,31,1)\r\n  --5/and pl_t>=CURRTMST+decode(aggs_type_id,4,31,1)\r\n  AND ROWNUM<=lmt AND AGGS_TYPE_ID=2;\r\n if pPL_ID.count<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_NV WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n  commit;\r\nend loop;'),
	(81, 1871, 'lmt:=nvl(:4,10000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n  SELECT --1//*+ FULL*/\r\n  PL_ID,PL_T,AGGS_TYPE_ID\r\n BULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA\r\n  WHERE pl_t<=CURRTMST+nvl(:1,1440)/1440+decode(aggs_type_id,4,31,1)\r\n  --5/and pl_t>=CURRTMST+decode(aggs_type_id,4,31,1)\r\n AND ROWNUM<=lmt AND pl_id IN\r\n  (SELECT pl_id FROM st_pl WHERE aggs_id=8 and not md_id in (5,6,7));\r\n if pPL_ID.count<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_NV WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n  commit;\r\nend loop;'),
	(82, 6817, 'Suminių, fiksuotų kas mėnesį, generavimas iš ankstesnių reikšmių ir mėnesių energijos'),
	(83, 9712, 'a:=prepare_scaler_read.run(:1);\r\nif a=\'0\' then\r\nhit:=1;\r\nend if;\r\npwo_execute(:1,:2,a);\r\nif a=\'0\' then\r\nhit:=1;\r\nDELETE gttt;\r\nINSERT INTO gttt (id1,id2,c1) VALUES (:1,:2,\'S\');\r\npwl_execute;\r\nend if;\r\nif hit=1 THEN\r\nCOMMIT;\r\nselect :2,\'0\' bulk collect into P1,A1 from dual;\r\ninit_fill_point_cfg(P1,A1,orn);\r\nif A1(1)=\'0\' then\r\nINSERT INTO ltl (req_type_code, rodo_id)\r\nSELECT req_type_code,orn FROM rc WHERE rc_id=5;\r\nelse\r\ncheck_pw_setting (:1,:2);\r\nend if;\r\nelse\r\ncheck_pw_setting (:1,:2);\r\na:=read_point_journal(:2,:1);\r\nend if;'),
	(84, 3708, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_TDAYFIX\';\r\nstep number := 0;\r\nst date;\r\npPL_ID T7.IRR;\r\npPL_T T7.DRR;\r\npAGGS_TYPE_ID T7.IRR;'),
	(85, 2087, 'Suminių reikšmių, fiksuotų kas mėnesį, generavimas iš suminių ir einamųjų mėnesio reikšmių'),
	(86, 7828, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_MINUTE\';\r\nstep number := 0;\r\nst date;\r\npPL_ID T7.IRR;\r\npPL_T T7.DRR;\r\npAGGS_TYPE_ID T7.IRR;'),
	(87, 6189, 'BY_DP'),
	(88, 6145, 'select user_id into r from st_curr_user;delete from gttq;\r\nFOR t IN(SELECT a.gr_id,a.gr_type_id,b.gr_type_id dp_gr_type_id FROM gr a,gr_type b\r\nWHERE a.gr_code=\'BY_DP\' AND b.gr_type_code=\'DP\') LOOP\r\nFOR h IN(SELECT gr_code,Max(gr_name)gr_name,Sum(i)i,Max(comp_id) comp_id\r\nFROM(\r\nSELECT DISTINCT comp_code gr_code,\'\' gr_name,-1 i,comp_id FROM st_grc WHERE cont_code=\'BY_DP\'\r\nUNION ALL\r\nSELECT DISTINCT \'BY_DP_\'||DP_CODE,DP_name,1,\'\'+0\r\nFROM st_se WHERE dp_deleted=0 AND src_et IS NULL\r\n)GROUP BY gr_code\r\nHAVING NOT Sum(i)=0\r\n)loop\r\nIF h.i=1 THEN SELECT gr_seq.NEXTVAL INTO f FROM dual;\r\ninsert into GR(GR_ID,USER_ID,GR_TYPE_ID,GR_CODE,IS_PUBLIC,GR_NAME)\r\nvalues(f,r,t.DP_GR_TYPE_ID,h.gr_code,1,h.gr_name);\r\ninsert into GRC(CONT_ID,COMP_ID)values(t.gr_id,f);\r\nELSE\r\nFOR y IN (SELECT * FROM grc WHERE cont_id=h.comp_id) LOOP\r\ndelete from grc where cont_id=y.comp_id or comp_id=y.comp_id;\r\ndelete from grp where gr_id=y.comp_id;\r\ndelete from gr where gr_id=y.comp_id;\r\nEND LOOP;\r\ndelete from grc where cont_id=h.comp_id or comp_id=h.comp_id;\r\ndelete from grp where gr_id=h.comp_id;\r\ndelete from gr where gr_id=h.comp_id;\r\nEND if;END LOOP;\r\nFOR m IN (SELECT gr_code,Max(gr_name)gr_name,Sum(i)i,Max(comp_id)comp_id,Max(u)u\r\nFROM (\r\nSELECT DISTINCT comp_code gr_code,\'\' gr_name,-1 i,comp_id,\'\' u\r\nFROM st_grc WHERE cont_id IN(SELECT comp_id FROM grc WHERE cont_id=t.gr_id)\r\nUNION all\r\nSELECT DISTINCT \'BY_DP_\'||DP_CODE||\'_\'||src_id,src_name,1,\r\n\'\'+0,\'BY_DP_\'||DP_CODE\r\nFROM st_se WHERE dp_deleted=0 AND src_et IS NULL\r\n)GROUP BY gr_code HAVING NOT Sum(i)=0\r\n)LOOP if m.i=1 then\r\nSELECT gr_seq.NEXTVAL INTO f FROM dual;\r\ninsert into GTTQ(id1,id2,c1,c2,c0,c9)\r\nvalues(f,t.DP_GR_TYPE_ID,m.gr_code,m.gr_name,\'I\',\'GR\');\r\nselect gr_id into g from gr where gr_code=m.u;\r\ninsert into GTTQ(id1,id2,c0,c9)values(f,g,\'I\',\'GRC\');\r\nelse\r\ndelete from grc where cont_id=m.comp_id or comp_id=m.comp_id;\r\ndelete from grp where gr_id=m.comp_id;\r\ndelete from gr where gr_id=m.comp_id;\r\nend if;end loop;\r\ninsert into GR(GR_ID,USER_ID,GR_TYPE_ID,GR_CODE,IS_PUBLIC,GR_NAME)\r\nselect id1,r,id2,c1,1,c2 from GTTQ where c0=\'I\' and c9=\'GR\';\r\ninsert into GRC(CONT_ID,COMP_ID)\r\nselect id2,id1 from GTTQ where c0=\'I\' and c9=\'GRC\';\r\ndelete from GTTQ;\r\nFOR d IN (SELECT gr_code,point_id,Sum(i) i,Max(gr_id) gr_id FROM (\r\nSELECT DISTINCT gr_id,gr_code,point_id,-1 i\r\nFROM st_grp WHERE gr_id IN(SELECT comp_id FROM grcj WHERE cont_id=t.gr_id)\r\nUNION all\r\nSELECT DISTINCT \'\'+0,\'BY_DP_\'||DP_CODE||\'_\'||src_id,point_id,1\r\nFROM st_se WHERE dp_deleted=0 AND src_et IS NULL AND point_id IS NOT null\r\n)GROUP BY gr_code,point_id\r\nHAVING NOT Sum(i)=0\r\n)LOOP\r\nIF d.i=1 THEN\r\nSELECT gr_id INTO f FROM gr WHERE gr_code=d.gr_code;\r\ninsert into GTTQ(id1,id2,c0,c9)values(f,d.point_id,\'I\',\'GRP\');\r\nELSE\r\ninsert into GTTQ(id1,id2,c0,c9)values(d.GR_ID,d.point_id,\'D\',\'GRP\');\r\nEND if;END LOOP;\r\ndelete from grp where grp_bt=Date\'1899-12-30\'\r\nand(gr_id,point_id)in(select id1,id2 from GTTQ where c0=\'D\' and c9=\'GRP\');\r\ninsert into GRP(GR_ID,POINT_ID)\r\nselect id1,id2 from GTTQ where c0=\'I\' and c9=\'GRP\';\r\ndelete from GTTQ;\r\nFOR s IN (SELECT gr_code,ds_id,Sum(i) i,Max(gr_id) gr_id FROM(\r\nSELECT DISTINCT gr_id,gr_code,ds_id,-1 i\r\nFROM st_ds_gr WHERE gr_id IN(SELECT comp_id FROM grcj WHERE cont_id=t.gr_id)\r\nUNION all\r\nSELECT DISTINCT \'\'+0,\'BY_DP_\'||DP_CODE||\'_\'||src_id,ds_id,1\r\nFROM st_se_ds WHERE dp_deleted=0 AND src_et IS NULL\r\n)GROUP BY gr_code,ds_id\r\nHAVING NOT Sum(i)=0\r\n)LOOP\r\nIF s.i=1 THEN\r\nSELECT gr_id INTO f FROM gr WHERE gr_code=s.gr_code;\r\ninsert into GTTQ(id1,id2,c0,c9)values(f,s.ds_id,\'I\',\'DS_GR\');\r\nELSE\r\ninsert into GTTQ(id1,id2,c0,c9)values(s.GR_ID,s.ds_id,\'D\',\'DS_GR\');\r\nEND if;\r\nEND LOOP;\r\ndelete from ds_gr where(gr_id,ds_id)in(select id1,id2 from GTTQ where c0=\'D\' and c9=\'DS_GR\');\r\ninsert into DS_GR(GR_ID,DS_ID) select id1,id2 from GTTQ where c0=\'I\' and c9=\'DS_GR\';\r\nend loop;'),
	(89, 8688, ' SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_PL_DATA_SEK\')\r\n, TRUNC ((SYSDATE-interval \'5\' year), \'Y\')) INTO CURRTMST FROM DUAL;\r\nLIMIT_FOR_SELECT:=nvl(:4,10000);\r\nTS := SYSDATE;\r\nDELETED_ROWS_COUNTF := 0;\r\nwhile (not (CURRTMST + nvl(:1,5) / 1440 > SYSDATE-nvl(:2,31) OR SYSDATE > TS + nvl(:3,45) / 86400)) LOOP\r\nSELECT /*+ FIRST_ROWS(10000) */ A.PL_ID,A.PL_T,A.AGGS_TYPE_ID\r\nBULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA A\r\nWHERE A.DB_TIME >= CURRTMST AND A.DB_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND A.AGGS_TYPE_ID=7 AND ROWNUM<= LIMIT_FOR_SELECT;\r\nIF (SQL%FOUND) then\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J) ;\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_NV     WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA        WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nDELETED_ROWS_COUNTF := pPL_ID.COUNT;\r\nelse DELETED_ROWS_COUNTF:=0;END IF;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then\r\nCURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_SEK\' ;\r\nIF (SQL%ROWCOUNT = 0)THEN\r\nINSERT INTO TMST (TMST_CODE,AMP) select \'AUTO_DELETE_ALL_FROM_PL_DATA_SEK\',CURRTMST from dual\r\nwhere not exists (select 0 from tmst where TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_SEK\');\r\nEND IF;END IF;END LOOP;COMMIT;\r\n'),
	(90, 1623, 'Periodo pradžia'),
	(91, 572, 'AUTO_DELETE_ALL_FROM_PL_DATA'),
	(92, 7703, '22'),
	(93, 7864, 'AUTO_DELETE_ALL_FROM_PL_DATA_SEK'),
	(94, 8413, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA\';\r\nstep number := 0;\r\nst date;\r\npPL_ID T7.IRR;\r\npPL_T T7.DRR;\r\npAGGS_TYPE_ID T7.IRR;'),
	(95, 6974, 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS (s0, s2);\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(select c1,c2,c3,d t,v,\'1\' s\r\nFROM (select b.*\r\n,Rank() over (PARTITION BY point_id,d ORDER BY i)r from\r\n(select point_id,c1,c2,c3,i,d,Sum(v)v FROM\r\n(select v.point_id,c1,c2,c3,i, ADD_MONTHS(da,Decode(i,2,Decode(ml_id,:1,0,-1),1)) d,\r\ncase when ml_id=:1 and i=2 then -1 else 1 end*val v\r\nfrom\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,:2))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1)-1,s2))\r\n v,(select level i from dual connect by level<=2)\r\n,(SELECT DISTINCT point_id, Trunc(mou_bt,\'MM\') m FROM mou) u\r\nwhere v.point_id = u.point_id(+)\r\nAND v.da = u.m (+)\r\nAND u.point_id IS NULL\r\nAND v.has_specific_dstatus=0\r\n) GROUP BY point_id,c1,c2,c3,i,d having Count(*)=2\r\n) b\r\n) where r=1)r\r\nWHERE Nvl(:7,0)=1 OR NOT EXISTS (SELECT 0 FROM pl_data_valid\r\nWHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0);\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(96, 7767, 'Kontrolės gylis minutėmis'),
	(97, 61, 'N:=:DEPTH'),
	(98, 6843, 'Word'),
	(99, 7734, 'lmt:=nvl(:4,10000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n  SELECT --1//*+ FULL*/\r\n  PL_ID,PL_T,AGGS_TYPE_ID\r\n  BULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA\r\n  WHERE pl_t<=CURRTMST+nvl(:1,1440)/1440+decode(aggs_type_id,4,31,1)\r\n  --5/and pl_t>=CURRTMST+decode(aggs_type_id,4,31,1)\r\n  AND ROWNUM<=lmt AND AGGS_TYPE_ID=5;\r\n if pPL_ID.count<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_NV WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n  commit;\r\nend loop;'),
	(100, 9974, 'AUTO_DELETE_ALL_FROM_PL_DATA_TDAYFIX'),
	(101, 5056, '15'),
	(102, 7830, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_PROFILE\';\r\nstep number := 0;\r\nst date;\r\npPL_ID T7.IRR;\r\npPL_T T7.DRR;\r\npAGGS_TYPE_ID T7.IRR;'),
	(103, 3851, 'a:=prepare_scaler_read.run(:1);\r\nif a=\'0\' then\r\nhit:=1;\r\nend if;\r\npwo_execute(:1,:2,a);\r\nif a=\'0\' then\r\nhit:=1;\r\nend if;\r\nif hit=1 THEN\r\nCOMMIT;\r\nselect :2,\'0\' bulk collect into P1,A1 from dual;\r\ninit_fill_point_cfg(P1,A1,orn);\r\nif A1(1)=\'0\' then\r\nINSERT INTO ltl (req_type_code, rodo_id)\r\nSELECT req_type_code,orn FROM rc WHERE rc_id=5;\r\nelse\r\ncheck_pw_setting (:1,:2);\r\nend if;\r\nelse\r\ncheck_pw_setting (:1,:2);\r\na:=read_point_journal(:2,:1);\r\nend if;'),
	(104, 5426, 'select sysdate dt, count(*) val from (\r\nselect distinct ses_nr from sta_ph_data where ses_time >= TRUNC(sysdate-1) and ses_time < TRUNC(sysdate))'),
	(105, 4295, 'D:<=:DA'),
	(106, 5189, 'DAY_FIXED_TOTALS_FROM_TOTALS_AND_DAY'),
	(107, 1107, 'lmt:=nvl(:4,10000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=SYSDATE-nvl(:2,31)\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n  SELECT --1//*+ FULL*/\r\n  PL_ID,PL_T,AGGS_TYPE_ID\r\n BULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA\r\n  WHERE pl_t<=CURRTMST+nvl(:1,1440)/1440+decode(aggs_type_id,4,31,1)\r\n  --5/and pl_t>=CURRTMST+decode(aggs_type_id,4,31,1)\r\n AND ROWNUM<=lmt AND AGGS_TYPE_ID=1;\r\n if pPL_ID.count<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_NV WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n  commit;\r\nend loop;'),
	(108, 984, 'loginiai adresai'),
	(109, 8724, 'AUTO_DELETE_ALL_FROM_PL_DATA_TMONFIX'),
	(110, 6483, '12'),
	(111, 5005, 'LogoScreenDataType'),
	(112, 1537, 'ANY_SUM_FROM_ANY_MIN_AVG_OR_SUM'),
	(113, 2501, 'lmt:=nvl(:4,10000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n  SELECT --1//*+ FULL*/\r\n  PL_ID,PL_T,AGGS_TYPE_ID\r\n BULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA\r\n  WHERE pl_t<=CURRTMST+nvl(:1,1440)/1440+decode(aggs_type_id,4,31,1)\r\n  --5/and pl_t>=CURRTMST+decode(aggs_type_id,4,31,1)\r\n AND ROWNUM<=lmt AND pl_id IN\r\n  (SELECT pl_id FROM st_pl WHERE aggs_id=8 and md_id in (5,6));\r\n if pPL_ID.count<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_NV WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n  commit;\r\nend loop;'),
	(114, 8458, 'Registro tipas LogoScreen'),
	(115, 7083, 'AUTO_DELETE_DOOM_CONTENTS'),
	(116, 4475, '1'),
	(117, 7628, 'Stambesnių intervalų (iki paros) sumos rodmenų generavimas iš smulkesnių intervalų'),
	(118, 4286, '20'),
	(119, 7801, 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_PL_DATA_INSTANT\')\r\n, TRUNC ((SYSDATE-interval \'5\' year), \'Y\')) INTO CURRTMST FROM DUAL;\r\nLIMIT_FOR_SELECT:=nvl(:4,10000);\r\nTS := SYSDATE;\r\nDELETED_ROWS_COUNTF := 0;\r\nwhile (not (CURRTMST + nvl(:1,5) / 1440 > SYSDATE-nvl(:2,31) OR SYSDATE > TS + nvl(:3,45) / 86400)) LOOP\r\nSELECT /*+ FIRST_ROWS(10000) */ A.PL_ID,A.PL_T,A.AGGS_TYPE_ID\r\nBULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA A\r\nWHERE A.DB_TIME >= CURRTMST AND A.DB_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND A.AGGS_TYPE_ID=6 AND ROWNUM<= LIMIT_FOR_SELECT;\r\nIF (SQL%FOUND) then\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J) ;\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_NV     WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA        WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nDELETED_ROWS_COUNTF := pPL_ID.COUNT;\r\nelse DELETED_ROWS_COUNTF:=0;END IF;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then\r\nCURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_INSTANT\' ;\r\nIF (SQL%ROWCOUNT = 0)THEN\r\nINSERT INTO TMST(TMST_CODE,AMP) select \'AUTO_DELETE_ALL_FROM_PL_DATA_INSTANT\',CURRTMST from dual\r\nwhere not exists (select 0 from tmst where TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_INSTANT\');\r\nEND IF;END IF;END LOOP;COMMIT;\r\n'),
	(120, 9633, 'DS_DATA_FROM_SAM'),
	(121, 9039, 'AUTO_DELETE_ALL_FROM_PL_DATA_DAY'),
	(122, 9903, 'Automatinis visų matavimo taškų matavimo linijų suminių fiksuotų iki mėn. duomenų įrašų trynimas'),
	(123, 5836, 'f number;\r\ng number;\r\nr number;'),
	(124, 6745, 'Užblokuoti sistemos vartotojai'),
	(125, 3409, 'WITH\r\np AS (SELECT SYSDATE-Nvl(:1,1)-10/1440 p1,SYSDATE-10/1440 p2 FROM dual)\r\n,i AS\r\n(SELECT p1,p2,ph_id,p2 - Greatest(p1,ses_time) v FROM (\r\nSELECT p1,p2,ph_id,ph_otype_id,ses_time,Rank() over (PARTITION BY ph_id ORDER BY src_atime desc,src_anr desc,nullif(ph_otype_id,2) desc) rnk\r\n FROM p,sta_ph_data WHERE src_atime>p1 AND src_atime<p2\r\n) WHERE rnk=1 AND NOT ph_otype_id=2)\r\n,d AS\r\n(\r\nSELECT p1,p2,ph_id,v FROM i\r\nUNION all\r\nSELECT p1,p2,ph_id,src_atime - Greatest(p1,ses_time) v FROM p,sta_ph_data\r\nWHERE src_atime>=p1 AND src_atime<p2 AND ph_otype_id=2 AND NOT src_atime=ses_time\r\n)\r\n,e AS\r\n(SELECT /*+materialize*/ * FROM (SELECT ph_id,Round(Sum(v)*100/(max(p2)-Max(p1)),2) prc FROM d GROUP BY ph_id) WHERE prc>=Nvl(:2,0))\r\n,f AS\r\n(SELECT dp_id,dp_code,ph_name,prc,Rank() over (PARTITION BY dp_id ORDER BY prc DESC,ph_id) r\r\nFROM e join ph USING (ph_id) join dp USING (dp_id))\r\nSELECT * FROM (\r\nSELECT -gr_id comp_id\r\n,To_Date(NULL) grc_bt\r\n,To_Date(NULL) grc_et\r\n,Rank() over (ORDER BY prc DESC,dp_id) grc_nr\r\n,substr(prc||\'% \'||ph_name,1,120) grc_desc\r\nFROM f\r\njoin gr b ON (b.gr_code=\'BY_DP_\'||f.DP_CODE)\r\nWHERE r=1\r\n) WHERE grc_nr<=10'),
	(126, 645, 'Automatinis visų matavimo taškų matavimo linijų mėnesių duomenų įrašų trynimas'),
	(127, 8595, 'Trinimą vykdyti tik žingsnio apimtyje'),
	(128, 5853, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nSELECT ML_ID\r\nINTO L\r\nFROM ML\r\nWHERE (MS_ID,DIR_ID,AGGS_ID,AGGF_ID,TFF_ID,MD_ID)\r\nIN (SELECT MS_ID,DIR_ID,AGGS_ID,AGGF_ID,TFF_ID,6\r\nFROM ML\r\nWHERE ML_ID = :2);\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM(SELECT c1,c2,c3,t,v\r\n,Decode(z,0,\'1\',\'14\') s FROM\r\n(SELECT c1,c2,c3,Decode(i,1,da,da+1) t\r\n,Max(Decode(i,1,val)) over (PARTITION BY m)+Decode(i,1,0,Sum(Decode(i,1,NULL,val)) over (PARTITION BY m ORDER BY da)) v\r\n,Decode(i,1,s,Max(s) over (PARTITION BY m ORDER BY da)) z,m,da from\r\n(SELECT a.*,Decode(val,NULL,2,has_specific_dstatus) s,Trunc(da,\'MM\') m,Decode(ml_id,L,1) i\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id, column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,L))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1,\'MM\'),s2))\r\n a )\r\n) WHERE z<2 AND m=Trunc(da+1,\'MM\'))r\r\nWHERE Nvl(:7,0)=1 OR NOT EXISTS (SELECT 0 FROM pl_data_valid\r\nWHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0);\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(129, 8775, 'select user_id into r from st_curr_user;delete from gttq;\r\nFOR t IN(SELECT a.gr_id,a.gr_type_id,b.gr_type_id dp_gr_type_id FROM gr a,gr_type b\r\nWHERE a.gr_code=\'BY_DP\' AND b.gr_type_code=\'DP\') LOOP\r\nFOR h IN(SELECT g,Max(n)n,Sum(i)i,Max(c)c\r\nFROM(\r\nSELECT DISTINCT comp_code g,\'\' n,-1 i,comp_id c FROM st_grc WHERE cont_code=\'BY_DP\'\r\nUNION ALL\r\nSELECT DISTINCT \'BY_DP_\'||DP_CODE,DP_name,1,\'\'+0\r\nFROM st_se WHERE dp_deleted=0 AND src_et IS NULL\r\n)GROUP BY g HAVING Sum(i)!=0\r\n)loop\r\nIF h.i=1 THEN SELECT gr_seq.NEXTVAL INTO f FROM dual;\r\ninsert into GR(GR_ID,USER_ID,GR_TYPE_ID,GR_CODE,IS_PUBLIC,GR_NAME)\r\nvalues(f,r,t.DP_GR_TYPE_ID,h.g,1,h.n);\r\ninsert into GRC(CONT_ID,COMP_ID)values(t.gr_id,f);\r\nELSE\r\nFOR y IN (SELECT comp_id c FROM grc WHERE cont_id=h.c) LOOP\r\ndelete from grc where cont_id=y.c or comp_id=y.c;\r\ndelete from grp where gr_id=y.c;\r\ndelete from gr where gr_id=y.c;\r\nEND LOOP;\r\ndelete from grc where cont_id=h.c or comp_id=h.c;\r\ndelete from grp where gr_id=h.c;\r\ndelete from gr where gr_id=h.c;\r\nEND if;END LOOP;\r\nFOR m IN (SELECT c,Max(n)n,Sum(i)i,Max(id)id,Max(u)u\r\nFROM (\r\nSELECT DISTINCT comp_code c,\'\' n,-1 i,comp_id id,\'\' u\r\nFROM st_grc WHERE cont_id IN(SELECT comp_id FROM grc WHERE cont_id=t.gr_id)\r\nUNION all\r\nSELECT DISTINCT \'BY_DP_\'||DP_CODE||\'_\'||src_id,src_name,1,\r\n\'\'+0,\'BY_DP_\'||DP_CODE\r\nFROM st_se WHERE dp_deleted=0 AND src_et IS NULL\r\n)GROUP BY c HAVING Sum(i)!=0\r\n)LOOP if m.i=1 then\r\nSELECT gr_seq.NEXTVAL INTO f FROM dual;\r\ninsert into GTTQ(id1,id2,c1,c2,c0,c9)\r\nvalues(f,t.DP_GR_TYPE_ID,m.c,m.n,\'I\',\'GR\');\r\nselect gr_id into g from gr where gr_code=m.u;\r\ninsert into GTTQ(id1,id2,c0,c9)values(f,g,\'I\',\'GRC\');\r\nelse\r\ndelete from grc where cont_id=m.id or comp_id=m.id;\r\ndelete from grp where gr_id=m.id;\r\ndelete from gr where gr_id=m.id;\r\nend if;end loop;\r\ninsert into GR(GR_ID,USER_ID,GR_TYPE_ID,GR_CODE,IS_PUBLIC,GR_NAME)\r\nselect id1,r,id2,c1,1,c2 from GTTQ where c0=\'I\' and c9=\'GR\';\r\ninsert into GRC(CONT_ID,COMP_ID)\r\nselect id2,id1 from GTTQ where c0=\'I\' and c9=\'GRC\';\r\ndelete from GTTQ;\r\nFOR d IN (SELECT gr_code c,point_id p,Sum(i)i,Max(gr_id)g FROM(\r\nSELECT DISTINCT gr_id,gr_code,point_id,-1 i\r\nFROM st_grp WHERE gr_id IN(SELECT comp_id FROM grcj WHERE cont_id=t.gr_id)\r\nUNION all\r\nSELECT DISTINCT \'\'+0,\'BY_DP_\'||DP_CODE||\'_\'||src_id,point_id,1\r\nFROM st_se WHERE dp_deleted=0 AND src_et IS NULL AND point_id IS NOT null\r\n)GROUP BY gr_code,point_id\r\nHAVING NOT Sum(i)=0\r\n)LOOP\r\nIF d.i=1 THEN\r\nSELECT gr_id INTO f FROM gr WHERE gr_code=d.c;\r\ninsert into GTTQ(id1,id2,c0,c9)values(f,d.p,\'I\',\'GRP\');\r\nELSE\r\ninsert into GTTQ(id1,id2,c0,c9)values(d.g,d.p,\'D\',\'GRP\');\r\nEND if;END LOOP;\r\ndelete from grp where grp_bt=Date\'1899-12-30\'\r\nand(gr_id,point_id)in(select id1,id2 from GTTQ where c0=\'D\' and c9=\'GRP\');\r\ninsert into GRP(GR_ID,POINT_ID)\r\nselect id1,id2 from GTTQ where c0=\'I\' and c9=\'GRP\';\r\ndelete from GTTQ;\r\nFOR s IN (SELECT gr_code,ds_id,Sum(i) i,Max(gr_id) gr_id FROM(\r\nSELECT DISTINCT gr_id,gr_code,ds_id,-1 i\r\nFROM st_ds_gr WHERE gr_id IN(SELECT comp_id FROM grcj WHERE cont_id=t.gr_id)\r\nUNION all\r\nSELECT DISTINCT \'\'+0,\'BY_DP_\'||DP_CODE||\'_\'||src_id,ds_id,1\r\nFROM st_se_ds WHERE dp_deleted=0 AND src_et IS NULL\r\n)GROUP BY gr_code,ds_id\r\nHAVING NOT Sum(i)=0\r\n)LOOP\r\nIF s.i=1 THEN\r\nSELECT gr_id INTO f FROM gr WHERE gr_code=s.gr_code;\r\ninsert into GTTQ(id1,id2,c0,c9)values(f,s.ds_id,\'I\',\'DS_GR\');\r\nELSE\r\ninsert into GTTQ(id1,id2,c0,c9)values(s.GR_ID,s.ds_id,\'D\',\'DS_GR\');\r\nEND if;\r\nEND LOOP;\r\ndelete from ds_gr where(gr_id,ds_id)in(select id1,id2 from GTTQ where c0=\'D\' and c9=\'DS_GR\');\r\ninsert into DS_GR(GR_ID,DS_ID) select id1,id2 from GTTQ where c0=\'I\' and c9=\'DS_GR\';\r\nend loop;\r\nFOR t IN (select * from dp,gr WHERE \'BY_DP_\'||dp_code=gr_code AND dp_name!=gr_name) LOOP\r\nUPDATE gr SET gr_name=t.dp_name WHERE gr_id=t.gr_id;\r\nEND LOOP;'),
	(130, 4815, ' SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_PL_DATA_DAY\')\r\n, TRUNC ((SYSDATE-interval \'6\' year), \'Y\')) INTO CURRTMST FROM DUAL;\r\nLIMIT_FOR_SELECT:=nvl(:4,10000);\r\nTS := SYSDATE;\r\nDELETED_ROWS_COUNTF := 0;\r\nwhile (not (CURRTMST + nvl(:1,5) / 1440 > ADD_MONTHS(SYSDATE, -nvl(:2,60)) OR SYSDATE > TS + nvl(:3,45) / 86400)) LOOP\r\nSELECT /*+ FIRST_ROWS(10000) */ A.PL_ID,A.PL_T,A.AGGS_TYPE_ID\r\nBULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA A\r\nWHERE A.DB_TIME >= CURRTMST AND A.DB_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND A.AGGS_TYPE_ID=3 AND ROWNUM<= LIMIT_FOR_SELECT;\r\nIF (SQL%FOUND) then\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J) ;\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_NV     WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA        WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nDELETED_ROWS_COUNTF := pPL_ID.COUNT;\r\nelse DELETED_ROWS_COUNTF:=0;END IF;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then\r\nCURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_DAY\' ;\r\nIF (SQL%ROWCOUNT = 0)THEN\r\nINSERT INTO TMST (TMST_CODE,AMP) select \'AUTO_DELETE_ALL_FROM_PL_DATA_DAY\',CURRTMST from dual\r\nwhere not exists (select 0 from tmst where TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_DAY\');\r\nEND IF;END IF;END LOOP;COMMIT;\r\n'),
	(131, 9780, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\ngf1 number(2);\r\ncnt1 number(5);\r\ncnt2 number(5);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 AND point_id=Nvl(:6,point_id);'),
	(132, 8441, 'Parametrų skaičius'),
	(133, 3413, '6'),
	(134, 1706, 'ANY_PROF_EN_FROM_ANY_PROF_EN_AND_DAY'),
	(135, 1953, '0'),
	(136, 5816, 'Pagal matavimo prietaisų tipus'),
	(137, 2715, 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_PL_DATA_TMONFIX\')\r\n, TRUNC ((SYSDATE-interval \'6\' year), \'Y\')) INTO CURRTMST FROM DUAL;\r\nLIMIT_FOR_SELECT:=nvl(:4,10000);\r\nTS := SYSDATE;\r\nDELETED_ROWS_COUNTF := 0;\r\nwhile (not (CURRTMST + nvl(:1,5) / 1440 > ADD_MONTHS(SYSDATE, -nvl(:2,60)) OR SYSDATE > TS + nvl(:3,45) / 86400)) LOOP\r\nSELECT /*+ FIRST_ROWS(10000) */ A.PL_ID,A.PL_T,A.AGGS_TYPE_ID\r\nBULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA A\r\nWHERE A.DB_TIME >= CURRTMST AND A.DB_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND A.pl_id IN (SELECT pl_id FROM st_pl WHERE aggs_id=8 and md_id in (5,6)) AND ROWNUM<= LIMIT_FOR_SELECT;\r\nIF (SQL%FOUND) then\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J) ;\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_NV     WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA        WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nDELETED_ROWS_COUNTF := pPL_ID.COUNT;\r\nelse DELETED_ROWS_COUNTF:=0;END IF;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then\r\nCURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_TMONFIX\' ;\r\nIF (SQL%ROWCOUNT = 0)THEN\r\nINSERT INTO TMST (TMST_CODE,AMP) select \'AUTO_DELETE_ALL_FROM_PL_DATA_TMONFIX\',CURRTMST from dual\r\nwhere not exists (select 0 from tmst where TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_TMONFIX\');\r\nEND IF;END IF;END LOOP;COMMIT;\r\n'),
	(138, 196, '4'),
	(139, 9003, 'Numeriai nuo 1 iki 6'),
	(140, 791, 'Automatinis audito įrašų apie duomenų keitimo operacijas, atliktas foninių užduočių, trynimas'),
	(141, 1989, '23'),
	(142, 9804, 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_PL_DATA_TOTAL\')\r\n, TRUNC ((SYSDATE-interval \'6\' year), \'Y\')) INTO CURRTMST FROM DUAL;\r\nLIMIT_FOR_SELECT:=nvl(:4,10000);\r\nTS := SYSDATE;\r\nDELETED_ROWS_COUNTF := 0;\r\nwhile (not (CURRTMST + nvl(:1,5) / 1440 > ADD_MONTHS(SYSDATE, -nvl(:2,60)) OR SYSDATE > TS + nvl(:3,45) / 86400)) LOOP\r\nSELECT /*+ FIRST_ROWS(10000) */ A.PL_ID,A.PL_T,A.AGGS_TYPE_ID\r\nBULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA A\r\nWHERE A.DB_TIME >= CURRTMST AND A.DB_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND A.pl_id IN (SELECT pl_id FROM st_pl WHERE aggs_id=8 and md_id=7) AND ROWNUM<= LIMIT_FOR_SELECT;\r\nIF (SQL%FOUND) then\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J) ;\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_NV     WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA        WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nDELETED_ROWS_COUNTF := pPL_ID.COUNT;\r\nelse DELETED_ROWS_COUNTF:=0;END IF;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then\r\nCURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_TOTAL\' ;\r\nIF (SQL%ROWCOUNT = 0)THEN\r\nINSERT INTO TMST (TMST_CODE,AMP) select \'AUTO_DELETE_ALL_FROM_PL_DATA_TOTAL\',CURRTMST from dual\r\nwhere not exists (select 0 from tmst where TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_TOTAL\');\r\nEND IF;END IF;END LOOP;COMMIT;\r\n'),
	(143, 6325, 'Automatinis visų matavimo taškų matavimo linijų paros profilio duomenų įrašų trynimas'),
	(144, 6477, '18'),
	(145, 4407, 'DAY_FIXED_TOTALS_FROM_MONTH_FIXED_AND_DAY_DATA'),
	(146, 828, 's0:=Trunc(Nvl(:4,SYSDATE-:3)); s2:=Nvl(Trunc(:5)+1,SYSDATE); SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty WHERE spty.spty_code=\'GENERATION_FETCH\'), 100) INTO pGF FROM dual;\r\nOPEN c_ROWS; LOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID LIMIT pGF;\r\nmi:=sPL_ID.Count; EXIT WHEN mi=0; select level BULK COLLECT INTO pNR from dual connect by level<=mi;\r\nDELETE GTTT; FORALL j in 1..mi INSERT INTO GTTT (id0,id1) values (pNR(j),sPL_ID(j));\r\nSELECT d BULK COLLECT INTO s1 FROM\r\n(SELECT /*+ use_nl(a b c) index(c plep_pk)*/ id0,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END d FROM gttt a\r\nleft join plu b ON (a.id1=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.id1=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY id0 ORDER BY id0);\r\nDELETE GTTT;\r\nFORALL j IN 1..mi\r\nINSERT INTO gttt (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT\r\nNULL,NULL,sPL_ID(j),sSEP_ID(j),bt\r\n,\'\',round(new_val,6),Nvl(:7,0),CASE WHEN s=0 AND p=0 AND bad=1 THEN \'1\' else \'14\' end\r\n,SYSDATE,\'\',sAGGS_TYPE_ID(j) FROM\r\n(with a1 as (\r\nSELECT point_id,ml_id,da,bt,val,HAS_SPECIFIC_DSTATUS s\r\nFROM v_ar\r\nWHERE point_id=sPOINT_ID(j)\r\nAND ml_id=:1\r\nAND da>=Trunc(s1(j)) AND da<s2\r\nAND NOT val IS NULL )\r\nselect * from (select a.* ,case when a.val is null then (c.val-sum)/bad end as new_val , c.s from (select * from(\r\nSELECT point_id,ml_id,da,bt,val\r\n,sum(decode(val,null,1,0))over(partition by point_id, ml_id, da) bad\r\n,sum(val)over(partition by point_id, ml_id, da) Sum\r\n,max(Nvl2(val,HAS_SPECIFIC_DSTATUS,NULL))over(partition by point_id, ml_id, da) p\r\nfrom(\r\n select point_id, ml_id, da, bt\r\n ,decode(ssep_id,tsep_id,null,hsd)HAS_SPECIFIC_DSTATUS\r\n ,decode(ssep_id,tsep_id,null,val)val\r\n from(\r\n select sSEP_ID(j) tsep_id, point_id, ml_id,da,bt, HAS_SPECIFIC_DSTATUS hsd, val\r\n ,(select sep_id from pl_data_valid b where sPL_ID(j)=PL_ID and b.pl_t=a.bt\r\n and sAGGS_TYPE_ID(j)=AGGS_TYPE_ID and sSEP_ID(j)=sep_id and Nvl(:7,0)=1) ssep_id\r\n FROM v_ar a WHERE point_id=sPOINT_ID(j) AND ml_id=:2 AND da>=Trunc(s1(j)) AND da<s2\r\n )d\r\n )\r\n)where bad>0) a join a1 c on (a.point_id=c.point_id and a.da=c.da)\r\n) where new_val is not null\r\n) f;\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\nWHERE Nvl(:7,0)=1 OR NOT EXISTS (SELECT 0 FROM pl_data_valid\r\nWHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND storable=1 and improvable=0);\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(147, 6395, 'Labiausiai užimtų ryšių kanalų nuskaitymo taškai'),
	(148, 4584, '2'),
	(149, 109, 'Automatinis visų matavimo taškų matavimo linijų minutinių duomenų įrašų trynimas'),
	(150, 169, 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_PL_DATA_PROFILE\')\r\n, TRUNC ((SYSDATE-interval \'6\' year), \'Y\')) INTO CURRTMST FROM DUAL;\r\nLIMIT_FOR_SELECT:=nvl(:4,10000);\r\nTS := SYSDATE;\r\nDELETED_ROWS_COUNTF := 0;\r\nwhile (not (CURRTMST + nvl(:1,5) / 1440 > ADD_MONTHS(SYSDATE, -nvl(:2,60)) OR SYSDATE > TS + nvl(:3,45) / 86400)) LOOP\r\nSELECT /*+ FIRST_ROWS(10000) */ A.PL_ID,A.PL_T,A.AGGS_TYPE_ID\r\nBULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA A\r\nWHERE A.DB_TIME >= CURRTMST AND A.DB_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND A.AGGS_TYPE_ID=2 AND ROWNUM<= LIMIT_FOR_SELECT;\r\nIF (SQL%FOUND) then\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J) ;\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_NV     WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA        WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nDELETED_ROWS_COUNTF := pPL_ID.COUNT;\r\nelse DELETED_ROWS_COUNTF:=0;END IF;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then\r\nCURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_PROFILE\' ;\r\nIF (SQL%ROWCOUNT = 0)THEN\r\nINSERT INTO TMST (TMST_CODE,AMP) select \'AUTO_DELETE_ALL_FROM_PL_DATA_PROFILE\',CURRTMST from dual\r\nwhere not exists (select 0 from tmst where TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_PROFILE\');\r\nEND IF;END IF;END LOOP;COMMIT;\r\n'),
	(151, 2652, 'fiziniai adresai'),
	(152, 4541, 'a DATE;\r\nb DATE;'),
	(153, 344, 'lmt:=nvl(:4,10000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=SYSDATE-nvl(:2,31)\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n  SELECT --1//*+ FULL*/\r\n  PL_ID,PL_T,AGGS_TYPE_ID\r\n BULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA\r\n  WHERE pl_t<=CURRTMST+nvl(:1,1440)/1440+decode(aggs_type_id,4,31,1)\r\n  --5/and pl_t>=CURRTMST+decode(aggs_type_id,4,31,1)\r\n AND ROWNUM<=lmt AND AGGS_TYPE_ID=7;\r\n if pPL_ID.count<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_NV WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n  commit;\r\nend loop;'),
	(154, 1707, 'Automatinis visų matavimo taškų matavimo linijų momentinių duomenų įrašų trynimas'),
	(155, 4557, '7'),
	(156, 501, 's0:=Trunc(Nvl(:4,SYSDATE-:3)); s2:=Nvl(Trunc(:5)+1,SYSDATE); SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty WHERE spty.spty_code=\'GENERATION_FETCH\'), 100) INTO pGF FROM dual;\r\nOPEN c_ROWS; LOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID LIMIT pGF;\r\nmi:=sPL_ID.Count; EXIT WHEN mi=0; select level BULK COLLECT INTO pNR from dual connect by level<=mi;\r\nDELETE GTTT; FORALL j in 1..mi INSERT INTO GTTT (id0,id1) values (pNR(j),sPL_ID(j));\r\nSELECT d BULK COLLECT INTO s1 FROM\r\n(SELECT /*+ use_nl(a b c) index(c plep_pk)*/ id0,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END d FROM gttt a\r\nleft join plu b ON (a.id1=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.id1=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY id0 ORDER BY id0);\r\nDELETE GTTT;\r\nFORALL j IN 1..mi\r\nINSERT INTO gttt (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT\r\nNULL,NULL,sPL_ID(j),sSEP_ID(j),bt\r\n,\'\',round(new_val,6),Nvl(:7,0),\'14\'\r\n,SYSDATE,\'\',sAGGS_TYPE_ID(j) FROM\r\n(with a1 as (\r\nSELECT point_id,ml_id,da,bt,val,decode(HAS_SPECIFIC_DSTATUS,0,1,14) s\r\nFROM v_ar\r\nWHERE point_id=sPOINT_ID(j)\r\nAND ml_id=:1\r\nAND da>=Trunc(s1(j)) /*AND bt>=s1(j)*/ AND da<s2\r\nAND NOT val IS NULL )\r\nselect * from (select a.* ,case when a.val is null then (c.val-sum)/bad end as new_val , c.s from (select * from(\r\nSELECT point_id,ml_id,da,bt,val, sum(decode(val,null,1,0))over(partition by point_id, ml_id, da) bad,sum(val)over(partition by point_id, ml_id, da) sum\r\nFROM v_ar WHERE point_id=sPOINT_ID(j) AND ml_id=:2 AND da>=Trunc(s1(j)) /*AND bt>=s1(j)*/ AND da<s2\r\n)where bad>0) a join a1 c on (a.point_id=c.point_id and a.da=c.da)\r\n) where new_val is not null\r\n) f;\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\nWHERE Nvl(:7,0)=1 OR NOT EXISTS (SELECT 0 FROM pl_data_valid\r\nWHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND storable=1 and improvable=0);\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(157, 7457, 'Ryšio kanalų unikalių sesijų kiekis per parą'),
	(158, 8683, 'BOTTOM_10_DP_BY_SES_DURATION'),
	(159, 9935, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_MONTH\';\r\nstep number := 0;\r\nst date;\r\npPL_ID T7.IRR;\r\npPL_T T7.DRR;\r\npAGGS_TYPE_ID T7.IRR;'),
	(160, 1585, 'D:>=:DA'),
	(161, 3212, 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))FROM spty WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF FROM dual;\r\nselect b.ml_id into m1 from st_ml a , st_ml b where a.ml_id=:1 and\r\na.MS_ID=b.ms_id and a.DIR_ID=b.dir_id and a.tff_id=b.TFF_ID and a.AGGF_ID=b.aggf_id\r\nand b.aggs_id=8 and a.aggs_id=6 and a.md_id=6 and b.MD_ID=7;\r\nOPEN c_ROWS; LOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1 LIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,mo t,v,Decode(s,0,\'1\',\'14\') s FROM\r\n(SELECT c1,c2,c3,bt,read_time, val,ml_id,read_time_mon,count(*) over (partition by point_id,mo) cnt\r\n,max(decode(ml_id,m1,val))over(partition by point_id,mo)-max(decode(ml_id,:1,val))over(partition by point_id,mo) v,s,mo\r\nfrom(SELECT point_id,c1,c2,c3,bt,read_time,val,ml_id,read_time_mon,rank() over (partition by point_id,mo,ml_id order by s,bt) rnk,s,mo\r\nfrom(SELECT point_id,c1,c2,c3,bt,read_time,val,ml_id,max(decode(ml_id,:1,read_time)) over (partition by point_id,trunc(da,\'MM\')) read_time_mon\r\n,decode(ml_id,m1,HAS_SPECIFIC_DSTATUS) s,trunc(da,\'MM\') mo\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,m1))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL)\r\nwhere abs(decode(ml_id,m1,bt,read_time)-read_time_mon)<=nvl(:8,5)/86400\r\nand read_time_mon-mo>=nvl(:9,0)/1440) where rnk=1) where cnt=2 AND ml_id=m1)r\r\nWHERE Nvl(:7,0)=1 OR NOT EXISTS (SELECT 0 FROM pl_data_valid\r\nWHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0);\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(162, 3625, 'CURRTMST DATE;\r\npPL_ID T7.IRR;\r\npPL_T T7.DRR;\r\npAGGS_TYPE_ID T7.IRR;\r\nI NUMBER;\r\nJ NUMBER;\r\nTS DATE;\r\nDELETED_ROWS_COUNTF NUMBER;\r\nDELETED_ROWS_COUNT_ALL NUMBER;\r\nANS VARCHAR2(250);\r\nmaximum number;\r\nlimit_for_select number;\r\n'),
	(163, 3330, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nm1 number;\r\nCURSOR c_ROWS IS\r\nWITH a AS (SELECT /*+ materialize*/ SEP_ID,PL_ID,POINT_ID,aggs_type_id FROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 AND point_id=Nvl(:6,point_id))\r\nSELECT /*+ use_nl(a b c) index(c plep_pk)*/ SEP_ID,a.PL_ID,POINT_ID ,aggs_type_id\r\n,CASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END from a\r\nleft join plu b ON (a.pl_id=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY SEP_ID,a.PL_ID,POINT_ID,aggs_type_id;'),
	(164, 5187, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_INSTANT\';\r\nstep number := 0;\r\nst date;\r\npPL_ID T7.IRR;\r\npPL_T T7.DRR;\r\npAGGS_TYPE_ID T7.IRR;'),
	(165, 988, 'N#1_24'),
	(166, 2140, 'Fiksuotų kas parą suminių duomenų generavimas iš fiksuotų kas mėnesį ir parų duomenų'),
	(167, 3405, 'STA.MESSAGE_1'),
	(168, 539, '11'),
	(169, 5742, 'MONTH_FIXED_TOTALS_FROM_MONTH_FIX_AND_MONTH_DATA'),
	(170, 4421, 'AUTO_DELETE_ALL_FROM_PL_DATA_PROFILE'),
	(171, 5826, 'Analizės gylis paromis'),
	(172, 6781, 'ENABLE_HOLES'),
	(173, 5289, 'Šablono kodas, neprivalomas'),
	(174, 2749, 'Numeriai nuo 1 iki 24'),
	(175, 5897, 'Poslinkis minutėmis nustatyti generuojamų matavimų periodą'),
	(176, 991, '14'),
	(177, 402, 'OTHER'),
	(178, 7938, 'lmt:=nvl(:4,10000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n  SELECT --1//*+ FULL*/\r\n  PL_ID,PL_T,AGGS_TYPE_ID\r\n BULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA\r\n  WHERE pl_t<=CURRTMST+nvl(:1,1440)/1440+decode(aggs_type_id,4,31,1)\r\n  --5/and pl_t>=CURRTMST+decode(aggs_type_id,4,31,1)\r\n AND ROWNUM<=lmt AND AGGS_TYPE_ID=3;\r\n if pPL_ID.count<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA_NV WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n FORALL J IN 1..pPL_ID.COUNT\r\n  DELETE PL_DATA WHERE PL_ID=pPL_ID(J)and PL_T=pPL_T(J)and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\n  commit;\r\nend loop;'),
	(179, 9132, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_DAY\';\r\nstep number := 0;\r\nst date;\r\npPL_ID T7.IRR;\r\npPL_T T7.DRR;\r\npAGGS_TYPE_ID T7.IRR;'),
	(180, 2251, '13'),
	(181, 7570, 'pPCK_T T7.DRR;pPCK_N T7.IRR;pPL_ID T7.IRR;sAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;pT T7.DRR;pDST T7.IRR;pV T7.NRR;pFORCED T7.IRR;pS T7.CRR;\r\npRT T7.DRR;pRDST T7.IRR;sSEP_ID T7.IRR;sPL_ID T7.IRR;sPOINT_ID T7.IRR;\r\npNR T7.IRR;ans VARCHAR2(250);s0 DATE;s1 T7.DRR;s2 DATE;pGF NUMBER;\r\nmi NUMBER;CURSOR c_ROWS IS SELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs WHERE ml_id=:2 AND bga_id=:0 AND point_id=Nvl(:6,point_id);'),
	(182, 7134, '16'),
	(183, 9829, 'Automatinis visų matavimo taškų matavimo linijų paros duomenų įrašų trynimas'),
	(184, 7568, 'Automatinis visų matavimo taškų matavimo linijų suminių fiksuotų iki paros duomenų įrašų trynimas'),
	(185, 6059, 'I NUMBER;\r\nANS VARCHAR2(250);\r\nlimit_rec number;\r\nlimit_sec NUMBER;\r\ndoom_gr_id number;\r\ndoom_gr_code VARCHAR(500);\r\nCURRSYSDATE DATE;\r\ncnt NUMBER;\r\ngr_cnt NUMBER;\r\n'),
	(186, 4474, 'with bga_conf as (SELECT /*+ materialize*/DS_TYPE_ID,GR_ID,DS_TYPE_GR_PRIORITY,SAM_ID\r\nFROM ST_DS_TYPE_GR where sam_id is not null\r\n--1/ and DS_TYPE_CODE=:1\r\n--2/ and SAM_CODE=:2\r\n--6/ and GR_CODE=:6 )\r\n, ds_conf as\r\n(select */*+ materialize*/\r\nfrom(\r\n    select a.*,d.ds_id\r\n    ,rank() over (partition by\r\n     a.DS_TYPE_ID,\r\n     a.SAM_ID order by a.ds_type_gr_priority, a.gr_id, b.comp_id\r\n    ) rnk\r\n    from\r\n    (SELECT gr_id cont_id, gr_id comp_id, ds_id , ds_type_id\r\n          FROM st_ds_gr\r\n          UNION /*ALL*/\r\n          SELECT cont_id, comp_id, ds_id , ds_type_id\r\n          FROM st_ds_gr a\r\n          join st_grcj b ON (b.comp_id=a.gr_id)\r\n          where grc_et IS NULL\r\n          ) b\r\n    join bga_conf a ON (b.cont_id=a.gr_id and a.ds_type_id=b.ds_type_id)\r\n    join st_ds0 d ON (b.ds_id=d.ds_id)\r\n    ) where rnk=1)\r\nselect\r\nSAM_ID,ds_id, null ssep_id,to_char(nvl(:4,SYSDATE+:3),\'YYYY.MM.DD HH24:MI:SS\')tbt, to_char(nvl(:5,sysdate+:7)+1,\'YYYY.MM.DD HH24:MI:SS\') tet\r\nbulk collect into\r\nsSAM_ID,sds_id,ssep_id,stbt,stet\r\nfrom ds_conf;\r\ndelete_ds_data(sds_id,ssep_id,stbt,stet, ans);\r\nIF NOT ans =\'0\' THEN\r\n  ans2 :=SubStr(\'BGA: \'||substr(ans,1,249),1,250);\r\n  event_i(1,1,1,1,SYSDATE,ans2);\r\n  COMMIT;\r\nEND IF;\r\nif ans=\'0\' then\r\ndelete gttt;\r\nFORALL j IN 1..sds_id.count\r\n  insert into gttt(id0,id1)values(ssam_id(j),sds_id(j));\r\n  select to_date(null),null,DS_ID,null,to_char(bt,\'YYYY.MM.DD HH24:MI:SS\')DS_BT,\'\',val,null,\'1\',sysdate, null,to_date(null),null,to_date(null),null\r\n  bulk collect into\r\n  pPCK_T,pPCK_N,pDS_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,pREQ_FROM,pREQ_FROM_DST,pREQ_TO,pREQ_TO_DST\r\n  from(\r\n  with arch as (\r\n    select b.*\r\n    ,lag(b.val) over(partition by b.sam_id order by b.mo,b.da,b.bt) lag_val\r\n    from (select b.*\r\n    from st_ar_sam b\r\n    where b.sam_id in (select distinct a.id0 from gttt a)\r\n    and b.da>=trunc(nvl(:4,SYSDATE+:3)) and b.da<trunc(nvl(:5,sysdate+:7)+1) and b.bt>=nvl(:4,SYSDATE+:3) and b.bt<nvl(:5,sysdate+:7)\r\n    and val is not null and has_specific_dstatus=0\r\n    )b)\r\nselect * from (\r\n     select b.id1 DS_ID,a.BT,a.val\r\n      ,decode(val,lag_val,0,1) rodiklis\r\n      from\r\n      arch a, gttt b where a.sam_id=b.id0\r\n     ) where rodiklis=1);\r\n  IF SQL%ROWCOUNT>0 THEN\r\n   store_ds(pPCK_T,pPCK_N,pDS_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,pREQ_FROM ,pREQ_FROM_DST,pREQ_TO,pREQ_TO_DST,ans);\r\n    IF NOT ans =\'0\' THEN\r\n      ans :=SubStr(\'CHECK_MA STORE_DS: \'||substr(ans,2,249),1,250);\r\n      event_i(1,1,1,1,SYSDATE,ans);\r\n      COMMIT;\r\n    END IF;\r\n  END IF;\r\nEND IF;'),
	(187, 1162, 's0:=Trunc(Nvl(:4,SYSDATE-:3)); s2:=Nvl(Trunc(:5)+1,SYSDATE); SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty WHERE spty.spty_code=\'GENERATION_FETCH\'), 100) INTO pGF FROM dual;\r\nOPEN c_ROWS; LOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID LIMIT pGF;\r\nmi:=sPL_ID.Count; EXIT WHEN mi=0; select level BULK COLLECT INTO pNR from dual connect by level<=mi;\r\nDELETE GTTT; FORALL j in 1..mi INSERT INTO GTTT (id0,id1) values (pNR(j),sPL_ID(j));\r\nSELECT d BULK COLLECT INTO s1 FROM\r\n(SELECT /*+ use_nl(a b c) index(c plep_pk)*/ id0,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END d FROM gttt a\r\nleft join plu b ON (a.id1=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.id1=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY id0 ORDER BY id0);\r\nDELETE GTTT;\r\nFORALL j IN 1..mi\r\nINSERT INTO gttt (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT\r\nNULL,NULL,sPL_ID(j),sSEP_ID(j),bt\r\n,\'\',round(new_val,6),Nvl(:7,0),CASE WHEN s=0 AND p=0 AND bad=1 THEN \'1\' else \'14\' end\r\n,SYSDATE,\'\',sAGGS_TYPE_ID(j) FROM\r\n(with a1 as (\r\nSELECT point_id,ml_id,da,bt,val,HAS_SPECIFIC_DSTATUS s\r\nFROM v_ar\r\nWHERE point_id=sPOINT_ID(j)\r\nAND ml_id=:1\r\nAND da>=Trunc(s1(j)) AND da<s2\r\nAND NOT val IS NULL )\r\nselect * from (select a.* ,case when a.val is null then (c.val-sum)/bad end as new_val , c.s from (select * from(\r\nSELECT point_id,ml_id,da,bt,val, sum(decode(val,null,1,0))over(partition by point_id, ml_id, da) bad\r\n,sum(val)over(partition by point_id, ml_id, da) Sum\r\n,max(Nvl2(val,HAS_SPECIFIC_DSTATUS,NULL))over(partition by point_id, ml_id, da) p\r\nFROM v_ar WHERE point_id=sPOINT_ID(j) AND ml_id=:2 AND da>=Trunc(s1(j)) AND da<s2\r\n)where bad>0) a join a1 c on (a.point_id=c.point_id and a.da=c.da)\r\n) where new_val is not null\r\n) f;\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\nWHERE Nvl(:7,0)=1 OR NOT EXISTS (SELECT 0 FROM pl_data_valid\r\nWHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND storable=1 and improvable=0);\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(188, 2198, 'Kiti'),
	(189, 5702, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)'),
	(190, 5353, 'N#1_6'),
	(191, 6798, 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_PL_DATA_TDAYFIX\')\r\n, TRUNC ((SYSDATE-interval \'6\' year), \'Y\')) INTO CURRTMST FROM DUAL;\r\nLIMIT_FOR_SELECT:=nvl(:4,10000);\r\nTS := SYSDATE;\r\nDELETED_ROWS_COUNTF := 0;\r\nwhile (not (CURRTMST + nvl(:1,5) / 1440 > ADD_MONTHS(SYSDATE, -nvl(:2,60)) OR SYSDATE > TS + nvl(:3,45) / 86400)) LOOP\r\nSELECT /*+ FIRST_ROWS(10000) */ A.PL_ID,A.PL_T,A.AGGS_TYPE_ID\r\nBULK COLLECT INTO pPL_ID,pPL_T,pAGGS_TYPE_ID FROM PL_DATA A\r\nWHERE A.DB_TIME >= CURRTMST AND A.DB_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND A.pl_id IN (SELECT pl_id FROM st_pl WHERE aggs_id=8 and not md_id in (5,6,7)) AND ROWNUM<= LIMIT_FOR_SELECT;\r\nIF (SQL%FOUND) then\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_CUSTOM WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J) ;\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA_NV     WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nFORALL J IN 1..pPL_ID.COUNT\r\nDELETE PL_DATA        WHERE PL_ID=pPL_ID(J) and PL_T=pPL_T(J) and AGGS_TYPE_ID=pAGGS_TYPE_ID(J);\r\nDELETED_ROWS_COUNTF := pPL_ID.COUNT;\r\nelse DELETED_ROWS_COUNTF:=0;END IF;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then\r\nCURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_TDAYFIX\' ;\r\nIF (SQL%ROWCOUNT = 0)THEN\r\nINSERT INTO TMST (TMST_CODE,AMP) select \'AUTO_DELETE_ALL_FROM_PL_DATA_TDAYFIX\',CURRTMST from dual\r\nwhere not exists (select 0 from tmst where TMST_CODE=\'AUTO_DELETE_ALL_FROM_PL_DATA_TDAYFIX\');\r\nEND IF;END IF;END LOOP;COMMIT;\r\n'),
	(192, 5102, 'MONTH_FIXED_TOTALS_FROM_TOTALS_AND_MON'),
	(193, 4748, 'PW_SETTING_POST_PROCESSING'),
	(194, 2334, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_SEK\';\r\nstep number := 0;\r\nst date;\r\npPL_ID T7.IRR;\r\npPL_T T7.DRR;\r\npAGGS_TYPE_ID T7.IRR;'),
	(195, 8515, 'AUTO_DELETE_ALL_FROM_PL_DATA_TOTAL'),
	(196, 487, 'ans varchar2(250);ans2 varchar2(250);\r\nsSAM_ID t7.irr;\r\nsds_id t7.irr;\r\nstbt t7.crr;\r\nstet t7.crr;\r\nssep_id t7.irr;\r\npPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npDS_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.CRR;\r\npDST T7.IRR;\r\npV T7.IRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\npREQ_FROM T7.DRR;\r\npREQ_FROM_DST T7.IRR;\r\npREQ_TO   T7.DRR;\r\npREQ_TO_DST T7.IRR;'),
	(197, 901, '5'),
	(198, 7145, 'SMTP'),
	(199, 8417, 'HOLES'),
	(200, 9077, 'STORAGE'),
	(201, 9780, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(202, 4543, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nL T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID ,aggs_type_id\r\nfrom GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(203, 4036, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT /*+ materialize*/\r\nSEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(204, 2240, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nfrom GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(205, 2681, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\ngf1 NUMBER(2);\r\ncnt1 number(5);\r\ncnt2 number(5);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT /*+ materialize*/\r\nSEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(206, 9153, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER; p number; m number;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nfrom GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(207, 4807, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(208, 3383, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nsML_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,ML_ID\r\nfrom GEN_IDs\r\nWHERE bga_id=:0 --6/ and point_id=:6\r\n;'),
	(209, 8981, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nsML_ID T7.IRR;\r\nsSAM_CODE T7.CRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,g.POINT_ID,g.aggs_type_id,z.ml_id,p.ppty_value\r\nfrom GEN_IDs g\r\njoin ml l ON (g.ml_id=l.ml_id)\r\njoin ml z ON (l.ms_id=z.ms_id AND l.dir_id=z.dir_id AND z.aggs_id=5 AND z.aggf_id=2 AND l.tff_id=z.tff_id AND z.md_id=5 AND l.md_id=4)\r\njoin ppty y ON (y.ppty_code=:8)\r\njoin point_ppty p ON (g.point_id=p.point_id AND y.ppty_id=p.ppty_id)\r\nWHERE l.ml_id=:2 AND bga_id=:0 --6/ and g.point_id=:6\r\n;'),
	(210, 2342, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\ncnt2 number(5);\r\ngf2 number(2);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(211, 9665, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns2 DATE;\r\ns1 T7.DRR;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(212, 417, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nfrom GEN_IDs WHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(213, 8614, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nfrom GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(214, 8997, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\ngf1 number(2);\r\ncnt1 number(5);\r\ncnt2 number(5);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(215, 7782, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT\r\nSEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(216, 8590, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\ngf1 NUMBER(2);\r\ncnt1 NUMBER(5);\r\ncnt2 NUMBER(5);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;v_tff_id number;\r\nCURSOR c_ROWS ( tff_CODE NUMBER) IS\r\nWITH a AS\r\n(SELECT /*+ materialize*/\r\nSEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n)\r\nSELECT /*+ use_nl(a b c) index(c plep_pk)*/ SEP_ID,a.PL_ID,a.POINT_ID ,aggs_type_id\r\n,CASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END\r\nfrom a\r\nJOIN ( SELECT distinct p.point_id FROM PTP p WHERE nvl(p.aggf_id,tff_CODE) = tff_CODE )\r\n     d ON d.point_id = a.POINT_ID\r\nleft join plu b ON (a.pl_id=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY SEP_ID,a.PL_ID,a.POINT_ID,aggs_type_id;'),
	(217, 4025, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\npNR T7.IRR;\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT\r\nSEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(218, 8294, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nsAGGF_ID T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npEXTREME_T T7.DRR;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID,AGGF_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\nand aggs_id in (select aggs_id from ml where ml_id=:1);'),
	(219, 6200, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nsAGGF_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npEXTREME_T T7.DRR;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT /*+ materialize*/\r\nSEP_ID,PL_ID,POINT_ID,aggs_type_id,aggf_id\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\nand aggs_id in (select aggs_id from ml where ml_id=:1);'),
	(220, 3901, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nsAGGF_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npEXTREME_T T7.DRR;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID,AGGF_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\nand aggs_id in (select aggs_id from ml where ml_id=:1);'),
	(221, 6760, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\n  from GEN_IDs\r\n WHERE ml_id=:2\r\n   AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(222, 4410, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\ngf1 NUMBER(2);\r\ncnt1 NUMBER(5);\r\ncnt2 NUMBER(5);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nCURSOR c_ROWS ( s0 DATE, s2 DATE) IS\r\nWITH a AS\r\n(SELECT /*+ materialize*/\r\n        SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\n   FROM GEN_IDs\r\n  WHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n)\r\nSELECT /*+ use_nl(a b c) index(c plep_pk)*/ SEP_ID,a.PL_ID,POINT_ID ,aggs_type_id\r\n  ,CASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\n  Min(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\n  ELSE s0 END\r\n  FROM a\r\n  LEFT JOIN plu b ON (a.pl_id=b.pl_id AND Nvl(:7,0)=0)\r\n  LEFT JOIN plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\n GROUP BY SEP_ID,a.PL_ID,POINT_ID,aggs_type_id;'),
	(223, 9254, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nm1 number;\r\nCURSOR c_ROWS IS\r\nWITH a AS (SELECT /*+ materialize*/ SEP_ID,PL_ID,POINT_ID,aggs_type_id FROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n)\r\nSELECT /*+ use_nl(a b c) index(c plep_pk)*/ SEP_ID,a.PL_ID,POINT_ID ,aggs_type_id\r\n,CASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END from a\r\nleft join plu b ON (a.pl_id=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY SEP_ID,a.PL_ID,POINT_ID,aggs_type_id;'),
	(224, 820, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT /*+ materialize*/\r\nSEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(225, 3149, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\ngf1 NUMBER(2);\r\ncnt1 NUMBER(5);\r\ncnt2 NUMBER(5);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nCURSOR c_ROWS ( s0 DATE, s2 DATE) IS\r\nWITH a AS\r\n(SELECT /*+ materialize*/\r\n        SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\n   FROM GEN_IDs\r\n  WHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n)\r\nSELECT /*+ use_nl(a b c) index(c plep_pk)*/ SEP_ID,a.PL_ID,POINT_ID ,aggs_type_id\r\n  ,Add_Months(CASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\n  Min(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\n  ELSE s0 END ,-1)\r\n  FROM a\r\n  LEFT JOIN plu b ON (a.pl_id=b.pl_id AND Nvl(:7,0)=0)\r\n  LEFT JOIN plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\n GROUP BY SEP_ID,a.PL_ID,POINT_ID,aggs_type_id;'),
	(226, 4000, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npDS_ID number;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\n  FROM GEN_IDs\r\n WHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(227, 7783, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;p number;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nfrom GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(228, 4681, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npNR T7.IRR;\r\nmi NUMBER;\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nfrom GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(229, 7964, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nsAGGF_ID T7.IRR;\r\ngf1 NUMBER(2);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npEXTREME_T T7.DRR;\r\npGF NUMBER;\r\nv_ttf_id number;\r\nv_md_id number;\r\nCURSOR c_ROWS ( tff_CODE NUMBER) IS\r\nWITH a AS\r\n(SELECT /*+ materialize*/\r\nSEP_ID,PL_ID,POINT_ID,aggs_type_id,aggf_id\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n)\r\nSELECT /*+ use_nl(a b c) index(c plep_pk)*/ SEP_ID,a.PL_ID,a.POINT_ID ,aggs_type_id,a.aggf_id\r\n,CASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END\r\nfrom a\r\nJOIN ( SELECT distinct p.point_id FROM PTP p WHERE nvl(p.aggf_id,tff_CODE) = tff_CODE )\r\n     d ON d.point_id = a.POINT_ID\r\nleft join plu b ON (a.pl_id=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY SEP_ID,a.PL_ID,a.POINT_ID,aggs_type_id,a.aggf_id;'),
	(230, 2765, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 date;\r\ns2 date;\r\nL NUMBER;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(231, 2945, 'pPCK_T T7.DRR;pPCK_N T7.IRR;pPL_ID T7.IRR;sAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;pT T7.DRR;pDST T7.IRR;pV T7.NRR;pFORCED T7.IRR;pS T7.CRR;\r\npRT T7.DRR;pRDST T7.IRR;sSEP_ID T7.IRR;sPL_ID T7.IRR;sPOINT_ID T7.IRR;\r\npNR T7.IRR;ans VARCHAR2(250);s0 DATE;s1 T7.DRR;s2 DATE;pGF NUMBER;\r\nmi NUMBER;CURSOR c_ROWS IS SELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs WHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;'),
	(232, 6877, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n              FROM spty\r\n             WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nDELETE FROM GEN_ADJ$F1;\r\nIF Nvl(:7,\'0\')=1 THEN\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_15MIN_TOTALS_F\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:1) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,1,s,c_DATA,\'\'\r\n         FROM GEN_15_TOTALS_FROM_ADJ_TOTALS;\r\nELSE\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_15MIN_TOTALS\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:1) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,0,s,c_DATA,\'\'\r\n         FROM GEN_15_TOTALS_FROM_ADJ_TOTALS;\r\nEND IF;\r\nLOOP\r\n  FETCH c_ROWS\r\n   BULK COLLECT\r\n   INTO pPCK_T, pPCK_N , pPL_ID, pSEP_ID, pT, pDST, pV, pFORCED, pS, pRT, pRDST\r\n  LIMIT pGF;\r\n  EXIT WHEN pPL_ID.COUNT = 0;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(233, 2282, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n              FROM spty\r\n             WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nDELETE FROM GEN_ADJ$F1;\r\nIF Nvl(:7,\'0\')=1 THEN\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_H_TOTALS_F\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:1) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,1,s,c_DATA,\'\'\r\n         FROM GEN_H_TOTALS_FROM_ADJ_TOTALS;\r\nELSE\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_H_TOTALS\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:1) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,0,s,c_DATA,\'\'\r\n         FROM GEN_H_TOTALS_FROM_ADJ_TOTALS;\r\nEND IF;\r\nLOOP\r\n  FETCH c_ROWS\r\n   BULK COLLECT\r\n   INTO pPCK_T, pPCK_N , pPL_ID, pSEP_ID, pT, pDST, pV, pFORCED, pS, pRT, pRDST\r\n  LIMIT pGF;\r\n  EXIT WHEN pPL_ID.COUNT = 0;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(234, 5752, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n              FROM spty\r\n             WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nDELETE FROM GEN_ADJ$F0;\r\nIF Nvl(:7,\'0\')=1 THEN\r\n  INSERT INTO GEN_ADJ$F0\r\n  SELECT *\r\n    FROM ADJ_TOTALS_F\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:1) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND (:2 IS NULL OR ml_id=:2)\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL, NULL, pl_id, sep_id, da, \'\', v, 1, s, c_DATA, \'\'\r\n         FROM GEN_TOTALS_FROM_ADJ_TOTALS;\r\nELSE\r\n  INSERT INTO GEN_ADJ$F0\r\n  SELECT *\r\n    FROM ADJ_TOTALS\r\n   WHERE da>=Nvl(:4,TRUNC(SYSDATE)-:1) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND (:2 IS NULL OR ml_id=:2)\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL, NULL, pl_id, sep_id, da, \'\', v, 0, s, c_DATA, \'\'\r\n         FROM GEN_TOTALS_FROM_ADJ_TOTALS;\r\nEND IF;\r\nLOOP\r\n  FETCH c_ROWS\r\n   BULK COLLECT\r\n   INTO pPCK_T, pPCK_N , pPL_ID, pSEP_ID, pT, pDST, pV, pFORCED, pS, pRT, pRDST\r\n  LIMIT pGF;\r\n  EXIT WHEN pPL_ID.COUNT = 0;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(235, 1034, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n              FROM spty\r\n             WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nDELETE FROM GEN_ADJ$F1;\r\nIF Nvl(:7,\'0\')=1 THEN\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_30MIN_TOTALS_F\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:1) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,1,s,c_DATA,\'\'\r\n         FROM GEN_30_TOTALS_FROM_ADJ_TOTALS;\r\nELSE\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_30MIN_TOTALS\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:1) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,0,s,c_DATA,\'\'\r\n         FROM GEN_30_TOTALS_FROM_ADJ_TOTALS;\r\nEND IF;\r\nLOOP\r\n  FETCH c_ROWS\r\n   BULK COLLECT\r\n   INTO pPCK_T, pPCK_N , pPL_ID, pSEP_ID, pT, pDST, pV, pFORCED, pS, pRT, pRDST\r\n  LIMIT pGF;\r\n  EXIT WHEN pPL_ID.COUNT = 0;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(236, 6366, 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100) INTO pGF FROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nEXECUTE IMMEDIATE \'truncate table gen$p\';\r\nFORALL j IN 1..mi\r\nINSERT INTO gen$p (pl_id,sep_id,point_id,aggs_type_id,s1)\r\nVALUES (sPL_ID(j),sSEP_ID(j),sPOINT_ID(j),sAGGS_TYPE_ID(j),s0);\r\nIF Nvl(:7,0)=0 THEN\r\nMERGE INTO gen$p y\r\nUSING (SELECT /*+ use_nl(a b c) index(c plep_pk)*/ a.pl_id,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=a.s1 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nEND s1\r\nFROM gen$p a\r\njoin plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=a.s1 AND c.plep_bt<s2)\r\nleft join plu b ON (a.pl_id=b.pl_id)\r\nGROUP BY a.pl_id\r\n) u ON (y.pl_id=u.pl_id)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.s1=u.s1\r\nWHERE y.s1<u.s1;\r\nEND IF;\r\nCOMMIT;\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v,Nvl(:7,0),s,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT c1,c2,c3,Trunc(da,\'MM\')t,sum(val)v,case WHEN\r\nMax(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=Add_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\')\r\nthen \'1\' else \'14\'||decode(count(*),Add_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\'),\'\',\'+3\') END s\r\nFROM TABLE(p_ar.p2(CURSOR(SELECT\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,s2,0))\r\nWHERE NOT val IS null\r\nGROUP BY c1,c2,c3,Trunc(da,\'MM\')) r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(237, 9215, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(bt,\'HH\') t,Avg(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=4\r\nthen \'1\' else \'14\'||decode(count(*),4,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da,Trunc(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(238, 4570, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,avg(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=24\r\nthen \'1\' else \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(239, 7897, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,sum(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=24\r\nthen \'1\' else \'14\'||decode(count(*),24,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(240, 4265, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(bt,\'HH\') t,Avg(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=12\r\nthen \'1\' else \'14\'||decode(count(*),12,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da,Trunc(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(241, 2500, 'SELECT ml_id BULK COLLECT INTO L FROM ml WHERE (ms_id,dir_id,aggs_id,aggf_id,md_id) IN\r\n(SELECT ms_id,dir_id,aggs_id,aggf_id,md_id FROM ml WHERE ml_id=:1) AND tff_id IN (1,2,3,4);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nDELETE gtts;\r\nFORALL j IN 1..sPL_ID.count\r\nINSERT INTO gtts (id1,d1,d2,v1)\r\nSELECT point_id,da,Max(bt),Sum(val)\r\nFROM ( SELECT point_id,ml_id,da,bt,val,Rank() over (PARTITION BY point_id,ml_id,da,Trunc(bt,\'MI\') ORDER BY bt) rnk\r\nFROM v_ar\r\nWHERE point_id=sPOINT_ID(j)\r\nAND ml_id IN (L(1),L(2),L(3),L(4))\r\nAND da>=Nvl(:4,SYSDATE-:3) AND da<=Nvl(:5,SYSDATE)\r\nAND NOT val IS NULL )\r\nWHERE rnk=1\r\nGROUP BY point_id,da,Trunc(bt,\'MI\')\r\nHAVING Count(*)=4;\r\nDELETE gttt;\r\nFORALL j IN 1..sPL_ID.count\r\nINSERT INTO gttt\r\n(d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT NULL,NULL,sPL_ID(j),sSEP_ID(j),bt\r\n,\'\',Sum(q*l),Nvl(:7,0),\'1\',SYSDATE,\'\',sAGGS_TYPE_ID(j)\r\nFROM (SELECT f.*,bt,greatest(g-\r\nNvl(Sum(Decode(has_specific_dstatus,0,(Least(te,et)-Greatest(tb,bt))*24*val))\r\nover (PARTITION BY id1,tb),0)\r\n,0)/Sum(Decode(has_specific_dstatus,1,(Least(te,et)-Greatest(tb,bt))*24))\r\nover (PARTITION BY id1,tb) q\r\n,Decode(has_specific_dstatus,1,(Least(te,et)-Greatest(tb,bt))*24) l\r\n,CASE WHEN te-tb>=15/24 and not g-\r\nNvl(Sum(Decode(has_specific_dstatus,0,(Least(te,et)-Greatest(tb,bt))*24*val))\r\nover (PARTITION BY id1,tb),0)\r\n=0 THEN 1 ELSE 0 END k\r\nFROM v_ar d,\r\n(SELECT id1,d2 tb\r\n,Lead(d2) over (PARTITION BY id1 ORDER BY d2) te\r\n,Lead(v1) over (PARTITION BY id1 ORDER BY d2)-\r\nCASE WHEN\r\nLead(v1) over (PARTITION BY id1 ORDER BY d2)-v1<-1000\r\n THEN 0 ELSE v1 end g\r\nFROM gtts) f,mou u\r\nWHERE sPOINT_ID(j)=u.point_id (+) AND f.tb<u.mou_bt (+) AND f.te>=u.mou_bt (+) AND u.mou_id IS null\r\nAND d.point_id=sPOINT_ID(j) AND ml_id=:2 AND da>=Nvl(:4,SYSDATE-:3)\r\nAND da<=Nvl(:5,SYSDATE)\r\nAND d.point_id=id1 AND et>tb AND bt<te\r\n) h\r\nGROUP BY bt\r\nHAVING Round(Sum(l),6)=1 AND Max(k)=0;\r\nSELECT d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(242, 6141, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,sum(val)/2 v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=48\r\nthen \'1\' else \'14\'||decode(count(*),48,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(243, 7870, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO\r\nsSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,bt+(nr-1) t,g/(et-bt) v\r\n,Decode((et-bt),1,\'1\',\'14\') s\r\nFROM\r\n(SELECT c1,c2,c3,da,bt, point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2+1))\r\nWHERE NOT val IS NULL AND bt=da\r\n) f,mou u,iger\r\nWHERE f.point_id=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\nAND nr<=round((et-bt),6) ) r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(244, 9080, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3),Nvl(:5+1,SYSDATE),1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,ib t\r\n,Sum(q*l)*2 v,Decode(Max(k),0,\'1\',\'14\') s\r\nFROM\r\n(SELECT f.*\r\n,Trunc(bt)+Trunc(Round((bt-Trunc(bt))*48,6))/48+(d.column_value-1)/48 ib\r\n,g/(et-bt)/48 q\r\n,(Least(et,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*48,6))/48+(d.column_value)/48)-Greatest(bt,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*48,6))/48+(d.column_value-1)/48))*48 l\r\n,CASE WHEN et-bt>=2/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM (SELECT da,bt, c1,c2,c3,point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),Nvl(:5+1,SYSDATE)))\r\nWHERE  NOT val IS NULL) f,mou u, TABLE(SELECT CAST(COLLECT(level) AS sql_objects) FROM dual CONNECT BY Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*48,6))/48+(LEVEL-1)/48<f.et) d\r\nwhere f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\n) h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(245, 7327, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nSELECT md_cnt,aggf_id\r\nINTO cnt1,gf1\r\nFROM st_ml\r\nWHERE ml_id=:1;\r\nSELECT md_cnt\r\nINTO cnt2\r\nFROM st_ml\r\nWHERE ml_id=:2;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da+Trunc(Round((bt-da)*cnt2,6))/cnt2 t,Avg(val*Decode(gf1,3,1,cnt1/24)) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0 and count(*)*cnt2=cnt1\r\nthen \'1\' else \'14\'||decode(count(*)*cnt2,cnt1,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da,da+Trunc(Round((bt-da)*cnt2,6))/cnt2 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(246, 8177, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))FROM spty WHERE spty.spty_code=\'GENERATION_FETCH\'),100)INTO pGF FROM dual;\r\nselect nvl(to_number(:9),0)into p from dual;select md_id into m from ml where ml_id=:1;\r\nif m=5 and p=2 then p:=1; end if; OPEN c_ROWS;LOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID LIMIT pGF; EXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3),Nvl(:5+1,SYSDATE),1);\r\nFOR d IN(SELECT DISTINCT Trunc(s1,\'MI\')s1 FROM gen$p)loop\r\nif p=0 then SELECT \'\',\'\',c1,c2,t,\'\',v,Nvl(:7,0),s,SYSDATE,\'\'\r\nBULK COLLECT INTO pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM(SELECT c1,c2,c3,ib t,\'\',Sum(q*l)v,Decode(Max(k),0,\'1\',\'14\')s\r\nFROM(SELECT f.*,Trunc(bt)+Trunc(Round((bt-Trunc(bt)),6))+(d.column_value-1)ib\r\n,g/(et-bt)q,(Least(et,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt)),6))+(d.column_value))-Greatest(bt,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt)),6))+(d.column_value-1)))l\r\n,CASE WHEN et-bt>=36/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM(SELECT da,bt,c1,c2,c3,point_id,\r\nLead(bt)over(PARTITION BY point_id,ml_id ORDER BY da,bt)et\r\n,Lead(val)over(PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN Lead(val)over(PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\nTHEN 0 ELSE val end g FROM\r\ntable(p_ar.p2(cursor(select point_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM gen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,Nvl(:5+1,SYSDATE)))\r\nWHERE NOT val IS NULL)f,mou u,TABLE(SELECT CAST(COLLECT(level)AS sql_objects)FROM dual CONNECT BY Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt)),6))+(LEVEL-1)<f.et)d\r\nwhere f.POINT_ID=u.point_id(+)AND f.bt<u.mou_bt(+)AND f.et>=u.mou_bt(+)AND u.mou_id IS null)h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists(SELECT 0 FROM pl_data_valid  WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nelse SELECT \'\',\'\',c1,c2,t,\'\',v,Nvl(:7,0),s,SYSDATE,\'\'\r\nBULK COLLECT INTO pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM(SELECT c1,c2,c3,decode(p,1,da-1,2,da)t,\'\',round(delta_val,6)v,s\r\nFROM(SELECT b.*,\r\ncase when(HAS_SPECIFIC_DSTATUS=0 and prev_HAS_SPECIFIC_DSTATUS=0)AND NOT(da=TRUNC(sysdate,\'DD\'))then 1 else 14\r\nend s FROM(SELECT a.*\r\n,val-lag(val)over(PARTITION by point_id,ml_id order by da)delta_val\r\n,lag(val)over(PARTITION by point_id,ml_id order by da)prev_val\r\n,lag(bt)over(PARTITION by point_id,ml_id order by da)prev_bt\r\n,lag(HAS_SPECIFIC_DSTATUS)over(PARTITION by point_id,ml_id order by da)prev_HAS_SPECIFIC_DSTATUS\r\nFROM(SELECT c1,c2,c3,point_id,ml_id,da,bt,val,HAS_SPECIFIC_DSTATUS\r\n,case when p=2 then rank()over(PARTITION by point_id,ml_id,da order by bt desc)\r\nwhen p=1 then rank()over(PARTITION by point_id,ml_id,da order by bt asc)\r\nend rnk\r\nFROM table(p_ar.p2(cursor(select point_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM gen$p WHERE Trunc(s1,\'MI\')=d.s1),d.s1-1,Nvl(:5+1,SYSDATE)+1))\r\nWHERE NOT val IS NULL )a where rnk=1)b,mou u\r\nWHERE b.POINT_ID=u.point_id(+)AND b.prev_bt<u.mou_bt(+)AND b.bt>=u.mou_bt(+)AND u.mou_id IS null\r\n)where delta_val>=0)r\r\n--/7 where not exists(SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;end if;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP; END LOOP; CLOSE c_ROWS;'),
	(247, 1015, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,sum(val)/4 v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=96\r\nthen \'1\' else \'14\'||decode(count(*),96,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(248, 5756, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,sML_ID,sSAM_CODE\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nselect level BULK COLLECT INTO pNR from dual connect by level<=mi;\r\nDELETE GTTT;\r\nFORALL j in 1..mi\r\nINSERT INTO GTTT (id0,id1) values (pNR(j),sPL_ID(j));\r\nSELECT d\r\nBULK COLLECT INTO s1\r\nFROM\r\n(SELECT /*+ use_nl(a b c) index(c plep_pk)*/ id0,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END d\r\nFROM\r\ngttt a\r\nleft join plu b ON (a.id1=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.id1=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY id0\r\nORDER BY id0);\r\nDELETE GTTT;\r\nFORALL j IN 1..mi\r\nINSERT INTO gttt (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT\r\nNULL,NULL,sPL_ID(j),sSEP_ID(j),bt,\'\',Decode(Trunc(et),da,f,f+p-Sum(f) over (PARTITION BY da)) v,Nvl(:7,0),d\r\n,SYSDATE,\'\',sAGGS_TYPE_ID(j) FROM\r\n(\r\nSELECT b.bt,b.et,b.da,c.val p,b.val s,Decode(c.has_specific_dstatus,0,\'1\',\'14\')d\r\n,Round(b.val*c.val/Sum(b.val) over (PARTITION BY b.da),6) f\r\nFROM  st_ar_sam b,v_ar c\r\nWHERE c.point_id=sPOINT_ID(j)\r\nAND b.da=c.da AND c.ml_id=sML_ID(j)\r\nAND b.sam_code=sSAM_CODE(j)\r\nAND b.da>=Trunc(s1(j)) AND b.bt>=s1(j) AND b.da<s2\r\nAND NOT c.val IS NULL AND NOT b.val IS null\r\n);\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8  AND storable=1 and improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(249, 8653, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT md_cnt,aggf_id INTO cnt2,gf2 FROM st_ml where ml_id=:2;\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,bt+(nr-1)/cnt2 t,g/(et-bt)/Decode(gf2,3,24,cnt2) v\r\n,CASE WHEN Greatest(h1,h2)=0 AND (Round((et-bt)*cnt2,6)=1 OR g=0) THEN \'1\' ELSE \'14\' END s\r\nFROM\r\n(SELECT c1,c2,c3,da,bt, point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val g\r\n,has_specific_dstatus h1\r\n,Lead(has_specific_dstatus) over (PARTITION BY point_id,ml_id ORDER BY da,bt) h2\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2+1))\r\nWHERE NOT val IS NULL AND bt=da+Trunc(Round((bt-da)*cnt2,6))/cnt2\r\n) f,mou u,iger\r\nWHERE f.point_id=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\nAND nr<=round((et-bt)*cnt2,6) ) r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(250, 3670, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,ib t\r\n,Sum(q*l)*2 v,Decode(Max(k),0,\'1\',\'14\') s\r\nFROM\r\n(SELECT f.*,g/(et-bt)/48 q, (Least(et,ib+1/48)-Greatest(bt,ib))*48 l\r\n,CASE WHEN et-bt>=2/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM (SELECT da,bt,c1,c2,c3,point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et,\r\nCASE WHEN (bt-trunc(bt,\'HH\'))*24*60 BETWEEN 0 and 29 THEN TRUNC(bt, \'HH\') ELSE TRUNC(bt, \'HH\')+1/48 END ib\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL) f,mou u, TABLE(SELECT CAST(COLLECT(level) AS sql_objects) FROM dual CONNECT BY Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*720,6))/720+(LEVEL-1)/720<f.et) d\r\nwhere f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\n) h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(251, 6631, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM(SELECT c1,c2,c3,Trunc(bt,\'HH\') t,Avg(val) v,Decode(Max(HAS_SPECIFIC_DSTATUS),0,\'1\',\'14\') s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id, :1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,Trunc(bt,\'HH\')\r\nHAVING Count(*)=2)r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nFORALL j IN 1..sPL_ID.count\r\nINSERT INTO gttt\r\n(d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT NULL,NULL,sPL_ID(j),sSEP_ID(j),Trunc(bt,\'HH\'),\'1\'\r\n,Avg(val),Nvl(:7,0),Decode(Max(HAS_SPECIFIC_DSTATUS),0,\'1\',\'14\'),SYSDATE,1\r\n,sAGGS_TYPE_ID(j) FROM v_ar_ah\r\nWHERE point_id=sPOINT_ID(j) AND ml_id=:1 AND da>=Trunc(s0) AND bt>=s0 AND da<s2\r\nAND NOT val IS NULL\r\nGROUP BY Trunc(bt,\'HH\')\r\nHAVING Count(*)=2;\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_ah_data_valid WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(252, 4261, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,MAX(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=24\r\nthen \'1\' else \'14\'||decode(count(*),24,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(253, 3762, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n             FROM spty\r\n            WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nFOR i IN 1..TO_NUMBER(TRUNC(NVL(:5,SYSDATE))-TRUNC(NVL(:4,SYSDATE-:3))) LOOP\r\n  OPEN c_ROWS;\r\n  LOOP\r\n    FETCH c_ROWS\r\n    BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n    LIMIT pGF;\r\n    EXIT WHEN sPL_ID.Count=0;\r\n    FORALL j IN 1..sPL_ID.count\r\n    INSERT INTO gttt\r\n    (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\n    SELECT\r\n    NULL,NULL,sPL_ID(j),sSEP_ID(j),tda,\'\',sum(pl_rv),Nvl(:7,0)\r\n    ,case when Max(HAS_SPECIFIC_DSTATUS)=0 and count(*)=49\r\n    then \'1\' else \'14\'||decode(count(*),49,null,\'+3\') end,SYSDATE,\'\'\r\n    ,sAGGS_TYPE_ID(j) aggs_type_id FROM\r\n    (SELECT da,da as tda, decode(has_act,1,val,case when \'+\'||dstatus like \'%+15%\' then 0 else pl_rv end)/2 as pl_rv\r\n    , case when \'+\'||dstatus like \'%+15%\' then 0 else HAS_SPECIFIC_DSTATUS end HAS_SPECIFIC_DSTATUS\r\n    FROM v_ar\r\n    WHERE point_id=sPOINT_ID(j) AND ml_id in (:1) AND da>=Nvl(:4,SYSDATE-:3)-1 + (i-1)\r\n    AND da<=Nvl(:5,SYSDATE)-1 AND NOT val IS NULL\r\n    union all\r\n    SELECT da, da+1 as tda, decode(has_act,1,val,pl_rv) as pl_rv, HAS_SPECIFIC_DSTATUS\r\n    FROM v_ar\r\n    WHERE point_id=sPOINT_ID(j) AND ml_id in (:2) AND da>=Nvl(:4,SYSDATE-:3)-2 + (i-1)\r\n    AND da<=Nvl(:5,SYSDATE)-2 AND NOT val IS NULL)\r\n    GROUP BY tda;\r\n    SELECT\r\n    d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\n    BULK COLLECT INTO\r\n    pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\n    FROM gttt f\r\n    --/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND storable=1 AND improvable=0)\r\n;\r\n    store_pl_now(pPCK_T,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\n  END LOOP;\r\n  CLOSE c_ROWS;\r\nEND LOOP;'),
	(254, 7109, 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(da,\'MM\') t,avg(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=Add_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\')\r\nthen \'1\' else \'14\'||decode(count(*),\r\nAdd_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\'),null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),Trunc(d.s1,\'MM\'),s2,0))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,Trunc(da,\'MM\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(255, 5659, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,bt+(nr-1)/24 t,g/(et-bt)/24 v\r\n,CASE WHEN Greatest(h1,h2)=0 AND ((et-bt)*24=1 OR g=0) THEN \'1\' ELSE \'14\' end  s\r\nFROM\r\n(SELECT c1,c2,c3,da,bt, point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val g\r\n,has_specific_dstatus h1\r\n,Lead(has_specific_dstatus) over (PARTITION BY point_id,ml_id ORDER BY da,bt) h2\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2+1))\r\nWHERE NOT val IS NULL AND bt=trunc(bt,\'HH\')\r\n) f,mou u,iger\r\nWHERE f.point_id=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\nAND nr<=round((et-bt)*24,6) ) r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(256, 1358, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3),Nvl(:5+1,SYSDATE),1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,ib t\r\n,Sum(q*l) v,Decode(Max(k),0,\'1\',\'14\') s\r\nFROM\r\n(SELECT f.*,Trunc(bt)+Trunc(Round((bt-Trunc(bt))*48,6))/48+(d.column_value-1)/48 ib,g/(et-bt)/48 q\r\n,(Least(et,Trunc(bt)+Trunc(Round((bt-Trunc(bt))*48,6))/48+d.column_value/48)-Greatest(bt,Trunc(bt)+Trunc(Round((bt-Trunc(bt))*48,6))/48+(d.column_value-1)/48))*48 l\r\n,CASE WHEN et-bt>=2/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM ( SELECT da,bt, c1,c2,c3,point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,Nvl(:5+1,SYSDATE)))\r\nWHERE NOT val IS NULL) f,mou u, TABLE(SELECT CAST(COLLECT(level) AS tn) FROM dual CONNECT BY Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*48,6))/48+(LEVEL-1)/48<f.et) d\r\nwhere f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\n) h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(257, 8010, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3),Nvl(:5+1,SYSDATE),1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT c1,c2,c3, ib t\r\n,Sum(q*l) v,Decode(Max(k),0,\'1\',\'14\') s\r\nFROM (SELECT f.*,d.*,g/(et-bt)/24 q\r\n,(Least(et,ie)-Greatest(bt,ib))*24 l\r\n,CASE WHEN et-bt>=2/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM(SELECT da,bt,c1,c2,c3,point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et,\r\nLead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN\r\nLead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\nTHEN 0 ELSE val end g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),Nvl(:5+1,SYSDATE)))\r\nWHERE\r\nNOT val IS NULL\r\n) f,mou u,(SELECT da y,da+(nr-1)/24 ib,da+nr/24 ie FROM days,iger WHERE nr<=24) d\r\nWHERE f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\nand (NOT y+1<=bt AND NOT y>=et AND NOT ie<=bt AND NOT ib>=et)) h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(258, 7987, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nselect md_cnt,aggf_id into cnt1,gf1 from st_ml where ml_id=:1;\r\nselect md_cnt into cnt2 from st_ml where ml_id=:2;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT /*da*/trunc(bt-(nvl(:8,0)/1440))+Trunc(Round((/*bt*/bt-(nvl(:8,0)/1440)-/*da*/trunc(bt-(nvl(:8,0)/1440)))*cnt2,6))/cnt2 t,c1,c2,c3,point_id, sum(val*Decode(gf1,3,24/cnt1,1)) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0 and count(*)*cnt2=cnt1\r\nthen \'1\' else \'14\'||decode(count(*)*cnt2,cnt1,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1)+(nvl(:8,0)/1440),s2+(nvl(:8,0)/1440)))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,point_id,/*da*/trunc(bt-(nvl(:8,0)/1440)),/*da*/trunc(bt-(nvl(:8,0)/1440))+Trunc(Round((/*bt*/bt-(nvl(:8,0)/1440)-/*da*/trunc(bt-(nvl(:8,0)/1440)))*cnt2,6))/cnt2 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(259, 9687, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT d.ib t,c1,c2,c3,point_id, Avg(val) v,\r\nCASE WHEN\r\n(Count(DISTINCT(Trunc((bt - d.ib)*48*4)))\r\n>=4) THEN \'1\' ELSE \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\n a join (SELECT da y,da+(nr-1)/48 ib,da+nr/48 ie FROM days,iger WHERE nr<=48) d\r\nON (NOT y+1<=bt AND NOT y>=et AND NOT ie<=bt AND NOT ib>=et)\r\nWHERE NOT val IS NULL AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,point_id,d.ib )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(260, 2651, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,MIN(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=24\r\nthen \'1\' else \'14\'||decode(count(*),24,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(261, 4698, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,TRUNC(bt, \'HH\') t,MAX(val) v,\r\nCASE WHEN (\r\nCount(DISTINCT(Trunc((bt - TRUNC(bt, \'HH\'))*24*4)))\r\n>=4) THEN \'1\' ELSE \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,TRUNC(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(262, 4802, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(da,\'MM\') t,MAX(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=Add_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\')\r\nthen \'1\' else \'14\'||decode(count(*),\r\nAdd_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\'),null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,Trunc(da,\'MM\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(263, 6227, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(da,\'MM\') t,MIN(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=Add_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\')\r\nthen \'1\' else \'14\'||decode(count(*),\r\nAdd_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\'),null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,Trunc(da,\'MM\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(264, 8093, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n             FROM spty\r\n            WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nSELECT md_cnt,aggf_id\r\n  INTO cnt1,gf1\r\n  FROM st_ml\r\n WHERE ml_id=:1;\r\nSELECT md_cnt,tff_id\r\n  INTO cnt2,v_tff_id\r\n  FROM st_ml\r\n WHERE ml_id=:2;\r\nOPEN c_ROWS ( gf1 );\r\nLOOP\r\n  FETCH c_ROWS\r\n  BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1\r\n  LIMIT pGF;\r\n  EXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT da+TRUNC(ROUND((bt-da)*cnt2,6))/cnt2 t,c1,c2,c3,point_id, NVL(SUM( DECODE( tff_ID, v_tff_id, VAL * DECODE( gf1, 3, 24/cnt1 ,1))),0) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0 and count(*)*cnt2=cnt1\r\nthen \'1\' else \'14\'||decode(count(*)*cnt2,cnt1,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,point_id,da,da+TRUNC(ROUND((bt-da)*cnt2,6))/cnt2 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(265, 3583, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nselect level BULK COLLECT INTO pNR from dual connect by level<=mi;\r\nDELETE GTTT;\r\nFORALL j in 1..mi\r\nINSERT INTO GTTT (id0,id1) values (pNR(j),sPL_ID(j));\r\nSELECT d\r\nBULK COLLECT INTO s1\r\nFROM\r\n(SELECT /*+ use_nl(a b c) index(c plep_pk)*/ id0,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END d\r\nFROM\r\ngttt a\r\nleft join plu b ON (a.id1=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.id1=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY id0\r\nORDER BY id0);\r\nDELETE GTTT;\r\nFORALL j IN 1..mi\r\nINSERT INTO gttt (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT NULL,NULL,sPL_ID(j),sSEP_ID(j),Trunc(bt,\'HH\'),\'\'\r\n,Avg(val),Nvl(:7,0),Decode(Max(HAS_SPECIFIC_DSTATUS),0,\'1\',\'14\'),SYSDATE,\'\'\r\n,sAGGS_TYPE_ID(j) FROM v_ar_wo_byp\r\nWHERE point_id=sPOINT_ID(j) AND ml_id=:1 AND da>=Trunc(s1(j)) AND bt>=s1(j) AND da<s2\r\nAND NOT val IS NULL\r\nGROUP BY Trunc(bt,\'HH\')\r\nHAVING Count(*)=2;\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8  AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(266, 6057, 's0:=Trunc(Nvl(:4,add_months(trunc(SYSDATE,\'MM\'),-1*:3)));\r\ns2:=Nvl(add_months(Trunc(:5,\'MM\'),1),trunc(SYSDATE,\'MM\'));\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',round(mval,6), Nvl(:7,0),\r\nstatus,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n( select * from(\r\nSELECT c1,c2,c3,Add_Months(da, nvl(:8, 0))t,\r\n da,val,lead(val) over (PARTITION BY f.point_id order by da)-val mval\r\n,case when HAS_SPECIFIC_DSTATUS=0 and lead(HAS_SPECIFIC_DSTATUS) over (PARTITION BY f.point_id order by da)=0 then \'1\' else \'14\' end status\r\n,MONTHS_BETWEEN(lead(da) over (PARTITION BY f.point_id order by da),da) mb\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1 and s1<s2 ),Trunc(d.s1),s2+1,0))\r\n f,mou u where f.point_id=u.point_id (+) AND f.da<u.mou_bt (+) AND add_months(f.da,1)>=u.mou_bt (+) AND u.mou_id IS null\r\nand\r\nNOT val IS NULL AND u.point_id IS null\r\n) where mb=1)r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(267, 1877, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,sAGGF_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0),sAGGF_ID);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\',ex\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,pEXTREME_T\r\nFROM\r\n(SELECT c1,c2, c3, TRUNC(BT, \'DD\') t, val v,\r\nCASE WHEN ST=1 OR SYSDATE<aET THEN \'14\' ELSE \'1\' END s, CASE WHEN (select aggf_id from ml where ml_id=:1) IN (4,5) THEN EXTREME_BT ELSE BT END ex\r\nFROM (select a.*,\r\nrank() over (partition by point_id, ml_id, TRUNC(BT, \'DD\') order by HAS_SPECIFIC_DSTATUS, VAL desc, BT desc) rnkmx\r\n,rank() over (partition by point_id, ml_id, TRUNC(BT, \'DD\') order by HAS_SPECIFIC_DSTATUS, -VAL desc, BT desc) rnkmn\r\n,max(HAS_SPECIFIC_DSTATUS) over (PARTITION BY POINT_ID, ML_ID, TRUNC(BT, \'DD\')) st,\r\nTRUNC(BT, \'DD\')+1 aET\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,param1,\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\n a\r\n) where ((rnkmx=1 and c4=4) or (rnkmn=1 and c4=5)) and not val is null and not bt is null) r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans,pPCK_T,pPCK_N,pPCK_T,pPCK_N,pEXTREME_T);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(268, 6236, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,sAGGF_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0),sAGGF_ID);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\',ex\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,pEXTREME_T\r\nFROM\r\n(SELECT c1,c2, c3, TRUNC(BT,\'HH\') t, val v,\r\nCASE WHEN ST=1 OR SYSDATE<aET THEN \'14\' ELSE \'1\' END s, CASE WHEN (select aggf_id from ml where ml_id=:1) IN (4,5) THEN EXTREME_BT ELSE BT END ex\r\nFROM (select a.*,\r\nrank() over (partition by point_id,ml_id,TRUNC(BT,\'HH\') order by HAS_SPECIFIC_DSTATUS,VAL desc,BT desc) rnkmx\r\n,rank() over (partition by point_id,ml_id,TRUNC(BT,\'HH\') order by HAS_SPECIFIC_DSTATUS,-VAL desc,BT desc) rnkmn\r\n,max(HAS_SPECIFIC_DSTATUS) over (PARTITION BY POINT_ID,ML_ID,TRUNC(BT,\'DD\')) st,\r\nTRUNC(BT,\'HH\')+1/24 aET\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,param1,\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\n a\r\n) where ((rnkmx=1 and c4=4) or (rnkmn=1 and c4=5)) and not val is null and not bt is null ) r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans,pPCK_T,pPCK_N,pPCK_T,pPCK_N,pEXTREME_T);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(269, 5, 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,sAGGF_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0),sAGGF_ID);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\',ex\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,pEXTREME_T\r\nFROM\r\n(SELECT c1,c2, c3, TRUNC(BT, \'MM\') t, val v,\r\nCASE WHEN ST=1 OR SYSDATE<aET THEN \'14\' ELSE \'1\' END s, CASE WHEN (select aggf_id from ml where ml_id=:1) IN (4,5) THEN EXTREME_BT ELSE BT END ex\r\nFROM (select a.*,\r\nrank() over (partition by point_id, ml_id, TRUNC(BT, \'MM\') order by HAS_SPECIFIC_DSTATUS, VAL desc, BT desc) rnkmx\r\n,rank() over (partition by point_id, ml_id, TRUNC(BT, \'MM\') order by HAS_SPECIFIC_DSTATUS, -VAL desc, BT desc) rnkmn\r\n,max(HAS_SPECIFIC_DSTATUS) over (PARTITION BY POINT_ID, ML_ID, TRUNC(BT, \'DD\')) st,\r\nADD_MONTHS(TRUNC(BT, \'MM\'),1) aET\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,param1,\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\n a\r\n) where ((rnkmx=1 and c4=4) or (rnkmn=1 and c4=5)) and not val is null and not bt is null) r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans,pPCK_T,pPCK_N,pPCK_T,pPCK_N,pEXTREME_T);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(270, 2135, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3),Nvl(:5+1,SYSDATE),1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,ib t\r\n,round(Sum(q*l)*30,6) v,Decode(Max(k),0,\'1\',\'14\') s\r\nFROM\r\n(SELECT f.*\r\n,Trunc(bt)+Trunc(Round((bt-Trunc(bt))*720,6))/720+(d.column_value-1)/720 ib\r\n,g/(et-bt)/720 q\r\n,(Least(et,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*720,6))/720+(d.column_value)/720)-Greatest(bt,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*720,6))/720+(d.column_value-1)/720))*720 l\r\n,CASE WHEN et-bt>=5/1440 and not g=0 THEN 1 ELSE 0 END k\r\nFROM (SELECT da,bt, c1,c2,c3,point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),Nvl(:5+1,SYSDATE)))\r\nWHERE NOT val IS NULL) f,mou u, TABLE(SELECT CAST(COLLECT(level) AS sql_objects) FROM dual CONNECT BY Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*720,6))/720+(LEVEL-1)/720<f.et) d\r\nwhere f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\n) h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(271, 4294, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n             FROM spty\r\n            WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nOPEN c_ROWS ( s0, s2);\r\nLOOP\r\n  FETCH c_ROWS\r\n  BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1\r\n  LIMIT pGF;\r\n  EXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n    (select c1,c2,c3,d t,v,\'1\' s\r\n    FROM (select b.*\r\n    ,Rank() over (PARTITION BY point_id,d ORDER BY i)r from\r\n    (select point_id,c1,c2,c3,i,d,Sum(v)v FROM\r\n    (select v.point_id,c1,c2,c3,i,da+Decode(i,2,Decode(ml_id,:1,0,-1),1) d,\r\n    case when ml_id=:1 and i=2 then -1 else 1 end*val v\r\n     from\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,:2))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1)-1,s2))\r\n     v,(SELECT LEVEL i FROM dual CONNECT BY LEVEL<=2),\r\n         (SELECT DISTINCT point_id, Trunc(mou_bt) m FROM mou) u\r\n    WHERE v.point_id = u.point_id(+)\r\n      AND v.da = u.m (+)\r\n      AND u.point_id IS NULL\r\n      AND v.has_specific_dstatus=0\r\n    ) GROUP BY point_id,c1,c2,c3,i,d having Count(*)=2\r\n    ) b\r\n    ) WHERE r=1)r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(272, 3465, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))FROM spty WHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF FROM dual;\r\nselect b.ml_id into m1 from st_ml a , st_ml b where a.ml_id=:1 and\r\na.MS_ID=b.ms_id and a.DIR_ID=b.dir_id and a.tff_id=b.TFF_ID and a.AGGF_ID=b.aggf_id\r\nand b.aggs_id=8 and a.aggs_id=5 and a.md_id=5 and b.MD_ID=7;\r\nOPEN c_ROWS;\r\nLOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1 LIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,v,Decode(s,0,\'1\',\'14\') s FROM\r\n(SELECT c1,c2,c3,da,bt,read_time, val,ml_id,read_time_day,count(*) over (partition by point_id,da) cnt\r\n,max(decode(ml_id,m1,val))over(partition by point_id,da)-max(decode(ml_id,:1,val))over(partition by point_id,da) v,s\r\nfrom(SELECT point_id,c1,c2,c3,da,bt,read_time,val,ml_id,read_time_day,rank() over (partition by point_id,da,ml_id order by s,bt) rnk,s\r\nfrom(SELECT point_id,c1,c2,c3,da,bt,read_time,val,ml_id,max(decode(ml_id,:1,read_time)) over (partition by point_id,da) read_time_day\r\n,decode(ml_id,m1,HAS_SPECIFIC_DSTATUS) s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,m1))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL)\r\nwhere abs(decode(ml_id,m1,bt,read_time)-read_time_day)<=nvl(:8,5)/86400\r\nand read_time_day-da>=nvl(:9,0)/1440) where rnk=1) where cnt=2 AND ml_id=m1)r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(273, 1907, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3, da t,\r\n Max(Decode(bitand(val,Power(2,7)),Power(2,7),1,0))*Power(2,7)\r\n+Max(Decode(bitand(val,Power(2,6)),Power(2,6),1,0))*Power(2,6)\r\n+Max(Decode(bitand(val,Power(2,5)),Power(2,5),1,0))*Power(2,5)\r\n+Max(Decode(bitand(val,Power(2,4)),Power(2,4),1,0))*Power(2,4)\r\n+Max(Decode(bitand(val,Power(2,3)),Power(2,3),1,0))*Power(2,3)\r\n+Max(Decode(bitand(val,Power(2,2)),Power(2,2),1,0))*Power(2,2)\r\n+Max(Decode(bitand(val,Power(2,1)),Power(2,1),1,0))*Power(2,1)\r\n+Max(Decode(bitand(val,Power(2,0)),Power(2,0),1,0))*Power(2,0) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0 and count(*)=24\r\nthen \'1\' else \'14\'||decode(count(*),24,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(274, 893, 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))FROM spty WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF FROM dual;\r\nselect b.ml_id into m1 from st_ml a , st_ml b where a.ml_id=:1 and\r\na.MS_ID=b.ms_id and a.DIR_ID=b.dir_id and a.tff_id=b.TFF_ID and a.AGGF_ID=b.aggf_id\r\nand b.aggs_id=8 and a.aggs_id=6 and a.md_id=6 and b.MD_ID=7;\r\nOPEN c_ROWS; LOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1 LIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,mo t,v,Decode(s,0,\'1\',\'14\') s FROM\r\n(SELECT c1,c2,c3,bt,read_time, val,ml_id,read_time_mon,count(*) over (partition by point_id,mo) cnt\r\n,max(decode(ml_id,m1,val))over(partition by point_id,mo)-max(decode(ml_id,:1,val))over(partition by point_id,mo) v,s,mo\r\nfrom(SELECT point_id,c1,c2,c3,bt,read_time,val,ml_id,read_time_mon,rank() over (partition by point_id,mo,ml_id order by s,bt) rnk,s,mo\r\nfrom(SELECT point_id,c1,c2,c3,bt,read_time,val,ml_id,max(decode(ml_id,:1,read_time)) over (partition by point_id,trunc(da,\'MM\')) read_time_mon\r\n,decode(ml_id,m1,HAS_SPECIFIC_DSTATUS) s,trunc(da,\'MM\') mo\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,m1))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL)\r\nwhere abs(decode(ml_id,m1,bt,read_time)-read_time_mon)<=nvl(:8,5)/86400\r\nand read_time_mon-mo>=nvl(:9,0)/1440) where rnk=1) where cnt=2 AND ml_id=m1)r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(275, 2333, 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS (s0, s2);\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(select c1,c2,c3,d t,v,\'1\' s\r\nFROM (select b.*\r\n,Rank() over (PARTITION BY point_id,d ORDER BY i)r from\r\n(select point_id,c1,c2,c3,i,d,Sum(v)v FROM\r\n(select v.point_id,c1,c2,c3,i, ADD_MONTHS(da,Decode(i,2,Decode(ml_id,:1,0,-1),1)) d,\r\ncase when ml_id=:1 and i=2 then -1 else 1 end*val v\r\nfrom\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,:2))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1)-1,s2))\r\n v,(select level i from dual connect by level<=2)\r\n,(SELECT DISTINCT point_id, Trunc(mou_bt,\'MM\') m FROM mou) u\r\nwhere v.point_id = u.point_id(+)\r\nAND v.da = u.m (+)\r\nAND u.point_id IS NULL\r\nAND v.has_specific_dstatus=0\r\n) GROUP BY point_id,c1,c2,c3,i,d having Count(*)=2\r\n) b\r\n) where r=1)r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(276, 941, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3, bt+(nr-1)/96 t ,g/(et-bt)/24 v,Decode((et-bt)*96,1,\'1\',\'14\') s\r\nFROM(select * from\r\n(SELECT c1,c2,c3,da,bt, point_id\r\n,Lead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2+1))\r\nWHERE NOT val IS NULL  )r\r\n) f,mou u,iger where f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null and nr<=round((et-bt)*96,6))r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(277, 103, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,TRUNC(bt, \'HH\') t,MIN(val) v,\r\nCASE WHEN (\r\nCount(DISTINCT(Trunc((bt - TRUNC(bt, \'HH\'))*24*4)))\r\n>=4) THEN \'1\' ELSE \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,TRUNC(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(278, 7783, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n             FROM spty\r\n            WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n  FETCH c_ROWS\r\n  BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n  LIMIT pGF;\r\n  EXIT WHEN sPL_ID.Count=0;\r\n  select DS_ID into pDS_ID FROM DS WHERE ds_code=:8 and DS_ENABLED=1;\r\n  delete gttt;\r\n  FORALL j IN 1..sPOINT_ID.count\r\n  insert into gttt(id1,id2,v1,id3,d1,d2)\r\n  select b.point_id,b.ml_id,b.val,b.has_specific_dstatus,b.bt,b.da\r\n   from v_ar b where  b.point_id=sPOINT_ID(j)and b.ml_id=:1 AND da >=NVL(:4,sysdate - :3)- 1/24\r\n  AND da <=NVL(:5,SYSDATE)and val is not null;\r\n  FORALL j IN 1..sPL_ID.count\r\n  INSERT INTO gttt\r\n  (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\n  with k as (select /*+ materialize */ a.*,trunc(a.new_ds_et,\'MI\')\r\n  tm_new_ds_et from (select lead(a.ds_bt)over (partition by a.ds_id order by a.ds_bt)as new_ds_et ,a.* from (select\r\n  a.ds_id,a.ds_t ds_bt ,trunc(a.ds_t,\'MI\')tm_ds_bt ,trunc(a.ds_t,\'DD\')td_ds_bt from v_AR_DS_PLAIN a\r\n  where a.ds_id=pDS_ID and a.ds_v=1 AND a.ds_t >=NVL(:4,sysdate-:3)-1/24 AND a.ds_t <=NVL(:5,SYSDATE))a)a),ar as (\r\n  select /*+ materialize */ id1  point_id,id2 ml_id,v1 val,id3 has_specific_dstatus,d1 bt,d2 da from gttt) SELECT\r\n  NULL,NULL,sPL_ID(j),sSEP_ID(j),ds_bt,\'\',round(val - prev_val,6)v,Nvl(:7,0)\r\n  ,case when greatest(prev_has_specific_dstatus,has_specific_dstatus)=0 then 1 else 14 end,SYSDATE,\'\',sAGGS_TYPE_ID(j)\r\n  FROM(select lag(val) over (partition by point_id order by bt)prev_val,lag(has_specific_dstatus)over (partition by\r\n  point_id order by bt)prev_has_specific_dstatus ,m.* from (select k.* from (select rank() over (partition by\r\n  point_id,ds_id,ds_bt,new_ds_et order by bt)rnk ,j.* from ( select a.ds_id,a.ds_bt,a.new_ds_et,b.* from ar b\r\n  join k a on (b.bt>=a.tm_ds_bt and b.bt<=a.tm_new_ds_et and a.td_ds_bt=b.da))j)k where rnk=1)m)n\r\n  where round(val - prev_val,6)IS not NULL;\r\n  SELECT\r\n  d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\n  BULK COLLECT INTO\r\n  pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\n  FROM gttt f\r\n  WHERE f.id8 is not null --/7 and not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND storable=1 AND improvable=0)\r\n;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(279, 918, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual; select nvl(to_number(:9),0) into p from dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,NVL( add_months(TRUNC(:4,\'MM\'),-1),add_months(TRUNC(sysdate,\'MM\'),-:3 -1) ),NVL( :5,SYSDATE ),1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT\r\nc1,c2,c3,mo1 t,round(delta_val,6) v\r\n,s FROM\r\n(\r\nSELECT b.*,case when (bt>=last_d-nvl(:8,5) and bt<last_d and prev_bt>=prev_last_d-nvl(:8,5) and prev_bt<prev_last_d)\r\nand (HAS_SPECIFIC_DSTATUS=0 and prev_HAS_SPECIFIC_DSTATUS=0) AND NOT (mo1=TRUNC(sysdate,\'MM\')) then 1 else 14\r\nend s\r\nFROM (SELECT a.*\r\n,val-lag(val) over (PARTITION by point_id,ml_id order by da) delta_val\r\n,lag(val) over (PARTITION by point_id,ml_id order by da) prev_val\r\n,lag(bt) over (PARTITION by point_id,ml_id order by da) prev_bt ,case when p=0 then mo when p=1 then add_months(mo,-1) end mo1\r\n,lag(HAS_SPECIFIC_DSTATUS) over (PARTITION by point_id,ml_id order by da) prev_HAS_SPECIFIC_DSTATUS\r\n,case when p=0 then last_day(mo)+1\r\n      when p=1 then mo+nvl(:8,5) end last_d\r\n,case when p=0 then last_day(add_months(mo,-1))+1\r\n      when p=1 then add_months(mo,-1)+nvl(:8,5) end prev_last_d\r\nFROM\r\n(SELECT c1,c2,c3,point_id,ml_id,da,bt,trunc(da,\'MM\') mo,val,HAS_SPECIFIC_DSTATUS\r\n,case when p=0 then rank() over (PARTITION by point_id,ml_id,trunc(da,\'MM\') order by da desc,bt desc)\r\n      when p=1 then rank() over (PARTITION by point_id,ml_id,trunc(da,\'MM\') order by da asc,bt asc)\r\n end rnk\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),NVL( :5,SYSDATE )))\r\nWHERE NOT val IS NULL\r\norder by ml_id,da desc,bt desc\r\n) a where rnk=1) b,mou u\r\nWHERE b.POINT_ID=u.point_id (+) AND b.prev_bt<u.mou_bt (+) AND b.bt>=u.mou_bt (+) AND u.mou_id IS null\r\n) where delta_val IS not NULL)r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(280, 6234, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n FROM spty\r\n WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(bt,\'HH\') t,Avg(val) v,\r\nCASE WHEN (\r\nCount(DISTINCT(Trunc((bt - TRUNC(bt, \'HH\'))*24*4)))\r\n>=4) THEN \'1\' ELSE \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,Trunc(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(281, 6354, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\ndelete gttt;\r\nFORALL j IN 1..sPL_ID.count\r\nINSERT INTO gttt\r\n(d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT NULL,NULL,sPL_ID(j),sSEP_ID(j),ib\r\n,\'\',Sum(q*l),Nvl(:7,0),Decode(Max(k),0,\'1\',\'14\'),SYSDATE,\'\'\r\n,sAGGS_TYPE_ID(j) FROM (SELECT f.*, w.* ,g/(et-bt)/24 q, TRUNC(f.bt, \'HH\')+(w.column_value-1)/24 ib\r\n,(Least(et,TRUNC(f.bt, \'HH\')+w.column_value /24)-Greatest(bt,TRUNC(f.bt, \'HH\')+(w.column_value-1)/24))*24 l\r\n,CASE WHEN et-bt>=2/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM\r\n(\r\nSELECT bt,\r\nLead(bt) over (ORDER BY bt) et,\r\nLead(val) over (ORDER BY bt)-\r\nCASE WHEN\r\nLead(val) over (ORDER BY bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nfrom\r\n(SELECT bt,val\r\nFROM v_ar\r\nWHERE point_id=sPOINT_ID(j) AND ml_id=:1 AND da>=Nvl(:4,SYSDATE-:3)\r\nAND da<=Nvl(:5,SYSDATE) AND NOT val IS NULL\r\n) r\r\nWHERE NOT EXISTS (\r\nSELECT 0 FROM\r\nst_map_plain p\r\n,st_map_data_plain d\r\nWHERE\r\np.point_id=sPOINT_ID(j) AND p.ml_id=:1 AND\r\np.ma_enabled=1 AND p.ma_auto_check=1 AND p.ma_auto_null_act=1 AND p.map_enabled=1\r\nAND p.map_id=d.map_id(+) AND r.bt=d.mt_time(+)\r\nAND r.bt>=p.bt AND r.bt<Nvl(p.et,r.bt+1)\r\nAND Nvl(d.mt_success,0)=0\r\n)\r\n) f,mou u, TABLE (SELECT CAST(COLLECT(level) AS sql_objects) FROM dual connect by level<=(ROUND(\r\n(CASE\r\nWHEN f.et=trunc(f.et, \'HH\')\r\nTHEN f.et\r\nELSE TRUNC(f.et, \'HH\')+1/24\r\nEND\r\n - TRUNC (f.bt, \'HH\')) * 24, 6))) w WHERE sPOINT_ID(j)=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null) h\r\nGROUP BY ib HAVING Round(Sum(l),6)=1;\r\nSELECT d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=f.id2 and aggs_type_id=f.id8 AND pl_t=f.d2 AND storable=1 and improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(282, 4857, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nselect level BULK COLLECT INTO pNR from dual connect by level<=mi;\r\nDELETE GTTT;\r\nFORALL j in 1..mi\r\nINSERT INTO GTTT (id0,id1) values (pNR(j),sPL_ID(j));\r\nSELECT d\r\nBULK COLLECT INTO s1\r\nFROM\r\n(SELECT /*+ use_nl(a b c) index(c plep_pk)*/ id0,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END d\r\nFROM\r\ngttt a\r\nleft join plu b ON (a.id1=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.id1=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY id0\r\nORDER BY id0);\r\nDELETE GTTT;\r\nFORALL j IN 1..mi\r\nINSERT INTO gttt (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT\r\nNULL,NULL,sPL_ID(j),sSEP_ID(j),xfe_t,\'\',xfe_v,Nvl(:7,0)\r\n,CASE WHEN improvable=0 THEN \'1\' ELSE \'14\' END,SYSDATE,\'\',sAGGS_TYPE_ID(j) aggs_type_id\r\nfrom\r\n(SELECT xfe_t,xfe_v,improvable\r\n,Rank() over (PARTITION BY point_id,ml_id,xfe_t ORDER BY xo_id desc) r\r\nFROM xfe_pl_data join xfe USING (xfe_id) join xfau USING (xfau_id) join xfa USING (xfa_id) join xf USING (xf_id)\r\nWHERE point_id=sPOINT_ID(j) AND ml_id=:1 AND xfe_t>=s1(j) AND xfe_t<s2\r\nAND regexp_like(xf_type_id,\'^(\'||Nvl(:8,\'1|6\')||\')$\')\r\n) WHERE r=1;\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(283, 9025, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n  FROM spty\r\n WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nSELECT aggf_id\r\n  INTO gf1\r\n  FROM st_ml\r\n WHERE ml_id=:1;\r\nSELECT tff_id, md_id\r\n  INTO v_ttf_id, v_md_id\r\n  FROM st_ml\r\n WHERE ml_id=:2;\r\nif v_md_id = 6 then\r\n  s0:=Trunc(Nvl(:4,SYSDATE-:3), \'MM\');\r\n  s2:=Nvl(Add_Months(Trunc(:5, \'MM\'),1),SYSDATE);\r\nelse\r\n  s0:=Trunc(Nvl(:4,SYSDATE-:3));\r\n  s2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nend if;\r\nOPEN c_ROWS ( gf1 );\r\nLOOP\r\n  FETCH c_ROWS\r\n  BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,sAGGF_ID,s1\r\n  LIMIT pGF;\r\n  EXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0),sAGGF_ID,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\',ex\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,pEXTREME_T\r\nFROM\r\n(SELECT c1,c2,c3,c4,\r\n   case when v_md_id = 6 then TRUNC(BT, \'MM\') else TRUNC(BT, \'DD\') end t\r\n   ,val v\r\n   ,CASE WHEN ST=1 OR SYSDATE<aET THEN \'14\' ELSE \'1\' END s\r\n   ,CASE WHEN (select aggf_id from ml where ml_id=:1) IN (4,5) THEN EXTREME_BT ELSE BT END ex\r\n  FROM\r\n    (select a.*\r\n    ,rank() over (partition by point_id, ml_id,\r\n     case when v_md_id = 6 then TRUNC(BT, \'MM\') else TRUNC(BT, \'DD\') end\r\n     order by HAS_SPECIFIC_DSTATUS, VAL desc, BT) rnkmx\r\n    ,rank() over (partition by point_id, ml_id,\r\n     case when v_md_id = 6 then TRUNC(BT, \'MM\') else TRUNC(BT, \'DD\') end\r\n     order by HAS_SPECIFIC_DSTATUS, -VAL desc, BT) rnkmn\r\n    ,max(HAS_SPECIFIC_DSTATUS) over (PARTITION BY POINT_ID, ML_ID,\r\n    case when v_md_id = 6 then TRUNC(BT, \'MM\') else TRUNC(BT, \'DD\') end) st,\r\n    case when v_md_id = 6 then TRUNC(add_months(BT,1), \'MM\')+1 else TRUNC(BT, \'DD\')+1 end aET\r\n    from\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,param1,\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\n    a where tff_id=v_ttf_id )\r\n    WHERE   ((rnkmx=1 and c4=4) or (rnkmn=1 and c4=5))\r\n    and val is not null and bt is not null) r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans,pPCK_T,pPCK_N,pPCK_T,pPCK_N,pEXTREME_T);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(284, 8739, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nSELECT ML_ID\r\nINTO L\r\nFROM ML\r\nWHERE (MS_ID,DIR_ID,AGGS_ID,AGGF_ID,TFF_ID,MD_ID)\r\nIN (SELECT MS_ID,DIR_ID,AGGS_ID,AGGF_ID,TFF_ID,6\r\nFROM ML\r\nWHERE ML_ID = :2);\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM(SELECT c1,c2,c3,t,v\r\n,Decode(z,0,\'1\',\'14\') s FROM\r\n(SELECT c1,c2,c3,Decode(i,1,da,da+1) t\r\n,Max(Decode(i,1,val)) over (PARTITION BY point_id,m)+Decode(i,1,0,Sum(Decode(i,1,NULL,val)) over (PARTITION BY point_id,m ORDER BY da)) v\r\n,Decode(i,1,s,Max(s) over (PARTITION BY point_id,m ORDER BY da)) z,m,da from\r\n(SELECT a.*,Decode(val,NULL,2,has_specific_dstatus) s,Trunc(da,\'MM\') m,Decode(ml_id,L,1) i\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id, column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,L))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1,\'MM\'),s2))\r\n a )\r\n) WHERE z<2 AND m=Trunc(da+1,\'MM\'))r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(285, 728, 's0:=Trunc(Nvl(:4,SYSDATE-:3)); s2:=Nvl(Trunc(:5)+1,SYSDATE); SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty WHERE spty.spty_code=\'GENERATION_FETCH\'), 100) INTO pGF FROM dual;\r\nOPEN c_ROWS; LOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID LIMIT pGF;\r\nmi:=sPL_ID.Count; EXIT WHEN mi=0; select level BULK COLLECT INTO pNR from dual connect by level<=mi;\r\nDELETE GTTT; FORALL j in 1..mi INSERT INTO GTTT (id0,id1) values (pNR(j),sPL_ID(j));\r\nSELECT d BULK COLLECT INTO s1 FROM\r\n(SELECT /*+ use_nl(a b c) index(c plep_pk)*/ id0,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END d FROM gttt a\r\nleft join plu b ON (a.id1=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.id1=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY id0 ORDER BY id0);\r\nDELETE GTTT;\r\nFORALL j IN 1..mi\r\nINSERT INTO gttt (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT\r\nNULL,NULL,sPL_ID(j),sSEP_ID(j),bt\r\n,\'\',round(new_val,6),Nvl(:7,0),CASE WHEN s=0 AND p=0 AND bad=1 THEN \'1\' else \'14\' end\r\n,SYSDATE,\'\',sAGGS_TYPE_ID(j) FROM\r\n(with a1 as (\r\nSELECT point_id,ml_id,da,bt,val,HAS_SPECIFIC_DSTATUS s\r\nFROM v_ar\r\nWHERE point_id=sPOINT_ID(j)\r\nAND ml_id=:1\r\nAND da>=Trunc(s1(j)) AND da<s2\r\nAND NOT val IS NULL )\r\nselect * from (select a.* ,case when a.val is null then (c.val-sum)/bad end as new_val , c.s from (select * from(\r\nSELECT point_id,ml_id,da,bt,val\r\n,sum(decode(val,null,1,0))over(partition by point_id, ml_id, da) bad\r\n,sum(val)over(partition by point_id, ml_id, da) Sum\r\n,max(Nvl2(val,HAS_SPECIFIC_DSTATUS,NULL))over(partition by point_id, ml_id, da) p\r\nfrom(\r\n select point_id, ml_id, da, bt\r\n ,decode(ssep_id,tsep_id,null,hsd)HAS_SPECIFIC_DSTATUS\r\n ,decode(ssep_id,tsep_id,null,val)val\r\n from(\r\n select sSEP_ID(j) tsep_id, point_id, ml_id,da,bt, HAS_SPECIFIC_DSTATUS hsd, val\r\n ,(select sep_id from pl_data_valid b where sPL_ID(j)=PL_ID and b.pl_t=a.bt\r\n and sAGGS_TYPE_ID(j)=AGGS_TYPE_ID and sSEP_ID(j)=sep_id and Nvl(:7,0)=1) ssep_id\r\n FROM v_ar a WHERE point_id=sPOINT_ID(j) AND ml_id=:2 AND da>=Trunc(s1(j)) AND da<s2\r\n )d\r\n )\r\n)where bad>0) a join a1 c on (a.point_id=c.point_id and a.da=c.da)\r\n) where new_val is not null\r\n) f;\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND storable=1 and improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(286, 3809, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n             FROM spty\r\n            WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nselect md_cnt,aggf_id into cnt1,gf1 from st_ml where ml_id=:1;\r\nselect md_cnt into cnt2 from st_ml where ml_id=:2;\r\nOPEN c_ROWS ( s0, s2);\r\nLOOP\r\n  FETCH c_ROWS\r\n  BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1\r\n  LIMIT pGF;\r\n  EXIT WHEN sPL_ID.Count=0;\r\n  FORALL j IN 1..sPL_ID.count\r\n    INSERT INTO gttt\r\n    (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\n    select \'\',\'\',sPL_ID(j),sSEP_ID(j),d,\'\',v,Nvl(:7,0),\'1\',sysdate,\'\',sAGGS_TYPE_ID(j)\r\n    FROM (select b.*\r\n    ,Rank() over (PARTITION BY d ORDER BY i)r from\r\n    (select i,d,Sum(v)v FROM\r\n    (select i,bt+Decode(i,2,Decode(ml_id,:1,0,(-1)/cnt1),1/cnt1) d,\r\n    case when ml_id=:1 and i=2 then -1 else 1 end*val*Decode(gf1,3,24/cnt1,1) v\r\n     from v_ar v,(SELECT LEVEL i FROM dual CONNECT BY LEVEL<=2),\r\n         (SELECT DISTINCT point_id, Trunc(mou_bt) m FROM mou) u\r\n    WHERE v.point_id = sPOINT_ID(j)\r\n      AND v.point_id = u.point_id(+)\r\n      AND v.da = u.m (+)\r\n      AND u.point_id IS NULL\r\n      AND v.ml_id in (:1,:2)\r\n      AND v.da>=trunc(s1(j))-1 and v.bt>=s1(j)-1/cnt1 and v.da<s2 and v.bt<s2\r\n      AND v.has_specific_dstatus=0\r\n    ) GROUP BY i,d having Count(*)=2\r\n    ) b\r\n    ) WHERE r=1;\r\n  SELECT d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\n  BULK COLLECT INTO\r\n  pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\n  FROM gttt f\r\n  --/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND storable=1 AND improvable=0)\r\n;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(287, 895, 'DELETE st_sp_lpty_w u WHERE lpty_id=103 AND lpty_value<>\'0\'\r\nAND NOT sp_id IN  (\r\nSELECT sp_id FROM (\r\nSELECT\r\ncol_name, new_val sp_id\r\n,Max(Decode(col_name,\'LPTY_ID\',new_val)) over (PARTITION BY db_time, au_nr) lpty_id\r\nFROM au_idata join au USING (db_time, au_nr) join tab USING (tab_id) join col USING (col_id)\r\nWHERE tab_name = \'SP_LPTY\' AND col_name IN (\'SP_ID\',\'LPTY_ID\') AND db_time> SYSDATE-NVL(:1,30)\r\n) WHERE lpty_id=103 AND col_name=\'SP_ID\'\r\n);'),
	(288, 5390, 'SELECT Nvl((SELECT amp FROM tmst WHERE tmst_code = \'AUTO_DELETE_BGA_AUD_DATA\'),DATE\'2000-01-01\'),Least(SYSDATE-Nvl(:1,10),SYSDATE-1/48) INTO a,b FROM dual;\r\ndelete (SELECT db_time FROM au join tab USING (tab_id) where tab_name in (\'GRP\',\'POINT_PPTY\',\'GR_GPTY\',\'GRC\') and ses_id is null and db_time>=a and db_time<b) WHERE rownum<=2000000;\r\nIF SQL%ROWCOUNT<2000000 THEN\r\nMERGE INTO tmst y\r\nUSING (SELECT \'AUTO_DELETE_BGA_AUD_DATA\' tmst_code,b amp FROM dual) u\r\n   ON (y.tmst_code = u.tmst_code)\r\nWHEN MATCHED THEN UPDATE SET\r\n y.amp= u.amp\r\nWHERE NOT y.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n (\r\n y.tmst_code\r\n,y.amp\r\n) values (\r\n u.tmst_code\r\n,u.amp\r\n);\r\nEND IF;'),
	(289, 193, 'a DATE;\r\nb DATE;\r\nTS DATE;\r\nrlimit number;'),
	(290, 8835, 'RLIMIT:=nvl(:4,10000);\r\nTS:= SYSDATE;\r\nSELECT Nvl((SELECT amp FROM tmst WHERE tmst_code=\'AUTO_DELETE_ALL_FROM_AUD_DATA\'),DATE\'2000-01-01\'),Least(ADD_MONTHS(SYSDATE, -nvl(:2,36)),SYSDATE-1/48) INTO a,b FROM dual;\r\nLOOP\r\ndelete (SELECT db_time FROM au where db_time>=a and db_time<b) WHERE rownum<=RLIMIT;\r\nIF SQL%ROWCOUNT<RLIMIT THEN\r\nMERGE INTO tmst y\r\nUSING (SELECT \'AUTO_DELETE_ALL_FROM_AUD_DATA\' tmst_code,b amp FROM dual) u\r\n   ON (y.tmst_code = u.tmst_code)\r\nWHEN MATCHED THEN UPDATE SET\r\n y.amp= u.amp\r\nWHERE NOT y.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n (\r\n y.tmst_code\r\n,y.amp\r\n) values (\r\n u.tmst_code\r\n,u.amp\r\n);\r\nts:=DATE\'2000-01-01\';\r\nEND IF;\r\nCOMMIT;\r\nEXIT WHEN SYSDATE > TS + nvl(:3,45)/86400;\r\nEND LOOP;'),
	(291, 3952, 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'PL_SE_POST_PROCESSING\'),add_months(sysdate,-12)),sysdate-10/1440 INTO vd1,vd2 FROM DUAL;\r\ndelete gttt;\r\ninsert into gttt (id1,id2)\r\nselect * from (\r\nWITH\r\nf as\r\n(\r\nSELECT /*+materialize*/ src_id,db_time FROM\r\n(SELECT new_val src_id, Max(db_time) db_time\r\nFROM au join tab USING (tab_id) join au_idata USING (db_time,au_nr) join col USING (col_id)\r\nWHERE tab_name = \'SE\' AND operation_type=\'I\' AND db_time>=vD1 AND db_time<vD2 AND col_name= \'SRC_ID\' AND :1 IS NULL\r\nGROUP BY new_val\r\nUNION ALL\r\nSELECT src_id, To_Date(NULL) FROM src_pw_tmst WHERE id=1 AND pck_t BETWEEN SYSDATE-2/24 AND SYSDATE-1/48 AND :1 IS NULL\r\nUNION ALL\r\nSELECT To_Number(:1),sysdate FROM dual WHERE NOT :1 IS null)\r\n)\r\n,s AS\r\n(SELECT a.src_id,c.point_id\r\nfrom f a\r\njoin src b on (a.src_id=b.src_id)\r\njoin src_pw_tmst c ON (b.src_id = c.src_id AND c.id IN (1,3,5))\r\nWHERE b.src_et IS NULL\r\nGROUP BY a.src_id,c.point_id\r\nHAVING Max(Decode(c.id,1,1))=1\r\nAND\r\n(Max(Decode(c.id,3,pw_rt)) is NULL\r\nOR Max(Decode(c.id,3,pw_rt))<Max(a.db_time)\r\nOR Max(Decode(c.id,3,pw_rt))<Max(Decode(c.id,5,pw_rt))\r\n)\r\n)\r\nSELECT s.src_id, s.point_id FROM\r\ns\r\nJOIN pl a ON (a.point_id=s.point_id)\r\nJOIN di i ON (a.pl_id=i.pl_id)\r\nJOIN se e ON (s.src_id=e.src_id AND e.di_id=i.di_id)\r\nJOIN sep p ON (e.se_id=p.se_id)\r\nGROUP BY s.src_id, s.point_id\r\n);\r\npwl_execute;\r\nUPDATE gttt r SET id4=1 WHERE NOT EXISTS (SELECT 0 FROM V_LPTY_MISSING V WHERE R.ID1 = V.SRC_ID AND NVL(V.POINT_ID,R.ID2)=R.ID2);\r\nMERGE INTO src_pw_tmst y\r\nUSING (SELECT id1,id2 FROM gttt WHERE id4=1) u\r\nON (y.src_id = u.id1 AND y.point_id=u.id2 AND y.id=3)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.pw_rt=sysdate\r\n,y.pck_t=sysdate\r\nWHEN NOT MATCHED THEN INSERT\r\n(y.src_id\r\n,y.point_id\r\n,y.id\r\n,y.pw_rt\r\n,y.pck_t\r\n) values (\r\n u.id1\r\n,u.id2\r\n,3\r\n,sysdate\r\n,sysdate\r\n);\r\nIF :1 IS NULL then\r\nSELECT id2 bulk collect into ePOINT_ID FROM gttt WHERE id4=1;\r\nFOR i IN 1..ePOINT_ID.Count LOOP\r\nSELECT ePOINT_ID(i),\'0\' BULK COLLECT INTO pPOINT_ID,ans FROM dual;\r\ninit_fill_point3(pPOINT_ID,ans,orn);\r\n if ans(1)=\'0\' then\r\n  INSERT INTO DTL (DB_TIME,REQ_TYPE_CODE,RODO_ID,URGENT)\r\n  select sysdate, REQ_TYPE_CODE, orn, 0 from rc where rc_id=16;\r\n end if;\r\nEND LOOP;\r\nMERGE INTO TMST y\r\n   USING (   SELECT \'PL_SE_POST_PROCESSING\' TMST_CODE,vd2 amp FROM dual) u\r\n   ON (y.TMST_CODE = u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\n y.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n (\r\n y.TMST_CODE\r\n,y.amp\r\n) values (\r\n u.TMST_CODE\r\n,u.amp\r\n);\r\nEND IF;'),
	(292, 396, 'SELECT /*+ parallel(a)*/p.point_id FROM\r\npoint p\r\njoin pl b ON (p.point_id=b.point_id)\r\njoin di i ON (b.pl_id=i.pl_id)\r\njoin plep a ON (b.pl_id=a.pl_id)\r\nleft join (SELECT new_val point_id\r\nFROM au join tab USING (tab_id) join au_idata USING (db_time,au_nr) join col USING (col_id)\r\nWHERE tab_name=\'SRC\' AND operation_type=\'I\' AND db_time>SYSDATE-1\r\nAND col_name = \'POINT_ID\' AND NOT new_val IS null) s ON (p.point_id=s.point_id)\r\nWHERE plep_bt>= Trunc(SYSDATE)-:1 and point_enabled=1\r\nAND point_auto_read_enabled=1 AND pl_enabled=1\r\nAND s.point_id IS null\r\nAND di_enabled=1 group by p.point_id having max(Nvl(s_hosf,0))<3'),
	(293, 6407, 'SELECT /*+ parallel(a)*/p.point_id FROM\r\npoint p\r\njoin pl b ON (p.point_id=b.point_id)\r\njoin di i ON (b.pl_id=i.pl_id)\r\njoin plep a ON (b.pl_id=a.pl_id)\r\nleft JOIN src_pw_tmst t ON (p.POINT_ID=t.point_id AND t.id=3 AND pw_rt>Trunc(SYSDATE)-:1)\r\nleft join (SELECT new_val point_id\r\nFROM au join tab USING (tab_id) join au_idata USING (db_time,au_nr) join col USING (col_id)\r\nWHERE tab_name=\'SRC\' AND operation_type=\'I\' AND db_time>SYSDATE-1\r\nAND col_name = \'POINT_ID\' AND NOT new_val IS null) s ON (p.point_id=s.point_id)\r\nWHERE plep_bt>= Trunc(SYSDATE)-:1 and point_enabled=1\r\nAND point_auto_read_enabled=1 AND pl_enabled=1\r\nAND s.point_id IS null\r\nAND di_enabled=1 group by p.point_id having max(Nvl(s_any,0))=0 AND Max(t.point_id) IS NULL'),
	(294, 6064, 'AUD_DEFAULT_DEPTH'),
	(295, 453, 'Audito nuskaitymo gylis paromis pagal nutylėjimą'),
	(296, 1497, 'RQ_DEPTH'),
	(297, 5314, 'Importuoti aktai'),
	(298, 598, 'Automatiškai suformuojami išskaičiavimo aktai'),
	(299, 1380, 'Automatiniai maskuojantys duomenis aktai dėl statusų'),
	(300, 387, 'Automatiniai maskuojantys duomenis aktai dėl monitoringo'),
	(301, 6592, 'Vartotojo sprendimu atmetamų abejotinos kokybės duomenų aktai'),
	(302, 8707, 'Vartotojo sprendimu priimamų abejotinos kokybės duomenų aktai'),
	(303, 8513, 'Paskutinės vasaros laiko valandos aktai'),
	(304, 2665, 'DYNAMIC_GROUPS'),
	(305, 5915, 'ABGA'),
	(306, 9887, 'DATABASE_GENERATED_DATA'),
	(307, 8414, 'tstlbl'),
	(308, 9265, 'FROZEN_DATA'),
	(309, 9976, 'AUTO_DELETE_OLD_DATA'),
	(310, 1322, 'PARTITION_ADMINISTRATION'),
	(311, 7647, 'DATA_SOURCES_CONFIGURATION'),
	(312, 8061, 'MA_CONFIGURATION'),
	(313, 6295, 'IMPORT'),
	(314, 9593, 'PARALLEL_DAS'),
	(315, 8244, 'CLASSIFIERS_SYNCHRONIZATION'),
	(316, 5294, 'SBST_CONFIGURATION'),
	(317, 6103, 'SPECIFIC_LINK_TASKS'),
	(318, 4767, 'SPECIFIC_DATA_TASKS'),
	(319, 7901, 'Vidutinio dujų koreguoto tūrio debito per valandą rodmenų generavimas iš augančių reikšmių'),
	(320, 5518, 'Dujų koreguoto tūrio kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių'),
	(321, 2749, 'Dujų koreguoto tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių'),
	(322, 5173, 'Taškai, nepasiekiami per apskaitos taškų medį'),
	(323, 3083, 'Suminių rodmenų proporcingas generavimas iš gretimų reikšmių'),
	(324, 8309, 'Vidutinės P+ galios per valandą rodmenų generavimas iš esamų valandinių ir augančių pagal tarifus reikšmių'),
	(325, 6996, 'Elektros pilnosios galios S+ per valandą duomenų generavimas iš P+ ir Q+'),
	(326, 8523, 'Šilumnešio tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių'),
	(327, 2330, 'Šilumnešio šilumos kiekio per mėnesį rodmenų generavimas iš parų reikšmių'),
	(328, 9974, 'Vidutinio šilumnešio tūrio debito per val. rodmenų generavimas iš aug. reikšmių, užfiksuotų kas 15 minučių'),
	(329, 9480, 'Periodinis automatinis visų plep duomenų įrašų trynimas'),
	(330, 8603, 'Elektros pilnosios galios S+ per 30 minučių duomenų generavimas iš P+ ir Q+'),
	(331, 7266, 'Vidutinio karšto vandens tūrio debito per 15 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių'),
	(332, 3827, 'Vidutinio karšto vandens tūrio debito per valandą rodmenų generavimas iš vidutinio debito reikšmių per 15 minučių'),
	(333, 6301, 'A+ energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį '),
	(334, 1517, 'Vidutinės tiekiamo šilumnešio temperatūros per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių'),
	(335, 2670, 'Vidutinės grįžtamo šilumnešio temperatūros per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių'),
	(336, 7914, 'Vidutinės P+ galios per 15 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių'),
	(337, 5199, 'Vidutinės P+ galios per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių'),
	(338, 6703, 'Vidutinio dujų koreguoto tūrio debito per valandą rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių'),
	(339, 4532, 'Vidutinės šilumnešio šilumos galios per val. rodmenų generavimas iš aug. reikšmių, užfiksuotų kas 15 minučių'),
	(340, 7768, 'Vidutinio šalto vandens tūrio debito per valandą rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių'),
	(341, 6711, 'Vidutinės P+ galios per valandą rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių'),
	(342, 5678, 'Vidutinio karšto vandens tūrio debito per valandą rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių'),
	(343, 5347, 'Pusvalandinės vidutinės P+ galios duomenų generavimas iš užfiksuotų kas 30 min. A+ suminių duomenų'),
	(344, 3351, 'R- energijos per parą rodmenų generavimas is valandinių reikšmių'),
	(345, 2922, 'R+ energijos per parą rodmenų generavimas is valandinių reikšmių'),
	(346, 3033, 'A- energijos per parą rodmenų generavimas is valandinių reikšmių'),
	(347, 9429, 'Periodinis automatinis visų DB aplikacijos foninių užduočių vykdymo užsakymų įrašų trynimas'),
	(348, 8339, 'Dujų koreguoto tūrio kiekio per parą rodmenų generavimas iš valandinių reikšmių'),
	(349, 8413, 'Vidutinės P+ galios per valandą rodmenų generavimas iš augančių reikšmių, užfiksuotų kas valandą'),
	(350, 6748, 'Vidutinės P+ galios per 30 min. rodmenų generavimas iš augančių reikšmių'),
	(351, 4011, 'A+ energijos per parą rodmenų generavimas iš vidutinių reikšmių per 30 min.'),
	(352, 5435, 'A- energijos per parą rodmenų generavimas iš vidutinių reikšmių per 30 min.'),
	(353, 4319, 'R+ energijos per parą rodmenų generavimas iš vidutinių reikšmių per 30 min.'),
	(354, 1613, 'R- energijos per parą rodmenų generavimas iš vidutinių reikšmių per 30 min.'),
	(355, 9007, 'A+ energijos per parą rodmenų generavimas iš augančių reikšmių'),
	(356, 9819, 'Vidutinės P+ galios per valandą rodmenų generavimas iš vidutinės galios per 5 minutes'),
	(357, 7074, 'Vidutinės Q+ galios per valandą rodmenų generavimas iš vidutinės galios per 5 minutes'),
	(358, 7940, 'Vidutinės P+ galios per valandą rodmenų generavimas iš augančių reikšmių'),
	(359, 6863, 'A+ energijos per mėnesį rodmenų generavimas iš parų reikšmių'),
	(360, 7542, 'A+ energijos per parą rodmenų generavimas iš valandinių reikšmių'),
	(361, 4254, 'A+ energijos per parą rodmenų generavimas iš visų tarifų energijų sumos'),
	(362, 5420, 'Karšto vandens tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių'),
	(363, 976, 'Karšto vandens tūrio kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių'),
	(364, 1560, 'Naujų generuojamų matavimų linijų įtraukimas naujiems taškams'),
	(365, 1836, 'Šalto vandens tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių'),
	(366, 2583, 'Šalto vandens tūrio kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių'),
	(367, 7593, 'Šilumnešio temp.grafiko Ukmergės Katilinės Nr.1 šilumos vartotojams duomenų generavimas pagal lauko temperatūrą'),
	(368, 3199, 'Šilumnešio temp.grafiko Ukmergės Katilinės Nr.3 šilumos vartotojams duomenų generavimas pagal lauko temperatūrą'),
	(369, 5264, 'Šilumnešio šilumos kiekio per parą rodmenų generavimas iš vidutinės šilumos galios per valandą'),
	(370, 7759, 'Šilumnešio tūrio kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių'),
	(371, 5046, 'Vidutinės grįžtamo šilumnešio temperatūros per parą rodmenų generavimas iš valandinių reikšmių'),
	(372, 807, 'Vidutinės grįžtamo šilumnešio temperatūros per valandą rodmenų generavimas iš momentinių reikšmių'),
	(373, 2454, 'Vidutinės oro temperatūros per parą rodmenų generavimas iš vidutinės oro temperatūros per valandą'),
	(374, 1074, 'Vidutinės oro temperatūros per valandą rodmenų generavimas iš vidutinės oro temperatūros per 15 minučių'),
	(375, 1486, 'Vidutinės P+ galios per valandą rodmenų generavimas iš vidutinės galios per 30 minučių'),
	(376, 8445, 'Vidutinės šilumnešio šilumos galios per valandą rodmenų generavimas iš augančių reikšmių'),
	(377, 599, 'Vidutinės tiekiamo šilumnešio temperatūros per parą rodmenų generavimas iš valandinių reikšmių'),
	(378, 7453, 'Vidutinės tiekiamo šilumnešio temperatūros per valandą rodmenų generavimas iš momentinių reikšmių'),
	(379, 1165, 'Vidutinio karšto vandens tūrio debito per valandą rodmenų generavimas iš augančių reikšmių'),
	(380, 6010, 'Vidutinio šalto vandens tūrio debito per valandą rodmenų generavimas iš augančių reikšmių'),
	(381, 9157, 'Vidutinio šalto vandens tūrio debito per valandą rodmenų generavimas iš vidutinio debito reikšmių per 15 minučių'),
	(382, 7028, 'Vidutinio šalto vandens tūrio debito per 15 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių'),
	(383, 2114, 'Vidutinio šilumnešio tūrio debito per valandą rodmenų generavimas iš augančių reikšmių'),
	(384, 7644, 'Vidutinio tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumo per parą rodmenų generavimas iš valandinių reikšmių'),
	(385, 4400, 'Vidutinio tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumo per valandą rodmenų generavimas iš momentinių reikšmių'),
	(386, 607, 'Vidutinės Q- galios per valandą rodmenų generavimas iš vidutinės galios per 5 minutes'),
	(387, 1502, 'Vidutinės P- galios per valandą rodmenų generavimas tiekimo taškams įskaitant linijos nuostolius'),
	(388, 6942, 'Vidutinio dujų tūrio debito per valandą rodmenų generavimas iš augančių reikšmių'),
	(389, 7792, 'Dujų tūrio kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių'),
	(390, 3443, 'Dujų tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių'),
	(391, 5321, 'Periodinis automatinis visų matavimo taškų matavimo linijų momentinių duomenų įrašų trynimas'),
	(392, 4488, 'Periodinis automatinis visų matavimo taškų matavimo linijų minutinių duomenų įrašų trynimas'),
	(393, 5940, 'Vidutinės P+ galios per 30 minučių rodmenų generavimas iš vidutinės galios per 3 minutes'),
	(394, 8681, 'Vidutinės P- galios per 30 minučių rodmenų generavimas iš vidutinės galios per 3 minutes'),
	(395, 1902, 'Naujų generuojamų suminių matavimų elementų įtraukimas naujiems taškams'),
	(396, 7586, 'Vidutinės P- galios per valandą rodmenų generavimas tiekimo taškams įskaitant transformatoriaus nuostolius'),
	(397, 9682, 'Vidutinės šilumnešio šilumos galios per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių'),
	(398, 888, 'Vidutinio dujų koreguoto tūrio debito per 15 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių'),
	(399, 9758, 'Vidutinės šilumnešio šilumos galios per 15 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių'),
	(400, 5968, 'Vidutinio dujų koreguoto tūrio debito per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių'),
	(401, 5721, 'Vidutinės Q+ galios per 30 minučių rodmenų generavimas iš reikšmių pagal kvadrantus Q1 ir Q2'),
	(402, 4060, 'Vidutinės Q- galios per 30 minučių rodmenų generavimas iš reikšmių pagal kvadrantus Q3 ir Q4'),
	(403, 3479, 'Vidutinio tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumo per valandą generavimas iš vidutinių 15 min. reikšmių'),
	(404, 8098, 'Periodinis automatinis visų matavimo taškų matavimo linijų duomenų įrašų trynimas'),
	(405, 4316, 'Periodinis automatinis visų audito įrašų apie duomenų keitimo operacijas, atliktų sistemos vartotojų, trynimas'),
	(406, 6381, 'Periodinis automatinis visų monitoringo priskyrimų automatinio tikrinimo rezultatų įrašų trynimas'),
	(407, 2948, 'Periodinis automatinis visų sistemos įvykių įrašų trynimas'),
	(408, 12, 'Periodinis automatinis visų ataskaitų formavimo ir siuntimo žurnalo įrašų trynimas'),
	(409, 8466, 'Periodinis automatinis visų nuskaitymų pagal pareikalavimą užsakymų įrašų trynimas'),
	(410, 3251, 'Periodinis automatinis negaliojančių matavimo taškų matavimo linijų duomenų įrašų trynimas'),
	(411, 783, 'Periodinis automatinis visų uždaromų periodų įrašų trynimas'),
	(412, 8598, 'Periodinis automatinis negaliojančių apskaitos būsenų duomenų įrašų trynimas'),
	(413, 6353, 'Periodinis automatinis visų apskaitos būsenų duomenų įrašų trynimas'),
	(414, 5133, 'Periodinis automatinis visų užfiksuotų įvykių atvejų istorijos įrašų trynimas'),
	(415, 1422, 'A- energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą'),
	(416, 7163, 'R+ energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą'),
	(417, 8087, 'R- energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą'),
	(418, 2554, 'R1 energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą'),
	(419, 4338, 'R2 energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą'),
	(420, 8147, 'R3 energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą'),
	(421, 6316, 'R4 energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą'),
	(422, 8747, 'A- energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį'),
	(423, 7640, 'R+ energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį'),
	(424, 6355, 'R- energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį'),
	(425, 1064, 'R1 energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį'),
	(426, 2642, 'R2 energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį'),
	(427, 9100, 'R3 energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį'),
	(428, 1464, 'R4 energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį'),
	(429, 4763, 'Vidutinės P- galios per 30 min. rodmenų generavimas tiekimo taškams įskaitant transformatoriaus nuostolius'),
	(430, 6724, 'R- energijos per mėnesį rodmenų generavimas iš parų reikšmių'),
	(431, 4329, 'R+ energijos per mėnesį rodmenų generavimas iš parų reikšmių'),
	(432, 1534, 'A- energijos per mėnesį rodmenų generavimas iš parų reikšmių'),
	(433, 6881, 'Vidutinės P- galios per valandą rodmenų generavimas iš vidutinės galios per 30 minučių'),
	(434, 3742, 'Vidutinės Q+ galios per valandą rodmenų generavimas iš vidutinės galios per 30 minučių'),
	(435, 9249, 'Vidutinės Q- galios per valandą rodmenų generavimas iš vidutinės galios per 30 minučių'),
	(436, 4688, 'Vidutinės P- galios per valandą rodmenų generavimas tiekimo taškams už 2 įvadų su transformatoriais'),
	(437, 1601, 'Vidutinės P- galios per val. rodmenų generavimas tiekimo taškams už 2 įvadų su transformatoriais, 2 įvadas nutolęs'),
	(438, 8813, 'Vidutinės P- galios per 30 min. rodmenų generavimas tiekimo taškams įskaitant transformatoriaus ir linijos nuostolius'),
	(439, 9451, 'Vidutinės P+ galios per 30min. generavimas tiekimo taškams už 2 įvadų su transformatoriais, įskaitant linijos nuostolius'),
	(440, 7290, 'Vidutinės P+ galios per 30min. generavimas tiekimo taškams įskaitant linijos nuostolius bei P ir Q kvadratų sumą'),
	(441, 7542, 'Vidutinės P+ galios per 30 min. rodmenų generavimas tiekimo taškams įskaitant transformatoriaus nuostolius'),
	(442, 1260, 'Vidutinės P+ galios per 30min. generavimas tiekimo taškams už 2 įvadų ir transformatoriaus'),
	(443, 5143, 'Periodinis automatinis visų apsikeitimo duomenimis operacijų įrašų trynimas'),
	(444, 97, 'Suminės R1 energijos rodmenų generavimas iš visų tarifų sumų'),
	(445, 3199, 'Suminės R2 energijos rodmenų generavimas iš visų tarifų sumų'),
	(446, 7647, 'Suminės R3 energijos rodmenų generavimas iš visų tarifų sumų'),
	(447, 9886, 'Suminės R4  energijos rodmenų generavimas iš visų tarifų sumų'),
	(448, 634, 'Vidutinio šalto vandens tūrio debito per val. rodmenų generavimas iš tūrio kiekio, fiksuojamo kas valandą'),
	(449, 1766, 'Vidutinio karšto vandens tūrio debito per val. rodmenų generavimas iš tūrio kiekio, fiksuojamo kas valandą'),
	(450, 2785, 'Suminės A+ energijos rodmenų generavimas iš visų tarifų sumų, fiksuotų kas val.'),
	(451, 6729, 'A+ energijos pagal 1 tarifą per mėnesį rodmenų generavimas iš parų reikšmių'),
	(452, 3626, 'A+ energijos pagal 2 tarifą per mėnesį rodmenų generavimas iš parų reikšmių'),
	(453, 8148, 'A+ energijos pagal 3 tarifą per mėnesį rodmenų generavimas iš parų reikšmių'),
	(454, 2233, 'A+ energijos pagal 4 tarifą per mėnesį rodmenų generavimas iš parų reikšmių'),
	(455, 4186, 'A+ energijos pagal 1 tarifą per parą rodmenų generavimas iš fiksuotų kas valandą suminių reikšmių'),
	(456, 8657, 'A+ energijos pagal 2 tarifą per parą rodmenų generavimas iš fiksuotų kas valandą suminių reikšmių'),
	(457, 7129, 'A+ energijos pagal 3 tarifą per parą rodmenų generavimas iš fiksuotų kas valandą suminių reikšmių'),
	(458, 9799, 'A+ energijos pagal 4 tarifą per parą rodmenų generavimas iš fiksuotų kas valandą suminių reikšmių'),
	(459, 3137, 'Suminės A+ energijos rodmenų generavimas iš visų tarifų sumų'),
	(460, 9980, 'Suminės A- energijos rodmenų generavimas iš visų tarifų sumų'),
	(461, 6680, 'Suminės R+ energijos rodmenų generavimas iš visų tarifų sumų'),
	(462, 4821, 'Suminės R- energijos rodmenų generavimas iš visų tarifų sumų'),
	(463, 2572, 'A- energijos per parą rodmenų generavimas iš augančių reikšmių'),
	(464, 9594, 'R+ energijos per parą rodmenų generavimas iš augančių reikšmių'),
	(465, 1139, 'R- energijos per parą rodmenų generavimas iš augančių reikšmių'),
	(466, 5182, 'Šilumnešio masės kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių'),
	(467, 4702, 'Vidutinio šilumnešio masės debito per val. rodmenų generavimas iš aug. reikšmių, užfiksuotų kas 15 minučių'),
	(468, 8257, 'Šilumnešio masės kiekio per mėnesį rodmenų generavimas iš parų reikšmių'),
	(469, 6811, 'Periodinis automatinis visų matavimo taškų matavimo linijų sekundinių duomenų įrašų trynimas'),
	(470, 2189, 'Periodinis automatinis visų matavimo taškų vytelių duomenų įrašų trynimas'),
	(471, 9120, 'Periodinis automatinis visų nuskaitymo taškų vytelių duomenų įrašų trynimas'),
	(472, 1230, 'Periodinis automatinis negaliojančių matavimo taškų vytelių duomenų įrašų trynimas'),
	(473, 7856, 'Periodinis automatinis negaliojančių nuskaitymo taškų vytelių duomenų įrašų trynimas'),
	(474, 5470, 'Periodinis automatinis senų nevykdytų ryšio užduočių trynimas'),
	(475, 8167, 'Pirminių suminių A+ energijos rodmenų generavimas iš pusvalandinių ir augančių rodmenų sumos, fiksuotų kas parą'),
	(476, 4228, 'Pirminių suminių A- energijos rodmenų generavimas iš pusvalandinių ir augančių rodmenų sumos, fiksuotų kas parą'),
	(477, 6167, 'Pirminių suminių R+ energijos rodmenų generavimas iš pusvalandinių ir augančių rodmenų sumos, fiksuotų kas parą'),
	(478, 1855, 'Pirminių suminių R- energijos rodmenų generavimas iš pusvalandinių ir augančių rodmenų sumos, fiksuotų kas parą'),
	(479, 7604, 'Parų rodmenų generavimas iš ankstesnių reikšmių'),
	(480, 6860, 'Valandinių P+ duomenų generavimas išdalinant paros sumą pagal šabloną'),
	(481, 2935, 'Valandinių P- duomenų generavimas išdalinant paros sumą pagal šabloną'),
	(482, 939, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų'),
	(483, 3039, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų'),
	(484, 6886, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų'),
	(485, 4902, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų'),
	(486, 7721, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 4 tarifą'),
	(487, 3030, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 4 tarifą'),
	(488, 5127, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 4 tarifą'),
	(489, 7291, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 4 tarifą'),
	(490, 1697, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 3 tarifą'),
	(491, 3025, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 3 tarifą'),
	(492, 1846, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 3 tarifą'),
	(493, 271, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 3 tarifą'),
	(494, 475, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 1 tarifą'),
	(495, 2886, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 1 tarifą'),
	(496, 3961, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 1 tarifą'),
	(497, 1554, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 1 tarifą'),
	(498, 4442, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 2 tarifą'),
	(499, 6011, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 2 tarifą'),
	(500, 9685, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 2 tarifą'),
	(501, 8076, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 2 tarifą'),
	(502, 6373, 'A+ energijos rodmenų per mėnesį pagal 1 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(503, 8580, 'A- energijos rodmenų per mėnesį pagal 1 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(504, 1366, 'R+ energijos rodmenų per mėnesį pagal 1 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(505, 7058, 'R- energijos rodmenų per mėnesį pagal 1 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(506, 8593, 'A+ energijos rodmenų per mėnesį pagal 2 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(507, 9467, 'A- energijos rodmenų per mėnesį pagal 2 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(508, 5269, 'R+ energijos rodmenų per mėnesį pagal 2 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(509, 7481, 'R- energijos rodmenų per mėnesį pagal 2 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(510, 7151, 'A+ energijos rodmenų per mėnesį pagal 3 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(511, 2295, 'A- energijos rodmenų per mėnesį pagal 3 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(512, 7978, 'R+ energijos rodmenų per mėnesį pagal 3 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(513, 8425, 'R- energijos rodmenų per mėnesį pagal 3 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(514, 3994, 'A+ energijos rodmenų per mėnesį pagal 4 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(515, 6002, 'A- energijos rodmenų per mėnesį pagal 4 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(516, 8257, 'R+ energijos rodmenų per mėnesį pagal 4 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(517, 8882, 'R- energijos rodmenų per mėnesį pagal 4 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(518, 2495, 'Vidutinės įtampos per 30 minučių rodmenų generavimas iš momentinės įtampos'),
	(519, 7115, 'Vidutinės įtampos 1 fazėje per 30 minučių rodmenų generavimas iš momentinės įtampos 1 fazėje'),
	(520, 5459, 'Vidutinės įtampos 2 fazėje per 30 minučių rodmenų generavimas iš momentinės įtampos 2 fazėje'),
	(521, 1283, 'Vidutinės įtampos 3 fazėje per 30 minučių rodmenų generavimas iš momentinės įtampos 3 fazėje'),
	(522, 9102, 'Vidutinės S+ galios per 5 min. rodmenų generavimas iš suminės W+ energijos, fiksuojamos kas 5 min.'),
	(523, 7452, 'W+ energijos per 5 min. rodmenų generavimas iš suminės W+ energijos, fiksuojamos kas 5 min.'),
	(524, 9447, 'W+ energijos per val. rodmenų generavimas iš W+ energijos per 5 min.'),
	(525, 297, 'Vidutinės S- galios per val. rodmenų generavimas iš vidutinės S- galios per 5 min.'),
	(526, 2702, 'Vidutinės S- galios per 5 min. rodmenų generavimas iš suminės W- energijos, fiksuojamos kas 5 min.'),
	(527, 1555, 'W- energijos per 5 min. rodmenų generavimas iš suminės W- energijos, fiksuojamos kas 5 min.'),
	(528, 1974, 'W- energijos per val. rodmenų generavimas iš W- energijos per 5 min.'),
	(529, 8540, 'Vidutinės Q+ galios per valandą rodmenų generavimas iš reikšmių pagal kvadrantus Q1 ir Q2'),
	(530, 2901, 'Vidutinės Q- galios per valandą rodmenų generavimas iš reikšmių pagal kvadrantus Q3 ir Q4'),
	(531, 1982, 'Vidutinio tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumo per 15 min. generavimas iš vidutinių reikšmių'),
	(532, 1200, 'Vidutinio tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumo per valandą generavimas iš vidutinių reikšmių'),
	(533, 6123, 'Periodinis ryšio kanalų statistikos duomenų įrašų trynimas'),
	(534, 7359, 'Dujų koreguotos masės kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(535, 5480, 'Periodinis automatinis visų šaltinių statistikos įrašų trynimas iki nurodytos datos'),
	(536, 9022, 'Naujų grupių įtraukimas į grupę pagal šaltinių tipus (atsiradus naujiems šaltinio tipams)'),
	(537, 9383, 'Vidutinės P- galios per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių'),
	(538, 4822, 'Vidutinės Q+ galios per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių'),
	(539, 1499, 'Vidutinės Q- galios per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių'),
	(540, 4131, 'A+ energijos per parą rodmenų generavimas iš vidutinių reikšmių per 15 min.'),
	(541, 4038, 'A- energijos per parą rodmenų generavimas iš vidutinių reikšmių per 15 min.'),
	(542, 1781, 'R+ energijos per parą rodmenų generavimas iš vidutinių reikšmių per 15 min.'),
	(543, 1038, 'R- energijos per parą rodmenų generavimas iš vidutinių reikšmių per 15 min.'),
	(544, 2493, 'Šalčio energijos per mėnesį rodmenų generavimas iš parų reikšmių'),
	(545, 6240, 'Šalčio tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių'),
	(546, 2042, 'Šalčio energijos per parą rodmenų generavimas iš augančių reikšmių'),
	(547, 6165, 'Šalčio tūrio kiekio per parą rodmenų generavimas iš augančių reikšmių'),
	(548, 4721, 'Vidutinės šalčio galios per val. rodmenų generavimas iš augančių reikšmių'),
	(549, 7898, 'Vidutinio šalčio tūrio debito per val. rodmenų generavimas iš augančių reikšmių'),
	(550, 9253, 'Periodinis automatinis visų matavimo taškų matavimo linijų mėnesių duomenų įrašų trynimas'),
	(551, 8634, 'Periodinis automatinis visų matavimo taškų matavimo linijų paros duomenų įrašų trynimas'),
	(552, 2235, 'Periodinis automatinis visų matavimo taškų matavimo linijų paros profilio duomenų įrašų trynimas'),
	(553, 7053, 'Periodinis automatinis visų matavimo taškų matavimo linijų suminių nefiksuotų duomenų įrašų trynimas'),
	(554, 9937, 'Periodinis automatinis visų matavimo taškų matavimo linijų suminių fiksuotų iki mėn. duomenų įrašų trynimas'),
	(555, 8697, 'Periodinis automatinis visų matavimo taškų matavimo linijų suminių fiksuotų iki paros duomenų įrašų trynimas'),
	(556, 7707, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(557, 3860, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(558, 4498, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(559, 633, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų, fiksuotų kas mėnesį'),
	(560, 2941, 'Suminės betarifinės A+ energijos duomenų generavimas iš tarifinių suminių matavimų, fiksuojamų kas parą'),
	(561, 4633, 'Suminės betarifinės A- energijos duomenų generavimas iš tarifinių suminių matavimų, fiksuojamų kas parą'),
	(562, 9990, 'Suminės betarifinės R+ energijos duomenų generavimas iš tarifinių suminių matavimų, fiksuojamų kas parą'),
	(563, 3854, 'Suminės betarifinės R- energijos duomenų generavimas iš tarifinių suminių matavimų, fiksuojamų kas parą'),
	(564, 5989, 'Šilumnešio koreguoto šilumos kiekio per parą generavimas iš valandinių reikšmių'),
	(565, 8196, 'Šilumnešio koreguoto šilumos kiekio per mėnesį generavimas iš parų reikšmių'),
	(566, 9984, 'Paros klaidos kodo rodmenų generavimas iš valandinių rodmenų'),
	(567, 8284, 'Periodinis automatinis šaltinio šablono taikymas šaltiniams'),
	(568, 8716, 'A+ energijos per parą rodmenų generavimas iš suminės A+ energijos, fiksuojamos kas parą'),
	(569, 9256, 'A+ energijos pagal 1 tarifą per parą rodmenų generavimas iš suminės A+ energijos pagal 1 tarifą, fiksuojamos kas parą'),
	(570, 5882, 'A+ energijos pagal 2 tarifą per parą rodmenų generavimas iš suminės A+ energijos pagal 2 tarifą, fiksuojamos kas parą'),
	(571, 9793, 'A+ energijos pagal 3 tarifą per parą rodmenų generavimas iš suminės A+ energijos pagal 3 tarifą, fiksuojamos kas parą'),
	(572, 3402, 'A+ energijos pagal 4 tarifą per parą rodmenų generavimas iš suminės A+ energijos pagal 4 tarifą, fiksuojamos kas parą'),
	(573, 3977, 'A- energijos per parą rodmenų generavimas iš suminės A- energijos, fiksuojamos kas parą'),
	(574, 1064, 'A- energijos pagal 1 tarifą per parą rodmenų generavimas iš suminės A- energijos pagal 1 tarifą, fiksuojamos kas parą'),
	(575, 5966, 'A- energijos pagal 2 tarifą per parą rodmenų generavimas iš suminės A- energijos pagal 2 tarifą, fiksuojamos kas parą'),
	(576, 7445, 'A- energijos pagal 3 tarifą per parą rodmenų generavimas iš suminės A- energijos pagal 3 tarifą, fiksuojamos kas parą'),
	(577, 7984, 'A- energijos pagal 4 tarifą per parą rodmenų generavimas iš suminės A- energijos pagal 4 tarifą, fiksuojamos kas parą'),
	(578, 2567, 'R+ energijos per parą rodmenų generavimas iš suminės R+ energijos, fiksuojamos kas parą'),
	(579, 2938, 'R+ energijos pagal 1 tarifą per parą rodmenų generavimas iš suminės R+ energijos pagal 1 tarifą, fiksuojamos kas parą'),
	(580, 7909, 'R+ energijos pagal 2 tarifą per parą rodmenų generavimas iš suminės R+ energijos pagal 2 tarifą, fiksuojamos kas parą'),
	(581, 8440, 'R+ energijos pagal 3 tarifą per parą rodmenų generavimas iš suminės R+ energijos pagal 3 tarifą, fiksuojamos kas parą'),
	(582, 8431, 'R+ energijos pagal 4 tarifą per parą rodmenų generavimas iš suminės R+ energijos pagal 4 tarifą, fiksuojamos kas parą'),
	(583, 5677, 'R- energijos per parą rodmenų generavimas iš suminės R- energijos, fiksuojamos kas parą'),
	(584, 8153, 'R- energijos pagal 1 tarifą per parą rodmenų generavimas iš suminės R- energijos pagal 1 tarifą, fiksuojamos kas parą'),
	(585, 9784, 'R- energijos pagal 2 tarifą per parą rodmenų generavimas iš suminės R- energijos pagal 2 tarifą, fiksuojamos kas parą'),
	(586, 6489, 'R- energijos pagal 3 tarifą per parą rodmenų generavimas iš suminės R- energijos pagal 3 tarifą, fiksuojamos kas parą'),
	(587, 5206, 'R- energijos pagal 4 tarifą per parą rodmenų generavimas iš suminės R- energijos pagal 4 tarifą, fiksuojamos kas parą'),
	(588, 5193, 'Vidutinio dujų koreguotos masės debito per val. rodmenų generavimas iš vidutinio dujų koreguotos masės debito per 5 min.'),
	(589, 7747, 'Vidutinio dujų koreguotos masės debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(590, 5139, 'Dujų koreguotos masės kiekio per val. rodmenų generavimas iš dujų koreguotos masės kiekio per 5 min.'),
	(591, 4922, 'Vidutinio dujų koreguoto tūrio debito per val. rodmenų generavimas iš vidutinio dujų koreguoto tūrio debito per 5 min.'),
	(592, 1922, 'Dujų koreguoto tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(593, 1525, 'Periodinis automatinis pasikartojančių apskaitos busenų duomenų įrašų trynimas'),
	(594, 5081, 'Maksimalių momentinių srovės stiprumo rodmenų per valandą generavimas iš momentinių'),
	(595, 418, 'Minimalių momentinių srovės stiprumo rodmenų per valandą  generavimas iš momentinių'),
	(596, 6782, 'Maksimalių momentinių srovės stiprumo rodmenų per parą generavimas iš maksimalių rodmenų per valandą'),
	(597, 5646, 'Minimalių momentinių srovės stiprumo rodmenų per parą generavimas iš minimalių rodmenų per valandą'),
	(598, 7711, 'Maksimalių momentinių įtampos rodmenų per valandą generavimas iš momentinių'),
	(599, 5978, 'Minimalių momentinių įtampos rodmenų per valandą generavimas iš momentinių'),
	(600, 3900, 'Maksimalių momentinių įtampos rodmenų per parą generavimas iš maksimalių rodmenų per valandą'),
	(601, 989, 'Minimalių momentinių įtampos rodmenų per parą rodmenų generavimas iš minimalių rodmenų per valandą'),
	(602, 5824, 'Maksimalių momentinių aktyvinė galia per valandą generavimas iš momentinių'),
	(603, 2690, 'Minimalių momentinių aktyvinė galia per valandą generavimas iš momentinių'),
	(604, 1044, 'Maksimalių momentinių aktyvinės galios rodmenų per parą generavimas iš maksimalių rodmenų per valandą'),
	(605, 3083, 'Minimalių momentinių aktyvinė galios rodmenų per parą generavimas iš minimalių rodmenų per valandą'),
	(606, 7184, 'Maksimalių momentinių reaktyvinės galios per valandą rodmenų generavimas iš momentinių'),
	(607, 7131, 'Minimalių momentinių reaktyvinės galios per valandą rodmenų generavimas iš momentinių'),
	(608, 9856, 'Maksimalių momentinių reaktyvinės galios rodmenų per parą generavimas iš maksimalių rodmenų per valandą'),
	(609, 6084, 'Minimalių momentinių reaktyvinės galios rodmenų per parą generavimas iš minimalių rodmenų per valandą'),
	(610, 6503, 'Maksimalių momentinių cos(fi) reikšmių per valandą rodmenų generavimas iš momentinių'),
	(611, 5318, 'Minimalių momentinių cos(fi) reikšmių per valandą rodmenų generavimas iš momentinių'),
	(612, 750, 'Maksimalių momentinių cos(fi) reikšmių per parą generavimas iš maksimalių reikšmių per valandą'),
	(613, 7868, 'Minimalių momentinių cos(fi) reikšmių per parą generavimas iš minimalių reikšmių per valandą'),
	(614, 6849, 'Maksimalių momentinių dažnis rodmenų per valandą generavimas iš momentinių'),
	(615, 8555, 'Minimalių momentinių dažnis rodmenų per valandą generavimas iš momentinių'),
	(616, 7970, 'Maksimalių momentinių dažnio rodmenų per parą generavimas iš maksimalių rodmenų per valandą'),
	(617, 8172, 'Minimalių momentinių dažnio rodmenų per parą generavimas iš minimalių rodmenų per valandą'),
	(618, 5069, 'Beviltiškos skylės'),
	(619, 8619, 'Vidutinės P galios per val. rodmenų generavimas iš vidutinės P galios per 5 min.'),
	(620, 7959, 'A energijos per 5 min. rodmenų generavimas iš suminės A energijos, fiksuojamos kas 5 min.'),
	(621, 5035, 'Vidutinės P galios per 5 min. rodmenų generavimas iš suminės A energijos, fiksuojamos kas 5 min.'),
	(622, 125, 'A energijos per val. rodmenų generavimas iš A energijos per 5 min.'),
	(623, 5950, 'Vidutinės P+ galios per val. rodmenų generavimas iš vidutinės P+ galios per 5 min.'),
	(624, 9696, 'A+ energijos per 5 min. rodmenų generavimas iš suminės A+ energijos, fiksuojamos kas 5 min.'),
	(625, 6558, 'Vidutinės P+ galios per 5 min. rodmenų generavimas iš suminės A+ energijos, fiksuojamos kas 5 min.'),
	(626, 9161, 'A+ energijos per val. rodmenų generavimas iš A+ energijos per 5 min.'),
	(627, 8875, 'Vidutinės P- galios per val. rodmenų generavimas iš vidutinės P- galios per 5 min.'),
	(628, 8701, 'A- energijos per 5 min. rodmenų generavimas iš suminės A- energijos, fiksuojamos kas 5 min.'),
	(629, 1502, 'Vidutinės P- galios per 5 min. rodmenų generavimas iš suminės A- energijos, fiksuojamos kas 5 min.'),
	(630, 2183, 'A- energijos per val. rodmenų generavimas iš A- energijos per 5 min.'),
	(631, 5449, 'Vidutinės talpuminės galios per val. rodmenų generavimas iš vidutinės talpuminės galios per 5 min.'),
	(632, 2722, 'Vidutinės talpuminės galios per 5 min. rodmenų generavimas iš suminės talpuminės R energijos, fiksuojamos kas 5 min.'),
	(633, 8809, 'Talpuminės energijos per 5 min. rodmenų generavimas iš suminės talpuminės R energijos, fiksuojamos kas 5 min.'),
	(634, 7008, 'Talpuminės energijos per val. rodmenų generavimas iš talpuminės energijos per 5 min.'),
	(635, 1105, 'Vidutinės Q+ galios per val. rodmenų generavimas iš vidutinės Q+ galios per 5 min.'),
	(636, 7229, 'Vidutinės Q+ galios per 5 min. rodmenų generavimas iš suminės R+ energijos, fiksuojamos kas 5 min.'),
	(637, 9325, 'R+ energijos per 5 min. rodmenų generavimas iš suminės R+ energijos, fiksuojamos kas 5 min.'),
	(638, 8737, 'R+ energijos per val. rodmenų generavimas iš R+ energijos per 5 min.'),
	(639, 3983, 'Vidutinės Q- galios per val. rodmenų generavimas iš vidutinės Q- galios per 5 min.'),
	(640, 7719, 'R- energijos per 5 min. rodmenų generavimas iš suminės R- energijos, fiksuojamos kas 5 min.'),
	(641, 9063, 'Vidutinės Q- galios per 5 min. rodmenų generavimas iš suminės R- energijos, fiksuojamos kas 5 min.'),
	(642, 396, 'R- energijos per val. rodmenų generavimas iš R- energijos per 5 min.'),
	(643, 2502, 'Vidutinės Q1 galios per val. rodmenų generavimas iš vidutinės Q1 galios per 5 min.'),
	(644, 9189, 'R1 energijos per 5 min. rodmenų generavimas iš suminės R1 energijos, fiksuojamos kas 5 min.'),
	(645, 787, 'Vidutinės Q1 galios per 5 min. rodmenų generavimas iš suminės R1 energijos, fiksuojamos kas 5 min.'),
	(646, 3083, 'R1 energijos per val. rodmenų generavimas iš R1 energijos per 5 min.'),
	(647, 2524, 'Vidutinės Q2 galios per val. rodmenų generavimas iš vidutinės Q2 galios per 5 min.'),
	(648, 5977, 'R2 energijos per 5 min. rodmenų generavimas iš suminės R2 energijos, fiksuojamos kas 5 min.'),
	(649, 9570, 'Vidutinės Q2 galios per 5 min. rodmenų generavimas iš suminės R2 energijos, fiksuojamos kas 5 min.'),
	(650, 70, 'R2 energijos per val. rodmenų generavimas iš R2 energijos per 5 min.'),
	(651, 6856, 'Vidutinės Q3 galios per val. rodmenų generavimas iš vidutinės Q3 galios per 5 min.'),
	(652, 319, 'R3 energijos per 5 min. rodmenų generavimas iš suminės R3 energijos, fiksuojamos kas 5 min.'),
	(653, 8093, 'Vidutinės Q3 galios per 5 min. rodmenų generavimas iš suminės R3 energijos, fiksuojamos kas 5 min.'),
	(654, 79, 'R3 energijos per val. rodmenų generavimas iš R3 energijos per 5 min.'),
	(655, 1298, 'Vidutinės Q4 galios per val. rodmenų generavimas iš vidutinės Q4 galios per 5 min.'),
	(656, 8006, 'Vidutinės Q4 galios per 5 min. rodmenų generavimas iš suminės R4 energijos, fiksuojamos kas 5 min.'),
	(657, 870, 'R4 energijos per 5 min. rodmenų generavimas iš suminės R4 energijos, fiksuojamos kas 5 min.'),
	(658, 2703, 'R4 energijos per val. rodmenų generavimas iš R4 energijos per 5 min.'),
	(659, 729, 'Vidutinės indukcinė galios per val. rodmenų generavimas iš vidutinės indukcinė galios per 5 min.'),
	(660, 8790, 'Indukcinė energijos per 5 min. rodmenų generavimas iš suminės indukcinė R energijos, fiksuojamos kas 5 min.'),
	(661, 6172, 'Vidutinės indukcinė galios per 5 min. rodmenų generavimas iš suminės indukcinė R energijos, fiksuojamos kas 5 min.'),
	(662, 1968, 'Indukcinė energijos per val. rodmenų generavimas iš Indukcinė energijos per 5 min.'),
	(663, 5375, 'Vidutinės S+ galios per val. rodmenų generavimas iš vidutinės S+ galios per 5 min.'),
	(664, 4749, 'Vidutinės grįžtamo šilumnešio šil. galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(665, 7932, 'Grįžtamo šilumnešio šilumos kiekio per val. rodmenų generavimas iš grįžtamo šilumnešio šil. kiekio per 5 min.'),
	(666, 7292, 'Vidutinio šilumnešio tūrio debito per val. rodmenų generavimas iš vidutinio šilumnešio tūrio debito per 5 min.'),
	(667, 6271, 'Šilumnešio tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(668, 1829, 'Vidutinio šilumnešio tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(669, 1453, 'Šilumnešio tūrio kiekio per val. rodmenų generavimas iš šilumnešio tūrio kiekio per 5 min.'),
	(670, 8933, 'Vidutinio tiekiamo šilumnešio tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.'),
	(671, 1343, 'Vidutinio tiekiamo šilumnešio tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(672, 19, 'Tiekiamo šilumnešio tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(673, 2841, 'Tiekiamo šilumnešio tūrio kiekio per val. rodmenų generavimas iš tiekiamo šilumnešio tūrio kiekio per 5 min.'),
	(674, 6148, 'Vidutinio grįžtamo šilumnešio tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.'),
	(675, 1873, 'Grįžtamo šilumnešio tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(676, 249, 'Vidutinio grįžtamo šilumnešio tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(677, 7644, 'Grįžtamo šilumnešio tūrio kiekio per val. rodmenų generavimas iš grįžtamo šilumnešio tūrio kiekio per 5 min.'),
	(678, 4512, 'Vidutinės šalto vandens šilumos galios per val. rodmenų generavimas iš vidutinės šalto vandens šilumos galios per 5 min.'),
	(679, 1198, 'Vidutinės šalto vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(680, 3881, 'Šalto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(681, 8988, 'Šalto vandens šilumos kiekio per val. rodmenų generavimas iš šalto vandens šilumos kiekio per 5 min.'),
	(682, 1315, 'Vidutinės tiekiamo šalto vandens šil. galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.'),
	(683, 6962, 'Tiekiamo šalto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(684, 9463, 'Vidutinės tiekiamo šalto vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(685, 8884, 'Tiekiamo šalto vandens šilumos kiekio per val. rodmenų generavimas iš tiekiamo šalto vandens šilumos kiekio per 5 min.'),
	(686, 6715, 'Vidutinės grįžtamo šalto vandens šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.'),
	(687, 9549, 'Grįžtamo šalto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(688, 3758, 'Vidutinės grįžtamo šalto vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(689, 3228, 'Grįžtamo šalto vandens šilumos kiekio per val. rodmenų generavimas iš grįžtamo šalto vandens šilumos kiekio per 5 min.'),
	(690, 3322, 'Vidutinio šalto vandens tūrio debito per val. rodmenų generavimas iš vidutinio šalto vandens tūrio debito per 5 min.'),
	(691, 9143, 'Vidutinio šalto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamųkas 5 min.'),
	(692, 2539, 'Šalto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(693, 4129, 'Šalto vandens tūrio kiekio per val. rodmenų generavimas iš Šalto vandens tūrio kiekio per 5 min.'),
	(694, 6296, 'Vidutinio tiekiamo šalto vandens tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.'),
	(695, 4926, 'Tiekiamo šalto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamųkas 5 min.'),
	(696, 2631, 'Vidutinio tiekiamo šalto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(697, 7499, 'Tiekiamo šalto vandens tūrio kiekio per val. rodmenų generavimas iš tiekiamo šalto vandens tūrio kiekio per 5 min.'),
	(698, 3563, 'Vidutinio grįžtamo šalto vandens tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.'),
	(699, 3961, 'Vidutinio grįžtamo šalto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(700, 4736, 'Grįžtamo šalto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(701, 616, 'Grįžtamo šalto vandens tūrio kiekio per val. rodmenų generavimas iš grįžtamo šalto vandens tūrio kiekio per 5 min.'),
	(702, 9324, 'Vidutinės karšto vandens šilumos galios per val. rodmenų generavimas iš vidutinės karšto vandens šil. galios per 5 min.'),
	(703, 4914, 'Karšto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(704, 680, 'Vidutinės karšto vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(705, 8267, 'Karšto vandens šilumos kiekio per val. rodmenų generavimas iš karšto vandens šilumos kiekio per 5 min.'),
	(706, 9087, 'Vidutinės tiekiamo karšto vandens šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.'),
	(707, 3799, 'Vidutinės tiekiamo karš. vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(708, 7686, 'Tiekiamo karšto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(709, 9447, 'Tiekiamo karšto vandens šilumos kiekio per val. rodmenų generavimas iš tiekiamo karšto vandens šilumos kiekio per 5 min.'),
	(710, 3421, 'Vidutinės grįžtamo karšto vandens šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.'),
	(711, 5944, 'Vidutinės grįžtamo karš. vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(712, 180, 'Grįžtamo karšto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(713, 2338, 'Grįžtamo karšto vandens šilumos kiekio per val. rodmenų generavimas iš grįžtamo karšto vandens šilumos kiekio per 5 min.'),
	(714, 6229, 'Vidutinio karšto vandens tūrio debito per val. rodmenų generavimas iš vidutinio karšto vandens tūrio debito per 5 min.'),
	(715, 2906, 'Karšto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminio karšto vandens tūrio kiekio, fiksuojamo kas 5 min.'),
	(716, 880, 'Vidutinio karšto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(717, 8769, 'Karšto vandens tūrio kiekio per val. rodmenų generavimas iš Karšto vandens tūrio kiekio per 5 min.'),
	(718, 9798, 'Vidutinio tiekiamo karšto vandens tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.'),
	(719, 7933, 'Vidutinio tiekiamo karšto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(720, 7402, 'Tiekiamo karšto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(721, 5712, 'Periodinis automatinis senų nevykdytų skubių ryšio užduočių trynimas'),
	(722, 6975, 'Sunaudotos šilumnešio šilumos kiekio per mėnesį generavimas iš parų reikšmių'),
	(723, 1230, 'Sunaudotos šilumnešio šilumos kiekio per parą generavimas iš valandinių reikšmių'),
	(724, 6825, 'Tiekiamo šilumnešio šilumos kiekio per mėnesį generavimas iš parų reikšmių'),
	(725, 1906, 'Tiekiamo šilumnešio šilumos kiekio per parą generavimas iš valandinių reikšmių'),
	(726, 4813, 'Šilumnešio šilumos kiekio per parą generavimas iš valandinių reikšmių'),
	(727, 8551, 'Karšto vandens šilumos kiekio per parą generavimas iš valandinių reikšmių'),
	(728, 4158, 'Karšto vandens šilumos kiekio per mėnesį generavimas iš parų reikšmių'),
	(729, 1671, 'Tiekiamo karšto vandens šilumos kiekio per mėnesį generavimas iš parų reikšmių'),
	(730, 338, 'Tiekiamo karšto vandens šilumos kiekio per parą generavimas iš valandinių reikšmių'),
	(731, 9739, 'Sunaudotos karšto vandens šilumos kiekio per mėnesį generavimas iš parų reikšmių'),
	(732, 1453, 'Sunaudotos karšto vandens šilumos kiekio per parą generavimas iš valandinių reikšmių'),
	(733, 6996, 'Periodinis automatinis visų tarpinių eksporto formų duomenų įrašų trynimas'),
	(734, 8036, 'Neatsakantys nuskaitymo taškai'),
	(735, 1045, 'Atsakantys nuskaitymo taškai, kuriems buvo ryšio būklės pasikeitimų'),
	(736, 9885, 'Atsakantys nuskaitymo taškai, kuriems buvo ryšio klaidų'),
	(737, 9030, 'Taškai, kurių archyvą turintiems skaitiklių šaltiniams nenustatytas atstatymo gylis'),
	(738, 8513, 'Nuskaitymo taškai, kuriems nėra duomenų už paskutines paras'),
	(739, 6336, 'Taškai, kuriems nėra duomenų už paskutines paras, nors nuskaitymo taškams yra'),
	(740, 6022, 'Neužpildytos būtinos ryšio savybės'),
	(741, 4826, 'Neužpildytos rekomenduojamos ryšio savybės'),
	(742, 1112, 'Sumontuoto taške skaitiklio numerio įrašymas į Saiman-1000 tipo šaltinių elementų savybę'),
	(743, 3284, 'Skylės už senus periodus'),
	(744, 9958, 'Neuždaryti'),
	(745, 1017, 'Taškų sisteminės savybės "Esminė problema" pildymas'),
	(746, 6352, 'Seno registravimo duomenų bazėje laiko informacijos išvalymas rodmenų lentelėje'),
	(747, 8539, 'Daug įvykių'),
	(748, 7390, 'Elektros apskaita'),
	(749, 3361, 'Momentinio rodiklio generavimas iš suminio dujų koreguoto tūrio kiekio, fiksuojamo kas minutę'),
	(750, 150, 'Periodinis automatinis taškų monitoringo šablonų taikymas'),
	(751, 2460, 'Periodinis automatinis grupių monitoringo šablonų taikymas'),
	(752, 5092, 'Sistemos monitoringo duomenų, fiksuojamų kas parą generavimas'),
	(753, 8761, 'Sistemos monitoringo duomenų, fiksuojamų kas valandą generavimas'),
	(754, 3035, 'Generated_by_SQL_Server'),
	(755, 1317, 'Atlikti ankščiau paruoštas eilės užduotis'),
	(756, 9691, 'Taško matavimo linijų pildymas pagal skaitiklio parametrus'),
	(757, 9687, 'Nuskaitymo konfigūracijos sukūrimas neužregistruotiems skaitikliams'),
	(758, 7551, 'Nėra jokių nesenų nuskaitymo duomenų'),
	(759, 8526, 'Vienalaikis einamosios mėnesių energijos ir suminių rodmenų nuskaitymas (taškui)'),
	(760, 9338, 'Vienalaikis einamosios mėnesių energijos ir suminių rodmenų nuskaitymas (taško energijos tarifui)'),
	(761, 9526, 'Duomenų šaltinio perkūrimas'),
	(762, 6656, 'Matavimo taškų prietaisų konfigūracinių parametrų skylių pildymas'),
	(763, 3492, 'Tiekiamo karšto vandens tūrio kiekio per val. rodmenų generavimas iš tiekiamo karšto vandens tūrio kiekio per 5 min.'),
	(764, 9475, 'Vidutinio grįžtamo karšto vandens tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.'),
	(765, 657, 'Grįžtamo karšto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(766, 1678, 'Vidutinio grįžtamo karšto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(767, 8511, 'Grįžtamo karšto vandens tūrio kiekio per val. rodmenų generavimas iš grįžtamo karšto vandens tūrio kiekio per 5 min.'),
	(768, 1787, 'Vidutinės šilumnešio koreguota šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.'),
	(769, 8855, 'Šilumnešio koreguoto šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(770, 6090, 'Vidutinės šilumnešio koreguota šil. galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(771, 5752, 'Šilumnešio koreguoto šil. kiekio per val. rodmenų generavimas iš šilumnešio koreguoto šil. kiekio per 5 min.'),
	(772, 4943, 'Grupės "Pagal matavimo prietaisų tipus" sudėties pildymas/valymas'),
	(773, 77, 'Aktyvinės/reaktyvinės energijos pakaita iš galios profilio'),
	(774, 7789, 'Atnaujinti grupių matavimų išskaičiavimo iš taškų matavimų konfigūraciją pagal taškų ekonominių profilių konfigūraciją'),
	(775, 9722, 'Atnaujinti grupių matavimų išskaičiavimo iš grupių-komponentų matavimų konfigūraciją pagal pildymo taisykles'),
	(776, 8680, 'Periodinis automatinis išsiųstų SMS pranešimų žurnalo įrašų trynimas'),
	(777, 8967, 'Fiksuotų kas parą suminių duomenų generavimas iš fiksuotų kas mėnesį ir parų energijos duomenų'),
	(778, 4992, 'Vidutinio šalto vandens debito per 2 min. generavimas iš augančių reikšmių'),
	(779, 5364, 'Blogiausi šaltiniai pagal klaidų kiekį'),
	(780, 2971, 'Blogiausi šaltiniai pagal negaliojančių nuskaitymų kiekį'),
	(781, 2101, 'Suminės A+ energijos proporcingas generavimas iš gretimų reikšmių, fiksuotų kas valandą '),
	(782, 9874, 'Periodinis automatinis daugiažingsnių užduočių istorinės informacijos trynimas'),
	(783, 9037, 'Automatinis TestMode išjungimas'),
	(784, 2018, 'Stambesnių intervalų (iki paros) sumos rodmenų generavimas iš smulkesnių intervalų pagal priskirtą tarifą'),
	(785, 277, 'Nesinchronizuoti'),
	(786, 735, 'Atomų išdalinimas duomenų surinkimo serveriams'),
	(787, 6329, 'Niekada nebuvo matavimų duomenų'),
	(788, 9030, 'Nepildoma dalis galiojančių matavimų'),
	(789, 9534, 'Senų signalų apie su šaltiniais susijusios aktualios surinkimui konfigūracijos pasikeitimus įrašų trynimas'),
	(790, 2050, 'Senos automatinio atomų priskyrimo duomenų surinkimo serveriams istorijos trynimas'),
	(791, 2433, 'Atitinkamų matavimo taškams duomenų šaltinių sukūrimas arba papildymas'),
	(792, 6910, 'Suminės A+ energijos proporcingas generavimas iš gretimų reikšmių, fiksuotų kas 15 min.'),
	(793, 8292, 'Suminės A+ energijos proporcingas generavimas iš gretimų reikšmių, fiksuotų kas 30 min.'),
	(794, 5842, 'Skylių ekonomijos rėžimo suspendavimas'),
	(795, 2120, 'Naujų grupių įtraukimas į grupę pagal matavimo taškų tipus (atsiradus naujiems matavimo tašku tipams)'),
	(796, 3537, 'Periodinis automatinis nuskaitymo konfigūracijos tikrinimas'),
	(797, 8720, 'Buferinių struktūrų suspaudimas'),
	(798, 777, 'Nėra galutinių rodmenų'),
	(799, 7132, 'Papildančių rodmenį specifinių nuskaitymų informacijos atnaujinimas'),
	(800, 4231, 'Nėra duomenų už paskutines paras'),
	(801, 5236, 'Naujų grupių įtraukimas į grupę pagal šaltinių šablonus (atsiradus naujiems šaltinių šablonams)'),
	(802, 4798, 'Suminės A+ energijos pagal 1 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių'),
	(803, 1799, 'Suminės A+ energijos pagal 2 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių'),
	(804, 8861, 'Suminės A+ energijos pagal 3 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių'),
	(805, 4044, 'Suminės A+ energijos pagal 4 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių'),
	(806, 4788, 'Suminės A- energijos pagal 1 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių'),
	(807, 5065, 'Suminės A- energijos pagal 2 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių'),
	(808, 6749, 'Suminės A- energijos pagal 3 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių'),
	(809, 13, 'Suminės A- energijos pagal 4 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių'),
	(810, 3065, 'Suminės R+ energijos pagal 1 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių'),
	(811, 1203, 'Suminės R+ energijos pagal 2 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių'),
	(812, 2604, 'Suminės R+ energijos pagal 3 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių'),
	(813, 1607, 'Suminės R+ energijos pagal 4 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių'),
	(814, 693, 'Suminės R- energijos pagal 1 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių'),
	(815, 1716, 'Suminės R- energijos pagal 2 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių'),
	(816, 2377, 'Suminės R- energijos pagal 3 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių'),
	(817, 3876, 'Suminės R- energijos pagal 4 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių'),
	(818, 912, 'Nėra nuskaitymo rezultatų'),
	(819, 3702, 'Nėra jokių nuskaitymo duomenų'),
	(820, 6550, 'Blogiausi atsakantys nuskaitymo taškai pagal užklausų sėkmės procentą'),
	(821, 8970, 'Vidutinio dujų koreguoto tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(822, 7487, 'Dujų koreguoto tūrio kiekio per val. rodmenų generavimas iš dujų koreguoto tūrio kiekio per 5 min.'),
	(823, 7484, 'Vidutinio dujų masės debito per val. rodmenų generavimas iš vidutinio dujų masės debito per 5 min.'),
	(824, 7224, 'Dujų masės kiekio per 5 min. rodmenų generavimas iš suminio dujų masės kiekio, fiksuojamo kas 5 min.'),
	(825, 1980, 'Vidutinio dujų masės debito per 5 min. rodmenų generavimas iš suminio dujų masės kiekio, fiksuojamo kas 5 min.'),
	(826, 2987, 'Dujų masės kiekio per val. rodmenų generavimas iš dujų masės kiekio per 5 min.'),
	(827, 1323, 'Vidutinės dujų šilumos galios per val. rodmenų generavimas iš vidutinės dujų šilumos galios per 5 min.'),
	(828, 3615, 'Dujų šilumos kiekio per 5 min. rodmenų generavimas iš suminio dujų šilumos kiekio, fiksuojamo kas 5 min.'),
	(829, 7589, 'Vidutinės dujų šilumos galios per 5 min. rodmenų generavimas iš suminio dujų šilumos kiekio, fiksuojamo kas 5 min.'),
	(830, 6062, 'Dujų šilumos kiekio per val. rodmenų generavimas iš dujų šilumos kiekio per 5 min.'),
	(831, 7439, 'Vidutinio dujų tūrio debito per val. rodmenų generavimas iš vidutinio dujų tūrio debito per 5 min.'),
	(832, 5028, 'Vidutinio dujų tūrio debito per 5 min. rodmenų generavimas iš suminio dujų tūrio kiekio, fiksuojamo kas 5 min.'),
	(833, 2844, 'Dujų tūrio kiekio per 5 min. rodmenų generavimas iš suminio dujų tūrio kiekio, fiksuojamo kas 5 min.'),
	(834, 4432, 'Dujų tūrio kiekio per val. rodmenų generavimas iš dujų tūrio kiekio per 5 min.'),
	(835, 39, 'Vidutinės šalčio galios per val. rodmenų generavimas iš vidutinės šalčio galios per 5 min.'),
	(836, 4441, 'Šalčio energijos per 5 min. rodmenų generavimas iš suminės šalčio energijos, fiksuojamos kas 5 min.'),
	(837, 8924, 'Vidutinės šalčio galios per 5 min. rodmenų generavimas iš suminės šalčio energijos, fiksuojamos kas 5 min.'),
	(838, 9627, 'Šalčio energijos per val. rodmenų generavimas iš šalčio energijos per 5 min.'),
	(839, 8532, 'Vidutinės tiekiamo šalčio galios per val. rodmenų generavimas iš vidutinės tiekiamo šalčio galios per 5 min.'),
	(840, 6700, 'Tiekiamo šalčio energijos per 5 min. rodmenų generavimas iš suminės tiekiamo šalčio energijos, fiksuojamos kas 5 min.'),
	(841, 5413, 'Vidutinės tiekiamo šalčio galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(842, 9438, 'Tiekiamo šalčio energijos per val. rodmenų generavimas iš tiekiamo šalčio energijos per 5 min.'),
	(843, 2243, 'Vidutinės grįžtamo šalčio galios per val. rodmenų generavimas iš vidutinės grįžtamo šalčio galios per 5 min.'),
	(844, 4023, 'Vidutinės grįžtamo šalčio galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(845, 2882, 'Grįžtamo šalčio energijos per 5 min. rodmenų generavimas iš suminės grįžtamo šalčio energijos, fiksuojamos kas 5 min.'),
	(846, 9748, 'Grįžtamo šalčio energijos per val. rodmenų generavimas iš grįžtamo šalčio energijos per 5 min.'),
	(847, 9139, 'Vidutinio šalčio tūrio debito per val. rodmenų generavimas iš vidutinio šalčio tūrio debito per 5 min.'),
	(848, 819, 'Vidutinio šalčio tūrio debito per 5 min. rodmenų generavimas iš suminio šalčio tūrio kiekio, fiksuojamo kas 5 min.'),
	(849, 6155, 'Šalčio tūrio kiekio per 5 min. rodmenų generavimas iš suminio šalčio tūrio kiekio, fiksuojamo kas 5 min.'),
	(850, 5466, 'Šalčio tūrio kiekio per val. rodmenų generavimas iš šalčio tūrio kiekio per 5 min.'),
	(851, 8891, 'Vidutinio tiekiamo šalčio tūrio debito per val. rodmenų generavimas iš vidutinio tiekiamo šalčio tūrio debito per 5 min.'),
	(852, 1710, 'Tiekiamo šalčio tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(853, 4506, 'Vidutinio tiekiamo šalčio tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(854, 4687, 'Tiekiamo šalčio tūrio kiekio per val. rodmenų generavimas iš tiekiamo šalčio tūrio kiekio per 5 min.'),
	(855, 8148, 'Vidutinio grįžtamo šalčio tūrio debito per val. rodmenų generavimas iš vidutinio grįžtamo šalčio tūrio debito per 5 min.'),
	(856, 1361, 'Vidutinio grįžtamo šalčio tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(857, 2917, 'Grįžtamo šalčio tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(858, 9009, 'Grįžtamo šalčio tūrio kiekio per val. rodmenų generavimas iš grįžtamo šalčio tūrio kiekio per 5 min.'),
	(859, 2622, 'Vidutinio šilumnešio masės debito per val. rodmenų generavimas iš vidutinio šilumnešio masės debito per 5 min.'),
	(860, 9424, 'Šilumnešio masės kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(861, 2234, 'Vidutinio šilumnešio masės debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(862, 5807, 'Šilumnešio masės kiekio per val. rodmenų generavimas iš šilumnešio masės kiekio per 5 min.'),
	(863, 7077, 'Vidutinio tiekiamo šilumnešio masės debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.'),
	(864, 2867, 'Vidutinio tiekiamo šilumnešio masės debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(865, 3489, 'Tiekiamo šilumnešio masės kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(866, 6950, 'Tiekiamo šilumnešio masės kiekio per val. rodmenų generavimas iš tiekiamo šilumnešio masės kiekio per 5 min.'),
	(867, 325, 'Vidutinio grįžtamo šilumnešio masės debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.'),
	(868, 6044, 'Grįžtamo šilumnešio masės kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(869, 1298, 'Vidutinio grįžtamo šilumnešio masės debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(870, 3788, 'Grįžtamo šilumnešio masės kiekio per val. rodmenų generavimas iš grįžtamo šilumnešio masės kiekio per 5 min.'),
	(871, 8436, 'Vidutinės šilumnešio šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.'),
	(872, 3329, 'Šilumnešio šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(873, 2730, 'Vidutinės šilumnešio šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(874, 9823, 'Šilumnešio šilumos kiekio per val. rodmenų generavimas iš šilumnešio šilumos kiekio per 5 min.'),
	(875, 4219, 'Vidutinės tiekiamo šilumnešio šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.'),
	(876, 6097, 'Tiekiamo šilumnešio šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(877, 3153, 'Vidutinės tiekiamo šilumnešio šil. galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(878, 9459, 'Tiekiamo šilumnešio šilumos kiekio per val. rodmenų generavimas iš tiekiamo šilumnešio šil. kiekio per 5 min.'),
	(879, 9957, 'Vidutinės grįžtamo šilumnešio šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.'),
	(880, 9714, 'Grįžtamo šilumnešio šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.'),
	(881, 9195, 'AUTO_TESTMODE_OFF_FROM_SP_LPTY'),
	(882, 4650, 'AUTO_DELETE_ALL_FROM_EVAH'),
	(883, 5323, 'ANY_AVG_FROM_ANY_MIN_AVG_OR_SUM'),
	(884, 4622, 'AUTO_DELETE_ALL_FROM_SRCACL'),
	(885, 6631, 'HOUR_AVG_FROM_5_MIN_AVG'),
	(886, 6669, 'MANY_EVENTS'),
	(887, 6077, 'DELIVERY_POINT_FROM_2_INLETS_WITH_TR_2ND_LINE_LOSS'),
	(888, 1172, 'BY_SRC_TYPE'),
	(889, 3092, 'HOUR_AVG_FROM_30_MIN_AVG'),
	(890, 7982, 'UPDATE_GRC_DATA_FROM_GRC_RULE'),
	(891, 9776, 'DAY_SUM_FROM_30_MIN_AVG'),
	(892, 7485, 'ADD_NEW_GROUP_BY_SRC_TMPL'),
	(893, 1781, 'BOTTOM_10_SRC_BY_ERRORS'),
	(894, 9044, 'DAY_AVG_FROM_HOUR_AVG'),
	(895, 7550, 'HOUR_AVG_FROM_INSTANT'),
	(896, 8891, 'LPTY_MISSING'),
	(897, 5976, 'MONTH_ENERGY_FROM_MONTH_FIXED_TOTALS'),
	(898, 4027, 'INSTANT_15MIN_TOTALS_FROM_ADJACENT_TOTALS'),
	(899, 6104, '30_MIN_SUM_FROM_INSTANT_TOTALS'),
	(900, 6853, 'INSTANT_30MIN_TOTALS_FROM_ADJACENT_TOTALS'),
	(901, 2697, 'MONTH_MIN_FROM_DAY_MIN'),
	(902, 548, 'INIT_FILL_POINT_CFG'),
	(903, 9630, 'BY_METER_TYPE_MANAGEMENT'),
	(904, 4517, 'DELIVERY_POINT_TO_MS_POINT_TRANS_AND_LINE_LOSS'),
	(905, 7853, 'AUTO_DELETE_INVALID_FROM_DS_DATA'),
	(906, 8067, 'AUTO_UPDATE_PMA_FROM_TMPL'),
	(907, 8605, 'IMPROPER'),
	(908, 8317, 'INSTANT_HOUR_TOTALS_FROM_ADJACENT_TOTALS'),
	(909, 9642, 'FROZEN_GR_MLSET_DAY_DATA'),
	(910, 8849, 'CREATE_LINK_CONFIGURATION_FOR_UNREGISTERED_METER'),
	(911, 7829, 'ANY_FROM_XFE_PL_DATA'),
	(912, 9221, 'GROUPS_BY_FLEXFIELD'),
	(913, 6225, 'DAY_SUM_FROM_N_MIN_TOTALS'),
	(914, 2452, 'AUTO_UPDATE_SRC_FROM_TMPL'),
	(915, 7041, 'ADD_NEW_GROUP_BY_SRC_TYPE'),
	(916, 4014, 'DAY_SUM_OF_ALL_TARIFFS_RAW'),
	(917, 8968, 'AUTO_DELETE_ALL_FROM_ATOM_DAS_LOG'),
	(918, 942, 'HOUR_AVG_FROM_HOUR_AVG_AND_TARIFF_TOTALS'),
	(919, 1103, 'POLYDYNAMIC_ON_GR_FLEXFIELD_MANAGEMENT'),
	(920, 7972, 'ADD_NEW_LINES_FOR_GENERATION'),
	(921, 395, 'BOTTOM_10_NOT_FAILED_DP_BY_SUCCESS'),
	(922, 741, 'ADD_NEW_ELEMENTS_FOR_TOTALS_GENERATION'),
	(923, 6390, 'MONTH_SUM_OF_ALL_TARIFFS_RAW'),
	(924, 8671, 'PLUS_MINUS_FROM_QUADRANTS'),
	(925, 8706, 'DAY_EXTREME_FROM_ANY'),
	(926, 5556, 'MONTH_SUM_FROM_SUM_OF_DAYS'),
	(927, 9674, 'RAW_FIXED_TOTALS_FROM_RAW_FIXED_TOTALS_AND_30_MIN'),
	(928, 2666, 'AUTO_DELETE_FROM_EAPP_EDEV_PRQ_EE_LOG'),
	(929, 2623, 'HOUR_AVG_FROM_15_MIN_AVG'),
	(930, 7768, 'BOTTOM_10_SRC_BY_NV'),
	(931, 9755, 'DELIVERY_POINT_FROM_TRANSFORMER_AND_2_INLETS_DATA'),
	(932, 3975, 'AUTO_DELETE_ALL_FROM_RODO'),
	(933, 5693, 'AUTO_DELETE_ALL_FROM_RP_LOG'),
	(934, 1614, 'MAJOR_ISSUE'),
	(935, 8136, '30_MIN_AVG_FROM_INSTANT'),
	(936, 8307, 'FROZEN_GR_MINUTE_DATA'),
	(937, 6675, 'SUM_OF_ALL_TARIFFS_HOUR_RAW'),
	(938, 6977, 'SUM_OF_ALL_TARIFFS_HOUR'),
	(939, 1910, 'AUTO_DELETE_ALL_FROM_BGAO'),
	(940, 7376, 'ANY_FROM_RP'),
	(941, 7377, 'AUTO_DELETE_REPEATED_DS_DATA'),
	(942, 5628, 'AUTO_DELETE_ALL_FROM_DS_DATA'),
	(943, 4107, 'ACT/REACT_ENERGY_FROM_POWER'),
	(944, 2951, 'POINTS_BY_FLEXFIELD'),
	(945, 7986, 'PWM_EXECUTE'),
	(946, 8015, 'DELIVERY_POINT_FROM_MS_POINT_AND_LINE_LOSS_P2_Q2'),
	(947, 26, 'AUTO_DELETE_INVALID_FROM_PL_DATA'),
	(948, 7569, 'AUTO_DELETE_ALL_FROM_DW_DATA'),
	(949, 2048, 'THERMO_TEMP_GRAPH_FROM_OUTSIDE_TEMP'),
	(950, 9095, 'BY_SRC_TMPL'),
	(951, 1151, 'HOPELESS'),
	(952, 501, 'DAY_SUM_OF_ALL_TARIFFS'),
	(953, 7746, 'DELIVERY_POINT_FROM_2_INLETS_WITH_TR_AND_LINE_LOSS'),
	(954, 5481, 'HOUR_AVG_FROM_DAY_SUM_DIVIDED_BY_SAMPLE'),
	(955, 9458, 'NO_RESTORE_DEPTH'),
	(956, 4821, 'ANY_AVG_OR_SUM_FROM_N_MIN_TOTALS'),
	(957, 4602, 'SPLUS_FROM_PPLUS_QPLUS'),
	(958, 1619, 'FROZEN_GR_MLSET_MINUTE_DATA'),
	(959, 1813, 'AUTO_DELETE_ALL_FROM_PLEP'),
	(960, 7738, 'UPDATE_GRP_DATA_FROM_ECP_DATA'),
	(961, 8431, 'AUTO_DELETE_STA_PH'),
	(962, 2103, 'NOT_CLOSED'),
	(963, 2521, 'NO_READING'),
	(964, 3386, 'AUTO_DELETE_ALL_STA_SRC'),
	(965, 5546, 'DTL_EXECUTE'),
	(966, 9248, 'NO_ANY_STORABLE_BUT_DP_HAS'),
	(967, 2735, 'MONTH_ENERGY_FROM_TOTALS'),
	(968, 3944, 'DELIVERY_POINT_FROM_MS_POINT_CONSIDERING_LINE_LOSS'),
	(969, 2425, 'SUM_OF_ALL_TARIFFS_RAW'),
	(970, 2835, 'MONTH_MAX_FROM_DAY_MAX'),
	(971, 5227, 'NOT_SYNCHRONIZED'),
	(972, 8899, 'HOLES_ECONOMY_SUSPEND'),
	(973, 6251, 'NEVER_GOT_STORABLE'),
	(974, 4259, 'INSTANT_TOTALS_FROM_ADJACENT_TOTALS'),
	(975, 5183, 'DP_NO_ANY_STORABLE'),
	(976, 8313, 'HOUR_SUM_FROM_INSTANT_TOTALS'),
	(977, 1550, 'SIMULTANEOUS_READ_TOTALS_MONTHS_M'),
	(978, 1971, 'SHRINK_BUF'),
	(979, 4553, 'DIVIDE_ATOMS_BETWEEN_DAS'),
	(980, 9254, 'POLYDYNAMIC_ON_POINT_FLEXFIELD_MANAGEMENT'),
	(981, 5904, 'MONTH_AVG_FROM_AVG_OF_DAYS'),
	(982, 862, 'SRC_FROM_RULE_FOR_POINT'),
	(983, 1679, 'AUTO_DELETE_INVALID_FROM_DW_DATA'),
	(984, 6186, 'DP_CONNECTION_FAILED'),
	(985, 8532, 'NO_ANY_RECENT_READING'),
	(986, 3303, 'DAY_MAX_FROM_HOUR_MAX'),
	(987, 15, 'OLD_HOLES'),
	(988, 3535, 'NO_ANY_READING'),
	(989, 4930, 'PL_SE_POST_PROCESSING'),
	(990, 3169, 'DAY_SUM_FROM_15_MIN_AVG'),
	(991, 2780, 'MONTH_EXTREME_FROM_ANY'),
	(992, 643, 'AUTO_DELETE_ALL_FROM_XDATA'),
	(993, 5989, 'PL_DATA_SET_DB_TIME_TO_NULL'),
	(994, 1398, 'AUTO_DELETE_ALL_FROM_XO'),
	(995, 6219, 'BY_POINT_TYPE'),
	(996, 3546, 'HOUR_MAX_FROM_INSTANT'),
	(997, 9697, 'AUTO_DELETE_ALL_FROM_UTL'),
	(998, 2886, 'ANY_TFF_SUM_FROM_ANY_MIN_AVG_OR_SUM'),
	(999, 1467, 'DP_CONNECTION_OK_WITH_ERRORS'),
	(1000, 1231, 'DAY_SUM_FROM_INSTANT_TOTALS'),
	(1001, 175, 'ANY_FROM_PREVIOUS'),
	(1002, 7906, 'AUTO_DELETE_ALL_FROM_EV'),
	(1003, 2581, '15_MIN_AVG_FROM_15_MIN_TOTALS'),
	(1004, 7047, 'SIMULTANEOUS_READ_TOTALS_MONTHS_P'),
	(1005, 9430, 'AUTO_UPDATE_GMA_FROM_TMPL'),
	(1006, 9521, 'INDICATOR_FROM_MIN_FIX_TOTALS'),
	(1007, 3204, 'RECREATE_SOURCE'),
	(1008, 8403, 'AUTO_DELETE_ALL_FROM_AUD_DATA'),
	(1009, 2424, 'DELIVERY_POINT_TO_MS_POINT_CONSIDERING_TRANSFORMER'),
	(1010, 5165, 'DAY_SUM_FROM_HOUR_AVG'),
	(1011, 2985, 'UPDATE_PL_DATA_CUSTOM'),
	(1012, 5688, 'HOUR_AVG_FROM_INSTANT_TOTALS'),
	(1013, 9103, 'SUM_OF_ALL_TARIFFS'),
	(1014, 7709, 'DELIVERY_POINT_FROM_2_INLETS_WITH_TRANSFORMERS'),
	(1015, 7289, 'NOT.IN.ALL.ROOT'),
	(1016, 7301, 'ADD_NEW_GROUP_BY_POINT_TYPE'),
	(1017, 8544, '30_MIN_AVG_FROM_30_MIN_TOTALS'),
	(1018, 9949, 'DP_CONNECTION_CHANGED_TO_OK'),
	(1019, 3747, 'AUTO_DELETE_ALL_FROM_LTL'),
	(1020, 1612, 'TFF_EXTREME_DD_MM'),
	(1021, 9631, 'INIT_GEN_ANY_FROM_XFE_PL_DATA'),
	(1022, 7865, 'AUTO_DELETE_INVALID_FROM_PW_DATA'),
	(1023, 692, '2_MIN_AVG_FROM_INSTANT_TOTALS'),
	(1024, 7948, 'N_MIN_FIXED_TOTALS_FROM_N_MIN_FIXED_AND_PROFILE'),
	(1025, 1028, 'AUTO_DELETE_ALL_FROM_CP'),
	(1026, 2220, 'METER_NUMBER_TO_ELEMENTS'),
	(1027, 3115, 'MONTH_SUM_OF_ALL_TARIFFS'),
	(1028, 3817, 'HOUR_AVG_FROM_N_MIN_TOTALS'),
	(1029, 9177, 'AUTO_DELETE_ALL_FROM_MAP_DATA'),
	(1030, 3054, '30_MIN_AVG_FROM_INSTANT_TOTALS'),
	(1031, 3410, 'DAY_MIN_FROM_HOUR_MIN'),
	(1032, 2051, 'HOUR_MIN_FROM_INSTANT'),
	(1033, 2147, 'HOUR_AVG_FROM_30_MIN_AVG_WO_BYP'),
	(1034, 5878, 'AUTO_DELETE_ALL_FROM_PW_DATA'),
	(1035, 1337, 'DAY_BITOR_FROM_HOUR'),
	(1036, 305, 'AUTO_DELETE_ALL_FROM_SMS_LOG'),
	(1037, 1163, 'DELTA_FROM_DIFFERENCE'),
	(1038, 7233, 'HOUR_EXTREME_FROM_ANY'),
	(1039, 9109, 'PARTIAL_FAILURE'),
	(1040, 2152, 'FROZEN_GR_DAY_DATA'),
	(1041, 8295, 'GROUP_ALREADY_INCLUDED'),
	(1042, 7297, 'A_FEW_METERS'),
	(1043, 2177, 'DIRECTION_NOT_FOUND'),
	(1044, 4789, 'PROPERTY_NOT_FOUND'),
	(1045, 6107, 'FORM_ELEMENT_DATA_NOT_SAVED'),
	(1046, 5322, 'READING_REQUEST_FROM_SIGNAL_NOT_PREPARED'),
	(1047, 8916, 'MONTH'),
	(1048, 4338, 'GROUP-CONTAINER_NOT_FOUND'),
	(1049, 3007, 'ECONOMIC_PROFILE_NOT_FOUND'),
	(1050, 870, 'GROUP_TYPE_NOT_FOUND'),
	(1051, 4116, 'POINT_PROPERTY_NOT_FOUND'),
	(1052, 5998, 'DUBLICATE_SOURCE_NAME'),
	(1053, 9888, 'DATA_SOURCES'),
	(1054, 2710, 'READING_DATA_ELEMENTS'),
	(1055, 9314, 'DATA_SOURCE_ELEMENTS'),
	(1056, 7963, 'UPDATE'),
	(1057, 4577, 'DELETE'),
	(1058, 7249, 'MEASURING'),
	(1059, 754, 'GROUP'),
	(1060, 7036, 'TEMPLATE'),
	(1061, 8583, 'OUTPUT'),
	(1062, 1057, '1_(2)'),
	(1063, 2892, '1_2_3'),
	(1064, 4678, 'READING_CONFIGURATION_NOT_FOUND'),
	(1065, 7552, 'NOT_FOUND'),
	(1066, 5310, 'BEFORE'),
	(1067, 3118, 'WRONG_TIME'),
	(1068, 8922, 'NO_GRANTS_FOR_INACTIVE_USER'),
	(1069, 9202, 'EXTERNAL_POINT'),
	(1070, 83, 'DISABLED_POINT'),
	(1071, 3017, 'RECORD_NOT_UPDATED'),
	(1072, 587, 'GROUP_HAS_POINT'),
	(1073, 9594, 'MIN'),
	(1074, 7371, 'WRONG_METER_TYPE'),
	(1075, 951, 'SECOND'),
	(1076, 1276, 'WRONG_ARRAY_LENGTH'),
	(1077, 2465, 'UNKNOWN_METER_INTEGRATION_PERIOD'),
	(1078, 5323, 'RECORDS_NOT_DELETED'),
	(1079, 473, 'GROUP_HAS_TEMPLATE'),
	(1080, 1208, 'WRONG_TYPE_OF_ENERGY'),
	(1081, 6470, 'APPEARED'),
	(1082, 6971, 'DISAPPEARED'),
	(1083, 7751, 'POWER_LOST'),
	(1084, 3496, 'WRONG_PARAMETERS_FOR_INSERT'),
	(1085, 4577, 'WRONG_PARAMETER_VALUE_FOR_THIS_TIME'),
	(1086, 8935, 'FATAL_ERROR'),
	(1087, 2498, 'PARAMETER_TIME_LATER_THAN_CURRENT'),
	(1088, 6810, 'PARAMETER_TIME_EARLER_THAN_ASSIGNED'),
	(1089, 6856, 'COMMAND_FINISH_INFORMATION_NOT_FOUND'),
	(1090, 1774, 'STARTED_BROKEN_JOB'),
	(1091, 5613, 'WRONG_METER_NUMBER'),
	(1092, 2016, 'DATA_READING_NOT_ALLOWED'),
	(1093, 3516, 'MEASURING_DATA_NOT_FOUND'),
	(1094, 1675, 'DAY_IS_CLOSED'),
	(1095, 8699, 'MONTH_IS_CLOSED'),
	(1096, 5640, 'WRONG_PARAMETER_FOR_EXECUTION'),
	(1097, 2936, 'TEST'),
	(1098, 3526, 'ID_NOT_FOUND'),
	(1099, 8938, 'DAY_MEASURING_DATA'),
	(1100, 3153, 'MONTH_MEASURING_DATA'),
	(1101, 988, 'NOT_DELAYED'),
	(1102, 9878, 'WRONG_ACCOUNTING_PERIOD'),
	(1103, 4539, 'VALUE_NOT_FINAL'),
	(1104, 8493, 'NO'),
	(1105, 6661, 'DUBLICATE_ACCOUNT_NODE'),
	(1106, 8218, 'RELATED_RECORD_FOUND'),
	(1107, 1291, 'EMPTY_VALUE'),
	(1108, 2230, 'DUBLICATE_VALUE'),
	(1109, 4425, 'WRONG_PERIOD'),
	(1110, 5829, 'CROSSED_PERIODS'),
	(1111, 1801, 'GROUP_PROPERTY_NOT_DIGITAL'),
	(1112, 6011, 'GROUPED_DATA_CHANGE_ALLOWED_FOR_DIGITAL_GROUP_PROPERTY_ONLY '),
	(1113, 9650, 'WRONG_DISCRETION_OF_MONITORING_INDICATORS'),
	(1114, 5655, 'SOURCE_DESTINATION_ASSIGNMENT_NOT_DIFFERENT'),
	(1115, 6733, 'CYCLIC_DEPENDENCY'),
	(1116, 8270, 'DUBLICATE_COMMUNICATE_CHANNEL_FOR_SOURCE'),
	(1117, 3098, 'RELATED_RECORDS_FOUND'),
	(1118, 2926, 'HOLES_NOT_FOUND'),
	(1119, 2039, 'MEASURING_DATA_NOT_ENOUGH_FOR_GROUP'),
	(1120, 8355, 'REAL_TIME_MEASURING_READING_PROFILE_NOT_FOUND'),
	(1121, 1031, 'MEASURING_NOT_FOUND_IN_REAL_TIME_MEASURING_READING_PROFILE'),
	(1122, 8912, 'DUBLICATE_COMMUNICATE_CHANNEL_TYPE'),
	(1123, 3115, 'POINT_PROPERTY_NOT_DIGITAL'),
	(1124, 1943, 'WEEK'),
	(1125, 1732, '1_2'),
	(1126, 1214, 'OFF'),
	(1127, 8205, 'ONN'),
	(1128, 5909, 'YYYY.MM.DD HH24:MI:SS'),
	(1129, 8801, '1_2_3_4_5'),
	(1130, 9910, 'ACCOUNTING_STATUS_SIGNAL_NOT_ALLOWED'),
	(1131, 6200, 'MAXIMUM_POINT_COUNT'),
	(1132, 2171, 'BACKGROUND_TASK_EXECUTING'),
	(1133, 6490, 'MEASURES_NOT_FOUND_FOR_GENERATION'),
	(1134, 1277, 'DUBLICATE_SOURCE_NAME_IN_DATAPOINT'),
	(1135, 6854, 'DUBLICATE_KIO-3_FORM_FILE_NAME'),
	(1136, 7298, 'STORE_PL.GROWTH_LIMIT_EXCEEDED'),
	(1137, 9560, 'READ_LTL.OLD_REMOVED'),
	(1138, 954, 'FFP_VAL_ROW_NUM_100'),
	(1139, 4531, 'CP.EV_MSG_1'),
	(1140, 9273, 'CP.EV_MSG_2'),
	(1141, 2007, 'CP.EV_MSG_3'),
	(1142, 6554, 'CP.EV_MSG_4'),
	(1143, 8315, 'CP.EV_MSG_5'),
	(1144, 7220, 'CP.EV_MSG_6'),
	(1145, 2985, 'AUD.ACT_DESC'),
	(1146, 7920, 'AUD.ACT_ENABLED'),
	(1147, 3341, 'AUD.ACT_ID'),
	(1148, 1960, 'AUD.ACT_MONTH'),
	(1149, 6648, 'AUD.ACT_NUMBER'),
	(1150, 3403, 'AUD.ACT_TYPE_ID'),
	(1151, 6013, 'AUD.ACT_TYPE_NAME'),
	(1152, 5653, 'AUD.ACT_VALUE'),
	(1153, 6463, 'AUD.AGGF_ID'),
	(1154, 4803, 'SOURCES_WITH_DIFFERENT_DATA_POINTS'),
	(1155, 3269, 'SOURCES_WITH_DIFFERENT_DATA_LOCATIONS'),
	(1156, 9079, 'SOURCES_WITH_DIFFERENT_TIME_ZONES'),
	(1157, 241, 'GROUP_NOT_FOUND'),
	(1158, 4478, 'PARAMETER_VALUE'),
	(1159, 9667, 'LOOP_PARAMETRATION_DATE_UPDATED'),
	(1160, 1939, 'COULD_NOT_DELETE_RECORD'),
	(1161, 182, 'WRONG_METER_PERIOD'),
	(1162, 240, 'POWER_LOST_PERIOD'),
	(1163, 9556, 'METER_EVENTS_AND_STATUSES_POSSIBLE_LOST'),
	(1164, 3209, 'UNKNOWN_PARAMETER'),
	(1165, 9662, 'TIME_CHANGE_FINISH_INFORMATION_NOT_FOUND'),
	(1166, 7517, 'GROUP_TEMPLATE_VALUE_MISMATCH_DAY_HOUR_VALUE'),
	(1167, 9588, 'CLOSED_DAY'),
	(1168, 9536, 'MEASURING_DATA_EARLIER'),
	(1169, 193, 'YES'),
	(1170, 6705, 'DUBLICATE_GROUP_CODE'),
	(1171, 3013, 'GROUP_PROPERTY_NOT_FOUND'),
	(1172, 9776, 'SYSTEM_USER_MODIFICATION_NOT_GRANTED'),
	(1173, 5694, 'INSERT'),
	(1174, 6603, 'VALUE'),
	(1175, 4136, '1_\'2\''),
	(1176, 4613, 'INPUT'),
	(1177, 7477, 'PERCENT'),
	(1178, 4460, 'UNKNOWN_MODULE'),
	(1179, 5319, 'AFTER'),
	(1180, 711, 'MEASURING_CHANNEL_DATA_NOT_FOUND'),
	(1181, 4423, 'HOUR'),
	(1182, 5160, 'WRONG_VALUES_COUNT'),
	(1183, 1229, 'MAGENTIC_FIELD_COUNT'),
	(1184, 1129, 'METER_DISMANTLED'),
	(1185, 6271, 'DETAILED_MEASURING_DATA'),
	(1186, 3941, 'MISMATCHED'),
	(1187, 8134, 'DELAYED'),
	(1188, 9090, 'WRONG_COLUMN'),
	(1189, 4480, 'RECORD_NOT_DELETED'),
	(1190, 9508, 'EMPTY'),
	(1191, 5649, 'DAY'),
	(1192, 4999, 'COLUMN_WRONG'),
	(1193, 912, 'TEMPLATE_HOUR_SHEDULE_NOT_FOUND'),
	(1194, 769, 'CONTROLLER_CONFIGURATION_CHANGED'),
	(1195, 3063, 'PARAMETER_VALUE_NOT_FOUND'),
	(1196, 2849, 'MATCHED'),
	(1197, 4435, 'LOAD_PERMITTED'),
	(1198, 7094, 'WRONG_FORM_TYPE_FOR_IMPORT'),
	(1199, 4471, 'MEASURING_NOT_FOUND'),
	(1200, 3855, 'POINT_TYPE_NOT_FOUND'),
	(1201, 8677, 'SOURCE_NOT_FOUND_FOR_IMPORT_FORM'),
	(1202, 7661, 'DUBLICATE_SIMPLE_SCHEDULE'),
	(1203, 8853, 'DUBLICATE_POINT_CODE'),
	(1204, 1934, 'METER_TYPE_NOT_FOUND'),
	(1205, 4052, 'EXECUTED_WITH_WARNINGS'),
	(1206, 9366, 'TRANSFORMED'),
	(1207, 974, 'DUBLICATE_TIME_LABEL'),
	(1208, 1688, 'WRONG_METER_ID'),
	(1209, 4119, 'POINT_AUTO_READ_DISABLED'),
	(1210, 3701, 'WRONG_METER_TIME'),
	(1211, 9845, 'PERIOD_TOO_LONG'),
	(1212, 994, 'PERIOD_BEFORE_PARAMETRATION'),
	(1213, 3596, 'CONTROLLER_LOOP_CONFIGURATION_CHANGED'),
	(1214, 9125, 'WRONG_PARAMETERS_FOR_INSERTS'),
	(1215, 19, 'WRONG_ENERGY_TARIFFS_COUNT'),
	(1216, 2850, 'TIME_LATER_THAN_CURRENT'),
	(1217, 7043, 'PARAMETRATION_FINISH_INFORMATION_NOT_FOUND'),
	(1218, 2857, 'METER_TIME_UPDATING_PROCEDURE_NOT_FINISHED'),
	(1219, 9819, 'METER_PARAMETRATION_DATE_LATER_THAN_DAY'),
	(1220, 1748, 'SUM_MEASURING_DATA'),
	(1221, 4536, 'MEASURING_DATA_LATER'),
	(1222, 5194, 'UPDATE_BLOCKED_TO_EXCLUDE_UNEXPECTED_REZULTS'),
	(1223, 5640, 'DATA_READING_NOT_ALLOWED_UNTILL_PARAMETRATION_READING_ENDS'),
	(1224, 4493, 'MISSING_METER_PARAMETRATION_DATA'),
	(1225, 2130, 'REQUIREMENT_TO_ARCHIVE_DELETED'),
	(1226, 4981, 'DAY_DATA_AGAIN_MISMATCH_DETAILED_DATA'),
	(1227, 5135, 'ALLOWED_ONLY_ONE_VERGE_ASSINGING_TO_ONE_TARGET'),
	(1228, 3490, 'METER_INSTALATION_DATE_LATER_THAN_MONTH'),
	(1229, 6413, 'RECORD_NOT_FOUNT'),
	(1230, 1369, 'OPTIC_PARAMETRATION_DATE_UPDATED'),
	(1231, 7757, 'RECORDS_NOT_FOUND'),
	(1232, 8486, 'PERIOD_BEFORE_INSTALLATION'),
	(1233, 115, 'WRONG_TIME_FOR_METER_DATA'),
	(1234, 468, 'TIME_UPDATING_REQUEST_NOT_FOUND'),
	(1235, 7634, 'METER_PARAMETER_CHANGED'),
	(1236, 2735, 'SOURCES_WITH_DIFFERENT_SECTION_TIME_ZONES'),
	(1237, 7887, 'SECTION_AND_ASKP_FILE_HAVE_DIFFERENT_TIME_ZONES'),
	(1238, 9979, 'EARLER_METER_CONFIGURATION_NOT_FOUND'),
	(1239, 6533, 'DAY_DATA_MISMATCH_DETAILED_DATA'),
	(1240, 8679, 'LOOP_PARAMETRATION_FINISH_INFORMATION_NOT_FOUND'),
	(1241, 5570, 'METER_INSTALATION_DATE_LATER_THAN_DAY'),
	(1242, 1865, 'METER_PARAMETRATION_DATE_LATER_THAN_MONTH'),
	(1243, 6442, 'METER_CONFIGURATION_DATA_NOT_FOUND'),
	(1244, 780, 'CLOSED_MONTH'),
	(1245, 9800, 'WRONG_ENTRY_FOR_VIEW'),
	(1246, 5591, 'DATA_NOT_RESETED_AFTER_METER_PARAMETRATION'),
	(1247, 5757, 'DATA_SOURCE_ELEMENTS_ON_COMMUNICATION_CHANNEL'),
	(1248, 1271, 'READ_CAUSE_OF_DATA_SOURCE_ELEMENTS_ON_COMMUNICATION_CHANNEL'),
	(1249, 6969, 'MULTIPLYING_IN_DEVICE_ONLY'),
	(1250, 3857, 'CHECK_COMMUNICATION_PRIORITY_ON_CONFIGURATION_PROFILES '),
	(1251, 1005, 'MEASURING_LINE_SET_NOT_FOUND'),
	(1252, 5404, 'DUBLICATE_POINT_MEASURING_IN_SOURCE_ELEMENTS'),
	(1253, 6685, 'ENTER_SQL_QUERY_TO_UPDATE_GROUP_COMPOSITION'),
	(1254, 8110, 'ECONOMIC_CATEGORY_CODE_NOT_FOUND'),
	(1255, 5481, 'SYSTEM_PROPERTY_VALUE_NOT_DIGITAL'),
	(1256, 9662, 'SOURCES_WITH_DIFFERENT_TYPES'),
	(1257, 8853, 'MOU_MADE_EXPL_DATA_CHECK'),
	(1258, 8624, 'FORM_PROTOCOL_CHECK'),
	(1259, 7413, 'LICENSE_WRONG'),
	(1260, 6709, 'LICENSE_CHECKED'),
	(1261, 1236, 'LICENSE_INSTALLED'),
	(1262, 70, 'LICENSE_EXPIRATION'),
	(1263, 9759, 'LICENSE_NOT_FOUND'),
	(1264, 701, 'IMPORT_FORM_AND_SOURCE_WITH_DIFFERENT_TIME_ZONES'),
	(1265, 7179, 'DUBLICATE_XFAU_MEASURING_IN_FORM'),
	(1266, 9669, 'DUBLICATE_COMMUNICATE_CHANNEL_TYPE_DEL'),
	(1267, 2184, 'LINK_CFG.SE_SUMMAND_ERROR1'),
	(1268, 534, 'AUD.AGGS_ID'),
	(1269, 8287, 'AUD.AGGS_TYPE_ID'),
	(1270, 2049, 'AUD.ALGR_CODE'),
	(1271, 7663, 'AUD.ALGR_ID'),
	(1272, 3559, 'AUD.AL_ID'),
	(1273, 8146, 'AUD.BDD'),
	(1274, 1068, 'AUD.BGA_CLASS_CODE'),
	(1275, 2710, 'AUD.BGA_CLASS_ID'),
	(1276, 8925, 'AUD.BGA_CLASS_NAME'),
	(1277, 6588, 'AUD.BGA_ENABLED'),
	(1278, 6255, 'AUD.BGA_ID'),
	(1279, 7021, 'AUD.BGA_NAME'),
	(1280, 7591, 'AUD.BGA_PARAM_NR'),
	(1281, 1744, 'AUD.BGA_PARAM_VALUE'),
	(1282, 6259, 'AUD.BGA_PARAM_VALUE_DESC'),
	(1283, 4998, 'AUD.BGA_TYPE_CODE'),
	(1284, 2614, 'AUD.BGA_TYPE_DECLARE'),
	(1285, 1756, 'AUD.BGA_TYPE_DESC'),
	(1286, 5748, 'AUD.BGA_TYPE_ID'),
	(1287, 5333, 'AUD.BGA_TYPE_NAME'),
	(1288, 9939, 'AUD.BGA_TYPE_PARAM_DESC'),
	(1289, 5900, 'AUD.BGA_TYPE_PARAM_KEY'),
	(1290, 2968, 'AUD.BGA_TYPE_PARAM_NR'),
	(1291, 9554, 'AUD.BGA_TYPE_PARAM_REGULAR'),
	(1292, 6478, 'AUD.BGA_TYPE_POST_ACTION'),
	(1293, 6310, 'AUD.BGA_TYPE_PRE_ACTION'),
	(1294, 7919, 'AUD.BGA_TYPE_REC_ACTION'),
	(1295, 3599, 'AUD.BGA_TYPE_SELECT'),
	(1296, 8079, 'AUD.BHH'),
	(1297, 5120, 'AUD.BMM'),
	(1298, 9725, 'AUD.BT'),
	(1299, 4011, 'AUD.BYP_DIR_INV'),
	(1300, 8491, 'AUD.BYP_ENABLED'),
	(1301, 7582, 'AUD.BYP_INV'),
	(1302, 5776, 'AUD.BYP_MODE'),
	(1303, 2735, 'AUD.BYP_POINT_ID'),
	(1304, 6937, 'AUD.CAP_CODE'),
	(1305, 8386, 'AUD.CAP_ID'),
	(1306, 3343, 'AUD.CAP_NAME'),
	(1307, 7142, 'AUD.CAP_PARAM_DESC'),
	(1308, 9449, 'AUD.CAP_PARAM_NR'),
	(1309, 2720, 'AUD.CAP_TEXT'),
	(1310, 7873, 'AUD.CAP_TEXT_DEFAULT'),
	(1311, 6825, 'AUD.CH_CNT'),
	(1312, 2297, 'AUD.CH_DPT'),
	(1313, 5895, 'AUD.CH_DSC'),
	(1314, 6360, 'AUD.INHERIT_CN'),
	(1315, 535, 'AUD.IS_PUBLIC'),
	(1316, 2665, 'AUD.LPTY_CODE'),
	(1317, 8704, 'AUD.LPTY_ID'),
	(1318, 3115, 'AUD.LPTY_VALUE'),
	(1319, 677, 'AUD.LP_ID'),
	(1320, 647, 'AUD.LP_NAME'),
	(1321, 5196, 'AUD.LP_PRIORITY'),
	(1322, 9411, 'AUD.LTC_CODE'),
	(1323, 52, 'AUD.MADE'),
	(1324, 7059, 'AUD.MAP_ENABLED'),
	(1325, 185, 'AUD.MAP_ID'),
	(1326, 7776, 'AUD.MA_AB'),
	(1327, 6606, 'AUD.MA_AUTO_CHECK'),
	(1328, 5577, 'AUD.MA_A_DENOM'),
	(1329, 1986, 'AUD.MA_A_NOM'),
	(1330, 7861, 'AUD.MA_B'),
	(1331, 9891, 'AUD.MA_ENABLED'),
	(1332, 8538, 'AUD.MA_ID'),
	(1333, 449, 'AUD.MA_REPORT_EXCEEDING'),
	(1334, 4848, 'AUD.MA_SHOW'),
	(1335, 1241, 'AUD.MD_ID'),
	(1336, 9354, 'AUD.MD_NAME'),
	(1337, 337, 'AUD.METER_CLASS'),
	(1338, 4547, 'AUD.METER_ID'),
	(1339, 4411, 'AUD.METER_NUMBER'),
	(1340, 3988, 'AUD.METER_TYPE_ID'),
	(1341, 3362, 'AUD.METER_TYPE_NAME'),
	(1342, 5386, 'AUD.METER_TYPE_PRODUCER'),
	(1343, 4142, 'AUD.MLSET_CODE'),
	(1344, 1213, 'AUD.MLSET_ID'),
	(1345, 8974, 'AUD.MLSET_NAME'),
	(1346, 901, 'AUD.ML_ID'),
	(1347, 354, 'AUD.ML_NAME'),
	(1348, 6741, 'AUD.MM'),
	(1349, 9760, 'AUD.MO1'),
	(1350, 297, 'AUD.MO10'),
	(1351, 4945, 'AUD.MO11'),
	(1352, 1848, 'AUD.MO12'),
	(1353, 723, 'AUD.MO2'),
	(1354, 9329, 'AUD.MO3'),
	(1355, 2474, 'AUD.MO4'),
	(1356, 6319, 'AUD.MO5'),
	(1357, 5951, 'AUD.MO6'),
	(1358, 1931, 'AUD.MO7'),
	(1359, 1027, 'AUD.MO8'),
	(1360, 9784, 'AUD.MO9'),
	(1361, 6984, 'AUD.MOU_BT'),
	(1362, 6107, 'AUD.MOU_ET'),
	(1363, 9561, 'AUD.MOU_ID'),
	(1364, 8977, 'AUD.MOU_TYPE_ID'),
	(1365, 3245, 'AUD.MOU_TYPE_NAME'),
	(1366, 756, 'AUD.MO_SPECIFIC'),
	(1367, 3134, 'AUD.MPTY_CODE'),
	(1368, 4455, 'AUD.MPTY_ID'),
	(1369, 579, 'AUD.MPTY_NAME'),
	(1370, 9291, 'AUD.MPTY_NR'),
	(1371, 1133, 'AUD.MPTY_TYPE_CODE'),
	(1372, 2397, 'AUD.MPTY_TYPE_ID'),
	(1373, 7919, 'AUD.MPTY_TYPE_NAME'),
	(1374, 950, 'AUD.MPTY_VALUE'),
	(1375, 9376, 'AUD.MS_CODE'),
	(1376, 6645, 'AUD.MS_ID'),
	(1377, 9514, 'AUD.MS_TYPE_ID'),
	(1378, 6959, 'AUD.MS_TYPE_NAME'),
	(1379, 3151, 'AUD.MT_ID'),
	(1380, 5752, 'AUD.NR'),
	(1381, 1013, 'AUD.NVAL1'),
	(1382, 3747, 'AUD.NVAL2'),
	(1383, 7048, 'AUD.OC_CNT'),
	(1384, 4082, 'AUD.OC_DPT'),
	(1385, 4063, 'AUD.OC_DSC'),
	(1386, 4566, 'AUD.OC_GRP'),
	(1387, 1362, 'AUD.OC_PNT'),
	(1388, 8567, 'AUD.PCK_T'),
	(1389, 5530, 'AUD.PER_ID'),
	(1390, 5083, 'AUD.PER_NAME'),
	(1391, 7651, 'AUD.PH_DELETED'),
	(1392, 5690, 'AUD.PH_ENABLED'),
	(1393, 6054, 'AUD.PH_FAILURE_COUNT'),
	(1394, 5443, 'AUD.PH_ID'),
	(1395, 5261, 'AUD.PH_LAYER_ID'),
	(1396, 6090, 'AUD.PH_LAYER_NAME'),
	(1397, 6585, 'AUD.PH_NAME'),
	(1398, 3443, 'AUD.PH_SAVE_STATISTICS'),
	(1399, 4702, 'AUD.PH_TYPE_ID'),
	(1400, 5820, 'AUD.PH_TYPE_NAME'),
	(1401, 5234, 'AUD.PL_ENABLED'),
	(1402, 9784, 'AUD.PL_ID'),
	(1403, 6714, 'AUD.PL_T'),
	(1404, 7222, 'AUD.POINT_AUTO_READ_ENABLED'),
	(1405, 8164, 'AUD.POINT_CODE'),
	(1406, 8871, 'AUD.POINT_COMMERCIAL'),
	(1407, 3732, 'AUD.POINT_DIR_ID'),
	(1408, 7162, 'AUD.POINT_ENABLED'),
	(1409, 8048, 'AUD.POINT_ID'),
	(1410, 6616, 'AUD.POINT_INTERNAL'),
	(1411, 8040, 'AUD.POINT_MS_ID'),
	(1412, 3067, 'AUD.POINT_NAME'),
	(1413, 3387, 'AUD.POINT_TYPE_CODE'),
	(1414, 7541, 'AUD.POINT_TYPE_ID'),
	(1415, 8264, 'AUD.POINT_TYPE_NAME'),
	(1416, 9381, 'AUD.POS_CODE'),
	(1417, 8489, 'AUD.POS_DESC'),
	(1418, 4735, 'AUD.POS_NR'),
	(1419, 6851, 'AUD.PPTY_CODE'),
	(1420, 2417, 'AUD.PPTY_ID'),
	(1421, 6146, 'AUD.PPTY_NAME'),
	(1422, 1439, 'AUD.PPTY_NR'),
	(1423, 5665, 'AUD.PPTY_NUMERIC'),
	(1424, 1060, 'AUD.PPTY_TYPE_CODE'),
	(1425, 1981, 'AUD.PPTY_TYPE_ID'),
	(1426, 4678, 'AUD.PPTY_TYPE_NAME'),
	(1427, 6618, 'AUD.PPTY_VALUE'),
	(1428, 8001, 'AUD.PTP_BT'),
	(1429, 4707, 'AUD.PTP_ET'),
	(1430, 3695, 'AUD.PTP_ID'),
	(1431, 1215, 'AUD.RC_CODE'),
	(1432, 8827, 'AUD.RC_ID'),
	(1433, 152, 'AUD.REL_ENABLED'),
	(1434, 3051, 'AUD.REL_ID'),
	(1435, 7589, 'AUD.REL_TYPE_CODE'),
	(1436, 1255, 'AUD.REL_TYPE_ID'),
	(1437, 7467, 'AUD.REL_TYPE_NAME'),
	(1438, 5009, 'AUD.RPAPV_ID'),
	(1439, 2432, 'AUD.RPA_DELAY_DELIVERY'),
	(1440, 6877, 'AUD.RPA_ENABLED'),
	(1441, 9594, 'AUD.RPA_ID'),
	(1442, 6038, 'AUD.RPA_LOG_ENABLED'),
	(1443, 5549, 'AUD.RPA_NAME'),
	(1444, 4130, 'AUD.RPF_CODE'),
	(1445, 638, 'AUD.RPF_ID'),
	(1446, 6160, 'AUD.RPP_CODE'),
	(1447, 3774, 'AUD.RPP_ID'),
	(1448, 2131, 'AUD.RPQC_ASC'),
	(1449, 5032, 'AUD.RPQC_ID'),
	(1450, 2285, 'AUD.RPQC_NR'),
	(1451, 8617, 'AUD.RPQF_ALLOW_EMPTY_VALUES'),
	(1452, 9360, 'AUD.RPQF_DESC'),
	(1453, 5366, 'AUD.RPQF_ESSENTIAL'),
	(1454, 6098, 'AUD.RPQF_ID'),
	(1455, 7871, 'AUD.RPQF_INV'),
	(1456, 3884, 'AUD.RPQF_NR'),
	(1457, 6200, 'AUD.RPQF_VALUE'),
	(1458, 6454, 'AUD.RPQO_CODE'),
	(1459, 1769, 'AUD.RPQO_ID'),
	(1460, 2198, 'AUD.RPQU_ID'),
	(1461, 1583, 'AUD.RPQU_NAME'),
	(1462, 232, 'AUD.RPQ_ADVANCED'),
	(1463, 5299, 'AUD.RPQ_DISTINCT'),
	(1464, 5744, 'AUD.RPQ_ID'),
	(1465, 9254, 'AUD.RPQ_MAXROWS'),
	(1466, 8060, 'AUD.RPQ_NAME'),
	(1467, 2368, 'AUD.RPQ_SLC'),
	(1468, 2832, 'AUD.RPTY_ID'),
	(1469, 7387, 'AUD.RPTY_NAME'),
	(1470, 3944, 'AUD.CH_GRP'),
	(1471, 6644, 'AUD.CH_PNT'),
	(1472, 6891, 'AUD.CH_STEADY'),
	(1473, 7108, 'AUD.COEF'),
	(1474, 3065, 'AUD.COLUMN_NAME'),
	(1475, 5010, 'AUD.COMP_DIR_ID'),
	(1476, 1288, 'AUD.COMP_EC_ID'),
	(1477, 3539, 'AUD.COMP_ID'),
	(1478, 1799, 'AUD.COMP_MS_ID'),
	(1479, 806, 'AUD.CONST_VAL'),
	(1480, 9537, 'AUD.CONT_DIR_ID'),
	(1481, 9022, 'AUD.CONT_EC_ID'),
	(1482, 9964, 'AUD.CONT_ID'),
	(1483, 3864, 'AUD.CONT_MS_ID'),
	(1484, 5990, 'AUD.COSTA_CODE'),
	(1485, 3109, 'AUD.COSTA_ID'),
	(1486, 8366, 'AUD.CVAL'),
	(1487, 9262, 'AUD.DATA_TYPE'),
	(1488, 3786, 'AUD.DA_DESC'),
	(1489, 9362, 'AUD.DBU'),
	(1490, 1517, 'AUD.DB_TIME'),
	(1491, 4983, 'AUD.DC_ENABLED'),
	(1492, 444, 'AUD.DC_ID'),
	(1493, 6642, 'AUD.DC_NAME'),
	(1494, 2689, 'AUD.DD'),
	(1495, 3819, 'AUD.DEVDP_ID'),
	(1496, 5187, 'AUD.DEV_DP_BT'),
	(1497, 2502, 'AUD.DEV_DP_ET'),
	(1498, 7204, 'AUD.DEV_ID'),
	(1499, 9505, 'AUD.DEV_NUMBER'),
	(1500, 3138, 'AUD.DEV_TYPE_ID'),
	(1501, 3804, 'AUD.DEV_TYPE_NAME'),
	(1502, 4217, 'AUD.DIR_CODE'),
	(1503, 1196, 'AUD.DIR_ID'),
	(1504, 7667, 'AUD.DI_ENABLED'),
	(1505, 5746, 'AUD.DI_ID'),
	(1506, 3057, 'AUD.DL_TYPE_ID'),
	(1507, 585, 'AUD.DL_TYPE_NAME'),
	(1508, 7330, 'AUD.DPR_ID'),
	(1509, 2151, 'AUD.DPR_NAME'),
	(1510, 5812, 'AUD.DP_CODE'),
	(1511, 6857, 'AUD.DP_DELETED'),
	(1512, 9606, 'AUD.DP_ENABLED'),
	(1513, 8640, 'AUD.DP_ID'),
	(1514, 8469, 'AUD.DP_NAME'),
	(1515, 6360, 'AUD.DP_TYPE_ID'),
	(1516, 8221, 'AUD.DP_TYPE_NAME'),
	(1517, 869, 'AUD.DS_CODE'),
	(1518, 6212, 'AUD.DS_ENABLED'),
	(1519, 8514, 'AUD.DS_EVENT_LOG'),
	(1520, 2549, 'AUD.DS_ID'),
	(1521, 8717, 'AUD.DS_IGNORED'),
	(1522, 623, 'AUD.DS_NAME'),
	(1523, 5773, 'AUD.DS_RT'),
	(1524, 7953, 'AUD.DS_RT_ENABLED'),
	(1525, 6005, 'AUD.DS_T'),
	(1526, 9206, 'AUD.DS_V'),
	(1527, 707, 'AUD.DU_CNT'),
	(1528, 2045, 'AUD.DU_DPT'),
	(1529, 5953, 'AUD.DU_DSC'),
	(1530, 7155, 'AUD.DU_GRP'),
	(1531, 8580, 'AUD.DU_PNT'),
	(1532, 7249, 'AUD.DU_STEADY'),
	(1533, 4966, 'AUD.ECP_CODE'),
	(1534, 8258, 'AUD.ECP_ID'),
	(1535, 3434, 'AUD.ECP_NAME'),
	(1536, 9339, 'AUD.EC_CODE'),
	(1537, 6218, 'AUD.EC_ID'),
	(1538, 5296, 'AUD.EC_IN'),
	(1539, 5488, 'AUD.EC_NAME'),
	(1540, 3050, 'AUD.EDD'),
	(1541, 1789, 'AUD.EHH'),
	(1542, 6681, 'AUD.ELSE_TFF_ID'),
	(1543, 7777, 'AUD.EMM'),
	(1544, 8762, 'AUD.ENUM_CODE'),
	(1545, 2090, 'AUD.ENUM_DATA_NR'),
	(1546, 3585, 'AUD.ENUM_ID'),
	(1547, 8377, 'AUD.ENUM_NAME'),
	(1548, 8204, 'AUD.ENUM_TYPE_CODE'),
	(1549, 6197, 'AUD.ENUM_TYPE_ID'),
	(1550, 6819, 'AUD.ENUM_TYPE_NAME'),
	(1551, 7451, 'AUD.ENUM_VALUE'),
	(1552, 390, 'AUD.ENUM_VALUE_DESC'),
	(1553, 6402, 'AUD.EPTY_CODE'),
	(1554, 6175, 'AUD.EPTY_ID'),
	(1555, 3488, 'AUD.EPTY_NAME'),
	(1556, 1229, 'AUD.EPTY_NR'),
	(1557, 4755, 'AUD.EPTY_NUMERIC'),
	(1558, 1735, 'AUD.EPTY_TYPE_CODE'),
	(1559, 1660, 'AUD.EPTY_TYPE_ID'),
	(1560, 4051, 'AUD.EPTY_TYPE_NAME'),
	(1561, 6131, 'AUD.EPTY_VALUE'),
	(1562, 2004, 'AUD.ET'),
	(1563, 7267, 'AUD.EVAC_INV'),
	(1564, 1586, 'AUD.EVAC_NR'),
	(1565, 2107, 'AUD.EVAC_TYPE_ID'),
	(1566, 9692, 'AUD.EVAC_TYPE_NAME'),
	(1567, 475, 'AUD.EVA_BLOCK'),
	(1568, 4340, 'AUD.EVA_BLOCKED_UNTIL'),
	(1569, 94, 'AUD.EVA_BLOCK_DURATION'),
	(1570, 1046, 'AUD.EVA_CODE'),
	(1571, 4202, 'AUD.EVA_ENABLED'),
	(1572, 3549, 'AUD.EVA_ID'),
	(1573, 3165, 'AUD.EVA_IMMEDIATE'),
	(1574, 2109, 'AUD.EVA_NAME'),
	(1575, 7890, 'AUD.EVA_TYPE_ID'),
	(1576, 1159, 'AUD.EVA_TYPE_NAME'),
	(1577, 6762, 'AUD.EVC_NAME'),
	(1578, 4761, 'AUD.EXPIRATION_INT_VALUE'),
	(1579, 9499, 'AUD.EXPL_START'),
	(1580, 608, 'AUD.FFP_CODE'),
	(1581, 3212, 'AUD.FFP_DATA_ID'),
	(1582, 8713, 'AUD.FFP_ID'),
	(1583, 3644, 'AUD.FFP_NAME'),
	(1584, 5856, 'AUD.FFP_TYPE'),
	(1585, 549, 'AUD.FFP_VAL_KEY_1'),
	(1586, 6068, 'AUD.FFP_VAL_KEY_2'),
	(1587, 6417, 'AUD.FFP_VAL_KEY_3'),
	(1588, 5266, 'AUD.FFP_VAL_ROW_NUM'),
	(1589, 3148, 'AUD.FFP_VT_ID'),
	(1590, 143, 'AUD.FIXED_TFF_ID'),
	(1591, 5283, 'AUD.FOLDER'),
	(1592, 6927, 'AUD.FORCED'),
	(1593, 4650, 'AUD.FORM_IF_EMPTY'),
	(1594, 1217, 'AUD.FPTY_CODE'),
	(1595, 3317, 'AUD.FPTY_ID'),
	(1596, 1935, 'AUD.FPTY_VALUE'),
	(1597, 2533, 'AUD.FP_CODE'),
	(1598, 9738, 'AUD.FP_ID'),
	(1599, 3465, 'AUD.FP_NAME'),
	(1600, 465, 'AUD.FP_NR'),
	(1601, 893, 'AUD.GMOD_CODE'),
	(1602, 8756, 'AUD.GMOD_DATA_NR'),
	(1603, 9108, 'AUD.GMOD_EU_CODE'),
	(1604, 1413, 'AUD.GMOD_EU_CODE_USAGE'),
	(1605, 2254, 'AUD.GMOD_ID'),
	(1606, 7501, 'AUD.GMOD_NAME'),
	(1607, 669, 'AUD.GPRC'),
	(1608, 7852, 'AUD.GPTY_CODE'),
	(1609, 4897, 'AUD.GPTY_ID'),
	(1610, 1903, 'AUD.GPTY_NAME'),
	(1611, 86, 'AUD.GPTY_NR'),
	(1612, 6534, 'AUD.GPTY_NUMERIC'),
	(1613, 2066, 'AUD.GPTY_TYPE_CODE'),
	(1614, 8617, 'AUD.GPTY_TYPE_ID'),
	(1615, 9959, 'AUD.GPTY_TYPE_NAME'),
	(1616, 7645, 'AUD.GPTY_VALUE'),
	(1617, 8076, 'AUD.GRC_BT'),
	(1618, 9448, 'AUD.GRC_DESC'),
	(1619, 2763, 'AUD.GRC_ET'),
	(1620, 3170, 'AUD.GRC_NR'),
	(1621, 2289, 'AUD.GRP_BT'),
	(1622, 9812, 'AUD.GRP_DESC'),
	(1623, 5504, 'AUD.GRP_ET'),
	(1624, 4001, 'AUD.GRP_NR'),
	(1625, 4082, 'AUD.GR_CODE'),
	(1626, 5142, 'AUD.GR_DIR_ID'),
	(1627, 3515, 'AUD.GR_EC_ID'),
	(1628, 6402, 'AUD.GR_ID'),
	(1629, 4401, 'AUD.GR_MS_ID'),
	(1630, 6745, 'AUD.GR_NAME'),
	(1631, 2384, 'AUD.GR_TYPE_CODE'),
	(1632, 7118, 'AUD.GR_TYPE_ID'),
	(1633, 7087, 'AUD.GR_TYPE_NAME'),
	(1634, 4917, 'AUD.GTP_BT'),
	(1635, 3659, 'AUD.GTP_ET'),
	(1636, 5348, 'AUD.GTP_ID'),
	(1637, 4616, 'AUD.HDAY'),
	(1638, 636, 'AUD.HH1'),
	(1639, 7660, 'AUD.HH10'),
	(1640, 5419, 'AUD.HH11'),
	(1641, 8982, 'AUD.HH12'),
	(1642, 5245, 'AUD.HH13'),
	(1643, 5084, 'AUD.HH14'),
	(1644, 9087, 'AUD.HH15'),
	(1645, 5645, 'AUD.HH16'),
	(1646, 661, 'AUD.HH17'),
	(1647, 2605, 'AUD.HH18'),
	(1648, 8670, 'AUD.HH19'),
	(1649, 4721, 'AUD.HH2'),
	(1650, 5213, 'AUD.HH20'),
	(1651, 6789, 'AUD.HH21'),
	(1652, 8922, 'AUD.HH22'),
	(1653, 9257, 'AUD.HH23'),
	(1654, 5046, 'AUD.HH24'),
	(1655, 5431, 'AUD.HH3'),
	(1656, 3834, 'AUD.HH4'),
	(1657, 3834, 'AUD.HH5'),
	(1658, 7645, 'AUD.HH6'),
	(1659, 7468, 'AUD.HH7'),
	(1660, 7658, 'AUD.HH8'),
	(1661, 8647, 'AUD.HH9'),
	(1662, 9091, 'AUD.HH_SPECIFIC'),
	(1663, 619, 'AUD.HLD_ID'),
	(1664, 3389, 'AUD.HLD_NAME'),
	(1665, 9921, 'AUD.IGNORE_GROUP_VALUE'),
	(1666, 7651, 'AUD.IGNORE_READ_DATA'),
	(1667, 1783, 'AUD.IGNORE_SE_AB'),
	(1668, 5615, 'AUD.XPTY_VALUE'),
	(1669, 740, 'AUD.DP_CODE.SRC_NAME.PH_NAME.POINT_CODE.SHEAF_NAME'),
	(1670, 6906, 'AUD.INHERIT_CN.DS_CODE'),
	(1671, 5177, 'AUD.DP_CODE.SRC_NAME.POINT_CODE.ML_NAME'),
	(1672, 5445, 'AUD.POINT_CODE.ML_NAME'),
	(1673, 7480, 'AUD.METER_NUMBER.METER_TYPE_NAME'),
	(1674, 9081, 'AUD.POINT_CODE.ML_NAME.EC_IN.GPRC'),
	(1675, 8354, 'AUD.ACT_NUMBER.ACT_MONTH'),
	(1676, 4062, 'AUD.POINT_CODE.SHEAF_NAME'),
	(1677, 5683, 'AUD.DP_CODE.SHEAF_NAME'),
	(1678, 3916, 'AUD.SRC_NAME.PH_NAME'),
	(1679, 3873, 'AUD.INHERIT_CN.GR_CODE'),
	(1680, 5597, 'AUD.DEV_NUMBER.DEV_TYPE_NAME'),
	(1681, 2877, 'AUD.SRC_TMPL_CODE.ML_NAME'),
	(1682, 1800, 'AUD.DP_CODE.SRC_NAME.POINT_CODE'),
	(1683, 7176, 'AUD.INHERIT_CN.POINT_CODE'),
	(1684, 8315, 'AUD.DP_CODE.SRC_NAME.PH_NAME'),
	(1685, 9325, 'AUD.DP_CODE.SRC_NAME.DS_CODE'),
	(1686, 109, 'AUD.COLUMN_NAME.RPQO_CODE'),
	(1687, 1232, 'AUD.DP_CODE.SRC_NAME.PH_NAME.SHEAF_NAME'),
	(1688, 3093, 'AUD.DP_CODE.SRC_NAME.PH_NAME.DS_CODE'),
	(1689, 2386, 'AUD.DP_CODE.SRC_NAME'),
	(1690, 8870, 'AUD.POINT_CODE.REL_TYPE_CODE'),
	(1691, 2373, 'STORE_PL.UNKNOWN_SF'),
	(1692, 2396, 'AUD.AGGS_TYPE_NAME'),
	(1693, 8262, 'AUD.AGGF_NAME'),
	(1694, 5834, 'AUD.AGGS_NAME'),
	(1695, 5470, 'PL_NOT_FOUND'),
	(1696, 7084, 'CP.CP_NOTE.A'),
	(1697, 8153, 'CP.CP_NOTE.B'),
	(1698, 4164, 'CP.CP_NOTE.C'),
	(1699, 1184, 'CP.CP_NOTE.D'),
	(1700, 1514, 'CP.CP_NOTE.E'),
	(1701, 6609, 'CP.CP_NOTE.F'),
	(1702, 8397, 'CP.CP_NOTE.H'),
	(1703, 7443, 'CP.CP_NOTE.G'),
	(1704, 2490, 'CP.CP_NOTE.I'),
	(1705, 7697, 'CP.CP_NOTE.K'),
	(1706, 2691, 'CP.CP_NOTE.J'),
	(1707, 7647, 'CP.PRD_NO_POINTS'),
	(1708, 4573, 'CP.ST_SE_INT_FP_IS_EMPTY'),
	(1709, 1173, 'CP.POINT_HAS_NO_FP'),
	(1710, 6201, 'CP.PRD_STATS'),
	(1711, 3491, 'CP.POINT_DISABLED'),
	(1712, 4519, 'CP.NO_ATTEMPT_TO_CLOSE_THE_POINT'),
	(1713, 3501, 'CP.ST_SE_IS_EMPTY'),
	(1714, 9439, 'AUD.DSTATUS'),
	(1715, 8280, 'AUD.RP_FORMULA'),
	(1716, 2797, 'AUD.SBST_ALTER_READ_TIME'),
	(1717, 4918, 'AUD.SBST_FLN'),
	(1718, 2466, 'AUD.SBST_OFFSET'),
	(1719, 7047, 'AUD.SBST_OFFSET_PER_ID'),
	(1720, 1, 'AUD.SBST_RADIUS'),
	(1721, 4232, 'AUD.SBST_RADIUS_PER_ID'),
	(1722, 1843, 'AUD.TSTATUS'),
	(1723, 5485, 'SRC_LPTY'),
	(1724, 9961, 'SP_LPTY'),
	(1725, 3622, 'SE_LPTY'),
	(1726, 5297, 'SE_SHEAF_LPTY'),
	(1727, 6167, 'SE_SHEAF'),
	(1728, 9034, 'SEP_SHEAF'),
	(1729, 8370, 'SEP_SHEAF_RC'),
	(1730, 8434, 'DI_SHEAF'),
	(1731, 6604, 'GRANT_NOT_FOUND_FOR_POINTS'),
	(1732, 1140, 'GRANT_NOT_FOUND_FOR_SOURCE'),
	(1733, 9769, 'SRC_TYPE_MOD.UNKNOWN_MOD'),
	(1734, 4383, 'SRC_TYPE_MOD.OTHER_MOD'),
	(1735, 9994, 'DEVICE_PARAMETER_CHANGE'),
	(1736, 8750, 'AUTH_DEVICE_PARAMETER_CHANGE'),
	(1737, 8620, 'AUTH_METER_PARAMETER_CHANGE'),
	(1738, 3944, 'SRC_TYPE_MOD.VERSION_FIRST'),
	(1739, 6661, 'SE_DP_SHEAF'),
	(1740, 7410, 'SE_DP_SHEAF_LPTY'),
	(1741, 2190, 'UNKNOWN_ENUM_TYPE_CODE'),
	(1742, 6494, 'UNKNOWN_ENUM_CODE'),
	(1743, 9951, 'UNKNOWN_PPTY_TYPE_CODE'),
	(1744, 7673, 'UNKNOWN_MPTY_TYPE_CODE'),
	(1745, 6615, 'UNKNOWN_GPTY_TYPE_CODE'),
	(1746, 2955, 'CHECK_LOCKED_USERS'),
	(1747, 71, 'STPROXY.UNKNOWN_TID_CONN_OPEN_RCVD'),
	(1748, 9713, 'STPROXY.UNKNOWN_TID_CONN_CLOSE_RCVD'),
	(1749, 185, 'STPROXY.TID_CONN_OPEN_RCVD'),
	(1750, 8170, 'STPROXY.TID_CONN_CLOSE_RCVD'),
	(1751, 326, 'SEP_DP_SHEAF'),
	(1752, 3171, 'SEP_DP_SHEAF_RC'),
	(1753, 9443, 'DI_DP_SHEAF'),
	(1754, 7539, 'CP.CP_NOTE.L0'),
	(1755, 7633, 'CP.CP_NOTE.L1'),
	(1756, 8431, 'CP.CP_NOTE.M0'),
	(1757, 1906, 'CP.CP_NOTE.M1'),
	(1758, 2455, 'STC_TYPE_TMPL_MISMATCH'),
	(1759, 9696, 'SOURCES_WITH_DIFFERENT_DIR'),
	(1760, 9482, 'NOT_CHANGED'),
	(1761, 3934, 'NO_DOUBT_DATA_FOUND'),
	(1762, 4958, 'CP.CP_NOTE.N'),
	(1763, 7849, 'CP.CP_NOTE.P'),
	(1764, 1521, 'CP.CP_NOTE.Q'),
	(1765, 2781, 'READ_UTL.OLD_REMOVED'),
	(1766, 6671, 'ACT_360.MEASURE_NOT_FOUND'),
	(1767, 9559, 'ACT_360.MONTH_ACT_EXISTS'),
	(1768, 7597, 'ACT_360.NO_ATTEMPT'),
	(1769, 2116, 'ACT_360.DAYS_CLOSED'),
	(1770, 9873, 'ACT_360.MT_MISSING'),
	(1771, 3409, 'ACT_360.SHORT'),
	(1772, 9467, 'ACT_360.NO_HOUR'),
	(1773, 5500, 'SMS_LIMIT_REACHED'),
	(1774, 8161, 'SMS_BEYOND_LIMIT'),
	(1775, 9323, 'XO_EXPORT_FORM/ELEMENT'),
	(1776, 6609, 'AUD_DATA_DEFAULT_CAPTION'),
	(1777, 9912, 'CP.CP_NOTE.R'),
	(1778, 4424, 'DS.DS_BINARY_CANNOT_BE_SET'),
	(1779, 1714, 'AUD.RPTY_VALUE'),
	(1780, 4163, 'AUD.RP_DESCRIPTION'),
	(1781, 242, 'AUD.RP_ID'),
	(1782, 8190, 'AUD.RP_LOG_ENABLED'),
	(1783, 9910, 'AUD.RP_NAME'),
	(1784, 5800, 'AUD.RP_PUBLIC'),
	(1785, 4613, 'AUD.RP_TYPE_ID'),
	(1786, 3219, 'AUD.RP_TYPE_NAME'),
	(1787, 885, 'AUD.RTP_CODE'),
	(1788, 5053, 'AUD.RTP_ID'),
	(1789, 5603, 'AUD.RTP_INT_VALUE'),
	(1790, 1898, 'AUD.RTP_ML_ENABLED'),
	(1791, 767, 'AUD.RTP_NAME'),
	(1792, 6284, 'AUD.SAMD_COMMON'),
	(1793, 8287, 'AUD.SAMD_ID'),
	(1794, 4716, 'AUD.SAMD_NAME'),
	(1795, 3012, 'AUD.SAMP_ID'),
	(1796, 4474, 'AUD.SAMP_INT_VALUE'),
	(1797, 9136, 'AUD.SAMP_PER_ID'),
	(1798, 5434, 'AUD.SAMU_DEPTH'),
	(1799, 9252, 'AUD.SAMU_DEPTH_PER_ID'),
	(1800, 4522, 'AUD.SAMU_ENABLED'),
	(1801, 1818, 'AUD.SAMU_LAG'),
	(1802, 6157, 'AUD.SAMU_LAG_PER_ID'),
	(1803, 4216, 'AUD.SAMU_TYPE_ID'),
	(1804, 9845, 'AUD.SAMW_COMMON'),
	(1805, 2630, 'AUD.SAMW_ID'),
	(1806, 847, 'AUD.SAMW_NAME'),
	(1807, 9477, 'AUD.SAMW_TYPE_ID'),
	(1808, 2793, 'AUD.SAM_CODE'),
	(1809, 6331, 'AUD.SAM_CYCLIC'),
	(1810, 7044, 'AUD.SAM_ID'),
	(1811, 539, 'AUD.SAM_NAME'),
	(1812, 5311, 'AUD.SAM_TYPE_ID'),
	(1813, 2817, 'AUD.SAM_TYPE_NAME'),
	(1814, 5863, 'AUD.SAM_V'),
	(1815, 3969, 'AUD.SBST_A'),
	(1816, 2234, 'AUD.SBST_AB'),
	(1817, 6106, 'AUD.SBST_B'),
	(1818, 9207, 'AUD.SBST_ENABLED'),
	(1819, 4733, 'AUD.SBST_IMPROVABLE'),
	(1820, 7226, 'AUD.SBST_LAG'),
	(1821, 129, 'AUD.SBST_PL_ID'),
	(1822, 9697, 'AUD.SBST_SF'),
	(1823, 6056, 'AUD.SCHI_NR'),
	(1824, 597, 'AUD.SCH_ID'),
	(1825, 6240, 'AUD.SCH_INT_ID'),
	(1826, 4591, 'AUD.SCH_INT_NAME'),
	(1827, 9976, 'AUD.SCH_INT_VALUE'),
	(1828, 16, 'AUD.SCH_NAME'),
	(1829, 7773, 'AUD.SCH_REPEAT'),
	(1830, 7880, 'AUD.SCH_REPEAT_TIMES'),
	(1831, 5448, 'AUD.SEP_ENABLED'),
	(1832, 285, 'AUD.SEP_ID'),
	(1833, 3338, 'AUD.SEP_RC_DEPTH'),
	(1834, 7246, 'AUD.SEP_RC_LAG'),
	(1835, 1926, 'AUD.SE_A'),
	(1836, 6595, 'AUD.SE_AB'),
	(1837, 9675, 'AUD.SE_B'),
	(1838, 7788, 'AUD.SE_ENABLED'),
	(1839, 4493, 'AUD.SE_FORCED'),
	(1840, 2747, 'AUD.SE_H'),
	(1841, 8078, 'AUD.SE_H_BOUND'),
	(1842, 2035, 'AUD.SE_H_DEPTH'),
	(1843, 3199, 'AUD.SE_H_PER_ID'),
	(1844, 598, 'AUD.SE_H_RESTORE_DEPTH'),
	(1845, 9114, 'AUD.SE_H_RESTORE_PER_ID'),
	(1846, 5480, 'AUD.SE_ID'),
	(1847, 8227, 'AUD.SE_TMPL_ID'),
	(1848, 4745, 'AUD.SE_TMPL_SHEAF_ID'),
	(1849, 6627, 'AUD.SHEAF_ID'),
	(1850, 1988, 'AUD.SHEAF_NAME'),
	(1851, 1432, 'AUD.SI_CNT'),
	(1852, 1771, 'AUD.SI_DPT'),
	(1853, 4341, 'AUD.SI_DSC'),
	(1854, 5268, 'AUD.SI_GRP'),
	(1855, 7515, 'AUD.SI_PNT'),
	(1856, 2751, 'AUD.SPTY_CODE'),
	(1857, 4383, 'AUD.SPTY_DEFAULT'),
	(1858, 6524, 'AUD.SPTY_ID'),
	(1859, 3879, 'AUD.SPTY_NAME'),
	(1860, 7328, 'AUD.SPTY_NR'),
	(1861, 3444, 'AUD.SPTY_NUMERIC'),
	(1862, 942, 'AUD.SPTY_TYPE_ID'),
	(1863, 2229, 'AUD.SPTY_VALUE'),
	(1864, 5860, 'AUD.SP_ID'),
	(1865, 878, 'AUD.SRC_BT'),
	(1866, 5834, 'AUD.SRC_ENABLED'),
	(1867, 7677, 'AUD.SRC_ET'),
	(1868, 5397, 'AUD.SRC_ID'),
	(1869, 4884, 'AUD.SRC_NAME'),
	(1870, 4502, 'AUD.SRC_NUMBER'),
	(1871, 287, 'AUD.SRC_SAVE_STATISTICS'),
	(1872, 3793, 'AUD.SRC_TMPL_CODE'),
	(1873, 911, 'AUD.SRC_TMPL_ID'),
	(1874, 2685, 'AUD.SRC_TMPL_MULTIPOINT'),
	(1875, 2719, 'AUD.SRC_TMPL_NAME'),
	(1876, 5352, 'AUD.SRC_TYPE_CODE'),
	(1877, 1716, 'AUD.SRC_TYPE_ID'),
	(1878, 3597, 'AUD.SRC_TZ_DST_USED'),
	(1879, 5882, 'AUD.STEADY_TYPE_ID'),
	(1880, 9709, 'AUD.STORABLE'),
	(1881, 4525, 'AUD.TABLE_NAME'),
	(1882, 5176, 'AUD.TFF_COLOR'),
	(1883, 6559, 'AUD.TFF_ENABLED'),
	(1884, 5392, 'AUD.TFF_ID'),
	(1885, 3185, 'AUD.TFF_NAME'),
	(1886, 4419, 'AUD.TPP_ID'),
	(1887, 2247, 'AUD.TP_ID'),
	(1888, 4625, 'AUD.TP_NAME'),
	(1889, 8152, 'AUD.TS_ID'),
	(1890, 9848, 'AUD.TS_NAME'),
	(1891, 769, 'AUD.TZ_CODE'),
	(1892, 8861, 'AUD.TZ_ID'),
	(1893, 1411, 'AUD.UG_ID'),
	(1894, 9185, 'AUD.UG_NAME'),
	(1895, 5420, 'AUD.USER_COMPANY'),
	(1896, 216, 'AUD.USER_DEPARTMENT'),
	(1897, 7099, 'AUD.USER_EMAIL'),
	(1898, 2195, 'AUD.USER_ENABLED'),
	(1899, 2764, 'AUD.USER_GSM'),
	(1900, 4457, 'AUD.USER_ID'),
	(1901, 1667, 'AUD.USER_LOCATION'),
	(1902, 3503, 'AUD.USER_NAME'),
	(1903, 5929, 'AUD.USER_PHONE'),
	(1904, 8142, 'AUD.USE_CONST_VAL'),
	(1905, 6449, 'AUD.VERGE_CODE'),
	(1906, 3398, 'AUD.VERGE_ID'),
	(1907, 8765, 'AUD.VERGE_NAME'),
	(1908, 3495, 'AUD.VISIBLE'),
	(1909, 1967, 'AUD.VP_BIAS'),
	(1910, 8771, 'AUD.VP_CODE'),
	(1911, 9997, 'AUD.VP_ID'),
	(1912, 2336, 'AUD.VP_NAME'),
	(1913, 1524, 'AUD.VP_NR'),
	(1914, 6926, 'AUD.VP_SEPARATE_TFF'),
	(1915, 3570, 'AUD.VP_SMALLEST_INTERVAL'),
	(1916, 3329, 'AUD.WD'),
	(1917, 6119, 'AUD.WD1'),
	(1918, 5825, 'AUD.WD2'),
	(1919, 6244, 'AUD.WD3'),
	(1920, 8807, 'AUD.WD4'),
	(1921, 6053, 'AUD.WD5'),
	(1922, 5511, 'AUD.WD6'),
	(1923, 3829, 'AUD.WD7'),
	(1924, 1660, 'AUD.WD8'),
	(1925, 18, 'AUD.WD_SPECIFIC'),
	(1926, 4748, 'AUD.WEEK'),
	(1927, 1632, 'AUD.WPR_ID'),
	(1928, 2633, 'AUD.WPR_NAME'),
	(1929, 2537, 'AUD.XA_ENABLED'),
	(1930, 1445, 'AUD.XA_ID'),
	(1931, 7694, 'AUD.XA_NAME'),
	(1932, 9083, 'AUD.XE_ID'),
	(1933, 6839, 'AUD.XE_NAME'),
	(1934, 7231, 'AUD.XFAU_CODE'),
	(1935, 7968, 'AUD.XFAU_CODE2'),
	(1936, 1712, 'AUD.XFAU_ENABLED'),
	(1937, 5155, 'AUD.XFAU_ID'),
	(1938, 109, 'AUD.XFAU_NAME'),
	(1939, 250, 'AUD.XFAU_NAME2'),
	(1940, 3628, 'AUD.XFAU_TYPE_ID'),
	(1941, 3251, 'AUD.XFAU_TYPE_NAME'),
	(1942, 5222, 'AUD.XFA_CODE'),
	(1943, 6115, 'AUD.XFA_ENABLED'),
	(1944, 8534, 'AUD.XFA_ID'),
	(1945, 9217, 'AUD.XFA_NAME'),
	(1946, 8559, 'AUD.XFA_TZ'),
	(1947, 4971, 'AUD.XFA_TZ_DST_USED'),
	(1948, 3171, 'AUD.XFE_ENABLED'),
	(1949, 439, 'AUD.XFE_ID'),
	(1950, 4638, 'AUD.XFE_INFO'),
	(1951, 7361, 'AUD.XF_ENABLED'),
	(1952, 8222, 'AUD.XF_ID'),
	(1953, 854, 'AUD.XF_IMPORT'),
	(1954, 2045, 'AUD.XF_NAME'),
	(1955, 6617, 'AUD.XF_RC_DEPTH'),
	(1956, 2046, 'AUD.XF_RC_LAG'),
	(1957, 2943, 'AUD.XF_TYPE_CODE'),
	(1958, 2589, 'AUD.XF_TYPE_ID'),
	(1959, 9968, 'AUD.XO_BT'),
	(1960, 9174, 'AUD.XO_ET'),
	(1961, 3162, 'AUD.XPTY_CODE'),
	(1962, 5110, 'AUD.XPTY_ID'),
	(1963, 7899, 'STORE_PW.SETTING_RECEIVED'),
	(1964, 422, 'STORE_DW.SETTING_RECEIVED'),
	(1965, 9647, 'RODO.SETTING.INDEX_OUT_OF_BOUNDS'),
	(1966, 4335, 'ACTION_61968_1'),
	(1967, 2880, 'REPORT_GENERATED'),
	(1968, 2212, 'FOR'),
	(1969, 754, 'INIT_GEN_POINT.ALL_PERIODS_CLOSE'),
	(1970, 3376, 'INIT_GEN_POINT.PART_PERIODS_CLOSE'),
	(1971, 2421, 'BACKGROUND_TASK_NOT_EXECUTING'),
	(1972, 1663, 'SRC_TMPL_MISM_SINGLE'),
	(1973, 5664, 'SRC_TMPL_MISM_MULTI'),
	(1974, 5954, 'EV_REGISTRATION'),
	(1975, 9867, 'LOG.WRITE_FIB'),
	(1976, 9206, 'DUPLICATE_IMPORT_FORMS'),
	(1977, 8173, 'SAM_TMPL_CHANGED'),
	(1978, 1885, 'SAM_TMPL_AI_CHANGED'),
	(1979, 4647, 'RELATED_SAM_FOUND'),
	(1980, 5321, 'DS.DS_BINARY_VIOLATED'),
	(1981, 7242, 'BYP.DS_BINARY'),
	(1982, 3678, 'STIPLISTENER.STORE_PA.UNKNOWN'),
	(1983, 6828, 'STIPLISTENER.STORE_PA.NO_MOU'),
	(1984, 4359, 'STIPLISTENER.STORE_PA.NO_16'),
	(1985, 8894, 'STIPLISTENER.STORE_PA.NEW_METER'),
	(1986, 816, 'STIPLISTENER.STORE_PA.METER_REGISTERED'),
	(1987, 6946, 'STIPLISTENER.STORE_PA.C_NEW_METER'),
	(1988, 9193, 'STIPLISTENER.STORE_PA.C_METER_REGISTERED'),
	(1989, 3746, 'STIPLISTENER.STORE_PA.R_NEW_METER'),
	(1990, 8049, 'STIPLISTENER.STORE_PA.R_METER_REGISTERED'),
	(1991, 9936, 'FULL_METER_CONFIG_SAVE'),
	(1992, 658, 'POINT_READ_CONFIG_FILL'),
	(1993, 1526, 'EVAC.NVAL1.UNDEFINED'),
	(1994, 9828, 'SRC_RULE_DP_NOT_FOUND'),
	(1995, 7295, 'SRC_RULE_SRC_TMPL_NOT_FOUND'),
	(1996, 7752, 'SRC_RULE_SRC_ALREADY_EXISTS'),
	(1997, 4068, 'INCOMPLETE_JOURNAL_METER_CONFIG_CHECK_DECLINED'),
	(1998, 9357, 'SOME_RECORDS_NOT_FOUND'),
	(1999, 7743, 'HAS_PL_CUSTOM'),
	(2000, 4861, 'SRC_FROM_TMPL_ARRAY'),
	(2001, 6762, 'BLOCK_PL'),
	(2002, 2444, 'LOG.WRITE_POINT_RELAY'),
	(2003, 7787, 'LOG.WRITE_POINT_TIME'),
	(2004, 5006, 'LOG.WRITE_POINT_TIME_CORRECTION'),
	(2005, 7405, 'LOG.WRITE_POINT_CONFIGURATION'),
	(2006, 6838, 'LOG.WRITE_DP_TIME'),
	(2007, 4858, 'LOG.WRITE_DP_TIME_CORRECTION'),
	(2008, 8541, 'LOG.WRITE_DP_CONFIGURATION'),
	(2009, 4721, 'STIPLISTENER.ESMON.UNKNOWN'),
	(2010, 2538, 'STIPLISTENER.ESMON.KNOWN'),
	(2011, 8999, 'METER_CONFIGURATION_DATE_UPDATED'),
	(2012, 2870, 'DEVICE_CONFIGURATION_DATE_UPDATED'),
	(2013, 4937, 'SDI_NOT_FOUND'),
	(2014, 3961, 'SRC_NOT_FOUND'),
	(2015, 7423, 'ECP_NOT_UNIQUE'),
	(2016, 5642, 'PARAMETRIZATION_NOT_ALLOWED'),
	(2017, 2753, 'GENERATED_DATA'),
	(2018, 7212, 'IMPORTED_DATA'),
	(2019, 529, 'EMCOS'),
	(2020, 908, 'SUPERVISOR'),
	(2021, 4991, 'MDC'),
	(2022, 831, 'MCL'),
	(2023, 8097, 'VALSENA'),
	(2024, 9146, 'SICON 200'),
	(2025, 6545, 'Koncentratoriuje'),
	(2026, 4412, 'Skaitiklyje'),
	(2027, 8852, 'GENERATED_BY_ORACLE'),
	(2028, 4266, 'IMPORTED'),
	(2029, 4771, 'Pagrindinis kontūras'),
	(2030, 6367, 'Rezervinis kontūras'),
	(2031, 3675, 'INLET'),
	(2032, 3670, 'OUTLET'),
	(2033, 7686, 'OWN'),
	(2034, 2423, 'GENERATION'),
	(2035, 1042, 'BinaryXML'),
	(2036, 3457, 'Language'),
	(2037, 7483, 'PointDataRead'),
	(2038, 1555, 'Manufacturer_MBus'),
	(2039, 3233, 'W10548E'),
	(2040, 2241, 'W10549E'),
	(2041, 1776, 'W10550E'),
	(2042, 8426, 'W10551E'),
	(2043, 9328, 'W10554E'),
	(2044, 570, 'W10562E'),
	(2045, 2815, 'Disp'),
	(2046, 5849, 'Protocol_MultiCal'),
	(2047, 9530, 'UseTransport'),
	(2048, 2669, 'Protocol_DK'),
	(2049, 6443, 'Protocol_EKOM'),
	(2050, 1759, 'Protocol_MBus'),
	(2051, 7492, 'DataSheet'),
	(2052, 5283, 'DAYTYPE'),
	(2053, 3375, 'ASKP_DATE_USE'),
	(2054, 7899, 'ASKP_VERSION'),
	(2055, 9779, 'TestMode'),
	(2056, 8849, 'HIDE_1'),
	(2057, 3632, 'W10581E'),
	(2058, 3109, 'Voltage'),
	(2059, 5507, 'OnOff'),
	(2060, 6228, 'MsType'),
	(2061, 6041, 'Protocol'),
	(2062, 6525, 'StopBits'),
	(2063, 4209, 'DataBits'),
	(2064, 7273, 'Parity'),
	(2065, 4639, 'HwHandshake'),
	(2066, 348, 'SwHandshake'),
	(2067, 2076, 'RTSToggle'),
	(2068, 5886, 'BaudRate'),
	(2069, 8803, 'IP_Kind'),
	(2070, 7656, 'TypeCode68'),
	(2071, 8668, 'YesNo'),
	(2072, 5248, 'ABB_TypeCode'),
	(2073, 9673, 'TypeCode69'),
	(2074, 2168, 'TypeCode79'),
	(2075, 2599, 'TypeCode80'),
	(2076, 8301, 'User'),
	(2077, 8511, 'TypeCodeMCL'),
	(2078, 4211, 'Journal_number'),
	(2079, 4979, 'W10299E'),
	(2080, 1231, 'W10300E'),
	(2081, 3054, 'W10301E'),
	(2082, 900, 'W10302E'),
	(2083, 3068, 'W10303E'),
	(2084, 7614, 'W10304E'),
	(2085, 6742, 'W10305E'),
	(2086, 7658, 'W10306E'),
	(2087, 5091, 'W10307E'),
	(2088, 2872, 'W10308E'),
	(2089, 90, 'W10309E'),
	(2090, 6317, 'W10310E'),
	(2091, 1467, 'W10311E'),
	(2092, 1165, 'W10312E'),
	(2093, 4110, 'W10313E'),
	(2094, 2378, 'W10314E'),
	(2095, 2725, 'W10315E'),
	(2096, 7967, 'W10316E'),
	(2097, 9985, 'W10317E'),
	(2098, 7849, 'W10318E'),
	(2099, 9727, 'W10319E'),
	(2100, 197, 'W10320E'),
	(2101, 5576, 'W10321E'),
	(2102, 6724, 'W10322E'),
	(2103, 3220, 'W10323E'),
	(2104, 687, 'W10324E'),
	(2105, 5288, 'W10325E'),
	(2106, 2184, 'W10326E'),
	(2107, 1624, 'W10327E'),
	(2108, 6888, 'W10328E'),
	(2109, 2597, 'W10329E'),
	(2110, 9400, 'W10330E'),
	(2111, 2198, 'W10331E'),
	(2112, 6065, 'W10332E'),
	(2113, 4074, 'W10333E'),
	(2114, 4430, 'W10334E'),
	(2115, 8054, 'W10335E'),
	(2116, 963, 'W10336E'),
	(2117, 7568, 'W10337E'),
	(2118, 7517, 'W10338E'),
	(2119, 1089, 'W10339E'),
	(2120, 6444, 'W10340E'),
	(2121, 48, 'W10341E'),
	(2122, 6865, 'W10342E'),
	(2123, 2163, 'W10343E'),
	(2124, 5187, 'W10344E'),
	(2125, 2447, 'W10345E'),
	(2126, 6838, 'W10346E'),
	(2127, 9165, 'W10347E'),
	(2128, 4153, 'W10348E'),
	(2129, 774, 'W10349E'),
	(2130, 8453, 'W10350E'),
	(2131, 5443, 'W10400E'),
	(2132, 1863, 'W10401E'),
	(2133, 3460, 'W10402E'),
	(2134, 5539, 'W10403E'),
	(2135, 797, 'W10404E'),
	(2136, 5585, 'W10405E'),
	(2137, 4830, 'W10446E'),
	(2138, 97, 'W10447E'),
	(2139, 3965, 'W10450E'),
	(2140, 5699, 'W10451E'),
	(2141, 6563, 'W10452E'),
	(2142, 1950, 'W10454E'),
	(2143, 7916, 'W10455E'),
	(2144, 5072, 'W10456E'),
	(2145, 2486, 'W10457E'),
	(2146, 8194, 'W10458E'),
	(2147, 4717, 'W10459E'),
	(2148, 1218, 'W10460E'),
	(2149, 1634, 'W10461E'),
	(2150, 6193, 'W10465E'),
	(2151, 4723, 'W10466E'),
	(2152, 5492, 'W10467E'),
	(2153, 5337, 'W10468E'),
	(2154, 6891, 'W10469E'),
	(2155, 1866, 'W10470E'),
	(2156, 8477, 'W10471E'),
	(2157, 7817, 'W10472E'),
	(2158, 4673, 'W10473E'),
	(2159, 1963, 'W10477E'),
	(2160, 2838, 'W10478E'),
	(2161, 5846, 'W10481E'),
	(2162, 4102, 'W10482E'),
	(2163, 9686, 'W10483E'),
	(2164, 1434, 'W10484E'),
	(2165, 1109, 'W10485E'),
	(2166, 4874, 'W10486E'),
	(2167, 4857, 'W10487E'),
	(2168, 2760, 'W10488E'),
	(2169, 3994, 'W10489E'),
	(2170, 5952, 'W10490E'),
	(2171, 9504, 'W10491E'),
	(2172, 7719, 'W10492E'),
	(2173, 1665, 'W10493E'),
	(2174, 7757, 'W10503E'),
	(2175, 1030, 'W10504E'),
	(2176, 1752, 'W10509E'),
	(2177, 7473, 'W10510E'),
	(2178, 1187, 'W10511E'),
	(2179, 9778, 'W10512E'),
	(2180, 696, 'W10513E'),
	(2181, 1219, 'W10514E'),
	(2182, 8820, 'W10515E'),
	(2183, 33, 'W10516E'),
	(2184, 2702, 'METER_TYPES_MND'),
	(2185, 8787, 'ROLES'),
	(2186, 903, 'DeviceType'),
	(2187, 6340, 'Manufacturer_Actaris_CF_55'),
	(2188, 6142, 'Protocol_Only_MBus'),
	(2189, 1568, 'W10012E'),
	(2190, 8192, 'W10009E'),
	(2191, 1745, 'W10007E'),
	(2192, 6387, 'W10000E'),
	(2193, 935, 'W10001E'),
	(2194, 7956, 'W10002E'),
	(2195, 7036, 'W10029E'),
	(2196, 9046, 'W10003E'),
	(2197, 9651, 'W10004E'),
	(2198, 8352, 'W10005E'),
	(2199, 4769, 'W10006E'),
	(2200, 5601, 'W10008E'),
	(2201, 6855, 'W10010E'),
	(2202, 5142, 'W10011E'),
	(2203, 3870, 'W10013E'),
	(2204, 7317, 'W10030E'),
	(2205, 797, 'W10261E'),
	(2206, 2465, 'W10264E'),
	(2207, 8444, 'W10266E'),
	(2208, 6855, 'W10267E'),
	(2209, 7623, 'W10268E'),
	(2210, 5106, 'W10269E'),
	(2211, 4318, 'W10270E'),
	(2212, 3751, 'W10053E'),
	(2213, 523, 'W10056E'),
	(2214, 4427, 'W10062E'),
	(2215, 3328, 'W10063E'),
	(2216, 6708, 'W10064E'),
	(2217, 6381, 'W10065E'),
	(2218, 4018, 'W10066E'),
	(2219, 7588, 'W10067E'),
	(2220, 2026, 'W10068E'),
	(2221, 8714, 'W10078E'),
	(2222, 3284, 'W10079E'),
	(2223, 3116, 'W10080E'),
	(2224, 863, 'W10084E'),
	(2225, 7252, 'W10096E'),
	(2226, 7243, 'W10097E'),
	(2227, 3875, 'W10098E'),
	(2228, 9956, 'W10099E'),
	(2229, 1931, 'W10100E'),
	(2230, 2283, 'W10101E'),
	(2231, 401, 'W10102E'),
	(2232, 669, 'W10103E'),
	(2233, 8368, 'W10104E'),
	(2234, 4469, 'W10105E'),
	(2235, 7833, 'W10106E'),
	(2236, 8699, 'W10107E'),
	(2237, 6044, 'W10119E'),
	(2238, 7153, 'W10120E'),
	(2239, 298, 'W10121E'),
	(2240, 1868, 'W10122E'),
	(2241, 7202, 'W10123E'),
	(2242, 4284, 'W10124E'),
	(2243, 4059, 'W10125E'),
	(2244, 7072, 'W10126E'),
	(2245, 6023, 'W10127E'),
	(2246, 2241, 'W10128E'),
	(2247, 7004, 'W10129E'),
	(2248, 5685, 'W10130E'),
	(2249, 7410, 'W10131E'),
	(2250, 8569, 'W10132E'),
	(2251, 2379, 'W10133E'),
	(2252, 6195, 'W10134E'),
	(2253, 7561, 'W10135E'),
	(2254, 4759, 'W10136E'),
	(2255, 7500, 'W10137E'),
	(2256, 8651, 'W10138E'),
	(2257, 4061, 'W10139E'),
	(2258, 9499, 'W10140E'),
	(2259, 1556, 'W10141E'),
	(2260, 4325, 'W10142E'),
	(2261, 4777, 'W10143E'),
	(2262, 4164, 'W10144E'),
	(2263, 5081, 'W10145E'),
	(2264, 4704, 'W10146E'),
	(2265, 2901, 'W10147E'),
	(2266, 849, 'W10148E'),
	(2267, 4146, 'W10149E'),
	(2268, 4042, 'W10150E'),
	(2269, 1962, 'W10151E'),
	(2270, 6560, 'W10152E'),
	(2271, 4952, 'W10153E'),
	(2272, 6874, 'W10154E'),
	(2273, 3861, 'W10155E'),
	(2274, 9024, 'W10156E'),
	(2275, 928, 'W10157E'),
	(2276, 8982, 'W10158E'),
	(2277, 2792, 'W10159E'),
	(2278, 1008, 'W10160E'),
	(2279, 1637, 'W10161E'),
	(2280, 4058, 'W10162E'),
	(2281, 9170, 'W10163E'),
	(2282, 7700, 'W10164E'),
	(2283, 7209, 'W10165E'),
	(2284, 9911, 'W10166E'),
	(2285, 4512, 'W10242E'),
	(2286, 7329, 'W10243E'),
	(2287, 147, 'W10244E'),
	(2288, 9137, 'W10245E'),
	(2289, 9459, 'W10246E'),
	(2290, 8019, 'W10247E'),
	(2291, 6175, 'W10248E'),
	(2292, 9142, 'W10249E'),
	(2293, 9449, 'W10250E'),
	(2294, 1640, 'Manufacturer_Danfoss_Sharky'),
	(2295, 1622, 'Manufacturer_ABB_SVM_F2'),
	(2296, 200, 'Manufacturer_PadPuls_M2C '),
	(2297, 390, 'Manufacturer_Sonometer_1000'),
	(2298, 8213, 'Manufacturer_MultiCal'),
	(2299, 1829, 'Manufacturer_Combimeter_Q'),
	(2300, 1483, 'Manufacturer_Infocal5'),
	(2301, 2113, 'Manufacturer_Hydro_Port'),
	(2302, 6740, 'Manufacturer_SiemensPulse_adapter'),
	(2303, 5833, 'Manufacturer_Siemens_WTT16'),
	(2304, 531, 'Manufacturer_Siemens_WFC21'),
	(2305, 1123, 'Manufacturer_Siemens_WFM21'),
	(2306, 2736, 'Manufacturer_Sensus_HRI '),
	(2307, 5175, 'Manufacturer_Siemens_AEW310'),
	(2308, 751, 'Manufacturer_Siemens_UH50'),
	(2309, 4859, 'Protocol_SET_PSC'),
	(2310, 9300, 'TypeCode101'),
	(2311, 2546, 'HalfHourSum'),
	(2312, 3422, 'UNIQUE_KEYS'),
	(2313, 7265, 'CHECK_KEYS'),
	(2314, 9766, 'EXPORT_TIMEZONE'),
	(2315, 7304, 'TypeCode161'),
	(2316, 2463, 'WS_Type'),
	(2317, 8751, 'Action'),
	(2318, 5195, 'DeviceTypeMDC'),
	(2319, 1100, 'DeviceTypeMDC_EPQS'),
	(2320, 2115, 'DeviceTypeMDC_EPQM'),
	(2321, 2987, 'DeviceTypeMDC_EMS'),
	(2322, 1436, 'DeviceTypeMDC_GAMA'),
	(2323, 9368, 'Manufacturer_Wehrle_ETK_EAX'),
	(2324, 3954, 'Gateway_through'),
	(2325, 6475, 'StoredData'),
	(2326, 553, 'DeviceVersionMDC'),
	(2327, 1076, 'AddInc'),
	(2328, 2758, 'ThreewireFourwire'),
	(2329, 4842, 'TypeCodeCEEO'),
	(2330, 2699, 'TypeCodeDmz'),
	(2331, 7372, 'DeviceTypeDKEG'),
	(2332, 7435, 'Mercury_225_RemoteBaudRate'),
	(2333, 4827, 'Mercury_225_RemoteDataBits'),
	(2334, 8003, 'Mercury_225_RemoteParity'),
	(2335, 3680, 'Mercury_225_RemoteStopBits'),
	(2336, 2897, 'Mercury_230_RemoteBaudRate'),
	(2337, 6430, 'Mercury_230_RemoteDataBits'),
	(2338, 3967, 'Mercury_230_RemoteParity'),
	(2339, 6025, 'Mercury_230_RemoteStopBits'),
	(2340, 2678, 'W10772'),
	(2341, 6889, 'W10775'),
	(2342, 2092, 'W10776'),
	(2343, 2986, 'W10777'),
	(2344, 2047, 'W10778'),
	(2345, 2354, 'W10779'),
	(2346, 5875, 'W10780'),
	(2347, 3464, 'W10781'),
	(2348, 5722, 'W10782'),
	(2349, 6639, 'W10783'),
	(2350, 3676, 'W10784'),
	(2351, 624, 'W10785'),
	(2352, 5656, 'W10786'),
	(2353, 7406, 'W10787'),
	(2354, 7898, 'W10789'),
	(2355, 3332, 'W10791'),
	(2356, 1332, 'W10798'),
	(2357, 7700, 'Binary/XML'),
	(2358, 9141, 'TypeCodeHXE'),
	(2359, 6441, 'W10934'),
	(2360, 1480, 'W10935'),
	(2361, 5137, 'W10936'),
	(2362, 5509, 'W10937'),
	(2363, 6613, 'W10938'),
	(2364, 2437, 'W10939'),
	(2365, 7019, 'W10940'),
	(2366, 8418, 'ConnectVia_PafalEa'),
	(2367, 686, 'W10284'),
	(2368, 4567, 'W10553'),
	(2369, 16, 'W-50201'),
	(2370, 442, 'Kind'),
	(2371, 8577, 'Interface_ADD_SNMP'),
	(2372, 6511, 'Phase_ADD_SNMP'),
	(2373, 6189, 'W10018'),
	(2374, 7038, 'W11089'),
	(2375, 6128, 'ACTION_61968'),
	(2376, 2928, 'FORCE_PERIOD'),
	(2377, 5363, 'Manufacturer_Integral_V_MaXX'),
	(2378, 1195, 'Online'),
	(2379, 4863, 'user/operator'),
	(2380, 6981, 'ConnectViaKm'),
	(2381, 9183, 'Port_KSPD_5'),
	(2382, 5769, 'BaudRate_KSPD_5'),
	(2383, 6370, 'W10014'),
	(2384, 5669, 'W10431'),
	(2385, 9399, 'W10518'),
	(2386, 7943, 'W10554'),
	(2387, 3857, 'W10562'),
	(2388, 9698, 'Manufacturer_Cyble'),
	(2389, 3924, 'N#0_512'),
	(2390, 9047, 'N#1_64'),
	(2391, 2069, 'N#1_32'),
	(2392, 2572, 'W11321'),
	(2393, 2351, 'W11322'),
	(2394, 309, 'N#1_512'),
	(2395, 3233, 'ProfileNr1/2'),
	(2396, 3737, 'ProfileNr_A1800'),
	(2397, 5841, 'Protocol_CVMk2'),
	(2398, 3210, 'DataType_CVMk2'),
	(2399, 3275, 'N#1_31'),
	(2400, 5095, 'AUTO_ADD_NEW_LINES_FOR_GENERATION'),
	(2401, 3134, 'W-50668'),
	(2402, 5275, 'W-50669'),
	(2403, 1213, 'W-50670'),
	(2404, 48, 'Level'),
	(2405, 2204, 'TypeCodeDalaOrman'),
	(2406, 6936, 'Config'),
	(2407, 6019, 'TypeCodeCorax'),
	(2408, 2585, 'TotalActivePowerError'),
	(2409, 7141, 'PLCCommunication'),
	(2410, 0, 'OFDMCommFail'),
	(2411, 6145, 'ProfileNr342'),
	(2412, 4692, 'PasswordErrKeyBoard'),
	(2413, 3043, 'FlashDiskOverload'),
	(2414, 6673, 'TSPowerOn'),
	(2415, 9781, 'W-50844'),
	(2416, 5753, 'W-50845'),
	(2417, 9702, 'TerminalCase_Open'),
	(2418, 9453, 'UnbalancedByCurrent'),
	(2419, 9027, 'Violation'),
	(2420, 1733, 'LocalConnectionBegin'),
	(2421, 7749, 'RemoutConnectionBegin'),
	(2422, 4375, 'COM_InsertedBad'),
	(2423, 2712, 'IO_InsertedBad'),
	(2424, 5471, 'PrepayTokenEnterOk'),
	(2425, 5931, 'PrepayCreditExpired'),
	(2426, 3021, 'Prepay_EM_CreditExpired'),
	(2427, 7539, 'UserConnect'),
	(2428, 6028, 'W-50722'),
	(2429, 5279, 'W-50764'),
	(2430, 5741, 'W-50765'),
	(2431, 9028, 'W-50791'),
	(2432, 2473, 'W-50794'),
	(2433, 6175, 'W-50854'),
	(2434, 2774, 'W-50863'),
	(2435, 8701, 'W-50877'),
	(2436, 962, 'W-50878'),
	(2437, 7785, 'ConnectViaZE114'),
	(2438, 3174, 'Device_type_S_or_C'),
	(2439, 6352, 'W11293E'),
	(2440, 5138, 'W11294E'),
	(2441, 4352, 'W11297E'),
	(2442, 1392, 'W11298E'),
	(2443, 6107, 'W11301E'),
	(2444, 6227, 'W11306E'),
	(2445, 2091, 'W11308E'),
	(2446, 9904, 'W11309E'),
	(2447, 2372, 'W11310E'),
	(2448, 6236, 'W11311E'),
	(2449, 3098, 'W11319E'),
	(2450, 3043, 'N#0_3'),
	(2451, 4186, 'W-50079'),
	(2452, 9641, 'SubDirs'),
	(2453, 4085, 'WHAT_TIME'),
	(2454, 9977, 'W10591'),
	(2455, 3292, 'W10592'),
	(2456, 8340, 'W10593'),
	(2457, 9135, 'W10594'),
	(2458, 6940, 'W10595'),
	(2459, 994, 'W10596'),
	(2460, 9682, 'W10598'),
	(2461, 8253, 'W10599'),
	(2462, 4166, 'W10600'),
	(2463, 3457, 'W10689'),
	(2464, 9258, 'W10690'),
	(2465, 4068, 'W10691'),
	(2466, 3085, 'W10692'),
	(2467, 6902, 'W10693'),
	(2468, 9835, 'W10694'),
	(2469, 9960, 'W10695'),
	(2470, 7133, 'W10696'),
	(2471, 4248, 'W10697'),
	(2472, 7778, 'W10698'),
	(2473, 1077, 'W10699'),
	(2474, 612, 'W10700'),
	(2475, 114, 'W10726'),
	(2476, 9325, 'W10730'),
	(2477, 2228, 'W10736'),
	(2478, 7276, 'Power'),
	(2479, 4214, 'RadioChannel'),
	(2480, 1826, 'W-50401'),
	(2481, 5120, 'Off|On'),
	(2482, 1650, 'DeviceTypeWM22EM4'),
	(2483, 6561, 'Protocol_EA'),
	(2484, 2898, 'TRUE/FALSE'),
	(2485, 4236, 'DeviceVersionOblik'),
	(2486, 7117, 'TypeCode137'),
	(2487, 5789, 'V_Protocol'),
	(2488, 1107, 'P_Protocol'),
	(2489, 7959, 'W10799'),
	(2490, 2879, 'W10800'),
	(2491, 1982, 'W10801'),
	(2492, 2446, 'Proxy'),
	(2493, 5120, 'Priority'),
	(2494, 3193, 'W10744'),
	(2495, 5701, 'W10745'),
	(2496, 9186, 'W10746'),
	(2497, 8786, 'W10747'),
	(2498, 9894, 'W10749'),
	(2499, 4180, 'W-50182'),
	(2500, 8854, 'W-50187'),
	(2501, 4437, 'W10837'),
	(2502, 5619, 'W10841'),
	(2503, 6548, 'W10842'),
	(2504, 3863, 'W10843'),
	(2505, 9297, 'W10844'),
	(2506, 2319, 'W10849'),
	(2507, 7554, 'W10845'),
	(2508, 6704, 'W10846'),
	(2509, 1139, 'W10847'),
	(2510, 6948, 'W10848'),
	(2511, 7317, 'W10854'),
	(2512, 3480, 'W10875'),
	(2513, 5513, 'W10876'),
	(2514, 482, 'W10889'),
	(2515, 8218, 'W-50208'),
	(2516, 8591, 'W-50216'),
	(2517, 3664, 'W-50218'),
	(2518, 3415, 'W-50220'),
	(2519, 6388, 'W-50223'),
	(2520, 1717, 'W-50231'),
	(2521, 7538, 'W-50232'),
	(2522, 1796, 'W-50242'),
	(2523, 9526, 'W-50245'),
	(2524, 172, 'W-50250'),
	(2525, 601, 'W-50268'),
	(2526, 3084, 'W-50270'),
	(2527, 6386, 'W-50273'),
	(2528, 7821, 'W-50277'),
	(2529, 6090, 'W-50284'),
	(2530, 457, 'W-50286'),
	(2531, 6571, 'W-50295'),
	(2532, 6639, 'W-50296'),
	(2533, 3450, 'W-50298'),
	(2534, 4747, 'W-50305'),
	(2535, 477, 'W-50308'),
	(2536, 5919, 'W-50309'),
	(2537, 362, 'Protocol_ZE311'),
	(2538, 5435, 'BaudRate2_ZE311'),
	(2539, 7401, 'ConnectVia_ZE311'),
	(2540, 5515, 'TypeCodeRiM099'),
	(2541, 2922, 'CosemDataType'),
	(2542, 2042, 'REALTIME_DATA_STORAGE_MODE'),
	(2543, 3524, 'W10946'),
	(2544, 914, 'W10947'),
	(2545, 7598, 'DATADATE_BEGIN_END'),
	(2546, 9533, 'W10951'),
	(2547, 1217, 'W10950'),
	(2548, 6599, 'Interface_USPD_164_01'),
	(2549, 2624, 'W10893'),
	(2550, 869, 'W10894'),
	(2551, 4233, 'W10895'),
	(2552, 959, 'W10896'),
	(2553, 1457, 'W10897'),
	(2554, 3070, 'W10898'),
	(2555, 7927, 'W10899'),
	(2556, 6624, 'W10900'),
	(2557, 9097, 'W10901'),
	(2558, 2182, 'W10902'),
	(2559, 5393, 'W10903'),
	(2560, 2244, 'W10904'),
	(2561, 9517, 'W10905'),
	(2562, 6772, 'W10906'),
	(2563, 6743, 'W10907'),
	(2564, 406, 'W10908'),
	(2565, 6174, 'W10909'),
	(2566, 7906, 'W10910'),
	(2567, 4931, 'W10911'),
	(2568, 3784, 'W10912'),
	(2569, 2075, 'W10913'),
	(2570, 575, 'W10914'),
	(2571, 9242, 'W10915'),
	(2572, 6988, 'W10916'),
	(2573, 6076, 'W10917'),
	(2574, 6548, 'W10918'),
	(2575, 3308, 'W10919'),
	(2576, 9626, 'W10920'),
	(2577, 4869, 'W10921'),
	(2578, 3327, 'W10922'),
	(2579, 5784, 'TypeCode_CE102'),
	(2580, 6741, 'DeviceTypeMercury230'),
	(2581, 1445, 'ChannelVzljot_TSRV_034'),
	(2582, 8454, 'W11014'),
	(2583, 9178, 'W11015'),
	(2584, 9673, 'W11016'),
	(2585, 2161, 'W11017'),
	(2586, 5143, 'W11018'),
	(2587, 6511, 'W11019'),
	(2588, 9242, 'W11020'),
	(2589, 8613, 'W11021'),
	(2590, 9998, 'W11022'),
	(2591, 2838, 'W11023'),
	(2592, 4199, 'W11024'),
	(2593, 2253, 'W11025'),
	(2594, 3162, 'W11026'),
	(2595, 1059, 'W11027'),
	(2596, 5083, 'System_Vzljet_020'),
	(2597, 2665, 'Channel_Vzljet_020'),
	(2598, 1945, 'System_Vzljet_010'),
	(2599, 5793, 'Channel_Vzljet_010'),
	(2600, 6591, 'W-50504'),
	(2601, 3404, 'CODEPAGE'),
	(2602, 872, 'ASKP_UNIT'),
	(2603, 6935, 'SendErrorifBoud'),
	(2604, 1768, '1/2'),
	(2605, 4980, '1/2/3'),
	(2606, 9507, 'CheckMeterNr'),
	(2607, 5370, 'StopKadr'),
	(2608, 8631, 'W10971'),
	(2609, 4278, 'W10972'),
	(2610, 5778, 'W10973'),
	(2611, 7378, 'W10974'),
	(2612, 9211, 'W10975'),
	(2613, 8224, 'W10976'),
	(2614, 9932, 'W-50381'),
	(2615, 3437, 'W-50198'),
	(2616, 1509, 'LATEST_SUCCESSFUL_READINGS_INFO_USAGE'),
	(2617, 3276, 'W-50440'),
	(2618, 998, 'W-50441'),
	(2619, 5484, 'W-50442'),
	(2620, 253, 'W-50444'),
	(2621, 8449, 'W-50445'),
	(2622, 4381, 'W-50446'),
	(2623, 5060, 'W-50447'),
	(2624, 1241, 'W-50448'),
	(2625, 6881, 'W-50449'),
	(2626, 374, 'W-50450'),
	(2627, 6482, 'W-50451'),
	(2628, 3210, 'W-50452'),
	(2629, 8261, 'SystemVzletTCP024M'),
	(2630, 2794, 'ChannelVzletTCP024M'),
	(2631, 2374, 'DeviceVersionAX_XMK_NX'),
	(2632, 9205, 'W11036'),
	(2633, 2365, 'W11037'),
	(2634, 3731, 'W11040'),
	(2635, 5539, 'W11041'),
	(2636, 9278, 'W11042'),
	(2637, 4007, 'W11043'),
	(2638, 9438, 'W11044'),
	(2639, 8630, 'W11045'),
	(2640, 6968, 'W11046'),
	(2641, 5125, 'W11047'),
	(2642, 7694, 'W_gt_0'),
	(2643, 1724, 'W11049'),
	(2644, 4504, 'W11050'),
	(2645, 8178, 'W11051'),
	(2646, 9001, 'W11052'),
	(2647, 2894, 'W11053'),
	(2648, 404, 'W11054'),
	(2649, 9677, 'W11055'),
	(2650, 8913, 'W11056'),
	(2651, 7682, 'W11057'),
	(2652, 8663, 'W11058'),
	(2653, 1585, 'TypeCodeKM5'),
	(2654, 5063, 'W11063'),
	(2655, 3595, 'W11073'),
	(2656, 825, 'ProtocolTekon19'),
	(2657, 3347, 'ChannelEsmon'),
	(2658, 8480, 'W-50505'),
	(2659, 6633, 'SOURCE_RP'),
	(2660, 848, 'W_LIMITS'),
	(2661, 6114, 'W_ON_OFF'),
	(2662, 2900, 'W10283'),
	(2663, 1012, 'PLCTimeRWMethod'),
	(2664, 6834, 'W-50691'),
	(2665, 7262, 'W11384'),
	(2666, 9171, 'WaterInSensor_Q'),
	(2667, 5281, 'W11386'),
	(2668, 7579, 'W11387'),
	(2669, 1398, 'W11388'),
	(2670, 9519, 'W11389'),
	(2671, 1185, 'W11390'),
	(2672, 2752, 'W10280'),
	(2673, 3089, 'W10281'),
	(2674, 2134, 'W10282'),
	(2675, 8987, 'W10285'),
	(2676, 3066, 'W10286'),
	(2677, 5141, 'W10287'),
	(2678, 4174, 'W10288'),
	(2679, 605, 'W10289'),
	(2680, 874, 'W10290'),
	(2681, 428, 'W10601'),
	(2682, 9901, 'W10688'),
	(2683, 3466, 'W11391'),
	(2684, 1061, 'W11392'),
	(2685, 4169, 'W11393'),
	(2686, 8838, 'W11394'),
	(2687, 3752, 'W11395'),
	(2688, 5026, 'W11396'),
	(2689, 5639, 'W11397'),
	(2690, 3152, 'W11398'),
	(2691, 9470, 'W11399'),
	(2692, 7525, 'W11400'),
	(2693, 3728, 'W11401'),
	(2694, 6843, 'W11402'),
	(2695, 946, 'W11403'),
	(2696, 9293, 'W11404'),
	(2697, 2235, 'W11405'),
	(2698, 5130, 'W11406'),
	(2699, 6069, 'W11407'),
	(2700, 1876, 'W11408'),
	(2701, 2025, 'W11409'),
	(2702, 6569, 'W11410'),
	(2703, 2031, 'W11411'),
	(2704, 2669, 'W11412'),
	(2705, 5718, 'W11413'),
	(2706, 4076, 'W11414'),
	(2707, 3321, 'W11415'),
	(2708, 4606, 'W11416'),
	(2709, 5426, 'W11417'),
	(2710, 411, 'W11418'),
	(2711, 3542, 'W11419'),
	(2712, 1323, 'W11420'),
	(2713, 9771, 'W11421'),
	(2714, 4476, 'W11422'),
	(2715, 6011, 'W11423'),
	(2716, 2415, 'OptimizationByDT'),
	(2717, 7067, 'DeviceAlarm_GUID'),
	(2718, 4301, 'W11242'),
	(2719, 2222, 'RetDevTime_Orman'),
	(2720, 2180, 'ModbusValsenaTemperature'),
	(2721, 7636, 'PROFILE_PERIOD_1517'),
	(2722, 2416, 'ATS_PRECISION'),
	(2723, 1591, 'ATS_SEPARATOR'),
	(2724, 2792, 'N#0_255'),
	(2725, 3522, 'W-50695'),
	(2726, 6322, 'W-50696'),
	(2727, 2220, 'W-50697'),
	(2728, 796, 'Manufacturer_SKU_03'),
	(2729, 1885, 'UniversalModbus'),
	(2730, 2685, 'N#1_255'),
	(2731, 2561, 'N#1_2'),
	(2732, 4531, 'N#1_3'),
	(2733, 8245, 'KANS_PRECISION'),
	(2734, 8255, 'AddressingType'),
	(2735, 1758, 'SecurityLevel'),
	(2736, 243, 'ASCII/binary'),
	(2737, 997, 'W11552'),
	(2738, 9538, 'Function'),
	(2739, 5815, 'W-50879'),
	(2740, 5530, 'W-50880'),
	(2741, 3343, 'W-50883'),
	(2742, 9786, 'W-50894'),
	(2743, 9596, 'W-50900'),
	(2744, 9539, 'W-50909'),
	(2745, 1692, 'W-50910'),
	(2746, 6039, 'DType'),
	(2747, 3721, 'W11337'),
	(2748, 9950, 'W11342'),
	(2749, 7516, 'W11343'),
	(2750, 3950, 'W11344'),
	(2751, 6390, 'W11345'),
	(2752, 5933, 'W11350'),
	(2753, 5388, 'W11351'),
	(2754, 1826, 'W11352'),
	(2755, 4751, 'W-50913'),
	(2756, 3200, 'UseGroupAddress_MIT_5000_MG'),
	(2757, 6375, 'Port_MIT_5000_MG'),
	(2758, 7956, 'BaudRate_MIT_5000_MG'),
	(2759, 5317, 'StopBits_MIT_5000_MG'),
	(2760, 8971, 'HasCalibration_MIT_5000_MG'),
	(2761, 8860, 'EvenOrOddCalibration_MIT_5000_MG'),
	(2762, 5090, 'DataBits_MIT_5000_MG'),
	(2763, 9547, 'ConnectVia_MIT_5000_MG'),
	(2764, 6762, 'ProfileNr_MIT_5000_MG'),
	(2765, 1198, 'STVzljotTSRV_TypeCode'),
	(2766, 3442, 'UNIVERSAL'),
	(2767, 9613, 'ENUM_LPTY'),
	(2768, 7929, 'ENUM_RPTY_FPTY_XPTY'),
	(2769, 1586, 'ENUM_JOURNAL'),
	(2770, 9664, 'ENUM_DISCRETE'),
	(2771, 5298, 'ENUM_GPTY'),
	(2772, 5255, 'ENUM_PPTY'),
	(2773, 2458, 'ENUM_MPTY'),
	(2774, 3814, 'ENUM_SPTY'),
	(2775, 2486, 'COR_COEF'),
	(2776, 6855, 'Q[XX]'),
	(2777, 7356, 'Q[KZ]'),
	(2778, 8089, 'P[XX]'),
	(2779, 403, 'P[KZ]'),
	(2780, 1527, 'S[NOM]'),
	(2781, 1098, 'U[NOM]'),
	(2782, 5065, 'r[UD]'),
	(2783, 5868, 'L[KL]'),
	(2784, 1838, 'cos[F]'),
	(2785, 1974, 'P[XX]1'),
	(2786, 984, 'P[XX]2'),
	(2787, 7716, 'P[KZ]1'),
	(2788, 3250, 'P[KZ]2'),
	(2789, 579, 'S[NOM]1'),
	(2790, 8669, 'S[NOM]2'),
	(2791, 2943, 'Q[XX]1'),
	(2792, 4648, 'Q[XX]2'),
	(2793, 5506, 'Q[KZ]1'),
	(2794, 9719, 'Q[KZ]2'),
	(2795, 853, 'r[UD]1'),
	(2796, 2853, 'r[UD]2'),
	(2797, 1759, 'L[KL]1'),
	(2798, 6720, 'L[KL]2'),
	(2799, 3781, 'OTHER_PROPS'),
	(2800, 3745, 'TRANSFORMER_PROPS'),
	(2801, 9089, 'LINE_PROPS'),
	(2802, 2015, 'STLINE_READY_TO_WORK'),
	(2803, 7190, 'PW_SETTING_FULL'),
	(2804, 8206, 'UNREGISTERED_METER_FOR_KNOWN_POINT'),
	(2805, 7693, 'PW_SETTING_RECEIVED'),
	(2806, 9171, 'Automatinis skaitiklių registravimas'),
	(2807, 8608, 'Operatyvūs pranešimai'),
	(2808, 7297, 'WS_POINT_PROFILE'),
	(2809, 1247, 'DEFAULT_GR_FFP'),
	(2810, 5831, 'DEFAULT_POINT_FFP'),
	(2811, 29, 'SUGGESTED_ROOT'),
	(2812, 8915, 'ALL.ROOT'),
	(2813, 67, 'EMS'),
	(2814, 4607, 'EPQM'),
	(2815, 3798, 'EPQS'),
	(2816, 9044, 'LZKM'),
	(2817, 2581, 'LZQM'),
	(2818, 2953, 'USER_GROUPS'),
	(2819, 6068, 'BY_DP_GENERATED_BY_ORACLE'),
	(2820, 8438, 'BY_DP_GENERATED_BY_ORACLE_1389'),
	(2821, 5963, 'BY_DP_GENERATED_BY_ORACLE_1388'),
	(2822, 8183, 'NO_DATA_FOR_THE_LAST_24_HOURS'),
	(2823, 8616, 'MANDATORY_LPTY_MISSING'),
	(2824, 5760, 'RECOMMENDED_LPTY_MISSING'),
	(2825, 6141, 'ELECTRICITY'),
	(2826, 999, 'OBJ'),
	(2827, 5464, 'SYSTEM'),
	(2828, 723, 'UNIT'),
	(2829, 5283, 'TOWN'),
	(2830, 1530, 'REGION'),
	(2831, 2785, 'UD'),
	(2832, 3347, 'DP'),
	(2833, 9926, 'Standartinis'),
	(2834, 2703, 'LZQM_EPQM_LZKM_INSTANT'),
	(2835, 3982, 'EMS_INSTANT'),
	(2836, 5888, 'EPQS_INSTANT'),
	(2837, 3994, 'NEEDLESS'),
	(2838, 9260, 'Skaitiklio montavimas'),
	(2839, 2030, 'dstEnabled'),
	(2840, 3835, 'loadControl'),
	(2841, 5028, 'lotNumber'),
	(2842, 2197, 'outageReport'),
	(2843, 1156, 'readRequest'),
	(2844, 2106, 'relayCapable'),
	(2845, 3684, 'reverseFlowHandling'),
	(2846, 5924, 'modelNumber'),
	(2847, 8230, 'modelVersion'),
	(2848, 2295, 'WS'),
	(2849, 4715, 'Kiti matavimai'),
	(2850, 6399, 'Elektra'),
	(2851, 4882, 'Oras'),
	(2852, 4987, 'Šaltis'),
	(2853, 6907, 'Šilumnešis'),
	(2854, 3209, 'Dujos'),
	(2855, 152, 'Šaltas vanduo'),
	(2856, 8281, 'Karštas vanduo'),
	(2857, 1951, 'Be ryšio kanalo'),
	(2858, 688, 'LAN (elektra)'),
	(2859, 7638, 'GPRS (elektra)'),
	(2860, 9308, 'RS232'),
	(2861, 7937, 'GPRS (temp.)'),
	(2862, 4911, 'GPRS (vanduo)'),
	(2863, 6913, 'LAN (vanduo)'),
	(2864, 8585, 'LAN (temperatūra)'),
	(2865, 583, 'Ryšio kanalai nenaudojami'),
	(2866, 9507, 'EMCOS_STATUS'),
	(2867, 3163, 'WATER_COLD'),
	(2868, 9393, 'TEMP_OUT'),
	(2869, 743, 'TEMP_IN'),
	(2870, 7763, 'WATER_HOT'),
	(2871, 3622, 'HEAT'),
	(2872, 6129, 'GAS'),
	(2873, 5108, 'VIRTUAL'),
	(2874, 7831, 'OUTPUT_TO_BILLING'),
	(2875, 3429, 'POINT_LOCATION_CODE'),
	(2876, 7091, 'POINT_LOCATION_DESC'),
	(2877, 2413, 'POINT_SUPL_CODE'),
	(2878, 6237, 'IMC_BIAS'),
	(2879, 9767, 'DELIVERY_POINT_TO_2_INLETS_WITH_TRANSFORMERS'),
	(2880, 433, 'DELIVERY_POINT_TO_2_INLETS_WITH_TRAN_2ND_LINE_LOSS'),
	(2881, 569, 'DELIVERY_POINT_TO_TRANSFORMER_AND_2_INLETS'),
	(2882, 5541, 'DELIVERY_POINT_TO_MS_POINT_CONSIDERING_LINE_LOSS'),
	(2883, 4659, 'DELIVERY_POINT_TO_2_INLETS_WITH_TRAN_AND_LINE_LOSS'),
	(2884, 2321, 'DELIVERY_POINT_TO_MS_POINT_WITH_TRAN_AND_LINE_LOSS'),
	(2885, 5415, 'DB sesijų monitoringas'),
	(2886, 9276, 'Laisvos vietos sekimas EMCOS_IND.'),
	(2887, 6479, 'Laisvos vietos sekimas EMCOS_TAB.'),
	(2888, 9547, 'Senų duomenų trynimo monitoringas'),
	(2889, 1418, 'Vatrotojų sesijų informacijos trynimas'),
	(2890, 1650, 'Nesekmingų bandymų prisijungti prie sistemos'),
	(2891, 4573, 'Vartotojų sesijų audito įjungimas'),
	(2892, 4261, 'Vartotojų sesijų audito išjungimas'),
	(2893, 9255, 'Užimtos EMCOS_IND tablespace vietos procentas'),
	(2894, 7964, 'Užimtos EMCOS_TAB tablespace vietos procentas'),
	(2895, 4637, 'Taškų matavimų galiojančių išsaugojimų kiekis per parą'),
	(2896, 4985, 'Taškų matavimų galiojančių išsaugojimų procentas per parą'),
	(2897, 3717, 'Turinčių diskretiškumą taškų matavimų išsaugojimų procentas per parą'),
	(2898, 1040, 'Suvestų apskaitos taškų kiekis'),
	(2899, 7849, 'Turinčių diskretiškumą taškų matavimų be skylių procentas'),
	(2900, 5541, 'Ryšio kanalų unikalių sesijų be transporto lygio klaidų procentas per parą'),
	(2901, 9000, 'Uždarytų taškų procentas per parą'),
	(2902, 1053, 'Įrašų kiekis taškų matavimų saugotinų nuskaitymų buferyje'),
	(2903, 9916, 'Įrašų kiekis taškų matavimų nesaugotinų nuskaitymų buferyje'),
	(2904, 8432, 'Svarbių Oracle pranešimų kiekis įvykių registre per parą'),
	(2905, 7995, 'Maksimalus eilės dydis per parą'),
	(2906, 7200, 'Suformuotų automatizuotų ataskaitų kiekis per parą'),
	(2907, 6132, 'Naudojamų ryšio kanalų kiekis'),
	(2908, 2260, 'Naudojamų ryšio kanalų, su kuriais yra ryšys, procentas'),
	(2909, 7168, 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą'),
	(2910, 3795, 'Turinčių diskretiškumą galiojančių saugotinų nepagerinamų išsaugojimų procentas per parą'),
	(2911, 4385, 'Neturinčių diskretiškumo galiojančių saugotinų nepagerinamų išsaugojimų procentas per parą'),
	(2912, 4254, 'Źīėč÷åńņāī ąāņīģąņčēčšīāąķķūõ ņī÷åź ó÷åņą'),
	(2913, 1842, 'Beviltiškų taškų procentas'),
	(2914, 5649, 'Beviltiškų taškų skylių užsakymų eilučių procentas nuo bendro kiekio'),
	(2915, 1147, 'Beviltiškų skylių užsakymų eilučių kiekis'),
	(2916, 7958, 'Lentelės PL_DATA apimties procentas nuo visų EMCOS_TAB segmentų'),
	(2917, 1120, 'Taškų su skylėmis procentas'),
	(2918, 6713, 'Nuskaitymo taškų, su kuriais nėra ryšio, procentas nuo galiojančių'),
	(2919, 7919, 'Galiojančių ryšio kanalų be ryšio kiekis'),
	(2920, 8335, 'Sėkmingai išsiųstų eksporto formų procentas'),
	(2921, 3844, 'Sėkmingų sugrupuotų užklausų procentas'),
	(2922, 4201, 'Įvykio registro pranešimų kiekis per parą'),
	(2923, 7267, 'Bendra EMCOS segmentų apimtis (GB)'),
	(2924, 7824, 'Negaliojančių rodmenų nuskaitymų lentelės PL_DATA_NV apimtis procentais'),
	(2925, 8013, 'Užblokuotų sistemos vartotojų ataskaita'),
	(2926, 4072, 'DB ilgai veikiančių sesijų paieška'),
	(2927, 8564, 'Nesekmingų bandymų prisijungti prie sistemos ataskaita'),
	(2928, 2461, 'Vartotojų sesijų audito įjungimas ataskaita'),
	(2929, 7399, 'Vartotojų sesijų audito išjungimas ataskaita'),
	(2930, 2046, 'Vatrotojų sesijų informacijos trynimas ataskaita'),
	(2931, 4892, 'Taškų matavimų saugotinų nuskaitymų kiekis buferyje'),
	(2932, 285, 'Taškų matavimų nesaugotinų nuskaitymų kiekis buferyje'),
	(2933, 9979, 'Vartotojų informacija'),
	(2934, 7075, 'EMCOS monitoringas'),
	(2935, 3519, 'DB session monitoring'),
	(2936, 4439, 'Sistemos gamintojams'),
	(2937, 2868, 'EMCOS_STATUS_PROFILE'),
	(2938, 118, 'Kas 15 min'),
	(2939, 2395, 'Kas 10 min'),
	(2940, 245, 'Kas parą'),
	(2941, 4307, 'Kas 5 minutes'),
	(2942, 5548, 'Kas valandą'),
	(2943, 4072, 'Kas 20 min'),
	(2944, 63, 'Kas pusvalandį'),
	(2945, 4499, 'Kas 4 valandas'),
	(2946, 4312, 'Kas mėnesį'),
	(2947, 5647, 'Kas 6 valandas'),
	(2948, 7761, 'Rodmenų generavimas pagal atnaujintų periodų informaciją'),
	(2949, 6349, 'Šilumnešio temperatūrų grafiko rodmenų generavimas pagal lauko temperatūros duomenis'),
	(2950, 2620, 'Šilumos teorinės rodmenų generavimas pagal lauko temperatūros duomenis'),
	(2951, 3430, 'Administratoriai'),
	(2952, 6811, 'Vartotojai be apribojimų pagal taškus'),
	(2953, 9753, 'HIHI'),
	(2954, 8932, 'HI'),
	(2955, 1175, 'LOLO'),
	(2956, 115, 'LO'),
	(2957, 4136, 'lmt number;\r\ncurrtmst date;\r\nstep number := 0;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_MINUTE\';\r\nst date;'),
	(2958, 6205, 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=SYSDATE-nvl(:2,31)\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_type_id=1) using (ml_id) WHERE\r\n PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;'),
	(2959, 6196, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_SEK\';\r\nstep number := 0;\r\nst date;'),
	(2960, 6586, 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=SYSDATE-nvl(:2,31)\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_type_id=7) using (ml_id) WHERE\r\n PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;'),
	(2961, 8236, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_INSTANT\';\r\nstep number := 0;\r\nst date;'),
	(2962, 7235, 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=SYSDATE-nvl(:2,31)\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_type_id=6) using (ml_id) WHERE\r\n PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;'),
	(2963, 4654, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_DAY\';\r\nstep number := 0;\r\nst date;'),
	(2964, 3369, 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_type_id=3) using (ml_id) WHERE\r\n PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;'),
	(2965, 7061, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_PROFILE\';\r\nstep number := 0;\r\nst date;'),
	(2966, 6669, 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_type_id=2) using (ml_id) WHERE\r\n PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;'),
	(2967, 2123, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_TOTAL\';\r\nstep number := 0;\r\nst date;'),
	(2968, 8024, 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_type_id=5) using (ml_id) WHERE\r\n PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;'),
	(2969, 2408, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_MONTH\';\r\nstep number := 0;\r\nst date;'),
	(2970, 1158, 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_type_id=4) using (ml_id) WHERE\r\n PL_T<=CURRTMST+nvl(:1,1440)/1440+31\r\n --5/and pl_t>=CURRTMST+31\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;'),
	(2971, 8792, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_TDAYFIX\';\r\nstep number := 0;\r\nst date;'),
	(2972, 1123, 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_id=8 and not md_id in (5,6,7))\r\n using (ml_id) WHERE PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;'),
	(2973, 9927, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_TMONFIX\';\r\nstep number := 0;\r\nst date;'),
	(2974, 6244, 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_id=8 and md_id in (5,6))\r\n using (ml_id) WHERE PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;'),
	(2975, 4761, 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA\';\r\nstep number := 0;\r\nst date;'),
	(2976, 2058, 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data WHERE\r\n PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;'),
	(2977, 7674, 'AUTO_DELETE_CUSTOM_FROM_PL_DATA'),
	(2978, 168, 'Automatinis visų matavimo taškų specifinių galiojančių duomenų įrašų trynimas'),
	(2979, 3048, 'CURRTMST DATE;\r\nTS DATE;\r\nep INTEGER;\r\nbtc VARCHAR(250):=\'AUTO_DELETE_CUSTOM_FROM_PL_DATA\';'),
	(2980, 2004, 'SELECT CASE WHEN exists (select 0 from USER_TAB_PARTITIONS where TABLESPACE_NAME like \'EMCOS_%\'\r\nAND TABLE_NAME = \'PL_DATA_CUSTOM\') THEN 1 ELSE 0 END INTO ep FROM dual;\r\nIF ep=1 THEN\r\nfor i in (select\r\nTABLE_NAME tn,\r\nPARTITION_NAME pname,\r\nADD_MONTHS(TO_DATE(SUBSTR(PARTITION_NAME,5,11)||\'01\', \'YYYYMMDD\'),1) dt\r\nfrom USER_TAB_PARTITIONS\r\nwhere TABLE_NAME = \'PL_DATA_CUSTOM\') LOOP\r\nif i.dt < SYSDATE-nvl(:2,31)\r\nTHEN\r\n--disable FK\r\nDELETE gtts;\r\nINSERT INTO gtts (id0,c1)\r\nSELECT ts_id,\r\n\'alter table ||table_name|| modify constraint ||constraint_name|| \'||Decode(ts_id,0,\'disable\',\'enable novalidate\')\r\nFROM (\r\nSELECT table_name,constraint_name FROM user_constraints a\r\nWHERE LEVEL=2\r\nCONNECT BY PRIOR constraint_name=r_constraint_name AND PRIOR constraint_type=\'P\' AND constraint_type=\'R\'\r\nSTART WITH table_name =\'PL_DATA_CUSTOM\'\r\n),ts;\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=0) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nEXECUTE IMMEDIATE \'alter table \'||i.tn||\' drop partition \'||i.pname;\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=1) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,i.dt amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET y.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT(y.tmst_code,y.amp) values (u.tmst_code,u.amp);\r\nend if;END LOOP;\r\nELSE\r\nSELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE=btc)\r\n,TRUNC ((SYSDATE-interval \'5\' year),\'Y\')) INTO CURRTMST FROM DUAL;\r\nTS := SYSDATE;\r\nwhile (not (CURRTMST+nvl(:1,5)/1440 > (SYSDATE-nvl(:2,31)) OR SYSDATE > TS+nvl(:3,45)/86400))LOOP\r\nDELETE PL_DATA_CUSTOM WHERE DB_TIME<CURRTMST+nvl(:1,5)/1440 AND ROWNUM<=nvl(:4,10000);\r\nIF SQL%ROWCOUNT=0 then\r\nCURRTMST := CURRTMST+nvl(:1,5)/1440;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,CURRTMST amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET y.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT(y.tmst_code,y.amp) values (u.tmst_code,u.amp);\r\nEND IF;\r\nCOMMIT;\r\nEND LOOP;\r\nEND IF;'),
	(2981, 8979, 'Žingsnis minutėmis'),
	(2982, 5883, 'N:=:STEP'),
	(2983, 3355, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis'),
	(2984, 1247, 'N:=:SEC_COUNT'),
	(2985, 4659, 'Maksimalus trinamų įrašų kiekis'),
	(2986, 4526, 'N:=:REC_COUNT'),
	(2987, 4784, 'Terminal_MIT_5000_MG'),
	(2988, 9869, 'Ryšiui per skaitiklį ar terminalą'),
	(2989, 7933, 'per skaitiklį'),
	(2990, 1714, 'per terminalą'),
	(2991, 2638, 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nsML_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,ML_ID,aggs_type_id\r\nfrom GEN_IDs\r\nWHERE bga_id=:0 --6/ and point_id=:6\r\n;'),
	(2992, 8250, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sML_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3)-1,Nvl(:5+1,SYSDATE),1,sML_ID);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',prev_val,Nvl(:7,0)\r\n, \'1\',SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT a.*,bt t,val v\r\n,Lag(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt) prev_val\r\n,Lag(has_specific_dstatus) over (PARTITION BY point_id,ml_id ORDER BY da,bt) prev_has_specific_dstatus\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,param1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,Nvl(:5+1,SYSDATE)))a )r\r\nWHERE (Nvl(:7,0)=1 OR v IS NULL) AND prev_has_specific_dstatus=0;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(2993, 3718, '1000000'),
	(2996, 1320, 'CENTRAL_DB'),
	(2997, 8641, 'Požymis, kad sistema yra centrinė (neleisti pilno importo)'),
	(2998, 3645, 'DATA_TRANSFER'),
	(2999, 6999, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT d.ib t,c1,c2,c3,point_id, Avg(val) v,\r\nCASE WHEN\r\n(d.ib+1/48<SYSDATE AND Count(DISTINCT(Trunc((bt - d.ib)*48*4)))\r\n>=4) THEN \'1\' ELSE \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\n a join (SELECT da y,da+(nr-1)/48 ib,da+nr/48 ie FROM days,iger WHERE nr<=48) d\r\nON (NOT y+1<=bt AND NOT y>=et AND NOT ie<=bt AND NOT ib>=et)\r\nWHERE NOT val IS NULL AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,point_id,d.ib )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3000, 5521, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n FROM spty\r\n WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(bt,\'HH\') t,Avg(val) v,\r\nCASE WHEN (\r\nTRUNC(bt,\'HH\')+1/24<SYSDATE AND Count(DISTINCT(Trunc((bt - TRUNC(bt, \'HH\'))*24*4)))\r\n>=4) THEN \'1\' ELSE \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,Trunc(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3001, 7349, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,TRUNC(bt, \'HH\') t,MAX(val) v,\r\nCASE WHEN (\r\nTRUNC(bt,\'HH\')+1/24<SYSDATE AND Count(DISTINCT(Trunc((bt - TRUNC(bt, \'HH\'))*24*4)))\r\n>=4) THEN \'1\' ELSE \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,TRUNC(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3002, 3174, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,TRUNC(bt, \'HH\') t,MIN(val) v,\r\nCASE WHEN (\r\nTRUNC(bt,\'HH\')+1/24<SYSDATE AND Count(DISTINCT(Trunc((bt - TRUNC(bt, \'HH\'))*24*4)))\r\n>=4) THEN \'1\' ELSE \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,TRUNC(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3003, 8465, 'Nesutampa %2 "%3" (%5) ir "%4" prieaugis (%6) už %1'),
	(3004, 6359, 'CP.CP_NOTE.S'),
	(3005, 81, 'Nesutampa suma už periodą ir suminių prieaugis'),
	(3006, 1555, 'Neužpildyti %2 "%4" duomenys, todėl nežinomas prieaugis už %1'),
	(3007, 7380, 'CP.CP_NOTE.T'),
	(3008, 8175, 'Neužpildyti suminiai duomenys, todėl nežinomas prieaugis už periodą'),
	(3009, 392, 'Periodas'),
	(3010, 7118, 'Matavimo ir krypties kodas'),
	(3011, 9428, 'Uždaromo agregavimo segmento pavadinimas'),
	(3012, 5185, 'Palyginamojo agregavimo segmento tipo pavadinimas'),
	(3013, 5479, 'Uždaromo agregavimo segmento matavimo reikšmė'),
	(3014, 5364, 'Palyginamojo agregavimo segmento matavimo reikšmė'),
	(3015, 856, 'SELECT src_tmpl_id, dp_id INTO t,d FROM src WHERE src_id = :1 AND src_et IS NULL;\r\nSELECT DISTINCT point_id,\'0\' BULK COLLECT INTO P1,A1 FROM st_se WHERE src_id =:1 AND NOT point_id IS NULL;\r\nUPDATE src SET src_et = SYSDATE, src_enabled=0 WHERE src_id = :1;\r\na:=src_from_tmpl_i(d,t,P1);\r\ninit_fill_point_cfg(P1,A1,orn);\r\nDELETE gttt;\r\nFORALL j IN 1..P1.count\r\nINSERT INTO gttt (id1,c1) VALUES (P1(j),A1(j));\r\nINSERT INTO dtl (req_type_code, rodo_id)\r\nSELECT req_type_code,orn FROM rc WHERE rc_id=16\r\nAND EXISTS (SELECT 0 FROM gttt WHERE c1=\'0\');\r\nIF SQL%ROWCOUNT=0 THEN\r\nFOR n IN (\r\nSELECT bga_id,src_seq.CURRVAL src_id FROM bga join bga_type USING (bga_type_id) WHERE bga_type_code=\'PL_SE_POST_PROCESSING\'\r\n) loop\r\nbgao_i(n.bga_id,t_varchar2_tab(n.src_id));\r\nEND LOOP;\r\nEND IF;\r\nINSERT INTO src_pw_tmst (src_id, point_id, id, pw_rt, pck_t)\r\nSELECT s.src_id, b.id1, o.id, o.pw_rt, o.pck_t\r\nFROM src s,gttt b,src_pw_tmst o\r\nWHERE s.dp_id=d\r\nAND s.src_tmpl_id=t\r\nAND s.src_et IS NULL\r\nAND Nvl(s.point_id,b.id1)=b.id1\r\nAND b.c1<>\'0\'\r\nAND o.src_id=:1\r\nAND o.id=1;'),
	(3016, 1405, 'Duomenų pakrovimo užsakymas %1 (%2) %3, pakeitimai negalimi'),
	(3017, 2678, 'DMP.UPDATE'),
	(3018, 7152, 'Duomenų pakrovimo užsakymo pakeitimai negalimi'),
	(3019, 843, 'Užsakymo ID'),
	(3020, 2555, 'Užsakymo aprašas'),
	(3021, 453, 'Užsakymo statusas'),
	(3022, 7871, 'Duomenų pakrovimo užsakymas %1 nerastas'),
	(3023, 363, 'DMP.NORECORD'),
	(3024, 6744, 'Duomenų pakrovimo užsakymas nerastas'),
	(3025, 5059, 'Duomenų perkėlimas nutrauktas. Bandymas pakrauti %1 versijos failą į %2'),
	(3026, 6425, 'DMP.VERSION'),
	(3027, 5514, 'Duomenų perkėlimas nutrauktas. Bandymas kitos versijos failą'),
	(3028, 2917, 'Kraunama versija'),
	(3029, 3292, 'Esama versija'),
	(3030, 5288, 'Duomenų perkėlimo klaida. Nepavyko įjungti išorinį raktą %1'),
	(3031, 4441, 'DMP.CONSTRAINT'),
	(3032, 1907, 'Duomenų perkėlimo klaida. Nepavyko įjungti išorinį raktą'),
	(3033, 9506, 'Išorinio rakto pavadinimas'),
	(3034, 9898, 'Duomenų perkėlimo klaida. Nepavyko įjungti trigerį %1'),
	(3035, 2379, 'DMP.TRIGGER'),
	(3036, 7559, 'Duomenų perkėlimo klaida. Nepavyko įjungti trigerį'),
	(3037, 3164, 'Trigerio pavadinimas'),
	(3038, 4971, 'Duomenų perkėlimo metu rasta %1 klaidų'),
	(3039, 1969, 'DMP.ERRORS'),
	(3040, 7659, 'Duomenų perkėlimo metu rasta klaidų'),
	(3041, 9726, 'Klaidų skaičius'),
	(3042, 8794, 'Duomenų perkėlimo klaida %1'),
	(3043, 2220, 'DMP.ERROR'),
	(3044, 6765, 'Duomenų perkėlimo klaida'),
	(3045, 9099, 'Klaidos pranešimas'),
	(3046, 2130, 'Pradėtas duomenų eksportas %1'),
	(3047, 8769, 'DMP.EXPORT_START'),
	(3048, 6461, 'Pradėtas duomenų eksportas'),
	(3049, 8371, 'Duomenų perkelimo užsakymo ID'),
	(3050, 973, 'Pradėtas duomenų importas iš failo %1'),
	(3051, 952, 'DMP.IMPORT_START'),
	(3052, 8393, 'Pradėtas duomenų importas iš failo'),
	(3053, 4676, 'Failo pavadinimas'),
	(3054, 4430, 'Duomenų perkėlimo pabaiga'),
	(3055, 7190, 'DMP.FINISH'),
	(3056, 2095, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\ndelete gttt;\r\nFORALL j IN 1..sPL_ID.count\r\nINSERT INTO gttt\r\n(d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT NULL,NULL,sPL_ID(j),sSEP_ID(j),ib\r\n,\'\',Sum(q*l),Nvl(:7,0),Decode(Max(k),0,\'1\',\'14\'),SYSDATE,\'\'\r\n,sAGGS_TYPE_ID(j) FROM (SELECT f.*, w.* ,g/(et-bt)/24 q, TRUNC(f.bt, \'HH\')+(w.column_value-1)/24 ib\r\n,(Least(et,TRUNC(f.bt, \'HH\')+w.column_value /24)-Greatest(bt,TRUNC(f.bt, \'HH\')+(w.column_value-1)/24))*24 l\r\n,CASE WHEN et-bt>=2/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM\r\n(\r\nSELECT bt,\r\nLead(bt) over (ORDER BY bt) et,\r\nLead(val) over (ORDER BY bt)-\r\nCASE WHEN\r\nLead(val) over (ORDER BY bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nfrom\r\n(SELECT bt,val\r\nFROM v_ar\r\nWHERE point_id=sPOINT_ID(j) AND ml_id=:1 AND da>=Nvl(:4,SYSDATE-:3)\r\nAND da<=Nvl(:5,SYSDATE) AND NOT val IS NULL\r\n) r\r\nWHERE NOT EXISTS (\r\nSELECT 0 FROM\r\nst_map_plain p\r\n,st_map_data_plain d\r\nWHERE\r\np.point_id=sPOINT_ID(j) AND p.ml_id=:1 AND\r\np.ma_enabled=1 AND p.ma_auto_check=1 AND p.ma_auto_null_act=1 AND p.map_enabled=1\r\nAND p.map_id=d.map_id(+) AND r.bt=d.mt_time(+)\r\nAND r.bt>=p.bt AND r.bt<Nvl(p.et,r.bt+1)\r\nAND Nvl(d.mt_success,0)=0\r\n)\r\n) f,mou u, TABLE (SELECT CAST(COLLECT(level) AS sql_objects) FROM dual connect by level<=(ROUND(\r\n(CASE\r\nWHEN f.et=trunc(f.et, \'HH\')\r\nTHEN f.et\r\nELSE TRUNC(f.et, \'HH\')+1/24\r\nEND\r\n - TRUNC (f.bt, \'HH\')) * 24, 6))) w WHERE sPOINT_ID(j)=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null) h\r\nGROUP BY ib HAVING Round(Sum(l),6)=1;\r\nSELECT d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=f.id2 and aggs_type_id=f.id8 AND pl_t=f.d2 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3057, 8682, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,sML_ID,sSAM_CODE\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nselect level BULK COLLECT INTO pNR from dual connect by level<=mi;\r\nDELETE GTTT;\r\nFORALL j in 1..mi\r\nINSERT INTO GTTT (id0,id1) values (pNR(j),sPL_ID(j));\r\nSELECT d\r\nBULK COLLECT INTO s1\r\nFROM\r\n(SELECT /*+ use_nl(a b c) index(c plep_pk)*/ id0,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END d\r\nFROM\r\ngttt a\r\nleft join plu b ON (a.id1=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.id1=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY id0\r\nORDER BY id0);\r\nDELETE GTTT;\r\nFORALL j IN 1..mi\r\nINSERT INTO gttt (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT\r\nNULL,NULL,sPL_ID(j),sSEP_ID(j),bt,\'\',Decode(Trunc(et),da,f,f+p-Sum(f) over (PARTITION BY da)) v,Nvl(:7,0),d\r\n,SYSDATE,\'\',sAGGS_TYPE_ID(j) FROM\r\n(\r\nSELECT b.bt,b.et,b.da,c.val p,b.val s,Decode(c.has_specific_dstatus,0,\'1\',\'14\')d\r\n,Round(b.val*c.val/Sum(b.val) over (PARTITION BY b.da),6) f\r\nFROM  st_ar_sam b,v_ar c\r\nWHERE c.point_id=sPOINT_ID(j)\r\nAND b.da=c.da AND c.ml_id=sML_ID(j)\r\nAND b.sam_code=sSAM_CODE(j)\r\nAND b.da>=Trunc(s1(j)) AND b.bt>=s1(j) AND b.da<s2\r\nAND NOT c.val IS NULL AND NOT b.val IS null\r\n);\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8  AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3058, 9551, 's0:=Trunc(Nvl(:4,SYSDATE-:3)); s2:=Nvl(Trunc(:5)+1,SYSDATE); SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty WHERE spty.spty_code=\'GENERATION_FETCH\'), 100) INTO pGF FROM dual;\r\nOPEN c_ROWS; LOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID LIMIT pGF;\r\nmi:=sPL_ID.Count; EXIT WHEN mi=0; select level BULK COLLECT INTO pNR from dual connect by level<=mi;\r\nDELETE GTTT; FORALL j in 1..mi INSERT INTO GTTT (id0,id1) values (pNR(j),sPL_ID(j));\r\nSELECT d BULK COLLECT INTO s1 FROM\r\n(SELECT /*+ use_nl(a b c) index(c plep_pk)*/ id0,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END d FROM gttt a\r\nleft join plu b ON (a.id1=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.id1=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY id0 ORDER BY id0);\r\nDELETE GTTT;\r\nFORALL j IN 1..mi\r\nINSERT INTO gttt (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT\r\nNULL,NULL,sPL_ID(j),sSEP_ID(j),bt\r\n,\'\',round(new_val,6),Nvl(:7,0),CASE WHEN s=0 AND p=0 AND bad=1 THEN \'1\' else \'14\' end\r\n,SYSDATE,\'\',sAGGS_TYPE_ID(j) FROM\r\n(with a1 as (\r\nSELECT point_id,ml_id,da,bt,val,HAS_SPECIFIC_DSTATUS s\r\nFROM v_ar\r\nWHERE point_id=sPOINT_ID(j)\r\nAND ml_id=:1\r\nAND da>=Trunc(s1(j)) AND da<s2\r\nAND NOT val IS NULL )\r\nselect * from (select a.* ,case when a.val is null then (c.val-sum)/bad end as new_val , c.s from (select * from(\r\nSELECT point_id,ml_id,da,bt,val\r\n,sum(decode(val,null,1,0))over(partition by point_id, ml_id, da) bad\r\n,sum(val)over(partition by point_id, ml_id, da) Sum\r\n,max(Nvl2(val,HAS_SPECIFIC_DSTATUS,NULL))over(partition by point_id, ml_id, da) p\r\nfrom(\r\n select point_id, ml_id, da, bt\r\n ,decode(ssep_id,tsep_id,null,hsd)HAS_SPECIFIC_DSTATUS\r\n ,decode(ssep_id,tsep_id,null,val)val\r\n from(\r\n select sSEP_ID(j) tsep_id, point_id, ml_id,da,bt, HAS_SPECIFIC_DSTATUS hsd, val\r\n ,(select sep_id from pl_data_valid b where sPL_ID(j)=PL_ID and b.pl_t=a.bt\r\n and sAGGS_TYPE_ID(j)=AGGS_TYPE_ID and sSEP_ID(j)=sep_id and Nvl(:7,0)=1) ssep_id\r\n FROM v_ar a WHERE point_id=sPOINT_ID(j) AND ml_id=:2 AND da>=Trunc(s1(j)) AND da<s2\r\n )d\r\n )\r\n)where bad>0) a join a1 c on (a.point_id=c.point_id and a.da=c.da)\r\n) where new_val is not null\r\n) f;\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3059, 7340, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,sum(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=24\r\nthen \'1\' else \'14\'||decode(count(*),24,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3060, 7003, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3, bt+(nr-1)/96 t ,g/(et-bt)/24 v,Decode((et-bt)*96,1,\'1\',\'14\') s\r\nFROM(select * from\r\n(SELECT c1,c2,c3,da,bt, point_id\r\n,Lead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2+1))\r\nWHERE NOT val IS NULL  )r\r\n) f,mou u,iger where f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null and nr<=round((et-bt)*96,6))r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3061, 1413, 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100) INTO pGF FROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nEXECUTE IMMEDIATE \'truncate table gen$p\';\r\nFORALL j IN 1..mi\r\nINSERT INTO gen$p (pl_id,sep_id,point_id,aggs_type_id,s1)\r\nVALUES (sPL_ID(j),sSEP_ID(j),sPOINT_ID(j),sAGGS_TYPE_ID(j),s0);\r\nIF Nvl(:7,0)=0 THEN\r\nMERGE INTO gen$p y\r\nUSING (SELECT /*+ use_nl(a b c) index(c plep_pk)*/ a.pl_id,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=a.s1 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nEND s1\r\nFROM gen$p a\r\njoin plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=a.s1 AND c.plep_bt<s2)\r\nleft join plu b ON (a.pl_id=b.pl_id)\r\nGROUP BY a.pl_id\r\n) u ON (y.pl_id=u.pl_id)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.s1=u.s1\r\nWHERE y.s1<u.s1;\r\nEND IF;\r\nCOMMIT;\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v,Nvl(:7,0),s,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT c1,c2,c3,Trunc(da,\'MM\')t,sum(val)v,case WHEN\r\nMax(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=Add_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\')\r\nthen \'1\' else \'14\'||decode(count(*),Add_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\'),\'\',\'+3\') END s\r\nFROM TABLE(p_ar.p2(CURSOR(SELECT\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,s2,0))\r\nWHERE NOT val IS null\r\nGROUP BY c1,c2,c3,Trunc(da,\'MM\')) r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3062, 9201, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,bt+(nr-1)/24 t,g/(et-bt)/24 v\r\n,CASE WHEN Greatest(h1,h2)=0 AND ((et-bt)*24=1 OR g=0) THEN \'1\' ELSE \'14\' end  s\r\nFROM\r\n(SELECT c1,c2,c3,da,bt, point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val g\r\n,has_specific_dstatus h1\r\n,Lead(has_specific_dstatus) over (PARTITION BY point_id,ml_id ORDER BY da,bt) h2\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2+1))\r\nWHERE NOT val IS NULL AND bt=trunc(bt,\'HH\')\r\n) f,mou u,iger\r\nWHERE f.point_id=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\nAND nr<=round((et-bt)*24,6) ) r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3063, 2363, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(bt,\'HH\') t,Avg(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=12\r\nthen \'1\' else \'14\'||decode(count(*),12,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da,Trunc(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3064, 5754, 'INSERT INTO gttt\r\n(d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\n(SELECT NULL,NULL,s.pl_id,s.sep_id,bt,\'\'\r\n,Decode(s.ml_id\r\n,274,Decode(Round(val),10,:4,9,:6,8,:8,7,:10,6,:12,5,:14,4,:16,3,:18,2,:20,1,:22,0,:24,-1,:26,-2,:28,-3,:30,-4,:32,-5,:34,-6,:36\r\n,-7,:38,-8,:40,-9,:42,-10,:44,-11,:46,-12,:48,-13,:50,-14,:52,-15,:54,-16,:56,-17,:58,-18,:60,-19,:62,-20,:64,-21,:66,-22,:68,-23,:70,-24,:72)\r\n,275,Decode(Round(val),10,:5,9,:7,8,:9,7,:11,6,:13,5,:15,4,:17,3,:19,2,:21,1,:23,0,:25,-1,:27,-2,:29,-3,:31,-4,:33,-5,:35,-6,:37\r\n,-7,:39,-8,:41,-9,:43,-10,:45,-11,:47,-12,:49,-13,:51,-14,:53,-15,:55,-16,:57,-17,:59,-18,:61,-19,:63,-20,:65,-21,:67,-22,:69,-23,:71,-24,:73)\r\n,276,Decode(Round(val),10,:4-:5,9,:6-:7,8,:8-:9,7,:10-:11,6,:12-:13,5,:14-:15,4,:16-:17,3,:18-:19,2,:20-:21,1,:22-:23,0,:24-:25\r\n,-1,:26-:27,-2,:28-:29,-3,:30-:31,-4,:32-:33,-5,:34-:35,-6,:36-:37,-7,:38-:39,-8,:40-:41,-9,:42-:43,-10,:44-:45,-11,:46-:47,-12,:48-:49\r\n,-13,:50-:51,-14,:52-:53,-15,:54-:55,-16,:56-:57,-17,:58-:59,-18,:60-:61,-19,:62-:63,-20,:64-:65,-21,:66-:67,-22,:68-:69,-23,:70-:71,-24,:72-:73)\r\n),0,Decode(a.has_specific_dstatus,0,\'1\',\'14\'),SYSDATE,\'\'\r\n, s.aggs_type_id FROM\r\n(SELECT\r\nA.SEP_ID,D.PL_ID,G.ML_ID, mm.aggs_type_id\r\nfrom sep A\r\njoin SE C on (A.SE_ID=C.SE_ID)\r\njoin SRC K on (C.SRC_ID=K.SRC_ID)\r\njoin SP L on (A.SP_ID=L.SP_ID)\r\njoin PH M on (L.PH_ID=M.PH_ID)\r\njoin DP O ON (K.DP_ID=O.DP_ID)\r\njoin DI D on (C.DI_ID=D.DI_ID)\r\njoin PL G on (D.PL_ID=G.PL_ID)\r\njoin ML mm on (g.ml_id=mm.ml_id)\r\njoin POINT I on (I.POINT_ID=G.POINT_ID)\r\nWHERE\r\nM.PH_DELETED=0 AND ph_enabled=1\r\nAND o.DP_DELETED=0 AND dp_enabled=1\r\nAND (K.SRC_BT IS NULL OR K.SRC_BT<=sysdate)\r\nAND (K.SRC_ET IS NULL OR K.SRC_ET>sysdate)\r\nAND k.src_enabled=1\r\nAND g.pl_enabled=1\r\nAND i.point_enabled=1\r\nAND I.POINT_AUTO_READ_ENABLED=1\r\nAND sep_enabled=1\r\nAND se_enabled=1\r\nAND di_enabled=1\r\nAND g.ml_id in (274,275,276) and src_type_id=0 AND src_name=(SELECT bga_type_name FROM st_bga WHERE bga_id=:0)\r\nAND i.point_code=:2\r\n) s\r\n,st_ar a\r\nWHERE point_code=:1 AND a.ml_id=125 AND da>=SYSDATE-:3 AND da<=SYSDATE\r\nAND val<10.5 AND val>-24.5);\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\nWHERE NOT EXISTS (SELECT 0 FROM pl_data\r\nWHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0);\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\n'),
	(3065, 4678, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(bt,\'HH\') t,Avg(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=4\r\nthen \'1\' else \'14\'||decode(count(*),4,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da,Trunc(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3066, 927, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\ndelete gttt;\r\nFORALL j IN 1..sPL_ID.count\r\nINSERT INTO gttt\r\n(d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT NULL,NULL,sPL_ID(j),sSEP_ID(j),ib\r\n,\'\',Sum(q*l),Nvl(:7,0),Decode(Max(k),0,\'1\',\'14\'),SYSDATE,\'\'\r\n,sAGGS_TYPE_ID(j) FROM (SELECT f.*, w.* ,g/(et-bt)/24 q, TRUNC(f.bt, \'HH\')+(w.column_value-1)/24 ib\r\n,(Least(et,TRUNC(f.bt, \'HH\')+w.column_value /24)-Greatest(bt,TRUNC(f.bt, \'HH\')+(w.column_value-1)/24))*24 l\r\n,CASE WHEN et-bt>=2/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM\r\n(\r\nSELECT bt,\r\nLead(bt) over (ORDER BY bt) et,\r\nLead(val) over (ORDER BY bt)-\r\nCASE WHEN\r\nLead(val) over (ORDER BY bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nfrom\r\n(SELECT bt,val\r\nFROM v_ar\r\nWHERE point_id=sPOINT_ID(j) AND ml_id=:1 AND da>=Nvl(:4,SYSDATE-:3)\r\nAND da<=Nvl(:5,SYSDATE) AND NOT val IS NULL\r\n) r\r\nWHERE NOT EXISTS (\r\nSELECT 0 FROM\r\nst_map_plain p\r\n,st_map_data_plain d\r\nWHERE\r\np.point_id=sPOINT_ID(j) AND p.ml_id=:1 AND\r\np.ma_enabled=1 AND p.ma_auto_check=1 AND p.ma_auto_null_act=1 AND p.map_enabled=1\r\nAND p.map_id=d.map_id(+) AND r.bt=d.mt_time(+)\r\nAND r.bt>=p.bt AND r.bt<Nvl(p.et,r.bt+1)\r\nAND Nvl(d.mt_success,0)=0\r\n)\r\n) f,mou u, TABLE (SELECT CAST(COLLECT(level) AS sql_objects) FROM dual connect by level<=(ROUND(\r\n(CASE\r\nWHEN f.et=trunc(f.et, \'HH\')\r\nTHEN f.et\r\nELSE TRUNC(f.et, \'HH\')+1/24\r\nEND\r\n - TRUNC (f.bt, \'HH\')) * 24, 6))) w WHERE sPOINT_ID(j)=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null) h\r\nGROUP BY ib HAVING Round(Sum(l),6)=1;\r\nSELECT d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 and aggs_type_id=f.id8 AND pl_t=f.d2 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3067, 1475, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3),Nvl(:5+1,SYSDATE),1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,ib t\r\n,Sum(q*l)*2 v,Decode(Max(k),0,\'1\',\'14\') s\r\nFROM\r\n(SELECT f.*\r\n,Trunc(bt)+Trunc(Round((bt-Trunc(bt))*48,6))/48+(d.column_value-1)/48 ib\r\n,g/(et-bt)/48 q\r\n,(Least(et,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*48,6))/48+(d.column_value)/48)-Greatest(bt,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*48,6))/48+(d.column_value-1)/48))*48 l\r\n,CASE WHEN et-bt>=2/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM (SELECT da,bt, c1,c2,c3,point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),Nvl(:5+1,SYSDATE)))\r\nWHERE  NOT val IS NULL) f,mou u, TABLE(SELECT CAST(COLLECT(level) AS sql_objects) FROM dual CONNECT BY Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*48,6))/48+(LEVEL-1)/48<f.et) d\r\nwhere f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\n) h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3068, 1967, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,sum(val)/2 v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=48\r\nthen \'1\' else \'14\'||decode(count(*),48,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3069, 8223, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,sum(val)/4 v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=96\r\nthen \'1\' else \'14\'||decode(count(*),96,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3070, 1990, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n FROM spty\r\n WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(bt,\'HH\') t,Avg(val) v,\r\nCASE WHEN (\r\nTRUNC(bt,\'HH\')+1/24<SYSDATE AND Count(DISTINCT(Trunc((bt - TRUNC(bt, \'HH\'))*24*4)))\r\n>=4) THEN \'1\' ELSE \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,Trunc(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3071, 3257, 'SELECT ml_id BULK COLLECT INTO L FROM ml WHERE (ms_id,dir_id,aggs_id,aggf_id,md_id) IN\r\n(SELECT ms_id,dir_id,aggs_id,aggf_id,md_id FROM ml WHERE ml_id=:1) AND tff_id IN (1,2,3,4);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nDELETE gtts;\r\nFORALL j IN 1..sPL_ID.count\r\nINSERT INTO gtts (id1,d1,d2,v1)\r\nSELECT point_id,da,Max(bt),Sum(val)\r\nFROM ( SELECT point_id,ml_id,da,bt,val,Rank() over (PARTITION BY point_id,ml_id,da,Trunc(bt,\'MI\') ORDER BY bt) rnk\r\nFROM v_ar\r\nWHERE point_id=sPOINT_ID(j)\r\nAND ml_id IN (L(1),L(2),L(3),L(4))\r\nAND da>=Nvl(:4,SYSDATE-:3) AND da<=Nvl(:5,SYSDATE)\r\nAND NOT val IS NULL )\r\nWHERE rnk=1\r\nGROUP BY point_id,da,Trunc(bt,\'MI\')\r\nHAVING Count(*)=4;\r\nDELETE gttt;\r\nFORALL j IN 1..sPL_ID.count\r\nINSERT INTO gttt\r\n(d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT NULL,NULL,sPL_ID(j),sSEP_ID(j),bt\r\n,\'\',Sum(q*l),Nvl(:7,0),\'1\',SYSDATE,\'\',sAGGS_TYPE_ID(j)\r\nFROM (SELECT f.*,bt,greatest(g-\r\nNvl(Sum(Decode(has_specific_dstatus,0,(Least(te,et)-Greatest(tb,bt))*24*val))\r\nover (PARTITION BY id1,tb),0)\r\n,0)/Sum(Decode(has_specific_dstatus,1,(Least(te,et)-Greatest(tb,bt))*24))\r\nover (PARTITION BY id1,tb) q\r\n,Decode(has_specific_dstatus,1,(Least(te,et)-Greatest(tb,bt))*24) l\r\n,CASE WHEN te-tb>=15/24 and not g-\r\nNvl(Sum(Decode(has_specific_dstatus,0,(Least(te,et)-Greatest(tb,bt))*24*val))\r\nover (PARTITION BY id1,tb),0)\r\n=0 THEN 1 ELSE 0 END k\r\nFROM v_ar d,\r\n(SELECT id1,d2 tb\r\n,Lead(d2) over (PARTITION BY id1 ORDER BY d2) te\r\n,Lead(v1) over (PARTITION BY id1 ORDER BY d2)-\r\nCASE WHEN\r\nLead(v1) over (PARTITION BY id1 ORDER BY d2)-v1<-1000\r\n THEN 0 ELSE v1 end g\r\nFROM gtts) f,mou u\r\nWHERE sPOINT_ID(j)=u.point_id (+) AND f.tb<u.mou_bt (+) AND f.te>=u.mou_bt (+) AND u.mou_id IS null\r\nAND d.point_id=sPOINT_ID(j) AND ml_id=:2 AND da>=Nvl(:4,SYSDATE-:3)\r\nAND da<=Nvl(:5,SYSDATE)\r\nAND d.point_id=id1 AND et>tb AND bt<te\r\n) h\r\nGROUP BY bt\r\nHAVING Round(Sum(l),6)=1 AND Max(k)=0;\r\nSELECT d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3072, 1625, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n             FROM spty\r\n            WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nFOR i IN 1..TO_NUMBER(TRUNC(NVL(:5,SYSDATE))-TRUNC(NVL(:4,SYSDATE-:3))) LOOP\r\n  OPEN c_ROWS;\r\n  LOOP\r\n    FETCH c_ROWS\r\n    BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n    LIMIT pGF;\r\n    EXIT WHEN sPL_ID.Count=0;\r\n    FORALL j IN 1..sPL_ID.count\r\n    INSERT INTO gttt\r\n    (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\n    SELECT\r\n    NULL,NULL,sPL_ID(j),sSEP_ID(j),tda,\'\',sum(pl_rv),Nvl(:7,0)\r\n    ,case when Max(HAS_SPECIFIC_DSTATUS)=0 and count(*)=49\r\n    then \'1\' else \'14\'||decode(count(*),49,null,\'+3\') end,SYSDATE,\'\'\r\n    ,sAGGS_TYPE_ID(j) aggs_type_id FROM\r\n    (SELECT da,da as tda, decode(has_act,1,val,case when \'+\'||dstatus like \'%+15%\' then 0 else pl_rv end)/2 as pl_rv\r\n    , case when \'+\'||dstatus like \'%+15%\' then 0 else HAS_SPECIFIC_DSTATUS end HAS_SPECIFIC_DSTATUS\r\n    FROM v_ar\r\n    WHERE point_id=sPOINT_ID(j) AND ml_id in (:1) AND da>=Nvl(:4,SYSDATE-:3)-1 + (i-1)\r\n    AND da<=Nvl(:5,SYSDATE)-1 AND NOT val IS NULL\r\n    union all\r\n    SELECT da, da+1 as tda, decode(has_act,1,val,pl_rv) as pl_rv, HAS_SPECIFIC_DSTATUS\r\n    FROM v_ar\r\n    WHERE point_id=sPOINT_ID(j) AND ml_id in (:2) AND da>=Nvl(:4,SYSDATE-:3)-2 + (i-1)\r\n    AND da<=Nvl(:5,SYSDATE)-2 AND NOT val IS NULL)\r\n    GROUP BY tda;\r\n    SELECT\r\n    d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\n    BULK COLLECT INTO\r\n    pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\n    FROM gttt f\r\n    --/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\n    store_pl_now(pPCK_T,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\n  END LOOP;\r\n  CLOSE c_ROWS;\r\nEND LOOP;'),
	(3073, 5766, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,sML_ID,sSAM_CODE\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nselect level BULK COLLECT INTO pNR from dual connect by level<=mi;\r\nDELETE GTTT;\r\nFORALL j in 1..mi\r\nINSERT INTO GTTT (id0,id1) values (pNR(j),sPL_ID(j));\r\nSELECT d\r\nBULK COLLECT INTO s1\r\nFROM\r\n(SELECT /*+ use_nl(a b c) index(c plep_pk)*/ id0,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END d\r\nFROM\r\ngttt a\r\nleft join plu b ON (a.id1=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.id1=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY id0\r\nORDER BY id0);\r\nDELETE GTTT;\r\nFORALL j IN 1..mi\r\nINSERT INTO gttt (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT\r\nNULL,NULL,sPL_ID(j),sSEP_ID(j),bt,\'\',Decode(Trunc(et),da,f,f+p-Sum(f) over (PARTITION BY da)) v,Nvl(:7,0),d\r\n,SYSDATE,\'\',sAGGS_TYPE_ID(j) FROM\r\n(\r\nSELECT b.bt,b.et,b.da,c.val p,b.val s,Decode(c.has_specific_dstatus,0,\'1\',\'14\')d\r\n,Round(b.val*c.val/Sum(b.val) over (PARTITION BY b.da),6) f\r\nFROM  st_ar_sam b,v_ar c\r\nWHERE c.point_id=sPOINT_ID(j)\r\nAND b.da=c.da AND c.ml_id=sML_ID(j)\r\nAND b.sam_code=sSAM_CODE(j)\r\nAND b.da>=Trunc(s1(j)) AND b.bt>=s1(j) AND b.da<s2\r\nAND NOT c.val IS NULL AND NOT b.val IS null\r\n);\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8  AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3074, 5883, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,avg(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=24\r\nthen \'1\' else \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3075, 7370, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual; select nvl(to_number(:9),0) into p from dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,NVL( add_months(TRUNC(:4,\'MM\'),-1),add_months(TRUNC(sysdate,\'MM\'),-:3 -1) ),NVL( :5,SYSDATE ),1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT\r\nc1,c2,c3,mo1 t,round(delta_val,6) v\r\n,s FROM\r\n(\r\nSELECT b.*,case when (bt>=last_d-nvl(:8,5) and bt<last_d and prev_bt>=prev_last_d-nvl(:8,5) and prev_bt<prev_last_d)\r\nand (HAS_SPECIFIC_DSTATUS=0 and prev_HAS_SPECIFIC_DSTATUS=0) AND NOT (mo1=TRUNC(sysdate,\'MM\')) then 1 else 14\r\nend s\r\nFROM (SELECT a.*\r\n,val-lag(val) over (PARTITION by point_id,ml_id order by da) delta_val\r\n,lag(val) over (PARTITION by point_id,ml_id order by da) prev_val\r\n,lag(bt) over (PARTITION by point_id,ml_id order by da) prev_bt ,case when p=0 then mo when p=1 then add_months(mo,-1) end mo1\r\n,lag(HAS_SPECIFIC_DSTATUS) over (PARTITION by point_id,ml_id order by da) prev_HAS_SPECIFIC_DSTATUS\r\n,case when p=0 then last_day(mo)+1\r\n      when p=1 then mo+nvl(:8,5) end last_d\r\n,case when p=0 then last_day(add_months(mo,-1))+1\r\n      when p=1 then add_months(mo,-1)+nvl(:8,5) end prev_last_d\r\nFROM\r\n(SELECT c1,c2,c3,point_id,ml_id,da,bt,trunc(da,\'MM\') mo,val,HAS_SPECIFIC_DSTATUS\r\n,case when p=0 then rank() over (PARTITION by point_id,ml_id,trunc(da,\'MM\') order by da desc,bt desc)\r\n      when p=1 then rank() over (PARTITION by point_id,ml_id,trunc(da,\'MM\') order by da asc,bt asc)\r\n end rnk\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),NVL( :5,SYSDATE )))\r\nWHERE NOT val IS NULL\r\norder by ml_id,da desc,bt desc\r\n) a where rnk=1) b,mou u\r\nWHERE b.POINT_ID=u.point_id (+) AND b.prev_bt<u.mou_bt (+) AND b.bt>=u.mou_bt (+) AND u.mou_id IS null\r\n) where delta_val IS not NULL)r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3076, 561, 's0:=Trunc(Nvl(:4,add_months(trunc(SYSDATE,\'MM\'),-1*:3)));\r\ns2:=Nvl(add_months(Trunc(:5,\'MM\'),1),trunc(SYSDATE,\'MM\'));\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',round(mval,6), Nvl(:7,0),\r\nstatus,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n( select * from(\r\nSELECT c1,c2,c3,Add_Months(da, nvl(:8, 0))t,\r\n da,val,lead(val) over (PARTITION BY f.point_id order by da)-val mval\r\n,case when HAS_SPECIFIC_DSTATUS=0 and lead(HAS_SPECIFIC_DSTATUS) over (PARTITION BY f.point_id order by da)=0 then \'1\' else \'14\' end status\r\n,MONTHS_BETWEEN(lead(da) over (PARTITION BY f.point_id order by da),da) mb\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1 and s1<s2 ),Trunc(d.s1),s2+1,0))\r\n f,mou u where f.point_id=u.point_id (+) AND f.da<u.mou_bt (+) AND add_months(f.da,1)>=u.mou_bt (+) AND u.mou_id IS null\r\nand\r\nNOT val IS NULL AND u.point_id IS null\r\n) where mb=1)r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3077, 3996, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3),Nvl(:5+1,SYSDATE),1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,ib t\r\n,Sum(q*l) v,Decode(Max(k),0,\'1\',\'14\') s\r\nFROM\r\n(SELECT f.*,Trunc(bt)+Trunc(Round((bt-Trunc(bt))*48,6))/48+(d.column_value-1)/48 ib,g/(et-bt)/48 q\r\n,(Least(et,Trunc(bt)+Trunc(Round((bt-Trunc(bt))*48,6))/48+d.column_value/48)-Greatest(bt,Trunc(bt)+Trunc(Round((bt-Trunc(bt))*48,6))/48+(d.column_value-1)/48))*48 l\r\n,CASE WHEN et-bt>=2/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM ( SELECT da,bt, c1,c2,c3,point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,Nvl(:5+1,SYSDATE)))\r\nWHERE NOT val IS NULL) f,mou u, TABLE(SELECT CAST(COLLECT(level) AS tn) FROM dual CONNECT BY Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*48,6))/48+(LEVEL-1)/48<f.et) d\r\nwhere f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\n) h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3078, 7801, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3),Nvl(:5+1,SYSDATE),1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT c1,c2,c3, ib t\r\n,Sum(q*l) v,Decode(Max(k),0,\'1\',\'14\') s\r\nFROM (SELECT f.*,d.*,g/(et-bt)/24 q\r\n,(Least(et,ie)-Greatest(bt,ib))*24 l\r\n,CASE WHEN et-bt>=2/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM(SELECT da,bt,c1,c2,c3,point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et,\r\nLead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN\r\nLead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\nTHEN 0 ELSE val end g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),Nvl(:5+1,SYSDATE)))\r\nWHERE\r\nNOT val IS NULL\r\n) f,mou u,(SELECT da y,da+(nr-1)/24 ib,da+nr/24 ie FROM days,iger WHERE nr<=24) d\r\nWHERE f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\nand (NOT y+1<=bt AND NOT y>=et AND NOT ie<=bt AND NOT ib>=et)) h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3079, 247, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nselect md_cnt,aggf_id into cnt1,gf1 from st_ml where ml_id=:1;\r\nselect md_cnt into cnt2 from st_ml where ml_id=:2;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT /*da*/trunc(bt-(nvl(:8,0)/1440))+Trunc(Round((/*bt*/bt-(nvl(:8,0)/1440)-/*da*/trunc(bt-(nvl(:8,0)/1440)))*cnt2,6))/cnt2 t,c1,c2,c3,point_id, sum(val*Decode(gf1,3,24/cnt1,1)) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0 and count(*)*cnt2=cnt1\r\nthen \'1\' else \'14\'||decode(count(*)*cnt2,cnt1,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1)+(nvl(:8,0)/1440),s2+(nvl(:8,0)/1440)))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,point_id,/*da*/trunc(bt-(nvl(:8,0)/1440)),/*da*/trunc(bt-(nvl(:8,0)/1440))+Trunc(Round((/*bt*/bt-(nvl(:8,0)/1440)-/*da*/trunc(bt-(nvl(:8,0)/1440)))*cnt2,6))/cnt2 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3080, 2988, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT md_cnt,aggf_id INTO cnt2,gf2 FROM st_ml where ml_id=:2;\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,bt+(nr-1)/cnt2 t,g/(et-bt)/Decode(gf2,3,24,cnt2) v\r\n,CASE WHEN Greatest(h1,h2)=0 AND (Round((et-bt)*cnt2,6)=1 OR g=0) THEN \'1\' ELSE \'14\' END s\r\nFROM\r\n(SELECT c1,c2,c3,da,bt, point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val g\r\n,has_specific_dstatus h1\r\n,Lead(has_specific_dstatus) over (PARTITION BY point_id,ml_id ORDER BY da,bt) h2\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2+1))\r\nWHERE NOT val IS NULL AND bt=da+Trunc(Round((bt-da)*cnt2,6))/cnt2\r\n) f,mou u,iger\r\nWHERE f.point_id=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\nAND nr<=round((et-bt)*cnt2,6) ) r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3081, 964, 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(da,\'MM\') t,avg(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=Add_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\')\r\nthen \'1\' else \'14\'||decode(count(*),\r\nAdd_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\'),null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),Trunc(d.s1,\'MM\'),s2,0))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,Trunc(da,\'MM\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3082, 8358, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3, da t,\r\n Max(Decode(bitand(val,Power(2,7)),Power(2,7),1,0))*Power(2,7)\r\n+Max(Decode(bitand(val,Power(2,6)),Power(2,6),1,0))*Power(2,6)\r\n+Max(Decode(bitand(val,Power(2,5)),Power(2,5),1,0))*Power(2,5)\r\n+Max(Decode(bitand(val,Power(2,4)),Power(2,4),1,0))*Power(2,4)\r\n+Max(Decode(bitand(val,Power(2,3)),Power(2,3),1,0))*Power(2,3)\r\n+Max(Decode(bitand(val,Power(2,2)),Power(2,2),1,0))*Power(2,2)\r\n+Max(Decode(bitand(val,Power(2,1)),Power(2,1),1,0))*Power(2,1)\r\n+Max(Decode(bitand(val,Power(2,0)),Power(2,0),1,0))*Power(2,0) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0 and count(*)=24\r\nthen \'1\' else \'14\'||decode(count(*),24,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3083, 9577, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT d.ib t,c1,c2,c3,point_id, Avg(val) v,\r\nCASE WHEN\r\n(d.ib+1/48<SYSDATE AND Count(DISTINCT(Trunc((bt - d.ib)*48*4)))\r\n>=4) THEN \'1\' ELSE \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\n a join (SELECT da y,da+(nr-1)/48 ib,da+nr/48 ie FROM days,iger WHERE nr<=48) d\r\nON (NOT y+1<=bt AND NOT y>=et AND NOT ie<=bt AND NOT ib>=et)\r\nWHERE NOT val IS NULL AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,point_id,d.ib )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3084, 9752, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nSELECT md_cnt,aggf_id\r\nINTO cnt1,gf1\r\nFROM st_ml\r\nWHERE ml_id=:1;\r\nSELECT md_cnt\r\nINTO cnt2\r\nFROM st_ml\r\nWHERE ml_id=:2;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da+Trunc(Round((bt-da)*cnt2,6))/cnt2 t,Avg(val*Decode(gf1,3,1,cnt1/24)) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0 and count(*)*cnt2=cnt1\r\nthen \'1\' else \'14\'||decode(count(*)*cnt2,cnt1,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da,da+Trunc(Round((bt-da)*cnt2,6))/cnt2 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3085, 9205, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,MAX(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=24\r\nthen \'1\' else \'14\'||decode(count(*),24,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3086, 1975, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nselect level BULK COLLECT INTO pNR from dual connect by level<=mi;\r\nDELETE GTTT;\r\nFORALL j in 1..mi\r\nINSERT INTO GTTT (id0,id1) values (pNR(j),sPL_ID(j));\r\nSELECT d\r\nBULK COLLECT INTO s1\r\nFROM\r\n(SELECT /*+ use_nl(a b c) index(c plep_pk)*/ id0,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END d\r\nFROM\r\ngttt a\r\nleft join plu b ON (a.id1=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.id1=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY id0\r\nORDER BY id0);\r\nDELETE GTTT;\r\nFORALL j IN 1..mi\r\nINSERT INTO gttt (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT NULL,NULL,sPL_ID(j),sSEP_ID(j),Trunc(bt,\'HH\'),\'\'\r\n,Avg(val),Nvl(:7,0),Decode(Max(HAS_SPECIFIC_DSTATUS),0,\'1\',\'14\'),SYSDATE,\'\'\r\n,sAGGS_TYPE_ID(j) FROM v_ar_wo_byp\r\nWHERE point_id=sPOINT_ID(j) AND ml_id=:1 AND da>=Trunc(s1(j)) AND bt>=s1(j) AND da<s2\r\nAND NOT val IS NULL\r\nGROUP BY Trunc(bt,\'HH\')\r\nHAVING Count(*)=2;\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8  AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3087, 3943, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n  FROM spty\r\n WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nSELECT aggf_id\r\n  INTO gf1\r\n  FROM st_ml\r\n WHERE ml_id=:1;\r\nSELECT tff_id, md_id\r\n  INTO v_ttf_id, v_md_id\r\n  FROM st_ml\r\n WHERE ml_id=:2;\r\nif v_md_id = 6 then\r\n  s0:=Trunc(Nvl(:4,SYSDATE-:3), \'MM\');\r\n  s2:=Nvl(Add_Months(Trunc(:5, \'MM\'),1),SYSDATE);\r\nelse\r\n  s0:=Trunc(Nvl(:4,SYSDATE-:3));\r\n  s2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nend if;\r\nOPEN c_ROWS ( gf1 );\r\nLOOP\r\n  FETCH c_ROWS\r\n  BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,sAGGF_ID,s1\r\n  LIMIT pGF;\r\n  EXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0),sAGGF_ID,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\',ex\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,pEXTREME_T\r\nFROM\r\n(SELECT c1,c2,c3,c4,\r\n   case when v_md_id = 6 then TRUNC(BT, \'MM\') else TRUNC(BT, \'DD\') end t\r\n   ,val v\r\n   ,CASE WHEN ST=1 OR SYSDATE<aET THEN \'14\' ELSE \'1\' END s\r\n   ,CASE WHEN (select aggf_id from ml where ml_id=:1) IN (4,5) THEN EXTREME_BT ELSE BT END ex\r\n  FROM\r\n    (select a.*\r\n    ,rank() over (partition by point_id, ml_id,\r\n     case when v_md_id = 6 then TRUNC(BT, \'MM\') else TRUNC(BT, \'DD\') end\r\n     order by HAS_SPECIFIC_DSTATUS, VAL desc, BT) rnkmx\r\n    ,rank() over (partition by point_id, ml_id,\r\n     case when v_md_id = 6 then TRUNC(BT, \'MM\') else TRUNC(BT, \'DD\') end\r\n     order by HAS_SPECIFIC_DSTATUS, -VAL desc, BT) rnkmn\r\n    ,max(HAS_SPECIFIC_DSTATUS) over (PARTITION BY POINT_ID, ML_ID,\r\n    case when v_md_id = 6 then TRUNC(BT, \'MM\') else TRUNC(BT, \'DD\') end) st,\r\n    case when v_md_id = 6 then TRUNC(add_months(BT,1), \'MM\')+1 else TRUNC(BT, \'DD\')+1 end aET\r\n    from\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,param1,\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\n    a where tff_id=v_ttf_id )\r\n    WHERE   ((rnkmx=1 and c4=4) or (rnkmn=1 and c4=5))\r\n    and val is not null and bt is not null) r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans,pPCK_T,pPCK_N,pPCK_T,pPCK_N,pEXTREME_T);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3088, 1348, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,MIN(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=24\r\nthen \'1\' else \'14\'||decode(count(*),24,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3089, 428, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,TRUNC(bt, \'HH\') t,MAX(val) v,\r\nCASE WHEN (\r\nTRUNC(bt,\'HH\')+1/24<SYSDATE AND Count(DISTINCT(Trunc((bt - TRUNC(bt, \'HH\'))*24*4)))\r\n>=4) THEN \'1\' ELSE \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,TRUNC(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3090, 9319, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,TRUNC(bt, \'HH\') t,MIN(val) v,\r\nCASE WHEN (\r\nTRUNC(bt,\'HH\')+1/24<SYSDATE AND Count(DISTINCT(Trunc((bt - TRUNC(bt, \'HH\'))*24*4)))\r\n>=4) THEN \'1\' ELSE \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,TRUNC(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3091, 2240, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(da,\'MM\') t,MAX(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=Add_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\')\r\nthen \'1\' else \'14\'||decode(count(*),\r\nAdd_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\'),null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,Trunc(da,\'MM\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3092, 644, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(da,\'MM\') t,MIN(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=Add_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\')\r\nthen \'1\' else \'14\'||decode(count(*),\r\nAdd_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\'),null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,Trunc(da,\'MM\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3093, 5178, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM(SELECT c1,c2,c3,Trunc(bt,\'HH\') t,Avg(val) v,Decode(Max(HAS_SPECIFIC_DSTATUS),0,\'1\',\'14\') s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id, :1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,Trunc(bt,\'HH\')\r\nHAVING Count(*)=2)r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nFORALL j IN 1..sPL_ID.count\r\nINSERT INTO gttt\r\n(d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT NULL,NULL,sPL_ID(j),sSEP_ID(j),Trunc(bt,\'HH\'),\'1\'\r\n,Avg(val),Nvl(:7,0),Decode(Max(HAS_SPECIFIC_DSTATUS),0,\'1\',\'14\'),SYSDATE,1\r\n,sAGGS_TYPE_ID(j) FROM v_ar_ah\r\nWHERE point_id=sPOINT_ID(j) AND ml_id=:1 AND da>=Trunc(s0) AND bt>=s0 AND da<s2\r\nAND NOT val IS NULL\r\nGROUP BY Trunc(bt,\'HH\')\r\nHAVING Count(*)=2;\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_ah_data_valid WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3094, 7135, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n             FROM spty\r\n            WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nSELECT md_cnt,aggf_id\r\n  INTO cnt1,gf1\r\n  FROM st_ml\r\n WHERE ml_id=:1;\r\nSELECT md_cnt,tff_id\r\n  INTO cnt2,v_tff_id\r\n  FROM st_ml\r\n WHERE ml_id=:2;\r\nOPEN c_ROWS ( gf1 );\r\nLOOP\r\n  FETCH c_ROWS\r\n  BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1\r\n  LIMIT pGF;\r\n  EXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT da+TRUNC(ROUND((bt-da)*cnt2,6))/cnt2 t,c1,c2,c3,point_id, NVL(SUM( DECODE( tff_ID, v_tff_id, VAL * DECODE( gf1, 3, 24/cnt1 ,1))),0) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0 and count(*)*cnt2=cnt1\r\nthen \'1\' else \'14\'||decode(count(*)*cnt2,cnt1,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,point_id,da,da+TRUNC(ROUND((bt-da)*cnt2,6))/cnt2 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3095, 7995, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nSELECT ML_ID\r\nINTO L\r\nFROM ML\r\nWHERE (MS_ID,DIR_ID,AGGS_ID,AGGF_ID,TFF_ID,MD_ID)\r\nIN (SELECT MS_ID,DIR_ID,AGGS_ID,AGGF_ID,TFF_ID,6\r\nFROM ML\r\nWHERE ML_ID = :2);\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM(SELECT c1,c2,c3,t,v\r\n,Decode(z,0,\'1\',\'14\') s FROM\r\n(SELECT c1,c2,c3,Decode(i,1,da,da+1) t\r\n,Max(Decode(i,1,val)) over (PARTITION BY point_id,m)+Decode(i,1,0,Sum(Decode(i,1,NULL,val)) over (PARTITION BY point_id,m ORDER BY da)) v\r\n,Decode(i,1,s,Max(s) over (PARTITION BY point_id,m ORDER BY da)) z,m,da from\r\n(SELECT a.*,Decode(val,NULL,2,has_specific_dstatus) s,Trunc(da,\'MM\') m,Decode(ml_id,L,1) i\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id, column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,L))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1,\'MM\'),s2))\r\n a )\r\n) WHERE z<2 AND m=Trunc(da+1,\'MM\'))r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3096, 8669, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,sAGGF_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0),sAGGF_ID);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\',ex\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,pEXTREME_T\r\nFROM\r\n(SELECT c1,c2, c3, TRUNC(BT, \'DD\') t, val v,\r\nCASE WHEN ST=1 OR SYSDATE<aET THEN \'14\' ELSE \'1\' END s, CASE WHEN (select aggf_id from ml where ml_id=:1) IN (4,5) THEN EXTREME_BT ELSE BT END ex\r\nFROM (select a.*,\r\nrank() over (partition by point_id, ml_id, TRUNC(BT, \'DD\') order by HAS_SPECIFIC_DSTATUS, VAL desc, BT desc) rnkmx\r\n,rank() over (partition by point_id, ml_id, TRUNC(BT, \'DD\') order by HAS_SPECIFIC_DSTATUS, -VAL desc, BT desc) rnkmn\r\n,max(HAS_SPECIFIC_DSTATUS) over (PARTITION BY POINT_ID, ML_ID, TRUNC(BT, \'DD\')) st,\r\nTRUNC(BT, \'DD\')+1 aET\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,param1,\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\n a\r\n) where ((rnkmx=1 and c4=4) or (rnkmn=1 and c4=5)) and not val is null and not bt is null) r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans,pPCK_T,pPCK_N,pPCK_T,pPCK_N,pEXTREME_T);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3097, 4048, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,sAGGF_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0),sAGGF_ID);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\',ex\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,pEXTREME_T\r\nFROM\r\n(SELECT c1,c2, c3, TRUNC(BT,\'HH\') t, val v,\r\nCASE WHEN ST=1 OR SYSDATE<aET THEN \'14\' ELSE \'1\' END s, CASE WHEN (select aggf_id from ml where ml_id=:1) IN (4,5) THEN EXTREME_BT ELSE BT END ex\r\nFROM (select a.*,\r\nrank() over (partition by point_id,ml_id,TRUNC(BT,\'HH\') order by HAS_SPECIFIC_DSTATUS,VAL desc,BT desc) rnkmx\r\n,rank() over (partition by point_id,ml_id,TRUNC(BT,\'HH\') order by HAS_SPECIFIC_DSTATUS,-VAL desc,BT desc) rnkmn\r\n,max(HAS_SPECIFIC_DSTATUS) over (PARTITION BY POINT_ID,ML_ID,TRUNC(BT,\'DD\')) st,\r\nTRUNC(BT,\'HH\')+1/24 aET\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,param1,\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\n a\r\n) where ((rnkmx=1 and c4=4) or (rnkmn=1 and c4=5)) and not val is null and not bt is null ) r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans,pPCK_T,pPCK_N,pPCK_T,pPCK_N,pEXTREME_T);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3098, 9380, 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,sAGGF_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0),sAGGF_ID);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\',ex\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,pEXTREME_T\r\nFROM\r\n(SELECT c1,c2, c3, TRUNC(BT, \'MM\') t, val v,\r\nCASE WHEN ST=1 OR SYSDATE<aET THEN \'14\' ELSE \'1\' END s, CASE WHEN (select aggf_id from ml where ml_id=:1) IN (4,5) THEN EXTREME_BT ELSE BT END ex\r\nFROM (select a.*,\r\nrank() over (partition by point_id, ml_id, TRUNC(BT, \'MM\') order by HAS_SPECIFIC_DSTATUS, VAL desc, BT desc) rnkmx\r\n,rank() over (partition by point_id, ml_id, TRUNC(BT, \'MM\') order by HAS_SPECIFIC_DSTATUS, -VAL desc, BT desc) rnkmn\r\n,max(HAS_SPECIFIC_DSTATUS) over (PARTITION BY POINT_ID, ML_ID, TRUNC(BT, \'DD\')) st,\r\nADD_MONTHS(TRUNC(BT, \'MM\'),1) aET\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,param1,\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\n a\r\n) where ((rnkmx=1 and c4=4) or (rnkmn=1 and c4=5)) and not val is null and not bt is null) r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans,pPCK_T,pPCK_N,pPCK_T,pPCK_N,pEXTREME_T);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3099, 4916, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3),Nvl(:5+1,SYSDATE),1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,ib t\r\n,round(Sum(q*l)*30,6) v,Decode(Max(k),0,\'1\',\'14\') s\r\nFROM\r\n(SELECT f.*\r\n,Trunc(bt)+Trunc(Round((bt-Trunc(bt))*720,6))/720+(d.column_value-1)/720 ib\r\n,g/(et-bt)/720 q\r\n,(Least(et,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*720,6))/720+(d.column_value)/720)-Greatest(bt,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*720,6))/720+(d.column_value-1)/720))*720 l\r\n,CASE WHEN et-bt>=5/1440 and not g=0 THEN 1 ELSE 0 END k\r\nFROM (SELECT da,bt, c1,c2,c3,point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),Nvl(:5+1,SYSDATE)))\r\nWHERE NOT val IS NULL) f,mou u, TABLE(SELECT CAST(COLLECT(level) AS sql_objects) FROM dual CONNECT BY Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*720,6))/720+(LEVEL-1)/720<f.et) d\r\nwhere f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\n) h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3100, 9199, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))FROM spty WHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF FROM dual;\r\nselect b.ml_id into m1 from st_ml a , st_ml b where a.ml_id=:1 and\r\na.MS_ID=b.ms_id and a.DIR_ID=b.dir_id and a.tff_id=b.TFF_ID and a.AGGF_ID=b.aggf_id\r\nand b.aggs_id=8 and a.aggs_id=5 and a.md_id=5 and b.MD_ID=7;\r\nOPEN c_ROWS;\r\nLOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1 LIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,v,Decode(s,0,\'1\',\'14\') s FROM\r\n(SELECT c1,c2,c3,da,bt,read_time, val,ml_id,read_time_day,count(*) over (partition by point_id,da) cnt\r\n,max(decode(ml_id,m1,val))over(partition by point_id,da)-max(decode(ml_id,:1,val))over(partition by point_id,da) v,s\r\nfrom(SELECT point_id,c1,c2,c3,da,bt,read_time,val,ml_id,read_time_day,rank() over (partition by point_id,da,ml_id order by s,bt) rnk,s\r\nfrom(SELECT point_id,c1,c2,c3,da,bt,read_time,val,ml_id,max(decode(ml_id,:1,read_time)) over (partition by point_id,da) read_time_day\r\n,decode(ml_id,m1,HAS_SPECIFIC_DSTATUS) s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,m1))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL)\r\nwhere abs(decode(ml_id,m1,bt,read_time)-read_time_day)<=nvl(:8,5)/86400\r\nand read_time_day-da>=nvl(:9,0)/1440) where rnk=1) where cnt=2 AND ml_id=m1)r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3101, 8100, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO\r\nsSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,bt+(nr-1) t,g/(et-bt) v\r\n,Decode((et-bt),1,\'1\',\'14\') s\r\nFROM\r\n(SELECT c1,c2,c3,da,bt, point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2+1))\r\nWHERE NOT val IS NULL AND bt=da\r\n) f,mou u,iger\r\nWHERE f.point_id=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\nAND nr<=round((et-bt),6) ) r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3102, 8077, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,ib t\r\n,Sum(q*l)*2 v,Decode(Max(k),0,\'1\',\'14\') s\r\nFROM\r\n(SELECT f.*,g/(et-bt)/48 q, (Least(et,ib+1/48)-Greatest(bt,ib))*48 l\r\n,CASE WHEN et-bt>=2/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM (SELECT da,bt,c1,c2,c3,point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et,\r\nCASE WHEN (bt-trunc(bt,\'HH\'))*24*60 BETWEEN 0 and 29 THEN TRUNC(bt, \'HH\') ELSE TRUNC(bt, \'HH\')+1/48 END ib\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL) f,mou u, TABLE(SELECT CAST(COLLECT(level) AS sql_objects) FROM dual CONNECT BY Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*720,6))/720+(LEVEL-1)/720<f.et) d\r\nwhere f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\n) h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3103, 4815, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n             FROM spty\r\n            WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nOPEN c_ROWS ( s0, s2);\r\nLOOP\r\n  FETCH c_ROWS\r\n  BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1\r\n  LIMIT pGF;\r\n  EXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n    (select c1,c2,c3,d t,v,\'1\' s\r\n    FROM (select b.*\r\n    ,Rank() over (PARTITION BY point_id,d ORDER BY i)r from\r\n    (select point_id,c1,c2,c3,i,d,Sum(v)v FROM\r\n    (select v.point_id,c1,c2,c3,i,da+Decode(i,2,Decode(ml_id,:1,0,-1),1) d,\r\n    case when ml_id=:1 and i=2 then -1 else 1 end*val v\r\n     from\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,:2))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1)-1,s2))\r\n     v,(SELECT LEVEL i FROM dual CONNECT BY LEVEL<=2),\r\n         (SELECT DISTINCT point_id, Trunc(mou_bt) m FROM mou) u\r\n    WHERE v.point_id = u.point_id(+)\r\n      AND v.da = u.m (+)\r\n      AND u.point_id IS NULL\r\n      AND v.has_specific_dstatus=0\r\n    ) GROUP BY point_id,c1,c2,c3,i,d having Count(*)=2\r\n    ) b\r\n    ) WHERE r=1)r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3104, 1738, 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS (s0, s2);\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(select c1,c2,c3,d t,v,\'1\' s\r\nFROM (select b.*\r\n,Rank() over (PARTITION BY point_id,d ORDER BY i)r from\r\n(select point_id,c1,c2,c3,i,d,Sum(v)v FROM\r\n(select v.point_id,c1,c2,c3,i, ADD_MONTHS(da,Decode(i,2,Decode(ml_id,:1,0,-1),1)) d,\r\ncase when ml_id=:1 and i=2 then -1 else 1 end*val v\r\nfrom\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,:2))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1)-1,s2))\r\n v,(select level i from dual connect by level<=2)\r\n,(SELECT DISTINCT point_id, Trunc(mou_bt,\'MM\') m FROM mou) u\r\nwhere v.point_id = u.point_id(+)\r\nAND v.da = u.m (+)\r\nAND u.point_id IS NULL\r\nAND v.has_specific_dstatus=0\r\n) GROUP BY point_id,c1,c2,c3,i,d having Count(*)=2\r\n) b\r\n) where r=1)r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3105, 1845, 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))FROM spty WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF FROM dual;\r\nselect b.ml_id into m1 from st_ml a , st_ml b where a.ml_id=:1 and\r\na.MS_ID=b.ms_id and a.DIR_ID=b.dir_id and a.tff_id=b.TFF_ID and a.AGGF_ID=b.aggf_id\r\nand b.aggs_id=8 and a.aggs_id=6 and a.md_id=6 and b.MD_ID=7;\r\nOPEN c_ROWS; LOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1 LIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,mo t,v,Decode(s,0,\'1\',\'14\') s FROM\r\n(SELECT c1,c2,c3,bt,read_time, val,ml_id,read_time_mon,count(*) over (partition by point_id,mo) cnt\r\n,max(decode(ml_id,m1,val))over(partition by point_id,mo)-max(decode(ml_id,:1,val))over(partition by point_id,mo) v,s,mo\r\nfrom(SELECT point_id,c1,c2,c3,bt,read_time,val,ml_id,read_time_mon,rank() over (partition by point_id,mo,ml_id order by s,bt) rnk,s,mo\r\nfrom(SELECT point_id,c1,c2,c3,bt,read_time,val,ml_id,max(decode(ml_id,:1,read_time)) over (partition by point_id,trunc(da,\'MM\')) read_time_mon\r\n,decode(ml_id,m1,HAS_SPECIFIC_DSTATUS) s,trunc(da,\'MM\') mo\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,m1))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL)\r\nwhere abs(decode(ml_id,m1,bt,read_time)-read_time_mon)<=nvl(:8,5)/86400\r\nand read_time_mon-mo>=nvl(:9,0)/1440) where rnk=1) where cnt=2 AND ml_id=m1)r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3106, 5576, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nselect level BULK COLLECT INTO pNR from dual connect by level<=mi;\r\nDELETE GTTT;\r\nFORALL j in 1..mi\r\nINSERT INTO GTTT (id0,id1) values (pNR(j),sPL_ID(j));\r\nSELECT d\r\nBULK COLLECT INTO s1\r\nFROM\r\n(SELECT /*+ use_nl(a b c) index(c plep_pk)*/ id0,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END d\r\nFROM\r\ngttt a\r\nleft join plu b ON (a.id1=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.id1=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY id0\r\nORDER BY id0);\r\nDELETE GTTT;\r\nFORALL j IN 1..mi\r\nINSERT INTO gttt (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT\r\nNULL,NULL,sPL_ID(j),sSEP_ID(j),xfe_t,\'\',xfe_v,Nvl(:7,0)\r\n,CASE WHEN improvable=0 THEN \'1\' ELSE \'14\' END,SYSDATE,\'\',sAGGS_TYPE_ID(j) aggs_type_id\r\nfrom\r\n(SELECT xfe_t,xfe_v,improvable\r\n,Rank() over (PARTITION BY point_id,ml_id,xfe_t ORDER BY xo_id desc) r\r\nFROM xfe_pl_data join xfe USING (xfe_id) join xfau USING (xfau_id) join xfa USING (xfa_id) join xf USING (xf_id)\r\nWHERE point_id=sPOINT_ID(j) AND ml_id=:1 AND xfe_t>=s1(j) AND xfe_t<s2\r\nAND regexp_like(xf_type_id,\'^(\'||Nvl(:8,\'1|6\')||\')$\')\r\n) WHERE r=1;\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3107, 2555, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))FROM spty WHERE spty.spty_code=\'GENERATION_FETCH\'),100)INTO pGF FROM dual;\r\nselect nvl(to_number(:9),0)into p from dual;select md_id into m from ml where ml_id=:1;\r\nif m=5 and p=2 then p:=1; end if; OPEN c_ROWS;LOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID LIMIT pGF; EXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3),Nvl(:5+1,SYSDATE),1);\r\nFOR d IN(SELECT DISTINCT Trunc(s1,\'MI\')s1 FROM gen$p)loop\r\nif p=0 then SELECT \'\',\'\',c1,c2,t,\'\',v,Nvl(:7,0),s,SYSDATE,\'\'\r\nBULK COLLECT INTO pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM(SELECT c1,c2,c3,ib t,\'\',Sum(q*l)v,Decode(Max(k),0,\'1\',\'14\')s\r\nFROM(SELECT f.*,Trunc(bt)+Trunc(Round((bt-Trunc(bt)),6))+(d.column_value-1)ib\r\n,g/(et-bt)q,(Least(et,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt)),6))+(d.column_value))-Greatest(bt,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt)),6))+(d.column_value-1)))l\r\n,CASE WHEN et-bt>=36/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM(SELECT da,bt,c1,c2,c3,point_id,\r\nLead(bt)over(PARTITION BY point_id,ml_id ORDER BY da,bt)et\r\n,Lead(val)over(PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN Lead(val)over(PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\nTHEN 0 ELSE val end g FROM\r\ntable(p_ar.p2(cursor(select point_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM gen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,Nvl(:5+1,SYSDATE)))\r\nWHERE NOT val IS NULL)f,mou u,TABLE(SELECT CAST(COLLECT(level)AS sql_objects)FROM dual CONNECT BY Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt)),6))+(LEVEL-1)<f.et)d\r\nwhere f.POINT_ID=u.point_id(+)AND f.bt<u.mou_bt(+)AND f.et>=u.mou_bt(+)AND u.mou_id IS null)h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists(SELECT 0 FROM pl_data  WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nelse SELECT \'\',\'\',c1,c2,t,\'\',v,Nvl(:7,0),s,SYSDATE,\'\'\r\nBULK COLLECT INTO pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM(SELECT c1,c2,c3,decode(p,1,da-1,2,da)t,\'\',round(delta_val,6)v,s\r\nFROM(SELECT b.*,\r\ncase when(HAS_SPECIFIC_DSTATUS=0 and prev_HAS_SPECIFIC_DSTATUS=0)AND NOT(da=TRUNC(sysdate,\'DD\'))then 1 else 14\r\nend s FROM(SELECT a.*\r\n,val-lag(val)over(PARTITION by point_id,ml_id order by da)delta_val\r\n,lag(val)over(PARTITION by point_id,ml_id order by da)prev_val\r\n,lag(bt)over(PARTITION by point_id,ml_id order by da)prev_bt\r\n,lag(HAS_SPECIFIC_DSTATUS)over(PARTITION by point_id,ml_id order by da)prev_HAS_SPECIFIC_DSTATUS\r\nFROM(SELECT c1,c2,c3,point_id,ml_id,da,bt,val,HAS_SPECIFIC_DSTATUS\r\n,case when p=2 then rank()over(PARTITION by point_id,ml_id,da order by bt desc)\r\nwhen p=1 then rank()over(PARTITION by point_id,ml_id,da order by bt asc)\r\nend rnk\r\nFROM table(p_ar.p2(cursor(select point_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM gen$p WHERE Trunc(s1,\'MI\')=d.s1),d.s1-1,Nvl(:5+1,SYSDATE)+1))\r\nWHERE NOT val IS NULL )a where rnk=1)b,mou u\r\nWHERE b.POINT_ID=u.point_id(+)AND b.prev_bt<u.mou_bt(+)AND b.bt>=u.mou_bt(+)AND u.mou_id IS null\r\n)where delta_val>=0)r\r\n--/7 where not exists(SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;end if;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP; END LOOP; CLOSE c_ROWS;'),
	(3108, 5566, 's0:=Trunc(Nvl(:4,SYSDATE-:3)); s2:=Nvl(Trunc(:5)+1,SYSDATE); SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty WHERE spty.spty_code=\'GENERATION_FETCH\'), 100) INTO pGF FROM dual;\r\nOPEN c_ROWS; LOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID LIMIT pGF;\r\nmi:=sPL_ID.Count; EXIT WHEN mi=0; select level BULK COLLECT INTO pNR from dual connect by level<=mi;\r\nDELETE GTTT; FORALL j in 1..mi INSERT INTO GTTT (id0,id1) values (pNR(j),sPL_ID(j));\r\nSELECT d BULK COLLECT INTO s1 FROM\r\n(SELECT /*+ use_nl(a b c) index(c plep_pk)*/ id0,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END d FROM gttt a\r\nleft join plu b ON (a.id1=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.id1=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY id0 ORDER BY id0);\r\nDELETE GTTT;\r\nFORALL j IN 1..mi\r\nINSERT INTO gttt (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT\r\nNULL,NULL,sPL_ID(j),sSEP_ID(j),bt\r\n,\'\',round(new_val,6),Nvl(:7,0),CASE WHEN s=0 AND p=0 AND bad=1 THEN \'1\' else \'14\' end\r\n,SYSDATE,\'\',sAGGS_TYPE_ID(j) FROM\r\n(with a1 as (\r\nSELECT point_id,ml_id,da,bt,val,HAS_SPECIFIC_DSTATUS s\r\nFROM v_ar\r\nWHERE point_id=sPOINT_ID(j)\r\nAND ml_id=:1\r\nAND da>=Trunc(s1(j)) AND da<s2\r\nAND NOT val IS NULL )\r\nselect * from (select a.* ,case when a.val is null then (c.val-sum)/bad end as new_val , c.s from (select * from(\r\nSELECT point_id,ml_id,da,bt,val\r\n,sum(decode(val,null,1,0))over(partition by point_id, ml_id, da) bad\r\n,sum(val)over(partition by point_id, ml_id, da) Sum\r\n,max(Nvl2(val,HAS_SPECIFIC_DSTATUS,NULL))over(partition by point_id, ml_id, da) p\r\nfrom(\r\n select point_id, ml_id, da, bt\r\n ,decode(ssep_id,tsep_id,null,hsd)HAS_SPECIFIC_DSTATUS\r\n ,decode(ssep_id,tsep_id,null,val)val\r\n from(\r\n select sSEP_ID(j) tsep_id, point_id, ml_id,da,bt, HAS_SPECIFIC_DSTATUS hsd, val\r\n ,(select sep_id from pl_data b where sPL_ID(j)=PL_ID and b.pl_t=a.bt\r\n and sAGGS_TYPE_ID(j)=AGGS_TYPE_ID and sSEP_ID(j)=sep_id and Nvl(:7,0)=1) ssep_id\r\n FROM v_ar a WHERE point_id=sPOINT_ID(j) AND ml_id=:2 AND da>=Trunc(s1(j)) AND da<s2\r\n )d\r\n )\r\n)where bad>0) a join a1 c on (a.point_id=c.point_id and a.da=c.da)\r\n) where new_val is not null\r\n) f;\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3109, 2251, 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n             FROM spty\r\n            WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nselect md_cnt,aggf_id into cnt1,gf1 from st_ml where ml_id=:1;\r\nselect md_cnt into cnt2 from st_ml where ml_id=:2;\r\nOPEN c_ROWS ( s0, s2);\r\nLOOP\r\n  FETCH c_ROWS\r\n  BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1\r\n  LIMIT pGF;\r\n  EXIT WHEN sPL_ID.Count=0;\r\n  FORALL j IN 1..sPL_ID.count\r\n    INSERT INTO gttt\r\n    (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\n    select \'\',\'\',sPL_ID(j),sSEP_ID(j),d,\'\',v,Nvl(:7,0),\'1\',sysdate,\'\',sAGGS_TYPE_ID(j)\r\n    FROM (select b.*\r\n    ,Rank() over (PARTITION BY d ORDER BY i)r from\r\n    (select i,d,Sum(v)v FROM\r\n    (select i,bt+Decode(i,2,Decode(ml_id,:1,0,(-1)/cnt1),1/cnt1) d,\r\n    case when ml_id=:1 and i=2 then -1 else 1 end*val*Decode(gf1,3,24/cnt1,1) v\r\n     from v_ar v,(SELECT LEVEL i FROM dual CONNECT BY LEVEL<=2),\r\n         (SELECT DISTINCT point_id, Trunc(mou_bt) m FROM mou) u\r\n    WHERE v.point_id = sPOINT_ID(j)\r\n      AND v.point_id = u.point_id(+)\r\n      AND v.da = u.m (+)\r\n      AND u.point_id IS NULL\r\n      AND v.ml_id in (:1,:2)\r\n      AND v.da>=trunc(s1(j))-1 and v.bt>=s1(j)-1/cnt1 and v.da<s2 and v.bt<s2\r\n      AND v.has_specific_dstatus=0\r\n    ) GROUP BY i,d having Count(*)=2\r\n    ) b\r\n    ) WHERE r=1;\r\n  SELECT d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\n  BULK COLLECT INTO\r\n  pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\n  FROM gttt f\r\n  --/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3110, 127, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n             FROM spty\r\n            WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n  FETCH c_ROWS\r\n  BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n  LIMIT pGF;\r\n  EXIT WHEN sPL_ID.Count=0;\r\n  select DS_ID into pDS_ID FROM DS WHERE ds_code=:8 and DS_ENABLED=1;\r\n  delete gttt;\r\n  FORALL j IN 1..sPOINT_ID.count\r\n  insert into gttt(id1,id2,v1,id3,d1,d2)\r\n  select b.point_id,b.ml_id,b.val,b.has_specific_dstatus,b.bt,b.da\r\n   from v_ar b where  b.point_id=sPOINT_ID(j)and b.ml_id=:1 AND da >=NVL(:4,sysdate - :3)- 1/24\r\n  AND da <=NVL(:5,SYSDATE)and val is not null;\r\n  FORALL j IN 1..sPL_ID.count\r\n  INSERT INTO gttt\r\n  (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\n  with k as (select /*+ materialize */ a.*,trunc(a.new_ds_et,\'MI\')\r\n  tm_new_ds_et from (select lead(a.ds_bt)over (partition by a.ds_id order by a.ds_bt)as new_ds_et ,a.* from (select\r\n  a.ds_id,a.ds_t ds_bt ,trunc(a.ds_t,\'MI\')tm_ds_bt ,trunc(a.ds_t,\'DD\')td_ds_bt from v_AR_DS_PLAIN a\r\n  where a.ds_id=pDS_ID and a.ds_v=1 AND a.ds_t >=NVL(:4,sysdate-:3)-1/24 AND a.ds_t <=NVL(:5,SYSDATE))a)a),ar as (\r\n  select /*+ materialize */ id1  point_id,id2 ml_id,v1 val,id3 has_specific_dstatus,d1 bt,d2 da from gttt) SELECT\r\n  NULL,NULL,sPL_ID(j),sSEP_ID(j),ds_bt,\'\',round(val - prev_val,6)v,Nvl(:7,0)\r\n  ,case when greatest(prev_has_specific_dstatus,has_specific_dstatus)=0 then 1 else 14 end,SYSDATE,\'\',sAGGS_TYPE_ID(j)\r\n  FROM(select lag(val) over (partition by point_id order by bt)prev_val,lag(has_specific_dstatus)over (partition by\r\n  point_id order by bt)prev_has_specific_dstatus ,m.* from (select k.* from (select rank() over (partition by\r\n  point_id,ds_id,ds_bt,new_ds_et order by bt)rnk ,j.* from ( select a.ds_id,a.ds_bt,a.new_ds_et,b.* from ar b\r\n  join k a on (b.bt>=a.tm_ds_bt and b.bt<=a.tm_new_ds_et and a.td_ds_bt=b.da))j)k where rnk=1)m)n\r\n  where round(val - prev_val,6)IS not NULL;\r\n  SELECT\r\n  d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\n  BULK COLLECT INTO\r\n  pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\n  FROM gttt f\r\n  WHERE f.id8 is not null --/7 and not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3111, 9350, 'W11561'),
	(3112, 4264, 'Maitinimo'),
	(3113, 4641, '31'),
	(3114, 8559, 'klaida'),
	(3115, 3807, '30'),
	(3116, 8248, 'Ok'),
	(3117, 7134, 'W11562'),
	(3118, 9297, 'MK taktavimo'),
	(3119, 2262, 'W11563'),
	(3120, 8207, 'Atminties"1" mikroschemos'),
	(3121, 213, 'W11564'),
	(3122, 7761, 'Atminties"2" mikroschemos'),
	(3123, 4247, 'W11565'),
	(3124, 2660, 'Programos kontrolinės sumos'),
	(3125, 4807, 'W11566'),
	(3126, 7669, 'Radijo daviklio suveikimas'),
	(3127, 7419, 'buvo'),
	(3128, 9851, 'nebuvo'),
	(3129, 5545, 'W11567'),
	(3130, 4273, 'Avarinis tarifas'),
	(3131, 8658, 'galioja'),
	(3132, 9815, 'negalioja'),
	(3133, 3980, 'W11568'),
	(3134, 7790, 'Energijos registrai '),
	(3135, 7631, 'pažeisti'),
	(3136, 8451, 'nepažeisti'),
	(3137, 2722, 'W11569'),
	(3138, 6651, 'Metrologinė kalibruotė'),
	(3139, 6015, 'pažeista'),
	(3140, 5616, 'nepažeista'),
	(3141, 4864, 'W11570'),
	(3142, 5642, 'Parametravimas'),
	(3143, 5075, 'pažeistas'),
	(3144, 8229, 'nepažeistas'),
	(3145, 6397, 'W11573'),
	(3146, 6131, 'Indikacija "Radijo"'),
	(3147, 1331, 'atvaizduojama '),
	(3148, 4345, 'neatvaizduojama'),
	(3149, 7604, 'W11574'),
	(3150, 1019, 'Indikacija "Magn"'),
	(3151, 2847, 'W11575'),
	(3152, 287, 'Indikacija "Borg"'),
	(3153, 4550, 'W11576'),
	(3154, 856, 'Įtampa žemiau normos fazėje L1'),
	(3155, 1870, 'yra'),
	(3156, 5878, 'nėra'),
	(3157, 4373, 'W11577'),
	(3158, 8939, 'Įtampa žemiau normos fazėje L2'),
	(3159, 1125, 'W11578'),
	(3160, 6395, 'Įtampa žemiau normos fazėje L3'),
	(3161, 8370, 'W11579'),
	(3162, 6943, 'Įtampa aukščiau normos fazėje L1'),
	(3163, 2049, 'W11580'),
	(3164, 6830, 'Įtampa aukščiau normos fazėje L2'),
	(3165, 6552, 'W11581'),
	(3166, 3708, 'Įtampa aukščiau normos fazėje L3'),
	(3167, 8160, 'W11582'),
	(3168, 7512, 'Srovė viršija normą fazėje L1'),
	(3169, 9771, 'W11583'),
	(3170, 1032, 'Srovė viršija normą fazėje L2'),
	(3171, 426, 'W11584'),
	(3172, 3189, 'Srovė viršija normą fazėje L3'),
	(3173, 854, 'W11585'),
	(3174, 5663, 'Optoportas, vartotojo autorizacija aktyvi'),
	(3175, 6340, 'W11586'),
	(3176, 7911, 'Optoportas, operatoriaus autorizacija aktyvi'),
	(3177, 8154, 'W11587'),
	(3178, 8693, 'Optoportas, vartotojo autorizacija užblokuota'),
	(3179, 650, 'W11588'),
	(3180, 6114, 'Optoportas, operatoriaus autorizacija užblokuota'),
	(3181, 7307, 'W11589'),
	(3182, 379, 'Interfeisas 1, vartotojo autorizacija aktyvi'),
	(3183, 1586, 'W11590'),
	(3184, 6039, 'Interfeisas 1, operatoriaus autorizacija aktyvi'),
	(3185, 3945, 'W11591'),
	(3186, 5870, 'Interfeisas 1, vartotojo autorizacija užblokuota'),
	(3187, 6540, 'W11592'),
	(3188, 4955, 'Interfeisas 1, operatoriaus autorizacija užblokuota'),
	(3189, 936, 'W11593'),
	(3190, 1747, 'Interfeisas 2, vartotojo autorizacija aktyvi'),
	(3191, 6504, 'W11594'),
	(3192, 4068, 'Interfeisas 2, operatoriaus autorizacija aktyvi'),
	(3193, 5351, 'W11595'),
	(3194, 7437, 'Interfeisas 2, vartotojo autorizacija užblokuota'),
	(3195, 1195, 'W11596'),
	(3196, 1173, 'Interfeisas 2, operatoriaus autorizacija užblokuota'),
	(3197, 4776, 'W11597'),
	(3198, 3073, 'Interfeisas 3, vartotojo autorizacija aktyvi'),
	(3199, 3892, 'W11598'),
	(3200, 6510, 'Interfeisas 3, operatoriaus autorizacija aktyvi'),
	(3201, 8571, 'W11599'),
	(3202, 4630, 'Interfeisas 3, vartotojo autorizacija užblokuota'),
	(3203, 367, 'W11600'),
	(3204, 9752, 'Interfeisas 3, operatoriaus autorizacija užblokuota'),
	(3205, 3503, 'W11631'),
	(3206, 5294, 'Poveikio radijo lauku'),
	(3207, 9409, 'pradžia'),
	(3208, 6135, 'pabaiga'),
	(3209, 9342, 'AUTO_DELETE_FROM_CP_DATA'),
	(3210, 7901, 'Automatinis rodmenų uždarymo verifikavimo rezultatų duomenų įrašų trynimas'),
	(3211, 7194, 'CURRTMST DATE;\r\nTS DATE;\r\nep INTEGER;\r\nbtc VARCHAR(250):=\'AUTO_DELETE_FROM_CP_DATA\';'),
	(3212, 7527, 'SELECT CASE WHEN exists (select 0 from USER_TAB_PARTITIONS where TABLESPACE_NAME like \'EMCOS_%\'\r\nAND TABLE_NAME = \'CP_DATA\') THEN 1 ELSE 0 END INTO ep FROM dual;\r\nIF ep=1 THEN\r\nfor i in (select\r\nTABLE_NAME tn,\r\nPARTITION_NAME pname,\r\nADD_MONTHS(TO_DATE(SUBSTR(PARTITION_NAME, 5, 11)||\'01\', \'YYYYMMDD\'),1) dt\r\nfrom USER_TAB_PARTITIONS\r\nwhere TABLE_NAME IN (\'CP_DATA\') order by 1) LOOP\r\nif i.dt < SYSDATE-nvl(:2,31)\r\nTHEN\r\n--disable FK\r\nDELETE gtts;\r\nINSERT INTO gtts (id0,c1)\r\nSELECT ts_id,\r\n\'alter table ||table_name|| modify constraint ||constraint_name|| \'||Decode(ts_id,0,\'disable\',\'enable novalidate\')\r\nFROM (\r\nSELECT table_name,constraint_name FROM user_constraints a\r\nWHERE LEVEL=2\r\nCONNECT BY PRIOR constraint_name=r_constraint_name AND PRIOR constraint_type = \'P\' AND constraint_type=\'R\'\r\nSTART WITH table_name IN (\'CP_DATA\')\r\n), ts;\r\n-- disable FK\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=0) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nEXECUTE IMMEDIATE \'alter table \'||i.tn||\' drop partition \'||i.pname;\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=1) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,i.dt amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\n y.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n (y.tmst_code,y.amp)values(u.tmst_code,u.amp);\r\nend if;END LOOP;\r\nELSE\r\nSELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE=btc)\r\n,TRUNC ((SYSDATE-interval \'5\' year),\'Y\')) INTO CURRTMST FROM DUAL;\r\nTS := SYSDATE;\r\nwhile (not (CURRTMST+nvl(:1,5)/1440 > (SYSDATE-nvl(:2,31)) OR SYSDATE > TS+nvl(:3,45)/86400))LOOP\r\nDELETE CP_DATA WHERE CP_T<CURRTMST+nvl(:1,5)/1440\r\n--5/AND CP_T>=CURRTMST\r\nAND ROWNUM<=nvl(:4,10000);\r\nIF SQL%ROWCOUNT=0 then\r\nCURRTMST := CURRTMST+nvl(:1,5)/1440;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,CURRTMST amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n (y.tmst_code,y.amp)values(u.tmst_code,u.amp);\r\nEND IF;\r\nCOMMIT;\r\nEND LOOP;\r\nEND IF;'),
	(3213, 2082, '1440'),
	(3214, 3878, 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'PL_SE_POST_PROCESSING\'),add_months(sysdate,-12)),sysdate-10/1440 INTO vd1,vd2 FROM DUAL;\r\ndelete gttt;\r\ninsert into gttt (id1,id2)\r\nselect * from (\r\nWITH\r\nf as\r\n(\r\nSELECT /*+materialize*/ src_id,db_time FROM\r\n(SELECT new_val src_id, Max(db_time) db_time\r\nFROM au join tab USING (tab_id) join au_idata USING (db_time,au_nr) join col USING (col_id)\r\nWHERE tab_name = \'SE\' AND operation_type=\'I\' AND db_time>=vD1 AND db_time<vD2 AND col_name= \'SRC_ID\' AND :1 IS NULL\r\nGROUP BY new_val\r\nUNION ALL\r\nSELECT src_id, To_Date(NULL) FROM src_pw_tmst WHERE id=1 AND pck_t BETWEEN SYSDATE-2/24 AND SYSDATE-1/48 AND :1 IS NULL\r\nUNION ALL\r\nSELECT To_Number(:1),sysdate FROM dual WHERE NOT :1 IS null)\r\n)\r\n,s AS\r\n(SELECT a.src_id,c.point_id\r\nfrom f a\r\njoin src b on (a.src_id=b.src_id)\r\njoin src_pw_tmst c ON (b.src_id = c.src_id AND c.id IN (1,3,5,6))\r\nWHERE b.src_et IS NULL\r\nGROUP BY a.src_id,c.point_id\r\nHAVING Max(Decode(c.id,1,1))=1\r\nAND\r\n(Max(Decode(c.id,3,pw_rt)) is NULL\r\nOR Max(Decode(c.id,3,pw_rt))<Max(a.db_time)\r\nOR Max(Decode(c.id,3,pw_rt))<Max(Decode(c.id,5,pw_rt,6,pw_rt))\r\n)\r\n)\r\nSELECT s.src_id, s.point_id FROM\r\ns\r\nJOIN pl a ON (a.point_id=s.point_id)\r\nJOIN di i ON (a.pl_id=i.pl_id)\r\nJOIN se e ON (s.src_id=e.src_id AND e.di_id=i.di_id)\r\nJOIN sep p ON (e.se_id=p.se_id)\r\nGROUP BY s.src_id, s.point_id\r\n);\r\npwl_execute;\r\nUPDATE gttt r SET id4=1 WHERE NOT EXISTS (SELECT 0 FROM V_LPTY_MISSING V WHERE R.ID1 = V.SRC_ID AND NVL(V.POINT_ID,R.ID2)=R.ID2);\r\nMERGE INTO src_pw_tmst y\r\nUSING (SELECT id1,id2 FROM gttt WHERE id4=1) u\r\nON (y.src_id = u.id1 AND y.point_id=u.id2 AND y.id=3)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.pw_rt=sysdate\r\n,y.pck_t=sysdate\r\nWHEN NOT MATCHED THEN INSERT\r\n(y.src_id\r\n,y.point_id\r\n,y.id\r\n,y.pw_rt\r\n,y.pck_t\r\n) values (\r\n u.id1\r\n,u.id2\r\n,3\r\n,sysdate\r\n,sysdate\r\n);\r\nIF :1 IS NULL then\r\nSELECT id2 bulk collect into ePOINT_ID FROM gttt WHERE id4=1;\r\nFOR i IN 1..ePOINT_ID.Count LOOP\r\nSELECT ePOINT_ID(i),\'0\' BULK COLLECT INTO pPOINT_ID,ans FROM dual;\r\ninit_fill_point3(pPOINT_ID,ans,orn);\r\n if ans(1)=\'0\' then\r\n  INSERT INTO DTL (DB_TIME,REQ_TYPE_CODE,RODO_ID,URGENT)\r\n  select sysdate, REQ_TYPE_CODE, orn, 0 from rc where rc_id=16;\r\n end if;\r\nEND LOOP;\r\nMERGE INTO TMST y\r\n   USING (   SELECT \'PL_SE_POST_PROCESSING\' TMST_CODE,vd2 amp FROM dual) u\r\n   ON (y.TMST_CODE = u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\n y.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n (\r\n y.TMST_CODE\r\n,y.amp\r\n) values (\r\n u.TMST_CODE\r\n,u.amp\r\n);\r\nEND IF;'),
	(3215, 4938, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n              FROM spty\r\n             WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nDELETE FROM GEN_ADJ$F0;\r\nIF Nvl(:7,\'0\')=1 THEN\r\n  INSERT INTO GEN_ADJ$F0\r\n  SELECT *\r\n    FROM ADJ_TOTALS_F\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:3) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND (:2 IS NULL OR ml_id=:2)\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL, NULL, pl_id, sep_id, da, \'\', v, 1, s, c_DATA, \'\'\r\n         FROM GEN_TOTALS_FROM_ADJ_TOTALS;\r\nELSE\r\n  INSERT INTO GEN_ADJ$F0\r\n  SELECT *\r\n    FROM ADJ_TOTALS\r\n   WHERE da>=Nvl(:4,TRUNC(SYSDATE)-:1) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND (:2 IS NULL OR ml_id=:2)\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL, NULL, pl_id, sep_id, da, \'\', v, 0, s, c_DATA, \'\'\r\n         FROM GEN_TOTALS_FROM_ADJ_TOTALS;\r\nEND IF;\r\nLOOP\r\n  FETCH c_ROWS\r\n   BULK COLLECT\r\n   INTO pPCK_T, pPCK_N , pPL_ID, pSEP_ID, pT, pDST, pV, pFORCED, pS, pRT, pRDST\r\n  LIMIT pGF;\r\n  EXIT WHEN pPL_ID.COUNT = 0;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3216, 6339, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n              FROM spty\r\n             WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nDELETE FROM GEN_ADJ$F1;\r\nIF Nvl(:7,\'0\')=1 THEN\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_H_TOTALS_F\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:3) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,1,s,c_DATA,\'\'\r\n         FROM GEN_H_TOTALS_FROM_ADJ_TOTALS;\r\nELSE\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_H_TOTALS\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:3) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,0,s,c_DATA,\'\'\r\n         FROM GEN_H_TOTALS_FROM_ADJ_TOTALS;\r\nEND IF;\r\nLOOP\r\n  FETCH c_ROWS\r\n   BULK COLLECT\r\n   INTO pPCK_T, pPCK_N , pPL_ID, pSEP_ID, pT, pDST, pV, pFORCED, pS, pRT, pRDST\r\n  LIMIT pGF;\r\n  EXIT WHEN pPL_ID.COUNT = 0;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3217, 2615, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n              FROM spty\r\n             WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nDELETE FROM GEN_ADJ$F1;\r\nIF Nvl(:7,\'0\')=1 THEN\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_15MIN_TOTALS_F\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:3) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,1,s,c_DATA,\'\'\r\n         FROM GEN_15_TOTALS_FROM_ADJ_TOTALS;\r\nELSE\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_15MIN_TOTALS\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:3) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,0,s,c_DATA,\'\'\r\n         FROM GEN_15_TOTALS_FROM_ADJ_TOTALS;\r\nEND IF;\r\nLOOP\r\n  FETCH c_ROWS\r\n   BULK COLLECT\r\n   INTO pPCK_T, pPCK_N , pPL_ID, pSEP_ID, pT, pDST, pV, pFORCED, pS, pRT, pRDST\r\n  LIMIT pGF;\r\n  EXIT WHEN pPL_ID.COUNT = 0;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3218, 3488, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n              FROM spty\r\n             WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nDELETE FROM GEN_ADJ$F1;\r\nIF Nvl(:7,\'0\')=1 THEN\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_30MIN_TOTALS_F\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:3) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,1,s,c_DATA,\'\'\r\n         FROM GEN_30_TOTALS_FROM_ADJ_TOTALS;\r\nELSE\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_30MIN_TOTALS\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:3) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,0,s,c_DATA,\'\'\r\n         FROM GEN_30_TOTALS_FROM_ADJ_TOTALS;\r\nEND IF;\r\nLOOP\r\n  FETCH c_ROWS\r\n   BULK COLLECT\r\n   INTO pPCK_T, pPCK_N , pPL_ID, pSEP_ID, pT, pDST, pV, pFORCED, pS, pRT, pRDST\r\n  LIMIT pGF;\r\n  EXIT WHEN pPL_ID.COUNT = 0;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3219, 8247, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n              FROM spty\r\n             WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nDELETE FROM GEN_ADJ$F0;\r\nIF Nvl(:7,\'0\')=1 THEN\r\n  INSERT INTO GEN_ADJ$F0\r\n  SELECT *\r\n    FROM ADJ_TOTALS_F\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:3) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND (:2 IS NULL OR ml_id=:2)\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL, NULL, pl_id, sep_id, da, \'\', v, 1, s, c_DATA, \'\'\r\n         FROM GEN_TOTALS_FROM_ADJ_TOTALS;\r\nELSE\r\n  INSERT INTO GEN_ADJ$F0\r\n  SELECT *\r\n    FROM ADJ_TOTALS\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:3) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND (:2 IS NULL OR ml_id=:2)\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL, NULL, pl_id, sep_id, da, \'\', v, 0, s, c_DATA, \'\'\r\n         FROM GEN_TOTALS_FROM_ADJ_TOTALS;\r\nEND IF;\r\nLOOP\r\n  FETCH c_ROWS\r\n   BULK COLLECT\r\n   INTO pPCK_T, pPCK_N , pPL_ID, pSEP_ID, pT, pDST, pV, pFORCED, pS, pRT, pRDST\r\n  LIMIT pGF;\r\n  EXIT WHEN pPL_ID.COUNT = 0;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3220, 9452, 'DMP_IMP_ENABLED'),
	(3221, 2110, 'Požymis, kad galimas duomenų perkėlimo importas'),
	(3222, 5023, 'Duomenų pakrovimas atmestas'),
	(3223, 9010, 'DMP.DENIED'),
	(3224, 9260, 'Duomenys priimti. Duomenų pakrovimas sustabdytas'),
	(3225, 7210, 'DMP.DELAYED'),
	(3226, 291, 'Eksportas nutrauktas. Duomenų perkėlimo užsakymo statusas turi būti Suformuotas'),
	(3227, 9978, 'DMP.WRONG_STATUS'),
	(3228, 7319, '5_MIN_AVG_FROM_INSTANT_TOTALS'),
	(3229, 1176, 'Vidutinių rodmenų per 5 minutes generavimas iš augančių reikšmių'),
	(3230, 8981, 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3),Nvl(:5+1,SYSDATE),1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,ib t\r\n,round(Sum(q*l)*12,6) v,Decode(Max(k),0,\'1\',\'14\') s\r\nFROM\r\n(SELECT f.*\r\n,Trunc(bt)+Trunc(Round((bt-Trunc(bt))*288,6))/288+(d.column_value-1)/288 ib\r\n,g/(et-bt)/288 q\r\n,(Least(et,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*288,6))/288+(d.column_value)/288)-Greatest(bt,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*288,6))/288+(d.column_value-1)/288))*288 l\r\n,CASE WHEN et-bt>=20/1440 and not g=0 THEN 1 ELSE 0 END k\r\nFROM (SELECT da,bt, c1,c2,c3,point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),Nvl(:5+1,SYSDATE)))\r\nWHERE NOT val IS NULL) f,mou u, TABLE(SELECT CAST(COLLECT(level) AS sql_objects) FROM dual CONNECT BY Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*288,6))/288+(LEVEL-1)/288<f.et) d\r\nwhere f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\n) h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;'),
	(3231, 329, 'Išeities matavimo linijos ID'),
	(3232, 4919, 'N:=:ML_ID1'),
	(3233, 8670, 'Paskirties matavimo linijos ID'),
	(3234, 3812, 'N:=:ML_ID2'),
	(3235, 5689, 'Generavimo gylis paromis'),
	(3236, 7525, 'Matavimo taško identifikatorius'),
	(3237, 1701, 'N:=:POINT_ID'),
	(3238, 5275, 'Priverstinio pergeneravimo požymis'),
	(3239, 4500, 'N:=:FORCED'),
	(3240, 1253, 'W11571'),
	(3241, 5504, 'Apkrovos valdymo relė'),
	(3242, 2057, 'atjungta'),
	(3243, 2389, 'neatjungta'),
	(3244, 4942, 'SAVE_FULL_RP_LOG'),
	(3245, 5879, 'Pilnos ataskaitų vykdymo statistikos rinkimas'),
	(3246, 2695, 'IMPORT/EXPORT'),
	(3247, 7064, 'W4011E'),
	(3248, 9405, 'Krovimo būklė'),
	(3249, 2031, '54727565'),
	(3250, 6032, 'True'),
	(3251, 5856, '46616C7365'),
	(3252, 9965, 'False'),
	(3253, 6333, 'W4013E'),
	(3254, 2055, 'Vartotojo sąsajos (Cl in) būklė'),
	(3255, 4814, 'W4014E'),
	(3256, 9523, 'Skaitiklio sąsajos (Cl out) būklė'),
	(3257, 4497, 'W4015E'),
	(3258, 1448, 'Maitinimo (AC) būklė'),
	(3259, 5741, 'REPLICATE_POINT_CONFIGURATION'),
	(3260, 8957, 'Pakeisti kitų taškų konfigūracinių parametrų reikšmes pagal pavyzdinį tašką'),
	(3261, 6778, 'ep NUMBER(10);\r\norn NUMBER(10);\r\npDB_TIME DATE;'),
	(3262, 221, 'SELECT point_id INTO ep FROM point WHERE point_code=:1;\r\nDELETE gttt;\r\nINSERT INTO gttt (id1,id2,id3,id4,cbig,id5,id6)\r\nWITH d AS\r\n(SELECT point_id,di_id,src_id,src_type_id,src_type_mod_nr,withe_id,pw_v,sep_id\r\nFROM\r\npw_setting\r\njoin sep USING (sep_id)\r\njoin se USING (se_id)\r\njoin (SELECT src_id,src_type_id,src_et FROM src) USING (src_id)\r\njoin src_mod USING (src_id)\r\n--2/join (select withe_id from witheset join witheset_data using (witheset_id) where witheset_code=:2) using (withe_id)\r\nWHERE src_et IS null)\r\n,e as\r\n(SELECT src_type_id,src_type_mod_nr,withe_id,pw_v FROM d\r\nWHERE point_id=ep\r\n)\r\n--4/select * from (\r\nSELECT\r\nd.point_id,\r\nd.di_id,\r\nd.src_id,\r\nd.sep_id,\r\nrawtochar(e.pw_v),\r\nd.withe_id\r\n--4/,max(Decode(e.pw_v,d.pw_v,0,1)) over (partition by d.point_id) m\r\n FROM\r\nd\r\njoin e ON (d.src_type_id=e.src_type_id AND d.src_type_mod_nr=e.src_type_mod_nr AND d.withe_id=e.withe_id)\r\n--3/join (select point_id from grpj join gr using (gr_id) where gr_code=:3 and grp_et is null) c on (d.point_id=c.point_id)\r\n--/4WHERE Decode(e.pw_v,d.pw_v,0,1)=1\r\n--4/) where m=1\r\n;\r\nINSERT INTO gttt (\r\nid1,id2,id3,id4,cbig,id5,id6,id7,id8,id9\r\n)\r\nWITH d AS\r\n(\r\nSELECT point_id,di_id,src_id,src_type_id,src_type_mod_nr,withe_id,ind1,ind2,ind3,enr,pw_v,sep_id\r\nFROM\r\npw_msetting\r\njoin sep USING (sep_id)\r\njoin se USING (se_id)\r\njoin (SELECT src_id,src_type_id,src_et FROM src) USING (src_id)\r\njoin src_mod USING (src_id)\r\n--2/ join (select withe_id from witheset join witheset_data using (witheset_id) where witheset_code=:2) using (withe_id)\r\nWHERE src_et IS null\r\n)\r\n,e as\r\n(SELECT src_type_id,src_type_mod_nr,withe_id,ind1,ind2,ind3,enr,pw_v\r\n,Count(*) over (PARTITION BY point_id,withe_id,ind1,ind2,ind3) Enr_cnt FROM d\r\nWHERE point_id=ep\r\n)\r\nSELECT\r\npoint_id,\r\ndi_id,\r\nsrc_id,\r\nsep_id,\r\nrawtochar(e_pw_v),\r\nwithe_id,\r\nind1,\r\nind2,\r\nind3,\r\ne_enr\r\nFROM (\r\nSELECT f.*\r\n,Max(CASE WHEN e_enr_cnt!=enr_cnt THEN 1 ELSE Decode(pw_v,e_pw_v,0,1) end) over\r\n(PARTITION BY point_id\r\n--/4,withe_id,ind1,ind2,ind3\r\n) m\r\nFROM (\r\nSELECT d.*,e.enr_cnt e_enr_cnt,e.enr e_enr,e.pw_v e_pw_v\r\n,Count(DISTINCT d.enr) over (PARTITION BY d.point_id,d.withe_id,d.ind1,d.ind2,d.ind3) enr_cnt\r\n,Rank() over (PARTITION BY d.point_id,d.withe_id,d.ind1,d.ind2,d.ind3,e.enr ORDER BY e.enr-d.enr,d.enr) rnk\r\nFROM\r\nd\r\njoin e ON (d.src_type_id=e.src_type_id AND d.src_type_mod_nr=e.src_type_mod_nr\r\nAND d.withe_id=e.withe_id AND d.ind1=e.ind1 AND d.ind2=e.ind2 AND d.ind3=e.ind3)\r\n--3/join (select point_id from grpj join gr using (gr_id) where gr_code=:3 and grp_et is null) c on (d.point_id=c.point_id)\r\n) f\r\nWHERE rnk=1) WHERE m=1;'),
	(3263, 7760, 'SELECT id1 FROM gttt GROUP BY id1'),
	(3264, 7545, 'pDB_TIME:=SYSDATE;\r\nSELECT rodo_seq.NEXTVAL INTO orn FROM dual;\r\nINSERT INTO rodo0\r\n(rodo_id,rodo_nr,db_time,user_id,rc_id,\r\ndi_id,src_id,sep_id,write2device,\r\nwithe_id,ind1,ind2,ind3,enr)\r\nSELECT\r\norn,ROWNUM,pDB_TIME,0,7,\r\nid2,id3,id4,cbig,\r\nid5,id6,id7,id8,id9\r\nFROM gttt WHERE id1=c.id1 AND ROWNUM<100000;\r\nINSERT INTO ltl (req_type_code, rodo_id)\r\nSELECT req_type_code,orn FROM rc WHERE rc_id=7;'),
	(3265, 2612, 'Pavyzdinio taško kodas'),
	(3266, 8093, 'C:=:POINT_CODE'),
	(3267, 3656, 'Konfigūracinių parametrų rinkinio kodas'),
	(3268, 9469, 'C:=:WITHESET_CODE'),
	(3269, 6999, 'Grupės kodas'),
	(3270, 40, 'Rašyti visą parametrų rinkinį'),
	(3271, 6577, 'N:=:FORCE_FULL_SET_WRITE'),
	(3272, 1061, 'N#1_9'),
	(3273, 2409, 'Numeriai nuo 1 iki 9'),
	(3274, 6076, 'Unigas_300_Channel'),
	(3275, 2521, 'Unigas-300 Kanalo numeris'),
	(3276, 9640, 'MacMAT_Protocol'),
	(3277, 1133, 'MacMAT Protokolas'),
	(3278, 4856, 'GazModem'),
	(3279, 3104, 'GazModem2'),
	(3280, 7632, 'MODBUS'),
	(3281, 1255, 'MacMAT_Channel'),
	(3282, 3065, 'MacMAT Kanalo numeris'),
	(3283, 5608, 'N#1_8'),
	(3284, 6982, 'Numeriai nuo 1 iki 8'),
	(3285, 2324, 'AUTO_DELETE_AE_COL_DATA'),
	(3286, 5977, 'Automatinis pasenusių audito duomenų įrašų trynimas'),
	(3287, 9101, 'execute immediate \'ALTER TABLE COLD_DATA DISABLE CONSTRAINT COLD_DATA_DESC_AE_FK\';\r\nexecute immediate \'ALTER TABLE AU_CDATA DISABLE CONSTRAINT AU_CDATA_NEW_AE_FK\';\r\nexecute immediate \'ALTER TABLE AU_CDATA DISABLE CONSTRAINT AU_CDATA_OLD_AE_FK\';\r\ninsert into gttt(id0,id1,c0)\r\nSELECT /*+ parallel(au_idata) full(au_idata)*/col_id,Decode(ts_id,0,old_val,new_val) col_val,\'Collect_pairs_4_stay\'\r\nFROM au join au_idata USING(db_time,au_nr)\r\njoin tab_col USING(tab_id,col_id)\r\njoin tab using(tab_id)\r\ncross join ts\r\nWHERE col_bp=1 AND NOT Decode(ts_id,0,old_val,new_val) IS NULL\r\nGROUP BY col_id, Decode(ts_id,0,old_val,new_val);\r\ndelete from cold_data where (col_id, col_val) in\r\n(select col_id,col_val from cold_data a\r\n  where not exists(select 0 from tab_col join tab USING(tab_id) WHERE col_bp=1 AND tab_type_id=0\r\n  and a.col_id=col_id)\r\n  minus\r\n  select id0, id1 from gttt where c0=\'Collect_pairs_4_stay\');\r\ninsert into gttt (id0,id1,c0)(select col_id, col_val, \'COLC_DATA_delete_rows\' from colc_data a\r\n  minus select id0, id1, \'COLC_DATA_delete_rows\' from gttt where c0=\'Collect_pairs_4_stay\');\r\ndelete from gttt where c0=\'Collect_pairs_4_stay\';\r\ndelete from colc_data where (col_id, col_val) in (\r\nselect id0, id1 from gttt where c0=\'COLC_DATA_delete_rows\');\r\ninsert into gttt (id0,c0)\r\nselect ae_id,\'AE_delete_rows\' from ae\r\nminus\r\nSELECT /*+parallel(au_cdata) full(au_cdata)*/Decode(ts_id,0,old_ae_id,new_ae_id) ae_id,\'AE_delete_rows\'\r\nFROM au_cdata,ts\r\nWHERE NOT Decode(ts_id,0,old_ae_id,new_ae_id) IS NULL\r\nGROUP BY Decode(ts_id,0,old_ae_id,new_ae_id)\r\nminus\r\nselect desc_ae_id,\'AE_delete_rows\' from cold_data;\r\ndelete from ae where ae_id in (\r\nselect id0 from gttt where c0=\'AE_delete_rows\');\r\nexecute immediate \'ALTER TABLE COLD_DATA ENABLE NOVALIDATE CONSTRAINT COLD_DATA_DESC_AE_FK\';\r\nexecute immediate \'ALTER TABLE AU_CDATA ENABLE NOVALIDATE CONSTRAINT AU_CDATA_NEW_AE_FK\';\r\nexecute immediate \'ALTER TABLE AU_CDATA ENABLE NOVALIDATE CONSTRAINT AU_CDATA_OLD_AE_FK\';'),
	(3288, 4109, 'Momentinis rodiklis Nr.8, fiksuojamas kas valandą'),
	(3289, 4052, 'MI'),
	(3290, 2966, 'Įrašų kiekis taškų vytelių buferyje'),
	(3291, 6060, 'XLS'),
	(3292, 6912, 'WITH t AS (SELECT /*+materialize*/pl_id FROM pl join ml USING (ml_id) WHERE NOT md_id=7)\r\nSELECT Trunc(SYSDATE)-1 dt, Nvl(Sum(Decode(pl_v,NULL,0,1)),0)/Nvl(nullif(Count(*),0),1)*100\r\nFROM PL_DATA join t using (pl_id)\r\nWHERE db_time>=Trunc(SYSDATE)-1 AND db_time<Trunc(SYSDATE)'),
	(3293, 521, 'SELECT /*+parallel(a)*/sysdate dt, count(*) val FROM store_pw_buf a'),
	(3294, 4412, '63'),
	(3295, 3090, 'SELECT 0 FROM dual WHERE EXISTS (SELECT 0 FROM gttn2 WHERE id1=-9)'),
	(3296, 7396, 'a:=src_from_tmpl_u(:1);'),
	(3297, 1399, 'Trynimą vykdyti tik žingsnio apimtyje'),
	(3298, 2394, 'SRC_TMPL.ENABLED'),
	(3299, 7540, 'Automatinis šaltinių šablonų taikymas'),
	(3300, 267, 'SRC_TMPL'),
	(3301, 7101, 'SRC_TMPL.RUN_MAX_DURATION'),
	(3302, 8150, 'Automatinio šaltinių šablonų taikymo vieno iškvietimo maksimali vykdymo trukmė sekundėmis'),
	(3303, 7729, '120'),
	(3304, 1183, 'SRC_TMPL.FLIMIT'),
	(3305, 7813, 'Duomenų šaltinių kiekis per vieną iteraciją'),
	(3306, 8106, '100'),
	(3307, 4186, 'SRC_TMPL.ULIMIT'),
	(3308, 1018, 'Duomenų šaltinių kiekis per vieną atitikimo šablonui tikrinimo iteraciją'),
	(3309, 8022, 'SELECT /*+parallel(a) full(a)*/sysdate dt, count(*) val FROM store_pw_buf a'),
	(3310, 7400, 'for i in (select table_name from user_tables\r\n  where table_name like \'%^_BUF\' escape \'^\') loop\r\n  begin\r\n    execute immediate \'alter table \'||i.table_name||\' enable row movement\';\r\n    execute immediate \'alter table \'||i.table_name||\' shrink space\';\r\n    execute immediate \'alter table \'||i.table_name||\' disable row movement\';\r\n  exception when others then null;\r\n  end;\r\nend loop;\r\nfor i in (select index_name from user_indexes\r\n  where table_name like \'%^_BUF\' escape \'^\') loop\r\n  begin\r\n    execute immediate \'alter index \'||i.index_name||\' shrink space\';\r\n  exception when others then null;\r\n  end;\r\nend loop;'),
	(3311, 3827, 'select user_id into r from st_curr_user;delete from gttq;\r\nFOR t IN(SELECT a.gr_id,a.gr_type_id,b.gr_type_id dp_gr_type_id FROM gr a,gr_type b\r\nWHERE a.gr_code=\'BY_DP\' AND b.gr_type_code=\'DP\') LOOP\r\nFOR h IN(SELECT g,Max(n)n,Sum(i)i,Max(c)c\r\nFROM(\r\nSELECT DISTINCT comp_code g,\'\' n,-1 i,comp_id c FROM st_grc WHERE cont_code=\'BY_DP\'\r\nUNION ALL\r\nSELECT DISTINCT \'BY_DP_\'||DP_CODE,DP_name,1,\'\'+0\r\nFROM st_se WHERE dp_deleted=0 AND src_et IS NULL\r\n)GROUP BY g HAVING Sum(i)!=0\r\n)loop\r\nIF h.i=1 THEN SELECT gr_seq.NEXTVAL INTO f FROM dual;\r\ninsert into GR(GR_ID,USER_ID,GR_TYPE_ID,GR_CODE,IS_PUBLIC,GR_NAME)\r\nvalues(f,r,t.DP_GR_TYPE_ID,h.g,1,h.n);\r\ninsert into GRC(CONT_ID,COMP_ID)values(t.gr_id,f);\r\nELSE\r\nFOR y IN (SELECT comp_id c FROM grc WHERE cont_id=h.c) LOOP\r\ndelete from grp where gr_id=y.c;\r\ndelete from grc where cont_id=y.c or comp_id=y.c;\r\ndelete from gr where gr_id=y.c;\r\nEND LOOP;\r\ndelete from grp where gr_id=h.c;\r\ndelete from grc where cont_id=h.c or comp_id=h.c;\r\ndelete from gr where gr_id=h.c;\r\nEND if;END LOOP;\r\nFOR m IN (SELECT c,Max(n)n,Sum(i)i,Max(id)id,Max(u)u\r\nFROM (\r\nSELECT DISTINCT comp_code c,\'\' n,-1 i,comp_id id,\'\' u\r\nFROM st_grc WHERE cont_id IN(SELECT comp_id FROM grc WHERE cont_id=t.gr_id)\r\nUNION all\r\nSELECT DISTINCT \'BY_DP_\'||DP_CODE||\'_\'||src_id,src_name,1,\r\n\'\'+0,\'BY_DP_\'||DP_CODE\r\nFROM st_se WHERE dp_deleted=0 AND src_et IS NULL\r\n)GROUP BY c HAVING Sum(i)!=0\r\n)LOOP if m.i=1 then\r\nSELECT gr_seq.NEXTVAL INTO f FROM dual;\r\ninsert into GTTQ(id1,id2,c1,c2,c0,c9)\r\nvalues(f,t.DP_GR_TYPE_ID,m.c,m.n,\'I\',\'GR\');\r\nselect gr_id into g from gr where gr_code=m.u;\r\ninsert into GTTQ(id1,id2,c0,c9)values(f,g,\'I\',\'GRC\');\r\nelse\r\ndelete from grp where gr_id=m.id;\r\ndelete from grc where cont_id=m.id or comp_id=m.id;\r\ndelete from gr where gr_id=m.id;\r\nend if;end loop;\r\ninsert into GR(GR_ID,USER_ID,GR_TYPE_ID,GR_CODE,IS_PUBLIC,GR_NAME)\r\nselect id1,r,id2,c1,1,c2 from GTTQ where c0=\'I\' and c9=\'GR\';\r\ninsert into GRC(CONT_ID,COMP_ID)\r\nselect id2,id1 from GTTQ where c0=\'I\' and c9=\'GRC\';\r\ndelete from GTTQ;\r\nFOR d IN (SELECT gr_code c,point_id p,Sum(i)i,Max(gr_id)g FROM(\r\nSELECT DISTINCT gr_id,gr_code,point_id,-1 i\r\nFROM st_grp WHERE gr_id IN(SELECT comp_id FROM grcj WHERE cont_id=t.gr_id)\r\nUNION all\r\nSELECT DISTINCT \'\'+0,\'BY_DP_\'||DP_CODE||\'_\'||src_id,point_id,1\r\nFROM st_se WHERE dp_deleted=0 AND src_et IS NULL AND point_id IS NOT null\r\n)GROUP BY gr_code,point_id\r\nHAVING NOT Sum(i)=0\r\n)LOOP\r\nIF d.i=1 THEN\r\nSELECT gr_id INTO f FROM gr WHERE gr_code=d.c;\r\ninsert into GTTQ(id1,id2,c0,c9)values(f,d.p,\'I\',\'GRP\');\r\nELSE\r\ninsert into GTTQ(id1,id2,c0,c9)values(d.g,d.p,\'D\',\'GRP\');\r\nEND if;END LOOP;\r\ndelete from grp where grp_bt=Date\'1899-12-30\'\r\nand(gr_id,point_id)in(select id1,id2 from GTTQ where c0=\'D\' and c9=\'GRP\');\r\ninsert into GRP(GR_ID,POINT_ID)\r\nselect id1,id2 from GTTQ where c0=\'I\' and c9=\'GRP\';\r\ndelete from GTTQ;\r\nFOR s IN (SELECT gr_code,ds_id,Sum(i) i,Max(gr_id) gr_id FROM(\r\nSELECT DISTINCT gr_id,gr_code,ds_id,-1 i\r\nFROM st_ds_gr WHERE gr_id IN(SELECT comp_id FROM grcj WHERE cont_id=t.gr_id)\r\nUNION all\r\nSELECT DISTINCT \'\'+0,\'BY_DP_\'||DP_CODE||\'_\'||src_id,ds_id,1\r\nFROM st_se_ds WHERE dp_deleted=0 AND src_et IS NULL\r\n)GROUP BY gr_code,ds_id\r\nHAVING NOT Sum(i)=0\r\n)LOOP\r\nIF s.i=1 THEN\r\nSELECT gr_id INTO f FROM gr WHERE gr_code=s.gr_code;\r\ninsert into GTTQ(id1,id2,c0,c9)values(f,s.ds_id,\'I\',\'DS_GR\');\r\nELSE\r\ninsert into GTTQ(id1,id2,c0,c9)values(s.GR_ID,s.ds_id,\'D\',\'DS_GR\');\r\nEND if;\r\nEND LOOP;\r\ndelete from ds_gr where(gr_id,ds_id)in(select id1,id2 from GTTQ where c0=\'D\' and c9=\'DS_GR\');\r\ninsert into DS_GR(GR_ID,DS_ID) select id1,id2 from GTTQ where c0=\'I\' and c9=\'DS_GR\';\r\nend loop;\r\nFOR t IN (select * from dp,gr WHERE \'BY_DP_\'||dp_code=gr_code AND dp_name!=gr_name) LOOP\r\nUPDATE gr SET gr_name=t.dp_name WHERE gr_id=t.gr_id;\r\nEND LOOP;'),
	(3312, 5466, 'W11635'),
	(3313, 5891, 'Reikšmės Z ir Zb intervalą'),
	(3314, 1956, 'neperžengė'),
	(3315, 1283, 'peržengė'),
	(3316, 5312, 'W11636'),
	(3317, 2820, 'Parametras p1 limitus I p1 arba u p1'),
	(3318, 4366, 'W11637'),
	(3319, 7249, 'Parametras p2 limitus I p2 arba u p2'),
	(3320, 4565, 'W11638'),
	(3321, 2428, 'Parametras Qb limitus I Qb arba u Qb'),
	(3322, 617, 'W11639'),
	(3323, 1433, 'Parametras Qm limitus I Qm arba u Qm'),
	(3324, 7275, 'W11640'),
	(3325, 769, 'Parametras dVbh limitą Vbh 3 '),
	(3326, 6099, 'neviršija'),
	(3327, 4199, 'viršyjo'),
	(3328, 2217, 'W11641'),
	(3329, 9371, 'Parametras dVbh limitą Vbh 2'),
	(3330, 3336, 'W11642'),
	(3331, 1338, 'Parametras dVbh limitą Vbh 1'),
	(3332, 3351, 'W11643'),
	(3333, 6545, 'Skirtumas Vm-V2 toleranciją'),
	(3334, 1945, 'W11644'),
	(3335, 1574, 'Dažnis LF limitą 2,5 kHz'),
	(3336, 3661, 'W11645'),
	(3337, 8585, 'Parametras p1 intervalą nuo p1 min iki p1 max'),
	(3338, 3423, 'W11646'),
	(3339, 1424, 'Parametras p2 intervalą nuo p2 min iki p2 max'),
	(3340, 9451, 'W11647'),
	(3341, 5547, 'Temperatūra intervalą nuo t min iki t max'),
	(3342, 9334, 'W11648'),
	(3343, 5977, 'Parametras Qb intervalą nuo Qm min iki Qm max'),
	(3344, 9043, 'W11649'),
	(3345, 587, 'Santykis HF / LF toleranciją'),
	(3346, 3422, 'neviršyja'),
	(3347, 5810, 'W11650'),
	(3348, 9694, 'Įteisinimas'),
	(3349, 6379, 'baigėsi'),
	(3350, 6312, 'prasidėjo'),
	(3351, 9791, 'W11651'),
	(3352, 2934, 'Pakeistas Vm'),
	(3353, 1215, 'iki'),
	(3354, 717, 'nuo'),
	(3355, 8392, 'W11652'),
	(3356, 6948, 'Registravimo periodas pakeistas'),
	(3357, 9068, 'W11653'),
	(3358, 8884, 'Impulsinių įėjimų konfigūracija pakeista'),
	(3359, 9750, 'W11654'),
	(3360, 6808, 'DP reišmė pakeista'),
	(3361, 1004, 'W11655'),
	(3362, 9050, 'DP tekstas pakeistas'),
	(3363, 9887, 'W11656'),
	(3364, 9091, 'Pakeistas dūjų parametras'),
	(3365, 4965, 'W11657'),
	(3366, 4911, 'Duomenys prietaise ištrinti'),
	(3367, 386, 'W11658'),
	(3368, 2561, 'Pasikeitė iėjimo S1 būsena'),
	(3369, 1844, 'W11659'),
	(3370, 2604, 'Pasikeitė iėjimo S2 būsena'),
	(3371, 2103, 'W11660'),
	(3372, 5077, 'Pasikeitė iėjimo S3 būsena'),
	(3373, 3746, 'W11661'),
	(3374, 2406, 'Saulės baterijos veikimo'),
	(3375, 7085, 'W11662'),
	(3376, 1275, 'Baterijos atsijungimo'),
	(3377, 5450, 'W11663'),
	(3378, 4399, 'Klaviatūros gedimų'),
	(3379, 6801, 'W11664'),
	(3380, 4990, 'Indikatoriaus perpildymo'),
	(3381, 195, 'W11665'),
	(3382, 1203, 'Kontrolinis kontaktas '),
	(3383, 4329, 'uždaras'),
	(3384, 7444, 'atviras'),
	(3385, 1785, 'W11666'),
	(3386, 3521, 'Prietaiso užrakinimas uždraustas'),
	(3387, 3508, 'W11667'),
	(3388, 5088, 'Iėjimo R1 reikšmė išėjo už ribų'),
	(3389, 4751, 'W11668'),
	(3390, 4461, 'Iėjimo R2 reikšmė išėjo už ribų'),
	(3391, 2016, 'W11669'),
	(3392, 5244, 'Iėjimo R3 reikšmė išėjo už ribų'),
	(3393, 2920, 'W11670'),
	(3394, 4682, 'Iėjimo R4 reikšmė išėjo už ribų'),
	(3395, 9513, 'W11671'),
	(3396, 3687, 'Atsijungė R1'),
	(3397, 3690, 'W11672'),
	(3398, 9025, 'Atsijungė R2'),
	(3399, 8330, 'W11673'),
	(3400, 957, 'Atsijungė R3'),
	(3401, 5700, 'W11674'),
	(3402, 8226, 'Pasikeitė statusas B aliarmo grupėje'),
	(3403, 9834, 'W11675'),
	(3404, 9257, 'Pasikeitė statusas A aliarmo grupėje'),
	(3405, 4008, 'W11676'),
	(3406, 8477, 'Pasikeitė iėjimo S4 būsena'),
	(3407, 8761, 'W11677'),
	(3408, 4029, 'Pasikeitė iėjimo S5 būsena'),
	(3409, 3000, 'W11678'),
	(3410, 8003, 'Pasikeitė iėjimo S6 būsena'),
	(3411, 8809, 'W11679'),
	(3412, 5349, 'Pasikeitė iėjimo S7 būsena'),
	(3413, 6315, 'W11680'),
	(3414, 7499, 'Pasikeitė iėjimo S8 būsena'),
	(3415, 4840, 'W11681'),
	(3416, 9090, 'Parametras dEh limitą l dEh 1'),
	(3417, 9955, 'W11682'),
	(3418, 9354, 'Parametras dEh limitą l dEh 2'),
	(3419, 7914, 'W11683'),
	(3420, 8536, 'Parametras dEh limitą l dEh 3'),
	(3421, 2714, 'W11684'),
	(3422, 7551, 'Sistemos įvykis'),
	(3423, 6822, 'W11685'),
	(3424, 6041, 'Parametras eph limitą l eph1'),
	(3425, 8773, 'W11686'),
	(3426, 5141, 'Parametras eph limitą l eph2'),
	(3427, 2184, 'W11687'),
	(3428, 8958, 'Signalizacijos atminies užimtumas viršija 90%. '),
	(3429, 2156, 'W11688'),
	(3430, 1090, 'Signalizacijos atminies užimtumas viršija 50%. '),
	(3431, 3564, 'W11689'),
	(3432, 400, 'Aplinkos temperatūra intervalo ribas nuo tamb min iki tamb max'),
	(3433, 8846, 'W11690'),
	(3434, 684, 'Primtinas dp/p santykis'),
	(3435, 8901, 'W11691'),
	(3436, 1704, 'Parametras dp diapazoną  3.95 ÷ 20.2 mA'),
	(3437, 2071, 'W11692'),
	(3438, 9670, 'Signalizacija suveiks kai p viršys diapazoną  3.95 ÷ 20.2 mA'),
	(3439, 7911, 'W11693'),
	(3440, 8127, 'Signalizacija suveiks kai t viršys diapazoną  3.95 ÷ 20.2 mA'),
	(3441, 3256, 'W11694'),
	(3442, 6902, 'Signalizacija suveiks kai rez1  viršys diapazoną 3.95 ÷ 20.2 mA'),
	(3443, 6681, 'W11695'),
	(3444, 8528, 'Signalizacija suveiks kai rez2 viršys diapazoną  3.95 ÷ 20.2 mA'),
	(3445, 8812, 'W11696'),
	(3446, 8270, 'Slėgio skirtumo dp reikšmė limitą'),
	(3447, 387, 'W11697'),
	(3448, 7844, 'Parametras rez1 limitą'),
	(3449, 2001, 'W11698'),
	(3450, 1790, 'Parametras rez2 limitą'),
	(3451, 7725, 'W11699'),
	(3452, 8264, 'Reinoldso skaičius'),
	(3453, 7187, 'W11700'),
	(3454, 9872, 'Keitiklių poros slėgio skirtumas  limitus e dpL arba e dpH'),
	(3455, 4725, 'W11701'),
	(3456, 7102, 'Keitiklių poros slėgio skirtumas 5%'),
	(3457, 9990, 'W11702'),
	(3458, 3366, 'Impulsų įėjimai HF2 ir HF3 impulsų skaičius toleranciją'),
	(3459, 3128, 'W11703'),
	(3460, 3945, 'Kompiūteris išjungtas klaviatūros pagalba'),
	(3461, 9042, 'W11704'),
	(3462, 119, 'Algoritmas ar matavimo kanalų tikrinimo moda'),
	(3463, 3158, 'išjungta'),
	(3464, 1675, 'įjungta'),
	(3465, 5209, 'W11705'),
	(3466, 7369, 'Maksimalus dažnis'),
	(3467, 9297, 'W11706'),
	(3468, 7601, 'Pakaitinis dujų sudėties skaičiavimas'),
	(3469, 7230, 'W11707'),
	(3470, 1636, 'Atliekamas baterijos testas'),
	(3471, 4609, 'W11708'),
	(3472, 2575, 'Baterija kraunama iš srauto kompjūterio'),
	(3473, 2280, 'W11709'),
	(3474, 6942, 'UPS išsikrovęs'),
	(3475, 9217, 'W11710'),
	(3476, 1490, 'Lauko temperatūra priimtino įkrovimo diapazono'),
	(3477, 1754, 'W11711'),
	(3478, 9665, 'Ryšys su baterijos  moduliu'),
	(3479, 2279, 'atsistatė'),
	(3480, 657, 'nutrūko'),
	(3481, 3671, 'W11712'),
	(3482, 9388, 'Baterijos patikra atlikta'),
	(3483, 3668, 'W11713'),
	(3484, 9077, 'S6-1 signalo aktyvumo'),
	(3485, 2550, 'W11714'),
	(3486, 4157, 'S6-2 signalo aktyvumo'),
	(3487, 3357, 'W11715'),
	(3488, 4476, 'S6-3 signalo aktyvumo'),
	(3489, 9582, 'W11716'),
	(3490, 3896, 'S6-4 signalo aktyvumo'),
	(3491, 4348, 'W11717'),
	(3492, 8528, 'S6-5 signalo aktyvumo'),
	(3493, 3874, 'W11718'),
	(3494, 3267, 'S6-6 signalo aktyvumo'),
	(3495, 4406, 'W11719'),
	(3496, 7129, 'SN4-1 signalo aktyvumo'),
	(3497, 1597, 'W11720'),
	(3498, 3720, 'SN4-2 signalo aktyvumo'),
	(3499, 9025, 'W11721'),
	(3500, 8505, 'SN4-3 signalo aktyvumo'),
	(3501, 5160, 'W11722'),
	(3502, 8989, 'SN4-4 signalo aktyvumo'),
	(3503, 1106, 'W11723'),
	(3504, 3500, 'SN4-N signalo aktyvumo'),
	(3505, 336, 'W11724'),
	(3506, 9580, 'Signalų aktyvumo'),
	(3507, 5473, 'W11725'),
	(3508, 7984, 'SN6-1 signalo aktyvumo'),
	(3509, 989, 'W11726'),
	(3510, 3211, 'SN6-2 signalo aktyvumo'),
	(3511, 9607, 'W11727'),
	(3512, 2432, 'SN6-3 signalo aktyvumo'),
	(3513, 7559, 'W11728'),
	(3514, 4473, 'SN6-4 signalo aktyvumo'),
	(3515, 5384, 'W11729'),
	(3516, 5554, 'SN6-5 signalo aktyvumo'),
	(3517, 1369, 'W11730'),
	(3518, 1707, 'SN6-6 signalo aktyvumo'),
	(3519, 1692, 'W11731'),
	(3520, 7759, 'SO-1 signalo aktyvumo'),
	(3521, 9851, 'W11732'),
	(3522, 559, 'SO-2 signalo aktyvumo'),
	(3523, 9691, 'W11733'),
	(3524, 4726, 'SO-3 signalo aktyvumo'),
	(3525, 6457, 'W11734'),
	(3526, 2719, 'SO-4 signalo aktyvumo'),
	(3527, 9357, 'W11735'),
	(3528, 8136, 'SO-5 signalo aktyvumo'),
	(3529, 4256, 'W11736'),
	(3530, 7, 'SO-6 signalo aktyvumo'),
	(3531, 340, 'W11737'),
	(3532, 7662, 'Ryšys su modulių nr 1'),
	(3533, 186, 'dingo'),
	(3534, 5929, 'W11738'),
	(3535, 1413, 'Ryšys su modulių nr 2'),
	(3536, 792, 'W11739'),
	(3537, 8447, 'Ryšys su modulių nr 3'),
	(3538, 7842, 'W11740'),
	(3539, 509, 'Ryšys su modulių nr 4'),
	(3540, 3486, 'W11741'),
	(3541, 4070, 'Ryšys su modulių nr 5'),
	(3542, 1692, 'W11742'),
	(3543, 5670, 'Sumatoriaus reikšmė maksimalią reikšmę'),
	(3544, 7598, 'W11743'),
	(3545, 3459, 'Korekcijos klaida'),
	(3546, 9784, 'baigesi'),
	(3547, 487, 'W11744'),
	(3548, 4690, 'Vidaus temperatūra pasiekė primtiną reikšmę'),
	(3549, 2056, 'W11745'),
	(3550, 9382, 'Aliarmas 1 '),
	(3551, 9433, 'W11746'),
	(3552, 4667, 'Aliarmas 2'),
	(3553, 5088, 'W11747'),
	(3554, 1637, 'Aliarmas 3'),
	(3555, 1837, 'W11748'),
	(3556, 5133, 'Aliarmas 4 '),
	(3557, 4025, 'W11749'),
	(3558, 2058, 'Patrametras rez3 intervalą 3.95 ÷ 20.2 mA'),
	(3559, 4816, 'W11750'),
	(3560, 938, 'Parametras rez3 limitą'),
	(3561, 5270, 'viršyja'),
	(3562, 9718, 'W11751'),
	(3563, 2289, 'Įtampa rezU1 intervalą  -1 ÷ 0 V arba -2 ÷ 0 V'),
	(3564, 5788, 'W11752'),
	(3565, 4615, 'Parametras rezU1 limitą'),
	(3566, 235, 'W11753'),
	(3567, 7166, 'Parametras p1w limitą '),
	(3568, 2467, 'W11754'),
	(3569, 3092, 'Aliarmų patvirtinimas'),
	(3570, 4351, 'W11755'),
	(3571, 2620, 'Dalybos iš nulio'),
	(3572, 1308, 'W11756'),
	(3573, 8891, 'Ryšio tarp procesoriaus ir analoginės dalies'),
	(3574, 592, 'atsistatymas'),
	(3575, 8353, 'dingimas'),
	(3576, 8092, 'commit; a:=src_from_tmpl_u(:1);'),
	(3577, 2984, 'P_AU_EXISTS_METHOD_MAX_DEPTH'),
	(3578, 1245, 'Maksimalus audito analizės diapazonas paromis, kuriam naudojamas EXISTS metodas'),
	(3579, 1594, 'Apskaitos būsenų signalų šaltinio elementai'),
	(3580, 4594, 'SE_DS'),
	(3581, 2250, 'Apskaitos būsenų signalų šaltinio elementų savybės'),
	(3582, 3920, 'SE_DS_LPTY'),
	(3583, 3563, 'Apskaitos būsenų signalų šaltinio elementai, pasiekiami per ryšio kanalą'),
	(3584, 6138, 'SEP_DS'),
	(3585, 2195, 'Pasiekiamų per ryšio kanalą apskaitos būsenų signalų šaltinių elementų konfigūracija pagal nuskaitymo priežastį'),
	(3586, 8685, 'SEP_DS_RC'),
	(3587, 1883, 'a varchar2(250);\r\nhit number(1):=0;\r\norn number;'),
	(3588, 5671, 'a:=prepare_scaler_read.run(:1);\r\nif a=\'0\' then\r\nhit:=1;\r\nend if;\r\npwo_execute(:1,:2,a);\r\nif a=\'0\' then\r\nhit:=1;\r\nDELETE gttt;\r\nINSERT INTO gttt (id1,id2,c1) VALUES (:1,:2,\'S\');\r\npwl_execute;\r\nend if;\r\nif hit=1 THEN\r\nCOMMIT;\r\ninit_fill_point1(:2,a,orn,pONLY_CFG=>1);\r\nif a=\'0\' then\r\nINSERT INTO ltl (req_type_code, rodo_id)\r\nSELECT req_type_code,orn FROM rc WHERE rc_id=5;\r\nelse\r\ncheck_pw_setting (:1,:2);\r\na:=read_point_journal(:2,:1);\r\nend if;\r\nelse\r\ncheck_pw_setting (:1,:2);\r\na:=read_point_journal(:2,:1);\r\nend if;'),
	(3589, 4268, 'LOOP\r\nDELETE gttt;\r\nINSERT INTO gttt (id1,id2,id3,id4,id5)\r\nWITH\r\nc AS\r\n(SELECT src_id s,bga_param_nr r,bga_param_value v\r\n,CASE WHEN bga_type_param_key LIKE \'%ML_ID%\'THEN 1 ELSE 0 END t\r\n,lpty_value+0 l\r\nFROM\r\nst_bga_param join\r\n(SELECT s.*,src_name bga_name FROM src s) USING (bga_name)\r\njoin dp USING (dp_id)\r\njoin src_lpty USING (src_id)\r\nWHERE bga_param_nr<3\r\nAND lpty_id=151 AND LPTY_VALUE>\'0\'\r\nAND bga_enabled=1\r\nAND src_type_id=0\r\nand src_et is null\r\nAND dp_code=\'GENERATED_BY_ORACLE\'\r\n),b AS\r\n(SELECT c.*,Decode(t,1,v)+0 i FROM c),a AS\r\n(SELECT point_id p,b.* FROM point,b WHERE point_enabled=1)\r\nSELECT s,p,i,x,h from\r\n(SELECT\r\nf.*,Dense_Rank() over (PARTITION BY p,i,x ORDER BY l DESC,Decode(l,1,s))d\r\nfrom\r\n(SELECT\r\ns,p,l,Max(Decode(r,2,i))i,Max(Decode(r,2,x))x,Min(Decode(r,1,e,Nvl2(nullif(src_type_id,0),0,Decode(s,src_id,0))))w,Max(Decode(r,2,Nvl2(e,Nvl2(di_id,0,1),2)))h\r\nFROM\r\n(SELECT a.*,pl_enabled e,di_id,\'\'+0 x\r\nFROM a\r\nleft join pl ON (pl.point_id=p AND ml_id=i)\r\nleft join di ON (pl.pl_id=di.pl_id)\r\nWHERE t=1\r\nUNION ALL\r\nSELECT a.*\r\n,ds_enabled e,di_id,y.ds_type_id\r\nFROM a\r\njoin ds_type y ON (ds_type_code=v)\r\nleft join ds ON (ds.point_id=p AND ds.ds_type_id=y.ds_type_id)\r\nleft join di ON (ds.ds_id=di.ds_id)\r\nWHERE t=0)\r\nleft join\r\n(SELECT src_id,di_id,src_type_id FROM\r\nse join src USING (src_id) join dp USING (dp_id)\r\nWHERE src_et IS NULL AND dp_deleted =0) USING (di_id)\r\nGROUP BY s,p,l)f\r\nWHERE w=1 AND Nvl(i,x)>0\r\n) WHERE d=1 AND ROWNUM<=10000;\r\nEXIT WHEN SQL%ROWCOUNT=0;\r\nINSERT INTO pl (pl_id,point_id,ml_id)\r\nSELECT pl_seq.NEXTVAL,a.* FROM\r\n(SELECT DISTINCT id2,id3 FROM gttt WHERE id3>0 AND id5=2)a;\r\nINSERT INTO ds (ds_id,ds_code,ds_name,ds_type_id,ds_enabled,ds_event_log,ds_rt_enabled,ds_binary,enum_id,point_id)\r\nSELECT ds_seq.NEXTVAL,a.* FROM\r\n(SELECT DISTINCT substr(point_code||\'.\'||DS_TYPE_CODE,1,120),DS_TYPE_NAME,id4,1,ds_event_log,ds_rt_enabled,ds_binary,enum_id,id2 FROM gttt a,ds_type,point\r\nWHERE id2=point_id AND id4=ds_type_id AND id5=2)a;\r\nINSERT INTO di (di_id,di_enabled,lp_id,pl_id,ds_id,point_id)\r\nSELECT di_seq.NEXTVAL,1,lp_id,a.* FROM\r\n(SELECT DISTINCT pl_id,\'\'+0 ds_id,\'\'+0 point_id FROM gttt,pl WHERE id2=point_id AND id3=ml_id AND id5>0\r\nUNION ALL SELECT DISTINCT \'\'+0,ds_id,point_id FROM gttt,ds WHERE id2=point_id AND id4=ds_type_id AND id5>0)a,(SELECT lp_id FROM (SELECT lp_id FROM lp ORDER BY 1) WHERE ROWNUM=1);\r\nUPDATE dip SET di_et=DATE\'9999-12-31\'\r\nWHERE di_id IN (SELECT di_id FROM gttt,pl b,di c WHERE b.pl_id=c.pl_id AND id2=b.point_id AND id3=ml_id AND id5>0\r\nUNION ALL SELECT di_id FROM gttt,ds b,di c WHERE b.ds_id=c.ds_id AND id2=b.point_id AND id4=ds_type_id AND id5>0) AND di_et IS NULL;\r\nMERGE INTO dip y\r\nUSING (SELECT di_id,Max(di_bt) di_bt\r\nFROM\r\n(SELECT di_id FROM gttt,pl b,di c WHERE b.pl_id=c.pl_id AND id2=b.point_id AND id3=ml_id\r\nUNION ALL SELECT di_id FROM gttt,ds b,di c WHERE b.ds_id=c.ds_id AND id2=b.point_id AND id4=ds_type_id) join dip USING (di_id)\r\nGROUP BY di_id\r\nHAVING Max(Decode(di_et,NULL,1,DATE\'9999-12-31\',1)) IS NULL\r\n) u\r\nON (y.di_id=u.di_id AND y.di_bt=u.di_bt)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.di_et=DATE\'9999-12-31\';\r\nINSERT INTO se (se_id, src_id, di_id, se_ab, se_a, se_b, se_enabled, se_forced, se_h, se_h_per_id, se_h_depth)\r\nSELECT se_seq.NEXTVAL,id1,di_id,\'\',\'\',\'\',1,0,1,4,2 FROM\r\n(SELECT id1,di_id FROM gttt,pl b,di c WHERE b.pl_id=c.pl_id AND id2=b.point_id AND id3=ml_id\r\nUNION ALL SELECT id1,di_id FROM gttt,ds b,di c WHERE b.ds_id=c.ds_id AND id2=b.point_id AND id4=ds_type_id);\r\nINSERT INTO sep (sep_id,se_id,sp_id)\r\nSELECT sep_seq.NEXTVAL,se_id,sp_id FROM\r\n(SELECT id1 src_id,di_id FROM gttt,pl b,di c WHERE b.pl_id=c.pl_id AND id2=b.point_id AND id3=ml_id\r\nUNION ALL SELECT id1,di_id FROM gttt,ds b,di c WHERE b.ds_id=c.ds_id AND id2=b.point_id AND id4=ds_type_id)\r\njoin se USING (src_id, di_id)\r\njoin sp USING (src_id);\r\nCOMMIT;\r\nEND LOOP;');
/*!40000 ALTER TABLE `ae` ENABLE KEYS */;

-- Dumping structure for table emcor.aggf
CREATE TABLE IF NOT EXISTS `aggf` (
  `aggf_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo funkcijos identifikatorius',
  `aggf_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Agregavimo funkcijos pavadinimas',
  PRIMARY KEY (`aggf_id`),
  UNIQUE KEY `aggf_name_u` (`aggf_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Agregavimo funkcijos';

-- Dumping data for table emcor.aggf: ~45 rows (approximately)
/*!40000 ALTER TABLE `aggf` DISABLE KEYS */;
INSERT INTO `aggf` (`aggf_id`, `aggf_name`) VALUES
	(1, 'Be agregavimo'),
	(45, 'Harmonika 01'),
	(6, 'Harmonika 02'),
	(7, 'Harmonika 03'),
	(8, 'Harmonika 04'),
	(9, 'Harmonika 05'),
	(10, 'Harmonika 06'),
	(11, 'Harmonika 07'),
	(12, 'Harmonika 08'),
	(13, 'Harmonika 09'),
	(14, 'Harmonika 10'),
	(15, 'Harmonika 11'),
	(16, 'Harmonika 12'),
	(17, 'Harmonika 13'),
	(18, 'Harmonika 14'),
	(19, 'Harmonika 15'),
	(20, 'Harmonika 16'),
	(21, 'Harmonika 17'),
	(22, 'Harmonika 18'),
	(23, 'Harmonika 19'),
	(24, 'Harmonika 20'),
	(25, 'Harmonika 21'),
	(26, 'Harmonika 22'),
	(27, 'Harmonika 23'),
	(28, 'Harmonika 24'),
	(29, 'Harmonika 25'),
	(30, 'Harmonika 26'),
	(31, 'Harmonika 27'),
	(32, 'Harmonika 28'),
	(33, 'Harmonika 29'),
	(34, 'Harmonika 30'),
	(35, 'Harmonika 31'),
	(36, 'Harmonika 32'),
	(37, 'Harmonika 33'),
	(38, 'Harmonika 34'),
	(39, 'Harmonika 35'),
	(40, 'Harmonika 36'),
	(41, 'Harmonika 37'),
	(42, 'Harmonika 38'),
	(43, 'Harmonika 39'),
	(44, 'Harmonika 40'),
	(4, 'Maksimumas'),
	(5, 'Minimumas'),
	(2, 'Suma'),
	(3, 'Vidurkis');
/*!40000 ALTER TABLE `aggf` ENABLE KEYS */;

-- Dumping structure for table emcor.aggs
CREATE TABLE IF NOT EXISTS `aggs` (
  `aggs_id` tinyint(3) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Agregavimo segmento identifikatorius',
  `aggs_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Agregavimo segmento pavadinimas',
  `aggs_value` smallint(5) unsigned DEFAULT NULL COMMENT 'Agregavimo dydis',
  `per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Periodo identifikatorius',
  `aggs_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  `aggs_cnt` mediumint(8) unsigned DEFAULT NULL COMMENT 'Agregavimo segmentų kiekis paroje',
  PRIMARY KEY (`aggs_id`),
  UNIQUE KEY `aggs_aggs_name_u` (`aggs_name`),
  KEY `aggs_aggs_type_i` (`aggs_type_id`),
  KEY `aggs_per_i` (`per_id`),
  CONSTRAINT `aggs_aggs_type_fk` FOREIGN KEY (`aggs_type_id`) REFERENCES `aggs_type` (`aggs_type_id`),
  CONSTRAINT `aggs_per_fk` FOREIGN KEY (`per_id`) REFERENCES `per` (`per_id`)
) ENGINE=InnoDB AUTO_INCREMENT=16 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Agregavimo segmentai';

-- Dumping data for table emcor.aggs: ~15 rows (approximately)
/*!40000 ALTER TABLE `aggs` DISABLE KEYS */;
INSERT INTO `aggs` (`aggs_id`, `aggs_name`, `aggs_value`, `per_id`, `aggs_type_id`, `aggs_cnt`) VALUES
	(1, '1 minutė', 1, 2, 1, 1440),
	(2, '2 minutės', 2, 2, 1, 720),
	(3, 'Pusvalandis', 30, 2, 2, 48),
	(4, 'Valanda', 1, 3, 2, 24),
	(5, 'Para', 1, 4, 3, 1),
	(6, 'Mėnuo', 1, 5, 4, 1),
	(7, 'Be agregavimo', NULL, NULL, 6, NULL),
	(8, 'Visas laikas', NULL, NULL, 5, NULL),
	(9, '3 minutės', 3, 2, 1, 480),
	(10, '4 minutės', 4, 2, 1, 360),
	(11, '5 minutės', 5, 2, 1, 288),
	(12, '10 minučių', 10, 2, 1, 144),
	(13, '15 minučių', 15, 2, 2, 96),
	(14, '20 minučių', 20, 2, 2, 72),
	(15, '3 sekundės', 3, 1, 7, 28800);
/*!40000 ALTER TABLE `aggs` ENABLE KEYS */;

-- Dumping structure for table emcor.aggs_type
CREATE TABLE IF NOT EXISTS `aggs_type` (
  `aggs_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  `aggs_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Agregavimo segmento tipo pavadinimas',
  PRIMARY KEY (`aggs_type_id`),
  UNIQUE KEY `aggs_type_name_u` (`aggs_type_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Agregavimo segmentų tipai';

-- Dumping data for table emcor.aggs_type: ~7 rows (approximately)
/*!40000 ALTER TABLE `aggs_type` DISABLE KEYS */;
INSERT INTO `aggs_type` (`aggs_type_id`, `aggs_type_name`) VALUES
	(1, 'Minutiniai duomenys'),
	(6, 'Momentiniai duomenys'),
	(4, 'Mėnesių duomenys'),
	(2, 'Paros profilis'),
	(3, 'Parų duomenys'),
	(7, 'Sekundiniai duomenys'),
	(5, 'Suminiai duomenys');
/*!40000 ALTER TABLE `aggs_type` ENABLE KEYS */;

-- Dumping structure for table emcor.alert_buf
CREATE TABLE IF NOT EXISTS `alert_buf` (
  `alertname` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Alert vardas'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Aplikacijos alertų buferis';

-- Dumping data for table emcor.alert_buf: ~0 rows (approximately)
/*!40000 ALTER TABLE `alert_buf` DISABLE KEYS */;
/*!40000 ALTER TABLE `alert_buf` ENABLE KEYS */;

-- Dumping structure for table emcor.algr
CREATE TABLE IF NOT EXISTS `algr` (
  `algr_id` tinyint(3) unsigned NOT NULL COMMENT 'Grupių prieigos lygio identifikatorius',
  `algr_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Grupių prieigos lygio kodas',
  `algr_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Grupių prieigos lygio pavadinimas',
  PRIMARY KEY (`algr_id`),
  UNIQUE KEY `algr_code_u` (`algr_code`),
  UNIQUE KEY `algr_name_u` (`algr_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Grupių prieigos lygiai';

-- Dumping data for table emcor.algr: ~3 rows (approximately)
/*!40000 ALTER TABLE `algr` DISABLE KEYS */;
INSERT INTO `algr` (`algr_id`, `algr_code`, `algr_name`) VALUES
	(1, 'VIEW_GROUP_WITHOUT_CONTENT', 'Grupės peržiūra be sudėties'),
	(2, 'VIEW_GROUP_WITH_CONTENT', 'Grupės peržiūra kartu su sudėtim'),
	(3, 'MODIFY_GROUP_CONTENT', 'Grupės peržiūra ir sudėties redagavimas');
/*!40000 ALTER TABLE `algr` ENABLE KEYS */;

-- Dumping structure for table emcor.au
CREATE TABLE IF NOT EXISTS `au` (
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `au_nr` mediumint(8) unsigned NOT NULL COMMENT 'Audito įvykio numeris',
  `user_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojo identifikatorius',
  `tab_id` mediumint(8) unsigned NOT NULL COMMENT 'Lentelės identifikatorius',
  `operation_type` varchar(1) COLLATE utf8_bin NOT NULL COMMENT 'Keitimo tipas',
  `ses_id` bigint(20) unsigned DEFAULT NULL COMMENT 'Sesijos identifikatorius',
  PRIMARY KEY (`db_time`,`au_nr`),
  KEY `au_tab_i` (`tab_id`,`db_time`),
  KEY `au_user_i` (`user_id`,`db_time`),
  CONSTRAINT `au_tab_fk` FOREIGN KEY (`tab_id`) REFERENCES `tab` (`tab_id`),
  CONSTRAINT `au_user_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Audito įrašai apie duomenų keitimo operacijas, atliktas sistemos vartotojų';

-- Dumping data for table emcor.au: ~0 rows (approximately)
/*!40000 ALTER TABLE `au` DISABLE KEYS */;
/*!40000 ALTER TABLE `au` ENABLE KEYS */;

-- Dumping structure for table emcor.au_cdata
CREATE TABLE IF NOT EXISTS `au_cdata` (
  `db_time` datetime NOT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `au_nr` mediumint(8) unsigned NOT NULL COMMENT 'Audito įvykio numeris',
  `col_id` mediumint(8) unsigned NOT NULL COMMENT 'Lauko identifikatorius',
  `old_ae_id` int(10) unsigned DEFAULT NULL COMMENT 'Senos tekstinės reikšmės elemento identifikatorius',
  `new_ae_id` int(10) unsigned DEFAULT NULL COMMENT 'Naujos tekstinės reikšmės elemento identifikatorius',
  PRIMARY KEY (`db_time`,`au_nr`,`col_id`),
  KEY `au_cdata_col_fk` (`col_id`),
  KEY `au_cdata_new_ae_fk` (`new_ae_id`),
  KEY `au_cdata_old_ae_fk` (`old_ae_id`),
  CONSTRAINT `au_cdata_au_fk` FOREIGN KEY (`db_time`, `au_nr`) REFERENCES `au` (`db_time`, `au_nr`) ON DELETE CASCADE,
  CONSTRAINT `au_cdata_col_fk` FOREIGN KEY (`col_id`) REFERENCES `col` (`col_id`),
  CONSTRAINT `au_cdata_new_ae_fk` FOREIGN KEY (`new_ae_id`) REFERENCES `ae` (`ae_id`),
  CONSTRAINT `au_cdata_old_ae_fk` FOREIGN KEY (`old_ae_id`) REFERENCES `ae` (`ae_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Audito informacija apie CHAR tipo laukus';

-- Dumping data for table emcor.au_cdata: ~0 rows (approximately)
/*!40000 ALTER TABLE `au_cdata` DISABLE KEYS */;
/*!40000 ALTER TABLE `au_cdata` ENABLE KEYS */;

-- Dumping structure for table emcor.au_ddata
CREATE TABLE IF NOT EXISTS `au_ddata` (
  `db_time` datetime NOT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `au_nr` mediumint(8) unsigned NOT NULL COMMENT 'Audito įvykio numeris',
  `col_id` mediumint(8) unsigned NOT NULL COMMENT 'Lauko identifikatorius',
  `old_val` datetime DEFAULT NULL COMMENT 'Sena reikšmė',
  `new_val` datetime DEFAULT NULL COMMENT 'Nauja reikšmė',
  PRIMARY KEY (`db_time`,`au_nr`,`col_id`),
  KEY `au_ddata_col_fk` (`col_id`),
  CONSTRAINT `au_ddata_au_fk` FOREIGN KEY (`db_time`, `au_nr`) REFERENCES `au` (`db_time`, `au_nr`) ON DELETE CASCADE,
  CONSTRAINT `au_ddata_col_fk` FOREIGN KEY (`col_id`) REFERENCES `col` (`col_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Audito informacija apie DATE tipo laukus';

-- Dumping data for table emcor.au_ddata: ~0 rows (approximately)
/*!40000 ALTER TABLE `au_ddata` DISABLE KEYS */;
/*!40000 ALTER TABLE `au_ddata` ENABLE KEYS */;

-- Dumping structure for table emcor.au_idata
CREATE TABLE IF NOT EXISTS `au_idata` (
  `db_time` datetime NOT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `au_nr` mediumint(8) unsigned NOT NULL COMMENT 'Audito įvykio numeris',
  `col_id` mediumint(8) unsigned NOT NULL COMMENT 'Lauko identifikatorius',
  `old_val` bigint(20) DEFAULT NULL COMMENT 'Sena reikšmė',
  `new_val` bigint(20) DEFAULT NULL COMMENT 'Nauja reikšmė',
  PRIMARY KEY (`db_time`,`au_nr`,`col_id`),
  KEY `au_idata_col_fk` (`col_id`),
  CONSTRAINT `au_idata_au_fk` FOREIGN KEY (`db_time`, `au_nr`) REFERENCES `au` (`db_time`, `au_nr`) ON DELETE CASCADE,
  CONSTRAINT `au_idata_col_fk` FOREIGN KEY (`col_id`) REFERENCES `col` (`col_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Audito informacija apie INTEGER tipo laukus';

-- Dumping data for table emcor.au_idata: ~0 rows (approximately)
/*!40000 ALTER TABLE `au_idata` DISABLE KEYS */;
/*!40000 ALTER TABLE `au_idata` ENABLE KEYS */;

-- Dumping structure for table emcor.au_ndata
CREATE TABLE IF NOT EXISTS `au_ndata` (
  `db_time` datetime NOT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `au_nr` mediumint(8) unsigned NOT NULL COMMENT 'Audito įvykio numeris',
  `col_id` mediumint(8) unsigned NOT NULL COMMENT 'Lauko identifikatorius',
  `old_val` double DEFAULT NULL COMMENT 'Sena reikšmė',
  `new_val` double DEFAULT NULL COMMENT 'Nauja reikšmė',
  PRIMARY KEY (`db_time`,`au_nr`,`col_id`),
  KEY `au_ndata_col_fk` (`col_id`),
  CONSTRAINT `au_ndata_au_fk` FOREIGN KEY (`db_time`, `au_nr`) REFERENCES `au` (`db_time`, `au_nr`) ON DELETE CASCADE,
  CONSTRAINT `au_ndata_col_fk` FOREIGN KEY (`col_id`) REFERENCES `col` (`col_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Audito informacija apie NUMBER tipo laukus';

-- Dumping data for table emcor.au_ndata: ~0 rows (approximately)
/*!40000 ALTER TABLE `au_ndata` DISABLE KEYS */;
/*!40000 ALTER TABLE `au_ndata` ENABLE KEYS */;

-- Dumping structure for table emcor.bga
CREATE TABLE IF NOT EXISTS `bga` (
  `bga_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'DB aplikacijos foninės užduoties ID',
  `bga_type_id` mediumint(8) unsigned NOT NULL COMMENT 'DB aplikacijos foninių užduočių tipo ID',
  `bga_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'DB aplikacijos foninės užduoties pavadinimas',
  `bga_enabled` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'DB aplikacijos foninės užduoties naudojimo požymis',
  `sch_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Tvarkaraščio identifikatorius',
  `gr_id` int(10) unsigned DEFAULT NULL COMMENT 'Grupės identifikatorius',
  `bgaq_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Foninių užduočių užsakymų eilės identifikatorius',
  `bga_priority` tinyint(3) unsigned NOT NULL DEFAULT 5 COMMENT 'DB aplikacijos foninės užduoties prioritetas',
  PRIMARY KEY (`bga_id`),
  UNIQUE KEY `bga_name_u` (`bga_name`),
  KEY `bga_bga_type_i` (`bga_type_id`),
  KEY `bga_gr_i` (`gr_id`),
  KEY `bga_sch_i` (`sch_id`),
  KEY `bga_bgaq_fk` (`bgaq_id`),
  CONSTRAINT `bga_bga_type_fk` FOREIGN KEY (`bga_type_id`) REFERENCES `bga_type` (`bga_type_id`) ON DELETE CASCADE,
  CONSTRAINT `bga_bgaq_fk` FOREIGN KEY (`bgaq_id`) REFERENCES `bgaq` (`bgaq_id`) ON DELETE SET NULL,
  CONSTRAINT `bga_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE,
  CONSTRAINT `bga_sch_fk` FOREIGN KEY (`sch_id`) REFERENCES `sch` (`sch_id`)
) ENGINE=InnoDB AUTO_INCREMENT=764 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='DB aplikacijos foninės užduotys';

-- Dumping data for table emcor.bga: ~570 rows (approximately)
/*!40000 ALTER TABLE `bga` DISABLE KEYS */;
INSERT INTO `bga` (`bga_id`, `bga_type_id`, `bga_name`, `bga_enabled`, `sch_id`, `gr_id`, `bgaq_id`, `bga_priority`) VALUES
	(21, 21, 'A+ energijos per mėnesį rodmenų generavimas iš parų reikšmių', 0, 62, NULL, NULL, 5),
	(22, 26, 'A+ energijos per parą rodmenų generavimas iš valandinių reikšmių', 0, 62, NULL, NULL, 5),
	(23, 131, 'A+ energijos per parą rodmenų generavimas iš visų tarifų energijų sumos', 0, 62, NULL, NULL, 5),
	(24, 21, 'Karšto vandens tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių', 0, 62, NULL, NULL, 5),
	(25, 26, 'Karšto vandens tūrio kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių', 0, 62, NULL, NULL, 5),
	(26, 27, 'Naujų generuojamų matavimų linijų įtraukimas naujiems taškams', 1, 62, NULL, NULL, 5),
	(27, 21, 'Šalto vandens tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių', 0, 62, NULL, NULL, 5),
	(28, 26, 'Šalto vandens tūrio kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių', 0, 62, NULL, NULL, 5),
	(29, 22, 'Šilumnešio temp.grafiko Ukmergės Katilinės Nr.1 šilumos vartotojams duomenų generavimas pagal lauko temperatūrą', 0, 62, NULL, NULL, 5),
	(30, 22, 'Šilumnešio temp.grafiko Ukmergės Katilinės Nr.3 šilumos vartotojams duomenų generavimas pagal lauko temperatūrą', 0, 62, NULL, NULL, 5),
	(32, 26, 'Šilumnešio šilumos kiekio per parą rodmenų generavimas iš vidutinės šilumos galios per valandą', 0, 62, NULL, NULL, 5),
	(33, 26, 'Šilumnešio tūrio kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių', 0, 62, NULL, NULL, 5),
	(34, 25, 'Vidutinės grįžtamo šilumnešio temperatūros per parą rodmenų generavimas iš valandinių reikšmių', 0, 62, NULL, NULL, 5),
	(35, 31, 'Vidutinės grįžtamo šilumnešio temperatūros per valandą rodmenų generavimas iš momentinių reikšmių', 0, 62, NULL, NULL, 5),
	(36, 25, 'Vidutinės oro temperatūros per parą rodmenų generavimas iš vidutinės oro temperatūros per valandą', 0, 62, NULL, NULL, 5),
	(37, 23, 'Vidutinės oro temperatūros per valandą rodmenų generavimas iš vidutinės oro temperatūros per 15 minučių', 0, 62, NULL, NULL, 5),
	(38, 28, 'Vidutinės P+ galios per valandą rodmenų generavimas iš vidutinės galios per 30 minučių', 0, 62, NULL, NULL, 5),
	(39, 30, 'Vidutinės šilumnešio šilumos galios per valandą rodmenų generavimas iš augančių reikšmių', 0, 62, NULL, NULL, 5),
	(40, 25, 'Vidutinės tiekiamo šilumnešio temperatūros per parą rodmenų generavimas iš valandinių reikšmių', 0, 62, NULL, NULL, 5),
	(41, 31, 'Vidutinės tiekiamo šilumnešio temperatūros per valandą rodmenų generavimas iš momentinių reikšmių', 0, 62, NULL, NULL, 5),
	(42, 30, 'Vidutinio karšto vandens tūrio debito per valandą rodmenų generavimas iš augančių reikšmių', 0, 62, NULL, NULL, 5),
	(43, 30, 'Vidutinio šalto vandens tūrio debito per valandą rodmenų generavimas iš augančių reikšmių', 0, 62, NULL, NULL, 5),
	(44, 23, 'Vidutinio šalto vandens tūrio debito per valandą rodmenų generavimas iš vidutinio debito reikšmių per 15 minučių', 0, 62, NULL, NULL, 5),
	(45, 29, 'Vidutinio šalto vandens tūrio debito per 15 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 0, 62, NULL, NULL, 5),
	(46, 30, 'Vidutinio šilumnešio tūrio debito per valandą rodmenų generavimas iš augančių reikšmių', 0, 62, NULL, NULL, 5),
	(47, 25, 'Vidutinio tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumo per parą rodmenų generavimas iš valandinių reikšmių', 0, 62, NULL, NULL, 5),
	(48, 31, 'Vidutinio tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumo per valandą rodmenų generavimas iš momentinių reikšmių', 0, 62, NULL, NULL, 5),
	(49, 30, 'Vidutinės P+ galios per valandą rodmenų generavimas iš augančių reikšmių', 0, 62, NULL, NULL, 5),
	(61, 30, 'Vidutinio dujų tūrio debito per valandą rodmenų generavimas iš augančių reikšmių', 0, 62, NULL, NULL, 5),
	(62, 26, 'Dujų tūrio kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių', 0, 62, NULL, NULL, 5),
	(63, 21, 'Dujų tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių', 0, 62, NULL, NULL, 5),
	(64, 30, 'Vidutinio dujų koreguoto tūrio debito per valandą rodmenų generavimas iš augančių reikšmių', 0, 62, NULL, NULL, 5),
	(65, 26, 'Dujų koreguoto tūrio kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių', 0, 62, NULL, NULL, 5),
	(66, 21, 'Dujų koreguoto tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių', 0, 62, NULL, NULL, 5),
	(71, 46, 'Taškai, nepasiekiami per apskaitos taškų medį', 1, 43, 549, NULL, 5),
	(86, 29, 'Vidutinio karšto vandens tūrio debito per 15 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 0, 62, NULL, NULL, 5),
	(87, 23, 'Vidutinio karšto vandens tūrio debito per valandą rodmenų generavimas iš vidutinio debito reikšmių per 15 minučių', 0, 62, NULL, NULL, 5),
	(91, 61, 'Naujų generuojamų suminių matavimų elementų įtraukimas naujiems taškams', 1, 62, NULL, NULL, 5),
	(92, 62, 'Suminių rodmenų proporcingas generavimas iš gretimų reikšmių', 0, 62, NULL, NULL, 5),
	(96, 132, 'A+ energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį ', 0, 43, NULL, NULL, 5),
	(106, 23, 'Vidutinės tiekiamo šilumnešio temperatūros per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių', 0, 62, NULL, NULL, 5),
	(107, 23, 'Vidutinės grįžtamo šilumnešio temperatūros per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių', 0, 62, NULL, NULL, 5),
	(110, 29, 'Vidutinės šilumnešio šilumos galios per 15 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 0, 62, NULL, NULL, 5),
	(111, 23, 'Vidutinės šilumnešio šilumos galios per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių', 0, 62, NULL, NULL, 5),
	(112, 29, 'Vidutinio dujų koreguoto tūrio debito per 15 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 0, 62, NULL, NULL, 5),
	(113, 23, 'Vidutinio dujų koreguoto tūrio debito per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių', 0, 62, NULL, NULL, 5),
	(116, 86, 'Vidutinės P+ galios per valandą rodmenų generavimas iš vidutinės galios per 5 minutes', 0, 62, NULL, NULL, 5),
	(117, 86, 'Vidutinės Q+ galios per valandą rodmenų generavimas iš vidutinės galios per 5 minutes', 0, 62, NULL, NULL, 5),
	(118, 86, 'Vidutinės Q- galios per valandą rodmenų generavimas iš vidutinės galios per 5 minutes', 0, 62, NULL, NULL, 5),
	(121, 29, 'Vidutinės P+ galios per 15 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 0, 62, NULL, NULL, 5),
	(122, 23, 'Vidutinės P+ galios per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių', 0, 62, NULL, NULL, 5),
	(126, 96, 'Vidutinio dujų koreguoto tūrio debito per valandą rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 0, 62, NULL, NULL, 5),
	(127, 96, 'Vidutinės šilumnešio šilumos galios per val. rodmenų generavimas iš aug. reikšmių, užfiksuotų kas 15 minučių', 0, 62, NULL, NULL, 5),
	(128, 96, 'Vidutinio šalto vandens tūrio debito per valandą rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 0, 62, NULL, NULL, 5),
	(129, 96, 'Vidutinės P+ galios per valandą rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 0, 62, NULL, NULL, 5),
	(130, 96, 'Vidutinio karšto vandens tūrio debito per valandą rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 0, 62, NULL, NULL, 5),
	(131, 101, 'Vidutinės Q+ galios per 30 minučių rodmenų generavimas iš reikšmių pagal kvadrantus Q1 ir Q2', 0, 62, NULL, NULL, 5),
	(132, 101, 'Vidutinės Q- galios per 30 minučių rodmenų generavimas iš reikšmių pagal kvadrantus Q3 ir Q4', 0, 62, NULL, NULL, 5),
	(136, 21, 'R- energijos per mėnesį rodmenų generavimas iš parų reikšmių', 0, NULL, NULL, NULL, 5),
	(137, 21, 'R+ energijos per mėnesį rodmenų generavimas iš parų reikšmių', 0, NULL, NULL, NULL, 5),
	(138, 21, 'A- energijos per mėnesį rodmenų generavimas iš parų reikšmių', 0, NULL, NULL, NULL, 5),
	(139, 23, 'Vidutinio tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumo per valandą generavimas iš vidutinių 15 min. reikšmių', 0, 62, NULL, NULL, 5),
	(140, 106, 'Pusvalandinės vidutinės P+ galios duomenų generavimas iš užfiksuotų kas 30 min. A+ suminių duomenų', 0, NULL, NULL, NULL, 5),
	(141, 111, 'Periodinis automatinis visų matavimo taškų matavimo linijų duomenų įrašų trynimas', 0, 62, NULL, NULL, 5),
	(142, 112, 'Periodinis automatinis visų audito įrašų apie duomenų keitimo operacijas, atliktų sistemos vartotojų, trynimas', 0, 303, NULL, NULL, 5),
	(143, 113, 'Periodinis automatinis visų monitoringo priskyrimų automatinio tikrinimo rezultatų įrašų trynimas', 1, 62, NULL, NULL, 5),
	(144, 114, 'Periodinis automatinis visų sistemos įvykių įrašų trynimas', 1, 62, NULL, NULL, 5),
	(145, 115, 'Periodinis automatinis visų ataskaitų formavimo ir siuntimo žurnalo įrašų trynimas', 1, 43, NULL, NULL, 5),
	(146, 116, 'Periodinis automatinis visų nuskaitymų pagal pareikalavimą užsakymų įrašų trynimas', 1, 43, NULL, NULL, 5),
	(147, 117, 'Periodinis automatinis negaliojančių matavimo taškų matavimo linijų duomenų įrašų trynimas', 1, 62, NULL, NULL, 5),
	(148, 118, 'Periodinis automatinis visų uždaromų periodų įrašų trynimas', 0, 303, NULL, NULL, 5),
	(149, 119, 'Periodinis automatinis negaliojančių apskaitos būsenų duomenų įrašų trynimas', 1, 62, NULL, NULL, 5),
	(150, 120, 'Periodinis automatinis visų apskaitos būsenų duomenų įrašų trynimas', 0, 62, NULL, NULL, 5),
	(151, 121, 'Periodinis automatinis visų užfiksuotų įvykių atvejų istorijos įrašų trynimas', 1, 43, NULL, NULL, 5),
	(156, 126, 'Periodinis automatinis visų matavimo taškų matavimo linijų momentinių duomenų įrašų trynimas', 0, 62, NULL, NULL, 5),
	(157, 127, 'Periodinis automatinis visų matavimo taškų matavimo linijų minutinių duomenų įrašų trynimas', 0, 62, NULL, NULL, 5),
	(162, 131, 'A- energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą', 0, NULL, NULL, NULL, 5),
	(163, 131, 'R+ energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą', 0, NULL, NULL, NULL, 5),
	(164, 131, 'R- energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą', 0, NULL, NULL, NULL, 5),
	(165, 131, 'R1 energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą', 0, NULL, NULL, NULL, 5),
	(166, 131, 'R2 energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą', 0, NULL, NULL, NULL, 5),
	(167, 131, 'R3 energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą', 0, NULL, NULL, NULL, 5),
	(168, 131, 'R4 energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą', 0, NULL, NULL, NULL, 5),
	(170, 132, 'A- energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį', 0, NULL, NULL, NULL, 5),
	(171, 132, 'R+ energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį', 0, NULL, NULL, NULL, 5),
	(172, 132, 'R- energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį', 0, NULL, NULL, NULL, 5),
	(173, 132, 'R1 energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį', 0, NULL, NULL, NULL, 5),
	(174, 132, 'R2 energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį', 0, NULL, NULL, NULL, 5),
	(175, 132, 'R3 energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį', 0, NULL, NULL, NULL, 5),
	(176, 132, 'R4 energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį', 0, NULL, NULL, NULL, 5),
	(181, 136, 'Vidutinės P+ galios per 30 minučių rodmenų generavimas iš vidutinės galios per 3 minutes', 0, NULL, NULL, NULL, 5),
	(182, 136, 'Vidutinės P- galios per 30 minučių rodmenų generavimas iš vidutinės galios per 3 minutes', 0, NULL, NULL, NULL, 5),
	(183, 137, 'Vidutinės P+ galios per valandą rodmenų generavimas iš esamų valandinių ir augančių pagal tarifus reikšmių', 0, NULL, NULL, NULL, 5),
	(186, 26, 'R- energijos per parą rodmenų generavimas is valandinių reikšmių', 0, 238, NULL, NULL, 5),
	(187, 26, 'R+ energijos per parą rodmenų generavimas is valandinių reikšmių', 0, 238, NULL, NULL, 5),
	(188, 26, 'A- energijos per parą rodmenų generavimas is valandinių reikšmių', 0, 238, NULL, NULL, 5),
	(202, 21, 'Šilumnešio tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių', 0, 238, NULL, NULL, 5),
	(203, 21, 'Šilumnešio šilumos kiekio per mėnesį rodmenų generavimas iš parų reikšmių', 0, 238, NULL, NULL, 5),
	(204, 96, 'Vidutinio šilumnešio tūrio debito per val. rodmenų generavimas iš aug. reikšmių, užfiksuotų kas 15 minučių', 0, 238, NULL, NULL, 5),
	(205, 151, 'Periodinis automatinis visų plep duomenų įrašų trynimas', 1, 62, NULL, NULL, 5),
	(206, 156, 'Periodinis automatinis visų DB aplikacijos foninių užduočių vykdymo užsakymų įrašų trynimas', 1, 62, NULL, NULL, 5),
	(207, 26, 'Dujų koreguoto tūrio kiekio per parą rodmenų generavimas iš valandinių reikšmių', 0, 238, NULL, NULL, 5),
	(211, 96, 'Vidutinės P+ galios per valandą rodmenų generavimas iš augančių reikšmių, užfiksuotų kas valandą', 0, 62, NULL, NULL, 5),
	(216, 166, 'Elektros pilnosios galios S+ per 30 minučių duomenų generavimas iš P+ ir Q+', 0, NULL, NULL, NULL, 5),
	(221, 166, 'Elektros pilnosios galios S+ per valandą duomenų generavimas iš P+ ir Q+', 0, NULL, NULL, NULL, 5),
	(226, 28, 'Vidutinės P- galios per valandą rodmenų generavimas iš vidutinės galios per 30 minučių', 0, NULL, NULL, NULL, 5),
	(227, 28, 'Vidutinės Q+ galios per valandą rodmenų generavimas iš vidutinės galios per 30 minučių', 0, NULL, NULL, NULL, 5),
	(228, 28, 'Vidutinės Q- galios per valandą rodmenų generavimas iš vidutinės galios per 30 minučių', 0, NULL, NULL, NULL, 5),
	(241, 171, 'Vidutinės P+ galios per 30 min. rodmenų generavimas iš augančių reikšmių', 0, NULL, NULL, NULL, 5),
	(242, 172, 'A+ energijos per parą rodmenų generavimas iš vidutinių reikšmių per 30 min.', 0, NULL, NULL, NULL, 5),
	(243, 172, 'A- energijos per parą rodmenų generavimas iš vidutinių reikšmių per 30 min.', 0, NULL, NULL, NULL, 5),
	(244, 172, 'R+ energijos per parą rodmenų generavimas iš vidutinių reikšmių per 30 min.', 0, NULL, NULL, NULL, 5),
	(245, 172, 'R- energijos per parą rodmenų generavimas iš vidutinių reikšmių per 30 min.', 0, NULL, NULL, NULL, 5),
	(246, 173, 'A+ energijos per parą rodmenų generavimas iš augančių reikšmių', 0, NULL, NULL, NULL, 5),
	(251, 173, 'A- energijos per parą rodmenų generavimas iš augančių reikšmių', 0, NULL, NULL, NULL, 5),
	(252, 173, 'R+ energijos per parą rodmenų generavimas iš augančių reikšmių', 0, NULL, NULL, NULL, 5),
	(253, 173, 'R- energijos per parą rodmenų generavimas iš augančių reikšmių', 0, NULL, NULL, NULL, 5),
	(256, 161, 'Suminės A+ energijos rodmenų generavimas iš visų tarifų sumų', 0, NULL, NULL, NULL, 5),
	(257, 161, 'Suminės A- energijos rodmenų generavimas iš visų tarifų sumų', 0, NULL, NULL, NULL, 5),
	(258, 161, 'Suminės R+ energijos rodmenų generavimas iš visų tarifų sumų', 0, NULL, NULL, NULL, 5),
	(259, 161, 'Suminės R- energijos rodmenų generavimas iš visų tarifų sumų', 0, NULL, NULL, NULL, 5),
	(260, 181, 'Periodinis automatinis visų apsikeitimo duomenimis operacijų įrašų trynimas', 1, 62, NULL, NULL, 5),
	(261, 161, 'Suminės R1 energijos rodmenų generavimas iš visų tarifų sumų', 0, NULL, NULL, NULL, 5),
	(262, 161, 'Suminės R2 energijos rodmenų generavimas iš visų tarifų sumų', 0, NULL, NULL, NULL, 5),
	(263, 161, 'Suminės R3 energijos rodmenų generavimas iš visų tarifų sumų', 0, NULL, NULL, NULL, 5),
	(264, 161, 'Suminės R4  energijos rodmenų generavimas iš visų tarifų sumų', 0, NULL, NULL, NULL, 5),
	(265, 96, 'Vidutinio šalto vandens tūrio debito per val. rodmenų generavimas iš tūrio kiekio, fiksuojamo kas valandą', 0, 62, NULL, NULL, 5),
	(266, 96, 'Vidutinio karšto vandens tūrio debito per val. rodmenų generavimas iš tūrio kiekio, fiksuojamo kas valandą', 0, 62, NULL, NULL, 5),
	(267, 182, 'Suminės A+ energijos rodmenų generavimas iš visų tarifų sumų, fiksuotų kas val.', 0, NULL, NULL, NULL, 5),
	(268, 21, 'A+ energijos pagal 1 tarifą per mėnesį rodmenų generavimas iš parų reikšmių', 0, NULL, NULL, NULL, 5),
	(269, 21, 'A+ energijos pagal 2 tarifą per mėnesį rodmenų generavimas iš parų reikšmių', 0, NULL, NULL, NULL, 5),
	(270, 21, 'A+ energijos pagal 3 tarifą per mėnesį rodmenų generavimas iš parų reikšmių', 0, NULL, NULL, NULL, 5),
	(271, 21, 'A+ energijos pagal 4 tarifą per mėnesį rodmenų generavimas iš parų reikšmių', 0, NULL, NULL, NULL, 5),
	(272, 183, 'A+ energijos pagal 1 tarifą per parą rodmenų generavimas iš fiksuotų kas valandą suminių reikšmių', 0, 62, NULL, NULL, 5),
	(273, 183, 'A+ energijos pagal 2 tarifą per parą rodmenų generavimas iš fiksuotų kas valandą suminių reikšmių', 0, 62, NULL, NULL, 5),
	(274, 183, 'A+ energijos pagal 3 tarifą per parą rodmenų generavimas iš fiksuotų kas valandą suminių reikšmių', 0, 62, NULL, NULL, 5),
	(275, 183, 'A+ energijos pagal 4 tarifą per parą rodmenų generavimas iš fiksuotų kas valandą suminių reikšmių', 0, 62, NULL, NULL, 5),
	(276, 186, 'Vidutinės P- galios per valandą rodmenų generavimas tiekimo taškams už 2 įvadų su transformatoriais', 0, NULL, NULL, NULL, 5),
	(277, 185, 'Vidutinės P- galios per valandą rodmenų generavimas tiekimo taškams įskaitant linijos nuostolius', 0, NULL, NULL, NULL, 5),
	(278, 189, 'Vidutinės P- galios per valandą rodmenų generavimas tiekimo taškams įskaitant transformatoriaus nuostolius', 0, NULL, NULL, NULL, 5),
	(279, 189, 'Vidutinės P- galios per 30 min. rodmenų generavimas tiekimo taškams įskaitant transformatoriaus nuostolius', 0, NULL, NULL, NULL, 5),
	(280, 184, 'Vidutinės P- galios per val. rodmenų generavimas tiekimo taškams už 2 įvadų su transformatoriais, 2 įvadas nutolęs', 0, NULL, NULL, NULL, 5),
	(281, 191, 'Vidutinės P- galios per 30 min. rodmenų generavimas tiekimo taškams įskaitant transformatoriaus ir linijos nuostolius', 0, NULL, NULL, NULL, 5),
	(282, 190, 'Vidutinės P+ galios per 30min. generavimas tiekimo taškams už 2 įvadų su transformatoriais, įskaitant linijos nuostolius', 0, NULL, NULL, NULL, 5),
	(283, 187, 'Vidutinės P+ galios per 30min. generavimas tiekimo taškams įskaitant linijos nuostolius bei P ir Q kvadratų sumą', 0, NULL, NULL, NULL, 5),
	(284, 189, 'Vidutinės P+ galios per 30 min. rodmenų generavimas tiekimo taškams įskaitant transformatoriaus nuostolius', 0, NULL, NULL, NULL, 5),
	(285, 188, 'Vidutinės P+ galios per 30min. generavimas tiekimo taškams už 2 įvadų ir transformatoriaus', 0, NULL, NULL, NULL, 5),
	(291, 194, 'Periodinis automatinis pasikartojančių apskaitos busenų duomenų įrašų trynimas', 1, 62, NULL, NULL, 5),
	(296, 101, 'Vidutinės Q+ galios per valandą rodmenų generavimas iš reikšmių pagal kvadrantus Q1 ir Q2', 0, 62, NULL, NULL, 5),
	(297, 101, 'Vidutinės Q- galios per valandą rodmenų generavimas iš reikšmių pagal kvadrantus Q3 ir Q4', 0, 62, NULL, NULL, 5),
	(298, 199, 'Vidutinio tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumo per 15 min. generavimas iš vidutinių reikšmių', 0, 62, NULL, NULL, 5),
	(299, 199, 'Vidutinio tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumo per valandą generavimas iš vidutinių reikšmių', 0, 62, NULL, NULL, 5),
	(301, 26, 'Šilumnešio masės kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių', 0, 238, NULL, NULL, 5),
	(302, 96, 'Vidutinio šilumnešio masės debito per val. rodmenų generavimas iš aug. reikšmių, užfiksuotų kas 15 minučių', 0, 238, NULL, NULL, 5),
	(303, 21, 'Šilumnešio masės kiekio per mėnesį rodmenų generavimas iš parų reikšmių', 0, 238, NULL, NULL, 5),
	(306, 204, 'Periodinis ryšio kanalų statistikos duomenų įrašų trynimas', 1, 62, NULL, NULL, 5),
	(311, 209, 'Periodinis automatinis visų šaltinių statistikos įrašų trynimas iki nurodytos datos', 1, 62, NULL, NULL, 5),
	(312, 211, 'Naujų grupių įtraukimas į grupę pagal šaltinių tipus (atsiradus naujiems šaltinio tipams)', 1, 62, NULL, NULL, 5),
	(316, 23, 'Vidutinės P- galios per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių', 0, 238, NULL, NULL, 5),
	(317, 23, 'Vidutinės Q+ galios per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių', 0, 238, NULL, NULL, 5),
	(318, 23, 'Vidutinės Q- galios per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių', 0, 238, NULL, NULL, 5),
	(319, 214, 'A+ energijos per parą rodmenų generavimas iš vidutinių reikšmių per 15 min.', 0, 238, NULL, NULL, 5),
	(320, 214, 'A- energijos per parą rodmenų generavimas iš vidutinių reikšmių per 15 min.', 0, 238, NULL, NULL, 5),
	(321, 214, 'R+ energijos per parą rodmenų generavimas iš vidutinių reikšmių per 15 min.', 0, 238, NULL, NULL, 5),
	(322, 214, 'R- energijos per parą rodmenų generavimas iš vidutinių reikšmių per 15 min.', 0, 238, NULL, NULL, 5),
	(323, 21, 'Šalčio energijos per mėnesį rodmenų generavimas iš parų reikšmių', 0, 238, NULL, NULL, 5),
	(324, 21, 'Šalčio tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių', 0, 238, NULL, NULL, 5),
	(325, 173, 'Šalčio energijos per parą rodmenų generavimas iš augančių reikšmių', 0, 238, NULL, NULL, 5),
	(326, 173, 'Šalčio tūrio kiekio per parą rodmenų generavimas iš augančių reikšmių', 0, 238, NULL, NULL, 5),
	(327, 30, 'Vidutinės šalčio galios per val. rodmenų generavimas iš augančių reikšmių', 0, 238, NULL, NULL, 5),
	(328, 30, 'Vidutinio šalčio tūrio debito per val. rodmenų generavimas iš augančių reikšmių', 0, 238, NULL, NULL, 5),
	(329, 215, 'Periodinis automatinis visų matavimo taškų matavimo linijų mėnesių duomenų įrašų trynimas', 0, 62, NULL, NULL, 5),
	(330, 216, 'Periodinis automatinis visų matavimo taškų matavimo linijų paros duomenų įrašų trynimas', 0, 62, NULL, NULL, 5),
	(331, 217, 'Periodinis automatinis visų matavimo taškų matavimo linijų paros profilio duomenų įrašų trynimas', 0, 62, NULL, NULL, 5),
	(332, 218, 'Periodinis automatinis visų matavimo taškų matavimo linijų suminių nefiksuotų duomenų įrašų trynimas', 0, 62, NULL, NULL, 5),
	(333, 219, 'Periodinis automatinis visų matavimo taškų matavimo linijų suminių fiksuotų iki mėn. duomenų įrašų trynimas', 0, 62, NULL, NULL, 5),
	(334, 220, 'Periodinis automatinis visų matavimo taškų matavimo linijų suminių fiksuotų iki paros duomenų įrašų trynimas', 0, 62, NULL, NULL, 5),
	(335, 221, 'Periodinis automatinis visų matavimo taškų matavimo linijų sekundinių duomenų įrašų trynimas', 0, 62, NULL, NULL, 5),
	(336, 223, 'Periodinis automatinis visų matavimo taškų vytelių duomenų įrašų trynimas', 0, 62, NULL, NULL, 5),
	(337, 224, 'Periodinis automatinis visų nuskaitymo taškų vytelių duomenų įrašų trynimas', 0, 62, NULL, NULL, 5),
	(338, 225, 'Periodinis automatinis negaliojančių matavimo taškų vytelių duomenų įrašų trynimas', 1, 62, NULL, NULL, 5),
	(339, 226, 'Periodinis automatinis negaliojančių nuskaitymo taškų vytelių duomenų įrašų trynimas', 1, 62, NULL, NULL, 5),
	(340, 227, 'Periodinis automatinis senų nevykdytų ryšio užduočių trynimas', 1, 62, NULL, NULL, 5),
	(341, 228, 'Pirminių suminių A+ energijos rodmenų generavimas iš pusvalandinių ir augančių rodmenų sumos, fiksuotų kas parą', 0, 238, NULL, NULL, 5),
	(342, 228, 'Pirminių suminių A- energijos rodmenų generavimas iš pusvalandinių ir augančių rodmenų sumos, fiksuotų kas parą', 0, 238, NULL, NULL, 5),
	(343, 228, 'Pirminių suminių R+ energijos rodmenų generavimas iš pusvalandinių ir augančių rodmenų sumos, fiksuotų kas parą', 0, 238, NULL, NULL, 5),
	(344, 228, 'Pirminių suminių R- energijos rodmenų generavimas iš pusvalandinių ir augančių rodmenų sumos, fiksuotų kas parą', 0, 238, NULL, NULL, 5),
	(345, 229, 'Parų rodmenų generavimas iš ankstesnių reikšmių', 0, 238, NULL, NULL, 5),
	(346, 230, 'Valandinių P+ duomenų generavimas išdalinant paros sumą pagal šabloną', 0, 238, NULL, NULL, 5),
	(347, 230, 'Valandinių P- duomenų generavimas išdalinant paros sumą pagal šabloną', 0, 238, NULL, NULL, 5),
	(351, 234, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(352, 234, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(353, 234, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(354, 234, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(355, 161, 'Suminės betarifinės A+ energijos duomenų generavimas iš tarifinių suminių matavimų, fiksuojamų kas parą', 0, NULL, NULL, NULL, 5),
	(356, 161, 'Suminės betarifinės A- energijos duomenų generavimas iš tarifinių suminių matavimų, fiksuojamų kas parą', 0, NULL, NULL, NULL, 5),
	(357, 161, 'Suminės betarifinės R+ energijos duomenų generavimas iš tarifinių suminių matavimų, fiksuojamų kas parą', 0, NULL, NULL, NULL, 5),
	(358, 161, 'Suminės betarifinės R- energijos duomenų generavimas iš tarifinių suminių matavimų, fiksuojamų kas parą', 0, NULL, NULL, NULL, 5),
	(361, 239, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų', 0, 238, NULL, NULL, 5),
	(362, 239, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų', 0, 238, NULL, NULL, 5),
	(363, 239, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų', 0, 238, NULL, NULL, 5),
	(364, 239, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų', 0, 238, NULL, NULL, 5),
	(365, 239, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 4 tarifą', 0, 238, NULL, NULL, 5),
	(366, 239, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 4 tarifą', 0, 238, NULL, NULL, 5),
	(367, 239, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 4 tarifą', 0, 238, NULL, NULL, 5),
	(368, 239, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 4 tarifą', 0, 238, NULL, NULL, 5),
	(369, 239, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 3 tarifą', 0, 238, NULL, NULL, 5),
	(370, 239, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 3 tarifą', 0, 238, NULL, NULL, 5),
	(371, 239, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 3 tarifą', 0, 238, NULL, NULL, 5),
	(372, 239, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 3 tarifą', 0, 238, NULL, NULL, 5),
	(373, 239, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 1 tarifą', 0, 238, NULL, NULL, 5),
	(374, 239, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 1 tarifą', 0, 238, NULL, NULL, 5),
	(375, 239, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 1 tarifą', 0, 238, NULL, NULL, 5),
	(376, 239, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 1 tarifą', 0, 238, NULL, NULL, 5),
	(377, 239, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 2 tarifą', 0, 238, NULL, NULL, 5),
	(378, 239, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 2 tarifą', 0, 238, NULL, NULL, 5),
	(379, 239, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 2 tarifą', 0, 238, NULL, NULL, 5),
	(380, 239, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 2 tarifą', 0, 238, NULL, NULL, 5),
	(381, 234, 'A+ energijos rodmenų per mėnesį pagal 1 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(382, 234, 'A- energijos rodmenų per mėnesį pagal 1 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(383, 234, 'R+ energijos rodmenų per mėnesį pagal 1 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(384, 234, 'R- energijos rodmenų per mėnesį pagal 1 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(385, 234, 'A+ energijos rodmenų per mėnesį pagal 2 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(386, 234, 'A- energijos rodmenų per mėnesį pagal 2 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(387, 234, 'R+ energijos rodmenų per mėnesį pagal 2 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(388, 234, 'R- energijos rodmenų per mėnesį pagal 2 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(389, 234, 'A+ energijos rodmenų per mėnesį pagal 3 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(390, 234, 'A- energijos rodmenų per mėnesį pagal 3 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(391, 234, 'R+ energijos rodmenų per mėnesį pagal 3 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(392, 234, 'R- energijos rodmenų per mėnesį pagal 3 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(393, 234, 'A+ energijos rodmenų per mėnesį pagal 4 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(394, 234, 'A- energijos rodmenų per mėnesį pagal 4 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(395, 234, 'R+ energijos rodmenų per mėnesį pagal 4 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(396, 234, 'R- energijos rodmenų per mėnesį pagal 4 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 0, 238, NULL, NULL, 5),
	(397, 244, 'Automatinis visų naikinančios grupės duomenų įrašų trynimas', 0, 42, NULL, NULL, 5),
	(398, 245, 'Pagal nuskaitymo tašką', 1, 43, NULL, NULL, 5),
	(401, 251, 'Šilumnešio koreguoto šilumos kiekio per parą generavimas iš valandinių reikšmių', 0, 62, NULL, NULL, 5),
	(402, 21, 'Šilumnešio koreguoto šilumos kiekio per mėnesį generavimas iš parų reikšmių', 0, 62, NULL, NULL, 5),
	(403, 254, 'Paros klaidos kodo rodmenų generavimas iš valandinių rodmenų', 0, 238, NULL, NULL, 5),
	(404, 255, 'Vidutinės įtampos per 30 minučių rodmenų generavimas iš momentinės įtampos', 0, 62, NULL, NULL, 5),
	(405, 255, 'Vidutinės įtampos 1 fazėje per 30 minučių rodmenų generavimas iš momentinės įtampos 1 fazėje', 0, 62, NULL, NULL, 5),
	(406, 255, 'Vidutinės įtampos 2 fazėje per 30 minučių rodmenų generavimas iš momentinės įtampos 2 fazėje', 0, 62, NULL, NULL, 5),
	(407, 255, 'Vidutinės įtampos 3 fazėje per 30 minučių rodmenų generavimas iš momentinės įtampos 3 fazėje', 0, 62, NULL, NULL, 5),
	(409, 183, 'A+ energijos per parą rodmenų generavimas iš suminės A+ energijos, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(410, 183, 'A+ energijos pagal 1 tarifą per parą rodmenų generavimas iš suminės A+ energijos pagal 1 tarifą, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(411, 183, 'A+ energijos pagal 2 tarifą per parą rodmenų generavimas iš suminės A+ energijos pagal 2 tarifą, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(412, 183, 'A+ energijos pagal 3 tarifą per parą rodmenų generavimas iš suminės A+ energijos pagal 3 tarifą, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(413, 183, 'A+ energijos pagal 4 tarifą per parą rodmenų generavimas iš suminės A+ energijos pagal 4 tarifą, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(414, 183, 'A- energijos per parą rodmenų generavimas iš suminės A- energijos, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(415, 183, 'A- energijos pagal 1 tarifą per parą rodmenų generavimas iš suminės A- energijos pagal 1 tarifą, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(416, 183, 'A- energijos pagal 2 tarifą per parą rodmenų generavimas iš suminės A- energijos pagal 2 tarifą, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(417, 183, 'A- energijos pagal 3 tarifą per parą rodmenų generavimas iš suminės A- energijos pagal 3 tarifą, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(418, 183, 'A- energijos pagal 4 tarifą per parą rodmenų generavimas iš suminės A- energijos pagal 4 tarifą, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(419, 183, 'R+ energijos per parą rodmenų generavimas iš suminės R+ energijos, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(420, 183, 'R+ energijos pagal 1 tarifą per parą rodmenų generavimas iš suminės R+ energijos pagal 1 tarifą, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(421, 183, 'R+ energijos pagal 2 tarifą per parą rodmenų generavimas iš suminės R+ energijos pagal 2 tarifą, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(422, 183, 'R+ energijos pagal 3 tarifą per parą rodmenų generavimas iš suminės R+ energijos pagal 3 tarifą, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(423, 183, 'R+ energijos pagal 4 tarifą per parą rodmenų generavimas iš suminės R+ energijos pagal 4 tarifą, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(424, 183, 'R- energijos per parą rodmenų generavimas iš suminės R- energijos, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(425, 183, 'R- energijos pagal 1 tarifą per parą rodmenų generavimas iš suminės R- energijos pagal 1 tarifą, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(426, 183, 'R- energijos pagal 2 tarifą per parą rodmenų generavimas iš suminės R- energijos pagal 2 tarifą, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(427, 183, 'R- energijos pagal 3 tarifą per parą rodmenų generavimas iš suminės R- energijos pagal 3 tarifą, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(428, 183, 'R- energijos pagal 4 tarifą per parą rodmenų generavimas iš suminės R- energijos pagal 4 tarifą, fiksuojamos kas parą', 0, 62, NULL, NULL, 5),
	(433, 263, 'Maksimalių momentinių srovės stiprumo rodmenų per valandą generavimas iš momentinių', 0, 62, NULL, NULL, 5),
	(434, 264, 'Minimalių momentinių srovės stiprumo rodmenų per valandą  generavimas iš momentinių', 0, 62, NULL, NULL, 5),
	(435, 261, 'Maksimalių momentinių srovės stiprumo rodmenų per parą generavimas iš maksimalių rodmenų per valandą', 0, 62, NULL, NULL, 5),
	(436, 262, 'Minimalių momentinių srovės stiprumo rodmenų per parą generavimas iš minimalių rodmenų per valandą', 0, 62, NULL, NULL, 5),
	(437, 263, 'Maksimalių momentinių įtampos rodmenų per valandą generavimas iš momentinių', 0, 62, NULL, NULL, 5),
	(438, 264, 'Minimalių momentinių įtampos rodmenų per valandą generavimas iš momentinių', 0, 62, NULL, NULL, 5),
	(439, 261, 'Maksimalių momentinių įtampos rodmenų per parą generavimas iš maksimalių rodmenų per valandą', 0, 62, NULL, NULL, 5),
	(440, 262, 'Minimalių momentinių įtampos rodmenų per parą rodmenų generavimas iš minimalių rodmenų per valandą', 0, 62, NULL, NULL, 5),
	(441, 263, 'Maksimalių momentinių aktyvinė galia per valandą generavimas iš momentinių', 0, 62, NULL, NULL, 5),
	(442, 264, 'Minimalių momentinių aktyvinė galia per valandą generavimas iš momentinių', 0, 62, NULL, NULL, 5),
	(443, 261, 'Maksimalių momentinių aktyvinės galios rodmenų per parą generavimas iš maksimalių rodmenų per valandą', 0, 62, NULL, NULL, 5),
	(444, 262, 'Minimalių momentinių aktyvinė galios rodmenų per parą generavimas iš minimalių rodmenų per valandą', 0, 62, NULL, NULL, 5),
	(445, 263, 'Maksimalių momentinių reaktyvinės galios per valandą rodmenų generavimas iš momentinių', 0, 62, NULL, NULL, 5),
	(446, 264, 'Minimalių momentinių reaktyvinės galios per valandą rodmenų generavimas iš momentinių', 0, 62, NULL, NULL, 5),
	(447, 261, 'Maksimalių momentinių reaktyvinės galios rodmenų per parą generavimas iš maksimalių rodmenų per valandą', 0, 62, NULL, NULL, 5),
	(448, 262, 'Minimalių momentinių reaktyvinės galios rodmenų per parą generavimas iš minimalių rodmenų per valandą', 0, 62, NULL, NULL, 5),
	(449, 263, 'Maksimalių momentinių cos(fi) reikšmių per valandą rodmenų generavimas iš momentinių', 0, 62, NULL, NULL, 5),
	(450, 264, 'Minimalių momentinių cos(fi) reikšmių per valandą rodmenų generavimas iš momentinių', 0, 62, NULL, NULL, 5),
	(451, 261, 'Maksimalių momentinių cos(fi) reikšmių per parą generavimas iš maksimalių reikšmių per valandą', 0, 62, NULL, NULL, 5),
	(452, 262, 'Minimalių momentinių cos(fi) reikšmių per parą generavimas iš minimalių reikšmių per valandą', 0, 62, NULL, NULL, 5),
	(453, 263, 'Maksimalių momentinių dažnis rodmenų per valandą generavimas iš momentinių', 0, 62, NULL, NULL, 5),
	(454, 264, 'Minimalių momentinių dažnis rodmenų per valandą generavimas iš momentinių', 0, 62, NULL, NULL, 5),
	(455, 261, 'Maksimalių momentinių dažnio rodmenų per parą generavimas iš maksimalių rodmenų per valandą', 0, 62, NULL, NULL, 5),
	(456, 262, 'Minimalių momentinių dažnio rodmenų per parą generavimas iš minimalių rodmenų per valandą', 0, 62, NULL, NULL, 5),
	(457, 267, 'Beviltiškos skylės', 1, 310, 860, NULL, 5),
	(458, 136, 'Vidutinės P galios per val. rodmenų generavimas iš vidutinės P galios per 5 min.', 0, 62, NULL, NULL, 5),
	(459, 252, 'A energijos per 5 min. rodmenų generavimas iš suminės A energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(460, 252, 'Vidutinės P galios per 5 min. rodmenų generavimas iš suminės A energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(461, 251, 'A energijos per val. rodmenų generavimas iš A energijos per 5 min.', 0, 62, NULL, NULL, 5),
	(462, 136, 'Vidutinės P+ galios per val. rodmenų generavimas iš vidutinės P+ galios per 5 min.', 0, 62, NULL, NULL, 5),
	(463, 252, 'A+ energijos per 5 min. rodmenų generavimas iš suminės A+ energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(464, 252, 'Vidutinės P+ galios per 5 min. rodmenų generavimas iš suminės A+ energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(465, 251, 'A+ energijos per val. rodmenų generavimas iš A+ energijos per 5 min.', 0, 62, NULL, NULL, 5),
	(466, 136, 'Vidutinės P- galios per val. rodmenų generavimas iš vidutinės P- galios per 5 min.', 0, 62, NULL, NULL, 5),
	(467, 252, 'A- energijos per 5 min. rodmenų generavimas iš suminės A- energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(468, 252, 'Vidutinės P- galios per 5 min. rodmenų generavimas iš suminės A- energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(469, 251, 'A- energijos per val. rodmenų generavimas iš A- energijos per 5 min.', 0, 62, NULL, NULL, 5),
	(470, 136, 'Vidutinės talpuminės galios per val. rodmenų generavimas iš vidutinės talpuminės galios per 5 min.', 0, 62, NULL, NULL, 5),
	(471, 252, 'Vidutinės talpuminės galios per 5 min. rodmenų generavimas iš suminės talpuminės R energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(472, 252, 'Talpuminės energijos per 5 min. rodmenų generavimas iš suminės talpuminės R energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(473, 251, 'Talpuminės energijos per val. rodmenų generavimas iš talpuminės energijos per 5 min.', 0, 62, NULL, NULL, 5),
	(474, 136, 'Vidutinės Q+ galios per val. rodmenų generavimas iš vidutinės Q+ galios per 5 min.', 0, 62, NULL, NULL, 5),
	(475, 252, 'Vidutinės Q+ galios per 5 min. rodmenų generavimas iš suminės R+ energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(476, 252, 'R+ energijos per 5 min. rodmenų generavimas iš suminės R+ energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(477, 251, 'R+ energijos per val. rodmenų generavimas iš R+ energijos per 5 min.', 0, 62, NULL, NULL, 5),
	(478, 136, 'Vidutinės Q- galios per val. rodmenų generavimas iš vidutinės Q- galios per 5 min.', 0, 62, NULL, NULL, 5),
	(479, 252, 'R- energijos per 5 min. rodmenų generavimas iš suminės R- energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(480, 252, 'Vidutinės Q- galios per 5 min. rodmenų generavimas iš suminės R- energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(481, 251, 'R- energijos per val. rodmenų generavimas iš R- energijos per 5 min.', 0, 62, NULL, NULL, 5),
	(482, 136, 'Vidutinės Q1 galios per val. rodmenų generavimas iš vidutinės Q1 galios per 5 min.', 0, 62, NULL, NULL, 5),
	(483, 252, 'R1 energijos per 5 min. rodmenų generavimas iš suminės R1 energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(484, 252, 'Vidutinės Q1 galios per 5 min. rodmenų generavimas iš suminės R1 energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(485, 251, 'R1 energijos per val. rodmenų generavimas iš R1 energijos per 5 min.', 0, 62, NULL, NULL, 5),
	(486, 136, 'Vidutinės Q2 galios per val. rodmenų generavimas iš vidutinės Q2 galios per 5 min.', 0, 62, NULL, NULL, 5),
	(487, 252, 'R2 energijos per 5 min. rodmenų generavimas iš suminės R2 energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(488, 252, 'Vidutinės Q2 galios per 5 min. rodmenų generavimas iš suminės R2 energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(489, 251, 'R2 energijos per val. rodmenų generavimas iš R2 energijos per 5 min.', 0, 62, NULL, NULL, 5),
	(490, 136, 'Vidutinės Q3 galios per val. rodmenų generavimas iš vidutinės Q3 galios per 5 min.', 0, 62, NULL, NULL, 5),
	(491, 252, 'R3 energijos per 5 min. rodmenų generavimas iš suminės R3 energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(492, 252, 'Vidutinės Q3 galios per 5 min. rodmenų generavimas iš suminės R3 energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(493, 251, 'R3 energijos per val. rodmenų generavimas iš R3 energijos per 5 min.', 0, 62, NULL, NULL, 5),
	(494, 136, 'Vidutinės Q4 galios per val. rodmenų generavimas iš vidutinės Q4 galios per 5 min.', 0, 62, NULL, NULL, 5),
	(495, 252, 'Vidutinės Q4 galios per 5 min. rodmenų generavimas iš suminės R4 energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(496, 252, 'R4 energijos per 5 min. rodmenų generavimas iš suminės R4 energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(497, 251, 'R4 energijos per val. rodmenų generavimas iš R4 energijos per 5 min.', 0, 62, NULL, NULL, 5),
	(498, 136, 'Vidutinės indukcinė galios per val. rodmenų generavimas iš vidutinės indukcinė galios per 5 min.', 0, 62, NULL, NULL, 5),
	(499, 252, 'Indukcinė energijos per 5 min. rodmenų generavimas iš suminės indukcinė R energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(500, 252, 'Vidutinės indukcinė galios per 5 min. rodmenų generavimas iš suminės indukcinė R energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(501, 251, 'Indukcinė energijos per val. rodmenų generavimas iš Indukcinė energijos per 5 min.', 0, 62, NULL, NULL, 5),
	(502, 136, 'Vidutinės S+ galios per val. rodmenų generavimas iš vidutinės S+ galios per 5 min.', 0, 62, NULL, NULL, 5),
	(503, 252, 'Vidutinės S+ galios per 5 min. rodmenų generavimas iš suminės W+ energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(504, 252, 'W+ energijos per 5 min. rodmenų generavimas iš suminės W+ energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(505, 251, 'W+ energijos per val. rodmenų generavimas iš W+ energijos per 5 min.', 0, 62, NULL, NULL, 5),
	(506, 136, 'Vidutinės S- galios per val. rodmenų generavimas iš vidutinės S- galios per 5 min.', 0, 62, NULL, NULL, 5),
	(507, 252, 'Vidutinės S- galios per 5 min. rodmenų generavimas iš suminės W- energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(508, 252, 'W- energijos per 5 min. rodmenų generavimas iš suminės W- energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(509, 251, 'W- energijos per val. rodmenų generavimas iš W- energijos per 5 min.', 0, 62, NULL, NULL, 5),
	(510, 136, 'Vidutinio dujų koreguotos masės debito per val. rodmenų generavimas iš vidutinio dujų koreguotos masės debito per 5 min.', 0, 62, NULL, NULL, 5),
	(511, 252, 'Dujų koreguotos masės kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(512, 252, 'Vidutinio dujų koreguotos masės debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(513, 251, 'Dujų koreguotos masės kiekio per val. rodmenų generavimas iš dujų koreguotos masės kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(514, 136, 'Vidutinio dujų koreguoto tūrio debito per val. rodmenų generavimas iš vidutinio dujų koreguoto tūrio debito per 5 min.', 0, 62, NULL, NULL, 5),
	(515, 252, 'Dujų koreguoto tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(516, 252, 'Vidutinio dujų koreguoto tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(517, 251, 'Dujų koreguoto tūrio kiekio per val. rodmenų generavimas iš dujų koreguoto tūrio kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(518, 136, 'Vidutinio dujų masės debito per val. rodmenų generavimas iš vidutinio dujų masės debito per 5 min.', 0, 62, NULL, NULL, 5),
	(519, 252, 'Dujų masės kiekio per 5 min. rodmenų generavimas iš suminio dujų masės kiekio, fiksuojamo kas 5 min.', 0, 62, NULL, NULL, 5),
	(520, 252, 'Vidutinio dujų masės debito per 5 min. rodmenų generavimas iš suminio dujų masės kiekio, fiksuojamo kas 5 min.', 0, 62, NULL, NULL, 5),
	(521, 251, 'Dujų masės kiekio per val. rodmenų generavimas iš dujų masės kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(522, 136, 'Vidutinės dujų šilumos galios per val. rodmenų generavimas iš vidutinės dujų šilumos galios per 5 min.', 0, 62, NULL, NULL, 5),
	(523, 252, 'Dujų šilumos kiekio per 5 min. rodmenų generavimas iš suminio dujų šilumos kiekio, fiksuojamo kas 5 min.', 0, 62, NULL, NULL, 5),
	(524, 252, 'Vidutinės dujų šilumos galios per 5 min. rodmenų generavimas iš suminio dujų šilumos kiekio, fiksuojamo kas 5 min.', 0, 62, NULL, NULL, 5),
	(525, 251, 'Dujų šilumos kiekio per val. rodmenų generavimas iš dujų šilumos kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(526, 136, 'Vidutinio dujų tūrio debito per val. rodmenų generavimas iš vidutinio dujų tūrio debito per 5 min.', 0, 62, NULL, NULL, 5),
	(527, 252, 'Vidutinio dujų tūrio debito per 5 min. rodmenų generavimas iš suminio dujų tūrio kiekio, fiksuojamo kas 5 min.', 0, 62, NULL, NULL, 5),
	(528, 252, 'Dujų tūrio kiekio per 5 min. rodmenų generavimas iš suminio dujų tūrio kiekio, fiksuojamo kas 5 min.', 0, 62, NULL, NULL, 5),
	(529, 251, 'Dujų tūrio kiekio per val. rodmenų generavimas iš dujų tūrio kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(530, 136, 'Vidutinės šalčio galios per val. rodmenų generavimas iš vidutinės šalčio galios per 5 min.', 0, 62, NULL, NULL, 5),
	(531, 252, 'Šalčio energijos per 5 min. rodmenų generavimas iš suminės šalčio energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(532, 252, 'Vidutinės šalčio galios per 5 min. rodmenų generavimas iš suminės šalčio energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(533, 251, 'Šalčio energijos per val. rodmenų generavimas iš šalčio energijos per 5 min.', 0, 62, NULL, NULL, 5),
	(534, 136, 'Vidutinės tiekiamo šalčio galios per val. rodmenų generavimas iš vidutinės tiekiamo šalčio galios per 5 min.', 0, 62, NULL, NULL, 5),
	(535, 252, 'Tiekiamo šalčio energijos per 5 min. rodmenų generavimas iš suminės tiekiamo šalčio energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(536, 252, 'Vidutinės tiekiamo šalčio galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(537, 251, 'Tiekiamo šalčio energijos per val. rodmenų generavimas iš tiekiamo šalčio energijos per 5 min.', 0, 62, NULL, NULL, 5),
	(538, 136, 'Vidutinės grįžtamo šalčio galios per val. rodmenų generavimas iš vidutinės grįžtamo šalčio galios per 5 min.', 0, 62, NULL, NULL, 5),
	(539, 252, 'Vidutinės grįžtamo šalčio galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(540, 252, 'Grįžtamo šalčio energijos per 5 min. rodmenų generavimas iš suminės grįžtamo šalčio energijos, fiksuojamos kas 5 min.', 0, 62, NULL, NULL, 5),
	(541, 251, 'Grįžtamo šalčio energijos per val. rodmenų generavimas iš grįžtamo šalčio energijos per 5 min.', 0, 62, NULL, NULL, 5),
	(542, 136, 'Vidutinio šalčio tūrio debito per val. rodmenų generavimas iš vidutinio šalčio tūrio debito per 5 min.', 0, 62, NULL, NULL, 5),
	(543, 252, 'Vidutinio šalčio tūrio debito per 5 min. rodmenų generavimas iš suminio šalčio tūrio kiekio, fiksuojamo kas 5 min.', 0, 62, NULL, NULL, 5),
	(544, 252, 'Šalčio tūrio kiekio per 5 min. rodmenų generavimas iš suminio šalčio tūrio kiekio, fiksuojamo kas 5 min.', 0, 62, NULL, NULL, 5),
	(545, 251, 'Šalčio tūrio kiekio per val. rodmenų generavimas iš šalčio tūrio kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(546, 136, 'Vidutinio tiekiamo šalčio tūrio debito per val. rodmenų generavimas iš vidutinio tiekiamo šalčio tūrio debito per 5 min.', 0, 62, NULL, NULL, 5),
	(547, 252, 'Tiekiamo šalčio tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(548, 252, 'Vidutinio tiekiamo šalčio tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(549, 251, 'Tiekiamo šalčio tūrio kiekio per val. rodmenų generavimas iš tiekiamo šalčio tūrio kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(550, 136, 'Vidutinio grįžtamo šalčio tūrio debito per val. rodmenų generavimas iš vidutinio grįžtamo šalčio tūrio debito per 5 min.', 0, 62, NULL, NULL, 5),
	(551, 252, 'Vidutinio grįžtamo šalčio tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(552, 252, 'Grįžtamo šalčio tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(553, 251, 'Grįžtamo šalčio tūrio kiekio per val. rodmenų generavimas iš grįžtamo šalčio tūrio kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(554, 136, 'Vidutinio šilumnešio masės debito per val. rodmenų generavimas iš vidutinio šilumnešio masės debito per 5 min.', 0, 62, NULL, NULL, 5),
	(555, 252, 'Šilumnešio masės kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(556, 252, 'Vidutinio šilumnešio masės debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(557, 251, 'Šilumnešio masės kiekio per val. rodmenų generavimas iš šilumnešio masės kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(558, 136, 'Vidutinio tiekiamo šilumnešio masės debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 0, 62, NULL, NULL, 5),
	(559, 252, 'Vidutinio tiekiamo šilumnešio masės debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(560, 252, 'Tiekiamo šilumnešio masės kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(561, 251, 'Tiekiamo šilumnešio masės kiekio per val. rodmenų generavimas iš tiekiamo šilumnešio masės kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(562, 136, 'Vidutinio grįžtamo šilumnešio masės debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 0, 62, NULL, NULL, 5),
	(563, 252, 'Grįžtamo šilumnešio masės kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(564, 252, 'Vidutinio grįžtamo šilumnešio masės debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(565, 251, 'Grįžtamo šilumnešio masės kiekio per val. rodmenų generavimas iš grįžtamo šilumnešio masės kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(566, 136, 'Vidutinės šilumnešio šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 0, 62, NULL, NULL, 5),
	(567, 252, 'Šilumnešio šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(568, 252, 'Vidutinės šilumnešio šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(569, 251, 'Šilumnešio šilumos kiekio per val. rodmenų generavimas iš šilumnešio šilumos kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(570, 136, 'Vidutinės tiekiamo šilumnešio šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 0, 62, NULL, NULL, 5),
	(571, 252, 'Tiekiamo šilumnešio šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(572, 252, 'Vidutinės tiekiamo šilumnešio šil. galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(573, 251, 'Tiekiamo šilumnešio šilumos kiekio per val. rodmenų generavimas iš tiekiamo šilumnešio šil. kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(574, 136, 'Vidutinės grįžtamo šilumnešio šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 0, 62, NULL, NULL, 5),
	(575, 252, 'Grįžtamo šilumnešio šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(576, 252, 'Vidutinės grįžtamo šilumnešio šil. galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(577, 251, 'Grįžtamo šilumnešio šilumos kiekio per val. rodmenų generavimas iš grįžtamo šilumnešio šil. kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(578, 136, 'Vidutinio šilumnešio tūrio debito per val. rodmenų generavimas iš vidutinio šilumnešio tūrio debito per 5 min.', 0, 62, NULL, NULL, 5),
	(579, 252, 'Šilumnešio tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(580, 252, 'Vidutinio šilumnešio tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(581, 251, 'Šilumnešio tūrio kiekio per val. rodmenų generavimas iš šilumnešio tūrio kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(582, 136, 'Vidutinio tiekiamo šilumnešio tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 0, 62, NULL, NULL, 5),
	(583, 252, 'Vidutinio tiekiamo šilumnešio tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(584, 252, 'Tiekiamo šilumnešio tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(585, 251, 'Tiekiamo šilumnešio tūrio kiekio per val. rodmenų generavimas iš tiekiamo šilumnešio tūrio kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(586, 136, 'Vidutinio grįžtamo šilumnešio tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 0, 62, NULL, NULL, 5),
	(587, 252, 'Grįžtamo šilumnešio tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(588, 252, 'Vidutinio grįžtamo šilumnešio tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(589, 251, 'Grįžtamo šilumnešio tūrio kiekio per val. rodmenų generavimas iš grįžtamo šilumnešio tūrio kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(590, 136, 'Vidutinės šalto vandens šilumos galios per val. rodmenų generavimas iš vidutinės šalto vandens šilumos galios per 5 min.', 0, 62, NULL, NULL, 5),
	(591, 252, 'Vidutinės šalto vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(592, 252, 'Šalto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(593, 251, 'Šalto vandens šilumos kiekio per val. rodmenų generavimas iš šalto vandens šilumos kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(594, 136, 'Vidutinės tiekiamo šalto vandens šil. galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 0, 62, NULL, NULL, 5),
	(595, 252, 'Tiekiamo šalto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(596, 252, 'Vidutinės tiekiamo šalto vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(597, 251, 'Tiekiamo šalto vandens šilumos kiekio per val. rodmenų generavimas iš tiekiamo šalto vandens šilumos kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(598, 136, 'Vidutinės grįžtamo šalto vandens šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 0, 62, NULL, NULL, 5),
	(599, 252, 'Grįžtamo šalto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(600, 252, 'Vidutinės grįžtamo šalto vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(601, 251, 'Grįžtamo šalto vandens šilumos kiekio per val. rodmenų generavimas iš grįžtamo šalto vandens šilumos kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(602, 136, 'Vidutinio šalto vandens tūrio debito per val. rodmenų generavimas iš vidutinio šalto vandens tūrio debito per 5 min.', 0, 62, NULL, NULL, 5),
	(603, 252, 'Vidutinio šalto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamųkas 5 min.', 0, 62, NULL, NULL, 5),
	(604, 252, 'Šalto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(605, 251, 'Šalto vandens tūrio kiekio per val. rodmenų generavimas iš Šalto vandens tūrio kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(606, 136, 'Vidutinio tiekiamo šalto vandens tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 0, 62, NULL, NULL, 5),
	(607, 252, 'Tiekiamo šalto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamųkas 5 min.', 0, 62, NULL, NULL, 5),
	(608, 252, 'Vidutinio tiekiamo šalto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(609, 251, 'Tiekiamo šalto vandens tūrio kiekio per val. rodmenų generavimas iš tiekiamo šalto vandens tūrio kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(610, 136, 'Vidutinio grįžtamo šalto vandens tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 0, 62, NULL, NULL, 5),
	(611, 252, 'Vidutinio grįžtamo šalto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(612, 252, 'Grįžtamo šalto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(613, 251, 'Grįžtamo šalto vandens tūrio kiekio per val. rodmenų generavimas iš grįžtamo šalto vandens tūrio kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(614, 136, 'Vidutinės karšto vandens šilumos galios per val. rodmenų generavimas iš vidutinės karšto vandens šil. galios per 5 min.', 0, 62, NULL, NULL, 5),
	(615, 252, 'Karšto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(616, 252, 'Vidutinės karšto vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(617, 251, 'Karšto vandens šilumos kiekio per val. rodmenų generavimas iš karšto vandens šilumos kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(618, 136, 'Vidutinės tiekiamo karšto vandens šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 0, 62, NULL, NULL, 5),
	(619, 252, 'Vidutinės tiekiamo karš. vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(620, 252, 'Tiekiamo karšto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(621, 251, 'Tiekiamo karšto vandens šilumos kiekio per val. rodmenų generavimas iš tiekiamo karšto vandens šilumos kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(622, 136, 'Vidutinės grįžtamo karšto vandens šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 0, 62, NULL, NULL, 5),
	(623, 252, 'Vidutinės grįžtamo karš. vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(624, 252, 'Grįžtamo karšto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(625, 251, 'Grįžtamo karšto vandens šilumos kiekio per val. rodmenų generavimas iš grįžtamo karšto vandens šilumos kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(626, 136, 'Vidutinio karšto vandens tūrio debito per val. rodmenų generavimas iš vidutinio karšto vandens tūrio debito per 5 min.', 0, 62, NULL, NULL, 5),
	(627, 252, 'Karšto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminio karšto vandens tūrio kiekio, fiksuojamo kas 5 min.', 0, 62, NULL, NULL, 5),
	(628, 252, 'Vidutinio karšto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(629, 251, 'Karšto vandens tūrio kiekio per val. rodmenų generavimas iš Karšto vandens tūrio kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(630, 136, 'Vidutinio tiekiamo karšto vandens tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 0, 62, NULL, NULL, 5),
	(631, 252, 'Vidutinio tiekiamo karšto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(632, 252, 'Tiekiamo karšto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(633, 251, 'Tiekiamo karšto vandens tūrio kiekio per val. rodmenų generavimas iš tiekiamo karšto vandens tūrio kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(634, 136, 'Vidutinio grįžtamo karšto vandens tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 0, 62, NULL, NULL, 5),
	(635, 252, 'Grįžtamo karšto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(636, 252, 'Vidutinio grįžtamo karšto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(637, 251, 'Grįžtamo karšto vandens tūrio kiekio per val. rodmenų generavimas iš grįžtamo karšto vandens tūrio kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(638, 136, 'Vidutinės šilumnešio koreguota šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 0, 62, NULL, NULL, 5),
	(639, 252, 'Šilumnešio koreguoto šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(640, 252, 'Vidutinės šilumnešio koreguota šil. galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 0, 62, NULL, NULL, 5),
	(641, 251, 'Šilumnešio koreguoto šil. kiekio per val. rodmenų generavimas iš šilumnešio koreguoto šil. kiekio per 5 min.', 0, 62, NULL, NULL, 5),
	(643, 276, 'Momentinio rodiklio generavimas iš suminio dujų koreguoto tūrio kiekio, fiksuojamo kas minutę', 0, 238, NULL, NULL, 5),
	(644, 277, 'Periodinis automatinis taškų monitoringo šablonų taikymas', 0, 238, NULL, NULL, 5),
	(645, 278, 'Periodinis automatinis grupių monitoringo šablonų taikymas', 0, 238, NULL, NULL, 5),
	(648, 281, 'Periodinis automatinis senų nevykdytų skubių ryšio užduočių trynimas', 1, 44, NULL, NULL, 5),
	(649, 21, 'Sunaudotos šilumnešio šilumos kiekio per mėnesį generavimas iš parų reikšmių', 0, 62, NULL, NULL, 5),
	(650, 251, 'Sunaudotos šilumnešio šilumos kiekio per parą generavimas iš valandinių reikšmių', 0, 62, NULL, NULL, 5),
	(651, 21, 'Tiekiamo šilumnešio šilumos kiekio per mėnesį generavimas iš parų reikšmių', 0, 62, NULL, NULL, 5),
	(652, 251, 'Tiekiamo šilumnešio šilumos kiekio per parą generavimas iš valandinių reikšmių', 0, 62, NULL, NULL, 5),
	(653, 251, 'Šilumnešio šilumos kiekio per parą generavimas iš valandinių reikšmių', 0, 62, NULL, NULL, 5),
	(654, 251, 'Karšto vandens šilumos kiekio per parą generavimas iš valandinių reikšmių', 0, 62, NULL, NULL, 5),
	(655, 21, 'Karšto vandens šilumos kiekio per mėnesį generavimas iš parų reikšmių', 0, 62, NULL, NULL, 5),
	(656, 21, 'Tiekiamo karšto vandens šilumos kiekio per mėnesį generavimas iš parų reikšmių', 0, 62, NULL, NULL, 5),
	(657, 251, 'Tiekiamo karšto vandens šilumos kiekio per parą generavimas iš valandinių reikšmių', 0, 62, NULL, NULL, 5),
	(658, 21, 'Sunaudotos karšto vandens šilumos kiekio per mėnesį generavimas iš parų reikšmių', 0, 62, NULL, NULL, 5),
	(659, 251, 'Sunaudotos karšto vandens šilumos kiekio per parą generavimas iš valandinių reikšmių', 0, 62, NULL, NULL, 5),
	(660, 282, 'Periodinis automatinis išsiųstų SMS pranešimų žurnalo įrašų trynimas', 1, 62, NULL, NULL, 5),
	(661, 283, 'Fiksuotų kas parą suminių duomenų generavimas iš fiksuotų kas mėnesį ir parų energijos duomenų', 0, 62, NULL, NULL, 5),
	(663, 286, 'Periodinis automatinis visų tarpinių eksporto formų duomenų įrašų trynimas', 1, 62, NULL, NULL, 5),
	(664, 287, 'Sistemos monitoringo duomenų, fiksuojamų kas parą generavimas', 1, 43, NULL, NULL, 5),
	(665, 287, 'Sistemos monitoringo duomenų, fiksuojamų kas valandą generavimas', 1, 62, NULL, NULL, 5),
	(666, 291, 'Periodinis automatinis nuskaitymo konfigūracijos tikrinimas', 1, NULL, NULL, NULL, 5),
	(667, 210, 'Generated_by_SQL_Server', 1, 62, 865, NULL, 5),
	(668, 296, 'Atlikti ankščiau paruoštas eilės užduotis', 1, NULL, NULL, NULL, 5),
	(669, 297, 'Tolesnis nuskaitytų skaitiklio parametrų apdorojimas', 1, NULL, NULL, NULL, 5),
	(670, 298, 'Taško matavimo linijų pildymas pagal skaitiklio parametrus', 1, NULL, NULL, NULL, 5),
	(671, 299, 'Nuskaitymo konfigūracijos sukūrimas neužregistruotiems skaitikliams', 1, NULL, NULL, NULL, 5),
	(673, 301, 'Vidutinio šalto vandens debito per 2 min. generavimas iš augančių reikšmių', 0, 62, NULL, NULL, 5),
	(674, 302, 'Blogiausi šaltiniai pagal klaidų kiekį', 1, 43, 870, NULL, 5),
	(675, 303, 'Blogiausi šaltiniai pagal negaliojančių nuskaitymų kiekį', 1, 43, 871, NULL, 5),
	(676, 304, 'Suminės A+ energijos proporcingas generavimas iš gretimų reikšmių, fiksuotų kas valandą ', 0, 62, NULL, NULL, 5),
	(677, 305, 'Periodinis automatinis daugiažingsnių užduočių istorinės informacijos trynimas', 1, 62, NULL, NULL, 5),
	(678, 306, 'Automatinis TestMode išjungimas', 0, 43, NULL, NULL, 5),
	(679, 307, 'Stambesnių intervalų (iki paros) sumos rodmenų generavimas iš smulkesnių intervalų pagal priskirtą tarifą', 0, 62, NULL, NULL, 5),
	(680, 308, 'Labiausiai užimtų ryšių kanalų nuskaitymo taškai', 1, 43, 872, NULL, 5),
	(681, 309, 'Nesinchronizuoti', 1, 43, 873, NULL, 5),
	(682, 267, 'Nėra duomenų už paskutines paras', 1, 310, 874, NULL, 5),
	(683, 311, 'Naujų grupių įtraukimas į grupę pagal šaltinių šablonus (atsiradus naujiems šaltinių šablonams)', 1, 62, NULL, NULL, 5),
	(684, 312, 'Suminės A+ energijos pagal 1 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 0, 62, NULL, NULL, 5),
	(685, 312, 'Suminės A+ energijos pagal 2 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 0, 62, NULL, NULL, 5),
	(686, 312, 'Suminės A+ energijos pagal 3 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 0, 62, NULL, NULL, 5),
	(687, 312, 'Suminės A+ energijos pagal 4 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 0, 62, NULL, NULL, 5),
	(688, 312, 'Suminės A- energijos pagal 1 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 0, 62, NULL, NULL, 5),
	(689, 312, 'Suminės A- energijos pagal 2 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 0, 62, NULL, NULL, 5),
	(690, 312, 'Suminės A- energijos pagal 3 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 0, 62, NULL, NULL, 5),
	(691, 312, 'Suminės A- energijos pagal 4 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 0, 62, NULL, NULL, 5),
	(692, 312, 'Suminės R+ energijos pagal 1 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 0, 62, NULL, NULL, 5),
	(693, 312, 'Suminės R+ energijos pagal 2 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 0, 62, NULL, NULL, 5),
	(694, 312, 'Suminės R+ energijos pagal 3 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 0, 62, NULL, NULL, 5),
	(695, 312, 'Suminės R+ energijos pagal 4 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 0, 62, NULL, NULL, 5),
	(696, 312, 'Suminės R- energijos pagal 1 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 0, 62, NULL, NULL, 5),
	(697, 312, 'Suminės R- energijos pagal 2 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 0, 62, NULL, NULL, 5),
	(698, 312, 'Suminės R- energijos pagal 3 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 0, 62, NULL, NULL, 5),
	(699, 312, 'Suminės R- energijos pagal 4 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 0, 62, NULL, NULL, 5),
	(700, 313, 'Nėra nuskaitymo rezultatų', 1, 310, 875, NULL, 5),
	(701, 314, 'Nėra jokių nuskaitymo duomenų', 1, 310, 876, NULL, 5),
	(702, 318, 'Atomų išdalinimas duomenų surinkimo serveriams', 1, 310, NULL, NULL, 5),
	(703, 319, 'Niekada nebuvo matavimų duomenų', 1, 310, 877, NULL, 5),
	(704, 320, 'Nepildoma dalis galiojančių matavimų', 1, 310, 878, NULL, 5),
	(705, 321, 'Senų signalų apie su šaltiniais susijusios aktualios surinkimui konfigūracijos pasikeitimus įrašų trynimas', 1, 62, NULL, NULL, 5),
	(706, 322, 'Senos automatinio atomų priskyrimo duomenų surinkimo serveriams istorijos trynimas', 1, 62, NULL, NULL, 5),
	(707, 323, 'Neatsakantys nuskaitymo taškai', 1, 238, 879, NULL, 5),
	(708, 324, 'Atsakantys nuskaitymo taškai, kuriems buvo ryšio būklės pasikeitimų', 1, 238, 880, NULL, 5),
	(709, 325, 'Atsakantys nuskaitymo taškai, kuriems buvo ryšio klaidų', 1, 238, 881, NULL, 5),
	(710, 326, 'Taškai, kurių archyvą turintiems skaitiklių šaltiniams nenustatytas atstatymo gylis', 1, 310, 882, NULL, 5),
	(711, 327, 'Nuskaitymo taškai, kuriems nėra duomenų už paskutines paras', 1, 238, 883, NULL, 5),
	(712, 328, 'Taškai, kuriems nėra duomenų už paskutines paras, nors nuskaitymo taškams yra', 1, 238, 884, NULL, 5),
	(713, 329, 'Neužpildytos būtinos ryšio savybės', 1, 238, 885, NULL, 5),
	(714, 329, 'Neužpildytos rekomenduojamos ryšio savybės', 1, 238, 886, NULL, 5),
	(715, 330, 'Sumontuoto taške skaitiklio numerio įrašymas į Saiman-1000 tipo šaltinių elementų savybę', 0, NULL, NULL, NULL, 5),
	(716, 331, 'Skylės už senus periodus', 1, 310, 887, NULL, 5),
	(717, 332, 'Neuždaryti', 1, 310, 888, NULL, 5),
	(718, 333, 'Taškų sisteminės savybės "Esminė problema" pildymas', 1, 167, NULL, NULL, 5),
	(723, 337, 'Grupės "Pagal matavimo prietaisų tipus" sudėties pildymas/valymas', 1, 238, NULL, NULL, 5),
	(724, 338, 'Aktyvinės/reaktyvinės energijos pakaita iš galios profilio', 0, NULL, NULL, NULL, 5),
	(725, 339, 'Atnaujinti grupių matavimų išskaičiavimo iš taškų matavimų konfigūraciją pagal taškų ekonominių profilių konfigūraciją', 0, NULL, NULL, NULL, 5),
	(726, 340, 'Atnaujinti grupių matavimų išskaičiavimo iš grupių-komponentų matavimų konfigūraciją pagal pildymo taisykles', 0, NULL, NULL, NULL, 5),
	(728, 341, 'Nėra jokių nesenų nuskaitymo duomenų', 1, 238, 895, NULL, 5),
	(729, 342, 'Vienalaikis einamosios mėnesių energijos ir suminių rodmenų nuskaitymas (taškui)', 0, NULL, NULL, NULL, 5),
	(730, 343, 'Vienalaikis einamosios mėnesių energijos ir suminių rodmenų nuskaitymas (taško energijos tarifui)', 0, NULL, NULL, NULL, 5),
	(731, 344, 'Duomenų šaltinio perkūrimas', 1, NULL, NULL, NULL, 5),
	(732, 345, 'Matavimo taškų prietaisų konfigūracinių parametrų skylių pildymas', 1, NULL, NULL, NULL, 5),
	(733, 348, 'Atitinkamų matavimo taškams duomenų šaltinių sukūrimas arba papildymas', 0, NULL, NULL, NULL, 5),
	(738, 351, 'Seno registravimo duomenų bazėje laiko informacijos išvalymas rodmenų lentelėje', 1, 62, NULL, NULL, 5),
	(739, 352, 'Daug įvykių', 1, 310, 900, NULL, 5),
	(743, 357, 'Suminės A+ energijos proporcingas generavimas iš gretimų reikšmių, fiksuotų kas 15 min.', 0, 62, NULL, NULL, 5),
	(744, 358, 'Suminės A+ energijos proporcingas generavimas iš gretimų reikšmių, fiksuotų kas 30 min.', 0, 62, NULL, NULL, 5),
	(745, 359, 'Skylių ekonomijos rėžimo suspendavimas', 0, NULL, NULL, NULL, 5),
	(746, 362, 'Naujų grupių įtraukimas į grupę pagal matavimo taškų tipus (atsiradus naujiems matavimo tašku tipams)', 1, 62, NULL, NULL, 5),
	(747, 361, 'Elektros apskaita', 1, 62, 906, NULL, 5),
	(748, 364, 'Buferinių struktūrų suspaudimas', 1, 43, NULL, NULL, 5),
	(749, 365, 'Nėra galutinių rodmenų', 0, 310, 907, NULL, 5),
	(750, 366, 'Papildančių rodmenį specifinių nuskaitymų informacijos atnaujinimas', 0, NULL, NULL, NULL, 5),
	(751, 367, 'Blogiausi atsakantys nuskaitymo taškai pagal užklausų sėkmės procentą', 1, 238, 908, NULL, 5),
	(752, 372, 'Diskretinių signalų generavimas iš šablono reikšmių', 0, 238, NULL, NULL, 5),
	(757, 377, 'Automatinis audito įrašų apie duomenų keitimo operacijas, atliktas foninių užduočių, trynimas', 1, 62, NULL, NULL, 5),
	(758, 378, 'Automatinis visų matavimo taškų specifinių galiojančių duomenų įrašų trynimas', 0, NULL, NULL, NULL, 5),
	(762, 382, 'Automatinis rodmenų uždarymo verifikavimo rezultatų duomenų įrašų trynimas', 0, NULL, NULL, NULL, 5),
	(763, 385, 'Automatinis pasenusių audito duomenų įrašų trynimas', 0, NULL, NULL, NULL, 5);
/*!40000 ALTER TABLE `bga` ENABLE KEYS */;

-- Dumping structure for table emcor.bgao
CREATE TABLE IF NOT EXISTS `bgao` (
  `bgao_id` int(10) unsigned NOT NULL COMMENT 'DB aplikacijos foninių užduočių vykdymo užsakymo ID',
  `bga_id` int(10) unsigned NOT NULL COMMENT 'DB aplikacijos foninės užduoties ID',
  `user_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojo identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `bgao_status` tinyint(3) unsigned DEFAULT 0 COMMENT 'DB aplikacijos foninių užduočių vykdymo užsakymo būsena',
  PRIMARY KEY (`bgao_id`),
  KEY `bgao_bga_i` (`bga_id`),
  KEY `bgao_db_time_i` (`db_time`),
  KEY `bgao_status_i` (`bgao_status`),
  KEY `bgao_user_i` (`user_id`),
  CONSTRAINT `bgao_bga_fk` FOREIGN KEY (`bga_id`) REFERENCES `bga` (`bga_id`) ON DELETE CASCADE,
  CONSTRAINT `bgao_users_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='DB aplikacijos foninių užduočių vykdymo užsakymai';

-- Dumping data for table emcor.bgao: ~0 rows (approximately)
/*!40000 ALTER TABLE `bgao` DISABLE KEYS */;
/*!40000 ALTER TABLE `bgao` ENABLE KEYS */;

-- Dumping structure for table emcor.bgao_param
CREATE TABLE IF NOT EXISTS `bgao_param` (
  `bgao_id` int(10) unsigned NOT NULL COMMENT 'DB aplikacijos foninių užduočių vykdymo užsakymo ID',
  `bga_param_nr` smallint(5) unsigned NOT NULL COMMENT 'DB aplikacijos foninės užduoties parametro numeris',
  `bga_param_value` varchar(250) COLLATE utf8_bin NOT NULL COMMENT 'DB aplikacijos foninės užduoties parametro reikšmė',
  PRIMARY KEY (`bgao_id`,`bga_param_nr`),
  CONSTRAINT `bgao_param_bgao_fk` FOREIGN KEY (`bgao_id`) REFERENCES `bgao` (`bgao_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='DB aplikacijos foninių užduočių vykdymo užsakymų parametrai';

-- Dumping data for table emcor.bgao_param: ~0 rows (approximately)
/*!40000 ALTER TABLE `bgao_param` DISABLE KEYS */;
/*!40000 ALTER TABLE `bgao_param` ENABLE KEYS */;

-- Dumping structure for table emcor.bgaq
CREATE TABLE IF NOT EXISTS `bgaq` (
  `bgaq_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Foninių užduočių užsakymų eilės identifikatorius',
  `bgaq_code` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Foninių užduočių užsakymų eilės kodas',
  `bgaq_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Foninių užduočių užsakymų eilės pavadinimas',
  PRIMARY KEY (`bgaq_id`),
  UNIQUE KEY `bgaq_code_u` (`bgaq_code`),
  UNIQUE KEY `bgaq_name_u` (`bgaq_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Foninių užduočių užsakymų eilės';

-- Dumping data for table emcor.bgaq: ~0 rows (approximately)
/*!40000 ALTER TABLE `bgaq` DISABLE KEYS */;
/*!40000 ALTER TABLE `bgaq` ENABLE KEYS */;

-- Dumping structure for table emcor.bga_chamber
CREATE TABLE IF NOT EXISTS `bga_chamber` (
  `bga_id` int(10) unsigned NOT NULL,
  PRIMARY KEY (`bga_id`),
  CONSTRAINT `bga_chamber_bga_fk` FOREIGN KEY (`bga_id`) REFERENCES `bga` (`bga_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.bga_chamber: ~63 rows (approximately)
/*!40000 ALTER TABLE `bga_chamber` DISABLE KEYS */;
INSERT INTO `bga_chamber` (`bga_id`) VALUES
	(26),
	(71),
	(91),
	(143),
	(144),
	(145),
	(146),
	(147),
	(149),
	(151),
	(205),
	(206),
	(260),
	(291),
	(306),
	(311),
	(312),
	(338),
	(339),
	(340),
	(398),
	(457),
	(648),
	(660),
	(663),
	(664),
	(665),
	(666),
	(667),
	(674),
	(675),
	(677),
	(680),
	(681),
	(682),
	(683),
	(700),
	(701),
	(702),
	(703),
	(704),
	(705),
	(706),
	(707),
	(708),
	(709),
	(710),
	(711),
	(712),
	(713),
	(714),
	(716),
	(717),
	(718),
	(723),
	(728),
	(738),
	(739),
	(746),
	(747),
	(748),
	(751),
	(757);
/*!40000 ALTER TABLE `bga_chamber` ENABLE KEYS */;

-- Dumping structure for table emcor.bga_class
CREATE TABLE IF NOT EXISTS `bga_class` (
  `bga_class_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'DB aplikacijos foninių užduočių klasės ID',
  `bga_class_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'DB aplikacijos foninių užduočių klasės kodas',
  `bga_class_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'DB aplikacijos foninių užduočių klasės pavadinimas',
  PRIMARY KEY (`bga_class_id`),
  UNIQUE KEY `bga_class_code_u` (`bga_class_code`),
  UNIQUE KEY `bga_class_name_u` (`bga_class_name`)
) ENGINE=InnoDB AUTO_INCREMENT=93 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='DB aplikacijos foninių užduočių klasės';

-- Dumping data for table emcor.bga_class: ~15 rows (approximately)
/*!40000 ALTER TABLE `bga_class` DISABLE KEYS */;
INSERT INTO `bga_class` (`bga_class_id`, `bga_class_code`, `bga_class_name`) VALUES
	(1, 'DYNAMIC_GROUPS', 'Dinamiškai atnaujinamos grupės'),
	(5, 'ABGA', 'Andriaus BGA'),
	(26, 'DATABASE_GENERATED_DATA', 'Bazės generuojami duomenys'),
	(38, 'tstlbl', 'lblTest'),
	(46, 'FROZEN_DATA', 'Užfiksuoti archyvų duomenys'),
	(56, 'AUTO_DELETE_OLD_DATA', 'Automatinis senų duomenų trynimas'),
	(57, 'PARTITION_ADMINISTRATION', 'Lentelių particijų administravimas'),
	(62, 'DATA_SOURCES_CONFIGURATION', 'Duomenų šaltinių konfigūracija'),
	(67, 'MA_CONFIGURATION', 'Monitoringo konfigūracija'),
	(72, 'IMPORT', 'Specifinis importuojamų duomenų apdorojimas'),
	(77, 'PARALLEL_DAS', 'Lygiagretus duomenų surinkimo serverių veikimas'),
	(78, 'CLASSIFIERS_SYNCHRONIZATION', 'Klasifikatorių ir savybių sinchronizavimas'),
	(82, 'SBST_CONFIGURATION', 'Pakaitos konfigūracija'),
	(87, 'SPECIFIC_LINK_TASKS', 'Specifinės ryšio užduotys'),
	(92, 'SPECIFIC_DATA_TASKS', 'Specifinės duomenų užduotys');
/*!40000 ALTER TABLE `bga_class` ENABLE KEYS */;

-- Dumping structure for table emcor.bga_debug
CREATE TABLE IF NOT EXISTS `bga_debug` (
  `sql_block` varchar(4000) COLLATE utf8_bin DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='DB aplikacijos foninių užduočių derinimo duomenys';

-- Dumping data for table emcor.bga_debug: ~0 rows (approximately)
/*!40000 ALTER TABLE `bga_debug` DISABLE KEYS */;
/*!40000 ALTER TABLE `bga_debug` ENABLE KEYS */;

-- Dumping structure for table emcor.bga_inferior
CREATE TABLE IF NOT EXISTS `bga_inferior` (
  `bga_id` int(10) unsigned NOT NULL COMMENT 'DB aplikacijos foninės užduoties ID',
  `superior_bga_id` int(10) unsigned NOT NULL COMMENT 'DB aplikacijos viršesnės foninės užduoties ID',
  PRIMARY KEY (`bga_id`,`superior_bga_id`),
  CONSTRAINT `bga_inferior_bga_fk` FOREIGN KEY (`bga_id`) REFERENCES `bga` (`bga_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Foninių užduočių viršenybė';

-- Dumping data for table emcor.bga_inferior: ~0 rows (approximately)
/*!40000 ALTER TABLE `bga_inferior` DISABLE KEYS */;
/*!40000 ALTER TABLE `bga_inferior` ENABLE KEYS */;

-- Dumping structure for table emcor.bga_param
CREATE TABLE IF NOT EXISTS `bga_param` (
  `bga_id` int(10) unsigned NOT NULL COMMENT 'DB aplikacijos foninės užduoties ID',
  `bga_param_nr` smallint(5) unsigned NOT NULL COMMENT 'DB aplikacijos foninės užduoties parametro numeris',
  `bga_param_value` varchar(250) COLLATE utf8_bin NOT NULL COMMENT 'DB aplikacijos foninės užduoties parametro reikšmė',
  `bga_param_value_desc` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'DB aplikacijos foninės užduoties parametro reikšmės aprašymas',
  PRIMARY KEY (`bga_id`,`bga_param_nr`),
  CONSTRAINT `bga_param_bga_fk` FOREIGN KEY (`bga_id`) REFERENCES `bga` (`bga_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='DB aplikacijos foninės užduoties parametrai';

-- Dumping data for table emcor.bga_param: ~1 781 rows (approximately)
/*!40000 ALTER TABLE `bga_param` DISABLE KEYS */;
INSERT INTO `bga_param` (`bga_id`, `bga_param_nr`, `bga_param_value`, `bga_param_value_desc`) VALUES
	(21, 1, '385', NULL),
	(21, 2, '381', NULL),
	(21, 3, '1', NULL),
	(22, 1, '377', NULL),
	(22, 2, '385', NULL),
	(22, 3, '3', NULL),
	(23, 1, '33', NULL),
	(23, 2, '385', NULL),
	(23, 3, '5', NULL),
	(24, 1, '1513', NULL),
	(24, 2, '1521', NULL),
	(24, 3, '2', NULL),
	(25, 1, '1509', NULL),
	(25, 2, '1513', NULL),
	(25, 3, '2', NULL),
	(27, 1, '357', NULL),
	(27, 2, '365', NULL),
	(27, 3, '2', NULL),
	(28, 1, '353', NULL),
	(28, 2, '357', NULL),
	(28, 3, '3', NULL),
	(29, 1, 'UT.UKM.ANTAKALNIO_67.TEMP.LAUK', NULL),
	(29, 2, 'UT.UKM.KAT1.ŠIL.TEMP.GRF', NULL),
	(29, 3, '2', NULL),
	(29, 4, '70', NULL),
	(29, 5, '40', NULL),
	(29, 6, '70', NULL),
	(29, 7, '39,9', NULL),
	(29, 8, '70', NULL),
	(29, 9, '39,8', NULL),
	(29, 10, '70', NULL),
	(29, 11, '39,7', NULL),
	(29, 12, '70', NULL),
	(29, 13, '39,6', NULL),
	(29, 14, '70', NULL),
	(29, 15, '39,6', NULL),
	(29, 16, '70', NULL),
	(29, 17, '39,5', NULL),
	(29, 18, '70', NULL),
	(29, 19, '39,6', NULL),
	(29, 20, '70', NULL),
	(29, 21, '39,7', NULL),
	(29, 22, '70', NULL),
	(29, 23, '39,5', NULL),
	(29, 24, '70', NULL),
	(29, 25, '40', NULL),
	(29, 26, '70', NULL),
	(29, 27, '40,5', NULL),
	(29, 28, '71,6', NULL),
	(29, 29, '41', NULL),
	(29, 30, '73,8', NULL),
	(29, 31, '41,6', NULL),
	(29, 32, '75,9', NULL),
	(29, 33, '42,1', NULL),
	(29, 34, '78,1', NULL),
	(29, 35, '42,6', NULL),
	(29, 36, '80,3', NULL),
	(29, 37, '43,1', NULL),
	(29, 38, '82,5', NULL),
	(29, 39, '43,7', NULL),
	(29, 40, '84,7', NULL),
	(29, 41, '44,2', NULL),
	(29, 42, '86,9', NULL),
	(29, 43, '44,7', NULL),
	(29, 44, '89,1', NULL),
	(29, 45, '45,2', NULL),
	(29, 46, '91,3', NULL),
	(29, 47, '45,8', NULL),
	(29, 48, '93,4', NULL),
	(29, 49, '46,3', NULL),
	(29, 50, '95,6', NULL),
	(29, 51, '46,8', NULL),
	(29, 52, '97,8', NULL),
	(29, 53, '47,3', NULL),
	(29, 54, '100', NULL),
	(29, 55, '47,9', NULL),
	(29, 56, '100', NULL),
	(29, 57, '48,4', NULL),
	(29, 58, '100', NULL),
	(29, 59, '48,9', NULL),
	(29, 60, '100', NULL),
	(29, 61, '49,4', NULL),
	(29, 62, '100', NULL),
	(29, 63, '50', NULL),
	(29, 64, '100', NULL),
	(29, 65, '50,5', NULL),
	(29, 66, '100', NULL),
	(29, 67, '51', NULL),
	(29, 68, '100', NULL),
	(29, 69, '51', NULL),
	(29, 70, '100', NULL),
	(29, 71, '51', NULL),
	(29, 72, '100', NULL),
	(29, 73, '51', NULL),
	(30, 1, 'UT.UKM.ANTAKALNIO_67.TEMP.LAUK', NULL),
	(30, 2, 'UT.UKM.KAT3.ŠIL.TEMP.GRF', NULL),
	(30, 3, '2', NULL),
	(30, 4, '70', NULL),
	(30, 5, '40', NULL),
	(30, 6, '70', NULL),
	(30, 7, '40', NULL),
	(30, 8, '70', NULL),
	(30, 9, '40', NULL),
	(30, 10, '70', NULL),
	(30, 11, '40', NULL),
	(30, 12, '70', NULL),
	(30, 13, '40', NULL),
	(30, 14, '70', NULL),
	(30, 15, '40', NULL),
	(30, 16, '70', NULL),
	(30, 17, '40', NULL),
	(30, 18, '70', NULL),
	(30, 19, '40', NULL),
	(30, 20, '70', NULL),
	(30, 21, '40', NULL),
	(30, 22, '70', NULL),
	(30, 23, '40', NULL),
	(30, 24, '70', NULL),
	(30, 25, '40', NULL),
	(30, 26, '70', NULL),
	(30, 27, '41', NULL),
	(30, 28, '70', NULL),
	(30, 29, '41', NULL),
	(30, 30, '71', NULL),
	(30, 31, '42', NULL),
	(30, 32, '72', NULL),
	(30, 33, '42', NULL),
	(30, 34, '73', NULL),
	(30, 35, '43', NULL),
	(30, 36, '74', NULL),
	(30, 37, '43', NULL),
	(30, 38, '76', NULL),
	(30, 39, '44', NULL),
	(30, 40, '77', NULL),
	(30, 41, '44', NULL),
	(30, 42, '79', NULL),
	(30, 43, '45', NULL),
	(30, 44, '80', NULL),
	(30, 45, '45', NULL),
	(30, 46, '81', NULL),
	(30, 47, '46', NULL),
	(30, 48, '82', NULL),
	(30, 49, '46', NULL),
	(30, 50, '84', NULL),
	(30, 51, '47', NULL),
	(30, 52, '85', NULL),
	(30, 53, '47', NULL),
	(30, 54, '86', NULL),
	(30, 55, '48', NULL),
	(30, 56, '87', NULL),
	(30, 57, '48', NULL),
	(30, 58, '88', NULL),
	(30, 59, '49', NULL),
	(30, 60, '89', NULL),
	(30, 61, '49', NULL),
	(30, 62, '90', NULL),
	(30, 63, '50', NULL),
	(30, 64, '91', NULL),
	(30, 65, '51', NULL),
	(30, 66, '92', NULL),
	(30, 67, '51', NULL),
	(30, 68, '93', NULL),
	(30, 69, '51', NULL),
	(30, 70, '93', NULL),
	(30, 71, '51', NULL),
	(30, 72, '94', NULL),
	(30, 73, '51', NULL),
	(32, 1, '249', NULL),
	(32, 2, '253', NULL),
	(32, 3, '3', NULL),
	(33, 1, '289', NULL),
	(33, 2, '293', NULL),
	(33, 3, '2', NULL),
	(34, 1, '275', NULL),
	(34, 2, '279', NULL),
	(34, 3, '2', NULL),
	(35, 1, '287', NULL),
	(35, 2, '275', NULL),
	(35, 3, '2', NULL),
	(36, 1, '125', NULL),
	(36, 2, '126', NULL),
	(36, 3, '3', NULL),
	(37, 1, '987', NULL),
	(37, 2, '125', NULL),
	(37, 3, '2', NULL),
	(38, 1, '49', NULL),
	(38, 2, '377', NULL),
	(38, 3, '2', NULL),
	(39, 1, '1736', NULL),
	(39, 2, '249', NULL),
	(39, 3, '2', NULL),
	(40, 1, '274', NULL),
	(40, 2, '278', NULL),
	(40, 3, '2', NULL),
	(41, 1, '286', NULL),
	(41, 2, '274', NULL),
	(41, 3, '2', NULL),
	(42, 1, '1754', NULL),
	(42, 2, '1509', NULL),
	(42, 3, '2', NULL),
	(43, 1, '1748', NULL),
	(43, 2, '353', NULL),
	(43, 3, '2', NULL),
	(44, 1, '1036', NULL),
	(44, 2, '353', NULL),
	(44, 3, '2', NULL),
	(45, 1, '2059', NULL),
	(45, 2, '1036', NULL),
	(45, 3, '2', NULL),
	(46, 1, '1733', NULL),
	(46, 2, '289', NULL),
	(46, 3, '2', NULL),
	(47, 1, '276', NULL),
	(47, 2, '280', NULL),
	(47, 3, '2', NULL),
	(48, 1, '288', NULL),
	(48, 2, '276', NULL),
	(48, 3, '2', NULL),
	(49, 1, '1498', NULL),
	(49, 2, '377', NULL),
	(49, 3, '2', NULL),
	(61, 1, '1760', NULL),
	(61, 2, '119', NULL),
	(61, 3, '3', NULL),
	(62, 1, '119', NULL),
	(62, 2, '120', NULL),
	(62, 3, '3', NULL),
	(63, 1, '120', NULL),
	(63, 2, '122', NULL),
	(63, 3, '2', NULL),
	(64, 1, '1763', NULL),
	(64, 2, '93', NULL),
	(64, 3, '3', NULL),
	(65, 1, '93', NULL),
	(65, 2, '94', NULL),
	(65, 3, '3', NULL),
	(66, 1, '94', NULL),
	(66, 2, '96', NULL),
	(66, 3, '2', NULL),
	(86, 1, '2082', NULL),
	(86, 2, '1704', NULL),
	(86, 3, '3', NULL),
	(87, 1, '1704', NULL),
	(87, 2, '1509', NULL),
	(87, 3, '3', NULL),
	(92, 1, '3', NULL),
	(96, 1, '17', NULL),
	(96, 2, '381', NULL),
	(96, 3, '3', NULL),
	(106, 1, '1049', NULL),
	(106, 2, '274', NULL),
	(106, 3, '3', NULL),
	(107, 1, '1050', NULL),
	(107, 2, '275', NULL),
	(107, 3, '3', NULL),
	(110, 1, '2002', NULL),
	(110, 2, '1028', NULL),
	(110, 3, '3', NULL),
	(111, 1, '1028', NULL),
	(111, 2, '249', NULL),
	(111, 3, '3', NULL),
	(112, 1, '2030', NULL),
	(112, 2, '978', NULL),
	(112, 3, '3', NULL),
	(113, 1, '978', NULL),
	(113, 2, '93', NULL),
	(113, 3, '3', NULL),
	(116, 1, '850', NULL),
	(116, 2, '377', NULL),
	(116, 3, '2', NULL),
	(117, 1, '852', NULL),
	(117, 2, '379', NULL),
	(117, 3, '2', NULL),
	(118, 1, '853', NULL),
	(118, 2, '380', NULL),
	(118, 3, '2', NULL),
	(121, 1, '1775', NULL),
	(121, 2, '1044', NULL),
	(121, 3, '3', NULL),
	(122, 1, '1044', NULL),
	(122, 2, '377', NULL),
	(122, 3, '3', NULL),
	(126, 1, '2030', NULL),
	(126, 2, '93', NULL),
	(126, 3, '3', NULL),
	(127, 1, '2002', NULL),
	(127, 2, '249', NULL),
	(127, 3, '3', NULL),
	(128, 1, '2059', NULL),
	(128, 2, '353', NULL),
	(128, 3, '3', NULL),
	(129, 1, '1775', NULL),
	(129, 2, '377', NULL),
	(129, 3, '3', NULL),
	(130, 1, '2082', NULL),
	(130, 2, '1509', NULL),
	(130, 3, '3', NULL),
	(131, 1, '1310', NULL),
	(131, 2, '51', NULL),
	(131, 3, '3', NULL),
	(132, 1, '1378', NULL),
	(132, 2, '52', NULL),
	(132, 3, '3', NULL),
	(136, 1, '388', NULL),
	(136, 2, '384', NULL),
	(136, 3, '1', NULL),
	(137, 1, '387', NULL),
	(137, 2, '383', NULL),
	(137, 3, '1', NULL),
	(138, 1, '386', NULL),
	(138, 2, '382', NULL),
	(138, 3, '1', NULL),
	(139, 1, '1051', NULL),
	(139, 2, '276', NULL),
	(139, 3, '3', NULL),
	(140, 1, '1765', NULL),
	(140, 2, '49', NULL),
	(140, 3, '3', NULL),
	(141, 2, '36', NULL),
	(141, 3, '45', NULL),
	(142, 1, '5', NULL),
	(142, 2, '36', NULL),
	(142, 3, '45', NULL),
	(143, 1, '5', NULL),
	(143, 2, '1080', NULL),
	(143, 3, '45', NULL),
	(144, 1, '5', NULL),
	(144, 2, '90', NULL),
	(144, 3, '45', NULL),
	(145, 1, '30', NULL),
	(145, 2, '3', NULL),
	(145, 3, '45', NULL),
	(146, 2, '30', 'Poslinkis dienomis (trinami įrašai, senesni už nurodytą dienų kiekį)'),
	(147, 1, '5', NULL),
	(147, 2, '30', NULL),
	(147, 3, '45', NULL),
	(148, 1, '30', NULL),
	(148, 2, '36', NULL),
	(148, 3, '45', NULL),
	(149, 1, '5', NULL),
	(149, 2, '30', NULL),
	(149, 3, '45', NULL),
	(150, 1, '5', NULL),
	(150, 2, '36', NULL),
	(150, 3, '45', NULL),
	(151, 1, '30', NULL),
	(151, 2, '90', NULL),
	(151, 3, '45', NULL),
	(156, 2, '90', NULL),
	(156, 3, '45', NULL),
	(157, 2, '90', NULL),
	(157, 3, '45', NULL),
	(162, 1, '34', NULL),
	(162, 2, '386', NULL),
	(162, 3, '5', NULL),
	(163, 1, '35', NULL),
	(163, 2, '387', NULL),
	(163, 3, '5', NULL),
	(164, 1, '36', NULL),
	(164, 2, '388', NULL),
	(164, 3, '5', NULL),
	(165, 1, '1306', NULL),
	(165, 2, '1296', NULL),
	(165, 3, '5', NULL),
	(166, 1, '1340', NULL),
	(166, 2, '1330', NULL),
	(166, 3, '5', NULL),
	(167, 1, '1374', NULL),
	(167, 2, '1364', NULL),
	(167, 3, '5', NULL),
	(168, 1, '1408', NULL),
	(168, 2, '1398', NULL),
	(168, 3, '5', NULL),
	(170, 1, '18', NULL),
	(170, 2, '382', NULL),
	(170, 3, '1', NULL),
	(171, 1, '19', NULL),
	(171, 2, '383', NULL),
	(171, 3, '1', NULL),
	(172, 1, '20', NULL),
	(172, 2, '384', NULL),
	(172, 3, '1', NULL),
	(173, 1, '1302', NULL),
	(173, 2, '1295', NULL),
	(173, 3, '1', NULL),
	(174, 1, '1336', NULL),
	(174, 2, '1329', NULL),
	(174, 3, '1', NULL),
	(175, 1, '1370', NULL),
	(175, 2, '1363', NULL),
	(175, 3, '1', NULL),
	(176, 1, '1404', NULL),
	(176, 2, '1397', NULL),
	(176, 3, '1', NULL),
	(181, 1, '656', NULL),
	(181, 2, '49', NULL),
	(181, 3, '1', NULL),
	(182, 1, '657', NULL),
	(182, 2, '50', NULL),
	(182, 3, '1', NULL),
	(183, 1, '1', NULL),
	(183, 2, '377', NULL),
	(183, 3, '2', NULL),
	(186, 1, '380', NULL),
	(186, 2, '388', NULL),
	(186, 3, '3', NULL),
	(187, 1, '379', NULL),
	(187, 2, '387', NULL),
	(187, 3, '3', NULL),
	(188, 1, '378', NULL),
	(188, 2, '386', NULL),
	(188, 3, '3', NULL),
	(202, 1, '293', NULL),
	(202, 2, '301', NULL),
	(202, 3, '2', NULL),
	(203, 1, '253', NULL),
	(203, 2, '261', NULL),
	(203, 3, '2', NULL),
	(204, 1, '2016', NULL),
	(204, 2, '289', NULL),
	(204, 3, '3', NULL),
	(205, 1, '100', NULL),
	(205, 2, '45', NULL),
	(206, 1, '5', NULL),
	(206, 2, '30', NULL),
	(206, 3, '45', NULL),
	(207, 1, '93', NULL),
	(207, 2, '94', NULL),
	(207, 3, '3', NULL),
	(211, 1, '1780', NULL),
	(211, 2, '377', NULL),
	(211, 3, '3', NULL),
	(216, 2, '1462', NULL),
	(216, 3, '3', NULL),
	(216, 11, '#PL.SELF.49', NULL),
	(216, 12, '#PL.SELF.51', NULL),
	(221, 2, '1430', NULL),
	(221, 3, '3', NULL),
	(221, 11, '#PL.SELF.377', NULL),
	(221, 12, '#PL.SELF.379', NULL),
	(226, 1, '50', NULL),
	(226, 2, '378', NULL),
	(226, 3, '2', NULL),
	(227, 1, '51', NULL),
	(227, 2, '379', NULL),
	(227, 3, '2', NULL),
	(228, 1, '52', NULL),
	(228, 2, '380', NULL),
	(228, 3, '2', NULL),
	(241, 1, '1498', NULL),
	(241, 2, '49', NULL),
	(241, 3, '3', NULL),
	(242, 1, '49', NULL),
	(242, 2, '385', NULL),
	(242, 3, '3', NULL),
	(243, 1, '50', NULL),
	(243, 2, '386', NULL),
	(243, 3, '3', NULL),
	(244, 1, '51', NULL),
	(244, 2, '387', NULL),
	(244, 3, '3', NULL),
	(245, 1, '52', NULL),
	(245, 2, '388', NULL),
	(245, 3, '3', NULL),
	(246, 1, '1498', NULL),
	(246, 2, '385', NULL),
	(246, 3, '5', NULL),
	(251, 1, '1499', NULL),
	(251, 2, '386', NULL),
	(251, 3, '5', NULL),
	(252, 1, '1500', NULL),
	(252, 2, '387', NULL),
	(252, 3, '5', NULL),
	(253, 1, '1501', NULL),
	(253, 2, '388', NULL),
	(253, 3, '5', NULL),
	(256, 1, '1', NULL),
	(256, 2, '1498', NULL),
	(256, 3, '3', NULL),
	(257, 1, '2', NULL),
	(257, 2, '1499', NULL),
	(257, 3, '3', NULL),
	(258, 1, '3', NULL),
	(258, 2, '1500', NULL),
	(258, 3, '3', NULL),
	(259, 1, '4', NULL),
	(259, 2, '1501', NULL),
	(259, 3, '3', NULL),
	(260, 1, '5', NULL),
	(260, 2, '150', NULL),
	(260, 3, '45', NULL),
	(261, 1, '1298', NULL),
	(261, 2, '1502', NULL),
	(261, 3, '3', NULL),
	(262, 1, '1332', NULL),
	(262, 2, '1503', NULL),
	(262, 3, '3', NULL),
	(263, 1, '1366', NULL),
	(263, 2, '1504', NULL),
	(263, 3, '3', NULL),
	(264, 1, '1400', NULL),
	(264, 2, '1505', NULL),
	(264, 3, '3', NULL),
	(265, 1, '2058', NULL),
	(265, 2, '353', NULL),
	(265, 3, '3', NULL),
	(266, 1, '2081', NULL),
	(266, 2, '1509', NULL),
	(266, 3, '3', NULL),
	(267, 1, '1781', NULL),
	(267, 2, '1780', NULL),
	(267, 3, '3', NULL),
	(268, 1, '33', NULL),
	(268, 2, '17', NULL),
	(268, 3, '1', NULL),
	(269, 1, '37', NULL),
	(269, 2, '21', NULL),
	(269, 3, '1', NULL),
	(270, 1, '41', NULL),
	(270, 2, '25', NULL),
	(270, 3, '1', NULL),
	(271, 1, '45', NULL),
	(271, 2, '29', NULL),
	(271, 3, '1', NULL),
	(272, 1, '1784', NULL),
	(272, 2, '33', NULL),
	(272, 3, '3', NULL),
	(273, 1, '1783', NULL),
	(273, 2, '37', NULL),
	(273, 3, '3', NULL),
	(274, 1, '1782', NULL),
	(274, 2, '41', NULL),
	(274, 3, '3', NULL),
	(275, 1, '1781', NULL),
	(275, 2, '45', NULL),
	(275, 3, '3', NULL),
	(276, 2, '378', NULL),
	(276, 3, '3', NULL),
	(276, 10, 'DELIVERY_POINT_TO_2_INLETS_WITH_TRANSFORMERS', NULL),
	(276, 11, '#PL.INLET1.378', NULL),
	(276, 12, '#PL.INLET2.378', NULL),
	(276, 13, '#EPTY.P[XX]1', NULL),
	(276, 14, '#EPTY.P[KZ]1', NULL),
	(276, 15, '#EPTY.S[NOM]1', NULL),
	(276, 16, '#EPTY.cos[F]', NULL),
	(276, 17, '#EPTY.P[XX]2', NULL),
	(276, 18, '#EPTY.P[KZ]2', NULL),
	(276, 19, '#EPTY.S[NOM]2', NULL),
	(277, 2, '378', NULL),
	(277, 3, '3', NULL),
	(277, 10, 'DELIVERY_POINT_TO_MS_POINT_CONSIDERING_LINE_LOSS', NULL),
	(277, 11, '#PL.MS_POINT.378', NULL),
	(277, 12, '#EPTY.U[NOM]', NULL),
	(277, 13, '#EPTY.cos[F]', NULL),
	(277, 14, '#EPTY.r[UD]', NULL),
	(277, 15, '#EPTY.L[KL]', NULL),
	(278, 2, '50', NULL),
	(278, 3, '3', NULL),
	(278, 10, 'DELIVERY_POINT_TO_MS_POINT_CONSIDERING_TRANSFORMER', NULL),
	(278, 11, '#PL.MS_POINT.50', NULL),
	(278, 12, '#PL.MS_POINT.52', NULL),
	(278, 13, '#EPTY.P[XX]', NULL),
	(278, 14, '#EPTY.P[KZ]', NULL),
	(278, 15, '#EPTY.S[NOM]', NULL),
	(279, 2, '50', NULL),
	(279, 3, '3', NULL),
	(279, 10, 'DELIVERY_POINT_TO_MS_POINT_CONSIDERING_TRANSFORMER', NULL),
	(279, 11, '#PL.MS_POINT.50', NULL),
	(279, 12, '#PL.MS_POINT.52', NULL),
	(279, 13, '#EPTY.P[XX]', NULL),
	(279, 14, '#EPTY.P[KZ]', NULL),
	(279, 15, '#EPTY.S[NOM]', NULL),
	(280, 2, '378', NULL),
	(280, 3, '3', NULL),
	(280, 10, 'DELIVERY_POINT_TO_2_INLETS_WITH_TRAN_2ND_LINE_LOSS', NULL),
	(280, 11, '#PL.INLET1.378', NULL),
	(280, 12, '#PL.INLET2.378', NULL),
	(280, 13, '#EPTY.P[XX]1', NULL),
	(280, 14, '#EPTY.P[KZ]1', NULL),
	(280, 15, '#EPTY.S[NOM]1', NULL),
	(280, 16, '#EPTY.cos[F]', NULL),
	(280, 17, '#EPTY.P[XX]2', NULL),
	(280, 18, '#EPTY.P[KZ]2', NULL),
	(280, 19, '#EPTY.S[NOM]2', NULL),
	(280, 20, '#EPTY.Q[XX]2', NULL),
	(280, 21, '#EPTY.Q[KZ]2', NULL),
	(280, 22, '#EPTY.U[NOM]', NULL),
	(280, 23, '#EPTY.r[UD]2', NULL),
	(280, 24, '#EPTY.L[KL]2', NULL),
	(281, 2, '49', NULL),
	(281, 3, '3', NULL),
	(281, 4, '2009.09.15', NULL),
	(281, 5, '2009.09.18', NULL),
	(281, 10, 'DELIVERY_POINT_TO_MS_POINT_WITH_TRAN_AND_LINE_LOSS', NULL),
	(281, 11, '#PL.MS_POINT.49', NULL),
	(281, 12, '#PL.MS_POINT.51', NULL),
	(281, 13, '#EPTY.P[XX]', NULL),
	(281, 14, '#EPTY.P[KZ]', NULL),
	(281, 15, '#EPTY.S[NOM]', NULL),
	(281, 16, '#EPTY.Q[XX]', NULL),
	(281, 17, '#EPTY.Q[KZ]', NULL),
	(281, 18, '#EPTY.U[NOM]', NULL),
	(281, 19, '#EPTY.r[UD]', NULL),
	(281, 20, '#EPTY.L[KL]', NULL),
	(282, 2, '49', NULL),
	(282, 3, '3', NULL),
	(282, 10, 'DELIVERY_POINT_TO_2_INLETS_WITH_TRAN_AND_LINE_LOSS', NULL),
	(282, 11, '#PL.INLET1.49', NULL),
	(282, 12, '#PL.INLET2.49', NULL),
	(282, 13, '#PL.INLET1.51', NULL),
	(282, 14, '#PL.INLET2.51', NULL),
	(282, 15, '#EPTY.P[XX]1', NULL),
	(282, 16, '#EPTY.P[KZ]1', NULL),
	(282, 17, '#EPTY.S[NOM]1', NULL),
	(282, 18, '#EPTY.Q[XX]1', NULL),
	(282, 19, '#EPTY.Q[KZ]1', NULL),
	(282, 20, '#EPTY.P[XX]2', NULL),
	(282, 21, '#EPTY.P[KZ]2', NULL),
	(282, 22, '#EPTY.S[NOM]2', NULL),
	(282, 23, '#EPTY.Q[XX]2', NULL),
	(282, 24, '#EPTY.Q[KZ]2', NULL),
	(282, 25, '#EPTY.U[NOM]', NULL),
	(282, 26, '#EPTY.r[UD]', NULL),
	(282, 27, '#EPTY.L[KL]', NULL),
	(283, 2, '49', NULL),
	(283, 3, '3', NULL),
	(283, 10, 'DELIVERY_POINT_TO_MS_POINT_CONSIDERING_LINE_LOSS', NULL),
	(283, 11, '#PL.MS_POINT.49', NULL),
	(283, 12, '#PL.MS_POINT.51', NULL),
	(283, 13, '#EPTY.U[NOM]', NULL),
	(283, 14, '#EPTY.r[UD]', NULL),
	(283, 15, '#EPTY.r[UD]', NULL),
	(284, 2, '49', NULL),
	(284, 3, '3', NULL),
	(284, 10, 'DELIVERY_POINT_TO_MS_POINT_CONSIDERING_TRANSFORMER', NULL),
	(284, 11, '#PL.MS_POINT.49', NULL),
	(284, 12, '#PL.MS_POINT.51', NULL),
	(284, 13, '#EPTY.P[XX]', NULL),
	(284, 14, '#EPTY.P[KZ]', NULL),
	(284, 15, '#EPTY.S[NOM]', NULL),
	(285, 2, '49', NULL),
	(285, 3, '3', NULL),
	(285, 10, 'DELIVERY_POINT_TO_TRANSFORMER_AND_2_INLETS', NULL),
	(285, 11, '#EPTY.P[XX]', NULL),
	(285, 12, '#EPTY.P[KZ]', NULL),
	(285, 13, '#EPTY.S[NOM]', NULL),
	(285, 14, '#PL.INLET1.49', NULL),
	(285, 15, '#PL.INLET2.49', NULL),
	(285, 16, '#PL.INLET1.51', NULL),
	(285, 17, '#PL.INLET2.51', NULL),
	(291, 1, '60', NULL),
	(291, 2, '70', NULL),
	(291, 3, '45', NULL),
	(296, 1, '1294', NULL),
	(296, 2, '379', NULL),
	(296, 3, '2', NULL),
	(297, 1, '1362', NULL),
	(297, 2, '380', NULL),
	(297, 3, '2', NULL),
	(298, 1, '1049', NULL),
	(298, 2, '1051', NULL),
	(298, 3, '3', NULL),
	(299, 1, '274', NULL),
	(299, 2, '276', NULL),
	(299, 3, '3', NULL),
	(301, 1, '209', NULL),
	(301, 2, '213', NULL),
	(301, 3, '3', NULL),
	(302, 1, '1990', NULL),
	(302, 2, '209', NULL),
	(302, 3, '3', NULL),
	(303, 1, '213', NULL),
	(303, 2, '221', NULL),
	(303, 3, '2', NULL),
	(306, 2, '4', NULL),
	(311, 2, '4', NULL),
	(316, 1, '1045', NULL),
	(316, 2, '378', NULL),
	(316, 3, '3', NULL),
	(317, 1, '1046', NULL),
	(317, 2, '379', NULL),
	(317, 3, '3', NULL),
	(318, 1, '1047', NULL),
	(318, 2, '380', NULL),
	(318, 3, '3', NULL),
	(319, 1, '1044', NULL),
	(319, 2, '385', NULL),
	(319, 3, '3', NULL),
	(320, 1, '1045', NULL),
	(320, 2, '386', NULL),
	(320, 3, '3', NULL),
	(321, 1, '1046', NULL),
	(321, 2, '387', NULL),
	(321, 3, '3', NULL),
	(322, 1, '1047', NULL),
	(322, 2, '388', NULL),
	(322, 3, '3', NULL),
	(323, 1, '149', NULL),
	(323, 2, '157', NULL),
	(323, 3, '2', NULL),
	(324, 1, '189', NULL),
	(324, 2, '197', NULL),
	(324, 3, '2', NULL),
	(325, 1, '1745', NULL),
	(325, 2, '149', NULL),
	(325, 3, '3', NULL),
	(326, 1, '1742', NULL),
	(326, 2, '189', NULL),
	(326, 3, '3', NULL),
	(327, 1, '1745', NULL),
	(327, 2, '145', NULL),
	(327, 3, '3', NULL),
	(328, 1, '1742', NULL),
	(328, 2, '185', NULL),
	(328, 3, '3', NULL),
	(329, 2, '120', NULL),
	(329, 3, '45', NULL),
	(330, 2, '60', NULL),
	(330, 3, '45', NULL),
	(331, 2, '60', NULL),
	(331, 3, '45', NULL),
	(332, 2, '60', NULL),
	(332, 3, '45', NULL),
	(333, 2, '60', NULL),
	(333, 3, '45', NULL),
	(334, 2, '60', NULL),
	(334, 3, '45', NULL),
	(335, 2, '90', NULL),
	(335, 3, '45', NULL),
	(336, 1, '5', NULL),
	(336, 2, '90', NULL),
	(336, 3, '45', NULL),
	(337, 1, '5', NULL),
	(337, 2, '90', NULL),
	(337, 3, '45', NULL),
	(338, 1, '5', NULL),
	(338, 2, '60', NULL),
	(338, 3, '45', NULL),
	(339, 1, '5', NULL),
	(339, 2, '60', NULL),
	(339, 3, '45', NULL),
	(340, 1, '3', NULL),
	(341, 1, '49', NULL),
	(341, 2, '2097', NULL),
	(341, 3, '3', NULL),
	(342, 1, '50', NULL),
	(342, 2, '2106', NULL),
	(342, 3, '3', NULL),
	(343, 1, '51', NULL),
	(343, 2, '2114', NULL),
	(343, 3, '3', NULL),
	(344, 1, '52', NULL),
	(344, 2, '2129', NULL),
	(344, 3, '3', NULL),
	(345, 3, '2', NULL),
	(346, 2, '377', NULL),
	(346, 3, '2', NULL),
	(347, 2, '378', NULL),
	(347, 3, '2', NULL),
	(351, 1, '2095', NULL),
	(351, 2, '381', NULL),
	(351, 3, '3', NULL),
	(352, 1, '2107', NULL),
	(352, 2, '382', NULL),
	(352, 3, '3', NULL),
	(353, 1, '2116', NULL),
	(353, 2, '383', NULL),
	(353, 3, '3', NULL),
	(354, 1, '2131', NULL),
	(354, 2, '384', NULL),
	(354, 3, '3', NULL),
	(355, 1, '2094', NULL),
	(355, 2, '2097', NULL),
	(355, 3, '3', NULL),
	(356, 1, '2111', NULL),
	(356, 2, '2106', NULL),
	(356, 3, '3', NULL),
	(357, 1, '2121', NULL),
	(357, 2, '2114', NULL),
	(357, 3, '3', NULL),
	(358, 1, '2126', NULL),
	(358, 2, '2129', NULL),
	(358, 3, '3', NULL),
	(361, 1, '1498', NULL),
	(361, 2, '381', NULL),
	(361, 3, '3', NULL),
	(361, 8, '5', NULL),
	(362, 1, '1499', NULL),
	(362, 2, '382', NULL),
	(362, 3, '3', NULL),
	(362, 8, '5', NULL),
	(363, 1, '1500', NULL),
	(363, 2, '383', NULL),
	(363, 3, '3', NULL),
	(363, 8, '5', NULL),
	(364, 1, '1501', NULL),
	(364, 2, '384', NULL),
	(364, 3, '3', NULL),
	(364, 8, '5', NULL),
	(365, 1, '13', NULL),
	(365, 2, '29', NULL),
	(365, 3, '3', NULL),
	(365, 8, '5', NULL),
	(366, 1, '14', NULL),
	(366, 2, '30', NULL),
	(366, 3, '3', NULL),
	(366, 8, '5', NULL),
	(367, 1, '15', NULL),
	(367, 2, '31', NULL),
	(367, 3, '3', NULL),
	(367, 8, '5', NULL),
	(368, 1, '16', NULL),
	(368, 2, '32', NULL),
	(368, 3, '3', NULL),
	(368, 8, '5', NULL),
	(369, 1, '9', NULL),
	(369, 2, '25', NULL),
	(369, 3, '3', NULL),
	(369, 8, '5', NULL),
	(370, 1, '10', NULL),
	(370, 2, '26', NULL),
	(370, 3, '3', NULL),
	(370, 8, '5', NULL),
	(371, 1, '11', NULL),
	(371, 2, '27', NULL),
	(371, 3, '3', NULL),
	(371, 8, '5', NULL),
	(372, 1, '12', NULL),
	(372, 2, '28', NULL),
	(372, 3, '3', NULL),
	(372, 8, '5', NULL),
	(373, 1, '1', NULL),
	(373, 2, '17', NULL),
	(373, 3, '3', NULL),
	(373, 8, '5', NULL),
	(374, 1, '2', NULL),
	(374, 2, '18', NULL),
	(374, 3, '3', NULL),
	(374, 8, '5', NULL),
	(375, 1, '3', NULL),
	(375, 2, '19', NULL),
	(375, 3, '3', NULL),
	(375, 8, '5', NULL),
	(376, 1, '4', NULL),
	(376, 2, '20', NULL),
	(376, 3, '3', NULL),
	(376, 8, '5', NULL),
	(377, 1, '5', NULL),
	(377, 2, '21', NULL),
	(377, 3, '3', NULL),
	(377, 8, '5', NULL),
	(378, 1, '6', NULL),
	(378, 2, '22', NULL),
	(378, 3, '3', NULL),
	(378, 8, '5', NULL),
	(379, 1, '7', NULL),
	(379, 2, '23', NULL),
	(379, 3, '3', NULL),
	(379, 8, '5', NULL),
	(380, 1, '8', NULL),
	(380, 2, '24', NULL),
	(380, 3, '3', NULL),
	(380, 8, '5', NULL),
	(381, 1, '2098', NULL),
	(381, 2, '17', NULL),
	(381, 3, '3', NULL),
	(382, 1, '2105', NULL),
	(382, 2, '18', NULL),
	(382, 3, '3', NULL),
	(383, 1, '2118', NULL),
	(383, 2, '19', NULL),
	(383, 3, '3', NULL),
	(384, 1, '2132', NULL),
	(384, 2, '20', NULL),
	(384, 3, '3', NULL),
	(385, 1, '2102', NULL),
	(385, 2, '21', NULL),
	(385, 3, '3', NULL),
	(386, 1, '2104', NULL),
	(386, 2, '22', NULL),
	(386, 3, '3', NULL),
	(387, 1, '2115', NULL),
	(387, 2, '23', NULL),
	(387, 3, '3', NULL),
	(388, 1, '2127', NULL),
	(388, 2, '24', NULL),
	(388, 3, '3', NULL),
	(389, 1, '2101', NULL),
	(389, 2, '25', NULL),
	(389, 3, '3', NULL),
	(390, 1, '2103', NULL),
	(390, 2, '26', NULL),
	(390, 3, '3', NULL),
	(391, 1, '2122', NULL),
	(391, 2, '27', NULL),
	(391, 3, '3', NULL),
	(392, 1, '2128', NULL),
	(392, 2, '28', NULL),
	(392, 3, '3', NULL),
	(393, 1, '2093', NULL),
	(393, 2, '29', NULL),
	(393, 3, '3', NULL),
	(394, 1, '2112', NULL),
	(394, 2, '30', NULL),
	(394, 3, '3', NULL),
	(395, 1, '2113', NULL),
	(395, 2, '31', NULL),
	(395, 3, '3', NULL),
	(396, 1, '2124', NULL),
	(396, 2, '32', NULL),
	(396, 3, '3', NULL),
	(397, 2, '60', NULL),
	(397, 3, '50000', NULL),
	(401, 1, '5269', NULL),
	(401, 2, '5246', NULL),
	(401, 3, '3', NULL),
	(402, 1, '5246', NULL),
	(402, 2, '5248', NULL),
	(402, 3, '3', NULL),
	(403, 1, '3640', NULL),
	(403, 2, '3641', NULL),
	(403, 3, '3', NULL),
	(404, 1, '78', NULL),
	(404, 2, '5392', NULL),
	(404, 3, '3', NULL),
	(405, 1, '54', NULL),
	(405, 2, '5326', NULL),
	(405, 3, '3', NULL),
	(406, 1, '56', NULL),
	(406, 2, '5337', NULL),
	(406, 3, '3', NULL),
	(407, 1, '58', NULL),
	(407, 2, '5348', NULL),
	(407, 3, '3', NULL),
	(409, 1, '2097', NULL),
	(409, 2, '385', NULL),
	(409, 3, '3', NULL),
	(410, 1, '2094', NULL),
	(410, 2, '33', NULL),
	(410, 3, '3', NULL),
	(411, 1, '2100', NULL),
	(411, 2, '37', NULL),
	(411, 3, '3', NULL),
	(412, 1, '2099', NULL),
	(412, 2, '41', NULL),
	(412, 3, '3', NULL),
	(413, 1, '2096', NULL),
	(413, 2, '45', NULL),
	(413, 3, '3', NULL),
	(414, 1, '2106', NULL),
	(414, 2, '386', NULL),
	(414, 3, '3', NULL),
	(415, 1, '2111', NULL),
	(415, 2, '34', NULL),
	(415, 3, '3', NULL),
	(416, 1, '2110', NULL),
	(416, 2, '38', NULL),
	(416, 3, '3', NULL),
	(417, 1, '2109', NULL),
	(417, 2, '42', NULL),
	(417, 3, '3', NULL),
	(418, 1, '2108', NULL),
	(418, 2, '46', NULL),
	(418, 3, '3', NULL),
	(419, 1, '2114', NULL),
	(419, 2, '387', NULL),
	(419, 3, '3', NULL),
	(420, 1, '2121', NULL),
	(420, 2, '35', NULL),
	(420, 3, '3', NULL),
	(421, 1, '2117', NULL),
	(421, 2, '39', NULL),
	(421, 3, '3', NULL),
	(422, 1, '2120', NULL),
	(422, 2, '43', NULL),
	(422, 3, '3', NULL),
	(423, 1, '2119', NULL),
	(423, 2, '47', NULL),
	(423, 3, '3', NULL),
	(424, 1, '2129', NULL),
	(424, 2, '388', NULL),
	(424, 3, '3', NULL),
	(425, 1, '2126', NULL),
	(425, 2, '36', NULL),
	(425, 3, '3', NULL),
	(426, 1, '2130', NULL),
	(426, 2, '40', NULL),
	(426, 3, '3', NULL),
	(427, 1, '2125', NULL),
	(427, 2, '44', NULL),
	(427, 3, '3', NULL),
	(428, 1, '2123', NULL),
	(428, 2, '48', NULL),
	(428, 3, '3', NULL),
	(433, 1, '77', NULL),
	(433, 2, '4832', NULL),
	(433, 3, '3', NULL),
	(434, 1, '77', NULL),
	(434, 2, '4833', NULL),
	(434, 3, '3', NULL),
	(435, 1, '4832', NULL),
	(435, 2, '4834', NULL),
	(435, 3, '3', NULL),
	(436, 1, '4833', NULL),
	(436, 2, '4835', NULL),
	(436, 3, '3', NULL),
	(437, 1, '78', NULL),
	(437, 2, '4838', NULL),
	(437, 3, '3', NULL),
	(438, 1, '78', NULL),
	(438, 2, '4839', NULL),
	(438, 3, '3', NULL),
	(439, 1, '4838', NULL),
	(439, 2, '4840', NULL),
	(439, 3, '3', NULL),
	(440, 1, '4839', NULL),
	(440, 2, '4841', NULL),
	(440, 3, '3', NULL),
	(441, 1, '80', NULL),
	(441, 2, '4850', NULL),
	(441, 3, '3', NULL),
	(442, 1, '80', NULL),
	(442, 2, '4851', NULL),
	(442, 3, '3', NULL),
	(443, 1, '4850', NULL),
	(443, 2, '4852', NULL),
	(443, 3, '3', NULL),
	(444, 1, '4851', NULL),
	(444, 2, '4853', NULL),
	(444, 3, '3', NULL),
	(445, 1, '81', NULL),
	(445, 2, '4856', NULL),
	(445, 3, '3', NULL),
	(446, 1, '81', NULL),
	(446, 2, '4857', NULL),
	(446, 3, '3', NULL),
	(447, 1, '4856', NULL),
	(447, 2, '4858', NULL),
	(447, 3, '3', NULL),
	(448, 1, '4857', NULL),
	(448, 2, '4859', NULL),
	(448, 3, '3', NULL),
	(449, 1, '83', NULL),
	(449, 2, '4868', NULL),
	(449, 3, '3', NULL),
	(450, 1, '83', NULL),
	(450, 2, '4869', NULL),
	(450, 3, '3', NULL),
	(451, 1, '4868', NULL),
	(451, 2, '4870', NULL),
	(451, 3, '3', NULL),
	(452, 1, '4869', NULL),
	(452, 2, '4871', NULL),
	(452, 3, '3', NULL),
	(453, 1, '85', NULL),
	(453, 2, '4880', NULL),
	(453, 3, '3', NULL),
	(454, 1, '85', NULL),
	(454, 2, '4881', NULL),
	(454, 3, '3', NULL),
	(455, 1, '4880', NULL),
	(455, 2, '4882', NULL),
	(455, 3, '3', NULL),
	(456, 1, '4881', NULL),
	(456, 2, '4883', NULL),
	(456, 3, '3', NULL),
	(457, 1, '14', NULL),
	(458, 1, '4395', NULL),
	(458, 2, '4042', NULL),
	(458, 3, '3', NULL),
	(459, 1, '6699', NULL),
	(459, 2, '4394', NULL),
	(459, 3, '3', NULL),
	(460, 1, '6699', NULL),
	(460, 2, '4395', NULL),
	(460, 3, '3', NULL),
	(461, 1, '4394', NULL),
	(461, 2, '4041', NULL),
	(461, 3, '3', NULL),
	(462, 1, '850', NULL),
	(462, 2, '377', NULL),
	(462, 3, '3', NULL),
	(463, 1, '6656', NULL),
	(463, 2, '846', NULL),
	(463, 3, '3', NULL),
	(464, 1, '6656', NULL),
	(464, 2, '850', NULL),
	(464, 3, '3', NULL),
	(465, 1, '846', NULL),
	(465, 2, '3605', NULL),
	(465, 3, '3', NULL),
	(466, 1, '851', NULL),
	(466, 2, '378', NULL),
	(466, 3, '3', NULL),
	(467, 1, '6660', NULL),
	(467, 2, '847', NULL),
	(467, 3, '3', NULL),
	(468, 1, '6660', NULL),
	(468, 2, '851', NULL),
	(468, 3, '3', NULL),
	(469, 1, '847', NULL),
	(469, 2, '3606', NULL),
	(469, 3, '3', NULL),
	(470, 1, '5917', NULL),
	(470, 2, '5913', NULL),
	(470, 3, '3', NULL),
	(471, 1, '6822', NULL),
	(471, 2, '5917', NULL),
	(471, 3, '3', NULL),
	(472, 1, '6822', NULL),
	(472, 2, '6838', NULL),
	(472, 3, '3', NULL),
	(473, 1, '6838', NULL),
	(473, 2, '6284', NULL),
	(473, 3, '3', NULL),
	(474, 1, '852', NULL),
	(474, 2, '379', NULL),
	(474, 3, '3', NULL),
	(475, 1, '6710', NULL),
	(475, 2, '852', NULL),
	(475, 3, '3', NULL),
	(476, 1, '6710', NULL),
	(476, 2, '848', NULL),
	(476, 3, '3', NULL),
	(477, 1, '848', NULL),
	(477, 2, '3607', NULL),
	(477, 3, '3', NULL),
	(478, 1, '853', NULL),
	(478, 2, '380', NULL),
	(478, 3, '3', NULL),
	(479, 1, '6715', NULL),
	(479, 2, '849', NULL),
	(479, 3, '3', NULL),
	(480, 1, '6715', NULL),
	(480, 2, '853', NULL),
	(480, 3, '3', NULL),
	(481, 1, '849', NULL),
	(481, 2, '3608', NULL),
	(481, 3, '3', NULL),
	(482, 1, '1322', NULL),
	(482, 2, '1294', NULL),
	(482, 3, '3', NULL),
	(483, 1, '6724', NULL),
	(483, 2, '1321', NULL),
	(483, 3, '3', NULL),
	(484, 1, '6724', NULL),
	(484, 2, '1322', NULL),
	(484, 3, '3', NULL),
	(485, 1, '1321', NULL),
	(485, 2, '3609', NULL),
	(485, 3, '3', NULL),
	(486, 1, '1356', NULL),
	(486, 2, '1328', NULL),
	(486, 3, '3', NULL),
	(487, 1, '6728', NULL),
	(487, 2, '1355', NULL),
	(487, 3, '3', NULL),
	(488, 1, '6728', NULL),
	(488, 2, '1356', NULL),
	(488, 3, '3', NULL),
	(489, 1, '1355', NULL),
	(489, 2, '3610', NULL),
	(489, 3, '3', NULL),
	(490, 1, '1390', NULL),
	(490, 2, '1362', NULL),
	(490, 3, '3', NULL),
	(491, 1, '6730', NULL),
	(491, 2, '1389', NULL),
	(491, 3, '3', NULL),
	(492, 1, '6730', NULL),
	(492, 2, '1390', NULL),
	(492, 3, '3', NULL),
	(493, 1, '1389', NULL),
	(493, 2, '3611', NULL),
	(493, 3, '3', NULL),
	(494, 1, '1424', NULL),
	(494, 2, '1396', NULL),
	(494, 3, '3', NULL),
	(495, 1, '6738', NULL),
	(495, 2, '1424', NULL),
	(495, 3, '3', NULL),
	(496, 1, '6738', NULL),
	(496, 2, '1423', NULL),
	(496, 3, '3', NULL),
	(497, 1, '1423', NULL),
	(497, 2, '3612', NULL),
	(497, 3, '3', NULL),
	(498, 1, '5906', NULL),
	(498, 2, '5902', NULL),
	(498, 3, '3', NULL),
	(499, 1, '6823', NULL),
	(499, 2, '6839', NULL),
	(499, 3, '3', NULL),
	(500, 1, '6823', NULL),
	(500, 2, '5906', NULL),
	(500, 3, '3', NULL),
	(501, 1, '6839', NULL),
	(501, 2, '6288', NULL),
	(501, 3, '3', NULL),
	(502, 1, '1486', NULL),
	(502, 2, '1430', NULL),
	(502, 3, '3', NULL),
	(503, 1, '6840', NULL),
	(503, 2, '1486', NULL),
	(503, 3, '3', NULL),
	(504, 1, '6840', NULL),
	(504, 2, '1484', NULL),
	(504, 3, '3', NULL),
	(505, 1, '1484', NULL),
	(505, 2, '3613', NULL),
	(505, 3, '3', NULL),
	(506, 1, '1487', NULL),
	(506, 2, '1431', NULL),
	(506, 3, '3', NULL),
	(507, 1, '6846', NULL),
	(507, 2, '1487', NULL),
	(507, 3, '3', NULL),
	(508, 1, '6846', NULL),
	(508, 2, '1485', NULL),
	(508, 3, '3', NULL),
	(509, 1, '1485', NULL),
	(509, 2, '3614', NULL),
	(509, 3, '3', NULL),
	(510, 1, '782', NULL),
	(510, 2, '87', NULL),
	(510, 3, '3', NULL),
	(511, 1, '6890', NULL),
	(511, 2, '781', NULL),
	(511, 3, '3', NULL),
	(512, 1, '6890', NULL),
	(512, 2, '782', NULL),
	(512, 3, '3', NULL),
	(513, 1, '781', NULL),
	(513, 2, '3572', NULL),
	(513, 3, '3', NULL),
	(514, 1, '784', NULL),
	(514, 2, '93', NULL),
	(514, 3, '3', NULL),
	(515, 1, '6891', NULL),
	(515, 2, '783', NULL),
	(515, 3, '3', NULL),
	(516, 1, '6891', NULL),
	(516, 2, '784', NULL),
	(516, 3, '3', NULL),
	(517, 1, '783', NULL),
	(517, 2, '3573', NULL),
	(517, 3, '3', NULL),
	(518, 1, '786', NULL),
	(518, 2, '99', NULL),
	(518, 3, '3', NULL),
	(519, 1, '6892', NULL),
	(519, 2, '785', NULL),
	(519, 3, '3', NULL),
	(520, 1, '6892', NULL),
	(520, 2, '786', NULL),
	(520, 3, '3', NULL),
	(521, 1, '785', NULL),
	(521, 2, '3574', NULL),
	(521, 3, '3', NULL),
	(522, 1, '789', NULL),
	(522, 2, '109', NULL),
	(522, 3, '3', NULL),
	(523, 1, '6893', NULL),
	(523, 2, '788', NULL),
	(523, 3, '3', NULL),
	(524, 1, '6893', NULL),
	(524, 2, '789', NULL),
	(524, 3, '3', NULL),
	(525, 1, '788', NULL),
	(525, 2, '3575', NULL),
	(525, 3, '3', NULL),
	(526, 1, '792', NULL),
	(526, 2, '119', NULL),
	(526, 3, '3', NULL),
	(527, 1, '6894', NULL),
	(527, 2, '792', NULL),
	(527, 3, '3', NULL),
	(528, 1, '6894', NULL),
	(528, 2, '791', NULL),
	(528, 3, '3', NULL),
	(529, 1, '791', NULL),
	(529, 2, '3576', NULL),
	(529, 3, '3', NULL),
	(530, 1, '802', NULL),
	(530, 2, '145', NULL),
	(530, 3, '3', NULL),
	(531, 1, '6899', NULL),
	(531, 2, '798', NULL),
	(531, 3, '3', NULL),
	(532, 1, '6899', NULL),
	(532, 2, '802', NULL),
	(532, 3, '3', NULL),
	(533, 1, '798', NULL),
	(533, 2, '3577', NULL),
	(533, 3, '3', NULL),
	(534, 1, '803', NULL),
	(534, 2, '146', NULL),
	(534, 3, '3', NULL),
	(535, 1, '6900', NULL),
	(535, 2, '799', NULL),
	(535, 3, '3', NULL),
	(536, 1, '6900', NULL),
	(536, 2, '803', NULL),
	(536, 3, '3', NULL),
	(537, 1, '799', NULL),
	(537, 2, '3578', NULL),
	(537, 3, '3', NULL),
	(538, 1, '804', NULL),
	(538, 2, '147', NULL),
	(538, 3, '3', NULL),
	(539, 1, '6901', NULL),
	(539, 2, '804', NULL),
	(539, 3, '3', NULL),
	(540, 1, '6901', NULL),
	(540, 2, '800', NULL),
	(540, 3, '3', NULL),
	(541, 1, '800', NULL),
	(541, 2, '3579', NULL),
	(541, 3, '3', NULL),
	(542, 1, '814', NULL),
	(542, 2, '185', NULL),
	(542, 3, '3', NULL),
	(543, 1, '6902', NULL),
	(543, 2, '814', NULL),
	(543, 3, '3', NULL),
	(544, 1, '6902', NULL),
	(544, 2, '810', NULL),
	(544, 3, '3', NULL),
	(545, 1, '810', NULL),
	(545, 2, '3581', NULL),
	(545, 3, '3', NULL),
	(546, 1, '815', NULL),
	(546, 2, '186', NULL),
	(546, 3, '3', NULL),
	(547, 1, '6903', NULL),
	(547, 2, '811', NULL),
	(547, 3, '3', NULL),
	(548, 1, '6903', NULL),
	(548, 2, '815', NULL),
	(548, 3, '3', NULL),
	(549, 1, '811', NULL),
	(549, 2, '3582', NULL),
	(549, 3, '3', NULL),
	(550, 1, '816', NULL),
	(550, 2, '187', NULL),
	(550, 3, '3', NULL),
	(551, 1, '6904', NULL),
	(551, 2, '816', NULL),
	(551, 3, '3', NULL),
	(552, 1, '6904', NULL),
	(552, 2, '812', NULL),
	(552, 3, '3', NULL),
	(553, 1, '812', NULL),
	(553, 2, '3583', NULL),
	(553, 3, '3', NULL),
	(554, 1, '822', NULL),
	(554, 2, '209', NULL),
	(554, 3, '3', NULL),
	(555, 1, '6905', NULL),
	(555, 2, '818', NULL),
	(555, 3, '3', NULL),
	(556, 1, '6905', NULL),
	(556, 2, '822', NULL),
	(556, 3, '3', NULL),
	(557, 1, '818', NULL),
	(557, 2, '3585', NULL),
	(557, 3, '3', NULL),
	(558, 1, '823', NULL),
	(558, 2, '210', NULL),
	(558, 3, '3', NULL),
	(559, 1, '6906', NULL),
	(559, 2, '823', NULL),
	(559, 3, '3', NULL),
	(560, 1, '6906', NULL),
	(560, 2, '819', NULL),
	(560, 3, '3', NULL),
	(561, 1, '819', NULL),
	(561, 2, '3586', NULL),
	(561, 3, '3', NULL),
	(562, 1, '824', NULL),
	(562, 2, '211', NULL),
	(562, 3, '3', NULL),
	(563, 1, '6907', NULL),
	(563, 2, '820', NULL),
	(563, 3, '3', NULL),
	(564, 1, '6907', NULL),
	(564, 2, '824', NULL),
	(564, 3, '3', NULL),
	(565, 1, '820', NULL),
	(565, 2, '3587', NULL),
	(565, 3, '3', NULL),
	(566, 1, '834', NULL),
	(566, 2, '249', NULL),
	(566, 3, '3', NULL),
	(567, 1, '6908', NULL),
	(567, 2, '830', NULL),
	(567, 3, '3', NULL),
	(568, 1, '6908', NULL),
	(568, 2, '834', NULL),
	(568, 3, '3', NULL),
	(569, 1, '830', NULL),
	(569, 2, '3589', NULL),
	(569, 3, '3', NULL),
	(570, 1, '835', NULL),
	(570, 2, '250', NULL),
	(570, 3, '3', NULL),
	(571, 1, '6909', NULL),
	(571, 2, '831', NULL),
	(571, 3, '3', NULL),
	(572, 1, '6909', NULL),
	(572, 2, '835', NULL),
	(572, 3, '3', NULL),
	(573, 1, '831', NULL),
	(573, 2, '3590', NULL),
	(573, 3, '3', NULL),
	(574, 1, '836', NULL),
	(574, 2, '251', NULL),
	(574, 3, '3', NULL),
	(575, 1, '6910', NULL),
	(575, 2, '832', NULL),
	(575, 3, '3', NULL),
	(576, 1, '6910', NULL),
	(576, 2, '836', NULL),
	(576, 3, '3', NULL),
	(577, 1, '832', NULL),
	(577, 2, '3591', NULL),
	(577, 3, '3', NULL),
	(578, 1, '862', NULL),
	(578, 2, '289', NULL),
	(578, 3, '3', NULL),
	(579, 1, '6911', NULL),
	(579, 2, '858', NULL),
	(579, 3, '3', NULL),
	(580, 1, '6911', NULL),
	(580, 2, '862', NULL),
	(580, 3, '3', NULL),
	(581, 1, '858', NULL),
	(581, 2, '3593', NULL),
	(581, 3, '3', NULL),
	(582, 1, '863', NULL),
	(582, 2, '290', NULL),
	(582, 3, '3', NULL),
	(583, 1, '6912', NULL),
	(583, 2, '863', NULL),
	(583, 3, '3', NULL),
	(584, 1, '6912', NULL),
	(584, 2, '859', NULL),
	(584, 3, '3', NULL),
	(585, 1, '859', NULL),
	(585, 2, '3594', NULL),
	(585, 3, '3', NULL),
	(586, 1, '864', NULL),
	(586, 2, '291', NULL),
	(586, 3, '3', NULL),
	(587, 1, '6913', NULL),
	(587, 2, '860', NULL),
	(587, 3, '3', NULL),
	(588, 1, '6913', NULL),
	(588, 2, '864', NULL),
	(588, 3, '3', NULL),
	(589, 1, '860', NULL),
	(589, 2, '3595', NULL),
	(589, 3, '3', NULL),
	(590, 1, '870', NULL),
	(590, 2, '313', NULL),
	(590, 3, '3', NULL),
	(591, 1, '6914', NULL),
	(591, 2, '870', NULL),
	(591, 3, '3', NULL),
	(592, 1, '6914', NULL),
	(592, 2, '866', NULL),
	(592, 3, '3', NULL),
	(593, 1, '866', NULL),
	(593, 2, '3597', NULL),
	(593, 3, '3', NULL),
	(594, 1, '871', NULL),
	(594, 2, '314', NULL),
	(594, 3, '3', NULL),
	(595, 1, '6915', NULL),
	(595, 2, '867', NULL),
	(595, 3, '3', NULL),
	(596, 1, '6915', NULL),
	(596, 2, '871', NULL),
	(596, 3, '3', NULL),
	(597, 1, '867', NULL),
	(597, 2, '3598', NULL),
	(597, 3, '3', NULL),
	(598, 1, '872', NULL),
	(598, 2, '315', NULL),
	(598, 3, '3', NULL),
	(599, 1, '6916', NULL),
	(599, 2, '868', NULL),
	(599, 3, '3', NULL),
	(600, 1, '6916', NULL),
	(600, 2, '872', NULL),
	(600, 3, '3', NULL),
	(601, 1, '868', NULL),
	(601, 2, '3599', NULL),
	(601, 3, '3', NULL),
	(602, 1, '842', NULL),
	(602, 2, '353', NULL),
	(602, 3, '3', NULL),
	(603, 1, '6654', NULL),
	(603, 2, '842', NULL),
	(603, 3, '3', NULL),
	(604, 1, '6654', NULL),
	(604, 2, '838', NULL),
	(604, 3, '3', NULL),
	(605, 1, '838', NULL),
	(605, 2, '3601', NULL),
	(605, 3, '3', NULL),
	(606, 1, '843', NULL),
	(606, 2, '354', NULL),
	(606, 3, '3', NULL),
	(607, 1, '6917', NULL),
	(607, 2, '839', NULL),
	(607, 3, '3', NULL),
	(608, 1, '6917', NULL),
	(608, 2, '843', NULL),
	(608, 3, '3', NULL),
	(609, 1, '839', NULL),
	(609, 2, '3602', NULL),
	(609, 3, '3', NULL),
	(610, 1, '844', NULL),
	(610, 2, '355', NULL),
	(610, 3, '3', NULL),
	(611, 1, '6918', NULL),
	(611, 2, '844', NULL),
	(611, 3, '3', NULL),
	(612, 1, '6918', NULL),
	(612, 2, '840', NULL),
	(612, 3, '3', NULL),
	(613, 1, '840', NULL),
	(613, 2, '3603', NULL),
	(613, 3, '3', NULL),
	(614, 1, '1672', NULL),
	(614, 2, '1541', NULL),
	(614, 3, '3', NULL),
	(615, 1, '6919', NULL),
	(615, 2, '1668', NULL),
	(615, 3, '3', NULL),
	(616, 1, '6919', NULL),
	(616, 2, '1672', NULL),
	(616, 3, '3', NULL),
	(617, 1, '1668', NULL),
	(617, 2, '3619', NULL),
	(617, 3, '3', NULL),
	(618, 1, '1673', NULL),
	(618, 2, '1542', NULL),
	(618, 3, '3', NULL),
	(619, 1, '6920', NULL),
	(619, 2, '1673', NULL),
	(619, 3, '3', NULL),
	(620, 1, '6920', NULL),
	(620, 2, '1669', NULL),
	(620, 3, '3', NULL),
	(621, 1, '1669', NULL),
	(621, 2, '3620', NULL),
	(621, 3, '3', NULL),
	(622, 1, '1674', NULL),
	(622, 2, '1543', NULL),
	(622, 3, '3', NULL),
	(623, 1, '6921', NULL),
	(623, 2, '1674', NULL),
	(623, 3, '3', NULL),
	(624, 1, '6921', NULL),
	(624, 2, '1670', NULL),
	(624, 3, '3', NULL),
	(625, 1, '1670', NULL),
	(625, 2, '3621', NULL),
	(625, 3, '3', NULL),
	(626, 1, '1664', NULL),
	(626, 2, '1509', NULL),
	(626, 3, '3', NULL),
	(627, 1, '6922', NULL),
	(627, 2, '1660', NULL),
	(627, 3, '3', NULL),
	(628, 1, '6922', NULL),
	(628, 2, '1664', NULL),
	(628, 3, '3', NULL),
	(629, 1, '1660', NULL),
	(629, 2, '3615', NULL),
	(629, 3, '3', NULL),
	(630, 1, '1665', NULL),
	(630, 2, '1510', NULL),
	(630, 3, '3', NULL),
	(631, 1, '6923', NULL),
	(631, 2, '1665', NULL),
	(631, 3, '3', NULL),
	(632, 1, '6923', NULL),
	(632, 2, '1661', NULL),
	(632, 3, '3', NULL),
	(633, 1, '1661', NULL),
	(633, 2, '3616', NULL),
	(633, 3, '3', NULL),
	(634, 1, '1666', NULL),
	(634, 2, '1511', NULL),
	(634, 3, '3', NULL),
	(635, 1, '6924', NULL),
	(635, 2, '1662', NULL),
	(635, 3, '3', NULL),
	(636, 1, '6924', NULL),
	(636, 2, '1666', NULL),
	(636, 3, '3', NULL),
	(637, 1, '1662', NULL),
	(637, 2, '3617', NULL),
	(637, 3, '3', NULL),
	(638, 1, '5260', NULL),
	(638, 2, '5245', NULL),
	(638, 3, '3', NULL),
	(639, 1, '6997', NULL),
	(639, 2, '5259', NULL),
	(639, 3, '3', NULL),
	(640, 1, '6997', NULL),
	(640, 2, '5260', NULL),
	(640, 3, '3', NULL),
	(641, 1, '5259', NULL),
	(641, 2, '5269', NULL),
	(641, 3, '3', NULL),
	(643, 1, '8508', NULL),
	(643, 2, '8512', NULL),
	(643, 3, '3', NULL),
	(644, 1, '120', NULL),
	(645, 1, '120', NULL),
	(648, 1, '60', NULL),
	(649, 1, '256', NULL),
	(649, 2, '264', NULL),
	(649, 3, '3', NULL),
	(650, 1, '3592', NULL),
	(650, 2, '256', NULL),
	(650, 3, '3', NULL),
	(651, 1, '254', NULL),
	(651, 2, '262', NULL),
	(651, 3, '3', NULL),
	(652, 1, '3590', NULL),
	(652, 2, '254', NULL),
	(652, 3, '3', NULL),
	(653, 1, '3589', NULL),
	(653, 2, '253', NULL),
	(653, 3, '3', NULL),
	(654, 1, '3619', NULL),
	(654, 2, '1545', NULL),
	(654, 3, '3', NULL),
	(655, 1, '1545', NULL),
	(655, 2, '1553', NULL),
	(655, 3, '3', NULL),
	(656, 1, '1546', NULL),
	(656, 2, '1554', NULL),
	(656, 3, '3', NULL),
	(657, 1, '3620', NULL),
	(657, 2, '1546', NULL),
	(657, 3, '3', NULL),
	(658, 1, '1548', NULL),
	(658, 2, '1556', NULL),
	(658, 3, '3', NULL),
	(659, 1, '3622', NULL),
	(659, 2, '1548', NULL),
	(659, 3, '3', NULL),
	(660, 1, '5', NULL),
	(660, 2, '120', NULL),
	(660, 3, '45', NULL),
	(661, 1, '4184', NULL),
	(661, 2, '5971', NULL),
	(661, 3, '3', NULL),
	(663, 1, '2', NULL),
	(663, 2, '45', NULL),
	(663, 3, '10000', NULL),
	(667, 1, 'Generated_by_SQL_Server', NULL),
	(673, 1, '1748', NULL),
	(673, 2, '551', NULL),
	(673, 3, '3', NULL),
	(676, 1, '1780', NULL),
	(676, 2, '1780', NULL),
	(676, 3, '3', NULL),
	(677, 1, '5', NULL),
	(677, 2, '30', NULL),
	(677, 3, '45', NULL),
	(677, 4, '10000', NULL),
	(678, 1, '30', 'Poslinkis dienomis (TestMode išjungimas, seniau už nurodytą dienų kiekį)'),
	(679, 1, '1484', NULL),
	(679, 2, '3613', NULL),
	(679, 3, '3', NULL),
	(682, 1, '1', 'Gylis paromis'),
	(684, 1, '33', NULL),
	(684, 2, '2094', NULL),
	(684, 3, '3', NULL),
	(684, 8, '5', NULL),
	(684, 9, '0', NULL),
	(685, 1, '37', NULL),
	(685, 2, '2100', NULL),
	(685, 3, '3', NULL),
	(685, 8, '5', NULL),
	(685, 9, '0', NULL),
	(686, 1, '41', NULL),
	(686, 2, '2099', NULL),
	(686, 3, '3', NULL),
	(686, 8, '5', NULL),
	(686, 9, '0', NULL),
	(687, 1, '45', NULL),
	(687, 2, '2096', NULL),
	(687, 3, '3', NULL),
	(687, 8, '5', NULL),
	(687, 9, '0', NULL),
	(688, 1, '34', NULL),
	(688, 2, '2111', NULL),
	(688, 3, '3', NULL),
	(688, 8, '5', NULL),
	(688, 9, '0', NULL),
	(689, 1, '38', NULL),
	(689, 2, '2110', NULL),
	(689, 3, '3', NULL),
	(689, 8, '5', NULL),
	(689, 9, '0', NULL),
	(690, 1, '42', NULL),
	(690, 2, '2109', NULL),
	(690, 3, '3', NULL),
	(690, 8, '5', NULL),
	(690, 9, '0', NULL),
	(691, 1, '46', NULL),
	(691, 2, '2108', NULL),
	(691, 3, '3', NULL),
	(691, 8, '5', NULL),
	(691, 9, '0', NULL),
	(692, 1, '35', NULL),
	(692, 2, '2121', NULL),
	(692, 3, '3', NULL),
	(692, 8, '5', NULL),
	(692, 9, '0', NULL),
	(693, 1, '39', NULL),
	(693, 2, '2117', NULL),
	(693, 3, '3', NULL),
	(693, 8, '5', NULL),
	(693, 9, '0', NULL),
	(694, 1, '43', NULL),
	(694, 2, '2120', NULL),
	(694, 3, '3', NULL),
	(694, 8, '5', NULL),
	(694, 9, '0', NULL),
	(695, 1, '47', NULL),
	(695, 2, '2119', NULL),
	(695, 3, '3', NULL),
	(695, 8, '5', NULL),
	(695, 9, '0', NULL),
	(696, 1, '36', NULL),
	(696, 2, '2126', NULL),
	(696, 3, '3', NULL),
	(696, 8, '5', NULL),
	(696, 9, '0', NULL),
	(697, 1, '40', NULL),
	(697, 2, '2130', NULL),
	(697, 3, '3', NULL),
	(697, 8, '5', NULL),
	(697, 9, '0', NULL),
	(698, 1, '44', NULL),
	(698, 2, '2125', NULL),
	(698, 3, '3', NULL),
	(698, 8, '5', NULL),
	(698, 9, '0', NULL),
	(699, 1, '48', NULL),
	(699, 2, '2123', NULL),
	(699, 3, '3', NULL),
	(699, 8, '5', NULL),
	(699, 9, '0', NULL),
	(705, 1, '12', NULL),
	(706, 1, '30', NULL),
	(706, 2, '100', NULL),
	(706, 3, '45', NULL),
	(713, 1, '1', NULL),
	(714, 1, '2', NULL),
	(715, 1, 'Saiman-1000', NULL),
	(715, 2, '1', NULL),
	(743, 1, '1775', NULL),
	(743, 2, '1775', NULL),
	(743, 3, '3', NULL),
	(744, 1, '1765', NULL),
	(744, 2, '1765', NULL),
	(744, 3, '3', NULL),
	(747, 1, 'ELECTRICITY', NULL),
	(749, 1, '14', NULL),
	(752, 3, '3', NULL),
	(752, 7, '14', NULL);
/*!40000 ALTER TABLE `bga_param` ENABLE KEYS */;

-- Dumping structure for table emcor.bga_state
CREATE TABLE IF NOT EXISTS `bga_state` (
  `bga_id` int(10) unsigned NOT NULL COMMENT 'DB aplikacijos foninės užduoties ID',
  `bga_running` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Požymis, ar DB aplikacijos foninė užduotis dabar vykdoma',
  `bga_last_exec_start` datetime DEFAULT NULL COMMENT 'DB aplikacijos foninės užduoties paskutinio vykdymo pradžia',
  `bga_last_exec_end` datetime DEFAULT NULL COMMENT 'DB aplikacijos foninės užduoties paskutinio vykdymo pabaiga',
  `bga_curr_exec_start` datetime DEFAULT NULL COMMENT 'DB aplikacijos foninės užduoties esamo vykdymo pradžia',
  `bgao_id` int(10) unsigned DEFAULT NULL,
  PRIMARY KEY (`bga_id`),
  KEY `bga_state_bgao_i` (`bgao_id`),
  CONSTRAINT `bga_state_bga_fk` FOREIGN KEY (`bga_id`) REFERENCES `bga` (`bga_id`) ON DELETE CASCADE,
  CONSTRAINT `bga_state_bgao_fk` FOREIGN KEY (`bgao_id`) REFERENCES `bgao` (`bgao_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='DB aplikacijos foninių užduočių vykdymo būsenos';

-- Dumping data for table emcor.bga_state: ~517 rows (approximately)
/*!40000 ALTER TABLE `bga_state` DISABLE KEYS */;
INSERT INTO `bga_state` (`bga_id`, `bga_running`, `bga_last_exec_start`, `bga_last_exec_end`, `bga_curr_exec_start`, `bgao_id`) VALUES
	(21, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(22, 0, '2012-02-08 10:31:14', '2012-02-08 10:31:14', NULL, NULL),
	(23, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(24, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(25, 0, '2012-02-08 10:31:14', '2012-02-08 10:31:14', NULL, NULL),
	(26, 0, '2017-03-24 16:31:00', '2017-03-24 16:31:00', NULL, NULL),
	(27, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(28, 0, '2012-02-08 10:31:14', '2012-02-08 10:31:14', NULL, NULL),
	(32, 0, '2012-02-08 10:31:14', '2012-02-08 10:31:14', NULL, NULL),
	(33, 0, '2012-02-08 10:31:14', '2012-02-08 10:31:14', NULL, NULL),
	(34, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(35, 0, '2012-02-08 10:31:14', '2012-02-08 10:31:14', NULL, NULL),
	(36, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(37, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(38, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(39, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(40, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(41, 0, '2012-02-08 10:31:14', '2012-02-08 10:31:14', NULL, NULL),
	(42, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(43, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(44, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(45, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(46, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(47, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(48, 0, '2012-02-08 10:31:14', '2012-02-08 10:31:14', NULL, NULL),
	(49, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(61, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(62, 0, '2012-02-08 10:31:14', '2012-02-08 10:31:14', NULL, NULL),
	(63, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(64, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(65, 0, '2012-02-08 10:31:14', '2012-02-08 10:31:14', NULL, NULL),
	(66, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(71, 0, '2017-03-24 00:02:07', '2017-03-24 00:02:07', NULL, NULL),
	(86, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(87, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(91, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(92, 0, '2012-02-08 10:31:14', '2012-02-08 10:31:14', NULL, NULL),
	(96, 0, '2012-02-08 00:02:10', '2012-02-08 00:02:10', NULL, NULL),
	(106, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(107, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(110, 0, '2012-02-08 10:31:14', '2012-02-08 10:31:15', NULL, NULL),
	(111, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(112, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(113, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(116, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(117, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(118, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(121, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(122, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(126, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(127, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(128, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(129, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(130, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(131, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(132, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(139, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(143, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(144, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(145, 0, '2017-03-24 00:02:07', '2017-03-24 00:02:07', NULL, NULL),
	(146, 0, '2017-03-24 00:02:07', '2017-03-24 00:02:07', NULL, NULL),
	(147, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(149, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(151, 0, '2017-03-24 00:02:07', '2017-03-24 00:02:07', NULL, NULL),
	(186, 0, '2012-02-08 08:03:19', '2012-02-08 08:03:19', NULL, NULL),
	(187, 0, '2012-02-08 08:03:19', '2012-02-08 08:03:19', NULL, NULL),
	(188, 0, '2012-02-08 08:03:19', '2012-02-08 08:03:19', NULL, NULL),
	(202, 0, '2012-02-08 08:03:19', '2012-02-08 08:03:19', NULL, NULL),
	(203, 0, '2012-02-08 08:03:19', '2012-02-08 08:03:19', NULL, NULL),
	(204, 0, '2012-02-08 08:03:19', '2012-02-08 08:03:19', NULL, NULL),
	(205, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(206, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(207, 0, '2012-02-08 08:03:19', '2012-02-08 08:03:19', NULL, NULL),
	(211, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(256, 0, '2009-12-21 11:34:09', '2009-12-21 11:34:09', NULL, NULL),
	(257, 0, '2009-12-21 11:34:12', '2009-12-21 11:34:12', NULL, NULL),
	(258, 0, '2009-12-21 11:34:12', '2009-12-21 11:34:12', NULL, NULL),
	(259, 0, '2009-12-21 11:34:12', '2009-12-21 11:34:12', NULL, NULL),
	(260, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(261, 0, '2009-12-24 03:09:00', '2009-12-24 03:09:00', NULL, NULL),
	(262, 0, '2009-12-24 03:09:02', '2009-12-24 03:09:02', NULL, NULL),
	(263, 0, '2009-12-24 03:09:02', '2009-12-24 03:09:02', NULL, NULL),
	(264, 0, '2009-12-24 03:09:02', '2009-12-24 03:09:02', NULL, NULL),
	(265, 0, '2009-12-24 03:09:04', '2009-12-24 03:09:04', NULL, NULL),
	(266, 0, '2009-12-24 03:09:04', '2009-12-24 03:09:04', NULL, NULL),
	(267, 0, '2009-12-24 03:09:05', '2009-12-24 03:09:05', NULL, NULL),
	(268, 0, '2009-12-24 03:09:07', '2009-12-24 03:09:07', NULL, NULL),
	(269, 0, '2009-12-24 03:09:09', '2009-12-24 03:09:09', NULL, NULL),
	(270, 0, '2009-12-24 03:09:09', '2009-12-24 03:09:09', NULL, NULL),
	(271, 0, '2009-12-24 03:09:09', '2009-12-24 03:09:09', NULL, NULL),
	(272, 0, '2009-12-24 03:09:10', '2009-12-24 03:09:10', NULL, NULL),
	(273, 0, '2009-12-24 03:09:10', '2009-12-24 03:09:10', NULL, NULL),
	(274, 0, '2009-12-24 03:09:10', '2009-12-24 03:09:10', NULL, NULL),
	(275, 0, '2009-12-24 03:09:10', '2009-12-24 03:09:10', NULL, NULL),
	(291, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(296, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(297, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(298, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(299, 0, '2012-02-08 10:31:15', '2012-02-08 10:31:15', NULL, NULL),
	(301, 0, '2010-04-15 10:51:04', '2010-04-15 10:51:04', NULL, NULL),
	(302, 0, '2010-04-15 10:51:13', '2010-04-15 10:51:13', NULL, NULL),
	(303, 0, '2010-04-15 10:51:13', '2010-04-15 10:51:13', NULL, NULL),
	(306, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(311, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(312, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(316, 0, '2011-04-22 07:54:42', '2011-04-22 07:54:42', NULL, NULL),
	(317, 0, '2011-04-22 07:54:43', '2011-04-22 07:54:43', NULL, NULL),
	(318, 0, '2011-04-22 07:54:43', '2011-04-22 07:54:43', NULL, NULL),
	(319, 0, '2011-04-22 07:54:44', '2011-04-22 07:54:44', NULL, NULL),
	(320, 0, '2011-04-22 07:54:44', '2011-04-22 07:54:44', NULL, NULL),
	(321, 0, '2011-04-22 07:54:44', '2011-04-22 07:54:44', NULL, NULL),
	(322, 0, '2011-04-22 07:54:44', '2011-04-22 07:54:44', NULL, NULL),
	(323, 0, '2011-04-22 08:03:35', '2011-04-22 08:03:35', NULL, NULL),
	(324, 0, '2011-04-22 08:03:36', '2011-04-22 08:03:36', NULL, NULL),
	(325, 0, '2011-04-22 08:03:36', '2011-04-22 08:03:36', NULL, NULL),
	(326, 0, '2011-04-22 08:03:37', '2011-04-22 08:03:37', NULL, NULL),
	(327, 0, '2011-04-22 08:03:37', '2011-04-22 08:03:37', NULL, NULL),
	(328, 0, '2011-04-22 08:03:37', '2011-04-22 08:03:37', NULL, NULL),
	(329, 0, '2011-04-22 08:03:39', '2011-04-22 08:03:39', NULL, NULL),
	(330, 0, '2011-04-22 08:03:39', '2011-04-22 08:03:39', NULL, NULL),
	(331, 0, '2011-04-22 08:03:40', '2011-04-22 08:03:40', NULL, NULL),
	(332, 0, '2011-04-22 08:03:40', '2011-04-22 08:03:40', NULL, NULL),
	(333, 0, '2011-04-22 08:03:41', '2011-04-22 08:03:41', NULL, NULL),
	(334, 0, '2011-04-22 08:03:41', '2011-04-22 08:03:41', NULL, NULL),
	(335, 0, '2011-04-22 08:09:13', '2011-04-22 08:09:13', NULL, NULL),
	(336, 0, '2011-04-22 10:49:28', '2011-04-22 10:49:28', NULL, NULL),
	(337, 0, '2011-04-22 10:49:29', '2011-04-22 10:49:29', NULL, NULL),
	(338, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(339, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(340, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(341, 0, '2011-04-22 12:28:06', '2011-04-22 12:28:06', NULL, NULL),
	(342, 0, '2011-04-22 12:28:07', '2011-04-22 12:28:07', NULL, NULL),
	(343, 0, '2011-04-22 12:28:07', '2011-04-22 12:28:07', NULL, NULL),
	(344, 0, '2011-04-22 12:28:07', '2011-04-22 12:28:07', NULL, NULL),
	(345, 0, '2011-04-22 12:28:07', '2011-04-22 12:28:07', NULL, NULL),
	(346, 0, '2011-04-22 12:28:07', '2011-04-22 12:28:07', NULL, NULL),
	(347, 0, '2011-04-22 12:28:07', '2011-04-22 12:28:07', NULL, NULL),
	(351, 0, '2011-05-27 01:24:17', '2011-05-27 01:24:17', NULL, NULL),
	(352, 0, '2011-05-27 01:24:19', '2011-05-27 01:24:19', NULL, NULL),
	(353, 0, '2011-05-27 01:24:19', '2011-05-27 01:24:19', NULL, NULL),
	(354, 0, '2011-05-27 01:24:19', '2011-05-27 01:24:19', NULL, NULL),
	(355, 0, '2011-05-27 01:24:52', '2011-05-27 01:24:52', NULL, NULL),
	(356, 0, '2011-05-27 01:24:52', '2011-05-27 01:24:52', NULL, NULL),
	(357, 0, '2011-05-27 01:24:52', '2011-05-27 01:24:52', NULL, NULL),
	(358, 0, '2011-05-27 01:24:52', '2011-05-27 01:24:52', NULL, NULL),
	(361, 0, '2011-07-01 21:19:54', '2011-07-01 21:19:54', NULL, NULL),
	(362, 0, '2011-07-01 21:19:54', '2011-07-01 21:19:54', NULL, NULL),
	(363, 0, '2011-07-01 21:19:55', '2011-07-01 21:19:55', NULL, NULL),
	(364, 0, '2011-07-01 21:19:55', '2011-07-01 21:19:55', NULL, NULL),
	(365, 0, '2011-07-01 21:19:55', '2011-07-01 21:19:55', NULL, NULL),
	(366, 0, '2011-07-01 21:19:55', '2011-07-01 21:19:55', NULL, NULL),
	(367, 0, '2011-07-01 21:19:55', '2011-07-01 21:19:55', NULL, NULL),
	(368, 0, '2011-07-01 21:19:55', '2011-07-01 21:19:55', NULL, NULL),
	(369, 0, '2011-07-01 21:19:55', '2011-07-01 21:19:55', NULL, NULL),
	(370, 0, '2011-07-01 21:19:55', '2011-07-01 21:19:55', NULL, NULL),
	(371, 0, '2011-07-01 21:19:55', '2011-07-01 21:19:55', NULL, NULL),
	(372, 0, '2011-07-01 21:19:55', '2011-07-01 21:19:55', NULL, NULL),
	(373, 0, '2011-07-01 21:19:55', '2011-07-01 21:19:55', NULL, NULL),
	(374, 0, '2011-07-01 21:19:55', '2011-07-01 21:19:55', NULL, NULL),
	(375, 0, '2011-07-01 21:19:55', '2011-07-01 21:19:55', NULL, NULL),
	(376, 0, '2011-07-01 21:19:56', '2011-07-01 21:19:56', NULL, NULL),
	(377, 0, '2011-07-01 21:19:56', '2011-07-01 21:19:56', NULL, NULL),
	(378, 0, '2011-07-01 21:19:56', '2011-07-01 21:19:56', NULL, NULL),
	(379, 0, '2011-07-01 21:19:56', '2011-07-01 21:19:56', NULL, NULL),
	(380, 0, '2011-07-01 21:19:56', '2011-07-01 21:19:56', NULL, NULL),
	(381, 0, '2011-08-02 17:28:30', '2011-08-02 17:28:30', NULL, NULL),
	(382, 0, '2011-08-02 17:28:33', '2011-08-02 17:28:33', NULL, NULL),
	(383, 0, '2011-08-02 17:28:33', '2011-08-02 17:28:33', NULL, NULL),
	(384, 0, '2011-08-02 17:28:33', '2011-08-02 17:28:33', NULL, NULL),
	(385, 0, '2011-08-02 17:28:33', '2011-08-02 17:28:33', NULL, NULL),
	(386, 0, '2011-08-02 17:28:33', '2011-08-02 17:28:33', NULL, NULL),
	(387, 0, '2011-08-02 17:28:33', '2011-08-02 17:28:33', NULL, NULL),
	(388, 0, '2011-08-02 17:28:33', '2011-08-02 17:28:33', NULL, NULL),
	(389, 0, '2011-08-02 17:28:34', '2011-08-02 17:28:34', NULL, NULL),
	(390, 0, '2011-08-02 17:28:34', '2011-08-02 17:28:34', NULL, NULL),
	(391, 0, '2011-08-02 17:28:34', '2011-08-02 17:28:34', NULL, NULL),
	(392, 0, '2011-08-02 17:28:34', '2011-08-02 17:28:34', NULL, NULL),
	(393, 0, '2011-08-02 17:28:34', '2011-08-02 17:28:34', NULL, NULL),
	(394, 0, '2011-08-02 17:28:34', '2011-08-02 17:28:34', NULL, NULL),
	(395, 0, '2011-08-02 17:28:34', '2011-08-02 17:28:34', NULL, NULL),
	(396, 0, '2011-08-02 17:28:34', '2011-08-02 17:28:34', NULL, NULL),
	(397, 0, '2011-09-19 16:34:50', '2011-09-19 16:34:50', NULL, NULL),
	(398, 0, '2017-03-24 00:02:07', '2017-03-24 00:02:07', NULL, NULL),
	(401, 0, '2011-11-25 06:38:16', '2011-11-25 06:38:16', NULL, NULL),
	(402, 0, '2011-11-25 06:38:16', '2011-11-25 06:38:16', NULL, NULL),
	(403, 0, '2011-11-25 06:38:21', '2011-11-25 06:38:21', NULL, NULL),
	(404, 0, '2012-01-11 14:27:44', '2012-01-11 14:27:44', NULL, NULL),
	(405, 0, '2012-01-11 14:27:45', '2012-01-11 14:27:45', NULL, NULL),
	(406, 0, '2012-01-11 14:27:45', '2012-01-11 14:27:45', NULL, NULL),
	(407, 0, '2012-01-11 14:27:45', '2012-01-11 14:27:45', NULL, NULL),
	(409, 0, '2012-03-07 15:47:13', '2012-03-07 15:47:13', NULL, NULL),
	(410, 0, '2012-03-07 15:47:14', '2012-03-07 15:47:14', NULL, NULL),
	(411, 0, '2012-03-07 15:47:14', '2012-03-07 15:47:14', NULL, NULL),
	(412, 0, '2012-03-07 15:47:14', '2012-03-07 15:47:14', NULL, NULL),
	(413, 0, '2012-03-07 15:47:14', '2012-03-07 15:47:14', NULL, NULL),
	(414, 0, '2012-03-07 15:47:14', '2012-03-07 15:47:14', NULL, NULL),
	(415, 0, '2012-03-07 15:47:14', '2012-03-07 15:47:14', NULL, NULL),
	(416, 0, '2012-03-07 15:47:14', '2012-03-07 15:47:14', NULL, NULL),
	(417, 0, '2012-03-07 15:47:14', '2012-03-07 15:47:14', NULL, NULL),
	(418, 0, '2012-03-07 15:47:14', '2012-03-07 15:47:14', NULL, NULL),
	(419, 0, '2012-03-07 15:47:14', '2012-03-07 15:47:14', NULL, NULL),
	(420, 0, '2012-03-07 15:47:14', '2012-03-07 15:47:14', NULL, NULL),
	(421, 0, '2012-03-07 15:47:15', '2012-03-07 15:47:15', NULL, NULL),
	(422, 0, '2012-03-07 15:47:15', '2012-03-07 15:47:15', NULL, NULL),
	(423, 0, '2012-03-07 15:47:15', '2012-03-07 15:47:15', NULL, NULL),
	(424, 0, '2012-03-07 15:47:15', '2012-03-07 15:47:15', NULL, NULL),
	(425, 0, '2012-03-07 15:47:15', '2012-03-07 15:47:15', NULL, NULL),
	(426, 0, '2012-03-07 15:47:15', '2012-03-07 15:47:15', NULL, NULL),
	(427, 0, '2012-03-07 15:47:15', '2012-03-07 15:47:15', NULL, NULL),
	(428, 0, '2012-03-07 15:47:15', '2012-03-07 15:47:15', NULL, NULL),
	(433, 0, '2012-05-02 22:06:13', '2012-05-02 22:06:13', NULL, NULL),
	(434, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(435, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(436, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(437, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(438, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(439, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(440, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(441, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(442, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(443, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(444, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(445, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(446, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(447, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(448, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(449, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(450, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(451, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(452, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(453, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(454, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(455, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(456, 0, '2012-05-02 22:06:14', '2012-05-02 22:06:14', NULL, NULL),
	(457, 0, '2017-03-24 12:03:08', '2017-03-24 12:03:08', NULL, NULL),
	(458, 0, '2012-06-12 11:41:43', '2012-06-12 11:41:43', NULL, NULL),
	(459, 0, '2012-06-12 11:41:47', '2012-06-12 11:41:47', NULL, NULL),
	(460, 0, '2012-06-12 11:41:47', '2012-06-12 11:41:47', NULL, NULL),
	(461, 0, '2012-06-12 11:41:47', '2012-06-12 11:41:47', NULL, NULL),
	(462, 0, '2012-06-12 11:41:47', '2012-06-12 11:41:47', NULL, NULL),
	(463, 0, '2012-06-12 11:41:47', '2012-06-12 11:41:47', NULL, NULL),
	(464, 0, '2012-06-12 11:41:47', '2012-06-12 11:41:47', NULL, NULL),
	(465, 0, '2012-06-12 11:41:47', '2012-06-12 11:41:47', NULL, NULL),
	(466, 0, '2012-06-12 11:41:47', '2012-06-12 11:41:47', NULL, NULL),
	(467, 0, '2012-06-12 11:41:47', '2012-06-12 11:41:47', NULL, NULL),
	(468, 0, '2012-06-12 11:41:47', '2012-06-12 11:41:47', NULL, NULL),
	(469, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(470, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(471, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(472, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(473, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(474, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(475, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(476, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(477, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(478, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(479, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(480, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(481, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(482, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(483, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(484, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(485, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(486, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(487, 0, '2012-06-12 11:41:48', '2012-06-12 11:41:48', NULL, NULL),
	(488, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(489, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(490, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(491, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(492, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(493, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(494, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(495, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(496, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(497, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(498, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(499, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(500, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(501, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(502, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(503, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(504, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(505, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(506, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(507, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(508, 0, '2012-06-12 11:41:49', '2012-06-12 11:41:49', NULL, NULL),
	(509, 0, '2012-06-12 11:41:50', '2012-06-12 11:41:50', NULL, NULL),
	(510, 0, '2012-06-12 11:41:50', '2012-06-12 11:41:50', NULL, NULL),
	(511, 0, '2012-06-12 11:41:50', '2012-06-12 11:41:50', NULL, NULL),
	(512, 0, '2012-06-12 11:41:50', '2012-06-12 11:41:50', NULL, NULL),
	(513, 0, '2012-06-12 11:41:50', '2012-06-12 11:41:50', NULL, NULL),
	(514, 0, '2012-06-12 11:41:50', '2012-06-12 11:41:50', NULL, NULL),
	(515, 0, '2012-06-12 11:41:50', '2012-06-12 11:41:50', NULL, NULL),
	(516, 0, '2012-06-12 11:41:50', '2012-06-12 11:41:50', NULL, NULL),
	(517, 0, '2012-06-12 11:41:50', '2012-06-12 11:41:50', NULL, NULL),
	(518, 0, '2012-06-12 11:41:50', '2012-06-12 11:41:50', NULL, NULL),
	(519, 0, '2012-06-12 11:41:50', '2012-06-12 11:41:50', NULL, NULL),
	(520, 0, '2012-06-12 11:41:50', '2012-06-12 11:41:50', NULL, NULL),
	(521, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(522, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(523, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(524, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(525, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(526, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(527, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(528, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(529, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(530, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(531, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(532, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(533, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(534, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(535, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(536, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(537, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(538, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(539, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(540, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(541, 0, '2012-06-12 11:41:51', '2012-06-12 11:41:51', NULL, NULL),
	(542, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(543, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(544, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(545, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(546, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(547, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(548, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(549, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(550, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(551, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(552, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(553, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(554, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(555, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(556, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(557, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(558, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(559, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(560, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(561, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(562, 0, '2012-06-12 11:41:52', '2012-06-12 11:41:52', NULL, NULL),
	(563, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(564, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(565, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(566, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(567, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(568, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(569, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(570, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(571, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(572, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(573, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(574, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(575, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(576, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(577, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(578, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(579, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(580, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(581, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(582, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(583, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(584, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(585, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(586, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(587, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(588, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(589, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(590, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(591, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(592, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(593, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(594, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(595, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(596, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(597, 0, '2012-06-12 11:41:53', '2012-06-12 11:41:53', NULL, NULL),
	(598, 0, '2012-06-12 11:41:54', '2012-06-12 11:41:54', NULL, NULL),
	(599, 0, '2012-06-12 11:41:54', '2012-06-12 11:41:54', NULL, NULL),
	(600, 0, '2012-06-12 11:41:54', '2012-06-12 11:41:54', NULL, NULL),
	(601, 0, '2012-06-12 11:41:54', '2012-06-12 11:41:54', NULL, NULL),
	(602, 0, '2012-06-12 11:41:54', '2012-06-12 11:41:54', NULL, NULL),
	(603, 0, '2012-06-12 11:41:54', '2012-06-12 11:41:54', NULL, NULL),
	(604, 0, '2012-06-12 11:41:54', '2012-06-12 11:41:54', NULL, NULL),
	(605, 0, '2012-06-12 11:41:54', '2012-06-12 11:41:54', NULL, NULL),
	(606, 0, '2012-06-12 11:41:54', '2012-06-12 11:41:54', NULL, NULL),
	(607, 0, '2012-06-12 11:41:55', '2012-06-12 11:41:55', NULL, NULL),
	(608, 0, '2012-06-12 11:41:55', '2012-06-12 11:41:55', NULL, NULL),
	(609, 0, '2012-06-12 11:41:55', '2012-06-12 11:41:55', NULL, NULL),
	(610, 0, '2012-06-12 11:41:55', '2012-06-12 11:41:55', NULL, NULL),
	(611, 0, '2012-06-12 11:41:55', '2012-06-12 11:41:55', NULL, NULL),
	(612, 0, '2012-06-12 11:41:55', '2012-06-12 11:41:55', NULL, NULL),
	(613, 0, '2012-06-12 11:41:55', '2012-06-12 11:41:55', NULL, NULL),
	(614, 0, '2012-06-12 11:41:55', '2012-06-12 11:41:55', NULL, NULL),
	(615, 0, '2012-06-12 11:41:55', '2012-06-12 11:41:55', NULL, NULL),
	(616, 0, '2012-06-12 11:41:55', '2012-06-12 11:41:55', NULL, NULL),
	(617, 0, '2012-06-12 11:41:55', '2012-06-12 11:41:55', NULL, NULL),
	(618, 0, '2012-06-12 11:41:55', '2012-06-12 11:41:55', NULL, NULL),
	(619, 0, '2012-06-12 11:41:55', '2012-06-12 11:41:55', NULL, NULL),
	(620, 0, '2012-06-12 11:41:55', '2012-06-12 11:41:55', NULL, NULL),
	(621, 0, '2012-06-12 11:41:56', '2012-06-12 11:41:56', NULL, NULL),
	(622, 0, '2012-06-12 11:41:56', '2012-06-12 11:41:56', NULL, NULL),
	(623, 0, '2012-06-12 11:41:56', '2012-06-12 11:41:56', NULL, NULL),
	(624, 0, '2012-06-12 11:41:56', '2012-06-12 11:41:56', NULL, NULL),
	(625, 0, '2012-06-12 11:41:56', '2012-06-12 11:41:56', NULL, NULL),
	(626, 0, '2012-06-12 11:41:56', '2012-06-12 11:41:56', NULL, NULL),
	(627, 0, '2012-06-12 11:41:56', '2012-06-12 11:41:56', NULL, NULL),
	(628, 0, '2012-06-12 11:41:56', '2012-06-12 11:41:56', NULL, NULL),
	(629, 0, '2012-06-12 11:41:56', '2012-06-12 11:41:56', NULL, NULL),
	(630, 0, '2012-06-12 11:41:56', '2012-06-12 11:41:56', NULL, NULL),
	(631, 0, '2012-06-12 11:41:56', '2012-06-12 11:41:56', NULL, NULL),
	(632, 0, '2012-06-12 11:41:56', '2012-06-12 11:41:56', NULL, NULL),
	(633, 0, '2012-06-12 11:41:56', '2012-06-12 11:41:56', NULL, NULL),
	(634, 0, '2012-06-12 11:41:56', '2012-06-12 11:41:56', NULL, NULL),
	(635, 0, '2012-06-12 11:41:56', '2012-06-12 11:41:56', NULL, NULL),
	(636, 0, '2012-06-12 11:41:56', '2012-06-12 11:41:56', NULL, NULL),
	(637, 0, '2012-06-12 11:41:57', '2012-06-12 11:41:57', NULL, NULL),
	(638, 0, '2012-06-12 11:41:57', '2012-06-12 11:41:57', NULL, NULL),
	(639, 0, '2012-06-12 11:41:57', '2012-06-12 11:41:57', NULL, NULL),
	(640, 0, '2012-06-12 11:41:57', '2012-06-12 11:41:57', NULL, NULL),
	(641, 0, '2012-06-12 11:41:57', '2012-06-12 11:41:57', NULL, NULL),
	(643, 0, '2012-09-06 15:53:25', '2012-09-06 15:53:25', NULL, NULL),
	(644, 0, '2012-09-07 11:58:54', '2012-09-07 11:58:54', NULL, NULL),
	(645, 0, '2012-09-07 11:58:54', '2012-09-07 11:58:54', NULL, NULL),
	(648, 0, '2017-03-24 16:51:12', '2017-03-24 16:51:12', NULL, NULL),
	(649, 0, '2012-12-17 15:42:48', '2012-12-17 15:42:48', NULL, NULL),
	(650, 0, '2012-12-17 15:42:49', '2012-12-17 15:42:49', NULL, NULL),
	(651, 0, '2012-12-17 15:42:49', '2012-12-17 15:42:49', NULL, NULL),
	(652, 0, '2012-12-17 15:42:49', '2012-12-17 15:42:49', NULL, NULL),
	(653, 0, '2012-12-17 15:42:49', '2012-12-17 15:42:49', NULL, NULL),
	(654, 0, '2012-12-17 15:42:49', '2012-12-17 15:42:49', NULL, NULL),
	(655, 0, '2012-12-17 15:42:49', '2012-12-17 15:42:49', NULL, NULL),
	(656, 0, '2012-12-17 15:42:49', '2012-12-17 15:42:49', NULL, NULL),
	(657, 0, '2012-12-17 15:42:49', '2012-12-17 15:42:49', NULL, NULL),
	(658, 0, '2012-12-17 15:42:49', '2012-12-17 15:42:49', NULL, NULL),
	(659, 0, '2012-12-17 15:42:49', '2012-12-17 15:42:49', NULL, NULL),
	(660, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(661, 0, '2012-12-17 15:57:28', '2012-12-17 15:57:28', NULL, NULL),
	(663, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(664, 0, '2017-03-24 00:02:00', '2017-03-24 00:02:06', NULL, NULL),
	(665, 0, '2017-03-24 16:31:00', '2017-03-24 16:31:00', NULL, NULL),
	(666, 0, '2016-03-03 09:21:14', '2016-03-03 09:21:15', NULL, NULL),
	(667, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(668, 0, '2013-03-25 11:11:52', '2013-03-25 11:11:52', NULL, NULL),
	(669, 0, '2013-03-25 11:11:58', '2013-03-25 11:11:58', NULL, NULL),
	(670, 0, '2013-03-25 11:11:58', '2013-03-25 11:11:58', NULL, NULL),
	(671, 0, '2013-03-25 11:13:29', '2013-03-25 11:13:29', NULL, NULL),
	(673, 0, '2014-07-30 12:22:26', '2014-07-30 12:22:26', NULL, NULL),
	(674, 0, '2017-03-24 00:02:07', '2017-03-24 00:02:07', NULL, NULL),
	(675, 0, '2017-03-24 00:02:07', '2017-03-24 00:02:07', NULL, NULL),
	(676, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(677, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(678, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(679, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(680, 0, '2017-03-24 00:02:07', '2017-03-24 00:02:08', NULL, NULL),
	(681, 0, '2017-03-24 00:02:08', '2017-03-24 00:02:08', NULL, NULL),
	(682, 0, '2017-03-24 12:03:08', '2017-03-24 12:03:09', NULL, NULL),
	(683, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(684, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(685, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(686, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(687, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(688, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(689, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(690, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(691, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(692, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(693, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(694, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(695, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(696, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(697, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(698, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(699, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(700, 0, '2017-03-24 12:03:09', '2017-03-24 12:03:09', NULL, NULL),
	(701, 0, '2017-03-24 12:03:09', '2017-03-24 12:03:09', NULL, NULL),
	(702, 0, '2017-03-24 12:03:09', '2017-03-24 12:03:09', NULL, NULL),
	(703, 0, '2017-03-24 12:03:09', '2017-03-24 12:03:09', NULL, NULL),
	(704, 0, '2017-03-24 12:03:09', '2017-03-24 12:03:09', NULL, NULL),
	(705, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(706, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(707, 0, '2017-03-24 16:03:10', '2017-03-24 16:03:10', NULL, NULL),
	(708, 0, '2017-03-24 16:03:10', '2017-03-24 16:03:10', NULL, NULL),
	(709, 0, '2017-03-24 16:03:10', '2017-03-24 16:03:10', NULL, NULL),
	(710, 0, '2017-03-24 12:03:09', '2017-03-24 12:03:09', NULL, NULL),
	(711, 0, '2017-03-24 16:03:10', '2017-03-24 16:03:10', NULL, NULL),
	(712, 0, '2017-03-24 16:03:10', '2017-03-24 16:03:10', NULL, NULL),
	(713, 0, '2017-03-24 16:03:10', '2017-03-24 16:03:11', NULL, NULL),
	(714, 0, '2017-03-24 16:03:11', '2017-03-24 16:03:11', NULL, NULL),
	(715, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(716, 0, '2017-03-24 12:03:09', '2017-03-24 12:03:09', NULL, NULL),
	(717, 0, '2017-03-24 12:03:09', '2017-03-24 12:03:09', NULL, NULL),
	(718, 0, '2017-03-24 16:36:05', '2017-03-24 16:36:05', NULL, NULL),
	(723, 0, '2017-03-24 16:03:11', '2017-03-24 16:03:11', NULL, NULL),
	(724, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(725, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(726, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(728, 0, '2017-03-24 16:03:11', '2017-03-24 16:03:11', NULL, NULL),
	(729, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(730, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(731, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(732, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(733, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(738, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(739, 0, '2017-03-24 12:03:09', '2017-03-24 12:03:09', NULL, NULL),
	(743, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(744, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(745, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(746, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:01', NULL, NULL),
	(747, 0, '2017-03-24 16:31:01', '2017-03-24 16:31:02', NULL, NULL),
	(748, 0, '2017-03-24 00:02:08', '2017-03-24 00:02:08', NULL, NULL),
	(749, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(750, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(751, 0, '2017-03-24 16:03:11', '2017-03-24 16:03:14', NULL, NULL),
	(752, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(757, 0, '2017-03-24 16:31:02', '2017-03-24 16:31:02', NULL, NULL),
	(758, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(762, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL),
	(763, 0, '1899-12-30 00:00:00', '1899-12-30 00:00:00', NULL, NULL);
/*!40000 ALTER TABLE `bga_state` ENABLE KEYS */;

-- Dumping structure for table emcor.bga_type
CREATE TABLE IF NOT EXISTS `bga_type` (
  `bga_type_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'DB aplikacijos foninių užduočių tipo ID',
  `bga_type_code` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'DB aplikacijos foninių užduočių tipo kodas',
  `bga_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'DB aplikacijos foninių užduočių tipo pavadinimas',
  `bga_type_desc` varchar(1024) COLLATE utf8_bin DEFAULT NULL COMMENT 'DB aplikacijos foninių užduočių tipo aprašymas',
  `bga_type_declare` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'SQL bloko DECLARE dalis',
  `bga_type_pre_action` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'SQL bloko pradžia',
  `bga_type_select` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'Iteruojama SQL užklausa',
  `bga_type_rec_action` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'SQL bloko iteracijos dalis',
  `bga_type_post_action` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'SQL bloko pabaiga',
  `bga_class_id` mediumint(8) unsigned NOT NULL COMMENT 'DB aplikacijos foninių užduočių klasės ID',
  PRIMARY KEY (`bga_type_id`),
  UNIQUE KEY `bga_type_code_u` (`bga_type_code`),
  UNIQUE KEY `bga_type_name_u` (`bga_type_name`),
  KEY `bga_type_bga_class_i` (`bga_class_id`),
  CONSTRAINT `bga_type_bga_class_fk` FOREIGN KEY (`bga_class_id`) REFERENCES `bga_class` (`bga_class_id`)
) ENGINE=InnoDB AUTO_INCREMENT=386 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='DB aplikacijos foninių užduočių tipai';

-- Dumping data for table emcor.bga_type: ~122 rows (approximately)
/*!40000 ALTER TABLE `bga_type` DISABLE KEYS */;
INSERT INTO `bga_type` (`bga_type_id`, `bga_type_code`, `bga_type_name`, `bga_type_desc`, `bga_type_declare`, `bga_type_pre_action`, `bga_type_select`, `bga_type_rec_action`, `bga_type_post_action`, `bga_class_id`) VALUES
	(21, 'MONTH_SUM_FROM_SUM_OF_DAYS', 'Mėnesio sumos rodmenų generavimas iš parų sumos rodmenų', 'Mėnesio sumos rodmenų generavimas iš parų sumos rodmenų', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100) INTO pGF FROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nEXECUTE IMMEDIATE \'truncate table gen$p\';\r\nFORALL j IN 1..mi\r\nINSERT INTO gen$p (pl_id,sep_id,point_id,aggs_type_id,s1)\r\nVALUES (sPL_ID(j),sSEP_ID(j),sPOINT_ID(j),sAGGS_TYPE_ID(j),s0);\r\nIF Nvl(:7,0)=0 THEN\r\nMERGE INTO gen$p y\r\nUSING (SELECT /*+ use_nl(a b c) index(c plep_pk)*/ a.pl_id,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=a.s1 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nEND s1\r\nFROM gen$p a\r\njoin plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=a.s1 AND c.plep_bt<s2)\r\nleft join plu b ON (a.pl_id=b.pl_id)\r\nGROUP BY a.pl_id\r\n) u ON (y.pl_id=u.pl_id)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.s1=u.s1\r\nWHERE y.s1<u.s1;\r\nEND IF;\r\nCOMMIT;\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v,Nvl(:7,0),s,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT c1,c2,c3,Trunc(da,\'MM\')t,sum(val)v,case WHEN\r\nMax(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=Add_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\')\r\nthen \'1\' else \'14\'||decode(count(*),Add_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\'),\'\',\'+3\') END s\r\nFROM TABLE(p_ar.p2(CURSOR(SELECT\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,s2,0))\r\nWHERE NOT val IS null\r\nGROUP BY c1,c2,c3,Trunc(da,\'MM\')) r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(22, 'THERMO_TEMP_GRAPH_FROM_OUTSIDE_TEMP', 'Šilumnešio temperatūrų grafiko rodmenų generavimas pagal lauko temperatūros duomenis', 'Šilumnešio temperatūrų grafiko rodmenų generavimas pagal lauko temperatūros duomenis', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nans VARCHAR2(250);\r\n', 'INSERT INTO gttt\r\n(d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\n(SELECT NULL,NULL,s.pl_id,s.sep_id,bt,\'\'\r\n,Decode(s.ml_id\r\n,274,Decode(Round(val),10,:4,9,:6,8,:8,7,:10,6,:12,5,:14,4,:16,3,:18,2,:20,1,:22,0,:24,-1,:26,-2,:28,-3,:30,-4,:32,-5,:34,-6,:36\r\n,-7,:38,-8,:40,-9,:42,-10,:44,-11,:46,-12,:48,-13,:50,-14,:52,-15,:54,-16,:56,-17,:58,-18,:60,-19,:62,-20,:64,-21,:66,-22,:68,-23,:70,-24,:72)\r\n,275,Decode(Round(val),10,:5,9,:7,8,:9,7,:11,6,:13,5,:15,4,:17,3,:19,2,:21,1,:23,0,:25,-1,:27,-2,:29,-3,:31,-4,:33,-5,:35,-6,:37\r\n,-7,:39,-8,:41,-9,:43,-10,:45,-11,:47,-12,:49,-13,:51,-14,:53,-15,:55,-16,:57,-17,:59,-18,:61,-19,:63,-20,:65,-21,:67,-22,:69,-23,:71,-24,:73)\r\n,276,Decode(Round(val),10,:4-:5,9,:6-:7,8,:8-:9,7,:10-:11,6,:12-:13,5,:14-:15,4,:16-:17,3,:18-:19,2,:20-:21,1,:22-:23,0,:24-:25\r\n,-1,:26-:27,-2,:28-:29,-3,:30-:31,-4,:32-:33,-5,:34-:35,-6,:36-:37,-7,:38-:39,-8,:40-:41,-9,:42-:43,-10,:44-:45,-11,:46-:47,-12,:48-:49\r\n,-13,:50-:51,-14,:52-:53,-15,:54-:55,-16,:56-:57,-17,:58-:59,-18,:60-:61,-19,:62-:63,-20,:64-:65,-21,:66-:67,-22,:68-:69,-23,:70-:71,-24,:72-:73)\r\n),0,Decode(a.has_specific_dstatus,0,\'1\',\'14\'),SYSDATE,\'\'\r\n, s.aggs_type_id FROM\r\n(SELECT\r\nA.SEP_ID,D.PL_ID,G.ML_ID, mm.aggs_type_id\r\nfrom sep A\r\njoin SE C on (A.SE_ID=C.SE_ID)\r\njoin SRC K on (C.SRC_ID=K.SRC_ID)\r\njoin SP L on (A.SP_ID=L.SP_ID)\r\njoin PH M on (L.PH_ID=M.PH_ID)\r\njoin DP O ON (K.DP_ID=O.DP_ID)\r\njoin DI D on (C.DI_ID=D.DI_ID)\r\njoin PL G on (D.PL_ID=G.PL_ID)\r\njoin ML mm on (g.ml_id=mm.ml_id)\r\njoin POINT I on (I.POINT_ID=G.POINT_ID)\r\nWHERE\r\nM.PH_DELETED=0 AND ph_enabled=1\r\nAND o.DP_DELETED=0 AND dp_enabled=1\r\nAND (K.SRC_BT IS NULL OR K.SRC_BT<=sysdate)\r\nAND (K.SRC_ET IS NULL OR K.SRC_ET>sysdate)\r\nAND k.src_enabled=1\r\nAND g.pl_enabled=1\r\nAND i.point_enabled=1\r\nAND I.POINT_AUTO_READ_ENABLED=1\r\nAND sep_enabled=1\r\nAND se_enabled=1\r\nAND di_enabled=1\r\nAND g.ml_id in (274,275,276) and src_type_id=0 AND src_name=(SELECT bga_type_name FROM st_bga WHERE bga_id=:0)\r\nAND i.point_code=:2\r\n) s\r\n,st_ar a\r\nWHERE point_code=:1 AND a.ml_id=125 AND da>=SYSDATE-:3 AND da<=SYSDATE\r\nAND val<10.5 AND val>-24.5);\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\nWHERE NOT EXISTS (SELECT 0 FROM pl_data\r\nWHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0);\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\n', NULL, NULL, NULL, 26),
	(23, 'HOUR_AVG_FROM_15_MIN_AVG', 'Vidutinių rodmenų per valandą generavimas iš vidutinių rodmenų per 15 minučių', 'Vidutinių rodmenų per valandą generavimas iš vidutinių rodmenų per 15 minučių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(bt,\'HH\') t,Avg(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=4\r\nthen \'1\' else \'14\'||decode(count(*),4,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da,Trunc(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(25, 'DAY_AVG_FROM_HOUR_AVG', 'Paros vidutinių rodmenų generavimas iš vidutinių rodmenų per valandą', 'Paros vidutinių rodmenų generavimas iš vidutinių rodmenų per valandą', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,avg(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=24\r\nthen \'1\' else \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(26, 'DAY_SUM_FROM_HOUR_AVG', 'Paros sumos rodmenų generavimas iš vidutinių rodmenų per valandą', 'Paros sumos rodmenų generavimas iš vidutinių rodmenų per valandą', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,sum(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=24\r\nthen \'1\' else \'14\'||decode(count(*),24,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(27, 'ADD_NEW_LINES_FOR_GENERATION', 'Naujų generuojamų matavimų linijų įtraukimas naujiems taškams', 'Naujų generuojamų matavimų linijų įtraukimas naujiems taškams', NULL, 'LOOP\r\nDELETE gttt;\r\nINSERT INTO gttt (id1,id2,id3,id4,id5)\r\nWITH\r\nc AS\r\n(SELECT src_id s,bga_param_nr r,bga_param_value v\r\n,CASE WHEN bga_type_param_key LIKE \'%ML_ID%\'THEN 1 ELSE 0 END t\r\n,lpty_value+0 l\r\nFROM\r\nst_bga_param join\r\n(SELECT s.*,src_name bga_name FROM src s) USING (bga_name)\r\njoin dp USING (dp_id)\r\njoin src_lpty USING (src_id)\r\nWHERE bga_param_nr<3\r\nAND lpty_id=151 AND LPTY_VALUE>\'0\'\r\nAND bga_enabled=1\r\nAND src_type_id=0\r\nand src_et is null\r\nAND dp_code=\'GENERATED_BY_ORACLE\'\r\n),b AS\r\n(SELECT c.*,Decode(t,1,v)+0 i FROM c),a AS\r\n(SELECT point_id p,b.* FROM point,b WHERE point_enabled=1)\r\nSELECT s,p,i,x,h from\r\n(SELECT\r\nf.*,Dense_Rank() over (PARTITION BY p,i,x ORDER BY l DESC,Decode(l,1,s))d\r\nfrom\r\n(SELECT\r\ns,p,l,Max(Decode(r,2,i))i,Max(Decode(r,2,x))x,Min(Decode(r,1,e,Nvl2(nullif(src_type_id,0),0,Decode(s,src_id,0))))w,Max(Decode(r,2,Nvl2(e,Nvl2(di_id,0,1),2)))h\r\nFROM\r\n(SELECT a.*,pl_enabled e,di_id,\'\'+0 x\r\nFROM a\r\nleft join pl ON (pl.point_id=p AND ml_id=i)\r\nleft join di ON (pl.pl_id=di.pl_id)\r\nWHERE t=1\r\nUNION ALL\r\nSELECT a.*\r\n,ds_enabled e,di_id,y.ds_type_id\r\nFROM a\r\njoin ds_type y ON (ds_type_code=v)\r\nleft join ds ON (ds.point_id=p AND ds.ds_type_id=y.ds_type_id)\r\nleft join di ON (ds.ds_id=di.ds_id)\r\nWHERE t=0)\r\nleft join\r\n(SELECT src_id,di_id,src_type_id FROM\r\nse join src USING (src_id) join dp USING (dp_id)\r\nWHERE src_et IS NULL AND dp_deleted =0) USING (di_id)\r\nGROUP BY s,p,l)f\r\nWHERE w=1 AND Nvl(i,x)>0\r\n) WHERE d=1 AND ROWNUM<=10000;\r\nEXIT WHEN SQL%ROWCOUNT=0;\r\nINSERT INTO pl (pl_id,point_id,ml_id)\r\nSELECT pl_seq.NEXTVAL,a.* FROM\r\n(SELECT DISTINCT id2,id3 FROM gttt WHERE id3>0 AND id5=2)a;\r\nINSERT INTO ds (ds_id,ds_code,ds_name,ds_type_id,ds_enabled,ds_event_log,ds_rt_enabled,ds_binary,enum_id,point_id)\r\nSELECT ds_seq.NEXTVAL,a.* FROM\r\n(SELECT DISTINCT substr(point_code||\'.\'||DS_TYPE_CODE,1,120),DS_TYPE_NAME,id4,1,ds_event_log,ds_rt_enabled,ds_binary,enum_id,id2 FROM gttt a,ds_type,point\r\nWHERE id2=point_id AND id4=ds_type_id AND id5=2)a;\r\nINSERT INTO di (di_id,di_enabled,lp_id,pl_id,ds_id,point_id)\r\nSELECT di_seq.NEXTVAL,1,lp_id,a.* FROM\r\n(SELECT DISTINCT pl_id,\'\'+0 ds_id,\'\'+0 point_id FROM gttt,pl WHERE id2=point_id AND id3=ml_id AND id5>0\r\nUNION ALL SELECT DISTINCT \'\'+0,ds_id,point_id FROM gttt,ds WHERE id2=point_id AND id4=ds_type_id AND id5>0)a,(SELECT lp_id FROM (SELECT lp_id FROM lp ORDER BY 1) WHERE ROWNUM=1);\r\nUPDATE dip SET di_et=DATE\'9999-12-31\'\r\nWHERE di_id IN (SELECT di_id FROM gttt,pl b,di c WHERE b.pl_id=c.pl_id AND id2=b.point_id AND id3=ml_id AND id5>0\r\nUNION ALL SELECT di_id FROM gttt,ds b,di c WHERE b.ds_id=c.ds_id AND id2=b.point_id AND id4=ds_type_id AND id5>0) AND di_et IS NULL;\r\nMERGE INTO dip y\r\nUSING (SELECT di_id,Max(di_bt) di_bt\r\nFROM\r\n(SELECT di_id FROM gttt,pl b,di c WHERE b.pl_id=c.pl_id AND id2=b.point_id AND id3=ml_id\r\nUNION ALL SELECT di_id FROM gttt,ds b,di c WHERE b.ds_id=c.ds_id AND id2=b.point_id AND id4=ds_type_id) join dip USING (di_id)\r\nGROUP BY di_id\r\nHAVING Max(Decode(di_et,NULL,1,DATE\'9999-12-31\',1)) IS NULL\r\n) u\r\nON (y.di_id=u.di_id AND y.di_bt=u.di_bt)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.di_et=DATE\'9999-12-31\';\r\nINSERT INTO se (se_id, src_id, di_id, se_ab, se_a, se_b, se_enabled, se_forced, se_h, se_h_per_id, se_h_depth)\r\nSELECT se_seq.NEXTVAL,id1,di_id,\'\',\'\',\'\',1,0,1,4,2 FROM\r\n(SELECT id1,di_id FROM gttt,pl b,di c WHERE b.pl_id=c.pl_id AND id2=b.point_id AND id3=ml_id\r\nUNION ALL SELECT id1,di_id FROM gttt,ds b,di c WHERE b.ds_id=c.ds_id AND id2=b.point_id AND id4=ds_type_id);\r\nINSERT INTO sep (sep_id,se_id,sp_id)\r\nSELECT sep_seq.NEXTVAL,se_id,sp_id FROM\r\n(SELECT id1 src_id,di_id FROM gttt,pl b,di c WHERE b.pl_id=c.pl_id AND id2=b.point_id AND id3=ml_id\r\nUNION ALL SELECT id1,di_id FROM gttt,ds b,di c WHERE b.ds_id=c.ds_id AND id2=b.point_id AND id4=ds_type_id)\r\njoin se USING (src_id, di_id)\r\njoin sp USING (src_id);\r\nCOMMIT;\r\nEND LOOP;', NULL, NULL, NULL, 26),
	(28, 'HOUR_AVG_FROM_30_MIN_AVG', 'Vidutinių rodmenų per valandą generavimas iš vidutinių rodmenų per 30 minučių', 'Vidutinių rodmenų per valandą generavimas iš vidutinių rodmenų per 30 minučių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM(SELECT c1,c2,c3,Trunc(bt,\'HH\') t,Avg(val) v,Decode(Max(HAS_SPECIFIC_DSTATUS),0,\'1\',\'14\') s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id, :1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,Trunc(bt,\'HH\')\r\nHAVING Count(*)=2)r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nFORALL j IN 1..sPL_ID.count\r\nINSERT INTO gttt\r\n(d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT NULL,NULL,sPL_ID(j),sSEP_ID(j),Trunc(bt,\'HH\'),\'1\'\r\n,Avg(val),Nvl(:7,0),Decode(Max(HAS_SPECIFIC_DSTATUS),0,\'1\',\'14\'),SYSDATE,1\r\n,sAGGS_TYPE_ID(j) FROM v_ar_ah\r\nWHERE point_id=sPOINT_ID(j) AND ml_id=:1 AND da>=Trunc(s0) AND bt>=s0 AND da<s2\r\nAND NOT val IS NULL\r\nGROUP BY Trunc(bt,\'HH\')\r\nHAVING Count(*)=2;\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_ah_data_valid WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(29, '15_MIN_AVG_FROM_15_MIN_TOTALS', 'Vidutinio debito per 15 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 'Vidutinio debito per 15 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3, bt+(nr-1)/96 t ,g/(et-bt)/24 v,Decode((et-bt)*96,1,\'1\',\'14\') s\r\nFROM(select * from\r\n(SELECT c1,c2,c3,da,bt, point_id\r\n,Lead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2+1))\r\nWHERE NOT val IS NULL  )r\r\n) f,mou u,iger where f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null and nr<=round((et-bt)*96,6))r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(30, 'HOUR_AVG_FROM_INSTANT_TOTALS', 'Vidutinės galios per valandą rodmenų generavimas iš augančių reikšmių', 'Vidutinės galios per valandą rodmenų generavimas iš augančių reikšmių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nfrom GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\ndelete gttt;\r\nFORALL j IN 1..sPL_ID.count\r\nINSERT INTO gttt\r\n(d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT NULL,NULL,sPL_ID(j),sSEP_ID(j),ib\r\n,\'\',Sum(q*l),Nvl(:7,0),Decode(Max(k),0,\'1\',\'14\'),SYSDATE,\'\'\r\n,sAGGS_TYPE_ID(j) FROM (SELECT f.*, w.* ,g/(et-bt)/24 q, TRUNC(f.bt, \'HH\')+(w.column_value-1)/24 ib\r\n,(Least(et,TRUNC(f.bt, \'HH\')+w.column_value /24)-Greatest(bt,TRUNC(f.bt, \'HH\')+(w.column_value-1)/24))*24 l\r\n,CASE WHEN et-bt>=2/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM\r\n(\r\nSELECT bt,\r\nLead(bt) over (ORDER BY bt) et,\r\nLead(val) over (ORDER BY bt)-\r\nCASE WHEN\r\nLead(val) over (ORDER BY bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nfrom\r\n(SELECT bt,val\r\nFROM v_ar\r\nWHERE point_id=sPOINT_ID(j) AND ml_id=:1 AND da>=Nvl(:4,SYSDATE-:3)\r\nAND da<=Nvl(:5,SYSDATE) AND NOT val IS NULL\r\n) r\r\nWHERE NOT EXISTS (\r\nSELECT 0 FROM\r\nst_map_plain p\r\n,st_map_data_plain d\r\nWHERE\r\np.point_id=sPOINT_ID(j) AND p.ml_id=:1 AND\r\np.ma_enabled=1 AND p.ma_auto_check=1 AND p.ma_auto_null_act=1 AND p.map_enabled=1\r\nAND p.map_id=d.map_id(+) AND r.bt=d.mt_time(+)\r\nAND r.bt>=p.bt AND r.bt<Nvl(p.et,r.bt+1)\r\nAND Nvl(d.mt_success,0)=0\r\n)\r\n) f,mou u, TABLE (SELECT CAST(COLLECT(level) AS sql_objects) FROM dual connect by level<=(ROUND(\r\n(CASE\r\nWHEN f.et=trunc(f.et, \'HH\')\r\nTHEN f.et\r\nELSE TRUNC(f.et, \'HH\')+1/24\r\nEND\r\n - TRUNC (f.bt, \'HH\')) * 24, 6))) w WHERE sPOINT_ID(j)=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null) h\r\nGROUP BY ib HAVING Round(Sum(l),6)=1;\r\nSELECT d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 and aggs_type_id=f.id8 AND pl_t=f.d2 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(31, 'HOUR_AVG_FROM_INSTANT', 'Vidutinių rodmenų per valandą generavimas iš momentinių rodmenų', 'Vidutinių rodmenų per valandą generavimas iš momentinių rodmenų', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npNR T7.IRR;\r\nmi NUMBER;\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nfrom GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n FROM spty\r\n WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(bt,\'HH\') t,Avg(val) v,\r\nCASE WHEN (\r\nTRUNC(bt,\'HH\')+1/24<SYSDATE AND Count(DISTINCT(Trunc((bt - TRUNC(bt, \'HH\'))*24*4)))\r\n>=4) THEN \'1\' ELSE \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,Trunc(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(46, 'NOT.IN.ALL.ROOT', 'Taškai, nepasiekiami per apskaitos taškų medį', 'Taškai, nepasiekiami per apskaitos taškų medį', NULL, NULL, 'select point_id from st_point p where not exists (select 0 from st_grcj a join st_grp b on a.comp_id=b.gr_id where a.cont_code = \'ALL.ROOT\' and b.point_id = p.point_id and not a.comp_code in (\'NOT.IN.ALL.ROOT\',\'ALL.POINTS\'))', NULL, NULL, 1),
	(61, 'ADD_NEW_ELEMENTS_FOR_TOTALS_GENERATION', 'Naujų generuojamų suminių matavimų elementų įtraukimas naujiems taškams', 'Naujų generuojamų suminių matavimų elementų įtraukimas naujiems taškams', 'a VARCHAR2(250);', 'FOR t IN (\r\nSELECT s.src_id,p.sp_id FROM src s join sp p ON s.src_id=p.src_id\r\nWHERE src_type_id=0 AND src_name IN\r\n(SELECT bga_type_name FROM bga_type WHERE bga_type_code=\'INSTANT_TOTALS_FROM_ADJACENT_TOTALS\')\r\n) LOOP\r\nFOR n IN (\r\nSELECT b.di_id FROM\r\npl a\r\njoin di b ON a.pl_id=b.pl_id\r\njoin ml c ON a.ml_id=c.ml_id\r\njoin se e ON b.di_id=e.di_id\r\njoin src d ON e.src_id=d.src_id\r\nWHERE src_enabled=1 AND src_et IS NULL\r\nAND pl_enabled=1 AND di_enabled=1\r\nAND se_enabled=1\r\nAND aggs_id=8 AND aggf_id=2 AND md_id=7\r\nAND EXISTS (SELECT 0 FROM sep where se_id=e.se_id AND sep_enabled=1)\r\nMINUS\r\nSELECT di_id FROM se WHERE src_id=t.src_id\r\n) LOOP\r\na:=se_i(t.src_id,n.di_id,null,null,null,1,0,1,4,2,null);\r\nFOR v IN (SELECT * FROM se WHERE src_id=t.src_id AND di_id=n.di_id) LOOP\r\na:=sep_ui(v.SE_ID,t.SP_ID,1,1);\r\nEND LOOP;\r\nEND LOOP;\r\nEND LOOP;\r\n', NULL, NULL, NULL, 26),
	(62, 'INSTANT_TOTALS_FROM_ADJACENT_TOTALS', 'Suminių rodmenų proporcingas generavimas iš gretimų reikšmių', 'Suminių rodmenų proporcingas generavimas iš gretimų reikšmių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nc_DATA DATE := SYSDATE;\r\nc_ROWS SYS_REFCURSOR;', 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n              FROM spty\r\n             WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nDELETE FROM GEN_ADJ$F0;\r\nIF Nvl(:7,\'0\')=1 THEN\r\n  INSERT INTO GEN_ADJ$F0\r\n  SELECT *\r\n    FROM ADJ_TOTALS_F\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:3) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND (:2 IS NULL OR ml_id=:2)\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL, NULL, pl_id, sep_id, da, \'\', v, 1, s, c_DATA, \'\'\r\n         FROM GEN_TOTALS_FROM_ADJ_TOTALS;\r\nELSE\r\n  INSERT INTO GEN_ADJ$F0\r\n  SELECT *\r\n    FROM ADJ_TOTALS\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:3) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND (:2 IS NULL OR ml_id=:2)\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL, NULL, pl_id, sep_id, da, \'\', v, 0, s, c_DATA, \'\'\r\n         FROM GEN_TOTALS_FROM_ADJ_TOTALS;\r\nEND IF;\r\nLOOP\r\n  FETCH c_ROWS\r\n   BULK COLLECT\r\n   INTO pPCK_T, pPCK_N , pPL_ID, pSEP_ID, pT, pDST, pV, pFORCED, pS, pRT, pRDST\r\n  LIMIT pGF;\r\n  EXIT WHEN pPL_ID.COUNT = 0;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(81, 'FROZEN_GR_DAY_DATA', 'Užfiksuoti grupių matavimų parų archyvų duomenys', 'Užfiksuoti grupių matavimų parų archyvų duomenys', NULL, 'MERGE INTO f_ar_g o\r\nUSING (select * from V_AR_GT where gr_type_code=:7 and ML_ID=:1\r\nAND DA>=Nvl(:4,Trunc(SYSDATE)-:2-:6)\r\nAND DA<=Nvl(:5,Trunc(SYSDATE)-:6-1)\r\nAND (:3 IS NULL OR gr_id=:3)\r\n) S\r\nON (o.gr_id=s.gr_id AND o.ml_id=S.ml_id AND o.bt=s.bt)\r\nWHEN MATCHED THEN UPDATE SET\r\no.val=s.val\r\n,o.val_prc=s.val_prc\r\n,o.val_prc_limit=s.val_prc_limit\r\n,o.has_act=s.has_act\r\n,o.has_specific_dstatus=s.has_specific_dstatus\r\n,o.dstatus=s.dstatus\r\n,o.read_time=s.read_time\r\n,o.val_input=s.val_input\r\n,o.has_input_act=s.has_input_act\r\n,o.has_input_specific_dstatus=s.has_input_specific_dstatus\r\n,o.dstatus_input=s.dstatus_input\r\n,o.read_time_input=s.read_time_input\r\n,o.val_output=s.val_output\r\n,o.has_output_act=s.has_output_act\r\n,o.has_output_specific_dstatus=s.has_output_specific_dstatus\r\n,o.dstatus_output=s.dstatus_output\r\n,o.read_time_output=s.read_time_output\r\n,o.tff_id=s.tff_id\r\n,o.extreme_bt=s.extreme_bt\r\n,o.extreme_et=s.extreme_et\r\n,o.extreme_input_bt=s.extreme_input_bt\r\n,o.extreme_input_et=s.extreme_input_et\r\n,o.extreme_output_bt=s.extreme_output_bt\r\n,o.extreme_output_et=s.extreme_output_et\r\n,o.extreme_prc_bt=s.extreme_prc_bt\r\n,o.extreme_prc_et=s.extreme_prc_et\r\n,o.extreme_prc_limit_bt=s.extreme_prc_limit_bt\r\n,o.extreme_prc_limit_et=s.extreme_prc_limit_et\r\nWHERE\r\ndecode(o.val,s.val,0,1)\r\n+decode(o.val_prc,s.val_prc,0,1)\r\n+decode(o.val_prc_limit,s.val_prc_limit,0,1)\r\n+decode(o.has_act,s.has_act,0,1)\r\n+decode(o.has_specific_dstatus,s.has_specific_dstatus,0,1)\r\n+decode(o.dstatus,s.dstatus,0,1)\r\n+decode(o.read_time,s.read_time,0,1)\r\n+decode(o.val_input,s.val_input,0,1)\r\n+decode(o.has_input_act,s.has_input_act,0,1)\r\n+decode(o.has_input_specific_dstatus,s.has_input_specific_dstatus,0,1)\r\n+decode(o.dstatus_input,s.dstatus_input,0,1)\r\n+decode(o.read_time_input,s.read_time_input,0,1)\r\n+decode(o.val_output,s.val_output,0,1)\r\n+decode(o.has_output_act,s.has_output_act,0,1)\r\n+decode(o.has_output_specific_dstatus,s.has_output_specific_dstatus,0,1)\r\n+decode(o.dstatus_output,s.dstatus_output,0,1)\r\n+decode(o.read_time_output,s.read_time_output,0,1)\r\n+decode(o.tff_id,s.tff_id,0,1)\r\n+decode(o.extreme_bt,s.extreme_bt,0,1)\r\n+decode(o.extreme_et,s.extreme_et,0,1)\r\n+decode(o.extreme_input_bt,s.extreme_input_bt,0,1)\r\n+decode(o.extreme_input_et,s.extreme_input_et,0,1)\r\n+decode(o.extreme_output_bt,s.extreme_output_bt,0,1)\r\n+decode(o.extreme_output_et,s.extreme_output_et,0,1)\r\n+decode(o.extreme_prc_bt,s.extreme_prc_bt,0,1)\r\n+decode(o.extreme_prc_et,s.extreme_prc_et,0,1)\r\n+decode(o.extreme_prc_limit_bt,s.extreme_prc_limit_bt,0,1)\r\n+decode(o.extreme_prc_limit_et,s.extreme_prc_limit_et,0,1)\r\n>0\r\nWHEN NOT MATCHED THEN INSERT (\r\no.gr_id\r\n,o.ml_id\r\n,o.bt\r\n,o.val\r\n,o.val_prc\r\n,o.val_prc_limit\r\n,o.has_act\r\n,o.has_specific_dstatus\r\n,o.dstatus\r\n,o.read_time\r\n,o.val_input\r\n,o.has_input_act\r\n,o.has_input_specific_dstatus\r\n,o.dstatus_input\r\n,o.read_time_input\r\n,o.val_output\r\n,o.has_output_act\r\n,o.has_output_specific_dstatus\r\n,o.dstatus_output\r\n,o.read_time_output\r\n,o.tff_id\r\n,o.extreme_bt\r\n,o.extreme_et\r\n,o.extreme_input_bt\r\n,o.extreme_input_et\r\n,o.extreme_output_bt\r\n,o.extreme_output_et\r\n,o.extreme_prc_bt\r\n,o.extreme_prc_et\r\n,o.extreme_prc_limit_bt\r\n,o.extreme_prc_limit_et\r\n) VALUES (\r\n s.gr_id\r\n,s.ml_id\r\n,s.bt\r\n,s.val\r\n,s.val_prc\r\n,s.val_prc_limit\r\n,s.has_act\r\n,s.has_specific_dstatus\r\n,s.dstatus\r\n,s.read_time\r\n,s.val_input\r\n,s.has_input_act\r\n,s.has_input_specific_dstatus\r\n,s.dstatus_input\r\n,s.read_time_input\r\n,s.val_output\r\n,s.has_output_act\r\n,s.has_output_specific_dstatus\r\n,s.dstatus_output\r\n,s.read_time_output\r\n,s.tff_id\r\n,s.extreme_bt\r\n,s.extreme_et\r\n,s.extreme_input_bt\r\n,s.extreme_input_et\r\n,s.extreme_output_bt\r\n,s.extreme_output_et\r\n,s.extreme_prc_bt\r\n,s.extreme_prc_et\r\n,s.extreme_prc_limit_bt\r\n,s.extreme_prc_limit_et\r\n);', NULL, NULL, NULL, 46),
	(86, 'HOUR_AVG_FROM_5_MIN_AVG', 'Vidutinių rodmenų per valandą generavimas iš vidutinių rodmenų per 5 minutes', 'Vidutinių rodmenų per valandą generavimas iš vidutinių rodmenų per 5 minutes', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(bt,\'HH\') t,Avg(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=12\r\nthen \'1\' else \'14\'||decode(count(*),12,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da,Trunc(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(96, 'HOUR_AVG_FROM_N_MIN_TOTALS', 'Vidutinio debito per valandą rodmenų generavimas iš augančių reikšmių, užfiksuotų kas n minučių', 'Vidutinio debito per valandą rodmenų generavimas iš augančių reikšmių, užfiksuotų kas n minučių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,bt+(nr-1)/24 t,g/(et-bt)/24 v\r\n,CASE WHEN Greatest(h1,h2)=0 AND ((et-bt)*24=1 OR g=0) THEN \'1\' ELSE \'14\' end  s\r\nFROM\r\n(SELECT c1,c2,c3,da,bt, point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val g\r\n,has_specific_dstatus h1\r\n,Lead(has_specific_dstatus) over (PARTITION BY point_id,ml_id ORDER BY da,bt) h2\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2+1))\r\nWHERE NOT val IS NULL AND bt=trunc(bt,\'HH\')\r\n) f,mou u,iger\r\nWHERE f.point_id=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\nAND nr<=round((et-bt)*24,6) ) r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(101, 'PLUS_MINUS_FROM_QUADRANTS', 'Elektros reaktyvinių tiekiamos ir grįžtamos krypčių rodmenų generavimas iš reikšmių pagal kvadrantus', 'Elektros reaktyvinių tiekiamos ir grįžtamos krypčių rodmenų generavimas iš reikšmių pagal kvadrantus', 'y T_VARCHAR2_TAB;\r\n', 'SELECT CAST(COLLECT(\'#PL.SELF.\'||b.ml_id) AS T_VARCHAR2_TAB) INTO y\r\nFROM ml a join ml b ON (b.ms_id=a.ms_id\r\nAND Decode(b.dir_id,5,1,6,1,7,2,8,2)=a.dir_id\r\nAND b.aggs_id=a.aggs_id AND b.aggf_id=a.aggf_id\r\nAND b.tff_id=a.tff_id AND b.md_id=a.md_id\r\n) WHERE a.ml_id=:2;\r\ngenerate_using_formula.run(\'[1]+[2]\'\r\n,:0,:2,:3,:4,:5,:6,:7\r\n,null,y,1);\r\n', NULL, NULL, NULL, 26),
	(106, '30_MIN_AVG_FROM_30_MIN_TOTALS', 'Vidutinio debito per 30 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 30 minučių', 'Vidutinio debito per 30 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 30 minučių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns2 DATE;\r\ns1 T7.DRR;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,ib t\r\n,Sum(q*l)*2 v,Decode(Max(k),0,\'1\',\'14\') s\r\nFROM\r\n(SELECT f.*,g/(et-bt)/48 q, (Least(et,ib+1/48)-Greatest(bt,ib))*48 l\r\n,CASE WHEN et-bt>=2/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM (SELECT da,bt,c1,c2,c3,point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et,\r\nCASE WHEN (bt-trunc(bt,\'HH\'))*24*60 BETWEEN 0 and 29 THEN TRUNC(bt, \'HH\') ELSE TRUNC(bt, \'HH\')+1/48 END ib\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL) f,mou u, TABLE(SELECT CAST(COLLECT(level) AS sql_objects) FROM dual CONNECT BY Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*720,6))/720+(LEVEL-1)/720<f.et) d\r\nwhere f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\n) h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(111, 'AUTO_DELETE_ALL_FROM_PL_DATA', 'Automatinis visų matavimo taškų matavimo linijų duomenų įrašų trynimas', 'Automatinis visų matavimo taškų matavimo linijų duomenų įrašų trynimas', 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA\';\r\nstep number := 0;\r\nst date;', 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data WHERE\r\n PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;', NULL, NULL, NULL, 56),
	(112, 'AUTO_DELETE_ALL_FROM_AUD_DATA', 'Automatinis visų audito įrašų apie duomenų keitimo operacijas, atliktų sistemos vartotojų, trynimas', 'Automatinis visų audito įrašų apie duomenų keitimo operacijas, atliktų sistemos vartotojų, trynimas', 'a DATE;\r\nb DATE;\r\nTS DATE;\r\nrlimit number;', 'RLIMIT:=nvl(:4,10000);\r\nTS:= SYSDATE;\r\nSELECT Nvl((SELECT amp FROM tmst WHERE tmst_code=\'AUTO_DELETE_ALL_FROM_AUD_DATA\'),DATE\'2000-01-01\'),Least(ADD_MONTHS(SYSDATE, -nvl(:2,36)),SYSDATE-1/48) INTO a,b FROM dual;\r\nLOOP\r\ndelete (SELECT db_time FROM au where db_time>=a and db_time<b) WHERE rownum<=RLIMIT;\r\nIF SQL%ROWCOUNT<RLIMIT THEN\r\nMERGE INTO tmst y\r\nUSING (SELECT \'AUTO_DELETE_ALL_FROM_AUD_DATA\' tmst_code,b amp FROM dual) u\r\n   ON (y.tmst_code = u.tmst_code)\r\nWHEN MATCHED THEN UPDATE SET\r\n y.amp= u.amp\r\nWHERE NOT y.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n (\r\n y.tmst_code\r\n,y.amp\r\n) values (\r\n u.tmst_code\r\n,u.amp\r\n);\r\nts:=DATE\'2000-01-01\';\r\nEND IF;\r\nCOMMIT;\r\nEXIT WHEN SYSDATE > TS + nvl(:3,45)/86400;\r\nEND LOOP;', NULL, NULL, NULL, 56),
	(113, 'AUTO_DELETE_ALL_FROM_MAP_DATA', 'Automatinis visų monitoringo priskyrimų automatinio tikrinimo rezultatų įrašų trynimas', 'Automatinis visų monitoringo priskyrimų automatinio tikrinimo rezultatų įrašų trynimas', 'CURRTMST DATE;\r\npMAP_ID T7.IRR;\r\npMT_TIME T7.DRR;\r\nI NUMBER;\r\nJ NUMBER;\r\nTS DATE;\r\nDELETED_ROWS_COUNTF NUMBER;\r\nDELETED_ROWS_COUNT_ALL NUMBER;\r\nANS VARCHAR2(250);\r\nmaximum number;\r\nlimit_for_select number;', ' SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_MAP_DATA\')\r\n , TRUNC ((SYSDATE-interval \'5\' year), \'Y\')) INTO CURRTMST FROM DUAL;\r\nLIMIT_FOR_SELECT:=nvl(:4,10000);\r\nTS := SYSDATE;\r\nDELETED_ROWS_COUNTF := 0;\r\nwhile (not (CURRTMST + nvl(:1,5) / 1440 > SYSDATE-nvl(:2,31) OR SYSDATE > TS + nvl(:3,45) / 86400))\r\nLOOP\r\nSELECT /*+ FIRST_ROWS(10000) */ MAP_ID,MT_TIME BULK COLLECT INTO pMAP_ID, pMT_TIME FROM MAP_DATA\r\nWHERE DB_TIME >= CURRTMST AND DB_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND ROWNUM<= LIMIT_FOR_SELECT;\r\nIF (SQL%FOUND) then\r\nFORALL J IN 1..pMAP_ID.COUNT\r\nDELETE MAP_DATA WHERE (MAP_ID=pMAP_ID(J) and MT_TIME=pMT_TIME (J)) ;\r\nDELETED_ROWS_COUNTF := pMAP_ID.COUNT;\r\nelse\r\nDELETED_ROWS_COUNTF:=0;\r\nEND IF;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then\r\nCURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_MAP_DATA\' ;\r\nIF (SQL%ROWCOUNT) = 0\r\nTHEN\r\nINSERT INTO TMST(TMST_CODE,AMP) select \'AUTO_DELETE_ALL_FROM_MAP_DATA\',CURRTMST from dual\r\nwhere not exists (select 0 from tmst where TMST_CODE=\'AUTO_DELETE_ALL_FROM_MAP_DATA\');\r\nEND IF;\r\nEND IF;\r\nEND LOOP;\r\nCOMMIT;\r\n', NULL, NULL, NULL, 56),
	(114, 'AUTO_DELETE_ALL_FROM_EV', 'Automatinis visų sistemos įvykių įrašų trynimas', 'Automatinis visų sistemos įvykių įrašų trynimas', 'CURRTMST DATE;\r\npEV_ID T7.IRR;\r\npEV_TIME T7.DRR;\r\nI NUMBER;\r\nJ NUMBER;\r\nTS DATE;\r\nDELETED_ROWS_COUNTF NUMBER;\r\nDELETED_ROWS_COUNT_ALL NUMBER;\r\nANS VARCHAR2(250);\r\nmaximum number;\r\nlimit_for_select number;', 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_EV\')\r\n, TRUNC ((SYSDATE-interval \'5\' year), \'Y\')) INTO CURRTMST FROM DUAL;\r\nLIMIT_FOR_SELECT:=nvl(:4,10000);\r\nTS := SYSDATE;\r\nDELETED_ROWS_COUNTF := 0;\r\nwhile (not (CURRTMST + nvl(:1,5) / 1440 > SYSDATE-nvl(:2,31) OR SYSDATE > TS + nvl(:3,45) / 86400))\r\nLOOP\r\nSELECT /*+ FIRST_ROWS(10000) */ EV_ID, EV_TIME BULK COLLECT INTO pEV_ID, pEV_TIME FROM EV\r\nWHERE EV_TIME >= CURRTMST AND EV_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND ROWNUM<= LIMIT_FOR_SELECT;\r\nIF (SQL%FOUND) then\r\nFORALL J IN 1..pEV_ID.COUNT\r\nDELETE EV WHERE EV_ID = pEV_ID(J) AND EV_TIME = pEV_TIME(J);\r\nDELETED_ROWS_COUNTF :=  pEV_ID.COUNT;\r\nelse\r\nDELETED_ROWS_COUNTF:=0;\r\nEND IF;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then\r\nCURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_EV\' ;\r\nIF (SQL%ROWCOUNT = 0)\r\nTHEN\r\nINSERT INTO TMST(TMST_CODE,AMP) select \'AUTO_DELETE_ALL_FROM_EV\',CURRTMST from dual\r\nwhere not exists (select 0 from tmst where TMST_CODE=\'AUTO_DELETE_ALL_FROM_EV\');\r\nEND IF;\r\nEND IF;\r\nEND LOOP;\r\nCOMMIT;\r\n', NULL, NULL, NULL, 56),
	(115, 'AUTO_DELETE_ALL_FROM_RP_LOG', 'Automatinis visų ataskaitų formavimo ir siuntimo žurnalo įrašų trynimas', 'Automatinis visų ataskaitų formavimo ir siuntimo žurnalo įrašų trynimas', 'CURRTMST DATE;\r\nTS DATE;\r\npLIMIT NUMBER;', 'FOR a IN (SELECT CASE WHEN exists (select 0 from USER_TAB_PARTITIONS where TABLE_NAME in (\'RP_LOG\')) THEN 1 ELSE 0 END p FROM dual) LOOP\r\nIF a.p=1 THEN\r\nFOR i IN\r\n(\r\nselect\r\nPARTITION_NAME as RP_LOG,\r\nyr,wk\r\nfrom\r\n(\r\nselect\r\nTABLE_NAME,\r\nPARTITION_NAME,\r\nSUBSTR(PARTITION_NAME,5,4) yr,\r\nTO_NUMBER(SUBSTR(PARTITION_NAME,9,2)) wk,\r\npartition_position\r\nfrom USER_TAB_PARTITIONS\r\nwhere TABLE_NAME IN (\'RP_LOG\')\r\n)\r\nwhere\r\n(yr=TO_CHAR(sysdate-:2,\'YYYY\') and wk<TO_CHAR(sysdate-:2,\'WW\'))\r\nOR\r\n(yr<TO_CHAR(sysdate-:2,\'YYYY\'))\r\norder by 2,3\r\n)\r\nLOOP\r\nif i.RP_LOG IS NOT NULL THEN EXECUTE IMMEDIATE \'alter table RP_LOG drop partition \'||i.RP_LOG;\r\nUPDATE TMST A SET A.AMP = Least(Add_Months(TO_DATE(TO_CHAR(i.YR)||\'.01.01\',\'YYYY.MM.DD\'),12),TO_DATE(TO_CHAR(i.YR)||\'.01.01\',\'YYYY.MM.DD\')+i.wk*7)\r\nWHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_RP_LOG\';\r\ncommit; end if;\r\nEND LOOP;\r\nELSE\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=\'AUTO_DELETE_ALL_FROM_RP_LOG\')\r\n,TRUNC((SYSDATE-interval \'5\' year),\'Y\')) INTO CURRTMST FROM DUAL;\r\npLIMIT:=nvl(:4,10000);\r\nTS:= SYSDATE;\r\nwhile not (CURRTMST+nvl(:1,5)/1440 > ADD_MONTHS(SYSDATE,-nvl(:2,36)) OR SYSDATE>TS+nvl(:3,45)/86400)\r\nLOOP\r\nDELETE rp_log\r\nWHERE DB_TIME>=CURRTMST AND DB_TIME<CURRTMST+nvl(:1,5)/1440\r\nAND ROWNUM<=pLIMIT;\r\nif SQL%rowcount<pLIMIT then\r\nCURRTMST:=CURRTMST+nvl(:1,5)/1440;\r\nMERGE INTO tmst y\r\nUSING (SELECT \'AUTO_DELETE_ALL_FROM_RP_LOG\' TMST_CODE,CURRTMST AMP FROM dual) u\r\nON (y.tmst_code = u.tmst_code)\r\nWHEN MATCHED THEN UPDATE SET y.amp=u.amp WHERE NOT y.amp=u.amp\r\nWHEN NOT MATCHED THEN INSERT (y.tmst_code,y.amp) values (u.tmst_code,u.amp);\r\nEND IF;\r\nCOMMIT;\r\nEND LOOP;\r\nEND IF;\r\nEND LOOP;', NULL, NULL, NULL, 56),
	(116, 'AUTO_DELETE_ALL_FROM_RODO', 'Automatinis visų nuskaitymų pagal pareikalavimą užsakymų įrašų trynimas', 'Automatinis visų nuskaitymų pagal pareikalavimą užsakymų įrašų trynimas', 's number(1);', NULL, 'SELECT table_name,part FROM hmp WHERE table_name IN (\'RODO\') AND amp< SYSDATE-:2 ORDER BY amp', 's:=0;\r\nBEGIN\r\nexecute immediate \'truncate table \'||c.table_name||\'#\'||c.part||\'_OPTY\';\r\nexecute immediate \'alter table \'||c.table_name||\'#\'||c.part||\'_OPTY \'||\r\n \'disable constraint RODO\'||c.part||\'_OPTY_RODO_FK\';\r\nexecute immediate \'truncate table \'||c.table_name||\'#\'||c.part;\r\nexecute immediate \'alter table \'||c.table_name||\'#\'||c.part||\'_OPTY \'||\r\n \'enable constraint RODO\'||c.part||\'_OPTY_RODO_FK\';\r\ns:=1;\r\nEXCEPTION WHEN OTHERS THEN NULL;\r\nEND;\r\nIF s=1 THEN\r\nUPDATE hmp SET amp=SYSDATE + :2/2 + 1 WHERE table_name=c.table_name AND part=c.part;\r\nEND IF;', NULL, 56),
	(117, 'AUTO_DELETE_INVALID_FROM_PL_DATA', 'Automatinis negaliojančių matavimo taškų matavimo linijų duomenų įrašų trynimas', 'Automatinis negaliojančių matavimo taškų matavimo linijų duomenų įrašų trynimas', 'CURRTMST DATE;\r\nTS DATE;\r\nep INTEGER;\r\nbtc VARCHAR(250):=\'AUTO_DELETE_INVALID_FROM_PL_DATA\';', 'SELECT CASE WHEN exists (select 0 from USER_TAB_PARTITIONS where TABLESPACE_NAME like \'EMCOS_%\'\r\nAND TABLE_NAME = \'PL_DATA_NV\') THEN 1 ELSE 0 END INTO ep FROM dual;\r\nIF ep=1 THEN\r\nfor i in (select\r\nTABLE_NAME tn,\r\nPARTITION_NAME pname,\r\nADD_MONTHS(TO_DATE(SUBSTR(PARTITION_NAME, 5, 11)||\'01\', \'YYYYMMDD\'),1) dt\r\nfrom USER_TAB_PARTITIONS\r\nwhere TABLE_NAME IN (\'PL_DATA_NV\',\'PL_DATA_EXT_NV\') order by 1) LOOP\r\nif i.dt < SYSDATE-nvl(:2,31)\r\nTHEN\r\n--disable FK\r\nDELETE gtts;\r\nINSERT INTO gtts (id0,c1)\r\nSELECT ts_id,\r\n\'alter table ||table_name|| modify constraint ||constraint_name|| \'||Decode(ts_id,0,\'disable\',\'enable novalidate\')\r\nFROM (\r\nSELECT table_name,constraint_name FROM user_constraints a\r\nWHERE LEVEL=2\r\nCONNECT BY PRIOR constraint_name=r_constraint_name AND PRIOR constraint_type = \'P\' AND constraint_type=\'R\'\r\nSTART WITH table_name IN (\'PL_DATA_NV\')\r\n), ts;\r\n-- disable FK\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=0) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nEXECUTE IMMEDIATE \'alter table \'||i.tn||\' drop partition \'||i.pname;\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=1) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,i.dt amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n(\r\n y.tmst_code\r\n,y.amp\r\n) values (\r\n u.tmst_code\r\n,u.amp\r\n);\r\nend if;END LOOP;\r\nELSE\r\nSELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE=btc)\r\n,TRUNC ((SYSDATE-interval \'5\' year),\'Y\')) INTO CURRTMST FROM DUAL;\r\nTS := SYSDATE;\r\nwhile (not (CURRTMST+nvl(:1,5)/1440 > (SYSDATE-nvl(:2,31)) OR SYSDATE > TS+nvl(:3,45)/86400))LOOP\r\nDELETE PL_DATA_NV WHERE DB_TIME<CURRTMST+nvl(:1,5)/1440 AND ROWNUM<=nvl(:4,10000);\r\nIF SQL%ROWCOUNT=0 then\r\nCURRTMST := CURRTMST+nvl(:1,5)/1440;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,CURRTMST amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n(\r\n y.tmst_code\r\n,y.amp\r\n) values (\r\n u.tmst_code\r\n,u.amp\r\n);\r\nEND IF;\r\nCOMMIT;\r\nEND LOOP;\r\nEND IF;', NULL, NULL, NULL, 56),
	(118, 'AUTO_DELETE_ALL_FROM_CP', 'Automatinis visų uždaromų periodų įrašų trynimas', 'Automatinis visų uždaromų periodų įrašų trynimas', 'CURRTMST DATE;\r\npPER_ID T7.IRR;\r\npPOINT_ID T7.IRR;\r\npCP_T T7.DRR;\r\nI NUMBER;\r\nJ NUMBER;\r\nTS DATE;\r\nDELETED_ROWS_COUNTF NUMBER;\r\nDELETED_ROWS_COUNT_ALL NUMBER;\r\nANS VARCHAR2(250);\r\nmaximum number;\r\nlimit_for_select number;', 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_CP\')\r\n , TRUNC ((SYSDATE-interval \'5\' year), \'Y\')) INTO CURRTMST FROM DUAL;\r\nLIMIT_FOR_SELECT:=nvl(:4,10000);\r\nTS := SYSDATE;\r\nDELETED_ROWS_COUNTF := 0;\r\nwhile ( not (CURRTMST + nvl(:1,5) / 1440 > ADD_MONTHS(SYSDATE, -nvl(:2,36)) OR SYSDATE > TS + nvl(:3,45) / 86400))\r\nLOOP\r\nSELECT /*+ FIRST_ROWS(10000) */ PER_ID, POINT_ID, CP_T BULK COLLECT INTO pPER_ID, pPOINT_ID, pCP_T FROM CP\r\nWHERE CP_T >= CURRTMST AND CP_T < CURRTMST + nvl(:1,5) / 1440\r\nAND ROWNUM<= LIMIT_FOR_SELECT;\r\nIF (SQL%FOUND) then\r\nFORALL J IN 1..pPER_ID.COUNT\r\nDELETE CP WHERE ( PER_ID = pPER_ID(J) and POINT_ID = pPOINT_ID(J) and CP_T = pCP_T(J) ) ;\r\nDELETED_ROWS_COUNTF := pPER_ID.COUNT;\r\nelse\r\nDELETED_ROWS_COUNTF:=0;\r\nEND IF;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then\r\nCURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_CP\' ;\r\nIF (SQL%ROWCOUNT = 0)\r\nTHEN\r\nINSERT INTO TMST (TMST_CODE,AMP) select \'AUTO_DELETE_ALL_FROM_CP\',CURRTMST from dual\r\nwhere not exists (select 0 from tmst where TMST_CODE=\'AUTO_DELETE_ALL_FROM_CP\');\r\nEND IF;\r\nEND IF;\r\nEND LOOP;\r\nCOMMIT;\r\n', NULL, NULL, NULL, 56),
	(119, 'AUTO_DELETE_INVALID_FROM_DS_DATA', 'Automatinis negaliojančių apskaitos būsenų duomenų įrašų trynimas', 'Automatinis negaliojančių apskaitos būsenų duomenų įrašų trynimas', 'CURRTMST DATE;\r\nTS DATE;\r\npLIMIT NUMBER;', 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_INVALID_FROM_DS_DATA\')\r\n      ,TRUNC ((SYSDATE - INTERVAL \'5\' YEAR), \'Y\'))\r\n  INTO CURRTMST\r\n  FROM DUAL;\r\npLIMIT := NVL(:4,10000);\r\nTS := SYSDATE;\r\nWHILE ( NOT (CURRTMST + NVL(:1,5) / 1440 > (SYSDATE-NVL(:2,31)) OR SYSDATE > TS + NVL(:3,45) / 86400))\r\nLOOP\r\n  DELETE DS_DATA_NV a\r\n   WHERE a.ds_t >= CURRTMST AND a.ds_t < CURRTMST + NVL(:1,5) / 1440\r\n     AND EXISTS (SELECT 0\r\n                   FROM ds_data_intervals\r\n                  WHERE ds_id = a.ds_id\r\n                    AND a.ds_t > ds_bt\r\n                    AND a.ds_t < NVL( ds_et, CAST(DATE\'9999-12-31\' AS TIMESTAMP(3))))\r\n     AND ROWNUM <= pLIMIT;\r\n  IF SQL%ROWCOUNT<pLIMIT THEN\r\n    CURRTMST := CURRTMST + NVL(:1,5) / 1440;\r\n    MERGE INTO TMST y\r\n    USING (SELECT \'AUTO_DELETE_INVALID_FROM_DS_DATA\' TMST_CODE, CURRTMST amp\r\n             FROM dual) u\r\n       ON (y.TMST_CODE = u.TMST_CODE)\r\n     WHEN MATCHED THEN UPDATE SET y.amp = u.amp WHERE NOT y.amp = u.amp\r\n     WHEN NOT MATCHED THEN INSERT ( y.tmst_code, y.amp) VALUES ( u.tmst_code, u.amp);\r\n  END IF;\r\n  COMMIT;\r\nEND LOOP;', NULL, NULL, NULL, 56),
	(120, 'AUTO_DELETE_ALL_FROM_DS_DATA', 'Automatinis visų apskaitos būsenų duomenų įrašų trynimas', 'Automatinis visų apskaitos būsenų duomenų įrašų trynimas', 'CURRTMST  DATE;\r\nTS        DATE;\r\npLIMIT    NUMBER;', 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_DS_DATA\')\r\n      ,TRUNC ((SYSDATE-interval \'5\' year), \'Y\'))\r\n  INTO CURRTMST\r\n  FROM DUAL;\r\npLIMIT := NVL(:4,10000);\r\nTS := SYSDATE;\r\nWHILE (NOT (CURRTMST + NVL(:1,5) / 1440 > ADD_MONTHS(SYSDATE, -NVL(:2,36)) OR SYSDATE > TS + NVL(:3,45) / 86400))\r\nLOOP\r\n  DELETE DS_DATA_NV a\r\n   WHERE a.ds_t >= CURRTMST AND a.ds_t < CURRTMST + NVL(:1,5) / 1440\r\n     AND EXISTS (SELECT 0\r\n                   FROM ds_data_intervals\r\n                  WHERE ds_id = a.ds_id\r\n                    AND a.ds_t > ds_bt\r\n                    AND a.ds_t < NVL( ds_et, CAST(DATE\'9999-12-31\' AS TIMESTAMP(3))))\r\n     AND ROWNUM <= pLIMIT;\r\n  IF SQL%ROWCOUNT<pLIMIT THEN\r\n    CURRTMST := CURRTMST + NVL(:1,5) / 1440;\r\n    MERGE INTO TMST y\r\n    USING (SELECT \'AUTO_DELETE_ALL_FROM_DS_DATA\' TMST_CODE, CURRTMST amp\r\n             FROM dual) u\r\n       ON (y.TMST_CODE = u.TMST_CODE)\r\n     WHEN MATCHED THEN UPDATE SET y.amp = u.amp WHERE NOT y.amp = u.amp\r\n     WHEN NOT MATCHED THEN INSERT ( y.tmst_code, y.amp) VALUES ( u.tmst_code, u.amp);\r\n  END IF;\r\n  COMMIT;\r\nEND LOOP;', NULL, NULL, NULL, 56),
	(121, 'AUTO_DELETE_ALL_FROM_EVAH', 'Automatinis visų užfiksuotų įvykių atvejų istorijos įrašų trynimas', 'Automatinis visų užfiksuotų įvykių atvejų istorijos įrašų trynimas', 'CURRTMST DATE;\r\npEVA_ID T7.IRR;\r\npEV_ID T7.IRR;\r\nI NUMBER;\r\nJ NUMBER;\r\nTS DATE;\r\nDELETED_ROWS_COUNTF NUMBER;\r\nDELETED_ROWS_COUNT_ALL NUMBER;\r\nANS VARCHAR2(250);\r\nmaximum number;\r\nlimit_for_select number;\r\npEV_TIME T7.DRR;\r\n', 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_EVAH\')\r\n , TRUNC ((SYSDATE-interval \'5\' year), \'Y\')) INTO CURRTMST FROM DUAL;\r\nLIMIT_FOR_SELECT:=nvl(:4,10000);\r\nTS := SYSDATE;\r\nDELETED_ROWS_COUNTF := 0;\r\nwhile (not (CURRTMST + nvl(:1,5) / 1440 > SYSDATE-nvl(:2,31)  OR SYSDATE > TS + nvl(:3,45) / 86400))\r\nLOOP\r\nSELECT /*+ FIRST_ROWS(10000) */ EVA_ID, EV_ID, EV_TIME BULK COLLECT INTO pEVA_ID, pEV_ID, pEV_TIME FROM EVAH\r\nWHERE DB_TIME >= CURRTMST AND DB_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND ROWNUM<= LIMIT_FOR_SELECT;\r\nIF (SQL%FOUND) then\r\nFORALL J IN 1..pEVA_ID.COUNT\r\nDELETE EVAH WHERE ( EVA_ID = pEVA_ID(J) and  EV_ID = pEV_ID (J) and EV_TIME=pEV_TIME(J)) ;\r\nDELETED_ROWS_COUNTF := pEVA_ID.COUNT;\r\nelse\r\nDELETED_ROWS_COUNTF:=0;\r\nEND IF;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then\r\nCURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_EVAH\' ;\r\nIF (SQL%ROWCOUNT = 0)\r\nTHEN\r\nINSERT INTO TMST(TMST_CODE,AMP) select \'AUTO_DELETE_ALL_FROM_EVAH\',CURRTMST from dual\r\nwhere not exists (select 0 from tmst where TMST_CODE=\'AUTO_DELETE_ALL_FROM_EVAH\');\r\nEND IF;\r\nEND IF;\r\nEND LOOP;\r\nCOMMIT;\r\n', NULL, NULL, NULL, 56),
	(126, 'AUTO_DELETE_ALL_FROM_PL_DATA_INSTANT', 'Automatinis visų matavimo taškų matavimo linijų momentinių duomenų įrašų trynimas', 'Automatinis visų matavimo taškų matavimo linijų momentinių duomenų įrašų trynimas', 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_INSTANT\';\r\nstep number := 0;\r\nst date;', 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=SYSDATE-nvl(:2,31)\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_type_id=6) using (ml_id) WHERE\r\n PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;', NULL, NULL, NULL, 56),
	(127, 'AUTO_DELETE_ALL_FROM_PL_DATA_MINUTE', 'Automatinis visų matavimo taškų matavimo linijų minutinių duomenų įrašų trynimas', 'Automatinis visų matavimo taškų matavimo linijų minutinių duomenų įrašų trynimas', 'lmt number;\r\ncurrtmst date;\r\nstep number := 0;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_MINUTE\';\r\nst date;', 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=SYSDATE-nvl(:2,31)\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_type_id=1) using (ml_id) WHERE\r\n PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;', NULL, NULL, NULL, 56),
	(131, 'DAY_SUM_OF_ALL_TARIFFS', 'Paros sumos rodmenų generavimas iš visų paros tarifų sumų', 'Paros sumos rodmenų generavimas iš visų paros tarifų sumų', 'y T_VARCHAR2_TAB;', 'SELECT CAST(COLLECT(\'#PL.SELF.\'||ml_id) AS T_VARCHAR2_TAB) INTO y\r\nFROM ml WHERE (ms_id,dir_id,aggs_id,aggf_id,md_id) IN\r\n(SELECT ms_id,dir_id,aggs_id,aggf_id,md_id FROM ml WHERE ml_id=:1) AND tff_id BETWEEN 1 AND 4;\r\ngenerate_using_formula.run(\'[1]+[2]+[3]+[4]\'\r\n,:0,:2,:3,:4,:5,:6,:7\r\n,null,y,1);\r\n', NULL, NULL, NULL, 26),
	(132, 'MONTH_SUM_OF_ALL_TARIFFS', 'Mėnesio sumos rodmenų generavimas iš mėnesio visų tarifų sumų', 'Mėnesio sumos rodmenų generavimas iš mėnesio visų tarifų sumų', 'y T_VARCHAR2_TAB;', 'SELECT CAST(COLLECT(\'#PL.SELF.\'||ml_id) AS T_VARCHAR2_TAB) INTO y\r\nFROM ml WHERE (ms_id,dir_id,aggs_id,aggf_id,md_id) IN\r\n(SELECT ms_id,dir_id,aggs_id,aggf_id,md_id FROM ml WHERE ml_id=:1) AND tff_id BETWEEN 1 AND 4;\r\ngenerate_using_formula.run(\'[1]+[2]+[3]+[4]\'\r\n,:0,:2,:3*31,:4,:5,:6,:7\r\n,null,y,1);\r\n', NULL, NULL, NULL, 26),
	(136, 'ANY_AVG_FROM_ANY_MIN_AVG_OR_SUM', 'Stambesnių intervalų (iki paros) vidurkių skaičiavimas iš smulkesnių intervalų', 'Stambesnių intervalų (iki paros) vidurkių skaičiavimas iš smulkesnių intervalų', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\ngf1 NUMBER(2);\r\ncnt1 number(5);\r\ncnt2 number(5);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT /*+ materialize*/\r\nSEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nSELECT md_cnt,aggf_id\r\nINTO cnt1,gf1\r\nFROM st_ml\r\nWHERE ml_id=:1;\r\nSELECT md_cnt\r\nINTO cnt2\r\nFROM st_ml\r\nWHERE ml_id=:2;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da+Trunc(Round((bt-da)*cnt2,6))/cnt2 t,Avg(val*Decode(gf1,3,1,cnt1/24)) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0 and count(*)*cnt2=cnt1\r\nthen \'1\' else \'14\'||decode(count(*)*cnt2,cnt1,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da,da+Trunc(Round((bt-da)*cnt2,6))/cnt2 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(137, 'HOUR_AVG_FROM_HOUR_AVG_AND_TARIFF_TOTALS', 'Vidutinės galios per valandą rodmenų generavimas iš esamų valandinių reikšmių ir augančių reikšmių pagal tarifus', 'Vidutinės galios per valandą rodmenų generavimas iš esamų valandinių reikšmių ir augančių reikšmių pagal tarifus', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nL T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID ,aggs_type_id\r\nfrom GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 'SELECT ml_id BULK COLLECT INTO L FROM ml WHERE (ms_id,dir_id,aggs_id,aggf_id,md_id) IN\r\n(SELECT ms_id,dir_id,aggs_id,aggf_id,md_id FROM ml WHERE ml_id=:1) AND tff_id IN (1,2,3,4);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nDELETE gtts;\r\nFORALL j IN 1..sPL_ID.count\r\nINSERT INTO gtts (id1,d1,d2,v1)\r\nSELECT point_id,da,Max(bt),Sum(val)\r\nFROM ( SELECT point_id,ml_id,da,bt,val,Rank() over (PARTITION BY point_id,ml_id,da,Trunc(bt,\'MI\') ORDER BY bt) rnk\r\nFROM v_ar\r\nWHERE point_id=sPOINT_ID(j)\r\nAND ml_id IN (L(1),L(2),L(3),L(4))\r\nAND da>=Nvl(:4,SYSDATE-:3) AND da<=Nvl(:5,SYSDATE)\r\nAND NOT val IS NULL )\r\nWHERE rnk=1\r\nGROUP BY point_id,da,Trunc(bt,\'MI\')\r\nHAVING Count(*)=4;\r\nDELETE gttt;\r\nFORALL j IN 1..sPL_ID.count\r\nINSERT INTO gttt\r\n(d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT NULL,NULL,sPL_ID(j),sSEP_ID(j),bt\r\n,\'\',Sum(q*l),Nvl(:7,0),\'1\',SYSDATE,\'\',sAGGS_TYPE_ID(j)\r\nFROM (SELECT f.*,bt,greatest(g-\r\nNvl(Sum(Decode(has_specific_dstatus,0,(Least(te,et)-Greatest(tb,bt))*24*val))\r\nover (PARTITION BY id1,tb),0)\r\n,0)/Sum(Decode(has_specific_dstatus,1,(Least(te,et)-Greatest(tb,bt))*24))\r\nover (PARTITION BY id1,tb) q\r\n,Decode(has_specific_dstatus,1,(Least(te,et)-Greatest(tb,bt))*24) l\r\n,CASE WHEN te-tb>=15/24 and not g-\r\nNvl(Sum(Decode(has_specific_dstatus,0,(Least(te,et)-Greatest(tb,bt))*24*val))\r\nover (PARTITION BY id1,tb),0)\r\n=0 THEN 1 ELSE 0 END k\r\nFROM v_ar d,\r\n(SELECT id1,d2 tb\r\n,Lead(d2) over (PARTITION BY id1 ORDER BY d2) te\r\n,Lead(v1) over (PARTITION BY id1 ORDER BY d2)-\r\nCASE WHEN\r\nLead(v1) over (PARTITION BY id1 ORDER BY d2)-v1<-1000\r\n THEN 0 ELSE v1 end g\r\nFROM gtts) f,mou u\r\nWHERE sPOINT_ID(j)=u.point_id (+) AND f.tb<u.mou_bt (+) AND f.te>=u.mou_bt (+) AND u.mou_id IS null\r\nAND d.point_id=sPOINT_ID(j) AND ml_id=:2 AND da>=Nvl(:4,SYSDATE-:3)\r\nAND da<=Nvl(:5,SYSDATE)\r\nAND d.point_id=id1 AND et>tb AND bt<te\r\n) h\r\nGROUP BY bt\r\nHAVING Round(Sum(l),6)=1 AND Max(k)=0;\r\nSELECT d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(151, 'AUTO_DELETE_ALL_FROM_PLEP', 'Automatinis visų taškų matavimų įvertintų periodų įrašų trynimas', 'Automatinis visų taškų matavimų įvertintų periodų įrašų trynimas', 'CURSOR c1 IS\r\nSELECT pl_id,plep_bt FROM plep\r\nWHERE plep_bt<sysdate-Nvl(:1,100);\r\npPL_ID T7.IRR;\r\npPLEP_BT T7.DRR;\r\nTS DATE:=sysdate;\r\n', 'OPEN c1;\r\nLOOP\r\nFETCH c1 BULK COLLECT INTO\r\npPL_ID\r\n,pPLEP_BT\r\nLIMIT 5000;\r\nFORALL j IN 1..pPL_ID.Count\r\nDELETE plep WHERE pl_id = pPL_ID(j) AND plep_bt=pPLEP_BT(j);\r\nEXIT WHEN SQL%rowcount=0 OR SYSDATE>TS+nvl(:2,45)/86400;\r\nCOMMIT;\r\nEND LOOP;', NULL, NULL, NULL, 56),
	(156, 'AUTO_DELETE_ALL_FROM_BGAO', 'Automatinis visų DB aplikacijos foninių užduočių vykdymo užsakymų įrašų trynimas', 'Automatinis visų DB aplikacijos foninių užduočių vykdymo užsakymų įrašų trynimas', 'CURRTMST DATE;\r\npBGAO_ID T7.IRR;\r\nI NUMBER;\r\nJ NUMBER;\r\nTS DATE;\r\nDELETED_ROWS_COUNTF NUMBER;\r\nDELETED_ROWS_COUNT_ALL NUMBER;\r\nANS VARCHAR2(250);\r\nmaximum number;\r\nlimit_for_select number;', 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_BGAO\')\r\n , TRUNC ((SYSDATE-interval \'5\' year), \'Y\'))\r\n INTO CURRTMST FROM DUAL;\r\nLIMIT_FOR_SELECT:=nvl(:4,10000);\r\nTS := SYSDATE;\r\nDELETED_ROWS_COUNTF := 0;\r\nwhile ( not (CURRTMST + nvl(:1,5) / 1440 > SYSDATE - nvl(:2,100) OR SYSDATE > TS + nvl(:3,45) / 86400))\r\nLOOP\r\nSELECT /*+ FIRST_ROWS(10000) */ A.BGAO_ID BULK COLLECT INTO pBGAO_ID FROM BGAO A\r\nWHERE A.DB_TIME >= CURRTMST AND A.DB_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND ROWNUM<= LIMIT_FOR_SELECT;\r\nIF (SQL%FOUND) then\r\nFORALL J IN 1..pBGAO_ID.COUNT\r\nDELETE BGAO WHERE BGAO_ID = pBGAO_ID (J);\r\nDELETED_ROWS_COUNTF := pBGAO_ID.COUNT;\r\nelse\r\nDELETED_ROWS_COUNTF:=0;\r\nEND IF;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then\r\nCURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_BGAO\' ;\r\nIF (SQL%ROWCOUNT = 0)\r\nTHEN\r\nINSERT INTO TMST (TMST_CODE,AMP) select \'AUTO_DELETE_ALL_FROM_BGAO\',CURRTMST from dual\r\nwhere not exists (select 0 from tmst where TMST_CODE=\'AUTO_DELETE_ALL_FROM_BGAO\');\r\nEND IF;\r\nEND IF;\r\nEND LOOP;\r\nCOMMIT;\r\n', NULL, NULL, NULL, 56),
	(161, 'SUM_OF_ALL_TARIFFS', 'Sumos rodmenų generavimas iš visų tarifų sumų', 'Sumos rodmenų generavimas iš visų tarifų sumų', 'y T_VARCHAR2_TAB;', 'SELECT CAST(COLLECT(\'#PL.SELF.\'||ml_id) AS T_VARCHAR2_TAB) INTO y\r\nFROM ml WHERE (ms_id,dir_id,aggs_id,aggf_id,md_id) IN\r\n(SELECT ms_id,dir_id,aggs_id,aggf_id,md_id FROM ml WHERE ml_id=:1) AND tff_id BETWEEN 1 AND 4;\r\ngenerate_using_formula.run(\'[1]+[2]+[3]+[4]\'\r\n,:0,:2,:3,:4,:5,:6,:7\r\n,null,y,1);\r\n', NULL, NULL, NULL, 26),
	(166, 'SPLUS_FROM_PPLUS_QPLUS', 'Elektros pilnosios galios S+ duomenų generavimas iš P+ ir Q+', 'Elektros pilnosios galios S+ duomenų generavimas iš P+ ir Q+', NULL, 'generate_using_formula.run(\r\n\'SQRT(POWER([1],2)+POWER([2],2))\'\r\n,:0,:2,:3,:4,:5,:6,:7\r\n,null\r\n,t_varchar2_tab(:11,:12));', NULL, NULL, NULL, 26),
	(171, '30_MIN_AVG_FROM_INSTANT_TOTALS', 'Vidutinių rodmenų per 30 minučių generavimas iš augančių reikšmių', 'Vidutinių rodmenų per 30 minučių generavimas iš augančių reikšmių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nfrom GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3),Nvl(:5+1,SYSDATE),1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,ib t\r\n,Sum(q*l)*2 v,Decode(Max(k),0,\'1\',\'14\') s\r\nFROM\r\n(SELECT f.*\r\n,Trunc(bt)+Trunc(Round((bt-Trunc(bt))*48,6))/48+(d.column_value-1)/48 ib\r\n,g/(et-bt)/48 q\r\n,(Least(et,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*48,6))/48+(d.column_value)/48)-Greatest(bt,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*48,6))/48+(d.column_value-1)/48))*48 l\r\n,CASE WHEN et-bt>=2/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM (SELECT da,bt, c1,c2,c3,point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),Nvl(:5+1,SYSDATE)))\r\nWHERE  NOT val IS NULL) f,mou u, TABLE(SELECT CAST(COLLECT(level) AS sql_objects) FROM dual CONNECT BY Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*48,6))/48+(LEVEL-1)/48<f.et) d\r\nwhere f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\n) h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(172, 'DAY_SUM_FROM_30_MIN_AVG', 'Paros sumos rodmenų generavimas iš vidutinių rodmenų per 30 minučių', 'Paros sumos rodmenų generavimas iš vidutinių rodmenų per 30 minučių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,sum(val)/2 v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=48\r\nthen \'1\' else \'14\'||decode(count(*),48,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(173, 'DAY_SUM_FROM_INSTANT_TOTALS', 'Paros sumos rodmenų generavimas iš augančių reikšmių', 'Paros sumos rodmenų generavimas iš augančių reikšmių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER; p number; m number;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nfrom GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))FROM spty WHERE spty.spty_code=\'GENERATION_FETCH\'),100)INTO pGF FROM dual;\r\nselect nvl(to_number(:9),0)into p from dual;select md_id into m from ml where ml_id=:1;\r\nif m=5 and p=2 then p:=1; end if; OPEN c_ROWS;LOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID LIMIT pGF; EXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3),Nvl(:5+1,SYSDATE),1);\r\nFOR d IN(SELECT DISTINCT Trunc(s1,\'MI\')s1 FROM gen$p)loop\r\nif p=0 then SELECT \'\',\'\',c1,c2,t,\'\',v,Nvl(:7,0),s,SYSDATE,\'\'\r\nBULK COLLECT INTO pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM(SELECT c1,c2,c3,ib t,\'\',Sum(q*l)v,Decode(Max(k),0,\'1\',\'14\')s\r\nFROM(SELECT f.*,Trunc(bt)+Trunc(Round((bt-Trunc(bt)),6))+(d.column_value-1)ib\r\n,g/(et-bt)q,(Least(et,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt)),6))+(d.column_value))-Greatest(bt,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt)),6))+(d.column_value-1)))l\r\n,CASE WHEN et-bt>=36/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM(SELECT da,bt,c1,c2,c3,point_id,\r\nLead(bt)over(PARTITION BY point_id,ml_id ORDER BY da,bt)et\r\n,Lead(val)over(PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN Lead(val)over(PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\nTHEN 0 ELSE val end g FROM\r\ntable(p_ar.p2(cursor(select point_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM gen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,Nvl(:5+1,SYSDATE)))\r\nWHERE NOT val IS NULL)f,mou u,TABLE(SELECT CAST(COLLECT(level)AS sql_objects)FROM dual CONNECT BY Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt)),6))+(LEVEL-1)<f.et)d\r\nwhere f.POINT_ID=u.point_id(+)AND f.bt<u.mou_bt(+)AND f.et>=u.mou_bt(+)AND u.mou_id IS null)h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists(SELECT 0 FROM pl_data  WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nelse SELECT \'\',\'\',c1,c2,t,\'\',v,Nvl(:7,0),s,SYSDATE,\'\'\r\nBULK COLLECT INTO pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM(SELECT c1,c2,c3,decode(p,1,da-1,2,da)t,\'\',round(delta_val,6)v,s\r\nFROM(SELECT b.*,\r\ncase when(HAS_SPECIFIC_DSTATUS=0 and prev_HAS_SPECIFIC_DSTATUS=0)AND NOT(da=TRUNC(sysdate,\'DD\'))then 1 else 14\r\nend s FROM(SELECT a.*\r\n,val-lag(val)over(PARTITION by point_id,ml_id order by da)delta_val\r\n,lag(val)over(PARTITION by point_id,ml_id order by da)prev_val\r\n,lag(bt)over(PARTITION by point_id,ml_id order by da)prev_bt\r\n,lag(HAS_SPECIFIC_DSTATUS)over(PARTITION by point_id,ml_id order by da)prev_HAS_SPECIFIC_DSTATUS\r\nFROM(SELECT c1,c2,c3,point_id,ml_id,da,bt,val,HAS_SPECIFIC_DSTATUS\r\n,case when p=2 then rank()over(PARTITION by point_id,ml_id,da order by bt desc)\r\nwhen p=1 then rank()over(PARTITION by point_id,ml_id,da order by bt asc)\r\nend rnk\r\nFROM table(p_ar.p2(cursor(select point_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM gen$p WHERE Trunc(s1,\'MI\')=d.s1),d.s1-1,Nvl(:5+1,SYSDATE)+1))\r\nWHERE NOT val IS NULL )a where rnk=1)b,mou u\r\nWHERE b.POINT_ID=u.point_id(+)AND b.prev_bt<u.mou_bt(+)AND b.bt>=u.mou_bt(+)AND u.mou_id IS null\r\n)where delta_val>=0)r\r\n--/7 where not exists(SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;end if;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP; END LOOP; CLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(181, 'AUTO_DELETE_ALL_FROM_XO', 'Automatinis visų apsikeitimo duomenimis operacijų įrašų trynimas', 'Automatinis visų apsikeitimo duomenimis operacijų įrašų trynimas', 'CURRTMST DATE;\r\npXO_ID T7.IRR;\r\nI NUMBER;\r\nJ NUMBER;\r\nTS DATE;\r\nDELETED_ROWS_COUNTF NUMBER;\r\nDELETED_ROWS_COUNT_ALL NUMBER;\r\nANS VARCHAR2(250);\r\nmaximum number;\r\nlimit_for_select number;\r\n', ' SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_XO\')\r\n , TRUNC ((SYSDATE-interval \'5\' year), \'Y\')) INTO CURRTMST FROM DUAL;\r\nLIMIT_FOR_SELECT:=nvl(:4,10000);TS := SYSDATE;DELETED_ROWS_COUNTF := 0;\r\nwhile (not (CURRTMST + nvl(:1,5) / 1440 > (SYSDATE-nvl(:2,150)) OR SYSDATE > TS + nvl(:3,45) / 86400))\r\nLOOP\r\nSELECT /*+ FIRST_ROWS(10000) */ XO_ID BULK COLLECT INTO pXO_ID FROM XO\r\nWHERE XO_TIME >= CURRTMST AND XO_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND ROWNUM<= LIMIT_FOR_SELECT;\r\nIF (SQL%FOUND) then\r\nFORALL J IN 1..pXO_ID.COUNT\r\nDELETE XO WHERE XO_ID = pXO_ID(J);\r\nDELETED_ROWS_COUNTF := pXO_ID.COUNT;\r\nelse\r\nDELETED_ROWS_COUNTF:=0;\r\nEND IF;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then\r\nCURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_XO\' ;\r\nIF (SQL%ROWCOUNT = 0)\r\nTHEN\r\nINSERT INTO TMST (TMST_CODE,AMP) select \'AUTO_DELETE_ALL_FROM_XO\',CURRTMST\r\nfrom dual where not exists (select 0 from tmst where TMST_CODE=\'AUTO_DELETE_ALL_FROM_XO\');\r\nEND IF;\r\nEND IF;\r\nEND LOOP;\r\nCOMMIT;\r\n', NULL, NULL, NULL, 56),
	(182, 'SUM_OF_ALL_TARIFFS_HOUR', 'Sumos rodmenų generavimas iš visų tarifų sumų, fiksuotų kas valandą', 'Sumos rodmenų generavimas iš visų tarifų sumų, fiksuotų kas valandą', 'y T_VARCHAR2_TAB;', 'SELECT CAST(COLLECT(\'#PL.SELF.\'||ml_id) AS T_VARCHAR2_TAB) INTO y\r\nFROM ml WHERE (ms_id,dir_id,aggs_id,aggf_id,md_id) IN\r\n(SELECT ms_id,dir_id,aggs_id,aggf_id,md_id FROM ml WHERE ml_id=:1) AND tff_id BETWEEN 1 AND 4;\r\ngenerate_using_formula.run(\'[1]+[2]+[3]+[4]\'\r\n,:0,:2,:3,:4,:5,:6,:7\r\n,null,y,1);\r\n', NULL, NULL, NULL, 26),
	(183, 'DAY_SUM_FROM_N_MIN_TOTALS', 'Paros sumos rodmenų generavimas iš augančių reikšmių užfiksuotų kas n minučių', 'Paros sumos rodmenų generavimas iš augančių reikšmių užfiksuotų kas n minučių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT /*+ materialize*/\r\nSEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO\r\nsSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,bt+(nr-1) t,g/(et-bt) v\r\n,Decode((et-bt),1,\'1\',\'14\') s\r\nFROM\r\n(SELECT c1,c2,c3,da,bt, point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2+1))\r\nWHERE NOT val IS NULL AND bt=da\r\n) f,mou u,iger\r\nWHERE f.point_id=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\nAND nr<=round((et-bt),6) ) r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(184, 'DELIVERY_POINT_FROM_2_INLETS_WITH_TR_2ND_LINE_LOSS', 'Tiekimo taškų už 2 įvadų su transformatoriais, 2 įvadas nutolęs per liniją, duomenų generavimas', 'Tiekimo taškų už 2 įvadų su transformatoriais, 2 įvadas nutolęs per liniją, duomenų generavimas', NULL, 'generate_using_formula.run(\'[1]+[2]+([3]+[4]*power([1],2)/power([5],2)/power([6],2))+([7]+[8]*power([2],2)/power([9],2)/power([6],2))+(power([2]+([7]+[8]*power([2],2)/power([9],2)/power([6],2)),2)+power(0.75*[2]+([10]+[11]*power([2],2)/power([9],2)/power([6],2)),2))/power([12],2)*[13]*[14]/1000\',:0,:2,:3,:4,:5,:6,:7,:10,t_varchar2_tab(:11,:12,:13,:14,:15,:16,:17,:18,:19,:20,:21,:22,:23,:24));', NULL, NULL, NULL, 26),
	(185, 'DELIVERY_POINT_FROM_MS_POINT_CONSIDERING_LINE_LOSS', 'Tiekimo taškų nutolusių nuo apskaitos taškų per liniją, duomenų generavimas', 'Tiekimo taškų nutolusių nuo apskaitos taškų per liniją, duomenų generavimas', NULL, 'generate_using_formula.run(\'[1]+power([1],2)/power([2],2)/power([3],2)*[4]*[5]/1000\',:0,:2,:3,:4,:5,:6,:7,:10,t_varchar2_tab(:11,:12,:13,:14,:15));', NULL, NULL, NULL, 26),
	(186, 'DELIVERY_POINT_FROM_2_INLETS_WITH_TRANSFORMERS', 'Tiekimo taškų už 2 įvadų su transformatoriais duomenų generavimas', 'Tiekimo taškų už 2 įvadų su transformatoriais duomenų generavimas', NULL, 'generate_using_formula.run(\'[1]+[2]+([3]+[4]*power([1],2)/power([5],2)/power([6],2))+([7]+[8]*power([2],2)/power([9],2)/power([6],2))\',:0,:2,:3,:4,:5,:6,:7,:10,t_varchar2_tab(:11,:12,:13,:14,:15,:16,:17,:18,:19));', NULL, NULL, NULL, 26),
	(187, 'DELIVERY_POINT_FROM_MS_POINT_AND_LINE_LOSS_P2_Q2', 'Tiekimo taškų duomenų generavimas įskaitant linijos nuostolius bei akt. ir reakt. energijos kvadratų sumą', 'Tiekimo taškų duomenų generavimas įskaitant linijos nuostolius bei akt. ir reakt. energijos kvadratų sumą', NULL, 'generate_using_formula.run(\'[1]+(power([1],2)+power([2],2))/power([3],2)*[4]*[5]/1000\',:0,:2,:3,:4,:5,:6,:7,:10,t_varchar2_tab(:11,:12,:13,:14,:15));', NULL, NULL, NULL, 26),
	(188, 'DELIVERY_POINT_FROM_TRANSFORMER_AND_2_INLETS_DATA', 'Tiekimo taškų už 2 įvadų ir transformatoriaus duomenų generavimas', 'Tiekimo taškų už 2 įvadų ir transformatoriaus duomenų generavimas', NULL, 'generate_using_formula.run(\'[1]+[2]*(power([4]+[5],2)/power([3],2)+power([6]+[7],2)/power([3],2))+[4]+[5]\',:0,:2,:3,:4,:5,:6,:7,:10,t_varchar2_tab(:11,:12,:13,:14,:15,:16,:17));', NULL, NULL, NULL, 26),
	(189, 'DELIVERY_POINT_TO_MS_POINT_CONSIDERING_TRANSFORMER', 'Tiekimo taškų duomenų generavimas įskaitant transformatoriaus nuostolius', 'Tiekimo taškų duomenų generavimas įskaitant transformatoriaus nuostolius', NULL, 'generate_using_formula.run(\'[1]+[3]+[4]*(power([1],2)+power([2],2))/power([5],2)\',:0,:2,:3,:4,:5,:6,:7,:10,t_varchar2_tab(:11,:12,:13,:14,:15));', NULL, NULL, NULL, 26),
	(190, 'DELIVERY_POINT_FROM_2_INLETS_WITH_TR_AND_LINE_LOSS', 'Tiekimo taškų už 2 įvadų su transformatoriais, įskaitant linijos nuostolius, duomenų generavimas', 'Tiekimo taškų už 2 įvadų su transformatoriais, įskaitant linijos nuostolius, duomenų generavimas', NULL, 'generate_using_formula.run(\'[1]+[2]+[5]+[6]*(Power([1],2)+Power([3],2))/Power([7],2)+[10]+[11]*(Power([2],2)+Power([4],2))/Power([12],2)+(Power([1]+[2]+[5]+[6]*(Power([1],2)+Power([3],2))/Power([7],2)+[10]+[11]*(Power([2],2)+Power([4],2))/Power([12],2),2)+Power([3]+[4]+[8]+[9]*(Power([1],2)+Power([3],2))/Power([7],2)+[13]+[14]*(Power([2],2)+Power([4],2))/Power([12],2),2))/Power([15],2)*[16]*[17]/1000\',:0,:2,:3,:4,:5,:6,:7,:10,t_varchar2_tab(:11,:12,:13,:14,:15,:16,:17,:18,:19,:20,:21,:22,:23,:24,:25,:26,:27));', NULL, NULL, NULL, 26),
	(191, 'DELIVERY_POINT_TO_MS_POINT_TRANS_AND_LINE_LOSS', 'Tiekimo taškų už transformatoriais, įskaitant linijos nuostolius, duomenų generavimas', 'Tiekimo taškų už transformatoriais, įskaitant linijos nuostolius, duomenų generavimas', NULL, 'generate_using_formula.run(\'[1]+[3]+[4]*(Power([1],2)+Power([2],2))/Power([5],2)+(Power([1]+[3]+[4]*(Power([1],2)+Power([2],2))/Power([5],2),2)+Power([2]+[6]+[7]*(Power([1],2)+Power([2],2))/Power([5],2),2))/Power([8],2)*[9]*[10]/1000\',:0,:2,:3,:4,:5,:6,:7,:10,t_varchar2_tab(:11,:12,:13,:14,:15,:16,:17,:18,:19,:20));', NULL, NULL, NULL, 26),
	(194, 'AUTO_DELETE_REPEATED_DS_DATA', 'Automatinis pasikartojančių apskaitos busenų duomenų įrašų trynimas', 'Automatinis pasikartojančių apskaitos busenų duomenų įrašų trynimas', 'CURRTMST DATE;\r\nTS DATE;\r\npLIMIT number;', 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_REPEATED_DS_DATA\')\r\n,TRUNC ((SYSDATE-interval \'5\' year), \'Y\')) INTO CURRTMST FROM DUAL;\r\npLIMIT:=nvl(:4,10000);\r\nTS := SYSDATE;\r\nwhile ( not (CURRTMST + nvl(:1,60) / 1440 > (SYSDATE-nvl(:2,70)) OR SYSDATE > TS + nvl(:3,45) / 86400))\r\nLOOP\r\nDELETE ds_data b\r\nWHERE ds_t>= CURRTMST AND ds_t < CURRTMST + nvl(:1,60) / 1440\r\nAND EXISTS (SELECT 0 FROM ds_data_intervals WHERE ds_id=b.ds_id\r\nand b.ds_t>ds_bt and b.ds_t<Nvl(ds_et,CAST(DATE\'9999-12-31\' AS TIMESTAMP(3))))\r\nAND ROWNUM<=pLIMIT;\r\nIF SQL%ROWCOUNT<pLIMIT THEN\r\nCURRTMST := CURRTMST + nvl(:1,60) / 1440;\r\nMERGE INTO TMST y\r\nUSING (SELECT \'AUTO_DELETE_REPEATED_DS_DATA\' TMST_CODE, CURRTMST amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET y.amp=u.amp WHERE NOT y.amp=u.amp\r\nWHEN NOT MATCHED THEN INSERT (y.tmst_code,y.amp) values (u.tmst_code,u.amp);\r\nEND IF;\r\nCOMMIT;\r\nEND LOOP;', NULL, NULL, NULL, 56),
	(199, 'DELTA_FROM_DIFFERENCE', 'Tiekiamo ir grįžtamo resurso matavimų skirtumo rodmenų generavimas', 'Tiekiamo ir grįžtamo resurso matavimų skirtumo rodmenų generavimas', 'y T_VARCHAR2_TAB;', 'SELECT CAST(COLLECT(\'#PL.SELF.\'||ml_id) AS T_VARCHAR2_TAB) INTO y\r\nFROM (SELECT ml_id FROM ml WHERE (ms_id,aggs_id,aggf_id,tff_id,md_id) IN\r\n(SELECT ms_id,aggs_id,aggf_id,tff_id,md_id FROM ml WHERE ml_id=:1)\r\nAND dir_id IN (1,2) ORDER BY dir_id);\r\ngenerate_using_formula.run(\r\n\'[1]-[2]\'\r\n,:0,:2,:3,:4,:5,:6,:7\r\n,null,y);', NULL, NULL, NULL, 26),
	(204, 'AUTO_DELETE_STA_PH', 'Automatinis ryšio kanalų statistikos duomenų įrašų trynimas', 'Automatinis ryšio kanalų statistikos duomenų įrašų trynimas', 's number(1);', NULL, 'SELECT table_name,part FROM hmp WHERE table_name IN (\'STA_PH_DATA\') AND amp< SYSDATE-:2 ORDER BY amp', 's:=0;\r\nBEGIN\r\nexecute immediate \'truncate table \'||c.table_name||\'#\'||c.part;\r\ns:=1;\r\nEXCEPTION WHEN OTHERS THEN NULL;\r\nEND;\r\nIF s=1 THEN\r\nUPDATE hmp SET amp=SYSDATE + :2/2 + 1 WHERE table_name=c.table_name AND part=c.part;\r\nEND IF;', NULL, 56),
	(209, 'AUTO_DELETE_ALL_STA_SRC', 'Automatinis visų šaltinių statistikos įrašų trynimas iki nurodytos datos', 'Automatinis visų šaltinių statistikos įrašų trynimas iki nurodytos datos', 's number(1);', NULL, 'SELECT table_name,part FROM hmp WHERE table_name IN (\'STA_GRQ_DATA\',\'STA_PRQ\',\'STA_PRQ_DATA\',\'STA_SRC_DATA\') AND amp< SYSDATE-:2 ORDER BY amp', 's:=0;\r\nBEGIN\r\nexecute immediate \'truncate table \'||c.table_name||\'#\'||c.part;\r\ns:=1;\r\nEXCEPTION WHEN OTHERS THEN NULL;\r\nEND;\r\nIF s=1 THEN\r\nUPDATE hmp SET amp=SYSDATE + :2/2 + 1 WHERE table_name=c.table_name AND part=c.part;\r\nEND IF;', NULL, 56),
	(210, 'BY_SRC_TYPE', 'Pagal šaltinių tipus', 'Pagal šaltinių tipus', NULL, NULL, 'select distinct point_id from st_se where not point_id is null and src_type_code=:1 and dp_deleted=0 AND dp_enabled=1 AND src_enabled=1 AND se_enabled=1 AND (src_et IS NULL OR src_et>SYSDATE)', NULL, NULL, 1),
	(211, 'ADD_NEW_GROUP_BY_SRC_TYPE', 'Naujų grupių įtraukimas į grupę pagal šaltinių tipus (atsiradus naujiems šaltinio tipams)', 'Naujų grupių įtraukimas į grupę pagal šaltinių tipus (atsiradus naujiems šaltinio tipams)', 'a VARCHAR2(250);', 'FOR t IN (SELECT * FROM\r\n (SELECT bga_type_id FROM bga_type WHERE bga_type_code = \'BY_SRC_TYPE\') a\r\n,(SELECT gr_type_id FROM gr_type WHERE gr_type_code = \'SYSTEM\') b\r\n,(SELECT sch_id FROM schi_data WHERE sch_int_id = 1 AND per_id = 3 AND sch_int_value = 1 AND ROWNUM<2) c\r\n,(SELECT gr_id FROM gr WHERE gr_code = \'BY_SRC_TYPE\') d\r\n) LOOP\r\nFOR u IN (\r\nSELECT co,Max(na)na,Max(gr_id)gr_id,Sum(cf)r FROM (\r\nSELECT 1 cf,src_type_code co,src_type_name na,\'\'+0 gr_id FROM src_type a WHERE EXISTS (SELECT 0 FROM src join dp USING (dp_id) join se USING (src_id)\r\n WHERE src_type_id = a.src_type_id\r\nAND dp_deleted=0 AND dp_enabled=1 AND src_enabled=1 AND se_enabled=1 AND (src_et IS NULL OR src_et>SYSDATE))\r\nUNION ALL\r\nSELECT -1 cf, bga_param_value co,\'\' na,gr_id FROM bga b join bga_param c on (b.bga_id=c.bga_id AND c.bga_param_nr=1) WHERE b.bga_type_id=t.bga_type_id\r\n) GROUP BY co having Sum(cf)!=0) LOOP\r\nIF u.r=1 THEN\r\na:=gr_i(t.GR_TYPE_ID,u.co,1,u.na);\r\nFOR g IN (SELECT gr_id FROM gr WHERE gr_code=u.co) LOOP\r\na:=grc_i(t.gr_id,g.gr_id);\r\na:=bga_i(t.BGA_TYPE_ID,u.na,1,t.SCH_ID,g.GR_ID);\r\nFOR b IN (SELECT bga_id FROM bga WHERE bga_name=u.na) LOOP\r\na:=bga_param_i(b.BGA_ID,1,u.co);\r\nEND LOOP;\r\nEND LOOP;\r\nELSIF u.r=-1 then\r\na:=gr_d(u.gr_id);\r\nEND IF;\r\nEND LOOP;\r\nEND LOOP;', NULL, NULL, NULL, 1),
	(214, 'DAY_SUM_FROM_15_MIN_AVG', 'Paros sumos rodmenų generavimas iš vidutinių reikšmių per 15 min', 'Paros sumos rodmenų generavimas iš vidutinių reikšmių per 15 min', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,sum(val)/4 v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=96\r\nthen \'1\' else \'14\'||decode(count(*),96,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(215, 'AUTO_DELETE_ALL_FROM_PL_DATA_MONTH', 'Automatinis visų matavimo taškų matavimo linijų mėnesių duomenų įrašų trynimas', 'Automatinis visų matavimo taškų matavimo linijų mėnesių duomenų įrašų trynimas', 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_MONTH\';\r\nstep number := 0;\r\nst date;', 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_type_id=4) using (ml_id) WHERE\r\n PL_T<=CURRTMST+nvl(:1,1440)/1440+31\r\n --5/and pl_t>=CURRTMST+31\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;', NULL, NULL, NULL, 56),
	(216, 'AUTO_DELETE_ALL_FROM_PL_DATA_DAY', 'Automatinis visų matavimo taškų matavimo linijų paros duomenų įrašų trynimas', 'Automatinis visų matavimo taškų matavimo linijų paros duomenų įrašų trynimas', 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_DAY\';\r\nstep number := 0;\r\nst date;', 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_type_id=3) using (ml_id) WHERE\r\n PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;', NULL, NULL, NULL, 56),
	(217, 'AUTO_DELETE_ALL_FROM_PL_DATA_PROFILE', 'Automatinis visų matavimo taškų matavimo linijų paros profilio duomenų įrašų trynimas', 'Automatinis visų matavimo taškų matavimo linijų paros profilio duomenų įrašų trynimas', 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_PROFILE\';\r\nstep number := 0;\r\nst date;', 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_type_id=2) using (ml_id) WHERE\r\n PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;', NULL, NULL, NULL, 56),
	(218, 'AUTO_DELETE_ALL_FROM_PL_DATA_TOTAL', 'Automatinis visų matavimo taškų matavimo linijų suminių nefiksuotų duomenų įrašų trynimas', 'Automatinis visų matavimo taškų matavimo linijų suminių nefiksuotų duomenų įrašų trynimas', 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_TOTAL\';\r\nstep number := 0;\r\nst date;', 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_type_id=5) using (ml_id) WHERE\r\n PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;', NULL, NULL, NULL, 56),
	(219, 'AUTO_DELETE_ALL_FROM_PL_DATA_TMONFIX', 'Automatinis visų matavimo taškų matavimo linijų suminių fiksuotų iki mėn. uomenų įrašų trynimas', 'Automatinis visų matavimo taškų matavimo linijų suminių fiksuotų iki mėn. duomenų įrašų trynimas', 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_TMONFIX\';\r\nstep number := 0;\r\nst date;', 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_id=8 and md_id in (5,6))\r\n using (ml_id) WHERE PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;', NULL, NULL, NULL, 56),
	(220, 'AUTO_DELETE_ALL_FROM_PL_DATA_TDAYFIX', 'Automatinis visų matavimo taškų matavimo linijų suminių fiksuotų iki paros duomenų įrašų trynimas', 'Automatinis visų matavimo taškų matavimo linijų suminių fiksuotų iki paros duomenų įrašų trynimas', 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_TDAYFIX\';\r\nstep number := 0;\r\nst date;', 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=ADD_MONTHS(SYSDATE,-nvl(:2,36))\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_id=8 and not md_id in (5,6,7))\r\n using (ml_id) WHERE PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;', NULL, NULL, NULL, 56),
	(221, 'AUTO_DELETE_ALL_FROM_PL_DATA_SEK', 'Automatinis visų matavimo taškų matavimo linijų sekundinių duomenų įrašų trynimas', 'Automatinis visų matavimo taškų matavimo linijų sekundinių duomenų įrašų trynimas', 'lmt number;\r\ncurrtmst date;\r\ncd varchar2(100):=\'AUTO_DELETE_ALL_FROM_PL_DATA_SEK\';\r\nstep number := 0;\r\nst date;', 'lmt:=nvl(:4,1000000);\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=cd)\r\n ,TRUNC((SYSDATE-interval \'5\' year),\'Y\'))INTO CURRTMST FROM DUAL;\r\nst:=sysdate;\r\nwhile not(CURRTMST+nvl(:1,1440)/1440>=SYSDATE-nvl(:2,31)\r\n or SYSDATE>st+nvl(:3,1800)/86400)loop\r\n DELETE ( SELECT /*+ index_rs_asc(pl_data pl_data_pk)*/ pl_t FROM pl_data join pl\r\n USING (pl_id) join (SELECT ml_id FROM ml where aggs_type_id=7) using (ml_id) WHERE\r\n PL_T<=CURRTMST+nvl(:1,1440)/1440+1\r\n --5/and pl_t>=CURRTMST+1\r\n ) WHERE ROWNUM<=lmt;\r\n if sql%rowcount<lmt then\r\n  CURRTMST:=CURRTMST+nvl(:1,1440)/1440;\r\n  step:=step+1;\r\n  merge into TMST y using (select cd tmst_code,currtmst amp,step arg_1 from dual)u on (u.tmst_code=y.tmst_code)\r\n  WHEN MATCHED THEN UPDATE SET y.amp=u.amp, arg_1=step\r\n  WHEN NOT MATCHED THEN INSERT (tmst_code,amp,arg_1) values (cd,currtmst,step);\r\n end if;\r\n  commit;\r\nend loop;', NULL, NULL, NULL, 56),
	(222, 'FROZEN_GR_MINUTE_DATA', 'Užfiksuoti grupių matavimų minučių archyvų duomenys', 'Užfiksuoti grupių matavimų minučių archyvų duomenys', NULL, 'MERGE INTO f_ar_g o\r\nUSING (select * from V_AR_GT where gr_type_code=:7 and ML_ID=:1\r\nAND DA>=Nvl(:4,Trunc(SYSDATE-(:2+:6)/1440))\r\nAND DA<=Nvl(:5,SYSDATE-:6/1440)\r\nAND BT>=Nvl(:4,SYSDATE-(:2+:6)/1440)\r\nAND BT< Nvl(:5,SYSDATE-:6/1440)\r\nAND (:3 IS NULL OR gr_id=:3)\r\n) S\r\nON (o.gr_id=s.gr_id AND o.ml_id=S.ml_id AND o.bt=s.bt)\r\nWHEN MATCHED THEN UPDATE SET\r\no.val=s.val\r\n,o.val_prc=s.val_prc\r\n,o.val_prc_limit=s.val_prc_limit\r\n,o.has_act=s.has_act\r\n,o.has_specific_dstatus=s.has_specific_dstatus\r\n,o.dstatus=s.dstatus\r\n,o.read_time=s.read_time\r\n,o.val_input=s.val_input\r\n,o.has_input_act=s.has_input_act\r\n,o.has_input_specific_dstatus=s.has_input_specific_dstatus\r\n,o.dstatus_input=s.dstatus_input\r\n,o.read_time_input=s.read_time_input\r\n,o.val_output=s.val_output\r\n,o.has_output_act=s.has_output_act\r\n,o.has_output_specific_dstatus=s.has_output_specific_dstatus\r\n,o.dstatus_output=s.dstatus_output\r\n,o.read_time_output=s.read_time_output\r\n,o.tff_id=s.tff_id\r\n,o.extreme_bt=s.extreme_bt\r\n,o.extreme_et=s.extreme_et\r\n,o.extreme_input_bt=s.extreme_input_bt\r\n,o.extreme_input_et=s.extreme_input_et\r\n,o.extreme_output_bt=s.extreme_output_bt\r\n,o.extreme_output_et=s.extreme_output_et\r\n,o.extreme_prc_bt=s.extreme_prc_bt\r\n,o.extreme_prc_et=s.extreme_prc_et\r\n,o.extreme_prc_limit_bt=s.extreme_prc_limit_bt\r\n,o.extreme_prc_limit_et=s.extreme_prc_limit_et\r\nWHERE\r\ndecode(o.val,s.val,0,1)\r\n+decode(o.val_prc,s.val_prc,0,1)\r\n+decode(o.val_prc_limit,s.val_prc_limit,0,1)\r\n+decode(o.has_act,s.has_act,0,1)\r\n+decode(o.has_specific_dstatus,s.has_specific_dstatus,0,1)\r\n+decode(o.dstatus,s.dstatus,0,1)\r\n+decode(o.read_time,s.read_time,0,1)\r\n+decode(o.val_input,s.val_input,0,1)\r\n+decode(o.has_input_act,s.has_input_act,0,1)\r\n+decode(o.has_input_specific_dstatus,s.has_input_specific_dstatus,0,1)\r\n+decode(o.dstatus_input,s.dstatus_input,0,1)\r\n+decode(o.read_time_input,s.read_time_input,0,1)\r\n+decode(o.val_output,s.val_output,0,1)\r\n+decode(o.has_output_act,s.has_output_act,0,1)\r\n+decode(o.has_output_specific_dstatus,s.has_output_specific_dstatus,0,1)\r\n+decode(o.dstatus_output,s.dstatus_output,0,1)\r\n+decode(o.read_time_output,s.read_time_output,0,1)\r\n+decode(o.tff_id,s.tff_id,0,1)\r\n+decode(o.extreme_bt,s.extreme_bt,0,1)\r\n+decode(o.extreme_et,s.extreme_et,0,1)\r\n+decode(o.extreme_input_bt,s.extreme_input_bt,0,1)\r\n+decode(o.extreme_input_et,s.extreme_input_et,0,1)\r\n+decode(o.extreme_output_bt,s.extreme_output_bt,0,1)\r\n+decode(o.extreme_output_et,s.extreme_output_et,0,1)\r\n+decode(o.extreme_prc_bt,s.extreme_prc_bt,0,1)\r\n+decode(o.extreme_prc_et,s.extreme_prc_et,0,1)\r\n+decode(o.extreme_prc_limit_bt,s.extreme_prc_limit_bt,0,1)\r\n+decode(o.extreme_prc_limit_et,s.extreme_prc_limit_et,0,1)\r\n>0\r\nWHEN NOT MATCHED THEN INSERT (\r\no.gr_id\r\n,o.ml_id\r\n,o.bt\r\n,o.val\r\n,o.val_prc\r\n,o.val_prc_limit\r\n,o.has_act\r\n,o.has_specific_dstatus\r\n,o.dstatus\r\n,o.read_time\r\n,o.val_input\r\n,o.has_input_act\r\n,o.has_input_specific_dstatus\r\n,o.dstatus_input\r\n,o.read_time_input\r\n,o.val_output\r\n,o.has_output_act\r\n,o.has_output_specific_dstatus\r\n,o.dstatus_output\r\n,o.read_time_output\r\n,o.tff_id\r\n,o.extreme_bt\r\n,o.extreme_et\r\n,o.extreme_input_bt\r\n,o.extreme_input_et\r\n,o.extreme_output_bt\r\n,o.extreme_output_et\r\n,o.extreme_prc_bt\r\n,o.extreme_prc_et\r\n,o.extreme_prc_limit_bt\r\n,o.extreme_prc_limit_et\r\n) VALUES (\r\n s.gr_id\r\n,s.ml_id\r\n,s.bt\r\n,s.val\r\n,s.val_prc\r\n,s.val_prc_limit\r\n,s.has_act\r\n,s.has_specific_dstatus\r\n,s.dstatus\r\n,s.read_time\r\n,s.val_input\r\n,s.has_input_act\r\n,s.has_input_specific_dstatus\r\n,s.dstatus_input\r\n,s.read_time_input\r\n,s.val_output\r\n,s.has_output_act\r\n,s.has_output_specific_dstatus\r\n,s.dstatus_output\r\n,s.read_time_output\r\n,s.tff_id\r\n,s.extreme_bt\r\n,s.extreme_et\r\n,s.extreme_input_bt\r\n,s.extreme_input_et\r\n,s.extreme_output_bt\r\n,s.extreme_output_et\r\n,s.extreme_prc_bt\r\n,s.extreme_prc_et\r\n,s.extreme_prc_limit_bt\r\n,s.extreme_prc_limit_et\r\n);', NULL, NULL, NULL, 46),
	(223, 'AUTO_DELETE_ALL_FROM_PW_DATA', 'Automatinis visų matavimo taškų vytelių duomenų įrašų trynimas', 'Automatinis visų matavimo taškų vytelių duomenų įrašų trynimas', 'CURRTMST DATE;\r\nTS DATE;\r\nep INTEGER;\r\nbtc VARCHAR(250):=\'AUTO_DELETE_ALL_FROM_PW_DATA\';', 'SELECT CASE WHEN exists (select 0 from USER_TAB_PARTITIONS where TABLESPACE_NAME like \'EMCOS_%\'\r\nAND TABLE_NAME = \'PW_DATA\') THEN 1 ELSE 0 END INTO ep FROM dual;\r\nIF ep=1 THEN\r\nfor i in (select\r\nTABLE_NAME tn,\r\nPARTITION_NAME pname,\r\nADD_MONTHS(TO_DATE(SUBSTR(PARTITION_NAME, 5, 11)||\'01\', \'YYYYMMDD\'),1) dt\r\nfrom USER_TAB_PARTITIONS\r\nwhere TABLE_NAME IN (\'PW_DATA\') order by 1) LOOP\r\nif i.dt < SYSDATE-nvl(:2,31)\r\nTHEN\r\n--disable FK\r\nDELETE gtts;\r\nINSERT INTO gtts (id0,c1)\r\nSELECT ts_id,\r\n\'alter table ||table_name|| modify constraint ||constraint_name|| \'||Decode(ts_id,0,\'disable\',\'enable novalidate\')\r\nFROM (\r\nSELECT table_name,constraint_name FROM user_constraints a\r\nWHERE LEVEL=2\r\nCONNECT BY PRIOR constraint_name=r_constraint_name AND PRIOR constraint_type = \'P\' AND constraint_type=\'R\'\r\nSTART WITH table_name IN (\'PW_DATA\')\r\n), ts;\r\n-- disable FK\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=0) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nEXECUTE IMMEDIATE \'alter table \'||i.tn||\' drop partition \'||i.pname;\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=1) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,i.dt amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n(\r\n y.tmst_code\r\n,y.amp\r\n) values (\r\n u.tmst_code\r\n,u.amp\r\n);\r\nend if;END LOOP;\r\nELSE\r\nSELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE=btc)\r\n,TRUNC ((SYSDATE-interval \'5\' year),\'Y\')) INTO CURRTMST FROM DUAL;\r\nTS := SYSDATE;\r\nwhile (not (CURRTMST+nvl(:1,5)/1440 > (SYSDATE-nvl(:2,31)) OR SYSDATE > TS+nvl(:3,45)/86400))LOOP\r\nDELETE PW_DATA WHERE DB_TIME<CURRTMST+nvl(:1,5)/1440 AND ROWNUM<=nvl(:4,10000);\r\nIF SQL%ROWCOUNT=0 then\r\nCURRTMST := CURRTMST+nvl(:1,5)/1440;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,CURRTMST amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n(\r\n y.tmst_code\r\n,y.amp\r\n) values (\r\n u.tmst_code\r\n,u.amp\r\n);\r\nEND IF;\r\nCOMMIT;\r\nEND LOOP;\r\nEND IF;', NULL, NULL, NULL, 56),
	(224, 'AUTO_DELETE_ALL_FROM_DW_DATA', 'Automatinis visų nuskaitymo taškų vytelių duomenų įrašų trynimas', 'Automatinis visų nuskaitymo taškų vytelių duomenų įrašų trynimas', 'CURRTMST DATE;\r\nTS DATE;\r\nep INTEGER;\r\nbtc VARCHAR(250):=\'AUTO_DELETE_ALL_FROM_DW_DATA\';', 'SELECT CASE WHEN exists (select 0 from USER_TAB_PARTITIONS where TABLESPACE_NAME like \'EMCOS_%\'\r\nAND TABLE_NAME = \'DW_DATA\') THEN 1 ELSE 0 END INTO ep FROM dual;\r\nIF ep=1 THEN\r\nfor i in (select\r\nTABLE_NAME tn,\r\nPARTITION_NAME pname,\r\nADD_MONTHS(TO_DATE(SUBSTR(PARTITION_NAME, 5, 11)||\'01\', \'YYYYMMDD\'),1) dt\r\nfrom USER_TAB_PARTITIONS\r\nwhere TABLE_NAME IN (\'DW_DATA\') order by 1) LOOP\r\nif i.dt < SYSDATE-nvl(:2,31)\r\nTHEN\r\n--disable FK\r\nDELETE gtts;\r\nINSERT INTO gtts (id0,c1)\r\nSELECT ts_id,\r\n\'alter table ||table_name|| modify constraint ||constraint_name|| \'||Decode(ts_id,0,\'disable\',\'enable novalidate\')\r\nFROM (\r\nSELECT table_name,constraint_name FROM user_constraints a\r\nWHERE LEVEL=2\r\nCONNECT BY PRIOR constraint_name=r_constraint_name AND PRIOR constraint_type = \'P\' AND constraint_type=\'R\'\r\nSTART WITH table_name IN (\'DW_DATA\')\r\n), ts;\r\n-- disable FK\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=0) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nEXECUTE IMMEDIATE \'alter table \'||i.tn||\' drop partition \'||i.pname;\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=1) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,i.dt amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n(\r\n y.tmst_code\r\n,y.amp\r\n) values (\r\n u.tmst_code\r\n,u.amp\r\n);\r\nend if;END LOOP;\r\nELSE\r\nSELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE=btc)\r\n,TRUNC ((SYSDATE-interval \'5\' year),\'Y\')) INTO CURRTMST FROM DUAL;\r\nTS := SYSDATE;\r\nwhile (not (CURRTMST+nvl(:1,5)/1440 > (SYSDATE-nvl(:2,31)) OR SYSDATE > TS+nvl(:3,45)/86400))LOOP\r\nDELETE DW_DATA WHERE DB_TIME<CURRTMST+nvl(:1,5)/1440 AND ROWNUM<=nvl(:4,10000);\r\nIF SQL%ROWCOUNT=0 then\r\nCURRTMST := CURRTMST+nvl(:1,5)/1440;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,CURRTMST amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n(\r\n y.tmst_code\r\n,y.amp\r\n) values (\r\n u.tmst_code\r\n,u.amp\r\n);\r\nEND IF;\r\nCOMMIT;\r\nEND LOOP;\r\nEND IF;', NULL, NULL, NULL, 56),
	(225, 'AUTO_DELETE_INVALID_FROM_PW_DATA', 'Automatinis negaliojančių matavimo taškų vytelių duomenų įrašų trynimas', 'Automatinis negaliojančių matavimo taškų vytelių duomenų įrašų trynimas', 'CURRTMST DATE;\r\nTS DATE;\r\nep INTEGER;\r\nbtc VARCHAR(250):=\'AUTO_DELETE_INVALID_FROM_PW_DATA\';', 'SELECT CASE WHEN exists (select 0 from USER_TAB_PARTITIONS where TABLESPACE_NAME like \'EMCOS_%\'\r\nAND TABLE_NAME = \'PW_DATA_NV\') THEN 1 ELSE 0 END INTO ep FROM dual;\r\nIF ep=1 THEN\r\nfor i in (select\r\nTABLE_NAME tn,\r\nPARTITION_NAME pname,\r\nADD_MONTHS(TO_DATE(SUBSTR(PARTITION_NAME, 5, 11)||\'01\', \'YYYYMMDD\'),1) dt\r\nfrom USER_TAB_PARTITIONS\r\nwhere TABLE_NAME IN (\'PW_DATA_NV\') order by 1) LOOP\r\nif i.dt < SYSDATE-nvl(:2,31)\r\nTHEN\r\n--disable FK\r\nDELETE gtts;\r\nINSERT INTO gtts (id0,c1)\r\nSELECT ts_id,\r\n\'alter table ||table_name|| modify constraint ||constraint_name|| \'||Decode(ts_id,0,\'disable\',\'enable novalidate\')\r\nFROM (\r\nSELECT table_name,constraint_name FROM user_constraints a\r\nWHERE LEVEL=2\r\nCONNECT BY PRIOR constraint_name=r_constraint_name AND PRIOR constraint_type = \'P\' AND constraint_type=\'R\'\r\nSTART WITH table_name IN (\'PW_DATA_NV\')\r\n), ts;\r\n-- disable FK\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=0) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nEXECUTE IMMEDIATE \'alter table \'||i.tn||\' drop partition \'||i.pname;\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=1) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,i.dt amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n(\r\n y.tmst_code\r\n,y.amp\r\n) values (\r\n u.tmst_code\r\n,u.amp\r\n);\r\nend if;END LOOP;\r\nELSE\r\nSELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE=btc)\r\n,TRUNC ((SYSDATE-interval \'5\' year),\'Y\')) INTO CURRTMST FROM DUAL;\r\nTS := SYSDATE;\r\nwhile (not (CURRTMST+nvl(:1,5)/1440 > (SYSDATE-nvl(:2,31)) OR SYSDATE > TS+nvl(:3,45)/86400))LOOP\r\nDELETE PW_DATA_NV WHERE DB_TIME<CURRTMST+nvl(:1,5)/1440 AND ROWNUM<=nvl(:4,10000);\r\nIF SQL%ROWCOUNT=0 then\r\nCURRTMST := CURRTMST+nvl(:1,5)/1440;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,CURRTMST amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n(\r\n y.tmst_code\r\n,y.amp\r\n) values (\r\n u.tmst_code\r\n,u.amp\r\n);\r\nEND IF;\r\nCOMMIT;\r\nEND LOOP;\r\nEND IF;', NULL, NULL, NULL, 56),
	(226, 'AUTO_DELETE_INVALID_FROM_DW_DATA', 'Automatinis negaliojančių nuskaitymo taškų vytelių duomenų įrašų trynimas', 'Automatinis negaliojančių nuskaitymo taškų vytelių duomenų įrašų trynimas', 'CURRTMST DATE;\r\nTS DATE;\r\nep INTEGER;\r\nbtc VARCHAR(250):=\'AUTO_DELETE_INVALID_FROM_DW_DATA\';', 'SELECT CASE WHEN exists (select 0 from USER_TAB_PARTITIONS where TABLESPACE_NAME like \'EMCOS_%\'\r\nAND TABLE_NAME = \'DW_DATA_NV\') THEN 1 ELSE 0 END INTO ep FROM dual;\r\nIF ep=1 THEN\r\nfor i in (select\r\nTABLE_NAME tn,\r\nPARTITION_NAME pname,\r\nADD_MONTHS(TO_DATE(SUBSTR(PARTITION_NAME, 5, 11)||\'01\', \'YYYYMMDD\'),1) dt\r\nfrom USER_TAB_PARTITIONS\r\nwhere TABLE_NAME IN (\'DW_DATA_NV\') order by 1) LOOP\r\nif i.dt < SYSDATE-nvl(:2,31)\r\nTHEN\r\n--disable FK\r\nDELETE gtts;\r\nINSERT INTO gtts (id0,c1)\r\nSELECT ts_id,\r\n\'alter table ||table_name|| modify constraint ||constraint_name|| \'||Decode(ts_id,0,\'disable\',\'enable novalidate\')\r\nFROM (\r\nSELECT table_name,constraint_name FROM user_constraints a\r\nWHERE LEVEL=2\r\nCONNECT BY PRIOR constraint_name=r_constraint_name AND PRIOR constraint_type = \'P\' AND constraint_type=\'R\'\r\nSTART WITH table_name IN (\'DW_DATA_NV\')\r\n), ts;\r\n-- disable FK\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=0) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nEXECUTE IMMEDIATE \'alter table \'||i.tn||\' drop partition \'||i.pname;\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=1) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,i.dt amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n(\r\n y.tmst_code\r\n,y.amp\r\n) values (\r\n u.tmst_code\r\n,u.amp\r\n);\r\nend if;END LOOP;\r\nELSE\r\nSELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE=btc)\r\n,TRUNC ((SYSDATE-interval \'5\' year),\'Y\')) INTO CURRTMST FROM DUAL;\r\nTS := SYSDATE;\r\nwhile (not (CURRTMST+nvl(:1,5)/1440 > (SYSDATE-nvl(:2,31)) OR SYSDATE > TS+nvl(:3,45)/86400))LOOP\r\nDELETE DW_DATA_NV WHERE DB_TIME<CURRTMST+nvl(:1,5)/1440 AND ROWNUM<=nvl(:4,10000);\r\nIF SQL%ROWCOUNT=0 then\r\nCURRTMST := CURRTMST+nvl(:1,5)/1440;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,CURRTMST amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n(\r\n y.tmst_code\r\n,y.amp\r\n) values (\r\n u.tmst_code\r\n,u.amp\r\n);\r\nEND IF;\r\nCOMMIT;\r\nEND LOOP;\r\nEND IF;', NULL, NULL, NULL, 56),
	(227, 'AUTO_DELETE_ALL_FROM_LTL', 'Periodinis automatinis senų nevykdytų ryšio užduočių trynimas', 'Periodinis automatinis senų nevykdytų ryšio užduočių trynimas', 'rows_cnt NUMBER;', 'UPDATE rodo SET src_id=NULL WHERE rodo_id IN (SELECT rodo_id FROM ltl) AND db_time<SYSDATE-:1/24;\r\nDELETE ltl WHERE rodo_id IN (SELECT rodo_id FROM rodo WHERE db_time<SYSDATE-:1/24);\r\nrows_cnt:=SQL%ROWCOUNT;\r\nIF rows_cnt>0 THEN\r\nevent_i(1,1,3540,1,sysdate,getcaption(221,rows_cnt,:1));\r\nEND IF;COMMIT;', NULL, NULL, NULL, 56),
	(228, 'RAW_FIXED_TOTALS_FROM_RAW_FIXED_TOTALS_AND_30_MIN', 'Pirminių suminių fiksuotų kas parą rodmenų generavimas iš pusvalandinių ir augančių rodmenų sumos', 'Pirminių suminių fiksuotų kas parą rodmenų generavimas iš pusvalandinių ir augančių rodmenų sumos', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nfrom GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n             FROM spty\r\n            WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nFOR i IN 1..TO_NUMBER(TRUNC(NVL(:5,SYSDATE))-TRUNC(NVL(:4,SYSDATE-:3))) LOOP\r\n  OPEN c_ROWS;\r\n  LOOP\r\n    FETCH c_ROWS\r\n    BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n    LIMIT pGF;\r\n    EXIT WHEN sPL_ID.Count=0;\r\n    FORALL j IN 1..sPL_ID.count\r\n    INSERT INTO gttt\r\n    (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\n    SELECT\r\n    NULL,NULL,sPL_ID(j),sSEP_ID(j),tda,\'\',sum(pl_rv),Nvl(:7,0)\r\n    ,case when Max(HAS_SPECIFIC_DSTATUS)=0 and count(*)=49\r\n    then \'1\' else \'14\'||decode(count(*),49,null,\'+3\') end,SYSDATE,\'\'\r\n    ,sAGGS_TYPE_ID(j) aggs_type_id FROM\r\n    (SELECT da,da as tda, decode(has_act,1,val,case when \'+\'||dstatus like \'%+15%\' then 0 else pl_rv end)/2 as pl_rv\r\n    , case when \'+\'||dstatus like \'%+15%\' then 0 else HAS_SPECIFIC_DSTATUS end HAS_SPECIFIC_DSTATUS\r\n    FROM v_ar\r\n    WHERE point_id=sPOINT_ID(j) AND ml_id in (:1) AND da>=Nvl(:4,SYSDATE-:3)-1 + (i-1)\r\n    AND da<=Nvl(:5,SYSDATE)-1 AND NOT val IS NULL\r\n    union all\r\n    SELECT da, da+1 as tda, decode(has_act,1,val,pl_rv) as pl_rv, HAS_SPECIFIC_DSTATUS\r\n    FROM v_ar\r\n    WHERE point_id=sPOINT_ID(j) AND ml_id in (:2) AND da>=Nvl(:4,SYSDATE-:3)-2 + (i-1)\r\n    AND da<=Nvl(:5,SYSDATE)-2 AND NOT val IS NULL)\r\n    GROUP BY tda;\r\n    SELECT\r\n    d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\n    BULK COLLECT INTO\r\n    pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\n    FROM gttt f\r\n    --/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\n    store_pl_now(pPCK_T,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\n  END LOOP;\r\n  CLOSE c_ROWS;\r\nEND LOOP;', NULL, NULL, NULL, 26),
	(229, 'ANY_FROM_PREVIOUS', 'Bet kokių rodmenų generavimas iš ankstesnių reikšmių', 'Bet kokių rodmenų generavimas iš ankstesnių reikšmių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nsML_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,ML_ID,aggs_type_id\r\nfrom GEN_IDs\r\nWHERE bga_id=:0 --6/ and point_id=:6\r\n;', 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sML_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3)-1,Nvl(:5+1,SYSDATE),1,sML_ID);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',prev_val,Nvl(:7,0)\r\n, \'1\',SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT a.*,bt t,val v\r\n,Lag(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt) prev_val\r\n,Lag(has_specific_dstatus) over (PARTITION BY point_id,ml_id ORDER BY da,bt) prev_has_specific_dstatus\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,param1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,Nvl(:5+1,SYSDATE)))a )r\r\nWHERE (Nvl(:7,0)=1 OR v IS NULL) AND prev_has_specific_dstatus=0;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(230, 'HOUR_AVG_FROM_DAY_SUM_DIVIDED_BY_SAMPLE', 'Valandinių duomenų generavimas išdalinant paros sumą pagal šabloną', 'Valandinių duomenų generavimas išdalinant paros sumą pagal šabloną', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nsML_ID T7.IRR;\r\nsSAM_CODE T7.CRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,g.POINT_ID,g.aggs_type_id,z.ml_id,p.ppty_value\r\nfrom GEN_IDs g\r\njoin ml l ON (g.ml_id=l.ml_id)\r\njoin ml z ON (l.ms_id=z.ms_id AND l.dir_id=z.dir_id AND z.aggs_id=5 AND z.aggf_id=2 AND l.tff_id=z.tff_id AND z.md_id=5 AND l.md_id=4)\r\njoin ppty y ON (y.ppty_code=:8)\r\njoin point_ppty p ON (g.point_id=p.point_id AND y.ppty_id=p.ppty_id)\r\nWHERE l.ml_id=:2 AND bga_id=:0 --6/ and g.point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,sML_ID,sSAM_CODE\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nselect level BULK COLLECT INTO pNR from dual connect by level<=mi;\r\nDELETE GTTT;\r\nFORALL j in 1..mi\r\nINSERT INTO GTTT (id0,id1) values (pNR(j),sPL_ID(j));\r\nSELECT d\r\nBULK COLLECT INTO s1\r\nFROM\r\n(SELECT /*+ use_nl(a b c) index(c plep_pk)*/ id0,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END d\r\nFROM\r\ngttt a\r\nleft join plu b ON (a.id1=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.id1=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY id0\r\nORDER BY id0);\r\nDELETE GTTT;\r\nFORALL j IN 1..mi\r\nINSERT INTO gttt (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT\r\nNULL,NULL,sPL_ID(j),sSEP_ID(j),bt,\'\',Decode(Trunc(et),da,f,f+p-Sum(f) over (PARTITION BY da)) v,Nvl(:7,0),d\r\n,SYSDATE,\'\',sAGGS_TYPE_ID(j) FROM\r\n(\r\nSELECT b.bt,b.et,b.da,c.val p,b.val s,Decode(c.has_specific_dstatus,0,\'1\',\'14\')d\r\n,Round(b.val*c.val/Sum(b.val) over (PARTITION BY b.da),6) f\r\nFROM  st_ar_sam b,v_ar c\r\nWHERE c.point_id=sPOINT_ID(j)\r\nAND b.da=c.da AND c.ml_id=sML_ID(j)\r\nAND b.sam_code=sSAM_CODE(j)\r\nAND b.da>=Trunc(s1(j)) AND b.bt>=s1(j) AND b.da<s2\r\nAND NOT c.val IS NULL AND NOT b.val IS null\r\n);\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8  AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(231, 'FROZEN_GR_MLSET_DAY_DATA', 'Užfiksuoti grupių atitinkamo rinkinio matavimų parų archyvų duomenys', 'Užfiksuoti grupių atitinkamo rinkinio matavimų parų archyvų duomenys', NULL, 'MERGE INTO f_ar_g o\r\nUSING (select * from V_AR_GT_MLSET where gr_type_code=:3 and MLSET_CODE=:1\r\nAND DA>=Nvl(:4,Trunc(SYSDATE)-:2-:6)\r\nAND DA<=Nvl(:5,Trunc(SYSDATE)-:6-1)\r\n) S\r\nON (o.gr_id=s.gr_id AND o.ml_id=S.ml_id AND o.bt=s.bt)\r\nWHEN MATCHED THEN UPDATE SET\r\no.val=s.val\r\n,o.val_prc=s.val_prc\r\n,o.val_prc_limit=s.val_prc_limit\r\n,o.has_act=s.has_act\r\n,o.has_specific_dstatus=s.has_specific_dstatus\r\n,o.dstatus=s.dstatus\r\n,o.read_time=s.read_time\r\n,o.val_input=s.val_input\r\n,o.has_input_act=s.has_input_act\r\n,o.has_input_specific_dstatus=s.has_input_specific_dstatus\r\n,o.dstatus_input=s.dstatus_input\r\n,o.read_time_input=s.read_time_input\r\n,o.val_output=s.val_output\r\n,o.has_output_act=s.has_output_act\r\n,o.has_output_specific_dstatus=s.has_output_specific_dstatus\r\n,o.dstatus_output=s.dstatus_output\r\n,o.read_time_output=s.read_time_output\r\n,o.tff_id=s.tff_id\r\n,o.extreme_bt=s.extreme_bt\r\n,o.extreme_et=s.extreme_et\r\n,o.extreme_input_bt=s.extreme_input_bt\r\n,o.extreme_input_et=s.extreme_input_et\r\n,o.extreme_output_bt=s.extreme_output_bt\r\n,o.extreme_output_et=s.extreme_output_et\r\n,o.extreme_prc_bt=s.extreme_prc_bt\r\n,o.extreme_prc_et=s.extreme_prc_et\r\n,o.extreme_prc_limit_bt=s.extreme_prc_limit_bt\r\n,o.extreme_prc_limit_et=s.extreme_prc_limit_et\r\nWHERE\r\ndecode(o.val,s.val,0,1)\r\n+decode(o.val_prc,s.val_prc,0,1)\r\n+decode(o.val_prc_limit,s.val_prc_limit,0,1)\r\n+decode(o.has_act,s.has_act,0,1)\r\n+decode(o.has_specific_dstatus,s.has_specific_dstatus,0,1)\r\n+decode(o.dstatus,s.dstatus,0,1)\r\n+decode(o.read_time,s.read_time,0,1)\r\n+decode(o.val_input,s.val_input,0,1)\r\n+decode(o.has_input_act,s.has_input_act,0,1)\r\n+decode(o.has_input_specific_dstatus,s.has_input_specific_dstatus,0,1)\r\n+decode(o.dstatus_input,s.dstatus_input,0,1)\r\n+decode(o.read_time_input,s.read_time_input,0,1)\r\n+decode(o.val_output,s.val_output,0,1)\r\n+decode(o.has_output_act,s.has_output_act,0,1)\r\n+decode(o.has_output_specific_dstatus,s.has_output_specific_dstatus,0,1)\r\n+decode(o.dstatus_output,s.dstatus_output,0,1)\r\n+decode(o.read_time_output,s.read_time_output,0,1)\r\n+decode(o.tff_id,s.tff_id,0,1)\r\n+decode(o.extreme_bt,s.extreme_bt,0,1)\r\n+decode(o.extreme_et,s.extreme_et,0,1)\r\n+decode(o.extreme_input_bt,s.extreme_input_bt,0,1)\r\n+decode(o.extreme_input_et,s.extreme_input_et,0,1)\r\n+decode(o.extreme_output_bt,s.extreme_output_bt,0,1)\r\n+decode(o.extreme_output_et,s.extreme_output_et,0,1)\r\n+decode(o.extreme_prc_bt,s.extreme_prc_bt,0,1)\r\n+decode(o.extreme_prc_et,s.extreme_prc_et,0,1)\r\n+decode(o.extreme_prc_limit_bt,s.extreme_prc_limit_bt,0,1)\r\n+decode(o.extreme_prc_limit_et,s.extreme_prc_limit_et,0,1)\r\n>0\r\nWHEN NOT MATCHED THEN INSERT (\r\no.gr_id\r\n,o.ml_id\r\n,o.bt\r\n,o.val\r\n,o.val_prc\r\n,o.val_prc_limit\r\n,o.has_act\r\n,o.has_specific_dstatus\r\n,o.dstatus\r\n,o.read_time\r\n,o.val_input\r\n,o.has_input_act\r\n,o.has_input_specific_dstatus\r\n,o.dstatus_input\r\n,o.read_time_input\r\n,o.val_output\r\n,o.has_output_act\r\n,o.has_output_specific_dstatus\r\n,o.dstatus_output\r\n,o.read_time_output\r\n,o.tff_id\r\n,o.extreme_bt\r\n,o.extreme_et\r\n,o.extreme_input_bt\r\n,o.extreme_input_et\r\n,o.extreme_output_bt\r\n,o.extreme_output_et\r\n,o.extreme_prc_bt\r\n,o.extreme_prc_et\r\n,o.extreme_prc_limit_bt\r\n,o.extreme_prc_limit_et\r\n) VALUES (\r\n s.gr_id\r\n,s.ml_id\r\n,s.bt\r\n,s.val\r\n,s.val_prc\r\n,s.val_prc_limit\r\n,s.has_act\r\n,s.has_specific_dstatus\r\n,s.dstatus\r\n,s.read_time\r\n,s.val_input\r\n,s.has_input_act\r\n,s.has_input_specific_dstatus\r\n,s.dstatus_input\r\n,s.read_time_input\r\n,s.val_output\r\n,s.has_output_act\r\n,s.has_output_specific_dstatus\r\n,s.dstatus_output\r\n,s.read_time_output\r\n,s.tff_id\r\n,s.extreme_bt\r\n,s.extreme_et\r\n,s.extreme_input_bt\r\n,s.extreme_input_et\r\n,s.extreme_output_bt\r\n,s.extreme_output_et\r\n,s.extreme_prc_bt\r\n,s.extreme_prc_et\r\n,s.extreme_prc_limit_bt\r\n,s.extreme_prc_limit_et\r\n);', NULL, NULL, NULL, 46),
	(232, 'FROZEN_GR_MLSET_MINUTE_DATA', 'Užfiksuoti grupių atitinkamo rinkinio matavimų minučių archyvų duomenys', 'Užfiksuoti grupių atitinkamo rinkinio matavimų minučių archyvų duomenys', NULL, 'MERGE INTO f_ar_g o\r\nUSING (select * from V_AR_GT_MLSET where gr_type_code=:3 and MLSET_CODE=:1\r\nAND DA>=Nvl(:4,Trunc(SYSDATE-(:2+:6)/1440))\r\nAND DA<=Nvl(:5,SYSDATE-:6/1440)\r\nAND BT>=Nvl(:4,SYSDATE-(:2+:6)/1440)\r\nAND BT< Nvl(:5,SYSDATE-:6/1440)\r\n) S\r\nON (o.gr_id=s.gr_id AND o.ml_id=S.ml_id AND o.bt=s.bt)\r\nWHEN MATCHED THEN UPDATE SET\r\no.val=s.val\r\n,o.val_prc=s.val_prc\r\n,o.val_prc_limit=s.val_prc_limit\r\n,o.has_act=s.has_act\r\n,o.has_specific_dstatus=s.has_specific_dstatus\r\n,o.dstatus=s.dstatus\r\n,o.read_time=s.read_time\r\n,o.val_input=s.val_input\r\n,o.has_input_act=s.has_input_act\r\n,o.has_input_specific_dstatus=s.has_input_specific_dstatus\r\n,o.dstatus_input=s.dstatus_input\r\n,o.read_time_input=s.read_time_input\r\n,o.val_output=s.val_output\r\n,o.has_output_act=s.has_output_act\r\n,o.has_output_specific_dstatus=s.has_output_specific_dstatus\r\n,o.dstatus_output=s.dstatus_output\r\n,o.read_time_output=s.read_time_output\r\n,o.tff_id=s.tff_id\r\n,o.extreme_bt=s.extreme_bt\r\n,o.extreme_et=s.extreme_et\r\n,o.extreme_input_bt=s.extreme_input_bt\r\n,o.extreme_input_et=s.extreme_input_et\r\n,o.extreme_output_bt=s.extreme_output_bt\r\n,o.extreme_output_et=s.extreme_output_et\r\n,o.extreme_prc_bt=s.extreme_prc_bt\r\n,o.extreme_prc_et=s.extreme_prc_et\r\n,o.extreme_prc_limit_bt=s.extreme_prc_limit_bt\r\n,o.extreme_prc_limit_et=s.extreme_prc_limit_et\r\nWHERE\r\ndecode(o.val,s.val,0,1)\r\n+decode(o.val_prc,s.val_prc,0,1)\r\n+decode(o.val_prc_limit,s.val_prc_limit,0,1)\r\n+decode(o.has_act,s.has_act,0,1)\r\n+decode(o.has_specific_dstatus,s.has_specific_dstatus,0,1)\r\n+decode(o.dstatus,s.dstatus,0,1)\r\n+decode(o.read_time,s.read_time,0,1)\r\n+decode(o.val_input,s.val_input,0,1)\r\n+decode(o.has_input_act,s.has_input_act,0,1)\r\n+decode(o.has_input_specific_dstatus,s.has_input_specific_dstatus,0,1)\r\n+decode(o.dstatus_input,s.dstatus_input,0,1)\r\n+decode(o.read_time_input,s.read_time_input,0,1)\r\n+decode(o.val_output,s.val_output,0,1)\r\n+decode(o.has_output_act,s.has_output_act,0,1)\r\n+decode(o.has_output_specific_dstatus,s.has_output_specific_dstatus,0,1)\r\n+decode(o.dstatus_output,s.dstatus_output,0,1)\r\n+decode(o.read_time_output,s.read_time_output,0,1)\r\n+decode(o.tff_id,s.tff_id,0,1)\r\n+decode(o.extreme_bt,s.extreme_bt,0,1)\r\n+decode(o.extreme_et,s.extreme_et,0,1)\r\n+decode(o.extreme_input_bt,s.extreme_input_bt,0,1)\r\n+decode(o.extreme_input_et,s.extreme_input_et,0,1)\r\n+decode(o.extreme_output_bt,s.extreme_output_bt,0,1)\r\n+decode(o.extreme_output_et,s.extreme_output_et,0,1)\r\n+decode(o.extreme_prc_bt,s.extreme_prc_bt,0,1)\r\n+decode(o.extreme_prc_et,s.extreme_prc_et,0,1)\r\n+decode(o.extreme_prc_limit_bt,s.extreme_prc_limit_bt,0,1)\r\n+decode(o.extreme_prc_limit_et,s.extreme_prc_limit_et,0,1)\r\n>0\r\nWHEN NOT MATCHED THEN INSERT (\r\no.gr_id\r\n,o.ml_id\r\n,o.bt\r\n,o.val\r\n,o.val_prc\r\n,o.val_prc_limit\r\n,o.has_act\r\n,o.has_specific_dstatus\r\n,o.dstatus\r\n,o.read_time\r\n,o.val_input\r\n,o.has_input_act\r\n,o.has_input_specific_dstatus\r\n,o.dstatus_input\r\n,o.read_time_input\r\n,o.val_output\r\n,o.has_output_act\r\n,o.has_output_specific_dstatus\r\n,o.dstatus_output\r\n,o.read_time_output\r\n,o.tff_id\r\n,o.extreme_bt\r\n,o.extreme_et\r\n,o.extreme_input_bt\r\n,o.extreme_input_et\r\n,o.extreme_output_bt\r\n,o.extreme_output_et\r\n,o.extreme_prc_bt\r\n,o.extreme_prc_et\r\n,o.extreme_prc_limit_bt\r\n,o.extreme_prc_limit_et\r\n) VALUES (\r\n s.gr_id\r\n,s.ml_id\r\n,s.bt\r\n,s.val\r\n,s.val_prc\r\n,s.val_prc_limit\r\n,s.has_act\r\n,s.has_specific_dstatus\r\n,s.dstatus\r\n,s.read_time\r\n,s.val_input\r\n,s.has_input_act\r\n,s.has_input_specific_dstatus\r\n,s.dstatus_input\r\n,s.read_time_input\r\n,s.val_output\r\n,s.has_output_act\r\n,s.has_output_specific_dstatus\r\n,s.dstatus_output\r\n,s.read_time_output\r\n,s.tff_id\r\n,s.extreme_bt\r\n,s.extreme_et\r\n,s.extreme_input_bt\r\n,s.extreme_input_et\r\n,s.extreme_output_bt\r\n,s.extreme_output_et\r\n,s.extreme_prc_bt\r\n,s.extreme_prc_et\r\n,s.extreme_prc_limit_bt\r\n,s.extreme_prc_limit_et\r\n);', NULL, NULL, NULL, 46),
	(234, 'MONTH_ENERGY_FROM_MONTH_FIXED_TOTALS', 'Rodmenų per mėnesį generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 'Rodmenų per mėnesį generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\npNR T7.IRR;\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT\r\nSEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,add_months(trunc(SYSDATE,\'MM\'),-1*:3)));\r\ns2:=Nvl(add_months(Trunc(:5,\'MM\'),1),trunc(SYSDATE,\'MM\'));\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',round(mval,6), Nvl(:7,0),\r\nstatus,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n( select * from(\r\nSELECT c1,c2,c3,Add_Months(da, nvl(:8, 0))t,\r\n da,val,lead(val) over (PARTITION BY f.point_id order by da)-val mval\r\n,case when HAS_SPECIFIC_DSTATUS=0 and lead(HAS_SPECIFIC_DSTATUS) over (PARTITION BY f.point_id order by da)=0 then \'1\' else \'14\' end status\r\n,MONTHS_BETWEEN(lead(da) over (PARTITION BY f.point_id order by da),da) mb\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1 and s1<s2 ),Trunc(d.s1),s2+1,0))\r\n f,mou u where f.point_id=u.point_id (+) AND f.da<u.mou_bt (+) AND add_months(f.da,1)>=u.mou_bt (+) AND u.mou_id IS null\r\nand\r\nNOT val IS NULL AND u.point_id IS null\r\n) where mb=1)r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(239, 'MONTH_ENERGY_FROM_TOTALS', 'Rodmenų per mėnesį generavimas iš augančių rodmenų', 'Rodmenų per mėnesį generavimas iš augančių rodmenų', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;p number;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nfrom GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual; select nvl(to_number(:9),0) into p from dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,NVL( add_months(TRUNC(:4,\'MM\'),-1),add_months(TRUNC(sysdate,\'MM\'),-:3 -1) ),NVL( :5,SYSDATE ),1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT\r\nc1,c2,c3,mo1 t,round(delta_val,6) v\r\n,s FROM\r\n(\r\nSELECT b.*,case when (bt>=last_d-nvl(:8,5) and bt<last_d and prev_bt>=prev_last_d-nvl(:8,5) and prev_bt<prev_last_d)\r\nand (HAS_SPECIFIC_DSTATUS=0 and prev_HAS_SPECIFIC_DSTATUS=0) AND NOT (mo1=TRUNC(sysdate,\'MM\')) then 1 else 14\r\nend s\r\nFROM (SELECT a.*\r\n,val-lag(val) over (PARTITION by point_id,ml_id order by da) delta_val\r\n,lag(val) over (PARTITION by point_id,ml_id order by da) prev_val\r\n,lag(bt) over (PARTITION by point_id,ml_id order by da) prev_bt ,case when p=0 then mo when p=1 then add_months(mo,-1) end mo1\r\n,lag(HAS_SPECIFIC_DSTATUS) over (PARTITION by point_id,ml_id order by da) prev_HAS_SPECIFIC_DSTATUS\r\n,case when p=0 then last_day(mo)+1\r\n      when p=1 then mo+nvl(:8,5) end last_d\r\n,case when p=0 then last_day(add_months(mo,-1))+1\r\n      when p=1 then add_months(mo,-1)+nvl(:8,5) end prev_last_d\r\nFROM\r\n(SELECT c1,c2,c3,point_id,ml_id,da,bt,trunc(da,\'MM\') mo,val,HAS_SPECIFIC_DSTATUS\r\n,case when p=0 then rank() over (PARTITION by point_id,ml_id,trunc(da,\'MM\') order by da desc,bt desc)\r\n      when p=1 then rank() over (PARTITION by point_id,ml_id,trunc(da,\'MM\') order by da asc,bt asc)\r\n end rnk\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),NVL( :5,SYSDATE )))\r\nWHERE NOT val IS NULL\r\norder by ml_id,da desc,bt desc\r\n) a where rnk=1) b,mou u\r\nWHERE b.POINT_ID=u.point_id (+) AND b.prev_bt<u.mou_bt (+) AND b.bt>=u.mou_bt (+) AND u.mou_id IS null\r\n) where delta_val IS not NULL)r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(244, 'AUTO_DELETE_DOOM_CONTENTS', 'Automatinis visų naikinančios grupės duomenų įrašų trynimas', NULL, 'ANS VARCHAR2(250);\r\nvGR number;\r\nvNOW DATE;', 'vNOW:=sysdate;\r\nselect gr_id into vGR from gr where gr_code=:1;\r\nif vGR is not null then\r\n delete gtts;\r\n insert /*+ append*/ into gtts(id1,id2)\r\n with a as (select /*+ MATERIALIZE*/ c.ml_id\r\n from mlset_data c left join mlset b on(b.mlset_id=c.mlset_id) where b.mlset_code=:4)\r\n select p.pl_id,p.point_id from grp g join pl p on(p.point_id=g.point_id) join a on(a.ml_id=p.ml_id)\r\n where g.gr_id=vGR\r\n union all\r\n select p.pl_id,p.point_id from grp g join pl p on(p.point_id=g.point_id)\r\n where g.gr_id=vGR and :4 is null;\r\n commit;\r\n for i in(select distinct id2 from gtts)loop\r\n  delete pl_data a where a.pl_id IN (select id1 from gtts where id2=i.id2)\r\n   and rownum<=nvl(:3,10000) and (:5 IS NULL OR PL_T>=:5) and (:6 IS NULL OR PL_T<:6);\r\n  IF SQL%ROWCOUNT<nvl(:3,10000) THEN\r\n   delete pl_data_nv a where a.pl_id IN (select id1 from gtts where id2=i.id2)\r\n    and rownum<=nvl(:3,10000) and (:5 IS NULL OR PL_T>=:5) and (:6 IS NULL OR PL_T<:6);\r\n   IF SQL%ROWCOUNT<nvl(:3,10000) THEN\r\n    merge into PLU y using (select g.id1 pl_id,1 harder from gtts g where g.id2=i.id2) u\r\n    on(y.pl_id=u.pl_id)\r\n    WHEN MATCHED THEN UPDATE SET y.harder = u.harder WHERE NOT y.harder=u.harder\r\n    WHEN NOT MATCHED THEN INSERT(y.pl_id,y.harder)values(u.pl_id,u.harder);\r\n    ans:=GRP_D(PGR_ID=>vGR,PPOINT_ID=>i.id2,WOC=>1);\r\n   end if;\r\n  end if;\r\n  commit;\r\n  if sysdate<vNOW+nvl(:2,45)/86400 then exit; end if;\r\n end loop;\r\nend if;\r\nexception when no_data_found then null;', NULL, NULL, NULL, 56),
	(245, 'BY_DP', 'Pagal nuskaitymo tašką', 'Pagal nuskaitymo tašką', 'f number;\r\ng number;\r\nr number;', 'select user_id into r from st_curr_user;delete from gttq;\r\nFOR t IN(SELECT a.gr_id,a.gr_type_id,b.gr_type_id dp_gr_type_id FROM gr a,gr_type b\r\nWHERE a.gr_code=\'BY_DP\' AND b.gr_type_code=\'DP\') LOOP\r\nFOR h IN(SELECT g,Max(n)n,Sum(i)i,Max(c)c\r\nFROM(\r\nSELECT DISTINCT comp_code g,\'\' n,-1 i,comp_id c FROM st_grc WHERE cont_code=\'BY_DP\'\r\nUNION ALL\r\nSELECT DISTINCT \'BY_DP_\'||DP_CODE,DP_name,1,\'\'+0\r\nFROM st_se WHERE dp_deleted=0 AND src_et IS NULL\r\n)GROUP BY g HAVING Sum(i)!=0\r\n)loop\r\nIF h.i=1 THEN SELECT gr_seq.NEXTVAL INTO f FROM dual;\r\ninsert into GR(GR_ID,USER_ID,GR_TYPE_ID,GR_CODE,IS_PUBLIC,GR_NAME)\r\nvalues(f,r,t.DP_GR_TYPE_ID,h.g,1,h.n);\r\ninsert into GRC(CONT_ID,COMP_ID)values(t.gr_id,f);\r\nELSE\r\nFOR y IN (SELECT comp_id c FROM grc WHERE cont_id=h.c) LOOP\r\ndelete from grp where gr_id=y.c;\r\ndelete from grc where cont_id=y.c or comp_id=y.c;\r\ndelete from gr where gr_id=y.c;\r\nEND LOOP;\r\ndelete from grp where gr_id=h.c;\r\ndelete from grc where cont_id=h.c or comp_id=h.c;\r\ndelete from gr where gr_id=h.c;\r\nEND if;END LOOP;\r\nFOR m IN (SELECT c,Max(n)n,Sum(i)i,Max(id)id,Max(u)u\r\nFROM (\r\nSELECT DISTINCT comp_code c,\'\' n,-1 i,comp_id id,\'\' u\r\nFROM st_grc WHERE cont_id IN(SELECT comp_id FROM grc WHERE cont_id=t.gr_id)\r\nUNION all\r\nSELECT DISTINCT \'BY_DP_\'||DP_CODE||\'_\'||src_id,src_name,1,\r\n\'\'+0,\'BY_DP_\'||DP_CODE\r\nFROM st_se WHERE dp_deleted=0 AND src_et IS NULL\r\n)GROUP BY c HAVING Sum(i)!=0\r\n)LOOP if m.i=1 then\r\nSELECT gr_seq.NEXTVAL INTO f FROM dual;\r\ninsert into GTTQ(id1,id2,c1,c2,c0,c9)\r\nvalues(f,t.DP_GR_TYPE_ID,m.c,m.n,\'I\',\'GR\');\r\nselect gr_id into g from gr where gr_code=m.u;\r\ninsert into GTTQ(id1,id2,c0,c9)values(f,g,\'I\',\'GRC\');\r\nelse\r\ndelete from grp where gr_id=m.id;\r\ndelete from grc where cont_id=m.id or comp_id=m.id;\r\ndelete from gr where gr_id=m.id;\r\nend if;end loop;\r\ninsert into GR(GR_ID,USER_ID,GR_TYPE_ID,GR_CODE,IS_PUBLIC,GR_NAME)\r\nselect id1,r,id2,c1,1,c2 from GTTQ where c0=\'I\' and c9=\'GR\';\r\ninsert into GRC(CONT_ID,COMP_ID)\r\nselect id2,id1 from GTTQ where c0=\'I\' and c9=\'GRC\';\r\ndelete from GTTQ;\r\nFOR d IN (SELECT gr_code c,point_id p,Sum(i)i,Max(gr_id)g FROM(\r\nSELECT DISTINCT gr_id,gr_code,point_id,-1 i\r\nFROM st_grp WHERE gr_id IN(SELECT comp_id FROM grcj WHERE cont_id=t.gr_id)\r\nUNION all\r\nSELECT DISTINCT \'\'+0,\'BY_DP_\'||DP_CODE||\'_\'||src_id,point_id,1\r\nFROM st_se WHERE dp_deleted=0 AND src_et IS NULL AND point_id IS NOT null\r\n)GROUP BY gr_code,point_id\r\nHAVING NOT Sum(i)=0\r\n)LOOP\r\nIF d.i=1 THEN\r\nSELECT gr_id INTO f FROM gr WHERE gr_code=d.c;\r\ninsert into GTTQ(id1,id2,c0,c9)values(f,d.p,\'I\',\'GRP\');\r\nELSE\r\ninsert into GTTQ(id1,id2,c0,c9)values(d.g,d.p,\'D\',\'GRP\');\r\nEND if;END LOOP;\r\ndelete from grp where grp_bt=Date\'1899-12-30\'\r\nand(gr_id,point_id)in(select id1,id2 from GTTQ where c0=\'D\' and c9=\'GRP\');\r\ninsert into GRP(GR_ID,POINT_ID)\r\nselect id1,id2 from GTTQ where c0=\'I\' and c9=\'GRP\';\r\ndelete from GTTQ;\r\nFOR s IN (SELECT gr_code,ds_id,Sum(i) i,Max(gr_id) gr_id FROM(\r\nSELECT DISTINCT gr_id,gr_code,ds_id,-1 i\r\nFROM st_ds_gr WHERE gr_id IN(SELECT comp_id FROM grcj WHERE cont_id=t.gr_id)\r\nUNION all\r\nSELECT DISTINCT \'\'+0,\'BY_DP_\'||DP_CODE||\'_\'||src_id,ds_id,1\r\nFROM st_se_ds WHERE dp_deleted=0 AND src_et IS NULL\r\n)GROUP BY gr_code,ds_id\r\nHAVING NOT Sum(i)=0\r\n)LOOP\r\nIF s.i=1 THEN\r\nSELECT gr_id INTO f FROM gr WHERE gr_code=s.gr_code;\r\ninsert into GTTQ(id1,id2,c0,c9)values(f,s.ds_id,\'I\',\'DS_GR\');\r\nELSE\r\ninsert into GTTQ(id1,id2,c0,c9)values(s.GR_ID,s.ds_id,\'D\',\'DS_GR\');\r\nEND if;\r\nEND LOOP;\r\ndelete from ds_gr where(gr_id,ds_id)in(select id1,id2 from GTTQ where c0=\'D\' and c9=\'DS_GR\');\r\ninsert into DS_GR(GR_ID,DS_ID) select id1,id2 from GTTQ where c0=\'I\' and c9=\'DS_GR\';\r\nend loop;\r\nFOR t IN (select * from dp,gr WHERE \'BY_DP_\'||dp_code=gr_code AND dp_name!=gr_name) LOOP\r\nUPDATE gr SET gr_name=t.dp_name WHERE gr_id=t.gr_id;\r\nEND LOOP;', NULL, NULL, NULL, 1),
	(249, '30_MIN_SUM_FROM_INSTANT_TOTALS', 'Sumos rodmenų per 30 minučių generavimas iš augančių reikšmių', 'Sumos rodmenų per 30 minučių generavimas iš augančių reikšmių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nfrom GEN_IDs WHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3),Nvl(:5+1,SYSDATE),1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,ib t\r\n,Sum(q*l) v,Decode(Max(k),0,\'1\',\'14\') s\r\nFROM\r\n(SELECT f.*,Trunc(bt)+Trunc(Round((bt-Trunc(bt))*48,6))/48+(d.column_value-1)/48 ib,g/(et-bt)/48 q\r\n,(Least(et,Trunc(bt)+Trunc(Round((bt-Trunc(bt))*48,6))/48+d.column_value/48)-Greatest(bt,Trunc(bt)+Trunc(Round((bt-Trunc(bt))*48,6))/48+(d.column_value-1)/48))*48 l\r\n,CASE WHEN et-bt>=2/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM ( SELECT da,bt, c1,c2,c3,point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,Nvl(:5+1,SYSDATE)))\r\nWHERE NOT val IS NULL) f,mou u, TABLE(SELECT CAST(COLLECT(level) AS tn) FROM dual CONNECT BY Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*48,6))/48+(LEVEL-1)/48<f.et) d\r\nwhere f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\n) h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(250, 'HOUR_SUM_FROM_INSTANT_TOTALS', 'Sumos rodmenų per valandą generavimas iš augančių reikšmių', 'Sumos rodmenų per valandą generavimas iš augančių reikšmių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nfrom GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3),Nvl(:5+1,SYSDATE),1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT c1,c2,c3, ib t\r\n,Sum(q*l) v,Decode(Max(k),0,\'1\',\'14\') s\r\nFROM (SELECT f.*,d.*,g/(et-bt)/24 q\r\n,(Least(et,ie)-Greatest(bt,ib))*24 l\r\n,CASE WHEN et-bt>=2/24 and not g=0 THEN 1 ELSE 0 END k\r\nFROM(SELECT da,bt,c1,c2,c3,point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et,\r\nLead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN\r\nLead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\nTHEN 0 ELSE val end g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),Nvl(:5+1,SYSDATE)))\r\nWHERE\r\nNOT val IS NULL\r\n) f,mou u,(SELECT da y,da+(nr-1)/24 ib,da+nr/24 ie FROM days,iger WHERE nr<=24) d\r\nWHERE f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\nand (NOT y+1<=bt AND NOT y>=et AND NOT ie<=bt AND NOT ib>=et)) h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(251, 'ANY_SUM_FROM_ANY_MIN_AVG_OR_SUM', 'Stambesnių intervalų (iki paros) sumos rodmenų generavimas iš smulkesnių intervalų', 'Stambesnių intervalų (iki paros) sumos rodmenų generavimas iš smulkesnių intervalų', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\ngf1 number(2);\r\ncnt1 number(5);\r\ncnt2 number(5);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nselect md_cnt,aggf_id into cnt1,gf1 from st_ml where ml_id=:1;\r\nselect md_cnt into cnt2 from st_ml where ml_id=:2;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT /*da*/trunc(bt-(nvl(:8,0)/1440))+Trunc(Round((/*bt*/bt-(nvl(:8,0)/1440)-/*da*/trunc(bt-(nvl(:8,0)/1440)))*cnt2,6))/cnt2 t,c1,c2,c3,point_id, sum(val*Decode(gf1,3,24/cnt1,1)) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0 and count(*)*cnt2=cnt1\r\nthen \'1\' else \'14\'||decode(count(*)*cnt2,cnt1,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1)+(nvl(:8,0)/1440),s2+(nvl(:8,0)/1440)))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,point_id,/*da*/trunc(bt-(nvl(:8,0)/1440)),/*da*/trunc(bt-(nvl(:8,0)/1440))+Trunc(Round((/*bt*/bt-(nvl(:8,0)/1440)-/*da*/trunc(bt-(nvl(:8,0)/1440)))*cnt2,6))/cnt2 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(252, 'ANY_AVG_OR_SUM_FROM_N_MIN_TOTALS', 'Stambesnių intervalų (iki paros) vidurkių arba sumos rodmenų generavimas iš augančių reikšmių, užfiksuotų kas n minučių', 'Stambesnių intervalų (iki paros) vidurkių arba sumos rodmenų generavimas iš augančių reikšmių, užfiksuotų kas n minučių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\ncnt2 number(5);\r\ngf2 number(2);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT md_cnt,aggf_id INTO cnt2,gf2 FROM st_ml where ml_id=:2;\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,bt+(nr-1)/cnt2 t,g/(et-bt)/Decode(gf2,3,24,cnt2) v\r\n,CASE WHEN Greatest(h1,h2)=0 AND (Round((et-bt)*cnt2,6)=1 OR g=0) THEN \'1\' ELSE \'14\' END s\r\nFROM\r\n(SELECT c1,c2,c3,da,bt, point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val g\r\n,has_specific_dstatus h1\r\n,Lead(has_specific_dstatus) over (PARTITION BY point_id,ml_id ORDER BY da,bt) h2\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2+1))\r\nWHERE NOT val IS NULL AND bt=da+Trunc(Round((bt-da)*cnt2,6))/cnt2\r\n) f,mou u,iger\r\nWHERE f.point_id=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\nAND nr<=round((et-bt)*cnt2,6) ) r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(253, 'MONTH_AVG_FROM_AVG_OF_DAYS', 'Mėnesio vidutinių rodmenų generavimas iš vidutinių rodmenų per parą', 'Mėnesio vidutinių rodmenų generavimas iš vidutinių rodmenų per parą', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(da,\'MM\') t,avg(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=Add_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\')\r\nthen \'1\' else \'14\'||decode(count(*),\r\nAdd_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\'),null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),Trunc(d.s1,\'MM\'),s2,0))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,Trunc(da,\'MM\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(254, 'DAY_BITOR_FROM_HOUR', 'Paros bitor rodmenų generavimas iš valandinių rodmenų', 'Paros bitor rodmenų generavimas iš valandinių rodmenų', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT /*+ materialize*/\r\nSEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3, da t,\r\n Max(Decode(bitand(val,Power(2,7)),Power(2,7),1,0))*Power(2,7)\r\n+Max(Decode(bitand(val,Power(2,6)),Power(2,6),1,0))*Power(2,6)\r\n+Max(Decode(bitand(val,Power(2,5)),Power(2,5),1,0))*Power(2,5)\r\n+Max(Decode(bitand(val,Power(2,4)),Power(2,4),1,0))*Power(2,4)\r\n+Max(Decode(bitand(val,Power(2,3)),Power(2,3),1,0))*Power(2,3)\r\n+Max(Decode(bitand(val,Power(2,2)),Power(2,2),1,0))*Power(2,2)\r\n+Max(Decode(bitand(val,Power(2,1)),Power(2,1),1,0))*Power(2,1)\r\n+Max(Decode(bitand(val,Power(2,0)),Power(2,0),1,0))*Power(2,0) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0 and count(*)=24\r\nthen \'1\' else \'14\'||decode(count(*),24,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(255, '30_MIN_AVG_FROM_INSTANT', 'Vidutinių rodmenų per 30 minučių generavimas iš momentinių rodmenų', 'Vidutinių rodmenų per 30 minučių generavimas iš momentinių rodmenų', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT /*+ materialize*/\r\nSEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT d.ib t,c1,c2,c3,point_id, Avg(val) v,\r\nCASE WHEN\r\n(d.ib+1/48<SYSDATE AND Count(DISTINCT(Trunc((bt - d.ib)*48*4)))\r\n>=4) THEN \'1\' ELSE \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\n a join (SELECT da y,da+(nr-1)/48 ib,da+nr/48 ie FROM days,iger WHERE nr<=48) d\r\nON (NOT y+1<=bt AND NOT y>=et AND NOT ie<=bt AND NOT ib>=et)\r\nWHERE NOT val IS NULL AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,point_id,d.ib )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(257, 'HOUR_AVG_FROM_30_MIN_AVG_WO_BYP', 'Vidutinių rodmenų per valandą generavimas iš vidutinių rodmenų per 30 minučių, be apeinamųjų taškų rodmenų įvertinimo', 'Vidutinių rodmenų per valandą generavimas iš vidutinių rodmenų per 30 minučių, be apeinamųjų taškų rodmenų įvertinimo', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nselect level BULK COLLECT INTO pNR from dual connect by level<=mi;\r\nDELETE GTTT;\r\nFORALL j in 1..mi\r\nINSERT INTO GTTT (id0,id1) values (pNR(j),sPL_ID(j));\r\nSELECT d\r\nBULK COLLECT INTO s1\r\nFROM\r\n(SELECT /*+ use_nl(a b c) index(c plep_pk)*/ id0,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END d\r\nFROM\r\ngttt a\r\nleft join plu b ON (a.id1=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.id1=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY id0\r\nORDER BY id0);\r\nDELETE GTTT;\r\nFORALL j IN 1..mi\r\nINSERT INTO gttt (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT NULL,NULL,sPL_ID(j),sSEP_ID(j),Trunc(bt,\'HH\'),\'\'\r\n,Avg(val),Nvl(:7,0),Decode(Max(HAS_SPECIFIC_DSTATUS),0,\'1\',\'14\'),SYSDATE,\'\'\r\n,sAGGS_TYPE_ID(j) FROM v_ar_wo_byp\r\nWHERE point_id=sPOINT_ID(j) AND ml_id=:1 AND da>=Trunc(s1(j)) AND bt>=s1(j) AND da<s2\r\nAND NOT val IS NULL\r\nGROUP BY Trunc(bt,\'HH\')\r\nHAVING Count(*)=2;\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8  AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(261, 'DAY_MAX_FROM_HOUR_MAX', 'Maksimalių reikšmių per dieną generavimas iš maksimalių reikšmių per valandą', 'Maksimalių reikšmių per dieną generavimas iš maksimalių reikšmių per valandą', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,MAX(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=24\r\nthen \'1\' else \'14\'||decode(count(*),24,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(262, 'DAY_MIN_FROM_HOUR_MIN', 'Minimalių reikšmių per dieną generavimas iš minimalių reikšmių per valandą', 'Minimalių reikšmių per dieną generavimas iš minimalių reikšmių per valandą', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,MIN(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=24\r\nthen \'1\' else \'14\'||decode(count(*),24,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,da )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(263, 'HOUR_MAX_FROM_INSTANT', 'Maksimalių reikšmių per valandą generavimas iš momentinių rodmenų', 'Maksimalių reikšmių per valandą generavimas iš momentinių rodmenų', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,TRUNC(bt, \'HH\') t,MAX(val) v,\r\nCASE WHEN (\r\nTRUNC(bt,\'HH\')+1/24<SYSDATE AND Count(DISTINCT(Trunc((bt - TRUNC(bt, \'HH\'))*24*4)))\r\n>=4) THEN \'1\' ELSE \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,TRUNC(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(264, 'HOUR_MIN_FROM_INSTANT', 'Minimalių reikšmių per valandą generavimas iš momentinių rodmenų', 'Minimalių reikšmių per valandą generavimas iš momentinių rodmenų', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,TRUNC(bt, \'HH\') t,MIN(val) v,\r\nCASE WHEN (\r\nTRUNC(bt,\'HH\')+1/24<SYSDATE AND Count(DISTINCT(Trunc((bt - TRUNC(bt, \'HH\'))*24*4)))\r\n>=4) THEN \'1\' ELSE \'14\' end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),d.s1,s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,TRUNC(bt,\'HH\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(265, 'MONTH_MAX_FROM_DAY_MAX', 'Maksimalių reikšmių per mėnesį generavimas iš maksimalių reikšmių per dieną', 'Maksimalių reikšmių per mėnesį generavimas iš maksimalių reikšmių per dieną', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT\r\nSEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(da,\'MM\') t,MAX(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=Add_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\')\r\nthen \'1\' else \'14\'||decode(count(*),\r\nAdd_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\'),null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,Trunc(da,\'MM\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(266, 'MONTH_MIN_FROM_DAY_MIN', 'Minimalių reikšmių per mėnesį generavimas iš minimalių reikšmių per dieną', 'Minimalių reikšmių per mėnesį generavimas iš minimalių reikšmių per dieną', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,Trunc(da,\'MM\') t,MIN(val) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0\r\nand count(*)=Add_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\')\r\nthen \'1\' else \'14\'||decode(count(*),\r\nAdd_Months(Trunc(da,\'MM\'),1)-Trunc(da,\'MM\'),null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL  AND has_specific_dstatus=0\r\nGROUP BY c1,c2,c3,Trunc(da,\'MM\') )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(267, 'HOPELESS', 'Beviltiškos skylės', 'Beviltiškos skylės', NULL, NULL, 'SELECT /*+ parallel(a)*/p.point_id FROM\r\npoint p\r\njoin pl b ON (p.point_id=b.point_id)\r\njoin di i ON (b.pl_id=i.pl_id)\r\njoin plep a ON (b.pl_id=a.pl_id)\r\nleft JOIN src_pw_tmst t ON (p.POINT_ID=t.point_id AND t.id=3 AND pw_rt>Trunc(SYSDATE)-:1)\r\nleft join (SELECT new_val point_id\r\nFROM au join tab USING (tab_id) join au_idata USING (db_time,au_nr) join col USING (col_id)\r\nWHERE tab_name=\'SRC\' AND operation_type=\'I\' AND db_time>SYSDATE-1\r\nAND col_name = \'POINT_ID\' AND NOT new_val IS null) s ON (p.point_id=s.point_id)\r\nWHERE plep_bt>= Trunc(SYSDATE)-:1 and point_enabled=1\r\nAND point_auto_read_enabled=1 AND pl_enabled=1\r\nAND s.point_id IS null\r\nAND di_enabled=1 group by p.point_id having max(Nvl(s_any,0))=0 AND Max(t.point_id) IS NULL', NULL, NULL, 1),
	(268, 'POLYDYNAMIC_ON_GR_FLEXFIELD_MANAGEMENT', 'Polidinaminių grupių, sudarytų pagal grupių dinamiškai pildomus laukus sudėties pildymas/valymas', 'Polidinaminių grupių, sudarytų pagal grupių dinamiškai pildomus laukus sudėties pildymas/valymas', 'ans VARCHAR2(250);\r\npBGA_TYPE_ID NUMBER;\r\npSCH_ID NUMBER;', 'FOR t IN (SELECT\r\nGR_ID, GR_CODE, (SELECT GR_TYPE_ID FROM GR_TYPE WHERE GR_TYPE_CODE=\'SYSTEM\') GR_TYPE_ID, GR_NAME FROM gr WHERE gr_code = :2\r\n) LOOP\r\nFOR h IN (\r\nSELECT co, MAX(co2) co2, Max(na)na,Max(gr_id)gr_id,Sum(cf)r FROM (\r\nSELECT DISTINCT 1 cf, t.gr_code||\'_\'||OBJECT_VALUE co, OBJECT_VALUE co2, OBJECT_VALUE_DESC na, \'\'+0 gr_id FROM ST_FFP_GR2\r\nwhere ffp_val_row_num=:1\r\nUNION ALL\r\nSELECT -1 cf, gr_code co,\'\' co2,\'\' na, gr_id FROM gr b where gr_id in (select comp_id from grc where cont_id=t.gr_id)\r\n) GROUP BY co having Sum(cf)!=0\r\n) LOOP\r\nIF h.r=1 THEN\r\nselect nvl(sch_id,(SELECT sch_id FROM st_sch WHERE sch_per_code = \'DD\' and sch_per_value=1 AND ROWNUM=1)) INTO pSCH_ID from bga where bga_id=:0;\r\nSELECT BGA_TYPE_ID INTO pBGA_TYPE_ID FROM BGA_TYPE WHERE BGA_TYPE_CODE=\'GROUPS_BY_FLEXFIELD\';\r\nans:=gr_i(t.GR_TYPE_ID,h.co,1,h.na);\r\nFOR g IN (SELECT gr_id FROM gr WHERE gr_code=h.co) LOOP\r\nans:=grc_i(t.gr_id,g.gr_id);\r\nans:=bga_i(pBGA_TYPE_ID,t.GR_NAME||\'.\'||h.na,1,pSCH_ID,g.GR_ID);\r\nFOR b IN (SELECT bga_id FROM bga WHERE bga_name=t.GR_NAME||\'.\'||h.na) LOOP\r\nans:=bga_param_i(b.BGA_ID,1,:1);\r\nans:=bga_param_i(b.BGA_ID,2,h.co2);\r\nEND LOOP;\r\nEND LOOP;\r\nELSIF h.r=-1 then\r\nans:=gr_d(h.gr_id);\r\nEND IF;\r\nEND LOOP;\r\nEND LOOP;', NULL, NULL, NULL, 1),
	(269, 'POLYDYNAMIC_ON_POINT_FLEXFIELD_MANAGEMENT', 'Polidinaminių grupių, sudarytų pagal taškų dinamiškai pildomus laukus sudėties pildymas/valymas', 'Polidinaminių grupių, sudarytų pagal taškų dinamiškai pildomus laukus sudėties pildymas/valymas', 'ans VARCHAR2(250);\r\npBGA_TYPE_ID NUMBER;\r\npSCH_ID NUMBER;', 'FOR t IN (SELECT\r\nGR_ID, GR_CODE, (SELECT GR_TYPE_ID FROM GR_TYPE WHERE GR_TYPE_CODE=\'SYSTEM\') GR_TYPE_ID, GR_NAME FROM gr WHERE gr_code = :2\r\n) LOOP\r\nFOR h IN (\r\nSELECT co, Max(co2) co2, Max(na)na,Max(gr_id)gr_id,Sum(cf)r FROM (\r\nSELECT DISTINCT 1 cf, t.gr_code||\'_\'||OBJECT_VALUE co, OBJECT_VALUE co2, OBJECT_VALUE_DESC na, \'\'+0 gr_id FROM ST_FFP_POINT2\r\nwhere ffp_val_row_num=:1\r\nUNION ALL\r\nSELECT -1 cf, gr_code co, \'\' co2, \'\' na, gr_id FROM gr b where gr_id in (select comp_id from grcj where cont_id=t.gr_id)\r\n) GROUP BY co having Sum(cf)!=0\r\n) LOOP\r\nIF h.r=1 THEN\r\nselect nvl(sch_id,(SELECT sch_id FROM st_sch WHERE sch_per_code = \'DD\' and sch_per_value=1 AND ROWNUM=1)) INTO pSCH_ID from bga where bga_id=:0;\r\nSELECT BGA_TYPE_ID INTO pBGA_TYPE_ID FROM BGA_TYPE WHERE BGA_TYPE_CODE=\'POINTS_BY_FLEXFIELD\';\r\nans:=gr_i(t.GR_TYPE_ID,h.co,1,h.na);\r\nFOR g IN (SELECT gr_id FROM gr WHERE gr_code=h.co) LOOP\r\nans:=grc_i(t.gr_id,g.gr_id);\r\nans:=bga_i(pBGA_TYPE_ID,t.GR_NAME||\'.\'||h.na,1,pSCH_ID,g.GR_ID);\r\nFOR b IN (SELECT bga_id FROM bga WHERE bga_name=t.GR_NAME||\'.\'||h.na) LOOP\r\nans:=bga_param_i(b.BGA_ID,1,:1);\r\nans:=bga_param_i(b.BGA_ID,2,h.co2);\r\nEND LOOP;\r\nEND LOOP;\r\nELSIF h.r=-1 then\r\nans:=gr_d(h.gr_id);\r\nEND IF;\r\nEND LOOP;\r\nEND LOOP;', NULL, NULL, NULL, 1),
	(270, 'GROUPS_BY_FLEXFIELD', 'Dinaminės grupės, sudarytos pagal grupių dinamiškai pildomus laukus', 'Dinaminės grupės, sudarytos pagal grupių dinamiškai pildomus laukus', NULL, NULL, 'SELECT \'-\'||gr_id FROM ST_FFP_GR2 where ffp_val_row_num=:1 and object_value=:2', NULL, NULL, 1),
	(271, 'POINTS_BY_FLEXFIELD', 'Dinaminės grupės, sudarytos pagal taškų dinamiškai pildomus laukus', 'Dinaminės grupės, sudarytos pagal taškų dinamiškai pildomus laukus', NULL, NULL, 'SELECT point_id FROM ST_FFP_POINT2 where ffp_val_row_num=:1 and object_value=:2', NULL, NULL, 1),
	(276, 'INDICATOR_FROM_MIN_FIX_TOTALS', 'Rodiklio generavimas iš augančių reikšmių', 'Rodiklio generavimas iš augančių reikšmių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npDS_ID number;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\n  FROM GEN_IDs\r\n WHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n             FROM spty\r\n            WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n  FETCH c_ROWS\r\n  BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\n  LIMIT pGF;\r\n  EXIT WHEN sPL_ID.Count=0;\r\n  select DS_ID into pDS_ID FROM DS WHERE ds_code=:8 and DS_ENABLED=1;\r\n  delete gttt;\r\n  FORALL j IN 1..sPOINT_ID.count\r\n  insert into gttt(id1,id2,v1,id3,d1,d2)\r\n  select b.point_id,b.ml_id,b.val,b.has_specific_dstatus,b.bt,b.da\r\n   from v_ar b where  b.point_id=sPOINT_ID(j)and b.ml_id=:1 AND da >=NVL(:4,sysdate - :3)- 1/24\r\n  AND da <=NVL(:5,SYSDATE)and val is not null;\r\n  FORALL j IN 1..sPL_ID.count\r\n  INSERT INTO gttt\r\n  (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\n  with k as (select /*+ materialize */ a.*,trunc(a.new_ds_et,\'MI\')\r\n  tm_new_ds_et from (select lead(a.ds_bt)over (partition by a.ds_id order by a.ds_bt)as new_ds_et ,a.* from (select\r\n  a.ds_id,a.ds_t ds_bt ,trunc(a.ds_t,\'MI\')tm_ds_bt ,trunc(a.ds_t,\'DD\')td_ds_bt from v_AR_DS_PLAIN a\r\n  where a.ds_id=pDS_ID and a.ds_v=1 AND a.ds_t >=NVL(:4,sysdate-:3)-1/24 AND a.ds_t <=NVL(:5,SYSDATE))a)a),ar as (\r\n  select /*+ materialize */ id1  point_id,id2 ml_id,v1 val,id3 has_specific_dstatus,d1 bt,d2 da from gttt) SELECT\r\n  NULL,NULL,sPL_ID(j),sSEP_ID(j),ds_bt,\'\',round(val - prev_val,6)v,Nvl(:7,0)\r\n  ,case when greatest(prev_has_specific_dstatus,has_specific_dstatus)=0 then 1 else 14 end,SYSDATE,\'\',sAGGS_TYPE_ID(j)\r\n  FROM(select lag(val) over (partition by point_id order by bt)prev_val,lag(has_specific_dstatus)over (partition by\r\n  point_id order by bt)prev_has_specific_dstatus ,m.* from (select k.* from (select rank() over (partition by\r\n  point_id,ds_id,ds_bt,new_ds_et order by bt)rnk ,j.* from ( select a.ds_id,a.ds_bt,a.new_ds_et,b.* from ar b\r\n  join k a on (b.bt>=a.tm_ds_bt and b.bt<=a.tm_new_ds_et and a.td_ds_bt=b.da))j)k where rnk=1)m)n\r\n  where round(val - prev_val,6)IS not NULL;\r\n  SELECT\r\n  d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\n  BULK COLLECT INTO\r\n  pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\n  FROM gttt f\r\n  WHERE f.id8 is not null --/7 and not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(277, 'AUTO_UPDATE_PMA_FROM_TMPL', 'Automatinis taškų monitoringo šablonų taikymas', 'Automatinis taškų monitoringo šablonų taikymas', '  TS date;\r\n  ans2 varchar2(250);\r\n  CURSOR pls(last_ number, code varchar2) IS\r\n  SELECT point_id, PMA_TMPL_id\r\n  FROM\r\n  (SELECT PMA_TMPL_id, POINT_id FROM ST_POINT_MAU_PMA_TMPL\r\n  WHERE PMA_TMPL_CODE=nvl(code,PMA_TMPL_CODE)\r\n  and POINT_id>last_  ORDER BY POINT_id);\r\nlast_POINT_id NUMBER;\r\nmax_POINT_id  number;\r\nlast_POINT    number;\r\npPOINT_ID     T7.IRR;\r\npPMA_TMPL_ID     T7.IRR;\r\npC         T7.CRR;  pP   T7.IRR;\r\nj number;\r\nx number; f number;\r\nmi number; jau number; c_POINT_id number;', 'TS := SYSDATE; f:=0;  jau:=0;\r\nSELECT count(POINT_id)\r\n  into c_POINT_id\r\n  FROM ST_POINT_MAU_PMA_TMPL\r\n  WHERE PMA_TMPL_CODE=nvl(:2,PMA_TMPL_CODE);\r\nif c_POINT_id >0 then\r\nSELECT max(POINT_id)\r\n  into max_POINT_id\r\n  FROM ST_POINT_MAU_PMA_TMPL\r\n  WHERE PMA_TMPL_CODE=nvl(:2,PMA_TMPL_CODE);\r\nWHILE not (SYSDATE > TS + nvl(:1,120) / 86400) and jau=0 LOOP\r\nLAST_point:=0;\r\nSELECT NVL ((select ARG_1 FROM TMST WHERE TMST_CODE =\'AUTO_UPDATE_PMA_FROM_TMPL\'), 0)\r\nINTO LAST_point\r\nFROM DUAL;\r\n OPEN pls(LAST_POINT,:2);\r\n  LOOP\r\n  pPOINT_ID.delete;\r\n  pPMA_TMPL_ID.delete;\r\n  mi:=0;\r\n  FETCH pls BULK COLLECT INTO pPOINT_ID,pPMA_TMPL_ID limit 100;\r\n  mi:=pPOINT_ID.Count;\r\n  EXIT WHEN mi = 0;\r\n    for i in 1..mi loop\r\n      j:=i;\r\n        ans2:=MA_FROM_PMA_TMPL_UI(pPMA_TMPL_ID(i),pPOINT_ID(i));\r\n        if ans2<>\'0\' then\r\n          ans2:=substr(\'MA_FROM_PMA_TMPL_UI [\'||pPMA_TMPL_ID(i)||\'] [\'||pPOINT_ID(i)||\'] \'||substr(ans2,2,249),1,249);\r\n          f:=f+1;pC(f):=ans2; pP(f):=pPOINT_ID(i);\r\n        end if;\r\n        if SYSDATE > TS + nvl(:1,120) / 86400 then\r\n           last_POINT_id:=pPOINT_ID(i);\r\n          exit;\r\n        end if;\r\n    end loop;\r\n last_POINT_id:=pPOINT_ID(j);\r\n EXIT WHEN  (SYSDATE > TS + nvl(:1,120) / 86400);\r\nEND LOOP;\r\nclose pls;\r\nif last_POINT_id=max_POINT_id then jau:=1;\r\n    UPDATE TMST A SET A.AMP = sysdate, ARG_1=0\r\n    WHERE A.TMST_CODE=\'AUTO_UPDATE_PMA_FROM_TMPL\';\r\n    INSERT INTO TMST(TMST_CODE,AMP,ARG_1)\r\n     select \'AUTO_UPDATE_PMA_FROM_TMPL\',sysdate,0 from dual\r\n    where not exists (select 0 from tmst where TMST_CODE=\'AUTO_UPDATE_PMA_FROM_TMPL\');\r\n else\r\n    UPDATE TMST A SET ARG_1=last_POINT_id, A.AMP=sysdate\r\n    WHERE A.TMST_CODE=\'AUTO_UPDATE_PMA_FROM_TMPL\';\r\n    INSERT INTO TMST(TMST_CODE,AMP,ARG_1)\r\nselect \'AUTO_UPDATE_PMA_FROM_TMPL\',sysdate,last_POINT_id from dual\r\n    where not exists (select 0 from tmst where TMST_CODE=\'AUTO_UPDATE_PMA_FROM_TMPL\');\r\n end if;\r\ncommit; END LOOP; for i in 1..f loop event_i(1,1,1,1,SYSDATE,pC(i),3,null,null,null,pP(i)); end loop; commit; end if;', NULL, NULL, NULL, 67),
	(278, 'AUTO_UPDATE_GMA_FROM_TMPL', 'Automatinis grupių monitoringo šablonų taikymas', 'Automatinis grupių monitoringo šablonų taikymas', '  TS date;\r\n  ans2 varchar2(250);\r\n  CURSOR pls(last_ number, code varchar2) IS\r\n  SELECT GR_id, GMA_TMPL_id\r\n  FROM\r\n  (SELECT GMA_TMPL_id, GR_id FROM ST_GR_MAU_GMA_TMPL\r\n  WHERE GMA_TMPL_CODE=nvl(code,GMA_TMPL_CODE)\r\n  and GR_id>last_  ORDER BY GR_id);\r\nlast_GR_id NUMBER;\r\nmax_GR_id  number;\r\nlast_POINT    number;\r\npGR_ID     T7.IRR;\r\npGMA_TMPL_ID     T7.IRR;\r\npC         T7.CRR;  pG   T7.IRR;\r\nj number;\r\nx number; f number;\r\nmi number;  jau number; c_GR_id number;', 'TS := SYSDATE; f:=0;  jau:=0;\r\nSELECT count(GR_id)\r\n  into c_GR_id\r\n  FROM ST_GR_MAU_GMA_TMPL\r\n  WHERE GMA_TMPL_CODE=nvl(:2,GMA_TMPL_CODE);\r\nif c_GR_id >0 then\r\nSELECT max(GR_id)\r\n  into max_GR_id\r\n  FROM ST_GR_MAU_GMA_TMPL\r\n  WHERE GMA_TMPL_CODE=nvl(:2,GMA_TMPL_CODE);\r\nWHILE not (SYSDATE > TS + nvl(:1,120) / 86400) and jau=0 LOOP\r\nLAST_point:=0;\r\nSELECT NVL ((select ARG_1 FROM TMST WHERE TMST_CODE =\'AUTO_UPDATE_GMA_FROM_TMPL\'), 0)\r\nINTO LAST_point\r\nFROM DUAL;\r\n OPEN pls(LAST_POINT,:2);\r\n  LOOP\r\n  pGR_ID.delete;\r\n  pGMA_TMPL_ID.delete;\r\n  mi:=0;\r\n  FETCH pls BULK COLLECT INTO pGR_ID,pGMA_TMPL_ID limit 100;\r\n  mi:=pGR_ID.Count;\r\n  EXIT WHEN mi = 0;\r\n    for i in 1..mi loop\r\n      j:=i;\r\n        ans2:=MA_FROM_GMA_TMPL_UI(pGMA_TMPL_ID(i),pGR_ID(i));\r\n        if ans2<>\'0\' then\r\n          ans2:=substr(\'MA_FROM_GMA_TMPL_UI [\'||pGMA_TMPL_ID(i)||\'] [\'||pGR_ID(i)||\'] \'||substr(ans2,2,249),1,249);\r\n          f:=f+1;pC(f):=ans2; pG(f):=pGR_ID(i);\r\n        end if;\r\n        if SYSDATE > TS + nvl(:1,120) / 86400 then\r\n           last_GR_id:=pGR_ID(i);\r\n          exit;\r\n        end if;\r\n    end loop;\r\n last_GR_id:=pGR_ID(j);\r\n EXIT WHEN  (SYSDATE > TS + nvl(:1,120) / 86400);\r\nEND LOOP;\r\nclose pls;\r\nif last_GR_id=max_GR_id then jau:=1;\r\n    UPDATE TMST A SET A.AMP = sysdate, ARG_1=0\r\n    WHERE A.TMST_CODE=\'AUTO_UPDATE_GMA_FROM_TMPL\';\r\n    INSERT INTO TMST(TMST_CODE,AMP,ARG_1)\r\n     select \'AUTO_UPDATE_GMA_FROM_TMPL\',sysdate,0 from dual\r\n    where not exists (select 0 from tmst where TMST_CODE=\'AUTO_UPDATE_GMA_FROM_TMPL\');\r\n else\r\n    UPDATE TMST A SET ARG_1=last_GR_id, A.AMP=sysdate\r\n    WHERE A.TMST_CODE=\'AUTO_UPDATE_GMA_FROM_TMPL\';\r\n    INSERT INTO TMST(TMST_CODE,AMP,ARG_1)\r\nselect \'AUTO_UPDATE_GMA_FROM_TMPL\',sysdate,last_GR_id from dual\r\n    where not exists (select 0 from tmst where TMST_CODE=\'AUTO_UPDATE_GMA_FROM_TMPL\');\r\n end if;\r\ncommit; END LOOP; for i in 1..f loop event_i(1,1,1,1,SYSDATE,pC(i),3,null,null,null,null,pG(i)); end loop; commit; end if;', NULL, NULL, NULL, 67),
	(281, 'AUTO_DELETE_ALL_FROM_UTL', 'Periodinis automatinis senų nevykdytų skubių ryšio užduočių trynimas', 'Periodinis automatinis senų nevykdytų skubių ryšio užduočių trynimas', 'rows_cnt NUMBER;', 'UPDATE rodo SET src_id=NULL WHERE rodo_id IN (SELECT rodo_id FROM utl) AND db_time<SYSDATE-:1/24;\r\nDELETE utl WHERE rodo_id IN (SELECT rodo_id FROM rodo WHERE db_time<SYSDATE-:1/86400);\r\nrows_cnt:=SQL%ROWCOUNT;\r\nIF rows_cnt>0 THEN\r\nevent_i(1,1,4540,1,sysdate,getcaption(288,rows_cnt,:1));\r\nEND IF;COMMIT;', NULL, NULL, NULL, 56),
	(282, 'AUTO_DELETE_ALL_FROM_SMS_LOG', 'Automatinis išsiųstų SMS pranešimų žurnalo įrašų trynimas', 'Automatinis išsiųstų SMS pranešimų žurnalo įrašų trynimas', 'CURRTMST DATE;\r\npPL_ID T7.IRR;\r\npPL_T T7.DRR;\r\npAGGS_TYPE_ID T7.IRR;\r\npDB_TIME T7.DRR;\r\nI NUMBER;\r\nJ NUMBER;\r\nTS DATE;\r\nDELETED_ROWS_COUNTF NUMBER;\r\nDELETED_ROWS_COUNT_ALL NUMBER;\r\nANS VARCHAR2(250);\r\nmaximum number;\r\nlimit_for_select number;\r\nep INTEGER;\r\npBGA_TYPE_CODE VARCHAR(250):=\'AUTO_DELETE_ALL_FROM_SMS_LOG\';\r\n', 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_ALL_FROM_SMS_LOG\')\r\n, TRUNC ((SYSDATE-interval \'5\' year), \'Y\')) INTO CURRTMST FROM DUAL;LIMIT_FOR_SELECT:=nvl(:4,10000);\r\nTS := SYSDATE;DELETED_ROWS_COUNTF := 0;\r\nwhile (not (CURRTMST + nvl(:1,5) / 1440 > (SYSDATE-nvl(:2,31)) OR SYSDATE > TS + nvl(:3,45) / 86400))LOOP\r\ndelete from sms_log a\r\nWHERE A.DB_TIME < CURRTMST + nvl(:1,5) / 1440 AND ROWNUM<= LIMIT_FOR_SELECT;\r\nDELETED_ROWS_COUNTF := SQL%ROWCOUNT;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then\r\nCURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_ALL_FROM_SMS_LOG\' ;\r\nIF (SQL%ROWCOUNT = 0 )THEN\r\nINSERT INTO TMST(TMST_CODE, AMP) select \'AUTO_DELETE_ALL_FROM_SMS_LOG\',CURRTMST from dual\r\nwhere not exists (select 0 from tmst where TMST_CODE=\'AUTO_DELETE_ALL_FROM_SMS_LOG\');\r\nEND IF;END IF;END LOOP;COMMIT;\r\n', NULL, NULL, NULL, 56),
	(283, 'DAY_FIXED_TOTALS_FROM_MONTH_FIXED_AND_DAY_DATA', 'Fiksuotų kas parą suminių duomenų generavimas iš fiksuotų kas mėnesį ir parų duomenų', 'Fiksuotų kas parą suminių duomenų generavimas iš fiksuotų kas mėnesį ir parų duomenų', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 date;\r\ns2 date;\r\nL NUMBER;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nSELECT ML_ID\r\nINTO L\r\nFROM ML\r\nWHERE (MS_ID,DIR_ID,AGGS_ID,AGGF_ID,TFF_ID,MD_ID)\r\nIN (SELECT MS_ID,DIR_ID,AGGS_ID,AGGF_ID,TFF_ID,6\r\nFROM ML\r\nWHERE ML_ID = :2);\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0));\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM(SELECT c1,c2,c3,t,v\r\n,Decode(z,0,\'1\',\'14\') s FROM\r\n(SELECT c1,c2,c3,Decode(i,1,da,da+1) t\r\n,Max(Decode(i,1,val)) over (PARTITION BY point_id,m)+Decode(i,1,0,Sum(Decode(i,1,NULL,val)) over (PARTITION BY point_id,m ORDER BY da)) v\r\n,Decode(i,1,s,Max(s) over (PARTITION BY point_id,m ORDER BY da)) z,m,da from\r\n(SELECT a.*,Decode(val,NULL,2,has_specific_dstatus) s,Trunc(da,\'MM\') m,Decode(ml_id,L,1) i\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id, column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,L))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1,\'MM\'),s2))\r\n a )\r\n) WHERE z<2 AND m=Trunc(da+1,\'MM\'))r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(286, 'AUTO_DELETE_ALL_FROM_XDATA', 'Automatinis visų tarpinių eksporto formų duomenų įrašų trynimas', 'Automatinis visų tarpinių eksporto formų duomenų įrašų trynimas', 'TS DATE;\r\nlimit_for_select number;\r\n', 'LIMIT_FOR_SELECT:=nvl(:3,10000);	\r\nTS := SYSDATE;\r\n      WHILE (SYSDATE < TS + nvl(:2,45) / 86400)\r\n      LOOP\r\n        DELETE XDATA WHERE DB_TIME<SYSDATE-nvl(:1,2) AND DB_TIME < sysdate-1\r\n        AND ROWNUM<= LIMIT_FOR_SELECT;\r\n        IF SQL%ROWCOUNT = 0\r\n        THEN\r\n          EXIT;\r\n        END IF;\r\n      END LOOP;\r\ncommit;\r\n', NULL, NULL, NULL, 56),
	(287, 'ANY_FROM_RP', 'Sistemos monitoringo duomenų generavimas', 'Sistemos monitoringo duomenų generavimas', NULL, 'generate_using_rp(:0);', NULL, NULL, NULL, 26),
	(288, 'DAY_EXTREME_FROM_ANY', 'Paros ekstremumų rodmenų generavimas', 'Paros ekstremumų rodmenų generavimas', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nsAGGF_ID T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npEXTREME_T T7.DRR;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID,AGGF_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\nand aggs_id in (select aggs_id from ml where ml_id=:1);', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,sAGGF_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0),sAGGF_ID);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\',ex\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,pEXTREME_T\r\nFROM\r\n(SELECT c1,c2, c3, TRUNC(BT, \'DD\') t, val v,\r\nCASE WHEN ST=1 OR SYSDATE<aET THEN \'14\' ELSE \'1\' END s, CASE WHEN (select aggf_id from ml where ml_id=:1) IN (4,5) THEN EXTREME_BT ELSE BT END ex\r\nFROM (select a.*,\r\nrank() over (partition by point_id, ml_id, TRUNC(BT, \'DD\') order by HAS_SPECIFIC_DSTATUS, VAL desc, BT desc) rnkmx\r\n,rank() over (partition by point_id, ml_id, TRUNC(BT, \'DD\') order by HAS_SPECIFIC_DSTATUS, -VAL desc, BT desc) rnkmn\r\n,max(HAS_SPECIFIC_DSTATUS) over (PARTITION BY POINT_ID, ML_ID, TRUNC(BT, \'DD\')) st,\r\nTRUNC(BT, \'DD\')+1 aET\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,param1,\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\n a\r\n) where ((rnkmx=1 and c4=4) or (rnkmn=1 and c4=5)) and not val is null and not bt is null) r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans,pPCK_T,pPCK_N,pPCK_T,pPCK_N,pEXTREME_T);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(289, 'HOUR_EXTREME_FROM_ANY', 'Valandos ekstremumų rodmenų generavimas', 'Valandos ekstremumų rodmenų generavimas', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nsAGGF_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npEXTREME_T T7.DRR;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT /*+ materialize*/\r\nSEP_ID,PL_ID,POINT_ID,aggs_type_id,aggf_id\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\nand aggs_id in (select aggs_id from ml where ml_id=:1);', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,sAGGF_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0),sAGGF_ID);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\',ex\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,pEXTREME_T\r\nFROM\r\n(SELECT c1,c2, c3, TRUNC(BT,\'HH\') t, val v,\r\nCASE WHEN ST=1 OR SYSDATE<aET THEN \'14\' ELSE \'1\' END s, CASE WHEN (select aggf_id from ml where ml_id=:1) IN (4,5) THEN EXTREME_BT ELSE BT END ex\r\nFROM (select a.*,\r\nrank() over (partition by point_id,ml_id,TRUNC(BT,\'HH\') order by HAS_SPECIFIC_DSTATUS,VAL desc,BT desc) rnkmx\r\n,rank() over (partition by point_id,ml_id,TRUNC(BT,\'HH\') order by HAS_SPECIFIC_DSTATUS,-VAL desc,BT desc) rnkmn\r\n,max(HAS_SPECIFIC_DSTATUS) over (PARTITION BY POINT_ID,ML_ID,TRUNC(BT,\'DD\')) st,\r\nTRUNC(BT,\'HH\')+1/24 aET\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,param1,\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\n a\r\n) where ((rnkmx=1 and c4=4) or (rnkmn=1 and c4=5)) and not val is null and not bt is null ) r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans,pPCK_T,pPCK_N,pPCK_T,pPCK_N,pEXTREME_T);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(290, 'MONTH_EXTREME_FROM_ANY', 'Mėnesio ekstremumų rodmenų generavimas', 'Mėnesio ekstremumų rodmenų generavimas', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nsAGGF_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npEXTREME_T T7.DRR;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID,AGGF_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\nand aggs_id in (select aggs_id from ml where ml_id=:1);', 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\n FETCH c_ROWS\r\n BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,sAGGF_ID\r\n LIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0),sAGGF_ID);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\',ex\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,pEXTREME_T\r\nFROM\r\n(SELECT c1,c2, c3, TRUNC(BT, \'MM\') t, val v,\r\nCASE WHEN ST=1 OR SYSDATE<aET THEN \'14\' ELSE \'1\' END s, CASE WHEN (select aggf_id from ml where ml_id=:1) IN (4,5) THEN EXTREME_BT ELSE BT END ex\r\nFROM (select a.*,\r\nrank() over (partition by point_id, ml_id, TRUNC(BT, \'MM\') order by HAS_SPECIFIC_DSTATUS, VAL desc, BT desc) rnkmx\r\n,rank() over (partition by point_id, ml_id, TRUNC(BT, \'MM\') order by HAS_SPECIFIC_DSTATUS, -VAL desc, BT desc) rnkmn\r\n,max(HAS_SPECIFIC_DSTATUS) over (PARTITION BY POINT_ID, ML_ID, TRUNC(BT, \'DD\')) st,\r\nADD_MONTHS(TRUNC(BT, \'MM\'),1) aET\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,param1,\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\n a\r\n) where ((rnkmx=1 and c4=4) or (rnkmn=1 and c4=5)) and not val is null and not bt is null) r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans,pPCK_T,pPCK_N,pPCK_T,pPCK_N,pEXTREME_T);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(291, 'PL_SE_POST_PROCESSING', 'Automatinis nuskaitymo konfigūracijos tikrinimas', 'Automatinis nuskaitymo konfigūracijos tikrinimas', 'vd1 date; vd2 date; orn number; ans t7.crr;ePOINT_ID t7.irr;pPOINT_ID t7.irr;', 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'PL_SE_POST_PROCESSING\'),add_months(sysdate,-12)),sysdate-10/1440 INTO vd1,vd2 FROM DUAL;\r\ndelete gttt;\r\ninsert into gttt (id1,id2)\r\nselect * from (\r\nWITH\r\nf as\r\n(\r\nSELECT /*+materialize*/ src_id,db_time FROM\r\n(SELECT new_val src_id, Max(db_time) db_time\r\nFROM au join tab USING (tab_id) join au_idata USING (db_time,au_nr) join col USING (col_id)\r\nWHERE tab_name = \'SE\' AND operation_type=\'I\' AND db_time>=vD1 AND db_time<vD2 AND col_name= \'SRC_ID\' AND :1 IS NULL\r\nGROUP BY new_val\r\nUNION ALL\r\nSELECT src_id, To_Date(NULL) FROM src_pw_tmst WHERE id=1 AND pck_t BETWEEN SYSDATE-2/24 AND SYSDATE-1/48 AND :1 IS NULL\r\nUNION ALL\r\nSELECT To_Number(:1),sysdate FROM dual WHERE NOT :1 IS null)\r\n)\r\n,s AS\r\n(SELECT a.src_id,c.point_id\r\nfrom f a\r\njoin src b on (a.src_id=b.src_id)\r\njoin src_pw_tmst c ON (b.src_id = c.src_id AND c.id IN (1,3,5,6))\r\nWHERE b.src_et IS NULL\r\nGROUP BY a.src_id,c.point_id\r\nHAVING Max(Decode(c.id,1,1))=1\r\nAND\r\n(Max(Decode(c.id,3,pw_rt)) is NULL\r\nOR Max(Decode(c.id,3,pw_rt))<Max(a.db_time)\r\nOR Max(Decode(c.id,3,pw_rt))<Max(Decode(c.id,5,pw_rt,6,pw_rt))\r\n)\r\n)\r\nSELECT s.src_id, s.point_id FROM\r\ns\r\nJOIN pl a ON (a.point_id=s.point_id)\r\nJOIN di i ON (a.pl_id=i.pl_id)\r\nJOIN se e ON (s.src_id=e.src_id AND e.di_id=i.di_id)\r\nJOIN sep p ON (e.se_id=p.se_id)\r\nGROUP BY s.src_id, s.point_id\r\n);\r\npwl_execute;\r\nUPDATE gttt r SET id4=1 WHERE NOT EXISTS (SELECT 0 FROM V_LPTY_MISSING V WHERE R.ID1 = V.SRC_ID AND NVL(V.POINT_ID,R.ID2)=R.ID2);\r\nMERGE INTO src_pw_tmst y\r\nUSING (SELECT id1,id2 FROM gttt WHERE id4=1) u\r\nON (y.src_id = u.id1 AND y.point_id=u.id2 AND y.id=3)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.pw_rt=sysdate\r\n,y.pck_t=sysdate\r\nWHEN NOT MATCHED THEN INSERT\r\n(y.src_id\r\n,y.point_id\r\n,y.id\r\n,y.pw_rt\r\n,y.pck_t\r\n) values (\r\n u.id1\r\n,u.id2\r\n,3\r\n,sysdate\r\n,sysdate\r\n);\r\nIF :1 IS NULL then\r\nSELECT id2 bulk collect into ePOINT_ID FROM gttt WHERE id4=1;\r\nFOR i IN 1..ePOINT_ID.Count LOOP\r\nSELECT ePOINT_ID(i),\'0\' BULK COLLECT INTO pPOINT_ID,ans FROM dual;\r\ninit_fill_point3(pPOINT_ID,ans,orn);\r\n if ans(1)=\'0\' then\r\n  INSERT INTO DTL (DB_TIME,REQ_TYPE_CODE,RODO_ID,URGENT)\r\n  select sysdate, REQ_TYPE_CODE, orn, 0 from rc where rc_id=16;\r\n end if;\r\nEND LOOP;\r\nMERGE INTO TMST y\r\n   USING (   SELECT \'PL_SE_POST_PROCESSING\' TMST_CODE,vd2 amp FROM dual) u\r\n   ON (y.TMST_CODE = u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\n y.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n (\r\n y.TMST_CODE\r\n,y.amp\r\n) values (\r\n u.TMST_CODE\r\n,u.amp\r\n);\r\nEND IF;', NULL, NULL, NULL, 62),
	(296, 'DTL_EXECUTE', 'Atlikti ankščiau paruoštas eilės užduotis', 'Atlikti ankščiau paruoštas eilės užduotis', NULL, 'dtl_execute;', NULL, NULL, NULL, 62),
	(297, 'PW_SETTING_POST_PROCESSING', 'Tolesnis nuskaitytų skaitiklio parametrų apdorojimas', 'Tolesnis nuskaitytų skaitiklio parametrų apdorojimas', 'a varchar2(250);\r\nhit number(1):=0;\r\norn number;', 'a:=prepare_scaler_read.run(:1);\r\nif a=\'0\' then\r\nhit:=1;\r\nend if;\r\npwo_execute(:1,:2,a);\r\nif a=\'0\' then\r\nhit:=1;\r\nDELETE gttt;\r\nINSERT INTO gttt (id1,id2,c1) VALUES (:1,:2,\'S\');\r\npwl_execute;\r\nend if;\r\nif hit=1 THEN\r\nCOMMIT;\r\ninit_fill_point1(:2,a,orn,pONLY_CFG=>1);\r\nif a=\'0\' then\r\nINSERT INTO ltl (req_type_code, rodo_id)\r\nSELECT req_type_code,orn FROM rc WHERE rc_id=5;\r\nelse\r\ncheck_pw_setting (:1,:2);\r\na:=read_point_journal(:2,:1);\r\nend if;\r\nelse\r\ncheck_pw_setting (:1,:2);\r\na:=read_point_journal(:2,:1);\r\nend if;', NULL, NULL, NULL, 62),
	(298, 'PWM_EXECUTE', 'Taško matavimo linijų pildymas pagal skaitiklio parametrus', 'Taško matavimo linijų pildymas pagal skaitiklio parametrus', 'a varchar2(250 char);', 'pwm_execute(:1,:2);', 'SELECT 0 FROM dual WHERE EXISTS (SELECT 0 FROM gttn2 WHERE id1=-9)', 'commit; a:=src_from_tmpl_u(:1);', NULL, 62),
	(299, 'CREATE_LINK_CONFIGURATION_FOR_UNREGISTERED_METER', 'Nuskaitymo konfigūracijos sukūrimas neužregistruotiems skaitikliams', 'Nuskaitymo konfigūracijos sukūrimas neužregistruotiems skaitikliams', 'a VARCHAR2(250);\r\npPH_ID NUMBER;\r\npDP_ID NUMBER;\r\npSRC_TMPL_ID NUMBER;\r\npPOINT_ID T7.IRR;\r\nA1 T7.CRR;\r\norn NUMBER;', 'IF :2 IS NULL THEN\r\nFOR t IN (select a.*,CASE WHEN NOT FLEX_FIELD99 IS NULL THEN FLEX_FIELD99||\', \'END||a.point_code name,src_tmpl_id,regexp_replace(:3,\'.*(IP=(.+)).*\',\'1\') ip\r\nfrom st_point a,st_src_tmpl b,table(p_ffp.p(a.point_id,tn(99))) where a.point_id=:1 and a.meter_type_name=b.src_tmpl_name) LOOP\r\npSRC_TMPL_ID:=t.SRC_TMPL_ID;\r\na:=dp_i(t.point_code,t.name,1,woC=>1);\r\nSELECT (SELECT dp_id FROM st_dp WHERE dp_code = t.point_code) INTO pDP_ID FROM dual;\r\na:=ph_i(1,pDP_ID,t.name,woC=>1);\r\nSELECT (SELECT ph_id FROM st_ph WHERE dp_id=pDP_ID AND ph_name=t.name) INTO pPH_ID FROM dual;\r\nINSERT INTO st_ph_lpty_w (ph_id, lpty_id, lpty_value)\r\nSELECT pPH_ID,lpty_id,Decode(lpty_id,1,t.ip,2,\'1234\',\'TCP\')\r\nFROM st_lpty WHERE NOT pPH_ID IS NULL AND lpty_id IN (1,2,6);\r\nEND LOOP;\r\nELSE\r\nfor t in (select DP_ID,SRC_TMPL_ID from st_point,st_src_tmpl,st_ph where point_id=:1 and ph_id=:2 and meter_type_name=src_tmpl_name) loop\r\npDP_ID:=t.DP_ID;\r\npSRC_TMPL_ID:=t.SRC_TMPL_ID;\r\nend loop;\r\nEND IF;\r\nIF NOT pDP_ID IS NULL THEN\r\nSELECT :1,\'0\' BULK COLLECT INTO pPOINT_ID,A1 FROM dual;\r\na:=src_from_tmpl_i(pDP_ID,pSRC_TMPL_ID,pPOINT_ID,woC=>1);\r\nIF a=\'0\' THEN\r\nINSERT INTO src_pw_tmst (src_id, point_id, id, pw_rt, pck_t)\r\nVALUES (src_seq.CURRVAL,:1,4,SYSDATE,SYSDATE);\r\nCOMMIT;\r\ninit_fill_point_cfg(pPOINT_ID,A1,orn);\r\nif A1(1)=\'0\' then\r\nINSERT INTO dtl (req_type_code, rodo_id)\r\nSELECT req_type_code,orn FROM rc WHERE rc_id=5;\r\nend if;\r\nEND IF;\r\nEND IF;', NULL, NULL, NULL, 62),
	(301, '2_MIN_AVG_FROM_INSTANT_TOTALS', 'Vidutinių rodmenų per 2 minutes generavimas iš augančių reikšmių', 'Vidutinių rodmenų per 2 minutes generavimas iš augančių reikšmių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\n  from GEN_IDs\r\n WHERE ml_id=:2\r\n   AND bga_id=:0 --6/ and point_id=:6\r\n;', 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3),Nvl(:5+1,SYSDATE),1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,ib t\r\n,round(Sum(q*l)*30,6) v,Decode(Max(k),0,\'1\',\'14\') s\r\nFROM\r\n(SELECT f.*\r\n,Trunc(bt)+Trunc(Round((bt-Trunc(bt))*720,6))/720+(d.column_value-1)/720 ib\r\n,g/(et-bt)/720 q\r\n,(Least(et,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*720,6))/720+(d.column_value)/720)-Greatest(bt,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*720,6))/720+(d.column_value-1)/720))*720 l\r\n,CASE WHEN et-bt>=5/1440 and not g=0 THEN 1 ELSE 0 END k\r\nFROM (SELECT da,bt, c1,c2,c3,point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),Nvl(:5+1,SYSDATE)))\r\nWHERE NOT val IS NULL) f,mou u, TABLE(SELECT CAST(COLLECT(level) AS sql_objects) FROM dual CONNECT BY Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*720,6))/720+(LEVEL-1)/720<f.et) d\r\nwhere f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\n) h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(302, 'BOTTOM_10_SRC_BY_ERRORS', 'Blogiausi šaltiniai pagal klaidų kiekį', 'Blogiausi šaltiniai pagal klaidų kiekį', NULL, NULL, 'WITH\r\nc AS\r\n(\r\nselect /*+materialize*/src_id,replace(replace(translate(ev_msg,\'0123456789\',\'^\'),\'^\'),chr(10)) m, count(*) ecnt\r\nfrom ev a\r\nwhere evc_id = 3 and evt_id = 1\r\nand ev_time> sysdate-Nvl(:1,1)\r\nGROUP BY src_id,replace(replace(translate(ev_msg,\'0123456789\',\'^\'),\'^\'),chr(10))\r\n)\r\n,e AS\r\n(SELECT /*+materialize*/* FROM\r\n(\r\nSELECT c.*,Rank() over (PARTITION BY c.src_id ORDER BY ecnt DESC,m) rnk,Sum(ecnt) over (PARTITION BY c.src_id) error_cnt\r\nFROM  c\r\n) WHERE rnk=1\r\n\r\n)\r\n,a0 AS (\r\nSELECT e.src_id,d.dp_code,error_cnt,\'(\'||ecnt||CASE WHEN error_cnt>ecnt THEN \'/\'||error_cnt end||\') \'||m main FROM\r\ne\r\njoin src b on (e.src_id=b.src_id)\r\njoin dp d on (b.dp_id=d.dp_id)\r\n)\r\nSELECT * FROM (\r\nSELECT -gr_id comp_id\r\n,To_Date(NULL) grc_bt\r\n,To_Date(NULL) grc_et\r\n,Rank() over (ORDER BY error_cnt DESC,src_id) grc_nr\r\n,substr(main,1,120) grc_desc\r\nFROM a0 a\r\njoin gr b ON (b.gr_code=\'BY_DP_\'||a.DP_CODE||\'_\'||a.src_id)\r\n) WHERE grc_nr<=10', NULL, NULL, 1),
	(303, 'BOTTOM_10_SRC_BY_NV', 'Blogiausi šaltiniai pagal negaliojančių nuskaitymų kiekį', 'Blogiausi šaltiniai pagal negaliojančių nuskaitymų kiekį', NULL, NULL, 'WITH c0 as\r\n(SELECT /*+materialize*/ sep_id,Count(*) cnt FROM\r\n(SELECT db_time,sep_id FROM pl_data_nv\r\nUNION ALL\r\nSELECT db_time,sep_id FROM ds_data_nv\r\nUNION ALL\r\nSELECT db_time,sep_id FROM pw_data_nv\r\nUNION ALL\r\nSELECT db_time,sep_id FROM dw_data_nv\r\n)\r\nWHERE db_time> SYSDATE-Nvl(:1,1)\r\nGROUP BY sep_id\r\n)\r\n,c1 AS (SELECT /*+materialize*/src_id,dp_code,nv_cnt,\'(\'||cnt||CASE WHEN nv_cnt>cnt THEN \'/\'||nv_cnt end||\') \'||ph_type_name||\' \'||\r\ncoalesce(point_code,ds_code,dp_code)||\r\nCASE WHEN ds_code IS NULL THEN \' \' END||\r\ncoalesce(ml_name,sheaf_name||CASE WHEN NOT witheset_name IS NULL THEN \' \'||witheset_name END) m\r\nFROM (\r\nSELECT c.*,Rank() over (PARTITION BY src_id ORDER BY cnt DESC,sep_id) rnk,Sum(cnt) over (PARTITION BY src_id) nv_cnt\r\nFROM (\r\nselect sep_id,cnt,src_id,dp_code,ph_type_name,point_code,ds_code,sheaf_name,ml_name,witheset_name FROM c0 join st_sep_plain USING (sep_id)\r\nWHERE NOT src_type_id=0\r\n) c\r\n)\r\nWHERE rnk=1\r\n)\r\nSELECT * FROM (\r\nSELECT -gr_id comp_id\r\n,To_Date(NULL) grc_bt\r\n,To_Date(NULL) grc_et\r\n,Rank() over (ORDER BY nv_cnt DESC,src_id) grc_nr\r\n,substr(m,1,120) grc_desc\r\nFROM c1 a\r\njoin gr b ON (b.gr_code=\'BY_DP_\'||a.DP_CODE||\'_\'||a.src_id)\r\n) WHERE grc_nr<=10', NULL, NULL, 1),
	(304, 'INSTANT_HOUR_TOTALS_FROM_ADJACENT_TOTALS', 'Suminių rodmenų proporcingas generavimas iš gretimų reikšmių, fiksuotų kas valandą', 'Suminių rodmenų proporcingas generavimas iš gretimų reikšmių, fiksuotų kas valandą', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nc_DATA DATE := SYSDATE;\r\nc_ROWS SYS_REFCURSOR;', 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n              FROM spty\r\n             WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nDELETE FROM GEN_ADJ$F1;\r\nIF Nvl(:7,\'0\')=1 THEN\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_H_TOTALS_F\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:3) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,1,s,c_DATA,\'\'\r\n         FROM GEN_H_TOTALS_FROM_ADJ_TOTALS;\r\nELSE\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_H_TOTALS\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:3) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,0,s,c_DATA,\'\'\r\n         FROM GEN_H_TOTALS_FROM_ADJ_TOTALS;\r\nEND IF;\r\nLOOP\r\n  FETCH c_ROWS\r\n   BULK COLLECT\r\n   INTO pPCK_T, pPCK_N , pPL_ID, pSEP_ID, pT, pDST, pV, pFORCED, pS, pRT, pRDST\r\n  LIMIT pGF;\r\n  EXIT WHEN pPL_ID.COUNT = 0;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(305, 'AUTO_DELETE_FROM_EAPP_EDEV_PRQ_EE_LOG', 'Automatinis daugiažingsnių užduočių istorinės informacijos trynimas', 'Automatinis daugiažingsnių užduočių istorinės informacijos trynimas', 'CURRTMST DATE;\r\nTS DATE;\r\nDELETED_ROWS_COUNTF NUMBER;\r\nlimit_for_select number;\r\n', 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE = \'AUTO_DELETE_FROM_EAPP_EDEV_PRQ_EE_LOG\')\r\n, TRUNC ((SYSDATE-interval \'3\' year), \'Y\')) INTO CURRTMST FROM DUAL;\r\nLIMIT_FOR_SELECT:=nvl(:4,10000);  TS := SYSDATE; DELETED_ROWS_COUNTF := 0;\r\nwhile (not (CURRTMST + nvl(:1,5) / 1440  > (SYSDATE-nvl(:2,30)) OR SYSDATE > TS + nvl(:3,45) / 86400))\r\nLOOP\r\nDELETED_ROWS_COUNTF:=0;\r\ndelete eapp_log a\r\nWHERE A.DB_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND ROWNUM<= LIMIT_FOR_SELECT;\r\nDELETED_ROWS_COUNTF := DELETED_ROWS_COUNTF+SQL%ROWCOUNT;\r\ndelete edev_log a\r\nWHERE A.DB_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND ROWNUM<= LIMIT_FOR_SELECT;\r\nDELETED_ROWS_COUNTF := DELETED_ROWS_COUNTF+SQL%ROWCOUNT;\r\ndelete edevprq_log a\r\nWHERE A.DB_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND ROWNUM<= LIMIT_FOR_SELECT;\r\nDELETED_ROWS_COUNTF := DELETED_ROWS_COUNTF+SQL%ROWCOUNT;\r\ndelete ee_log a\r\nWHERE A.DB_TIME < CURRTMST + nvl(:1,5) / 1440\r\nAND ROWNUM<= LIMIT_FOR_SELECT;\r\nDELETED_ROWS_COUNTF := DELETED_ROWS_COUNTF+SQL%ROWCOUNT;\r\nif (DELETED_ROWS_COUNTF<limit_for_select) then CURRTMST := CURRTMST + nvl(:1,5) / 1440;\r\nUPDATE TMST A SET A.AMP = CURRTMST WHERE A.TMST_CODE=\'AUTO_DELETE_FROM_EAPP_EDEV_PRQ_EE_LOG\' ;\r\nIF (SQL%ROWCOUNT = 0) THEN\r\nINSERT INTO TMST (TMST_CODE,AMP) select \'AUTO_DELETE_FROM_EAPP_EDEV_PRQ_EE_LOG\',CURRTMST from dual where not exists\r\n(select 0 from tmst where TMST_CODE=\'AUTO_DELETE_FROM_EAPP_EDEV_PRQ_EE_LOG\');\r\nEND IF;END IF;END LOOP; COMMIT;\r\n', NULL, NULL, NULL, 56),
	(306, 'AUTO_TESTMODE_OFF_FROM_SP_LPTY', 'Automatinis TestMode išjungimas', 'Automatinis TestMode išjungimas', NULL, 'DELETE st_sp_lpty_w u WHERE lpty_id=103 AND lpty_value<>\'0\'\r\nAND NOT sp_id IN  (\r\nSELECT sp_id FROM (\r\nSELECT\r\ncol_name, new_val sp_id\r\n,Max(Decode(col_name,\'LPTY_ID\',new_val)) over (PARTITION BY db_time, au_nr) lpty_id\r\nFROM au_idata join au USING (db_time, au_nr) join tab USING (tab_id) join col USING (col_id)\r\nWHERE tab_name = \'SP_LPTY\' AND col_name IN (\'SP_ID\',\'LPTY_ID\') AND db_time> SYSDATE-NVL(:1,30)\r\n) WHERE lpty_id=103 AND col_name=\'SP_ID\'\r\n);', NULL, NULL, NULL, 62),
	(307, 'ANY_TFF_SUM_FROM_ANY_MIN_AVG_OR_SUM', 'Stambesnių intervalų (iki paros) sumos rodmenų generavimas iš smulkesnių intervalų pagal priskirtą tarifą', 'Stambesnių intervalų (iki paros) sumos rodmenų generavimas iš smulkesnių intervalų, panaudojant pagal tarifų profilį priskirtą tarifą', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\ngf1 NUMBER(2);\r\ncnt1 NUMBER(5);\r\ncnt2 NUMBER(5);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;v_tff_id number;\r\nCURSOR c_ROWS ( tff_CODE NUMBER) IS\r\nWITH a AS\r\n(SELECT /*+ materialize*/\r\nSEP_ID,PL_ID,POINT_ID,aggs_type_id\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n)\r\nSELECT /*+ use_nl(a b c) index(c plep_pk)*/ SEP_ID,a.PL_ID,a.POINT_ID ,aggs_type_id\r\n,CASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END\r\nfrom a\r\nJOIN ( SELECT distinct p.point_id FROM PTP p WHERE nvl(p.aggf_id,tff_CODE) = tff_CODE )\r\n     d ON d.point_id = a.POINT_ID\r\nleft join plu b ON (a.pl_id=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY SEP_ID,a.PL_ID,a.POINT_ID,aggs_type_id;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n             FROM spty\r\n            WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nSELECT md_cnt,aggf_id\r\n  INTO cnt1,gf1\r\n  FROM st_ml\r\n WHERE ml_id=:1;\r\nSELECT md_cnt,tff_id\r\n  INTO cnt2,v_tff_id\r\n  FROM st_ml\r\n WHERE ml_id=:2;\r\nOPEN c_ROWS ( gf1 );\r\nLOOP\r\n  FETCH c_ROWS\r\n  BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1\r\n  LIMIT pGF;\r\n  EXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM (SELECT da+TRUNC(ROUND((bt-da)*cnt2,6))/cnt2 t,c1,c2,c3,point_id, NVL(SUM( DECODE( tff_ID, v_tff_id, VAL * DECODE( gf1, 3, 24/cnt1 ,1))),0) v\r\n,case when Max(HAS_SPECIFIC_DSTATUS)=0 and count(*)*cnt2=cnt1\r\nthen \'1\' else \'14\'||decode(count(*)*cnt2,cnt1,null,\'+3\') end s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL\r\nGROUP BY c1,c2,c3,point_id,da,da+TRUNC(ROUND((bt-da)*cnt2,6))/cnt2 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(308, 'BOTTOM_10_DP_BY_SES_DURATION', 'Labiausiai užimtų ryšių kanalų nuskaitymo taškai', 'Labiausiai užimtų ryšių kanalų nuskaitymo taškai', NULL, NULL, 'WITH\r\np AS (SELECT SYSDATE-Nvl(:1,1)-10/1440 p1,SYSDATE-10/1440 p2 FROM dual)\r\n,i AS\r\n(SELECT p1,p2,ph_id,p2 - Greatest(p1,ses_time) v FROM (\r\nSELECT p1,p2,ph_id,ph_otype_id,ses_time,Rank() over (PARTITION BY ph_id ORDER BY src_atime desc,src_anr desc,nullif(ph_otype_id,2) desc) rnk\r\n FROM p,sta_ph_data WHERE src_atime>p1 AND src_atime<p2\r\n) WHERE rnk=1 AND NOT ph_otype_id=2)\r\n,d AS\r\n(\r\nSELECT p1,p2,ph_id,v FROM i\r\nUNION all\r\nSELECT p1,p2,ph_id,src_atime - Greatest(p1,ses_time) v FROM p,sta_ph_data\r\nWHERE src_atime>=p1 AND src_atime<p2 AND ph_otype_id=2 AND NOT src_atime=ses_time\r\n)\r\n,e AS\r\n(SELECT /*+materialize*/ * FROM (SELECT ph_id,Round(Sum(v)*100/(max(p2)-Max(p1)),2) prc FROM d GROUP BY ph_id) WHERE prc>=Nvl(:2,0))\r\n,f AS\r\n(SELECT dp_id,dp_code,ph_name,prc,Rank() over (PARTITION BY dp_id ORDER BY prc DESC,ph_id) r\r\nFROM e join ph USING (ph_id) join dp USING (dp_id))\r\nSELECT * FROM (\r\nSELECT -gr_id comp_id\r\n,To_Date(NULL) grc_bt\r\n,To_Date(NULL) grc_et\r\n,Rank() over (ORDER BY prc DESC,dp_id) grc_nr\r\n,substr(prc||\'% \'||ph_name,1,120) grc_desc\r\nFROM f\r\njoin gr b ON (b.gr_code=\'BY_DP_\'||f.DP_CODE)\r\nWHERE r=1\r\n) WHERE grc_nr<=10', NULL, NULL, 1),
	(309, 'NOT_SYNCHRONIZED', 'Nesinchronizuoti', 'Nesinchronizuoti', NULL, NULL, 'WITH s as\r\n(SELECT * FROM\r\n(\r\nSELECT b.*\r\n,rank() over (partition by b.point_id order by pck_t desc,sep_id,withe_id,Ind1,Ind2,Ind3,Enr) r1\r\nfrom\r\n(\r\nselect f.point_id,a.pck_t\r\n,a.pl_rt rt,d.src_tz_dst_used\r\n,a.sep_id\r\n,To_Number(NULL) withe_id\r\n,To_Number(NULL) Ind1\r\n,To_Number(NULL) Ind2\r\n,To_Number(NULL) Ind3\r\n,To_Number(NULL) ENr\r\nfrom rt_pl a\r\njoin sep b on (a.sep_id=b.sep_id)\r\njoin sp c ON (b.sp_id=c.sp_id)\r\njoin src d ON (c.src_id=d.src_id)\r\njoin src_type e ON (d.src_type_id=e.src_type_id)\r\njoin pl f ON (a.pl_id=f.pl_id)\r\nwhere not d.src_type_id=0 AND e.src_type_internal=1\r\nAND NOT a.pl_rt IS null\r\nUNION ALL\r\nselect a.point_id,Nvl(a.pck_t,a.db_time) pck_t\r\n,a.pw_rt rt,d.src_tz_dst_used\r\n,a.sep_id\r\n,a.withe_id\r\n,To_Number(NULL) Ind1\r\n,To_Number(NULL) Ind2\r\n,To_Number(NULL) Ind3\r\n,To_Number(NULL) ENr\r\nfrom pw_state a\r\njoin sep b on (a.sep_id=b.sep_id)\r\njoin sp c ON (b.sp_id=c.sp_id)\r\njoin src d ON (c.src_id=d.src_id)\r\njoin src_type e ON (d.src_type_id=e.src_type_id)\r\nwhere not d.src_type_id=0 AND e.src_type_internal=1\r\nAND NOT a.pw_rt IS null\r\nUNION ALL\r\nselect a.point_id,Nvl(a.pck_t,a.db_time) pck_t\r\n,a.pw_rt rt,d.src_tz_dst_used\r\n,a.sep_id\r\n,a.withe_id\r\n,To_Number(NULL) Ind1\r\n,To_Number(NULL) Ind2\r\n,To_Number(NULL) Ind3\r\n,To_Number(NULL) ENr\r\nfrom pw_setting a\r\njoin sep b on (a.sep_id=b.sep_id)\r\njoin sp c ON (b.sp_id=c.sp_id)\r\njoin src d ON (c.src_id=d.src_id)\r\njoin src_type e ON (d.src_type_id=e.src_type_id)\r\nwhere not d.src_type_id=0 AND e.src_type_internal=1\r\nAND NOT a.pw_rt IS null\r\nUNION ALL\r\nselect a.point_id,Nvl(a.pck_t,a.db_time) pck_t\r\n,a.pw_rt rt,d.src_tz_dst_used\r\n,a.sep_id\r\n,a.withe_id\r\n,Ind1\r\n,Ind2\r\n,Ind3\r\n,ENr\r\nfrom pw_msetting a\r\njoin sep b on (a.sep_id=b.sep_id)\r\njoin sp c ON (b.sp_id=c.sp_id)\r\njoin src d ON (c.src_id=d.src_id)\r\njoin src_type e ON (d.src_type_id=e.src_type_id)\r\nwhere not d.src_type_id=0 AND e.src_type_internal=1\r\nAND NOT a.pw_rt IS null\r\n) b\r\n) where r1=1\r\n)\r\nSELECT * FROM\r\n(SELECT point_id,to_date(null) grp_bt,to_date(null) grp_et\r\n,Rank() over (ORDER BY Abs(delta) DESC,point_id) r2\r\n,ddifc(SYSDATE,SYSDATE+delta) delta_txt\r\nfrom\r\n(\r\nselect point_id\r\n,(rt+CASE WHEN Nvl(c.spty_value,c.spty_default)=\'0\'\r\nAND NOT z.server_tz_dst_used=s.src_tz_dst_used\r\nAND get_w_or_s(pck_t,z1.tz_code)>0\r\nTHEN (z.server_tz_dst_used-s.src_tz_dst_used) ELSE 0 END/24\r\n)-pck_t delta\r\nFROM s,server_tz z,tz z1,spty c\r\nWHERE z.tz_id = z1.tz_id\r\nAND c.spty_id =1\r\n) where abs(delta)>Nvl(:1,120)/86400\r\n) WHERE r2<=Nvl(:2,9999999)', NULL, NULL, 1),
	(310, 'BY_SRC_TMPL', 'Pagal šaltinių šablonus', 'Pagal šaltinių šablonus', NULL, NULL, 'SELECT DISTINCT\r\n       point_id\r\n  FROM st_se\r\n WHERE POINT_ID is NOT NULL\r\n   AND POINT_ENABLED = 1\r\n   AND SRC_TMPL_ID IS NOT NULL\r\n   AND DP_ENABLED = 1\r\n   AND DP_DELETED = 0\r\n   AND SRC_TMPL_CODE = :1\r\n   AND SRC_ENABLED = 1\r\n   AND SE_ENABLED  = 1\r\n   AND (src_et IS NULL OR src_et > SYSDATE)\r\n', NULL, NULL, 1),
	(311, 'ADD_NEW_GROUP_BY_SRC_TMPL', 'Naujų grupių įtraukimas į grupę pagal šaltinių šablonus (atsiradus naujiems šaltinių šablonams)', 'Naujų grupių įtraukimas į grupę pagal šaltinių šablonus (atsiradus naujiems šaltinių šablonams)', 'a VARCHAR2(250);\r\n', 'FOR t IN (SELECT * FROM\r\n (SELECT bga_type_id FROM bga_type  WHERE bga_type_code = \'BY_SRC_TMPL\') a\r\n,(SELECT gr_type_id  FROM gr_type   WHERE gr_type_code  = \'SYSTEM\') b\r\n,(SELECT sch_id      FROM schi_data WHERE sch_int_id    = 1 AND per_id = 3 AND sch_int_value = 1 AND ROWNUM<2) c\r\n,(SELECT gr_id       FROM gr        WHERE gr_code       = \'BY_SRC_TMPL\') d\r\n) LOOP\r\n  FOR u IN (\r\n    SELECT co, Max(na) na, Max(gr_id) gr_id, Sum(cf) r\r\n      FROM (\r\n            SELECT 1 cf,src_tmpl_code co,src_tmpl_name na,\'\'+0 gr_id\r\n              FROM src_tmpl a\r\n             WHERE EXISTS\r\n               (SELECT NULL\r\n                  FROM src\r\n                  JOIN se  USING (src_id)\r\n                 WHERE src_type_id = a.src_type_id\r\n                   AND src_tmpl_id = a.src_tmpl_id\r\n                   AND src_enabled = 1\r\n                   AND se_enabled = 1\r\n                   AND (src_et IS NULL OR src_et > SYSDATE))\r\n             UNION ALL\r\n            SELECT -1 cf, bga_param_value co,\'\' na,gr_id\r\n              FROM bga b\r\n              JOIN bga_param c ON ( b.bga_id=c.bga_id AND c.bga_param_nr = 1)\r\n             WHERE b.bga_type_id = t.bga_type_id\r\n           )\r\n     GROUP BY co HAVING SUM(cf)!=0 ) LOOP\r\n    IF u.r = 1\r\n    THEN\r\n      a := gr_i( t.GR_TYPE_ID, u.co, 1, u.na);\r\n      FOR g IN (SELECT gr_id FROM gr WHERE gr_code = u.co) LOOP\r\n        a := grc_i(t.gr_id,g.gr_id);\r\n        a := bga_i(t.BGA_TYPE_ID,u.na,1,t.SCH_ID,g.GR_ID);\r\n        FOR b IN (SELECT bga_id FROM bga WHERE bga_name = u.na) LOOP\r\n          a:=bga_param_i(b.BGA_ID,1,u.co);\r\n        END LOOP;\r\n      END LOOP;\r\n    ELSIF u.r = -1\r\n     THEN\r\n      a := gr_d(u.gr_id);\r\n    END IF;\r\n  END LOOP;\r\nEND LOOP;\r\n  COMMIT;\r\n', NULL, NULL, NULL, 1),
	(312, 'DAY_FIXED_TOTALS_FROM_TOTALS_AND_DAY', 'Suminių reikšmių, fiksuotų kas parą, generavimas iš suminių ir einamųjų paros reikšmių', 'Suminių reikšmių, fiksuotų kas parą, generavimas iš suminių ir einamųjų paros reikšmių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nm1 number;\r\nCURSOR c_ROWS IS\r\nWITH a AS (SELECT /*+ materialize*/ SEP_ID,PL_ID,POINT_ID,aggs_type_id FROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n)\r\nSELECT /*+ use_nl(a b c) index(c plep_pk)*/ SEP_ID,a.PL_ID,POINT_ID ,aggs_type_id\r\n,CASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END from a\r\nleft join plu b ON (a.pl_id=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY SEP_ID,a.PL_ID,POINT_ID,aggs_type_id;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))FROM spty WHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF FROM dual;\r\nselect b.ml_id into m1 from st_ml a , st_ml b where a.ml_id=:1 and\r\na.MS_ID=b.ms_id and a.DIR_ID=b.dir_id and a.tff_id=b.TFF_ID and a.AGGF_ID=b.aggf_id\r\nand b.aggs_id=8 and a.aggs_id=5 and a.md_id=5 and b.MD_ID=7;\r\nOPEN c_ROWS;\r\nLOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1 LIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,da t,v,Decode(s,0,\'1\',\'14\') s FROM\r\n(SELECT c1,c2,c3,da,bt,read_time, val,ml_id,read_time_day,count(*) over (partition by point_id,da) cnt\r\n,max(decode(ml_id,m1,val))over(partition by point_id,da)-max(decode(ml_id,:1,val))over(partition by point_id,da) v,s\r\nfrom(SELECT point_id,c1,c2,c3,da,bt,read_time,val,ml_id,read_time_day,rank() over (partition by point_id,da,ml_id order by s,bt) rnk,s\r\nfrom(SELECT point_id,c1,c2,c3,da,bt,read_time,val,ml_id,max(decode(ml_id,:1,read_time)) over (partition by point_id,da) read_time_day\r\n,decode(ml_id,m1,HAS_SPECIFIC_DSTATUS) s\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,m1))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL)\r\nwhere abs(decode(ml_id,m1,bt,read_time)-read_time_day)<=nvl(:8,5)/86400\r\nand read_time_day-da>=nvl(:9,0)/1440) where rnk=1) where cnt=2 AND ml_id=m1)r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(313, 'NO_READING', 'Nėra nuskaitymo rezultatų', 'Nėra nuskaitymo rezultatų', NULL, NULL, 'SELECT DISTINCT point_id\r\n  FROM PL\r\n  JOIN ( SELECT DISTINCT pl_id\r\n           FROM\r\n point JOIN pl USING (point_id) JOIN ml USING (ml_id) JOIN (SELECT di_id,pl_id, di_enabled FROM di) USING (pl_id) JOIN se USING (di_id) JOIN src USING (src_id)\r\n          WHERE point_enabled=1\r\n            AND point_auto_read_enabled=1\r\n            AND pl_enabled=1\r\n            AND di_enabled=1\r\n            AND md_id != 6\r\n            AND src_type_id != 0\r\n            AND NOT src_type_id in (SELECT src_type_id\r\n                                      FROM xf_type\r\n                                     WHERE  src_type_id IS NOT NULL)\r\n        MINUS\r\n         SELECT DISTINCT pl_id\r\n           FROM ( SELECT /*+parallel(a)*/DISTINCT pl_id\r\n                    FROM pl_data a\r\n                    WHERE db_time > SYSDATE - NVL(:1,2880)/1440 AND pck_t IS NOT  NULL\r\n                   UNION ALL\r\n                  SELECT /*+parallel(a)*/pl_id\r\n                    FROM pl_data_nv a\r\n                    WHERE db_time > SYSDATE - NVL(:1,2880)/1440 AND pck_t IS NOT  NULL\r\n                    )\r\n       ) USING (pl_id)', NULL, NULL, 1),
	(314, 'NO_ANY_READING', 'Nėra jokių nuskaitymo duomenų', 'Nėra jokių nuskaitymo duomenų', NULL, NULL, 'WITH p AS\r\n(SELECT /*+materialize*/DISTINCT point_id, pl_id\r\n   FROM st_se\r\n  WHERE point_enabled=1\r\n    AND point_auto_read_enabled=1\r\n    AND pl_enabled=1\r\n    AND di_enabled=1\r\n    AND md_id != 6\r\n    AND src_type_id != 0\r\n    AND NOT src_type_id IN (SELECT src_type_id FROM xf_type where src_type_id IS NOT NULL)\r\n)\r\n,f AS\r\n(SELECT /*+materialize*/DISTINCT pl_id\r\n   FROM ( SELECT pl_id, db_time, pck_t FROM pl_data\r\n           UNION ALL\r\n          SELECT pl_id, db_time, pck_t FROM pl_data_nv)\r\n  WHERE db_time > SYSDATE - NVL(:1,2880)/1440\r\n    AND pck_t IS NOT NULL\r\n)\r\nSELECT point_id\r\n  FROM p\r\n  LEFT\r\n  JOIN f ON (p.pl_id=f.pl_id)\r\n GROUP BY point_id\r\nHAVING MAX(f.pl_id) IS NULL', NULL, NULL, 1),
	(315, 'DAY_FIXED_TOTALS_FROM_DAY_FIXED_AND_DAY_DATA', 'Suminių, fiksuotų kas parą, generavimas iš ankstesnių reikšmių ir parų energijos', 'Suminių, fiksuotų kas parą, generavimas iš ankstesnių reikšmių ir parų energijos', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\ngf1 NUMBER(2);\r\ncnt1 NUMBER(5);\r\ncnt2 NUMBER(5);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nCURSOR c_ROWS ( s0 DATE, s2 DATE) IS\r\nWITH a AS\r\n(SELECT /*+ materialize*/\r\n        SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\n   FROM GEN_IDs\r\n  WHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n)\r\nSELECT /*+ use_nl(a b c) index(c plep_pk)*/ SEP_ID,a.PL_ID,POINT_ID ,aggs_type_id\r\n  ,CASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\n  Min(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\n  ELSE s0 END\r\n  FROM a\r\n  LEFT JOIN plu b ON (a.pl_id=b.pl_id AND Nvl(:7,0)=0)\r\n  LEFT JOIN plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\n GROUP BY SEP_ID,a.PL_ID,POINT_ID,aggs_type_id;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n             FROM spty\r\n            WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nOPEN c_ROWS ( s0, s2);\r\nLOOP\r\n  FETCH c_ROWS\r\n  BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1\r\n  LIMIT pGF;\r\n  EXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n    (select c1,c2,c3,d t,v,\'1\' s\r\n    FROM (select b.*\r\n    ,Rank() over (PARTITION BY point_id,d ORDER BY i)r from\r\n    (select point_id,c1,c2,c3,i,d,Sum(v)v FROM\r\n    (select v.point_id,c1,c2,c3,i,da+Decode(i,2,Decode(ml_id,:1,0,-1),1) d,\r\n    case when ml_id=:1 and i=2 then -1 else 1 end*val v\r\n     from\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,:2))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1)-1,s2))\r\n     v,(SELECT LEVEL i FROM dual CONNECT BY LEVEL<=2),\r\n         (SELECT DISTINCT point_id, Trunc(mou_bt) m FROM mou) u\r\n    WHERE v.point_id = u.point_id(+)\r\n      AND v.da = u.m (+)\r\n      AND u.point_id IS NULL\r\n      AND v.has_specific_dstatus=0\r\n    ) GROUP BY point_id,c1,c2,c3,i,d having Count(*)=2\r\n    ) b\r\n    ) WHERE r=1)r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(316, 'MONTH_FIXED_TOTALS_FROM_MONTH_FIX_AND_MONTH_DATA', 'Suminių, fiksuotų kas mėnesį, generavimas iš ankstesnių reikšmių ir mėnesių energijos', 'Suminių, fiksuotų kas mėnesį, generavimas iš ankstesnių reikšmių ir mėnesių energijos', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\ngf1 NUMBER(2);\r\ncnt1 NUMBER(5);\r\ncnt2 NUMBER(5);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nCURSOR c_ROWS ( s0 DATE, s2 DATE) IS\r\nWITH a AS\r\n(SELECT /*+ materialize*/\r\n        SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\n   FROM GEN_IDs\r\n  WHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n)\r\nSELECT /*+ use_nl(a b c) index(c plep_pk)*/ SEP_ID,a.PL_ID,POINT_ID ,aggs_type_id\r\n  ,Add_Months(CASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\n  Min(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\n  ELSE s0 END ,-1)\r\n  FROM a\r\n  LEFT JOIN plu b ON (a.pl_id=b.pl_id AND Nvl(:7,0)=0)\r\n  LEFT JOIN plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\n GROUP BY SEP_ID,a.PL_ID,POINT_ID,aggs_type_id;', 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS (s0, s2);\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(select c1,c2,c3,d t,v,\'1\' s\r\nFROM (select b.*\r\n,Rank() over (PARTITION BY point_id,d ORDER BY i)r from\r\n(select point_id,c1,c2,c3,i,d,Sum(v)v FROM\r\n(select v.point_id,c1,c2,c3,i, ADD_MONTHS(da,Decode(i,2,Decode(ml_id,:1,0,-1),1)) d,\r\ncase when ml_id=:1 and i=2 then -1 else 1 end*val v\r\nfrom\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,:2))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1)-1,s2))\r\n v,(select level i from dual connect by level<=2)\r\n,(SELECT DISTINCT point_id, Trunc(mou_bt,\'MM\') m FROM mou) u\r\nwhere v.point_id = u.point_id(+)\r\nAND v.da = u.m (+)\r\nAND u.point_id IS NULL\r\nAND v.has_specific_dstatus=0\r\n) GROUP BY point_id,c1,c2,c3,i,d having Count(*)=2\r\n) b\r\n) where r=1)r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(317, 'MONTH_FIXED_TOTALS_FROM_TOTALS_AND_MON', 'Suminių reikšmių, fiksuotų kas mėnesį, generavimas iš suminių ir einamųjų mėnesio reikšmių', 'Suminių reikšmių, fiksuotų kas mėnesį, generavimas iš suminių ir einamųjų mėnesio reikšmių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nm1 number;\r\nCURSOR c_ROWS IS\r\nWITH a AS (SELECT /*+ materialize*/ SEP_ID,PL_ID,POINT_ID,aggs_type_id FROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n)\r\nSELECT /*+ use_nl(a b c) index(c plep_pk)*/ SEP_ID,a.PL_ID,POINT_ID ,aggs_type_id\r\n,CASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END from a\r\nleft join plu b ON (a.pl_id=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY SEP_ID,a.PL_ID,POINT_ID,aggs_type_id;', 's0:=Nvl(Trunc(:4,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),-:3));\r\ns2:=Nvl(Add_Months(Trunc(:5,\'MM\'),1),SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))FROM spty WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF FROM dual;\r\nselect b.ml_id into m1 from st_ml a , st_ml b where a.ml_id=:1 and\r\na.MS_ID=b.ms_id and a.DIR_ID=b.dir_id and a.tff_id=b.TFF_ID and a.AGGF_ID=b.aggf_id\r\nand b.aggs_id=8 and a.aggs_id=6 and a.md_id=6 and b.MD_ID=7;\r\nOPEN c_ROWS; LOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1 LIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,1,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,mo t,v,Decode(s,0,\'1\',\'14\') s FROM\r\n(SELECT c1,c2,c3,bt,read_time, val,ml_id,read_time_mon,count(*) over (partition by point_id,mo) cnt\r\n,max(decode(ml_id,m1,val))over(partition by point_id,mo)-max(decode(ml_id,:1,val))over(partition by point_id,mo) v,s,mo\r\nfrom(SELECT point_id,c1,c2,c3,bt,read_time,val,ml_id,read_time_mon,rank() over (partition by point_id,mo,ml_id order by s,bt) rnk,s,mo\r\nfrom(SELECT point_id,c1,c2,c3,bt,read_time,val,ml_id,max(decode(ml_id,:1,read_time)) over (partition by point_id,trunc(da,\'MM\')) read_time_mon\r\n,decode(ml_id,m1,HAS_SPECIFIC_DSTATUS) s,trunc(da,\'MM\') mo\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,column_value as ml_id,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p,TABLE(tn(:1,m1))\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\nWHERE NOT val IS NULL)\r\nwhere abs(decode(ml_id,m1,bt,read_time)-read_time_mon)<=nvl(:8,5)/86400\r\nand read_time_mon-mo>=nvl(:9,0)/1440) where rnk=1) where cnt=2 AND ml_id=m1)r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(318, 'DIVIDE_ATOMS_BETWEEN_DAS', 'Atomų išdalinimas duomenų surinkimo serveriams', 'Atomų išdalinimas duomenų surinkimo serveriams', NULL, 'divide_atoms_between_das;', NULL, NULL, NULL, 77),
	(319, 'NEVER_GOT_STORABLE', 'Niekada nebuvo matavimų duomenų', 'Niekada nebuvo matavimų duomenų', NULL, NULL, 'select a.point_id from st_point a\r\nleft join st_rt_pl b on (a.point_id=b.point_id)\r\nwhere b.pl_id is null', NULL, NULL, 1),
	(320, 'PARTIAL_FAILURE', 'Nepildoma dalis galiojančių matavimų', 'Nepildoma dalis galiojančių matavimų', NULL, NULL, 'with a as\r\n(\r\nselect /*+materialize*/point_id, pl_id from st_di\r\nwhere point_enabled=1 and point_auto_read_enabled=1 and pl_enabled=1 and di_enabled=1\r\nand not md_id = 6\r\n)\r\nselect point_id from (\r\nselect a.point_id,a.pl_id\r\n,min(decode(s_hosf,4,1,0)) w\r\n,max(decode(s_any,1,1,0)) x\r\nfrom a join st_plep b on (a.pl_id=b.pl_id)\r\nwhere b.plep_bt between sysdate-7 and sysdate-1\r\ngroup by a.point_id,a.pl_id\r\n) group by point_id having max(w)>min(x)\r\n', NULL, NULL, 1),
	(321, 'AUTO_DELETE_ALL_FROM_SRCACL', 'Senų signalų apie su šaltiniais susijusios aktualios surinkimui konfigūracijos pasikeitimus įrašų trynimas', 'Senų signalų apie su šaltiniais susijusios aktualios surinkimui konfigūracijos pasikeitimus įrašų trynimas', NULL, 'DELETE srcacl WHERE db_time<SYSDATE-:1/24;', NULL, NULL, NULL, 56),
	(322, 'AUTO_DELETE_ALL_FROM_ATOM_DAS_LOG', 'Senos automatinio atomų priskyrimo duomenų surinkimo serveriams istorijos trynimas', 'Senos automatinio atomų priskyrimo duomenų surinkimo serveriams istorijos trynimas', 'CURRTMST DATE;\r\nTS DATE;\r\ndlcnt1 number:=1;\r\ndlcnt2 number:=1;\r\ndlcnt3 number:=1;', 'ts:=SYSDATE;\r\nSELECT NVL((SELECT AMP FROM TMST WHERE TMST_CODE=\'AUTO_DELETE_ALL_FROM_ATOM_DAS_LOG\')\r\n,TRUNC((SYSDATE - INTERVAL \'5\' YEAR),\'Y\'))\r\nINTO CURRTMST\r\nFROM DUAL;\r\nLOOP\r\nIF dlcnt1>0 then\r\nDELETE dp_das_log\r\nWHERE DB_TIME>=CURRTMST\r\nAND DB_TIME<CURRTMST+nvl(:1,30)/1440\r\nAND ROWNUM <= NVL(:4,10000);\r\ndlcnt1:=sql%rowcount;\r\nEND IF;\r\nIF dlcnt2>0 then\r\nDELETE rp_das_log\r\nWHERE DB_TIME>=CURRTMST\r\nAND DB_TIME<CURRTMST+nvl(:1,30)/1440\r\nAND ROWNUM <= NVL(:4,10000);\r\ndlcnt2:=sql%rowcount;\r\nEND IF;\r\nIF dlcnt3>0 then\r\nDELETE dp_das_log\r\nWHERE DB_TIME>=CURRTMST\r\nAND DB_TIME<CURRTMST+nvl(:1,30)/1440\r\nAND ROWNUM <= NVL(:4,10000);\r\ndlcnt3:=sql%rowcount;\r\nEND IF;\r\nIF Greatest(dlcnt1,dlcnt2,dlcnt3)=0 THEN\r\nCURRTMST:=CURRTMST + nvl(:1,30)/1440;\r\ndlcnt1:=1;\r\ndlcnt2:=1;\r\ndlcnt3:=1;\r\nMERGE INTO TMST y\r\nUSING (SELECT \'AUTO_DELETE_ALL_FROM_ATOM_DAS_LOG\' tmst_code,CURRTMST amp FROM dual) u\r\nON (y.tmst_code = u.tmst_code)\r\nWHEN MATCHED THEN UPDATE SET\r\n y.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n (\r\n y.tmst_code\r\n,y.amp\r\n) values (\r\n u.tmst_code\r\n,u.amp\r\n);\r\nEND IF;\r\nEXIT WHEN (CURRTMST + NVL(:1,30) / 1440 > SYSDATE - NVL(:2,100) OR SYSDATE > TS + NVL(:3,45)/86400);\r\nEND LOOP;', NULL, NULL, NULL, 56),
	(323, 'DP_CONNECTION_FAILED', 'Neatsakantys nuskaitymo taškai', 'Neatsakantys nuskaitymo taškai', NULL, NULL, 'SELECT -gr_id FROM\r\n(SELECT \'BY_DP_\'||DP_CODE gr_code FROM st_ph WHERE dp_deleted=0 AND ph_deleted=0\r\nGROUP BY dp_id, dp_code HAVING Min(Decode(costa_expired,0,costa_id))=2\r\n) join st_gr USING (gr_code)', NULL, NULL, 1),
	(324, 'DP_CONNECTION_CHANGED_TO_OK', 'Atsakantys nuskaitymo taškai, kuriems buvo ryšio būklės pasikeitimų', 'Atsakantys nuskaitymo taškai, kuriems buvo ryšio būklės pasikeitimų', NULL, NULL, 'SELECT -gr_id FROM\r\n(SELECT \'BY_DP_\'||DP_CODE gr_code FROM st_ph WHERE dp_deleted=0 AND ph_deleted=0\r\nAND costa_from >SYSDATE-nvl(:1,2880)/1440\r\nGROUP BY dp_id, dp_code HAVING Min(Decode(costa_expired,0,costa_id))=1\r\n) join st_gr USING (gr_code)', NULL, NULL, 1),
	(325, 'DP_CONNECTION_OK_WITH_ERRORS', 'Atsakantys nuskaitymo taškai, kuriems buvo ryšio klaidų', 'Atsakantys nuskaitymo taškai, kuriems buvo ryšio klaidų', NULL, NULL, 'WITH d AS\r\n(SELECT /*+ materialize*/DISTINCT ph_id FROM ev WHERE evc_id=3 AND evt_id IN (1,10) AND ev_time> SYSDATE-nvl(:1,2880)/1440)\r\nSELECT -gr_id FROM\r\n(SELECT DISTINCT \'BY_DP_\'||DP_CODE gr_code FROM ph a join dp b ON (a.dp_id=b.dp_id) join ph_state c ON (a.ph_id=c.ph_id) join d ON (a.ph_id=d.ph_id)\r\nWHERE dp_deleted=0 AND ph_deleted=0\r\nAND /*costa_expired*/\r\nCASE WHEN SYSDATE>\r\n CASE nvl(a.COSTA_G_PER_ID,4)\r\n   WHEN 6 THEN Add_Months(c.costa_last_check,12*a.COSTA_G_EXP_VALUE)\r\n   WHEN 5 THEN Add_Months(c.costa_last_check,a.COSTA_G_EXP_VALUE)\r\n   WHEN 4 THEN c.costa_last_check+Nvl(a.COSTA_G_EXP_VALUE,1)\r\n   WHEN 3 THEN c.costa_last_check+a.COSTA_G_EXP_VALUE/24\r\n   WHEN 2 THEN c.costa_last_check+a.COSTA_G_EXP_VALUE/1440\r\n   WHEN 1 THEN c.costa_last_check+a.COSTA_G_EXP_VALUE/86400\r\n END\r\nTHEN 1 ELSE 0 END\r\n=0 AND costa_id=1\r\n) join gr USING (gr_code)', NULL, NULL, 1),
	(326, 'NO_RESTORE_DEPTH', 'Taškai, kurių archyvą turintiems skaitiklių šaltiniams nenustatytas atstatymo gylis', 'Taškai, kurių archyvą turintiems skaitiklių šaltiniams nenustatytas atstatymo gylis', NULL, NULL, 'select distinct point_id from st_se where se_h=1 and dl_type_id = 2 and not src_type_id = 0 and se_h_restore_depth is null and not point_id is null', NULL, NULL, 1),
	(327, 'DP_NO_ANY_STORABLE', 'Nuskaitymo taškai, kuriems nėra duomenų už paskutines paras', 'Nuskaitymo taškai, kuriems nėra duomenų už paskutines paras', NULL, NULL, 'WITH p AS\r\n(\r\nSELECT /*+ parallel(a)*/pl_id,max(Nvl(s_any,0)) s FROM plep a\r\nWHERE plep_bt>= Trunc(SYSDATE)-nvl(:1,1)\r\ngroup by pl_id\r\n)\r\nSELECT -gr_id FROM\r\n(SELECT \'BY_DP_\'||DP_CODE gr_code\r\nFROM\r\nse e\r\njoin src s ON (e.src_id=s.src_id)\r\njoin dp d ON (s.dp_id=d.dp_id)\r\njoin di i ON (e.di_id=i.di_id)\r\njoin pl b ON (i.pl_id=b.pl_id)\r\njoin point a ON (b.point_id=a.point_id)\r\njoin p ON (b.pl_id=p.pl_id)\r\n WHERE dp_deleted=0 AND di_enabled = 1 AND src_et IS NULL AND NOT src_type_id=0\r\nAND point_enabled = 1 AND point_auto_read_enabled=1 AND pl_enabled = 1\r\nGROUP BY d.dp_id, d.dp_code HAVING max(s)=0) join gr USING (gr_code)', NULL, NULL, 1),
	(328, 'NO_ANY_STORABLE_BUT_DP_HAS', 'Taškai, kuriems nėra duomenų už paskutines paras, nors nuskaitymo taškams yra', 'Taškai, kuriems nėra duomenų už paskutines paras, nors nuskaitymo taškams yra', NULL, NULL, 'WITH p AS\r\n(\r\nSELECT /*+ parallel(a)*/c.point_id,max(Nvl(s_any,0)) s FROM plep a JOIN pl b ON (a.pl_id=b.pl_id) JOIN point c ON (b.point_id=c.point_id)\r\nWHERE plep_bt>= Trunc(SYSDATE)-nvl(:1,1) and point_enabled = 1 AND point_auto_read_enabled=1 AND pl_enabled = 1\r\ngroup by c.point_id\r\n)\r\nSELECT DISTINCT point_id FROM\r\n(SELECT DISTINCT point_id,s,Max(s) over (PARTITION BY dp_id) m\r\nFROM pl join p USING (point_id) JOIN (SELECT di_id, pl_id, di_enabled FROM di) USING (pl_id)\r\nJOIN se USING (di_id) JOIN (SELECT src_id, dp_id, src_et,src_type_id FROM src) USING (src_id) JOIN dp USING (dp_id)\r\n WHERE dp_deleted=0 AND di_enabled = 1 AND pl_enabled=1 AND src_et IS NULL AND NOT src_type_id=0\r\n) WHERE s=0 AND m=1', NULL, NULL, 1),
	(329, 'LPTY_MISSING', 'Neužpildytos ryšio savybės', 'Neužpildytos ryšio savybės', NULL, NULL, 'SELECT DISTINCT e.point_id,to_date(\'\') grp_bt,to_date(\'\') grp_et,to_number(\'\') grp_nr\r\n,substr(First_Value(\'\'||e.dp_code||\'\'||e.src_name||CASE WHEN NOT m.se_id IS NULL THEN \'\'||Nvl(e.ml_name,e.sheaf_name) END||\'<\'||m.lpty_code||\'> [\'||m.scope||\']\')\r\nover (PARTITION BY e.point_id ORDER BY m.scope DESC,m.src_id,m.sp_id,m.lpty_id,e.se_id),1,120) grp_desc\r\nFROM st_lpty_missing m join st_se e ON (m.src_id=e.src_id)\r\nWHERE src_et IS NULL AND dp_deleted=0 AND e.se_id = Nvl(m.se_id,e.se_id) AND NOT e.point_id IS NULL\r\nAND di_enabled = 1 AND point_enabled=1 AND point_auto_read_enabled = 1 AND src_enabled=1 AND dp_enabled=1\r\nAND m.src_lpty_usage=:1', NULL, NULL, 1),
	(330, 'METER_NUMBER_TO_ELEMENTS', 'Sumontuoto taške skaitiklio numerio įrašymas į elementų savybę', 'Sumontuoto taške skaitiklio numerio įrašymas į elementų savybę', NULL, 'DELETE gttt;\r\nINSERT INTO gttt (id1,c1)\r\nSELECT * FROM (\r\nSELECT se_id\r\n,CASE WHEN :2=1 THEN regexp_substr(meter_number,\'[1-9]d+$\') ELSE meter_number END c1\r\nFROM\r\nst_se\r\njoin (SELECT point_id,meter_number FROM st_point) USING (point_id)\r\njoin (SELECT src_type_id,lpty_id FROM st_se_type_lpty) USING (src_type_id)\r\nWHERE lpty_id=232 AND src_type_name=:1 AND NOT pl_id IS NULL\r\n) WHERE NOT c1 IS null;\r\nDELETE st_se_lpty_w WHERE lpty_id=232 AND se_id IN (SELECT se_id FROM st_se\r\nWHERE src_type_name=:1 AND NOT pl_id IS null)\r\nAND NOT se_id IN (SELECT id1 FROM gttt);\r\nMERGE INTO st_se_lpty_w y USING gttt u ON (y.se_id=u.id1 AND y.lpty_id=232)\r\nWHEN MATCHED THEN UPDATE SET\r\n y.lpty_value=u.c1\r\n WHERE NOT y.lpty_value=u.c1\r\nWHEN NOT MATCHED THEN INSERT\r\n(\r\n y.se_id\r\n,y.lpty_id\r\n,y.lpty_value\r\n) values (\r\n u.id1\r\n,232\r\n,u.c1\r\n);', NULL, NULL, NULL, 62),
	(331, 'OLD_HOLES', 'Skylės už senus periodus', 'Skylės už senus periodus', NULL, NULL, 'select DISTINCT\r\npoint_id,to_date(null) grp_bt,to_date(null) grp_et,to_number(null) r\r\n,substr(replace(first_value(c1||\' [\'||To_Char(rodo_bt,f)||\'-\'||Nvl(To_Char(rodo_et,f),\'<Now>\')||\'] \'||to_char(db_time,\'HH24:MI\')) over (partition by point_id order by rodo_id desc, rodo_nr DESC, sep_id, withe_id),\' 00:00:00\'),1,120) d\r\n from (\r\nSELECT db_time,point_id,ml_name c1,rodo_bt,rodo_et, rodo_id,rodo_nr, sep_id,To_Number(NULL) withe_id\r\nFROM st_rodo join st_di USING (di_id) join (SELECT pl_id,et FROM st_rt_pl WHERE improvable=0) USING (pl_id)\r\nWHERE db_time> SYSDATE-1 AND rc_id IN (4,14) AND rodo_bt<et AND rodo_bt<SYSDATE-3\r\nUNION ALL\r\nSELECT db_time,point_id,sheaf_name c1,rodo_bt,rodo_et, rodo_id,rodo_nr, sep_id,w withe_id\r\nFROM (SELECT rodo_id,rodo_nr, di_id, rodo_bt, rodo_et, rc_id, db_time FROM st_rodo) join st_sep_pw USING (di_id) join (SELECT point_id,sep_id,withe_id w,pw_t+0 et FROM st_pw_state) USING (point_id,sep_id)\r\nWHERE db_time> SYSDATE-1 AND rc_id IN (4,14) AND rodo_bt<et AND rodo_bt<SYSDATE-3\r\n),(SELECT /*+no_merge*/getcaption(190) f FROM dual)', NULL, NULL, 1),
	(332, 'NOT_CLOSED', 'Neuždaryti', 'Neuždaryti', NULL, NULL, 'WITH a0 AS\r\n(SELECT /*+materialize*/ m.point_id, Decode(l.md_id,6,5,4) per_id\r\nFROM\r\npoint m\r\nJOIN point_fp p ON (m.point_id = p.point_id)\r\njoin pl b ON (p.point_id=b.point_id)\r\nJOIN di i ON (b.pl_id=i.pl_id)\r\nJOIN ml l ON (b.ml_id=l.ml_id)\r\njoin fp_data d ON (p.fp_id=d.fp_id)\r\nWHERE m.point_enabled = 1\r\nAND b.pl_enabled = 1 AND i.di_enabled = 1\r\nAND l.aggs_type_id = Nvl(d.aggs_type_id,l.aggs_type_id)\r\nAND l.ms_id = Nvl(d.ms_id,l.ms_id)\r\nAND l.dir_id = Nvl(d.dir_id,l.dir_id)\r\nAND l.aggs_id = Nvl(d.aggs_id,l.aggs_id)\r\nAND l.aggf_id = Nvl(d.aggf_id,l.aggf_id)\r\nAND l.tff_id = Nvl(d.tff_id,l.tff_id)\r\nAND l.md_id = Nvl(d.md_id,l.md_id)\r\nGROUP BY m.point_id,l.md_id\r\n)\r\nSELECT point_id FROM (\r\nSELECT a.per_id,a.point_id,d.cp_t FROM\r\n a0 a\r\njoin (\r\nSELECT add_months(trunc(sysdate,\'MM\'),-1) cp_t, 5 per_id FROM dual WHERE To_Char(SYSDATE,\'DD\')<=20 AND SYSDATE> trunc(sysdate,\'MM\')+9/24\r\nUNION ALL\r\nSELECT trunc(sysdate)-level cp_t, 4 per_id FROM dual WHERE SYSDATE> trunc(sysdate)-LEVEL+1+9/24\r\nCONNECT BY LEVEL<=greatest(5,to_char(sysdate,\'DD\')-1)\r\n) d ON (a.per_id=d.per_id)\r\nMINUS\r\nSELECT per_id,point_id,cp_t FROM cp WHERE cp_enabled=1\r\n)\r\nGROUP BY point_id', NULL, NULL, 1),
	(333, 'MAJOR_ISSUE', 'Taškų sisteminės savybės "Esminė problema" pildymas', 'Taškų sisteminės savybės "Esminė problema" pildymas', NULL, NULL, 'select ppty_id from st_ppty where ppty_code =\'MAJOR_ISSUE\'', 'DELETE gttt;\r\nINSERT INTO gttt (id1,c1)\r\nWITH g AS (\r\nSELECT ROWNUM r,column_value gr_code FROM TABLE(t_varchar2_tab(\r\n\'MANDATORY_LPTY_MISSING\'\r\n,\'NEVER_GOT_STORABLE\'\r\n,\'DP_CONNECTION_FAILED\'\r\n,\'NOT_SYNCHRONIZED\'\r\n,\'DP_NO_ANY_STORABLE\'\r\n,\'HOPELESS\'\r\n,\'NO_ANY_READING\'\r\n,\'NO_ANY_STORABLE_BUT_DP_HAS\'\r\n,\'NO_DATA_FOR_THE_LAST_24_HOURS\'\r\n,\'NO_READING\'\r\n,\'PARTIAL_FAILURE\'\r\n,\'OLD_HOLES\'\r\n,\'NOT_CLOSED\'\r\n,\'DP_CONNECTION_CHANGED_TO_OK\'\r\n,\'NO_RESTORE_DEPTH\'\r\n,\'RECOMMENDED_LPTY_MISSING\'\r\n,\'DP_CONNECTION_OK_WITH_ERRORS\'\r\n,\'BOTTOM_10_SRC_BY_ERRORS\'\r\n,\'BOTTOM_10_SRC_BY_NV\'\r\n,\'BOTTOM_10_DP_BY_SES_DURATION\'\r\n,\'MANY_EVENTS\'\r\n))\r\n)\r\nSELECT point_id,To_Char(Min(r))\r\nFROM st_grpj join g USING (gr_code)\r\nGROUP BY point_id;\r\nDELETE st_point_ppty_w WHERE ppty_id=c.ppty_id AND NOT point_id IN (SELECT id1 FROM gttt);\r\nMERGE INTO st_point_ppty_w y\r\nUSING (\r\n SELECT id1 point_id,c.ppty_id ppty_id,c1 ppty_value FROM gttt\r\n ) u\r\nON (y.point_id=u.point_id AND y.ppty_id=u.ppty_id)\r\nWHEN MATCHED THEN UPDATE SET\r\n y.ppty_value=u.ppty_value\r\nWHERE NOT y.ppty_value=u.ppty_value\r\nWHEN NOT MATCHED THEN INSERT\r\n (\r\n y.point_id\r\n,y.ppty_id\r\n,y.ppty_value\r\n) values (\r\n u.point_id\r\n,u.ppty_id\r\n,u.ppty_value\r\n);', NULL, 78),
	(336, 'BY_METER_TYPE', 'Pagal matavimo prietaisų tipus', 'Pagal matavimo prietaisų tipus', NULL, NULL, 'SELECT point_id FROM st_point WHERE meter_type_name=:1', NULL, NULL, 1),
	(337, 'BY_METER_TYPE_MANAGEMENT', 'Grupės "Pagal matavimo prietaisų tipus" sudėties pildymas/valymas', 'Grupės "Pagal matavimo prietaisų tipus" sudėties pildymas/valymas', 'ans VARCHAR2(250);\r\npBGA_TYPE_ID NUMBER;\r\npSCH_ID NUMBER;', 'FOR t IN (SELECT gr_id,gr_type_id,gr_name FROM st_gr WHERE gr_code=\'BY_METER_TYPE\') LOOP\r\nFOR h IN (\r\nSELECT co, MAX(co2) co2, Max(na)na,Max(gr_id)gr_id,Sum(cf)r FROM (\r\nSELECT DISTINCT 1 cf, \'MT_\'||meter_type_name co, meter_type_name co2, meter_type_name na, \'\'+0 gr_id FROM ST_POINT WHERE NOT METER_ID IS null\r\nUNION ALL\r\nSELECT -1 cf, comp_code co,\'\' co2,\'\' na, comp_id FROM st_grc b where cont_id=t.gr_id\r\n) GROUP BY co having Sum(cf)!=0\r\n) LOOP\r\nIF h.r=1 THEN\r\nselect nvl(sch_id,(SELECT sch_id FROM st_sch WHERE sch_per_code = \'HH\' and sch_per_value=4 AND ROWNUM=1)) INTO pSCH_ID\r\nfrom bga where bga_id=:0;\r\nSELECT BGA_TYPE_ID INTO pBGA_TYPE_ID FROM ST_BGA_TYPE WHERE BGA_TYPE_CODE=\'BY_METER_TYPE\';\r\nans:=gr_i(t.GR_TYPE_ID,h.co,1,h.na);\r\nFOR g IN (SELECT gr_id FROM st_gr WHERE gr_code=h.co) LOOP\r\nans:=grc_i(t.gr_id,g.gr_id);\r\nans:=bga_i(pBGA_TYPE_ID,t.GR_NAME||\'.\'||h.na,1,pSCH_ID,g.GR_ID);\r\nFOR b IN (SELECT bga_id FROM st_bga WHERE bga_name=t.GR_NAME||\'.\'||h.na) LOOP\r\nans:=bga_param_i(b.BGA_ID,1,h.co2);\r\nEND LOOP;\r\nEND LOOP;\r\nELSIF h.r=-1 then\r\nans:=gr_d(h.gr_id);\r\nEND IF;\r\nEND LOOP;\r\nEND LOOP;', NULL, NULL, NULL, 1),
	(338, 'ACT/REACT_ENERGY_FROM_POWER', 'Aktyvinės/reaktyvinės energijos pakaita iš galios profilio', 'Ēąģåłåķčå ąźņčāķīé/šåąźņčāķīé żķåšćčč čē ļšīōčė˙ ģīłķīńņč', NULL, 'INSERT INTO st_pl_w (pl_id,point_id,ml_id)\r\nSELECT pl_seq.NEXTVAL,point_id,ml_id FROM\r\n(\r\nSELECT a.point_id,b.ml_id\r\n,CASE WHEN\r\nb.aggf_id=2 AND\r\nMin(nvl2(c.pl_id,b.aggf_id,NULL)) over (PARTITION BY a.point_id,b.ms_id,b.dir_id,b.aggs_id,b.tff_id,b.md_id)=3\r\nthen 1 END y\r\n FROM\r\nst_point a\r\njoin st_ml b ON (b.ms_id IN (1,3) AND b.dir_id IN (1,2) AND b.aggf_id IN (2,3) AND b.md_per_id<4)\r\nleft join st_pl c ON (a.point_id=c.point_id AND b.ml_id=c.ml_id)\r\n) WHERE y=1;\r\nINSERT INTO st_sbst_w (pl_id, sbst_pl_id, sbst_sf, sbst_ab, sbst_a, sbst_b, sbst_improvable)\r\nSELECT pl_id,sbst_pl_id,0,nvl2(sbst_a,1,0) sbst_ab,sbst_a,nvl2(sbst_a,0,null) sbst_b,0 FROM (\r\nSELECT a.*\r\n,Max(Decode(aggf_id,3,pl_id)) over (PARTITION BY point_id,ms_id,dir_id,aggs_id,tff_id,md_id) sbst_pl_id\r\n,Nullif(Round(24*md_int_value/Decode(md_per_id,1,86400,2,1440,3,24),6),1) sbst_a\r\nFROM st_pl a WHERE ms_id IN (1,3) AND dir_id IN (1,2) AND aggf_id IN (2,3) AND md_per_id<4\r\n) WHERE aggf_id = 2 AND NOT sbst_pl_id IS NULL AND NOT pl_id IN (SELECT pl_id FROM st_sbst);', NULL, NULL, NULL, 82),
	(339, 'UPDATE_GRP_DATA_FROM_ECP_DATA', 'Atnaujinti grupių matavimų išskaičiavimo iš taškų matavimų konfigūraciją pagal taškų ekonominių profilių konfigūraciją', 'Atnaujinti grupių matavimų išskaičiavimo iš taškų matavimų konfigūraciją pagal taškų ekonominių profilių konfigūraciją', NULL, 'update_grp_data_from_ecp_data;', NULL, NULL, NULL, 1),
	(340, 'UPDATE_GRC_DATA_FROM_GRC_RULE', 'Atnaujinti grupių matavimų išskaičiavimo iš grupių-komponentų matavimų konfigūraciją pagal pildymo taisykles', 'Atnaujinti grupių matavimų išskaičiavimo iš grupių-komponentų matavimų konfigūraciją pagal pildymo taisykles', NULL, 'update_grc_data_from_grc_rule;', NULL, NULL, NULL, 1),
	(341, 'NO_ANY_RECENT_READING', 'Nėra jokių nesenų nuskaitymo duomenų', 'Nėra jokių nesenų nuskaitymo duomenų', NULL, NULL, 'WITH p AS\r\n(SELECT /*+materialize*/DISTINCT point_id, pl_id\r\n   FROM st_se\r\n  WHERE point_enabled=1\r\n    AND point_auto_read_enabled=1\r\n    AND pl_enabled=1\r\n    AND di_enabled=1\r\n    AND md_id != 6\r\n    AND src_type_id != 0\r\n    AND NOT src_type_id IN (SELECT src_type_id FROM xf_type where src_type_id IS NOT NULL)\r\n)\r\n,f AS\r\n(SELECT /*+materialize*/DISTINCT pl_id\r\n   FROM ( SELECT pl_id, db_time, pck_t, pl_t FROM pl_data\r\n           UNION ALL\r\n          SELECT pl_id, db_time, pck_t,pl_t FROM pl_data_nv)\r\n  WHERE db_time > SYSDATE - NVL(:1,2880)/1440 and pl_t> SYSDATE - NVL(:1,2880)/1440\r\n    AND pck_t IS NOT NULL\r\n)\r\nSELECT point_id\r\n  FROM p\r\n  LEFT\r\n  JOIN f ON (p.pl_id=f.pl_id)\r\n GROUP BY point_id\r\nHAVING MAX(f.pl_id) IS NULL', NULL, NULL, 1),
	(342, 'SIMULTANEOUS_READ_TOTALS_MONTHS_P', 'Vienalaikis einamosios mėnesių energijos ir suminių rodmenų nuskaitymas (taškui)', 'Vienalaikis einamosios mėnesių energijos ir suminių rodmenų nuskaitymas (taškui)', 'pRODO_ID NUMBER;\r\npPOINT_ID NUMBER;\r\npRODO_NR NUMBER;', NULL, 'WITH f AS (\r\nSELECT\r\ndistinct\r\npoint_id\r\n,Max(Decode(r.ole,1,di_id)) over (PARTITION BY point_id,ms_id,dir_id,tff_id) di1\r\n,Max(Decode(r.ole,1,sep_id)) over (PARTITION BY point_id,ms_id,dir_id,tff_id) sep1\r\n,Max(Decode(r.ole,1,src_id)) over (PARTITION BY point_id,ms_id,dir_id,tff_id) src1\r\n,Max(Decode(r.ole,2,di_id)) over (PARTITION BY point_id,ms_id,dir_id,tff_id) di2\r\n,Max(Decode(r.ole,2,sep_id)) over (PARTITION BY point_id,ms_id,dir_id,tff_id) sep2\r\n,Max(Decode(r.ole,2,src_id)) over (PARTITION BY point_id,ms_id,dir_id,tff_id) src2\r\n,Max(Decode(r.ole,3,pl_id)) over (PARTITION BY point_id,ms_id,dir_id,tff_id) pl3\r\n,Count(DISTINCT r.ole) over (PARTITION BY point_id,ms_id,dir_id,tff_id) cnt\r\n FROM  st_sep_pl a\r\n,(SELECT LEVEL ole FROM dual CONNECT BY LEVEL<=3) r\r\nWHERE\r\npoint_enabled=1\r\nAND point_auto_read_enabled=1\r\nAND pl_enabled=1\r\nAND di_enabled=1\r\nAND src_enabled=1\r\nAND src_et IS NULL\r\nAND se_enabled=1\r\nAND sep_enabled=1\r\nAND dp_deleted = 0\r\nAND dp_enabled= 1\r\nAND ph_deleted = 0\r\nAND ph_enabled=1\r\nAND aggf_id = 2\r\nAND\r\n(r.ole=1 AND aggs_id=8 AND md_id=7\r\nOR r.ole=2 AND aggs_id=6 AND md_id=6\r\nOR r.ole=3 AND aggs_id=8 AND md_id=6\r\n)\r\nAND\r\n(\r\nr.ole<3\r\nAND NOT src_type_id = 0\r\nAND NOT src_type_id IN (SELECT src_type_id FROM st_xf_type WHERE NOT src_type_id IS null)\r\nAND (point_id,dp_type_id, ph_type_id,dl_type_id) IN (SELECT point_id,dp_type_id, ph_type_id,dl_type_id FROM point_tpl)\r\nOR\r\nr.ole=3 AND src_type_id = 0\r\nAND src_name IN (SELECT bga_name FROM bga join bga_type USING (bga_type_id)\r\nWHERE bga_enabled=1 AND NOT sch_id IS null AND bga_type_code = \'MONTH_FIXED_TOTALS_FROM_TOTALS_AND_MON\')\r\n)\r\n)\r\nSELECT f.*\r\nFROM f\r\nleft join rt_pl k ON (f.pl3=k.pl_id AND k.improvable=0)\r\nWHERE cnt=3\r\nAND Nvl(k.pl_t,DATE\'1899-12-30\')<>Trunc(SYSDATE,\'MM\')\r\nORDER BY 1,6', 'IF pPOINT_ID IS NULL THEN\r\npPOINT_ID:=c.point_id;\r\nSELECT rodo_seq.NEXTVAL,1 INTO pRODO_ID,pRODO_NR FROM dual;\r\nEND IF;\r\nIF NOT c.point_id=pPOINT_ID THEN\r\nINSERT INTO ltl (req_type_code, rodo_id) VALUES (\'READ_BY_EVENT\',pRODO_ID);\r\nCOMMIT;\r\npPOINT_ID:=c.point_id;\r\nSELECT rodo_seq.NEXTVAL,1 INTO pRODO_ID,pRODO_NR FROM dual;\r\nEND IF;\r\nINSERT INTO rodo (rodo_id, rodo_nr, db_time, user_id, rc_id, di_id, rodo_bt, rodo_et, src_id, sep_id)\r\nVALUES (pRODO_ID, pRODO_NR, sysdate, 0, 17, c.di1, null, null, c.src1, c.sep1);\r\npRODO_NR:=pRODO_NR+1;\r\nINSERT INTO rodo (rodo_id, rodo_nr, db_time, user_id, rc_id, di_id, rodo_bt, rodo_et, src_id, sep_id)\r\nVALUES (pRODO_ID, pRODO_NR, sysdate, 0, 17, c.di2, Trunc(SYSDATE,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),1), c.src2, c.sep2);\r\npRODO_NR:=pRODO_NR+1;', 'IF NOT pPOINT_ID IS NULL THEN\r\nINSERT INTO ltl (req_type_code, rodo_id) VALUES (\'READ_BY_EVENT\',pRODO_ID);\r\nEND IF;', 87),
	(343, 'SIMULTANEOUS_READ_TOTALS_MONTHS_M', 'Vienalaikis einamosios mėnesių energijos ir suminių rodmenų nuskaitymas (taško energijos tarifui)', 'Vienalaikis einamosios mėnesių energijos ir suminių rodmenų nuskaitymas (taško energijos tarifui)', 'pRODO_ID NUMBER;', NULL, 'WITH f AS (\r\nSELECT\r\ndistinct\r\npoint_id\r\n,Max(Decode(r.ole,1,di_id)) over (PARTITION BY point_id,ms_id,dir_id,tff_id) di1\r\n,Max(Decode(r.ole,1,sep_id)) over (PARTITION BY point_id,ms_id,dir_id,tff_id) sep1\r\n,Max(Decode(r.ole,1,src_id)) over (PARTITION BY point_id,ms_id,dir_id,tff_id) src1\r\n,Max(Decode(r.ole,2,di_id)) over (PARTITION BY point_id,ms_id,dir_id,tff_id) di2\r\n,Max(Decode(r.ole,2,sep_id)) over (PARTITION BY point_id,ms_id,dir_id,tff_id) sep2\r\n,Max(Decode(r.ole,2,src_id)) over (PARTITION BY point_id,ms_id,dir_id,tff_id) src2\r\n,Max(Decode(r.ole,3,pl_id)) over (PARTITION BY point_id,ms_id,dir_id,tff_id) pl3\r\n,Count(DISTINCT r.ole) over (PARTITION BY point_id,ms_id,dir_id,tff_id) cnt\r\n FROM  st_sep_pl a\r\n,(SELECT LEVEL ole FROM dual CONNECT BY LEVEL<=3) r\r\nWHERE\r\npoint_enabled=1\r\nAND point_auto_read_enabled=1\r\nAND pl_enabled=1\r\nAND di_enabled=1\r\nAND src_enabled=1\r\nAND src_et IS NULL\r\nAND se_enabled=1\r\nAND sep_enabled=1\r\nAND dp_deleted = 0\r\nAND dp_enabled= 1\r\nAND ph_deleted = 0\r\nAND ph_enabled=1\r\nAND aggf_id = 2\r\nAND\r\n(r.ole=1 AND aggs_id=8 AND md_id=7\r\nOR r.ole=2 AND aggs_id=6 AND md_id=6\r\nOR r.ole=3 AND aggs_id=8 AND md_id=6\r\n)\r\nAND\r\n(\r\nr.ole<3\r\nAND NOT src_type_id = 0\r\nAND NOT src_type_id IN (SELECT src_type_id FROM st_xf_type WHERE NOT src_type_id IS null)\r\nAND (point_id,dp_type_id, ph_type_id,dl_type_id) IN (SELECT point_id,dp_type_id, ph_type_id,dl_type_id FROM point_tpl)\r\nOR\r\nr.ole=3 AND src_type_id = 0\r\nAND src_name IN (SELECT bga_name FROM bga join bga_type USING (bga_type_id)\r\nWHERE bga_enabled=1 AND NOT sch_id IS null AND bga_type_code = \'MONTH_FIXED_TOTALS_FROM_TOTALS_AND_MON\')\r\n)\r\n)\r\nSELECT f.*\r\nFROM f\r\nleft join rt_pl k ON (f.pl3=k.pl_id AND k.improvable=0)\r\nWHERE cnt=3\r\nAND Nvl(k.pl_t,DATE\'1899-12-30\')<>Trunc(SYSDATE,\'MM\')\r\nORDER BY 1,6', 'SELECT rodo_seq.NEXTVAL INTO pRODO_ID FROM dual;\r\nINSERT INTO rodo (rodo_id, rodo_nr, db_time, user_id, rc_id, di_id, rodo_bt, rodo_et, src_id, sep_id)\r\nVALUES (pRODO_ID, 1, sysdate, 0, 17, c.di1, null, null, c.src1, c.sep1);\r\nINSERT INTO rodo (rodo_id, rodo_nr, db_time, user_id, rc_id, di_id, rodo_bt, rodo_et, src_id, sep_id)\r\nVALUES (pRODO_ID, 2, sysdate, 0, 17, c.di2, Trunc(SYSDATE,\'MM\'),Add_Months(Trunc(SYSDATE,\'MM\'),1), c.src2, c.sep2);\r\nINSERT INTO ltl (req_type_code, rodo_id) VALUES (\'READ_BY_EVENT\',pRODO_ID);', NULL, 87),
	(344, 'RECREATE_SOURCE', 'Duomenų šaltinio perkūrimas', 'Duomenų šaltinio perkūrimas', 'a VARCHAR2(250);\r\nt NUMBER;\r\nd NUMBER;\r\norn NUMBER;\r\nP1 T7.IRR;\r\nA1 T7.CRR;', 'SELECT src_tmpl_id, dp_id INTO t,d FROM src WHERE src_id = :1 AND src_et IS NULL;\r\nSELECT DISTINCT point_id,\'0\' BULK COLLECT INTO P1,A1 FROM st_se WHERE src_id =:1 AND NOT point_id IS NULL;\r\nUPDATE src SET src_et = SYSDATE, src_enabled=0 WHERE src_id = :1;\r\na:=src_from_tmpl_i(d,t,P1);\r\ninit_fill_point_cfg(P1,A1,orn);\r\nDELETE gttt;\r\nFORALL j IN 1..P1.count\r\nINSERT INTO gttt (id1,c1) VALUES (P1(j),A1(j));\r\nINSERT INTO dtl (req_type_code, rodo_id)\r\nSELECT req_type_code,orn FROM rc WHERE rc_id=16\r\nAND EXISTS (SELECT 0 FROM gttt WHERE c1=\'0\');\r\nIF SQL%ROWCOUNT=0 THEN\r\nFOR n IN (\r\nSELECT bga_id,src_seq.CURRVAL src_id FROM bga join bga_type USING (bga_type_id) WHERE bga_type_code=\'PL_SE_POST_PROCESSING\'\r\n) loop\r\nbgao_i(n.bga_id,t_varchar2_tab(n.src_id));\r\nEND LOOP;\r\nEND IF;\r\nINSERT INTO src_pw_tmst (src_id, point_id, id, pw_rt, pck_t)\r\nSELECT s.src_id, b.id1, o.id, o.pw_rt, o.pck_t\r\nFROM src s,gttt b,src_pw_tmst o\r\nWHERE s.dp_id=d\r\nAND s.src_tmpl_id=t\r\nAND s.src_et IS NULL\r\nAND Nvl(s.point_id,b.id1)=b.id1\r\nAND b.c1<>\'0\'\r\nAND o.src_id=:1\r\nAND o.id=1;', NULL, NULL, NULL, 62),
	(345, 'INIT_FILL_POINT_CFG', 'Matavimo taškų prietaisų konfigūracinių parametrų skylių pildymas', 'Matavimo taškų prietaisų konfigūracinių parametrų skylių pildymas', 'orn NUMBER;\r\nP1 T7.IRR;\r\nA1 T7.CRR;', 'SELECT :1,\'0\' BULK COLLECT INTO P1,A1 FROM dual;\r\ninit_fill_point_cfg(P1,A1,orn);\r\nif A1(1)=\'0\' then\r\nif Nvl(:2,0)=0 then\r\nINSERT INTO ltl (req_type_code, rodo_id)\r\nSELECT req_type_code,orn FROM rc WHERE rc_id=16;\r\nelse\r\nINSERT INTO utl (req_type_code, rodo_id)\r\nSELECT req_type_code,orn FROM rc WHERE rc_id=16;\r\nend if;\r\nend if;', NULL, NULL, NULL, 87),
	(346, 'ANY_FROM_XFE_PL_DATA', 'Rodmenų generavimas iš suformuotų eksporto dokumentų', 'Rodmenų generavimas iš suformuotų eksporto dokumentų', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\npNR T7.IRR;\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nmi NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code=\'GENERATION_FETCH\'),100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nmi:=sPL_ID.Count;\r\nEXIT WHEN mi=0;\r\nselect level BULK COLLECT INTO pNR from dual connect by level<=mi;\r\nDELETE GTTT;\r\nFORALL j in 1..mi\r\nINSERT INTO GTTT (id0,id1) values (pNR(j),sPL_ID(j));\r\nSELECT d\r\nBULK COLLECT INTO s1\r\nFROM\r\n(SELECT /*+ use_nl(a b c) index(c plep_pk)*/ id0,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END d\r\nFROM\r\ngttt a\r\nleft join plu b ON (a.id1=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.id1=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY id0\r\nORDER BY id0);\r\nDELETE GTTT;\r\nFORALL j IN 1..mi\r\nINSERT INTO gttt (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT\r\nNULL,NULL,sPL_ID(j),sSEP_ID(j),xfe_t,\'\',xfe_v,Nvl(:7,0)\r\n,CASE WHEN improvable=0 THEN \'1\' ELSE \'14\' END,SYSDATE,\'\',sAGGS_TYPE_ID(j) aggs_type_id\r\nfrom\r\n(SELECT xfe_t,xfe_v,improvable\r\n,Rank() over (PARTITION BY point_id,ml_id,xfe_t ORDER BY xo_id desc) r\r\nFROM xfe_pl_data join xfe USING (xfe_id) join xfau USING (xfau_id) join xfa USING (xfa_id) join xf USING (xf_id)\r\nWHERE point_id=sPOINT_ID(j) AND ml_id=:1 AND xfe_t>=s1(j) AND xfe_t<s2\r\nAND regexp_like(xf_type_id,\'^(\'||Nvl(:8,\'1|6\')||\')$\')\r\n) WHERE r=1;\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(347, 'INIT_GEN_ANY_FROM_XFE_PL_DATA', 'Rodmenų generavimo iš suformuoto eksporto dokumento inicijavimas', 'Rodmenų generavimo iš suformuoto eksporto dokumento inicijavimas', NULL, NULL, 'SELECT * FROM\r\n(SELECT DISTINCT point_id,xo_bt,xo_et FROM xo join xf USING (xf_id) join xfa USING (xf_id) join xfau USING (xfa_id)\r\n WHERE regexp_like(xf_type_id,\'^(\'||Nvl(:8,\'1|6\')||\')$\') AND xo_id=:1 AND NOT point_id IS NULL\r\n)\r\n,(SELECT bga_id FROM bga join bga_type USING (bga_type_id) WHERE bga_enabled=1 AND bga_type_code =\'ANY_FROM_XFE_PL_DATA\')', 'bgao_i(c.bga_id,t_varchar2_tab(\'\',\'\',\'\',To_Char(c.xo_bt,\'YYYY.MM.DD\'),To_Char(c.xo_et,\'YYYY.MM.DD\'),c.point_id,1));', NULL, 26),
	(348, 'SRC_FROM_RULE_FOR_POINT', 'Atitinkamų matavimo taškams duomenų šaltinių sukūrimas arba papildymas', 'Atitinkamų matavimo taškams duomenų šaltinių sukūrimas arba papildymas', 'a VARCHAR2(250);\r\npPOINT_ID T7.IRR;', 'IF :1 IS NULL then\r\nFOR t IN\r\n(\r\nSELECT u.point_id FROM\r\nmou u\r\nJOIN point p ON (u.point_id=p.point_id)\r\nJOIN meter m ON (u.meter_id=m.meter_id)\r\nJOIN src_rule r ON (m.meter_type_id=r.meter_type_id)\r\nleft JOIN src s ON (u.point_id = s.point_id)\r\nWHERE u.mou_et IS NULL\r\nAND p.point_type_id=Nvl(r.point_type_id,p.point_type_id)\r\nAND Decode(p.ecp_id,Nvl(r.ecp_id,p.ecp_id),0,1)=0\r\nGROUP BY u.point_id\r\nHAVING NOT Min(s.src_id) IS NULL\r\nAND Max(Decode(src_et,NULL,1,0))=0\r\n) loop\r\nbgao_i(:0,t_varchar2_tab(t.point_id));\r\nEND LOOP;\r\nelse\r\nSELECT :1 BULK COLLECT INTO pPOINT_ID FROM dual;\r\na:=src_from_rule_i(\'\',\'\',pPOINT_ID,0);\r\nIF a LIKE \'1%\' THEN\r\nevent_i(1,1,-2,1,SYSDATE,\'SRC_FROM_RULE_I: \'||substr(a,2,249),pPOINT_ID=>:1);\r\nEND IF;\r\nEND IF;', NULL, NULL, NULL, 62),
	(351, 'PL_DATA_SET_DB_TIME_TO_NULL', 'Seno registravimo duomenų bazėje laiko informacijos išvalymas rodmenų lentelėje', 'Seno registravimo duomenų bazėje laiko informacijos išvalymas rodmenų lentelėje', 'CURRTMST DATE;\r\nTS DATE;\r\nbtc VARCHAR(250):=\'PL_DATA_SET_DB_TIME_TO_NULL\';', 'SELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE=btc)\r\n,TRUNC ((SYSDATE-interval \'5\' year),\'Y\')) INTO CURRTMST FROM DUAL;\r\nTS := SYSDATE;\r\nwhile (not (CURRTMST+nvl(:1,5)/1440 > (SYSDATE-nvl(:2,120)) OR SYSDATE > TS+nvl(:3,45)/86400)) LOOP\r\nUPDATE pl_data SET DB_TIME=NULL WHERE DB_TIME>=CURRTMST AND DB_TIME<CURRTMST + nvl(:1,5) / 1440\r\nAND ROWNUM<=nvl(:4,10000);\r\nIF SQL%ROWCOUNT=0 then\r\nCURRTMST := CURRTMST+nvl(:1,5)/1440;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,CURRTMST amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n(\r\n y.tmst_code\r\n,y.amp\r\n) values (\r\n u.tmst_code\r\n,u.amp\r\n);\r\nEND IF;\r\nCOMMIT;\r\nEND LOOP;', NULL, NULL, NULL, 56),
	(352, 'MANY_EVENTS', 'Daug įvykių', 'Daug įvykių', NULL, NULL, 'WITH c0 as\r\n(SELECT /*+parallel(a) materialize*/ point_id, withe_id,Count(*) cnt FROM\r\npw_data a\r\nWHERE pw_t> SYSDATE-Nvl(:1,4)\r\nGROUP BY point_id, withe_id\r\n)\r\n,c1 AS (SELECT /*+materialize*/point_id,o_cnt,\'(\'||cnt||CASE WHEN o_cnt>cnt THEN \'/\'||o_cnt end||\') \'||withe_name m\r\nFROM (\r\nSELECT c.*,Rank() over (PARTITION BY point_id ORDER BY cnt DESC,withe_id) rnk,Sum(cnt) over (PARTITION BY point_id) o_cnt\r\nFROM (\r\nselect point_id,withe_id,cnt,withe_name FROM c0 join withe USING (withe_id)\r\n) c\r\n)\r\nWHERE rnk=1\r\n)\r\nSELECT point_id\r\n,To_Date(NULL) grp_bt\r\n,To_Date(NULL) grp_et\r\n,Rank() over (ORDER BY o_cnt DESC,point_id) grp_nr\r\n,substr(m,1,120) grp_desc\r\nFROM c1 a\r\n WHERE o_cnt>=Nvl(:2,500)', NULL, NULL, 1),
	(356, 'TFF_EXTREME_DD_MM', 'Parų ar mėnesių ekstremumų tarifinių rodmenų generavimas', 'Parų ar mėnesių ekstremumų tarifinių rodmenų generavimas', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nsAGGF_ID T7.IRR;\r\ngf1 NUMBER(2);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npEXTREME_T T7.DRR;\r\npGF NUMBER;\r\nv_ttf_id number;\r\nv_md_id number;\r\nCURSOR c_ROWS ( tff_CODE NUMBER) IS\r\nWITH a AS\r\n(SELECT /*+ materialize*/\r\nSEP_ID,PL_ID,POINT_ID,aggs_type_id,aggf_id\r\nFROM GEN_IDs\r\nWHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n)\r\nSELECT /*+ use_nl(a b c) index(c plep_pk)*/ SEP_ID,a.PL_ID,a.POINT_ID ,aggs_type_id,a.aggf_id\r\n,CASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END\r\nfrom a\r\nJOIN ( SELECT distinct p.point_id FROM PTP p WHERE nvl(p.aggf_id,tff_CODE) = tff_CODE )\r\n     d ON d.point_id = a.POINT_ID\r\nleft join plu b ON (a.pl_id=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY SEP_ID,a.PL_ID,a.POINT_ID,aggs_type_id,a.aggf_id;', 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n  FROM spty\r\n WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nSELECT aggf_id\r\n  INTO gf1\r\n  FROM st_ml\r\n WHERE ml_id=:1;\r\nSELECT tff_id, md_id\r\n  INTO v_ttf_id, v_md_id\r\n  FROM st_ml\r\n WHERE ml_id=:2;\r\nif v_md_id = 6 then\r\n  s0:=Trunc(Nvl(:4,SYSDATE-:3), \'MM\');\r\n  s2:=Nvl(Add_Months(Trunc(:5, \'MM\'),1),SYSDATE);\r\nelse\r\n  s0:=Trunc(Nvl(:4,SYSDATE-:3));\r\n  s2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nend if;\r\nOPEN c_ROWS ( gf1 );\r\nLOOP\r\n  FETCH c_ROWS\r\n  BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,sAGGF_ID,s1\r\n  LIMIT pGF;\r\n  EXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(2,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,s0,s2,Nvl(:7,0),sAGGF_ID,s1=>s1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\',ex\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,pEXTREME_T\r\nFROM\r\n(SELECT c1,c2,c3,c4,\r\n   case when v_md_id = 6 then TRUNC(BT, \'MM\') else TRUNC(BT, \'DD\') end t\r\n   ,val v\r\n   ,CASE WHEN ST=1 OR SYSDATE<aET THEN \'14\' ELSE \'1\' END s\r\n   ,CASE WHEN (select aggf_id from ml where ml_id=:1) IN (4,5) THEN EXTREME_BT ELSE BT END ex\r\n  FROM\r\n    (select a.*\r\n    ,rank() over (partition by point_id, ml_id,\r\n     case when v_md_id = 6 then TRUNC(BT, \'MM\') else TRUNC(BT, \'DD\') end\r\n     order by HAS_SPECIFIC_DSTATUS, VAL desc, BT) rnkmx\r\n    ,rank() over (partition by point_id, ml_id,\r\n     case when v_md_id = 6 then TRUNC(BT, \'MM\') else TRUNC(BT, \'DD\') end\r\n     order by HAS_SPECIFIC_DSTATUS, -VAL desc, BT) rnkmn\r\n    ,max(HAS_SPECIFIC_DSTATUS) over (PARTITION BY POINT_ID, ML_ID,\r\n    case when v_md_id = 6 then TRUNC(BT, \'MM\') else TRUNC(BT, \'DD\') end) st,\r\n    case when v_md_id = 6 then TRUNC(add_months(BT,1), \'MM\')+1 else TRUNC(BT, \'DD\')+1 end aET\r\n    from\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,param1,\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),s2))\r\n    a where tff_id=v_ttf_id )\r\n    WHERE   ((rnkmx=1 and c4=4) or (rnkmn=1 and c4=5))\r\n    and val is not null and bt is not null) r\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans,pPCK_T,pPCK_N,pPCK_T,pPCK_N,pEXTREME_T);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(357, 'INSTANT_15MIN_TOTALS_FROM_ADJACENT_TOTALS', 'Suminių rodmenų proporcingas generavimas iš gretimų reikšmių, fiksuotų kas 15 min.', 'Suminių rodmenų proporcingas generavimas iš gretimų reikšmių, fiksuotų kas 15 min.', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nc_DATA DATE := SYSDATE;\r\nc_ROWS SYS_REFCURSOR;', 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n              FROM spty\r\n             WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nDELETE FROM GEN_ADJ$F1;\r\nIF Nvl(:7,\'0\')=1 THEN\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_15MIN_TOTALS_F\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:3) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,1,s,c_DATA,\'\'\r\n         FROM GEN_15_TOTALS_FROM_ADJ_TOTALS;\r\nELSE\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_15MIN_TOTALS\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:3) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,0,s,c_DATA,\'\'\r\n         FROM GEN_15_TOTALS_FROM_ADJ_TOTALS;\r\nEND IF;\r\nLOOP\r\n  FETCH c_ROWS\r\n   BULK COLLECT\r\n   INTO pPCK_T, pPCK_N , pPL_ID, pSEP_ID, pT, pDST, pV, pFORCED, pS, pRT, pRDST\r\n  LIMIT pGF;\r\n  EXIT WHEN pPL_ID.COUNT = 0;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(358, 'INSTANT_30MIN_TOTALS_FROM_ADJACENT_TOTALS', 'Suminių rodmenų proporcingas generavimas iš gretimų reikšmių, fiksuotų kas 30 min.', 'Suminių rodmenų proporcingas generavimas iš gretimų reikšmių, fiksuotų kas 30 min.', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nc_DATA DATE := SYSDATE;\r\nc_ROWS SYS_REFCURSOR;', 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n              FROM spty\r\n             WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nDELETE FROM GEN_ADJ$F1;\r\nIF Nvl(:7,\'0\')=1 THEN\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_30MIN_TOTALS_F\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:3) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,1,s,c_DATA,\'\'\r\n         FROM GEN_30_TOTALS_FROM_ADJ_TOTALS;\r\nELSE\r\n  INSERT INTO GEN_ADJ$F1\r\n  SELECT *\r\n    FROM ADJ_30MIN_TOTALS\r\n   WHERE da>=Nvl(:4,Trunc(SYSDATE)-:3) AND da<=Nvl(:5,sysdate)\r\n     --6/ and point_id=:6\r\n     AND ml_id=:2\r\n     AND bga_id=:0;\r\n  OPEN c_ROWS\r\n   FOR SELECT NULL,NULL,pl_id,sep_id,bt,\'\',v,0,s,c_DATA,\'\'\r\n         FROM GEN_30_TOTALS_FROM_ADJ_TOTALS;\r\nEND IF;\r\nLOOP\r\n  FETCH c_ROWS\r\n   BULK COLLECT\r\n   INTO pPCK_T, pPCK_N , pPL_ID, pSEP_ID, pT, pDST, pV, pFORCED, pS, pRT, pRDST\r\n  LIMIT pGF;\r\n  EXIT WHEN pPL_ID.COUNT = 0;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(359, 'HOLES_ECONOMY_SUSPEND', 'Skylių ekonomijos rėžimo suspendavimas', 'Skylių ekonomijos rėžimo suspendavimas', NULL, 'merge into TMST t using (select \'HOLES_ECONOMY_SUSPEND\' code, sysdate time from dual) a\r\n   ON (t.tmst_code = a.code)\r\nWHEN MATCHED THEN UPDATE SET t.amp = a.time\r\nWHEN NOT MATCHED THEN INSERT (t.tmst_code, amp) values (a.code, a.time);', NULL, NULL, NULL, 87),
	(360, 'ANY_PROF_EN_FROM_ANY_PROF_EN_AND_DAY', 'Energijos profilio rodmenų generavimas iš profilio reikšmių ir paros reikšmių', 'Energijos profilio rodmenų generavimas iš profilio reikšmių ir paros reikšmių', 'pPCK_T T7.DRR;pPCK_N T7.IRR;pPL_ID T7.IRR;sAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;pT T7.DRR;pDST T7.IRR;pV T7.NRR;pFORCED T7.IRR;pS T7.CRR;\r\npRT T7.DRR;pRDST T7.IRR;sSEP_ID T7.IRR;sPL_ID T7.IRR;sPOINT_ID T7.IRR;\r\npNR T7.IRR;ans VARCHAR2(250);s0 DATE;s1 T7.DRR;s2 DATE;pGF NUMBER;\r\nmi NUMBER;CURSOR c_ROWS IS SELECT SEP_ID,PL_ID,POINT_ID,AGGS_TYPE_ID\r\nFROM GEN_IDs WHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n;', 's0:=Trunc(Nvl(:4,SYSDATE-:3)); s2:=Nvl(Trunc(:5)+1,SYSDATE); SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty WHERE spty.spty_code=\'GENERATION_FETCH\'), 100) INTO pGF FROM dual;\r\nOPEN c_ROWS; LOOP FETCH c_ROWS BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID LIMIT pGF;\r\nmi:=sPL_ID.Count; EXIT WHEN mi=0; select level BULK COLLECT INTO pNR from dual connect by level<=mi;\r\nDELETE GTTT; FORALL j in 1..mi INSERT INTO GTTT (id0,id1) values (pNR(j),sPL_ID(j));\r\nSELECT d BULK COLLECT INTO s1 FROM\r\n(SELECT /*+ use_nl(a b c) index(c plep_pk)*/ id0,\r\nCASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\nMin(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\nELSE s0 END d FROM gttt a\r\nleft join plu b ON (a.id1=b.pl_id AND Nvl(:7,0)=0)\r\nleft join plep c ON (a.id1=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\nGROUP BY id0 ORDER BY id0);\r\nDELETE GTTT;\r\nFORALL j IN 1..mi\r\nINSERT INTO gttt (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\nSELECT\r\nNULL,NULL,sPL_ID(j),sSEP_ID(j),bt\r\n,\'\',round(new_val,6),Nvl(:7,0),CASE WHEN s=0 AND p=0 AND bad=1 THEN \'1\' else \'14\' end\r\n,SYSDATE,\'\',sAGGS_TYPE_ID(j) FROM\r\n(with a1 as (\r\nSELECT point_id,ml_id,da,bt,val,HAS_SPECIFIC_DSTATUS s\r\nFROM v_ar\r\nWHERE point_id=sPOINT_ID(j)\r\nAND ml_id=:1\r\nAND da>=Trunc(s1(j)) AND da<s2\r\nAND NOT val IS NULL )\r\nselect * from (select a.* ,case when a.val is null then (c.val-sum)/bad end as new_val , c.s from (select * from(\r\nSELECT point_id,ml_id,da,bt,val\r\n,sum(decode(val,null,1,0))over(partition by point_id, ml_id, da) bad\r\n,sum(val)over(partition by point_id, ml_id, da) Sum\r\n,max(Nvl2(val,HAS_SPECIFIC_DSTATUS,NULL))over(partition by point_id, ml_id, da) p\r\nfrom(\r\n select point_id, ml_id, da, bt\r\n ,decode(ssep_id,tsep_id,null,hsd)HAS_SPECIFIC_DSTATUS\r\n ,decode(ssep_id,tsep_id,null,val)val\r\n from(\r\n select sSEP_ID(j) tsep_id, point_id, ml_id,da,bt, HAS_SPECIFIC_DSTATUS hsd, val\r\n ,(select sep_id from pl_data b where sPL_ID(j)=PL_ID and b.pl_t=a.bt\r\n and sAGGS_TYPE_ID(j)=AGGS_TYPE_ID and sSEP_ID(j)=sep_id and Nvl(:7,0)=1) ssep_id\r\n FROM v_ar a WHERE point_id=sPOINT_ID(j) AND ml_id=:2 AND da>=Trunc(s1(j)) AND da<s2\r\n )d\r\n )\r\n)where bad>0) a join a1 c on (a.point_id=c.point_id and a.da=c.da)\r\n) where new_val is not null\r\n) f;\r\nSELECT\r\nd1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM gttt f\r\n--/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(361, 'BY_POINT_TYPE', 'Pagal matavimo taškų tipus', 'Pagal matavimo taškų tipus', NULL, NULL, 'select point_id from st_point where point_type_code=:1 and point_enabled=1', NULL, NULL, 1),
	(362, 'ADD_NEW_GROUP_BY_POINT_TYPE', 'Naujų grupių įtraukimas į grupę pagal matavimo taškų tipus (atsiradus naujiems matavimo tašku tipams)', 'Naujų grupių įtraukimas į grupę pagal matavimo taškų tipus (atsiradus naujiems matavimo tašku tipams)', 'a VARCHAR2(250);', 'FOR t IN (SELECT * FROM\r\n (SELECT bga_type_id FROM bga_type WHERE bga_type_code = \'BY_POINT_TYPE\') a\r\n,(SELECT gr_type_id FROM gr_type WHERE gr_type_code = \'SYSTEM\') b\r\n,(SELECT sch_id FROM schi_data WHERE sch_int_id = 1\r\n  AND per_id = 3 AND sch_int_value = 1 AND ROWNUM<2) c\r\n,(SELECT gr_id FROM gr WHERE gr_code = \'BY_POINT_TYPE\') d\r\n) LOOP\r\n  FOR u IN (\r\n  SELECT co,Max(na)na,Max(gr_id)gr_id,Sum(cf)r FROM (\r\n  SELECT 1 cf,point_type_code co,point_type_name na,\'\'+0 gr_id\r\n  FROM point_type a\r\n  WHERE EXISTS (SELECT 0 FROM point WHERE point_type_id = a.point_type_id AND point_enabled=1)\r\n  UNION ALL\r\n  SELECT -1 cf, bga_param_value co,\'\' na,gr_id FROM bga b\r\n  join bga_param c on (b.bga_id=c.bga_id AND c.bga_param_nr=1)\r\n  WHERE b.bga_type_id=t.bga_type_id\r\n  ) GROUP BY co having Sum(cf)!=0) LOOP\r\n    IF u.r=1 THEN\r\n      a:=gr_i(t.GR_TYPE_ID,u.co,1,u.na);\r\n      FOR g IN (SELECT gr_id FROM gr WHERE gr_code=u.co) LOOP\r\n        a:=grc_i(t.gr_id,g.gr_id);\r\n        a:=bga_i(t.BGA_TYPE_ID,u.na,1,t.SCH_ID,g.GR_ID);\r\n        FOR b IN (SELECT bga_id FROM bga WHERE bga_name=u.na) LOOP\r\n          a:=bga_param_i(b.BGA_ID,1,u.co);\r\n        END LOOP;\r\n      END LOOP;\r\n    ELSIF u.r=-1 then\r\n      a:=gr_d(u.gr_id);\r\n    END IF;\r\n  END LOOP;\r\nEND LOOP;', NULL, NULL, NULL, 1),
	(363, 'N_MIN_FIXED_TOTALS_FROM_N_MIN_FIXED_AND_PROFILE', 'Trūkstamų fiksuojamų kas N min suminių rodmenų generavimas iš fiksuojamų suminių ir profilio (galios arba energijos)', 'Trūkstamų fiksuojamų kas N min suminių rodmenų generavimas iš fiksuojamų suminių ir profilio (galios arba energijos)', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\ngf1 NUMBER(2);\r\ncnt1 NUMBER(5);\r\ncnt2 NUMBER(5);\r\nans VARCHAR2(250);\r\ns0 DATE;\r\ns1 T7.DRR;\r\ns2 DATE;\r\npGF NUMBER;\r\nCURSOR c_ROWS ( s0 DATE, s2 DATE) IS\r\nWITH a AS\r\n(SELECT /*+ materialize*/\r\n        SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\n   FROM GEN_IDs\r\n  WHERE ml_id=:2 AND bga_id=:0 --6/ and point_id=:6\r\n)\r\nSELECT /*+ use_nl(a b c) index(c plep_pk)*/ SEP_ID,a.PL_ID,POINT_ID ,aggs_type_id\r\n  ,CASE WHEN Min(CASE WHEN c.plep_bt=s0 AND s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL THEN 1 END)=1 THEN\r\n  Min(CASE WHEN NOT (s_hosf=4 AND exp_t IS NULL AND b.pl_id IS NULL) THEN c.plep_bt END)\r\n  ELSE s0 END\r\n  FROM a\r\n  LEFT JOIN plu b ON (a.pl_id=b.pl_id AND Nvl(:7,0)=0)\r\n  LEFT JOIN plep c ON (a.pl_id=c.pl_id AND c.plep_bt>=s0 AND c.plep_bt<s2 AND Nvl(:7,0)=0)\r\n GROUP BY SEP_ID,a.PL_ID,POINT_ID,aggs_type_id;', 's0:=Trunc(Nvl(:4,SYSDATE-:3));\r\ns2:=Nvl(Trunc(:5)+1,SYSDATE);\r\nSELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\n             FROM spty\r\n            WHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\n INTO pGF\r\n FROM dual;\r\nselect md_cnt,aggf_id into cnt1,gf1 from st_ml where ml_id=:1;\r\nselect md_cnt into cnt2 from st_ml where ml_id=:2;\r\nOPEN c_ROWS ( s0, s2);\r\nLOOP\r\n  FETCH c_ROWS\r\n  BULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID,s1\r\n  LIMIT pGF;\r\n  EXIT WHEN sPL_ID.Count=0;\r\n  FORALL j IN 1..sPL_ID.count\r\n    INSERT INTO gttt\r\n    (d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6,id8)\r\n    select \'\',\'\',sPL_ID(j),sSEP_ID(j),d,\'\',v,Nvl(:7,0),\'1\',sysdate,\'\',sAGGS_TYPE_ID(j)\r\n    FROM (select b.*\r\n    ,Rank() over (PARTITION BY d ORDER BY i)r from\r\n    (select i,d,Sum(v)v FROM\r\n    (select i,bt+Decode(i,2,Decode(ml_id,:1,0,(-1)/cnt1),1/cnt1) d,\r\n    case when ml_id=:1 and i=2 then -1 else 1 end*val*Decode(gf1,3,24/cnt1,1) v\r\n     from v_ar v,(SELECT LEVEL i FROM dual CONNECT BY LEVEL<=2),\r\n         (SELECT DISTINCT point_id, Trunc(mou_bt) m FROM mou) u\r\n    WHERE v.point_id = sPOINT_ID(j)\r\n      AND v.point_id = u.point_id(+)\r\n      AND v.da = u.m (+)\r\n      AND u.point_id IS NULL\r\n      AND v.ml_id in (:1,:2)\r\n      AND v.da>=trunc(s1(j))-1 and v.bt>=s1(j)-1/cnt1 and v.da<s2 and v.bt<s2\r\n      AND v.has_specific_dstatus=0\r\n    ) GROUP BY i,d having Count(*)=2\r\n    ) b\r\n    ) WHERE r=1;\r\n  SELECT d1,id1,id2,id3,d2,id4,v1,id5,c1,d3,id6\r\n  BULK COLLECT INTO\r\n  pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\n  FROM gttt f\r\n  --/7 where not exists (SELECT 0 FROM pl_data WHERE pl_id=f.id2 AND pl_t=f.d2 and aggs_type_id=f.id8 AND nvl2(pl_v,nvl(bitand(tstatus,1),0),1)=0)\r\n;\r\n  store_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(364, 'SHRINK_BUF', 'Buferinių struktūrų suspaudimas', 'Buferinių struktūrų suspaudimas', NULL, 'for i in (select table_name from user_tables\r\n  where table_name like \'%^_BUF\' escape \'^\') loop\r\n  begin\r\n    execute immediate \'alter table \'||i.table_name||\' enable row movement\';\r\n    execute immediate \'alter table \'||i.table_name||\' shrink space\';\r\n    execute immediate \'alter table \'||i.table_name||\' disable row movement\';\r\n  exception when others then null;\r\n  end;\r\nend loop;\r\nfor i in (select index_name from user_indexes\r\n  where table_name like \'%^_BUF\' escape \'^\') loop\r\n  begin\r\n    execute immediate \'alter index \'||i.index_name||\' shrink space\';\r\n  exception when others then null;\r\n  end;\r\nend loop;', NULL, NULL, NULL, 56),
	(365, 'IMPROPER', 'Nėra galutinių rodmenų', 'Nėra galutinių rodmenų', NULL, NULL, 'SELECT /*+ parallel(a)*/p.point_id FROM\r\npoint p\r\njoin pl b ON (p.point_id=b.point_id)\r\njoin di i ON (b.pl_id=i.pl_id)\r\njoin plep a ON (b.pl_id=a.pl_id)\r\nleft join (SELECT new_val point_id\r\nFROM au join tab USING (tab_id) join au_idata USING (db_time,au_nr) join col USING (col_id)\r\nWHERE tab_name=\'SRC\' AND operation_type=\'I\' AND db_time>SYSDATE-1\r\nAND col_name = \'POINT_ID\' AND NOT new_val IS null) s ON (p.point_id=s.point_id)\r\nWHERE plep_bt>= Trunc(SYSDATE)-:1 and point_enabled=1\r\nAND point_auto_read_enabled=1 AND pl_enabled=1\r\nAND s.point_id IS null\r\nAND di_enabled=1 group by p.point_id having max(Nvl(s_hosf,0))<3', NULL, NULL, 1),
	(366, 'UPDATE_PL_DATA_CUSTOM', 'Papildančių rodmenį specifinių nuskaitymų informacijos atnaujinimas', 'Papildančių rodmenį specifinių nuskaitymų informacijos atnaujinimas', NULL, 'update_pl_data_custom\r\n(\r\nNvl(:2,Add_Months(Trunc(SYSDATE,\'MM\'),1-Nvl(:1,2)))\r\n,Nvl(:3,sysdate)\r\n,:4\r\n);', NULL, NULL, NULL, 92),
	(367, 'BOTTOM_10_NOT_FAILED_DP_BY_SUCCESS', 'Blogiausi atsakantys nuskaitymo taškai pagal užklausų sėkmės procentą', 'Blogiausi atsakantys nuskaitymo taškai pagal užklausų sėkmės procentą', NULL, NULL, 'WITH\r\nr AS (SELECT\r\n Trunc(SYSDATE)-1 - grq_max_duration/1440 d0\r\n,Trunc(SYSDATE)-1 d1\r\n,Trunc(SYSDATE) d2\r\nFROM\r\n(SELECT Nvl((SELECT To_Number(Nvl(spty_value,spty_default)) FROM spty WHERE spty_id = 52),180) grq_max_duration FROM dual)\r\n)\r\n,f as\r\n(SELECT src_atime, das_id, src_anr\r\nFROM sta_prq_data,r\r\nWHERE src_atime BETWEEN d0 AND d2-1/86400\r\nAND NOT evc_id IS NULL\r\n)\r\n,e AS\r\n(\r\nSELECT grq_time, das_id, grq_nr FROM\r\n(SELECT grq_time, das_id, grq_nr\r\nFROM sta_src_data,r\r\nWHERE src_atime BETWEEN d0 AND d2-1/86400\r\nAND NOT evc_id IS NULL\r\nUNION ALL\r\nSELECT grq_time, das_id, grq_nr\r\nFROM r cross join sta_src_data join f USING (src_atime, das_id, src_anr)\r\nWHERE src_atime BETWEEN d0 AND d2-1/86400\r\n)\r\nGROUP BY grq_time, das_id, grq_nr\r\n)\r\n,j as\r\n(SELECT grq_time, das_id, grq_nr\r\n,Max(CASE WHEN NOT evc_id IS NULL THEN 1 END) E\r\n  FROM sta_grq_data,r\r\n  WHERE grq_time BETWEEN d0 AND d2-1/86400\r\nGROUP BY grq_time,das_id,grq_nr\r\nHAVING Max(CASE WHEN grq_otype_id IN (4,5,6,7,9,10) THEN grq_otime end) BETWEEN Max(d1) AND Max(d2)-1/86400\r\n  )\r\n,k AS (\r\nSELECT\r\na.dp_id\r\n FROM spac a\r\njoin ph a0 ON (a.ph_id = a0.ph_id)\r\nleft join ph_state s ON (a.ph_id=s.ph_id)\r\n WHERE a.ph_enabled=1 AND dp_enabled=1\r\nGROUP BY a.dp_id\r\nHAVING\r\nNvl(Max(\r\nCASE WHEN s.costa_id=1 AND SYSDATE<=\r\n CASE nvl(a0.COSTA_G_PER_ID,4)\r\n   WHEN 6 THEN Add_Months(s.costa_last_check,12*a0.COSTA_G_EXP_VALUE)\r\n   WHEN 5 THEN Add_Months(s.costa_last_check,a0.COSTA_G_EXP_VALUE)\r\n   WHEN 4 THEN s.costa_last_check+Nvl(a0.COSTA_G_EXP_VALUE,1)\r\n   WHEN 3 THEN s.costa_last_check+a0.COSTA_G_EXP_VALUE/24\r\n   WHEN 2 THEN s.costa_last_check+a0.COSTA_G_EXP_VALUE/1440\r\n   WHEN 1 THEN s.costa_last_check+a0.COSTA_G_EXP_VALUE/86400\r\n END\r\nTHEN 1\r\nWHEN s.costa_id=2 AND SYSDATE>\r\n CASE nvl(a0.COSTA_B_PER_ID,3)\r\n   WHEN 6 THEN Add_Months(s.costa_last_check,12*a0.COSTA_B_EXP_VALUE)\r\n   WHEN 5 THEN Add_Months(s.costa_last_check,a0.COSTA_B_EXP_VALUE)\r\n   WHEN 4 THEN s.costa_last_check+a0.COSTA_B_EXP_VALUE\r\n   WHEN 3 THEN s.costa_last_check+Nvl(a0.COSTA_B_EXP_VALUE,1)/24\r\n   WHEN 2 THEN s.costa_last_check+a0.COSTA_B_EXP_VALUE/1440\r\n   WHEN 1 THEN s.costa_last_check+a0.COSTA_B_EXP_VALUE/86400\r\n END\r\nTHEN 0\r\nEND\r\n),1)>0\r\n)\r\n,d AS\r\n(SELECT\r\ngrq_time, das_id, grq_nr, Max(e) e, Max(dp_id) dp_id\r\nFROM j\r\ncross join r\r\njoin sta_prq USING (grq_time, das_id, grq_nr)\r\njoin sepac USING (sep_id)\r\njoin k USING (dp_id)\r\nWHERE prq_time BETWEEN d0 AND d2-1/86400\r\nGROUP BY grq_time, das_id, grq_nr\r\n)\r\n,c AS\r\n(SELECT grq_time, das_id, grq_nr,dp_id FROM (\r\nSELECT grq_time, das_id, grq_nr,dp_id\r\nFROM d WHERE NOT e IS NULL\r\nUNION ALL\r\nSELECT grq_time, das_id, grq_nr,dp_id\r\nFROM d join e USING (grq_time, das_id, grq_nr)\r\n)\r\nGROUP BY grq_time, das_id, grq_nr,dp_id\r\n)\r\nSELECT /*+parallel*/ * FROM\r\n(\r\nSELECT -gr_id comp_id\r\n,To_Date(NULL) grc_bt\r\n,To_Date(NULL) grc_et\r\n,Rank() over (ORDER BY (1-cnt_bad/cnt_all),cnt_all DESC,dp_id) grc_nr\r\n,Round((1-cnt_bad/cnt_all)*100,2)||\'% (\'||cnt_all||\')\' grc_desc\r\nFROM\r\n(SELECT dp_id,Count(*) cnt_all FROM d GROUP BY dp_id)\r\njoin (SELECT dp_id,Count(*) cnt_bad FROM c GROUP BY dp_id) USING (dp_id)\r\njoin (SELECT dp_id,gr_id FROM dp,gr WHERE gr_code=\'BY_DP_\'||DP_CODE) USING (dp_id)\r\nWHERE cnt_bad< cnt_all\r\n) WHERE grc_nr<=10', NULL, NULL, 1),
	(368, 'MONTH_SUM_OF_ALL_TARIFFS_RAW', 'Mėnesio sumos rodmenų generavimas iš mėnesio visų tarifų sumų rodmenų pirminių reikšmių', 'Mėnesio sumos rodmenų generavimas iš mėnesio visų tarifų sumų rodmenų pirminių reikšmių', 'y T_VARCHAR2_TAB;', 'SELECT CAST(COLLECT(\'#PL.SELF.\'||ml_id||\'.RAW\') AS T_VARCHAR2_TAB) INTO y\r\nFROM ml WHERE (ms_id,dir_id,aggs_id,aggf_id,md_id) IN\r\n(SELECT ms_id,dir_id,aggs_id,aggf_id,md_id FROM ml WHERE ml_id=:1) AND tff_id BETWEEN 1 AND 4;\r\ngenerate_using_formula.run(\'[1]+[2]+[3]+[4]\'\r\n,:0,:2,:3*31,:4,:5,:6,:7\r\n,null,y,1);', NULL, NULL, NULL, 26),
	(369, 'SUM_OF_ALL_TARIFFS_HOUR_RAW', 'Sumos rodmenų generavimas iš visų tarifų suminių rodmenų, fiksuotų kas valandą, pirminių reikšmių', 'Sumos rodmenų generavimas iš visų tarifų suminių rodmenų, fiksuotų kas valandą, pirminių reikšmių', 'y T_VARCHAR2_TAB;', 'SELECT CAST(COLLECT(\'#PL.SELF.\'||ml_id||\'.RAW\') AS T_VARCHAR2_TAB) INTO y\r\nFROM ml WHERE (ms_id,dir_id,aggs_id,aggf_id,md_id) IN\r\n(SELECT ms_id,dir_id,aggs_id,aggf_id,md_id FROM ml WHERE ml_id=:1) AND tff_id BETWEEN 1 AND 4;\r\ngenerate_using_formula.run(\'[1]+[2]+[3]+[4]\'\r\n,:0,:2,:3,:4,:5,:6,:7\r\n,null,y,1);', NULL, NULL, NULL, 26),
	(370, 'SUM_OF_ALL_TARIFFS_RAW', 'Sumos rodmenų generavimas iš visų tarifų sumų rodmenų pirminių reikšmių', 'Sumos rodmenų generavimas iš visų tarifų sumų rodmenų pirminių reikšmių', 'y T_VARCHAR2_TAB;', 'SELECT CAST(COLLECT(\'#PL.SELF.\'||ml_id||\'.RAW\') AS T_VARCHAR2_TAB) INTO y\r\nFROM ml WHERE (ms_id,dir_id,aggs_id,aggf_id,md_id) IN\r\n(SELECT ms_id,dir_id,aggs_id,aggf_id,md_id FROM ml WHERE ml_id=:1) AND tff_id BETWEEN 1 AND 4;\r\ngenerate_using_formula.run(\'[1]+[2]+[3]+[4]\'\r\n,:0,:2,:3,:4,:5,:6,:7\r\n,null,y,1);', NULL, NULL, NULL, 26),
	(371, 'DAY_SUM_OF_ALL_TARIFFS_RAW', 'Paros sumos rodmenų generavimas iš visų tarifų sumų rodmenų pirminių reikšmių', 'Paros sumos rodmenų generavimas iš visų tarifų sumų rodmenų pirminių reikšmių', 'y T_VARCHAR2_TAB;', 'SELECT CAST(COLLECT(\'#PL.SELF.\'||ml_id||\'.RAW\') AS T_VARCHAR2_TAB) INTO y\r\nFROM ml WHERE (ms_id,dir_id,aggs_id,aggf_id,md_id) IN\r\n(SELECT ms_id,dir_id,aggs_id,aggf_id,md_id FROM ml WHERE ml_id=:1) AND tff_id BETWEEN 1 AND 4;\r\ngenerate_using_formula.run(\'[1]+[2]+[3]+[4]\'\r\n,:0,:2,:3,:4,:5,:6,:7\r\n,null,y,1);', NULL, NULL, NULL, 26),
	(372, 'DS_DATA_FROM_SAM', 'Diskretinių signalų generavimas iš šablono reikšmių', 'Diskretinių signalų generavimas iš šablono reikšmių', 'ans varchar2(250);ans2 varchar2(250);\r\nsSAM_ID t7.irr;\r\nsds_id t7.irr;\r\nstbt t7.crr;\r\nstet t7.crr;\r\nssep_id t7.irr;\r\npPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npDS_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.CRR;\r\npDST T7.IRR;\r\npV T7.IRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\npREQ_FROM T7.DRR;\r\npREQ_FROM_DST T7.IRR;\r\npREQ_TO   T7.DRR;\r\npREQ_TO_DST T7.IRR;', 'with bga_conf as (SELECT /*+ materialize*/DS_TYPE_ID,GR_ID,DS_TYPE_GR_PRIORITY,SAM_ID\r\nFROM ST_DS_TYPE_GR where sam_id is not null\r\n--1/ and DS_TYPE_CODE=:1\r\n--2/ and SAM_CODE=:2\r\n--6/ and GR_CODE=:6 )\r\n, ds_conf as\r\n(select */*+ materialize*/\r\nfrom(\r\n    select a.*,d.ds_id\r\n    ,rank() over (partition by\r\n     a.DS_TYPE_ID,\r\n     a.SAM_ID order by a.ds_type_gr_priority, a.gr_id, b.comp_id\r\n    ) rnk\r\n    from\r\n    (SELECT gr_id cont_id, gr_id comp_id, ds_id , ds_type_id\r\n          FROM st_ds_gr\r\n          UNION /*ALL*/\r\n          SELECT cont_id, comp_id, ds_id , ds_type_id\r\n          FROM st_ds_gr a\r\n          join st_grcj b ON (b.comp_id=a.gr_id)\r\n          where grc_et IS NULL\r\n          ) b\r\n    join bga_conf a ON (b.cont_id=a.gr_id and a.ds_type_id=b.ds_type_id)\r\n    join st_ds0 d ON (b.ds_id=d.ds_id)\r\n    ) where rnk=1)\r\nselect\r\nSAM_ID,ds_id, null ssep_id,to_char(nvl(:4,SYSDATE+:3),\'YYYY.MM.DD HH24:MI:SS\')tbt, to_char(nvl(:5,sysdate+:7)+1,\'YYYY.MM.DD HH24:MI:SS\') tet\r\nbulk collect into\r\nsSAM_ID,sds_id,ssep_id,stbt,stet\r\nfrom ds_conf;\r\ndelete_ds_data(sds_id,ssep_id,stbt,stet, ans);\r\nIF NOT ans =\'0\' THEN\r\n  ans2 :=SubStr(\'BGA: \'||substr(ans,1,249),1,250);\r\n  event_i(1,1,1,1,SYSDATE,ans2);\r\n  COMMIT;\r\nEND IF;\r\nif ans=\'0\' then\r\ndelete gttt;\r\nFORALL j IN 1..sds_id.count\r\n  insert into gttt(id0,id1)values(ssam_id(j),sds_id(j));\r\n  select to_date(null),null,DS_ID,null,to_char(bt,\'YYYY.MM.DD HH24:MI:SS\')DS_BT,\'\',val,null,\'1\',sysdate, null,to_date(null),null,to_date(null),null\r\n  bulk collect into\r\n  pPCK_T,pPCK_N,pDS_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,pREQ_FROM,pREQ_FROM_DST,pREQ_TO,pREQ_TO_DST\r\n  from(\r\n  with arch as (\r\n    select b.*\r\n    ,lag(b.val) over(partition by b.sam_id order by b.mo,b.da,b.bt) lag_val\r\n    from (select b.*\r\n    from st_ar_sam b\r\n    where b.sam_id in (select distinct a.id0 from gttt a)\r\n    and b.da>=trunc(nvl(:4,SYSDATE+:3)) and b.da<trunc(nvl(:5,sysdate+:7)+1) and b.bt>=nvl(:4,SYSDATE+:3) and b.bt<nvl(:5,sysdate+:7)\r\n    and val is not null and has_specific_dstatus=0\r\n    )b)\r\nselect * from (\r\n     select b.id1 DS_ID,a.BT,a.val\r\n      ,decode(val,lag_val,0,1) rodiklis\r\n      from\r\n      arch a, gttt b where a.sam_id=b.id0\r\n     ) where rodiklis=1);\r\n  IF SQL%ROWCOUNT>0 THEN\r\n   store_ds(pPCK_T,pPCK_N,pDS_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,pREQ_FROM ,pREQ_FROM_DST,pREQ_TO,pREQ_TO_DST,ans);\r\n    IF NOT ans =\'0\' THEN\r\n      ans :=SubStr(\'CHECK_MA STORE_DS: \'||substr(ans,2,249),1,250);\r\n      event_i(1,1,1,1,SYSDATE,ans);\r\n      COMMIT;\r\n    END IF;\r\n  END IF;\r\nEND IF;', NULL, NULL, NULL, 26),
	(377, 'AUTO_DELETE_BGA_AUD_DATA', 'Automatinis audito įrašų apie duomenų keitimo operacijas, atliktas foninių užduočių, trynimas', 'Automatinis audito įrašų apie duomenų keitimo operacijas, atliktas foninių užduočių, trynimas', 'a DATE;\r\nb DATE;', 'SELECT Nvl((SELECT amp FROM tmst WHERE tmst_code = \'AUTO_DELETE_BGA_AUD_DATA\'),DATE\'2000-01-01\'),Least(SYSDATE-Nvl(:1,10),SYSDATE-1/48) INTO a,b FROM dual;\r\ndelete (SELECT db_time FROM au join tab USING (tab_id) where tab_name in (\'GRP\',\'POINT_PPTY\',\'GR_GPTY\',\'GRC\') and ses_id is null and db_time>=a and db_time<b) WHERE rownum<=2000000;\r\nIF SQL%ROWCOUNT<2000000 THEN\r\nMERGE INTO tmst y\r\nUSING (SELECT \'AUTO_DELETE_BGA_AUD_DATA\' tmst_code,b amp FROM dual) u\r\n   ON (y.tmst_code = u.tmst_code)\r\nWHEN MATCHED THEN UPDATE SET\r\n y.amp= u.amp\r\nWHERE NOT y.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n (\r\n y.tmst_code\r\n,y.amp\r\n) values (\r\n u.tmst_code\r\n,u.amp\r\n);\r\nEND IF;', NULL, NULL, NULL, 56),
	(378, 'AUTO_DELETE_CUSTOM_FROM_PL_DATA', 'Automatinis visų matavimo taškų specifinių galiojančių duomenų įrašų trynimas', 'Automatinis visų matavimo taškų specifinių galiojančių duomenų įrašų trynimas', 'CURRTMST DATE;\r\nTS DATE;\r\nep INTEGER;\r\nbtc VARCHAR(250):=\'AUTO_DELETE_CUSTOM_FROM_PL_DATA\';', 'SELECT CASE WHEN exists (select 0 from USER_TAB_PARTITIONS where TABLESPACE_NAME like \'EMCOS_%\'\r\nAND TABLE_NAME = \'PL_DATA_CUSTOM\') THEN 1 ELSE 0 END INTO ep FROM dual;\r\nIF ep=1 THEN\r\nfor i in (select\r\nTABLE_NAME tn,\r\nPARTITION_NAME pname,\r\nADD_MONTHS(TO_DATE(SUBSTR(PARTITION_NAME,5,11)||\'01\', \'YYYYMMDD\'),1) dt\r\nfrom USER_TAB_PARTITIONS\r\nwhere TABLE_NAME = \'PL_DATA_CUSTOM\') LOOP\r\nif i.dt < SYSDATE-nvl(:2,31)\r\nTHEN\r\n--disable FK\r\nDELETE gtts;\r\nINSERT INTO gtts (id0,c1)\r\nSELECT ts_id,\r\n\'alter table ||table_name|| modify constraint ||constraint_name|| \'||Decode(ts_id,0,\'disable\',\'enable novalidate\')\r\nFROM (\r\nSELECT table_name,constraint_name FROM user_constraints a\r\nWHERE LEVEL=2\r\nCONNECT BY PRIOR constraint_name=r_constraint_name AND PRIOR constraint_type=\'P\' AND constraint_type=\'R\'\r\nSTART WITH table_name =\'PL_DATA_CUSTOM\'\r\n),ts;\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=0) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nEXECUTE IMMEDIATE \'alter table \'||i.tn||\' drop partition \'||i.pname;\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=1) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,i.dt amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET y.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT(y.tmst_code,y.amp) values (u.tmst_code,u.amp);\r\nend if;END LOOP;\r\nELSE\r\nSELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE=btc)\r\n,TRUNC ((SYSDATE-interval \'5\' year),\'Y\')) INTO CURRTMST FROM DUAL;\r\nTS := SYSDATE;\r\nwhile (not (CURRTMST+nvl(:1,5)/1440 > (SYSDATE-nvl(:2,31)) OR SYSDATE > TS+nvl(:3,45)/86400))LOOP\r\nDELETE PL_DATA_CUSTOM WHERE DB_TIME<CURRTMST+nvl(:1,5)/1440 AND ROWNUM<=nvl(:4,10000);\r\nIF SQL%ROWCOUNT=0 then\r\nCURRTMST := CURRTMST+nvl(:1,5)/1440;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,CURRTMST amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET y.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT(y.tmst_code,y.amp) values (u.tmst_code,u.amp);\r\nEND IF;\r\nCOMMIT;\r\nEND LOOP;\r\nEND IF;', NULL, NULL, NULL, 56),
	(382, 'AUTO_DELETE_FROM_CP_DATA', 'Automatinis rodmenų uždarymo verifikavimo rezultatų duomenų įrašų trynimas', 'Automatinis rodmenų uždarymo verifikavimo rezultatų duomenų įrašų trynimas', 'CURRTMST DATE;\r\nTS DATE;\r\nep INTEGER;\r\nbtc VARCHAR(250):=\'AUTO_DELETE_FROM_CP_DATA\';', 'SELECT CASE WHEN exists (select 0 from USER_TAB_PARTITIONS where TABLESPACE_NAME like \'EMCOS_%\'\r\nAND TABLE_NAME = \'CP_DATA\') THEN 1 ELSE 0 END INTO ep FROM dual;\r\nIF ep=1 THEN\r\nfor i in (select\r\nTABLE_NAME tn,\r\nPARTITION_NAME pname,\r\nADD_MONTHS(TO_DATE(SUBSTR(PARTITION_NAME, 5, 11)||\'01\', \'YYYYMMDD\'),1) dt\r\nfrom USER_TAB_PARTITIONS\r\nwhere TABLE_NAME IN (\'CP_DATA\') order by 1) LOOP\r\nif i.dt < SYSDATE-nvl(:2,31)\r\nTHEN\r\n--disable FK\r\nDELETE gtts;\r\nINSERT INTO gtts (id0,c1)\r\nSELECT ts_id,\r\n\'alter table ||table_name|| modify constraint ||constraint_name|| \'||Decode(ts_id,0,\'disable\',\'enable novalidate\')\r\nFROM (\r\nSELECT table_name,constraint_name FROM user_constraints a\r\nWHERE LEVEL=2\r\nCONNECT BY PRIOR constraint_name=r_constraint_name AND PRIOR constraint_type = \'P\' AND constraint_type=\'R\'\r\nSTART WITH table_name IN (\'CP_DATA\')\r\n), ts;\r\n-- disable FK\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=0) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nEXECUTE IMMEDIATE \'alter table \'||i.tn||\' drop partition \'||i.pname;\r\nFOR t IN (SELECT c1 FROM gtts WHERE id0=1) LOOP\r\nEXECUTE IMMEDIATE t.c1;\r\nEND LOOP;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,i.dt amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\n y.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n (y.tmst_code,y.amp)values(u.tmst_code,u.amp);\r\nend if;END LOOP;\r\nELSE\r\nSELECT NVL ((SELECT AMP FROM TMST WHERE TMST_CODE=btc)\r\n,TRUNC ((SYSDATE-interval \'5\' year),\'Y\')) INTO CURRTMST FROM DUAL;\r\nTS := SYSDATE;\r\nwhile (not (CURRTMST+nvl(:1,5)/1440 > (SYSDATE-nvl(:2,31)) OR SYSDATE > TS+nvl(:3,45)/86400))LOOP\r\nDELETE CP_DATA WHERE CP_T<CURRTMST+nvl(:1,5)/1440\r\n--5/AND CP_T>=CURRTMST\r\nAND ROWNUM<=nvl(:4,10000);\r\nIF SQL%ROWCOUNT=0 then\r\nCURRTMST := CURRTMST+nvl(:1,5)/1440;\r\nMERGE INTO tmst y\r\nUSING (SELECT btc TMST_CODE,CURRTMST amp FROM dual) u\r\nON (y.TMST_CODE=u.TMST_CODE)\r\nWHEN MATCHED THEN UPDATE SET\r\ny.amp = u.amp\r\nWHEN NOT MATCHED THEN INSERT\r\n (y.tmst_code,y.amp)values(u.tmst_code,u.amp);\r\nEND IF;\r\nCOMMIT;\r\nEND LOOP;\r\nEND IF;', NULL, NULL, NULL, 56),
	(383, '5_MIN_AVG_FROM_INSTANT_TOTALS', 'Vidutinių rodmenų per 5 minutes generavimas iš augančių reikšmių', 'Vidutinių rodmenų per 5 minutes generavimas iš augančių reikšmių', 'pPCK_T T7.DRR;\r\npPCK_N T7.IRR;\r\npPL_ID T7.IRR;\r\nsAGGS_TYPE_ID T7.IRR;\r\npSEP_ID T7.IRR;\r\npT T7.DRR;\r\npDST T7.IRR;\r\npV T7.NRR;\r\npFORCED T7.IRR;\r\npS T7.CRR;\r\npRT T7.DRR;\r\npRDST T7.IRR;\r\nsSEP_ID T7.IRR;\r\nsPL_ID T7.IRR;\r\nsPOINT_ID T7.IRR;\r\nans VARCHAR2(250);\r\npGF NUMBER;\r\nCURSOR c_ROWS IS\r\nSELECT SEP_ID,PL_ID,POINT_ID,aggs_type_id\r\n  from GEN_IDs\r\n WHERE ml_id=:2\r\n   AND bga_id=:0 --6/ and point_id=:6\r\n;', 'SELECT NVL((SELECT TO_NUMBER(NVL(spty_value,spty_default))\r\nFROM spty\r\nWHERE spty.spty_code = \'GENERATION_FETCH\'), 100)\r\nINTO pGF\r\nFROM dual;\r\nOPEN c_ROWS;\r\nLOOP\r\nFETCH c_ROWS\r\nBULK COLLECT INTO sSEP_ID,sPL_ID,sPOINT_ID,sAGGS_TYPE_ID\r\nLIMIT pGF;\r\nEXIT WHEN sPL_ID.Count=0;\r\nmerge_genp(1,sPL_ID,sSEP_ID,sPOINT_ID,sAGGS_TYPE_ID,Nvl(:4,SYSDATE-:3),Nvl(:5+1,SYSDATE),1);\r\nFOR d IN (SELECT DISTINCT Trunc(s1,\'MI\') s1 FROM gen$p) loop\r\nSELECT\r\n\'\',\'\',c1,c2,t,\'\',v, Nvl(:7,0),\r\ns,SYSDATE,\'\'\r\nBULK COLLECT INTO\r\npPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST\r\nFROM\r\n(SELECT c1,c2,c3,ib t\r\n,round(Sum(q*l)*12,6) v,Decode(Max(k),0,\'1\',\'14\') s\r\nFROM\r\n(SELECT f.*\r\n,Trunc(bt)+Trunc(Round((bt-Trunc(bt))*288,6))/288+(d.column_value-1)/288 ib\r\n,g/(et-bt)/288 q\r\n,(Least(et,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*288,6))/288+(d.column_value)/288)-Greatest(bt,Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*288,6))/288+(d.column_value-1)/288))*288 l\r\n,CASE WHEN et-bt>=20/1440 and not g=0 THEN 1 ELSE 0 END k\r\nFROM (SELECT da,bt, c1,c2,c3,point_id,\r\nLead(bt) over (PARTITION BY point_id,ml_id ORDER BY da,bt) et\r\n,Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-\r\nCASE WHEN Lead(val) over (PARTITION BY point_id,ml_id ORDER BY da,bt)-val<-1000\r\n THEN 0 ELSE val end g\r\nFROM\r\ntable(p_ar.p2(cursor(select\r\npoint_id,:1,pl_id,sep_id,aggs_type_id,\'\',\'\',\'\',\'\',\'\',\'\',\'\'\r\nFROM\r\ngen$p\r\nWHERE Trunc(s1,\'MI\')=d.s1),trunc(d.s1),Nvl(:5+1,SYSDATE)))\r\nWHERE NOT val IS NULL) f,mou u, TABLE(SELECT CAST(COLLECT(level) AS sql_objects) FROM dual CONNECT BY Trunc(f.bt)+Trunc(Round((f.bt-Trunc(f.bt))*288,6))/288+(LEVEL-1)/288<f.et) d\r\nwhere f.POINT_ID=u.point_id (+) AND f.bt<u.mou_bt (+) AND f.et>=u.mou_bt (+) AND u.mou_id IS null\r\n) h\r\nGROUP BY c1,c2,c3,ib HAVING Round(Sum(l),6)=1 )r\r\n--/7 where not exists (SELECT 0 FROM pl_data_valid WHERE pl_id=r.c1 AND pl_t=r.t and aggs_type_id=r.c3 AND storable=1 AND improvable=0)\r\n;\r\nstore_pl(pPCK_T,pPCK_N,pPL_ID,pSEP_ID,pT,pDST,pV,pFORCED,pS,pRT,pRDST,ans);\r\nEND LOOP;\r\nEND LOOP;\r\nCLOSE c_ROWS;', NULL, NULL, NULL, 26),
	(384, 'REPLICATE_POINT_CONFIGURATION', 'Pakeisti kitų taškų konfigūracinių parametrų reikšmes pagal pavyzdinį tašką', 'Pakeisti kitų taškų konfigūracinių parametrų reikšmes pagal pavyzdinį tašką', 'ep NUMBER(10);\r\norn NUMBER(10);\r\npDB_TIME DATE;', 'SELECT point_id INTO ep FROM point WHERE point_code=:1;\r\nDELETE gttt;\r\nINSERT INTO gttt (id1,id2,id3,id4,cbig,id5,id6)\r\nWITH d AS\r\n(SELECT point_id,di_id,src_id,src_type_id,src_type_mod_nr,withe_id,pw_v,sep_id\r\nFROM\r\npw_setting\r\njoin sep USING (sep_id)\r\njoin se USING (se_id)\r\njoin (SELECT src_id,src_type_id,src_et FROM src) USING (src_id)\r\njoin src_mod USING (src_id)\r\n--2/join (select withe_id from witheset join witheset_data using (witheset_id) where witheset_code=:2) using (withe_id)\r\nWHERE src_et IS null)\r\n,e as\r\n(SELECT src_type_id,src_type_mod_nr,withe_id,pw_v FROM d\r\nWHERE point_id=ep\r\n)\r\n--4/select * from (\r\nSELECT\r\nd.point_id,\r\nd.di_id,\r\nd.src_id,\r\nd.sep_id,\r\nrawtochar(e.pw_v),\r\nd.withe_id\r\n--4/,max(Decode(e.pw_v,d.pw_v,0,1)) over (partition by d.point_id) m\r\n FROM\r\nd\r\njoin e ON (d.src_type_id=e.src_type_id AND d.src_type_mod_nr=e.src_type_mod_nr AND d.withe_id=e.withe_id)\r\n--3/join (select point_id from grpj join gr using (gr_id) where gr_code=:3 and grp_et is null) c on (d.point_id=c.point_id)\r\n--/4WHERE Decode(e.pw_v,d.pw_v,0,1)=1\r\n--4/) where m=1\r\n;\r\nINSERT INTO gttt (\r\nid1,id2,id3,id4,cbig,id5,id6,id7,id8,id9\r\n)\r\nWITH d AS\r\n(\r\nSELECT point_id,di_id,src_id,src_type_id,src_type_mod_nr,withe_id,ind1,ind2,ind3,enr,pw_v,sep_id\r\nFROM\r\npw_msetting\r\njoin sep USING (sep_id)\r\njoin se USING (se_id)\r\njoin (SELECT src_id,src_type_id,src_et FROM src) USING (src_id)\r\njoin src_mod USING (src_id)\r\n--2/ join (select withe_id from witheset join witheset_data using (witheset_id) where witheset_code=:2) using (withe_id)\r\nWHERE src_et IS null\r\n)\r\n,e as\r\n(SELECT src_type_id,src_type_mod_nr,withe_id,ind1,ind2,ind3,enr,pw_v\r\n,Count(*) over (PARTITION BY point_id,withe_id,ind1,ind2,ind3) Enr_cnt FROM d\r\nWHERE point_id=ep\r\n)\r\nSELECT\r\npoint_id,\r\ndi_id,\r\nsrc_id,\r\nsep_id,\r\nrawtochar(e_pw_v),\r\nwithe_id,\r\nind1,\r\nind2,\r\nind3,\r\ne_enr\r\nFROM (\r\nSELECT f.*\r\n,Max(CASE WHEN e_enr_cnt!=enr_cnt THEN 1 ELSE Decode(pw_v,e_pw_v,0,1) end) over\r\n(PARTITION BY point_id\r\n--/4,withe_id,ind1,ind2,ind3\r\n) m\r\nFROM (\r\nSELECT d.*,e.enr_cnt e_enr_cnt,e.enr e_enr,e.pw_v e_pw_v\r\n,Count(DISTINCT d.enr) over (PARTITION BY d.point_id,d.withe_id,d.ind1,d.ind2,d.ind3) enr_cnt\r\n,Rank() over (PARTITION BY d.point_id,d.withe_id,d.ind1,d.ind2,d.ind3,e.enr ORDER BY e.enr-d.enr,d.enr) rnk\r\nFROM\r\nd\r\njoin e ON (d.src_type_id=e.src_type_id AND d.src_type_mod_nr=e.src_type_mod_nr\r\nAND d.withe_id=e.withe_id AND d.ind1=e.ind1 AND d.ind2=e.ind2 AND d.ind3=e.ind3)\r\n--3/join (select point_id from grpj join gr using (gr_id) where gr_code=:3 and grp_et is null) c on (d.point_id=c.point_id)\r\n) f\r\nWHERE rnk=1) WHERE m=1;', 'SELECT id1 FROM gttt GROUP BY id1', 'pDB_TIME:=SYSDATE;\r\nSELECT rodo_seq.NEXTVAL INTO orn FROM dual;\r\nINSERT INTO rodo0\r\n(rodo_id,rodo_nr,db_time,user_id,rc_id,\r\ndi_id,src_id,sep_id,write2device,\r\nwithe_id,ind1,ind2,ind3,enr)\r\nSELECT\r\norn,ROWNUM,pDB_TIME,0,7,\r\nid2,id3,id4,cbig,\r\nid5,id6,id7,id8,id9\r\nFROM gttt WHERE id1=c.id1 AND ROWNUM<100000;\r\nINSERT INTO ltl (req_type_code, rodo_id)\r\nSELECT req_type_code,orn FROM rc WHERE rc_id=7;', NULL, 87),
	(385, 'AUTO_DELETE_AE_COL_DATA', 'Automatinis pasenusių audito duomenų įrašų trynimas', 'Automatinis pasenusių audito duomenų įrašų trynimas', NULL, 'execute immediate \'ALTER TABLE COLD_DATA DISABLE CONSTRAINT COLD_DATA_DESC_AE_FK\';\r\nexecute immediate \'ALTER TABLE AU_CDATA DISABLE CONSTRAINT AU_CDATA_NEW_AE_FK\';\r\nexecute immediate \'ALTER TABLE AU_CDATA DISABLE CONSTRAINT AU_CDATA_OLD_AE_FK\';\r\ninsert into gttt(id0,id1,c0)\r\nSELECT /*+ parallel(au_idata) full(au_idata)*/col_id,Decode(ts_id,0,old_val,new_val) col_val,\'Collect_pairs_4_stay\'\r\nFROM au join au_idata USING(db_time,au_nr)\r\njoin tab_col USING(tab_id,col_id)\r\njoin tab using(tab_id)\r\ncross join ts\r\nWHERE col_bp=1 AND NOT Decode(ts_id,0,old_val,new_val) IS NULL\r\nGROUP BY col_id, Decode(ts_id,0,old_val,new_val);\r\ndelete from cold_data where (col_id, col_val) in\r\n(select col_id,col_val from cold_data a\r\n  where not exists(select 0 from tab_col join tab USING(tab_id) WHERE col_bp=1 AND tab_type_id=0\r\n  and a.col_id=col_id)\r\n  minus\r\n  select id0, id1 from gttt where c0=\'Collect_pairs_4_stay\');\r\ninsert into gttt (id0,id1,c0)(select col_id, col_val, \'COLC_DATA_delete_rows\' from colc_data a\r\n  minus select id0, id1, \'COLC_DATA_delete_rows\' from gttt where c0=\'Collect_pairs_4_stay\');\r\ndelete from gttt where c0=\'Collect_pairs_4_stay\';\r\ndelete from colc_data where (col_id, col_val) in (\r\nselect id0, id1 from gttt where c0=\'COLC_DATA_delete_rows\');\r\ninsert into gttt (id0,c0)\r\nselect ae_id,\'AE_delete_rows\' from ae\r\nminus\r\nSELECT /*+parallel(au_cdata) full(au_cdata)*/Decode(ts_id,0,old_ae_id,new_ae_id) ae_id,\'AE_delete_rows\'\r\nFROM au_cdata,ts\r\nWHERE NOT Decode(ts_id,0,old_ae_id,new_ae_id) IS NULL\r\nGROUP BY Decode(ts_id,0,old_ae_id,new_ae_id)\r\nminus\r\nselect desc_ae_id,\'AE_delete_rows\' from cold_data;\r\ndelete from ae where ae_id in (\r\nselect id0 from gttt where c0=\'AE_delete_rows\');\r\nexecute immediate \'ALTER TABLE COLD_DATA ENABLE NOVALIDATE CONSTRAINT COLD_DATA_DESC_AE_FK\';\r\nexecute immediate \'ALTER TABLE AU_CDATA ENABLE NOVALIDATE CONSTRAINT AU_CDATA_NEW_AE_FK\';\r\nexecute immediate \'ALTER TABLE AU_CDATA ENABLE NOVALIDATE CONSTRAINT AU_CDATA_OLD_AE_FK\';', NULL, NULL, NULL, 56);
/*!40000 ALTER TABLE `bga_type` ENABLE KEYS */;

-- Dumping structure for table emcor.bga_type_param
CREATE TABLE IF NOT EXISTS `bga_type_param` (
  `bga_type_id` mediumint(8) unsigned NOT NULL COMMENT 'DB aplikacijos foninių užduočių tipo ID',
  `bga_type_param_nr` smallint(5) unsigned NOT NULL COMMENT 'DB aplikacijos foninių užduočių tipo parametro numeris',
  `bga_type_param_desc` varchar(1024) COLLATE utf8_bin DEFAULT NULL COMMENT 'DB aplikacijos foninių užduočių tipo parametro aprašymas',
  `bga_type_param_regular` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'DB aplikacijos foninių užduočių tipo įprastinio parametro požymis',
  `bga_type_param_key` varchar(40) COLLATE utf8_bin DEFAULT NULL COMMENT 'DB aplikacijos foninių užduočių tipo parametro kodinis pavadinimas',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  `bga_param_default_value` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'DB aplikacijos foninių užduočių tipo galimo parametro reikšme pagal nutylėjimą',
  PRIMARY KEY (`bga_type_param_nr`,`bga_type_id`),
  KEY `bga_type_param_bga_type_i` (`bga_type_id`),
  CONSTRAINT `bga_type_param_bga_type_fk` FOREIGN KEY (`bga_type_id`) REFERENCES `bga_type` (`bga_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='DB aplikacijos foninių užduočių tipo parametrai';

-- Dumping data for table emcor.bga_type_param: ~967 rows (approximately)
/*!40000 ALTER TABLE `bga_type_param` DISABLE KEYS */;
INSERT INTO `bga_type_param` (`bga_type_id`, `bga_type_param_nr`, `bga_type_param_desc`, `bga_type_param_regular`, `bga_type_param_key`, `enum_id`, `bga_param_default_value`) VALUES
	(21, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(22, 1, 'Lauko temperatūros taško taško kodas', 1, NULL, NULL, NULL),
	(23, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(25, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(26, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(28, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(29, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(30, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(31, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(62, 1, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(81, 1, 'Matavimo linijos identifikatorius', 1, 'N:=:ML_ID', NULL, NULL),
	(86, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(96, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(101, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(106, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(111, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, '1440'),
	(112, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(113, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(114, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(115, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(117, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(118, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(119, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(120, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(121, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(126, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, '1440'),
	(127, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, '1440'),
	(131, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(132, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(136, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(137, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(151, 1, 'Poslinkis dienomis (trinami įrašai, senesni už nurodytą dienų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(156, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(161, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(166, 1, 'Rezervuotas', 0, 'N:=:ML_ID1', NULL, NULL),
	(171, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(172, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(173, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(181, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(182, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(183, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(184, 1, 'Rezervuota', 0, NULL, NULL, NULL),
	(185, 1, 'Rezervuota', 0, NULL, NULL, NULL),
	(186, 1, 'Rezervuota', 0, NULL, NULL, NULL),
	(187, 1, 'Rezervuota', 0, NULL, NULL, NULL),
	(188, 1, 'Rezervuota', 0, NULL, NULL, NULL),
	(189, 1, 'Rezervuota', 0, NULL, NULL, NULL),
	(190, 1, 'Rezervuota', 0, NULL, NULL, NULL),
	(191, 1, 'Rezervuota', 0, NULL, NULL, NULL),
	(194, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(199, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(210, 1, 'Šaltinių tipo kodas', 1, NULL, NULL, NULL),
	(214, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(215, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, '1440'),
	(216, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, '1440'),
	(217, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, '1440'),
	(218, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, '1440'),
	(219, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, '1440'),
	(220, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, '1440'),
	(221, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, '1440'),
	(222, 1, 'Matavimo linijos identifikatorius', 1, 'N:=:ML_ID', NULL, NULL),
	(223, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(224, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(225, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(226, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(227, 1, 'Poslinkis valandomis', 1, 'N:=:HOUR_COUNT', NULL, NULL),
	(228, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(229, 1, 'Rezervuota', 0, NULL, NULL, NULL),
	(230, 1, 'Rezervuota', 0, NULL, NULL, NULL),
	(231, 1, 'Matavimų rinkinio kodas', 1, 'C:=:MLSET', NULL, NULL),
	(232, 1, 'Matavimų rinkinio kodas', 1, 'C:=:MLSET', NULL, NULL),
	(234, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(239, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(244, 1, 'Naikinančios grupės kodas', 1, '?:=:GR_CODE', NULL, NULL),
	(249, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(250, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(251, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(252, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(253, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(254, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(255, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(257, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(261, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(262, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(263, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(264, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(265, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(266, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(267, 1, 'Analizės gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(268, 1, 'Dinamiškai pildomo lauko numeris', 1, 'N:=:FF_ID', NULL, NULL),
	(269, 1, 'Dinamiškai pildomo lauko numeris', 1, 'N:=:FF_ID', NULL, NULL),
	(270, 1, 'Dinamiškai pildomo lauko numeris', 1, 'N:=:FF_ID', NULL, NULL),
	(271, 1, 'Dinamiškai pildomo lauko numeris', 1, 'N:=:FF_ID', NULL, NULL),
	(276, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(277, 1, 'Maksimalus užduoties veikimo laikas sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(278, 1, 'Maksimalus užduoties veikimo laikas sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(281, 1, 'Poslinkis sekundėmis', 1, 'N:=:SECONDS_COUNT', NULL, NULL),
	(282, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(283, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(286, 1, 'Poslinkis dienomis (trinami įrašai, senesni už nurodytą dienų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(288, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(289, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(290, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(291, 1, 'Duomenų šaltinio identifikatorius', 0, NULL, NULL, NULL),
	(297, 1, 'Šaltinio identifikatorius', 1, NULL, NULL, NULL),
	(298, 1, 'Šaltinio identifikatorius', 1, NULL, NULL, NULL),
	(299, 1, 'Taško indentifikatorius', 1, NULL, NULL, NULL),
	(301, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(302, 1, 'Gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(303, 1, 'Gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(304, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(305, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(306, 1, 'Poslinkis dienomis (TestMode išjungimas, seniau už nurodytą dienų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(307, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(308, 1, 'Gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(309, 1, 'Ribinis leistinas skirtumas sekundėmis', 1, 'N:=:THRESHOLD', NULL, NULL),
	(310, 1, 'Šaltinių šablono kodas', 1, NULL, NULL, NULL),
	(312, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(313, 1, 'Kontrolės gylis minutėmis', 1, 'N:=:DEPTH', NULL, NULL),
	(314, 1, 'Kontrolės gylis minutėmis', 1, 'N:=:DEPTH', NULL, NULL),
	(315, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(316, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(317, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(321, 1, 'Poslinkis valandomis', 1, 'N:=:STEP', NULL, NULL),
	(322, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(324, 1, 'Kontrolinio periodo trukmė minutėmis', 1, 'N:=:DEPTH', NULL, NULL),
	(325, 1, 'Kontrolinio periodo trukmė minutėmis', 1, 'N:=:DEPTH', NULL, NULL),
	(327, 1, 'Analizės gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(328, 1, 'Analizės gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(329, 1, 'Ryšio modulių savybės naudojimo požymis', 1, 'N:=:SRC_LPTY_USAGE', NULL, NULL),
	(330, 1, 'Šaltinių tipo pavadinimas', 1, 'C:=:SRC_TYPE_NAME', NULL, NULL),
	(336, 1, 'Ķąčģåķīāąķč˙ ņčļą ńšåäńņā čēģåšåķč˙', 1, 'C:=:METER_TYPE', NULL, NULL),
	(341, 1, 'Kontrolės gylis minutėmis', 1, 'N:=:DEPTH', NULL, NULL),
	(344, 1, 'Duomenų šaltinio identifikatorius', 1, 'N:=:SRC_ID', NULL, NULL),
	(345, 1, 'Matavimo taško identifikatorius', 1, 'N:=:POINT_ID', NULL, NULL),
	(346, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(347, 1, 'Eksporto operacijos identifikatorius', 1, 'N:=:XO_ID', NULL, NULL),
	(348, 1, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(351, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, '5'),
	(352, 1, 'Analizės gylis paromis', 1, 'N:=:DEPTH', NULL, '4'),
	(356, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(357, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(358, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(360, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(361, 1, 'Matavimo taško tipo kodas', 1, NULL, NULL, NULL),
	(363, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(365, 1, 'Aanalyzės gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(366, 1, 'Analizės gylis mėnesiais', 1, 'N:=:DEPTH', NULL, '2'),
	(368, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(369, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(370, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(371, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(372, 1, 'Diskretinio signalo tipo kodas, neprivalomas', 0, 'C:=:DS_TYPE_CODE', NULL, NULL),
	(377, 1, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, '10'),
	(378, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, NULL),
	(382, 1, 'Žingsnis minutėmis', 1, 'N:=:STEP', NULL, '1440'),
	(383, 1, 'Išeities matavimo linijos ID', 1, 'N:=:ML_ID1', NULL, NULL),
	(384, 1, 'Pavyzdinio taško kodas', 1, 'C:=:POINT_CODE', NULL, NULL),
	(21, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(22, 2, 'Šilumnešio temperatūrų grafiko taško kodas', 1, NULL, NULL, NULL),
	(23, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(25, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(26, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(28, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(29, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(30, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(31, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(62, 2, 'Paskirties matavimo linijos ID', 0, 'N:=:ML_ID2', NULL, NULL),
	(81, 2, 'Gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(86, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(96, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(101, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(106, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(111, 2, 'Poslinkis mėnesiais (trinami įrašai, senesni už nurodytą mėnesių kiekį)', 1, 'N:=:MONTH_COUNT', NULL, NULL),
	(112, 2, 'Poslinkis mėnesiais (trinami įrašai, senesni už nurodytą mėnesių kiekį)', 1, 'N:=:MONTH_COUNT', NULL, NULL),
	(113, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(114, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(115, 2, 'Poslinkis mėnesiais (trinami įrašai, senesni už nurodytą mėnesių kiekį)', 1, 'N:=:MONTH_COUNT', NULL, NULL),
	(116, 2, 'Poslinkis dienomis (trinami įrašai, senesni už nurodytą dienų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(117, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(118, 2, 'Poslinkis mėnesiais (trinami įrašai, senesni už nurodytą mėnesių kiekį)', 1, 'N:=:MONTH_COUNT', NULL, NULL),
	(119, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(120, 2, 'Poslinkis mėnesiais (trinami įrašai, senesni už nurodytą mėnesių kiekį)', 1, 'N:=:MONTH_COUNT', NULL, NULL),
	(121, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(126, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(127, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(131, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(132, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(136, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(137, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(151, 2, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(156, 2, 'Poslinkis dienomis (trinami įrašai, senesni už nurodytą dienų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(161, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(166, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(171, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(172, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(173, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(181, 2, 'Poslinkis dienomis (trinami įrašai, senesni už nurodytą dienų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(182, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(183, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(184, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(185, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(186, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(187, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(188, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(189, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(190, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(191, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(194, 2, 'Poslinkis dienomis (trinami įrašai, senesni už nurodytą dienų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(199, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(204, 2, 'Poslinkis dienomis (trinami įrašai, senesni už nurodytą dienų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(209, 2, 'Poslinkis dienomis (trinami įrašai, senesni už nurodytą dienų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(214, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(215, 2, 'Poslinkis mėnesiais (trinami įrašai, senesni už nurodytą mėnesių kiekį)', 1, 'N:=:MONTH_COUNT', NULL, NULL),
	(216, 2, 'Poslinkis mėnesiais (trinami įrašai, senesni už nurodytą mėnesių kiekį)', 1, 'N:=:MONTH_COUNT', NULL, NULL),
	(217, 2, 'Poslinkis mėnesiais (trinami įrašai, senesni už nurodytą mėnesių kiekį)', 1, 'N:=:MONTH_COUNT', NULL, NULL),
	(218, 2, 'Poslinkis mėnesiais (trinami įrašai, senesni už nurodytą mėnesių kiekį)', 1, 'N:=:MONTH_COUNT', NULL, NULL),
	(219, 2, 'Poslinkis mėnesiais (trinami įrašai, senesni už nurodytą mėnesių kiekį)', 1, 'N:=:MONTH_COUNT', NULL, NULL),
	(220, 2, 'Poslinkis mėnesiais (trinami įrašai, senesni už nurodytą mėnesių kiekį)', 1, 'N:=:MONTH_COUNT', NULL, NULL),
	(221, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(222, 2, 'Gylis minutėmis', 1, 'N:=:DEPTH', NULL, NULL),
	(223, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(224, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(225, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(226, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(228, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(229, 2, 'Rezervuota', 0, NULL, NULL, NULL),
	(230, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(231, 2, 'Gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(232, 2, 'Gylis minutėmis', 1, 'N:=:DEPTH', NULL, NULL),
	(234, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(239, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(244, 2, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(249, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(250, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(251, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(252, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(253, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(254, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(255, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(257, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(261, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(262, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(263, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(264, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(265, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(266, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(268, 2, 'Šakninės grupės kodas', 1, 'C:=:GR_CODE', NULL, NULL),
	(269, 2, 'Šakninės grupės kodas', 1, 'C:=:GR_CODE', NULL, NULL),
	(270, 2, 'Dinamiškai pildomo lauko reikšmė', 1, 'C:=:FF_VAL', NULL, NULL),
	(271, 2, 'Dinamiškai pildomo lauko reikšmė', 1, 'C:=:FF_VAL', NULL, NULL),
	(276, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(277, 2, 'Monitoringo šablono kodas', 1, 'C:=:TMPL_CODE', NULL, NULL),
	(278, 2, 'Monitoringo šablono kodas', 1, 'C:=:TMPL_CODE', NULL, NULL),
	(282, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(283, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(286, 2, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(288, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(289, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(290, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(297, 2, 'Taško identifikatorius', 1, NULL, NULL, NULL),
	(298, 2, 'Taško identifikatorius', 1, NULL, NULL, NULL),
	(299, 2, 'Nuskaitymo kanalo identifikatorius', 1, NULL, NULL, NULL),
	(301, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(304, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(305, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(307, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(308, 2, 'Apatinė procentinė riba', 1, 'N:=:LOLIMIT', NULL, NULL),
	(309, 2, 'Taškų kiekio grupėje riba', 1, 'N:=:POINT_COUNT', NULL, NULL),
	(312, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(315, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(316, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(317, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(322, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą gylį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(330, 2, 'Įrašyti skaitmeninę dalį', 1, 'N:=:JUST_NUMERIC_PART', NULL, NULL),
	(345, 2, 'Skubaus vykdymo požymis', 1, 'N:=:URGENT', NULL, NULL),
	(346, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(351, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, '120'),
	(352, 2, 'Kiekio riba', 1, 'N:=:LIMIT', NULL, '500'),
	(356, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(357, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(358, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(360, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(363, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(366, 2, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(368, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(369, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(370, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(371, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(372, 2, 'Šablono kodas, neprivalomas', 0, 'C:=:SAM_CODE', NULL, NULL),
	(378, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(382, 2, 'Poslinkis paromis (trinami įrašai, senesni už nurodytą parų kiekį)', 1, 'N:=:DAY_COUNT', NULL, NULL),
	(383, 2, 'Paskirties matavimo linijos ID', 1, 'N:=:ML_ID2', NULL, NULL),
	(384, 2, 'Konfigūracinių parametrų rinkinio kodas', 1, 'C:=:WITHESET_CODE', NULL, NULL),
	(21, 3, 'Generavimo gylis mėnesiais', 1, 'N:=:DEPTH', NULL, NULL),
	(22, 3, 'Generavimo gylis paromis', 1, NULL, NULL, NULL),
	(23, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(25, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(26, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(28, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(29, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(30, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(31, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(81, 3, 'Grupės identifikatorius', 0, 'N:=:GR_ID', NULL, NULL),
	(86, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(96, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(101, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(106, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(111, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(112, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(113, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(114, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(115, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(117, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(118, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(119, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(120, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(121, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(126, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(127, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(131, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(132, 3, 'Generavimo gylis mėnesiais', 1, 'N:=:DEPTH', NULL, NULL),
	(136, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(137, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(156, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(161, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(166, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(171, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(172, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(173, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(181, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(182, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(183, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(184, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(185, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(186, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(187, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(188, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(189, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(190, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(191, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(194, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(199, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(214, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(215, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(216, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(217, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(218, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(219, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(220, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(221, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(222, 3, 'Grupės identifikatorius', 0, 'N:=:GR_ID', NULL, NULL),
	(223, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(224, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(225, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(226, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(228, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(229, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(230, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(231, 3, 'Grupių tipo kodas', 1, 'C:=:GR_TYPE', NULL, NULL),
	(232, 3, 'Grupių tipo kodas', 1, 'C:=:GR_TYPE', NULL, NULL),
	(234, 3, 'Generavimo gylis mėnesiais', 1, 'N:=:DEPTH', NULL, NULL),
	(239, 3, 'Generavimo gylis mėnesiais', 1, 'N:=:DEPTH', NULL, NULL),
	(244, 3, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, NULL),
	(249, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(250, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(251, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(252, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(253, 3, 'Generavimo gylis mėnesiais', 1, 'N:=:DEPTH', NULL, NULL),
	(254, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(255, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(257, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(261, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(262, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(263, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(264, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(265, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(266, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(276, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(282, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(283, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(286, 3, 'Maksimalus trinamų įrašų kiekis per iteraciją', 1, 'N:=:REC_COUNT', NULL, NULL),
	(288, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(289, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(290, 3, 'Generavimo gylis mėnesiais', 1, 'N:=:DEPTH', NULL, NULL),
	(299, 3, 'Įvykio pranešimas', 1, NULL, NULL, NULL),
	(301, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(304, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(305, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(307, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(312, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(315, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(316, 3, 'Generavimo gylis mėnesiais', 1, 'N:=:DEPTH', NULL, NULL),
	(317, 3, 'Generavimo gylis mėnesiais', 1, 'N:=:DEPTH', NULL, NULL),
	(322, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(346, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(351, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, '45'),
	(356, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(357, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(358, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(360, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(363, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(366, 3, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(368, 3, 'Generavimo gylis mėnesiais', 1, 'N:=:DEPTH', NULL, NULL),
	(369, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(370, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(371, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(372, 3, 'Parų kiekis į ateitį, nusakantis periodo pradžią', 1, 'N:=:DEPTH', NULL, NULL),
	(378, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(382, 3, 'Maksimalus vieno trynimo veikimo laikas, sekundėmis', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(383, 3, 'Generavimo gylis paromis', 1, 'N:=:DEPTH', NULL, NULL),
	(384, 3, 'Grupės kodas', 1, 'C:=:GR_CODE', NULL, NULL),
	(21, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(22, 4, 'Tiekiamo term. vandens temperatūra prie 10 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(23, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(25, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(26, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(28, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(29, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(30, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(31, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(62, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(81, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(86, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(96, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(101, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(106, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(111, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, '1000000'),
	(112, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, NULL),
	(113, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, NULL),
	(114, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, NULL),
	(115, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, NULL),
	(117, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, NULL),
	(118, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, NULL),
	(119, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, NULL),
	(120, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, NULL),
	(121, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, NULL),
	(126, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, '1000000'),
	(127, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, '1000000'),
	(131, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(132, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(136, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(137, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(156, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, NULL),
	(161, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(166, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(171, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(172, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(173, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(181, 4, 'Maksimalus trinamų įrašų kiekis per iteraciją', 1, 'N:=:REC_COUNT', NULL, NULL),
	(182, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(183, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(184, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(185, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(186, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(187, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(188, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(189, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(190, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(191, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(194, 4, 'Maksimalus trinamų įrašų kiekis per iteraciją', 1, 'N:=:REC_COUNT', NULL, NULL),
	(199, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(214, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(215, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, '1000000'),
	(216, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, '1000000'),
	(217, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, '1000000'),
	(218, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, '1000000'),
	(219, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, '1000000'),
	(220, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, '1000000'),
	(221, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, '1000000'),
	(222, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(223, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, NULL),
	(224, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, NULL),
	(225, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, NULL),
	(226, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, NULL),
	(228, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(229, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(230, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(231, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(232, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(234, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(239, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(244, 4, 'Matavimo rinkinio kodas', 1, 'C:=:MLSET_CODE', NULL, NULL),
	(249, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(250, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(251, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(252, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(253, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(254, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(255, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(257, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(261, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(262, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(263, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(264, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(265, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(266, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(276, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(282, 4, 'Maksimalus trinamų įrašų kiekis per iteraciją', 1, 'N:=:REC_COUNT', NULL, NULL),
	(283, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(288, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(289, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(290, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(301, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(304, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(305, 4, 'Maksimalus trinamų įrašų kiekis per iteraciją', 1, 'N:=:REC_COUNT', NULL, NULL),
	(307, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(312, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(315, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(316, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(317, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(322, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, NULL),
	(346, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(351, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, '10000'),
	(356, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(357, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(358, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(360, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(363, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(366, 4, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(368, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(369, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(370, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(371, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(372, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(378, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, NULL),
	(382, 4, 'Maksimalus trinamų įrašų kiekis', 1, 'N:=:REC_COUNT', NULL, '1000000'),
	(383, 4, 'Periodo pradžia', 0, 'D:>=:DA', NULL, NULL),
	(384, 4, 'Rašyti visą parametrų rinkinį', 1, 'N:=:FORCE_FULL_SET_WRITE', NULL, NULL),
	(21, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(22, 5, 'Grįžtamo term. vandens temperatūra prie 10 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(23, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(25, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(26, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(28, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(29, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(30, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(31, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(62, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(81, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(86, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(96, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(101, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(106, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(111, 5, 'Trynimą vykdyti tik žingsnio apimtyje', 1, 'N:=:LOWER_LIMIT', NULL, '1'),
	(126, 5, 'Trynimą vykdyti tik žingsnio apimtyje', 1, 'N:=:LOWER_LIMIT', NULL, '1'),
	(127, 5, 'Trynimą vykdyti tik žingsnio apimtyje', 1, 'N:=:LOWER_LIMIT', NULL, '1'),
	(131, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(132, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(136, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(137, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(161, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(166, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(171, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(172, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(173, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(182, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(183, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(184, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(185, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(186, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(187, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(188, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(189, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(190, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(191, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(199, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(214, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(215, 5, 'Trynimą vykdyti tik žingsnio apimtyje', 1, 'N:=:LOWER_LIMIT', NULL, '1'),
	(216, 5, 'Trynimą vykdyti tik žingsnio apimtyje', 1, 'N:=:LOWER_LIMIT', NULL, '1'),
	(217, 5, 'Trynimą vykdyti tik žingsnio apimtyje', 1, 'N:=:LOWER_LIMIT', NULL, '1'),
	(218, 5, 'Trynimą vykdyti tik žingsnio apimtyje', 1, 'N:=:LOWER_LIMIT', NULL, '1'),
	(219, 5, 'Trynimą vykdyti tik žingsnio apimtyje', 1, 'N:=:LOWER_LIMIT', NULL, '1'),
	(220, 5, 'Trynimą vykdyti tik žingsnio apimtyje', 1, 'N:=:LOWER_LIMIT', NULL, '1'),
	(221, 5, 'Trynimą vykdyti tik žingsnio apimtyje', 1, 'N:=:LOWER_LIMIT', NULL, '1'),
	(222, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(228, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(229, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(230, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(231, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(232, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(234, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(239, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(244, 5, 'Periodo pradžia', 1, 'D:>=:DA', NULL, NULL),
	(249, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(250, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(251, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(252, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(253, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(254, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(255, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(257, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(261, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(262, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(263, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(264, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(265, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(266, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(276, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(283, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(288, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(289, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(290, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(301, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(304, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(307, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(312, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(315, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(316, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(317, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(346, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(356, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(357, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(358, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(360, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(363, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(368, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(369, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(370, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(371, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(372, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(382, 5, 'Trinimą vykdyti tik žingsnio apimtyje', 1, 'N:=:LOWER_LIMIT', NULL, NULL),
	(383, 5, 'Periodo pabaiga', 0, 'D:<=:DA', NULL, NULL),
	(21, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(22, 6, 'Tiekiamo term. vandens temperatūra prie 9 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(23, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(25, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(26, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(28, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(29, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(30, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(31, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(62, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(81, 6, 'Poslinkis paromis', 1, 'N:=:LAG', NULL, NULL),
	(86, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(96, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(101, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(106, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(131, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(132, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(136, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(137, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(161, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(166, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(171, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(172, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(173, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(182, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(183, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(184, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(185, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(186, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(187, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(188, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(189, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(190, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(191, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(199, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(214, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(222, 6, 'Poslinkis minutėmis', 1, 'N:=:LAG', NULL, NULL),
	(228, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(229, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(230, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(231, 6, 'Poslinkis paromis', 1, 'N:=:LAG', NULL, NULL),
	(232, 6, 'Poslinkis minutėmis', 1, 'N:=:LAG', NULL, NULL),
	(234, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(239, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(244, 6, 'Periodo pabaiga', 1, 'D:<=:DA', NULL, NULL),
	(249, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(250, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(251, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(252, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(253, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(254, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(255, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(257, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(261, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(262, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(263, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(264, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(265, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(266, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(276, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(283, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(288, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(289, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(290, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(301, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(304, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(307, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(312, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(315, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(316, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(317, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(346, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(356, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(357, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(358, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(360, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(363, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(368, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(369, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(370, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(371, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(372, 6, 'Grupės kodas, neprivalomas', 0, 'C:=:GR_CODE', NULL, NULL),
	(383, 6, 'Matavimo taško identifikatorius', 0, 'N:=:POINT_ID', NULL, NULL),
	(21, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(22, 7, 'Grįžtamo term. vandens temperatūra prie 9 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(23, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(25, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(26, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(28, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(29, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(30, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(31, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(62, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(81, 7, 'Grupių tipo kodas', 1, 'C:=:GR_TYPE', NULL, NULL),
	(86, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(96, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(101, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(106, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(131, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(132, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(136, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(137, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(161, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(166, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(171, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(172, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(173, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(182, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(183, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(184, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(185, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(186, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(187, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(188, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(189, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(190, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(191, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(199, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(214, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(222, 7, 'Grupių tipo kodas', 1, 'C:=:GR_TYPE', NULL, NULL),
	(228, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(229, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(230, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(234, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(239, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(249, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(250, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(251, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(252, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(253, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(254, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(255, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(257, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(261, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(262, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(263, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(264, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(265, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(266, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(276, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(283, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(288, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(289, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(290, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(301, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(304, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(307, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(312, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(315, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(316, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(317, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(346, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(356, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(357, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(358, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(360, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(363, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(368, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(369, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(370, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(371, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(372, 7, 'Parų kiekis į ateitį, nusakantis periodo pabaigą', 1, 'N:=:DEPTH2', NULL, NULL),
	(383, 7, 'Priverstinio pergeneravimo požymis', 0, 'N:=:FORCED', NULL, NULL),
	(22, 8, 'Tiekiamo term. vandens temperatūra prie 8 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(166, 8, 'Rezervuotas', 0, NULL, NULL, NULL),
	(173, 8, 'Rezervuota', 0, 'N:=:DCOUNT', NULL, NULL),
	(184, 8, 'Rezervuota', 0, NULL, NULL, NULL),
	(185, 8, 'Rezervuota', 0, NULL, NULL, NULL),
	(186, 8, 'Rezervuota', 0, NULL, NULL, NULL),
	(187, 8, 'Rezervuota', 0, NULL, NULL, NULL),
	(188, 8, 'Rezervuota', 0, NULL, NULL, NULL),
	(189, 8, 'Rezervuota', 0, NULL, NULL, NULL),
	(190, 8, 'Rezervuota', 0, NULL, NULL, NULL),
	(191, 8, 'Rezervuota', 0, NULL, NULL, NULL),
	(230, 8, 'Taško savybės kodas, kurioje nurodytas atitinkamo šablono kodas', 1, 'N:=:PPTY', NULL, NULL),
	(234, 8, 'Laiko poslinkis (mėnesiais) sugeneruotiems duomenims', 1, 'N:=:SHIFT', NULL, NULL),
	(239, 8, 'Poslinkis paromis, leistinas be kokybės praradimo', 1, 'N:=:DCOUNT', NULL, NULL),
	(251, 8, 'Poslinkis minutėmis nustatyti generuojamų matavimų periodą', 1, 'N:=:SHIFT', NULL, NULL),
	(276, 8, 'Apskaitos būsenų signalo kodas', 1, 'C:=:DS_CODE', NULL, NULL),
	(312, 8, 'Didžiausias leistinas laiko skirtumas tarp suminių ir einamųjų parų duomenų nuskaitymų, sek', 0, 'N:=:SEC_COUNT', NULL, NULL),
	(317, 8, 'Didžiausias leistinas laiko skirtumas tarp suminių ir einamųjų mėnesio duomenų nuskaitymų, sek', 1, 'N:=:SEC_COUNT', NULL, NULL),
	(346, 8, 'Aktualių eksporto formų tipų identifikatorių sąrašas', 1, 'C:=:XF_TYPE_LIST', NULL, NULL),
	(347, 8, 'Aktualių eksporto formų tipų identifikatorių sąrašas', 1, 'C:=:XF_TYPE_LIST', NULL, NULL),
	(22, 9, 'Grįžtamo term. vandens temperatūra prie 8 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(166, 9, 'Rezervuotas', 0, NULL, NULL, NULL),
	(173, 9, 'Skaičiuoja laužtinę tarp nuskaitymų, atrenka kur ji kerta parų ribas(0)/Skaičiuoja skirtumą tarp pirmų nuskaitymų parose (1)/Skaičiuoja skirtumą tarp paskutinių nuskaitymų parose (2)', 1, 'N:=:SIGN', NULL, NULL),
	(184, 9, 'Rezervuota', 0, NULL, NULL, NULL),
	(185, 9, 'Rezervuota', 0, NULL, NULL, NULL),
	(186, 9, 'Rezervuota', 0, NULL, NULL, NULL),
	(187, 9, 'Rezervuota', 0, NULL, NULL, NULL),
	(188, 9, 'Rezervuota', 0, NULL, NULL, NULL),
	(189, 9, 'Rezervuota', 0, NULL, NULL, NULL),
	(190, 9, 'Rezervuota', 0, NULL, NULL, NULL),
	(191, 9, 'Rezervuota', 0, NULL, NULL, NULL),
	(239, 9, 'Skaičiuojamas skirtumas tarp pirmo šio mėnesio ir pirmo sekančio mėnesio suminio rodmens', 1, 'N:=:SIGN', NULL, NULL),
	(312, 9, 'Mažiausias privalomas laiko skirtumas tarp paros pradžios ir einamųjų duomenų už parą nuskaitymų, min', 0, 'N:=:MIN_COUNT', NULL, NULL),
	(317, 9, 'Mažiausias privalomas laiko skirtumas tarp mėnesio pradžios ir einamųjų duomenų už mėnesį nuskaitymų, min', 1, 'N:=:MIN_COUNT', NULL, NULL),
	(22, 10, 'Tiekiamo term. vandens temperatūra prie 7 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(166, 10, 'Rezervuotas', 0, NULL, NULL, NULL),
	(184, 10, 'Sąryšių tipo kodas', 1, NULL, NULL, NULL),
	(185, 10, 'Sąryšių tipo kodas', 1, NULL, NULL, NULL),
	(186, 10, 'Sąryšių tipo kodas', 1, NULL, NULL, NULL),
	(187, 10, 'Sąryšių tipo kodas', 1, NULL, NULL, NULL),
	(188, 10, 'Sąryšių tipo kodas', 1, NULL, NULL, NULL),
	(189, 10, 'Sąryšių tipo kodas', 1, NULL, NULL, NULL),
	(190, 10, 'Sąryšių tipo kodas', 1, NULL, NULL, NULL),
	(191, 10, 'Sąryšių tipo kodas', 1, NULL, NULL, NULL),
	(22, 11, 'Grįžtamo term. vandens temperatūra prie 7 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(166, 11, 'P+ galios matavimas', 1, NULL, NULL, NULL),
	(184, 11, '1 įvado akt. galios matavimas', 1, NULL, NULL, NULL),
	(185, 11, 'Matavimo taško akt. galia', 1, NULL, NULL, NULL),
	(186, 11, '1 įvado akt. galios matavimas', 1, NULL, NULL, NULL),
	(187, 11, 'Matavimo taško akt. galia', 1, NULL, NULL, NULL),
	(188, 11, 'Tuščiosios veikos nuostoliai', 1, NULL, NULL, NULL),
	(189, 11, 'Matavimo taško akt. galia', 1, NULL, NULL, NULL),
	(190, 11, '1 įvado akt. galios matavimas', 1, NULL, NULL, NULL),
	(191, 11, 'Matavimo taško akt. galia', 1, NULL, NULL, NULL),
	(22, 12, 'Tiekiamo term. vandens temperatūra prie 6 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(166, 12, 'Q+ galios matavimas', 1, NULL, NULL, NULL),
	(184, 12, '2 įvado akt. galios matavimas', 1, NULL, NULL, NULL),
	(185, 12, 'Vardinė įtampa', 1, NULL, NULL, NULL),
	(186, 12, '2 įvado akt. galios matavimas', 1, NULL, NULL, NULL),
	(187, 12, 'Matavimo taško reakt. galia', 1, NULL, NULL, NULL),
	(188, 12, 'Trumpojo jungimo nuostoliai', 1, NULL, NULL, NULL),
	(189, 12, 'Matavimo taško reakt. galia', 1, NULL, NULL, NULL),
	(190, 12, '2 įvado akt. galios matavimas', 1, NULL, NULL, NULL),
	(191, 12, 'Matavimo taško reakt. galia', 1, NULL, NULL, NULL),
	(22, 13, 'Grįžtamo term. vandens temperatūra prie 6 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(184, 13, '1 įvado transformatoriaus tuščiosios veikos nuostoliai', 1, NULL, NULL, NULL),
	(185, 13, 'cos(f)', 1, NULL, NULL, NULL),
	(186, 13, '1 įvado transformatoriaus tuščiosios veikos nuostoliai', 1, NULL, NULL, NULL),
	(187, 13, 'Vardinė įtampa', 1, NULL, NULL, NULL),
	(188, 13, 'Vardinė galia', 1, NULL, NULL, NULL),
	(189, 13, 'Tuščiosios veikos nuostoliai', 1, NULL, NULL, NULL),
	(190, 13, '1 įvado reakt. galios matavimas', 1, NULL, NULL, NULL),
	(191, 13, 'Tuščiosios veikos nuostoliai', 1, NULL, NULL, NULL),
	(22, 14, 'Tiekiamo term. vandens temperatūra prie 5 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(184, 14, '1 įvado transformatoriaus trumpojo jungimo nuostoliai', 1, NULL, NULL, NULL),
	(185, 14, 'Linijos varža', 1, NULL, NULL, NULL),
	(186, 14, '1 įvado transformatoriaus trumpojo jungimo nuostoliai', 1, NULL, NULL, NULL),
	(187, 14, 'Linijos varža', 1, NULL, NULL, NULL),
	(188, 14, '1 įvado akt. galios matavimas', 1, NULL, NULL, NULL),
	(189, 14, 'Trumpojo jungimo nuostoliai', 1, NULL, NULL, NULL),
	(190, 14, '2 įvado reakt. galios matavimas', 1, NULL, NULL, NULL),
	(191, 14, 'Trumpojo jungimo nuostoliai', 1, NULL, NULL, NULL),
	(22, 15, 'Grįžtamo term. vandens temperatūra prie 5 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(184, 15, '1 įvado transformatoriaus vardinė galia', 1, NULL, NULL, NULL),
	(185, 15, 'Linijos ilgis', 1, NULL, NULL, NULL),
	(186, 15, '1 įvado transformatoriaus vardinė galia', 1, NULL, NULL, NULL),
	(187, 15, 'Linijos ilgis', 1, NULL, NULL, NULL),
	(188, 15, '2 įvado akt. galios matavimas', 1, NULL, NULL, NULL),
	(189, 15, 'Vardinė galia', 1, NULL, NULL, NULL),
	(190, 15, '1 įvado transformatoriaus tuščiosios veikos nuostoliai', 1, NULL, NULL, NULL),
	(191, 15, 'Vardinė galia', 1, NULL, NULL, NULL),
	(22, 16, 'Tiekiamo term. vandens temperatūra prie 4 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(184, 16, 'cos(f)', 1, NULL, NULL, NULL),
	(186, 16, 'cos(f)', 1, NULL, NULL, NULL),
	(188, 16, '1 įvado reakt. galios matavimas', 1, NULL, NULL, NULL),
	(190, 16, '1 įvado transformatoriaus trumpojo jungimo nuostoliai', 1, NULL, NULL, NULL),
	(191, 16, 'Tuščiosios veikos reagento nuostoliai', 1, NULL, NULL, NULL),
	(22, 17, 'Grįžtamo term. vandens temperatūra prie 4 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(184, 17, '2 įvado transformatoriaus tuščiosios veikos nuostoliai', 1, NULL, NULL, NULL),
	(186, 17, '2 įvado transformatoriaus tuščiosios veikos nuostoliai', 1, NULL, NULL, NULL),
	(188, 17, '2 įvado reakt. galios matavimas', 1, NULL, NULL, NULL),
	(190, 17, '1 įvado transformatoriaus vardinė galia', 1, NULL, NULL, NULL),
	(191, 17, 'Trumpojo jungimo reagento nuostoliai', 1, NULL, NULL, NULL),
	(22, 18, 'Tiekiamo term. vandens temperatūra prie 3 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(184, 18, '2 įvado transformatoriaus trumpojo jungimo nuostoliai', 1, NULL, NULL, NULL),
	(186, 18, '2 įvado transformatoriaus trumpojo jungimo nuostoliai', 1, NULL, NULL, NULL),
	(190, 18, '1 įvado transformatoriaus tuščiosios veikos reagento nuostoliai', 1, NULL, NULL, NULL),
	(191, 18, 'Vardinė įtampa', 1, NULL, NULL, NULL),
	(22, 19, 'Grįžtamo term. vandens temperatūra prie 3 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(184, 19, '2 įvado transformatoriaus vardinė galia', 1, NULL, NULL, NULL),
	(186, 19, '2 įvado transformatoriaus vardinė galia', 1, NULL, NULL, NULL),
	(190, 19, '1 įvado transformatoriaus trumpojo jungimo reagento nuostoliai', 1, NULL, NULL, NULL),
	(191, 19, 'Linijos varža', 1, NULL, NULL, NULL),
	(22, 20, 'Tiekiamo term. vandens temperatūra prie 2 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(184, 20, '2 įvado transformatoriaus tuščiosios veikos reagento nuostoliai', 1, NULL, NULL, NULL),
	(190, 20, '2 įvado transformatoriaus tuščiosios veikos nuostoliai', 1, NULL, NULL, NULL),
	(191, 20, 'Linijos ilgis', 1, NULL, NULL, NULL),
	(22, 21, 'Grįžtamo term. vandens temperatūra prie 2 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(184, 21, '2 įvado transformatoriaus trumpojo jungimo reagento nuostoliai', 1, NULL, NULL, NULL),
	(190, 21, '2 įvado transformatoriaus trumpojo jungimo nuostoliai', 1, NULL, NULL, NULL),
	(22, 22, 'Tiekiamo term. vandens temperatūra prie 1 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(184, 22, 'Vardinė įtampa', 1, NULL, NULL, NULL),
	(190, 22, '2 įvado transformatoriaus vardinė galia', 1, NULL, NULL, NULL),
	(22, 23, 'Grįžtamo term. vandens temperatūra prie 1 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(184, 23, 'Linijos varža iki 2 įvado', 1, NULL, NULL, NULL),
	(190, 23, '2 įvado transformatoriaus tuščiosios veikos reagento nuostoliai', 1, NULL, NULL, NULL),
	(22, 24, 'Tiekiamo term. vandens temperatūra prie 0 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(184, 24, 'Linijos ilgis iki 2 įvado', 1, NULL, NULL, NULL),
	(190, 24, '2 įvado transformatoriaus trumpojo jungimo reagento nuostoliai', 1, NULL, NULL, NULL),
	(22, 25, 'Grįžtamo term. vandens temperatūra prie 0 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(190, 25, 'Vardinė įtampa', 1, NULL, NULL, NULL),
	(22, 26, 'Tiekiamo term. vandens temperatūra prie -1 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(190, 26, 'Linijos varža', 1, NULL, NULL, NULL),
	(22, 27, 'Grįžtamo term. vandens temperatūra prie -1 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(190, 27, 'Linijos ilgis', 1, NULL, NULL, NULL),
	(22, 28, 'Tiekiamo term. vandens temperatūra prie -2 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 29, 'Grįžtamo term. vandens temperatūra prie -2 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 30, 'Tiekiamo term. vandens temperatūra prie -3 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 31, 'Grįžtamo term. vandens temperatūra prie -3 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 32, 'Tiekiamo term. vandens temperatūra prie -4 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 33, 'Grįžtamo term. vandens temperatūra prie -4 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 34, 'Tiekiamo term. vandens temperatūra prie -5 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 35, 'Grįžtamo term. vandens temperatūra prie -5 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 36, 'Tiekiamo term. vandens temperatūra prie -6 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 37, 'Grįžtamo term. vandens temperatūra prie -6 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 38, 'Tiekiamo term. vandens temperatūra prie -7 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 39, 'Grįžtamo term. vandens temperatūra prie -7 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 40, 'Tiekiamo term. vandens temperatūra prie -8 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 41, 'Grįžtamo term. vandens temperatūra prie -8 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 42, 'Tiekiamo term. vandens temperatūra prie -9 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 43, 'Grįžtamo term. vandens temperatūra prie -9 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 44, 'Tiekiamo term. vandens temperatūra prie -10 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 45, 'Grįžtamo term. vandens temperatūra prie -10 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 46, 'Tiekiamo term. vandens temperatūra prie -11 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 47, 'Grįžtamo term. vandens temperatūra prie -11 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 48, 'Tiekiamo term. vandens temperatūra prie -12 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 49, 'Grįžtamo term. vandens temperatūra prie -12 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 50, 'Tiekiamo term. vandens temperatūra prie -13 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 51, 'Grįžtamo term. vandens temperatūra prie -13 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 52, 'Tiekiamo term. vandens temperatūra prie -14 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 53, 'Grįžtamo term. vandens temperatūra prie -14 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 54, 'Tiekiamo term. vandens temperatūra prie -15 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 55, 'Grįžtamo term. vandens temperatūra prie -15 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 56, 'Tiekiamo term. vandens temperatūra prie -16 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 57, 'Grįžtamo term. vandens temperatūra prie -16 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 58, 'Tiekiamo term. vandens temperatūra prie -17 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 59, 'Grįžtamo term. vandens temperatūra prie -17 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 60, 'Tiekiamo term. vandens temperatūra prie -18 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 61, 'Grįžtamo term. vandens temperatūra prie -18 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 62, 'Tiekiamo term. vandens temperatūra prie -19 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 63, 'Grįžtamo term. vandens temperatūra prie -19 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 64, 'Tiekiamo term. vandens temperatūra prie -20 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 65, 'Grįžtamo term. vandens temperatūra prie -20 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 66, 'Tiekiamo term. vandens temperatūra prie -21 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 67, 'Grįžtamo term. vandens temperatūra prie -21 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 68, 'Tiekiamo term. vandens temperatūra prie -22 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 69, 'Grįžtamo term. vandens temperatūra prie -22 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 70, 'Tiekiamo term. vandens temperatūra prie -23 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 71, 'Grįžtamo term. vandens temperatūra prie -23 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 72, 'Tiekiamo term. vandens temperatūra prie -24 °C lauko temperatūros', 1, NULL, NULL, NULL),
	(22, 73, 'Grįžtamo term. vandens temperatūra prie -24 °C lauko temperatūros', 1, NULL, NULL, NULL);
/*!40000 ALTER TABLE `bga_type_param` ENABLE KEYS */;

-- Dumping structure for table emcor.bga_type_ug
CREATE TABLE IF NOT EXISTS `bga_type_ug` (
  `bga_type_id` mediumint(8) unsigned NOT NULL COMMENT 'DB aplikacijos foninių užduočių tipo ID',
  `ug_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojų grupės identifikatorius',
  PRIMARY KEY (`bga_type_id`,`ug_id`),
  KEY `bga_type_ug_i` (`ug_id`),
  CONSTRAINT `bga_type_ug_bga_type_fk` FOREIGN KEY (`bga_type_id`) REFERENCES `bga_type` (`bga_type_id`) ON DELETE CASCADE,
  CONSTRAINT `bga_type_ug_fk` FOREIGN KEY (`ug_id`) REFERENCES `ug` (`ug_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Vartotojų grupėms suteikiamos teisės vykdyti atitinkamų tipų fonines užduotis';

-- Dumping data for table emcor.bga_type_ug: ~0 rows (approximately)
/*!40000 ALTER TABLE `bga_type_ug` DISABLE KEYS */;
/*!40000 ALTER TABLE `bga_type_ug` ENABLE KEYS */;

-- Dumping structure for table emcor.byp
CREATE TABLE IF NOT EXISTS `byp` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `byp_point_id` int(10) unsigned NOT NULL COMMENT 'Apėjimui naudojamo matavimo taško identifikatorius',
  `ds_id` int(10) unsigned NOT NULL COMMENT 'Apskaitos būsenos signalo identifikatorius',
  `byp_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Apėjimo naudojimo požymis',
  `byp_inv` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Požymis, ar naudojama invertuota signalo reikšmė apėjimo būsenai nustatyti',
  `byp_dir_inv` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Priešingos krypties matavimų naudojimo apeinamajame taške požymis',
  `byp_mode` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Pagrindinio taško duomenų naudojimo ir apeinamojo taško naudojimo periodo dengiamuose intervaluose požymis',
  PRIMARY KEY (`point_id`,`byp_point_id`),
  KEY `byp_byp_point_i` (`byp_point_id`),
  KEY `byp_ds_i` (`ds_id`),
  CONSTRAINT `byp_byp_point_fk` FOREIGN KEY (`byp_point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `byp_ds_fk` FOREIGN KEY (`ds_id`) REFERENCES `ds` (`ds_id`),
  CONSTRAINT `byp_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `BYP_POINT_ITSELF_CHK` CHECK (`byp_point_id` <> `point_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apeinamieji taškai';

-- Dumping data for table emcor.byp: ~0 rows (approximately)
/*!40000 ALTER TABLE `byp` DISABLE KEYS */;
/*!40000 ALTER TABLE `byp` ENABLE KEYS */;

-- Dumping structure for table emcor.caption
CREATE TABLE IF NOT EXISTS `caption` (
  `cap_id` mediumint(8) NOT NULL COMMENT 'Pranešimo identifikatorius',
  `cap_text` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Pranešimo tekstas',
  `cap_code` varchar(70) COLLATE utf8_bin NOT NULL COMMENT 'Pranešimo kodas',
  `cap_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Pranešimo pavadinimas',
  `cap_text_default` varchar(250) COLLATE utf8_bin NOT NULL COMMENT 'Pranešimo tekstas pagal nutylėjimą',
  PRIMARY KEY (`cap_id`),
  UNIQUE KEY `cap_code_u` (`cap_code`),
  UNIQUE KEY `cap_name_u` (`cap_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Programinių pranešimų sąrašas';

-- Dumping data for table emcor.caption: ~998 rows (approximately)
/*!40000 ALTER TABLE `caption` DISABLE KEYS */;
INSERT INTO `caption` (`cap_id`, `cap_text`, `cap_code`, `cap_name`, `cap_text_default`) VALUES
	(-1, '%1 %2 %3 %4 %5 %6 %7 %8 %9', 'AUD_DATA_DEFAULT_CAPTION', 'Cap name', 'CAP_TEXT'),
	(1, 'Neteisingai nurodytas laukas', 'WRONG_COLUMN', 'Neteisingai nurodytas laukas', 'Neteisingai nurodytas laukas'),
	(2, 'Teisės neaktyviems vartotojams nenustatomos', 'NO_GRANTS_FOR_INACTIVE_USER', 'Teisės neaktyviems vartotojams nenustatomos', 'Teisės neaktyviems vartotojams nenustatomos'),
	(3, 'Skaitiklio identifikatorius yra neleistinas', 'WRONG_METER_ID', 'Skaitiklio identifikatorius yra neleistinas', 'Skaitiklio identifikatorius yra neleistinas'),
	(4, 'Apskaitos taškas nėra savas', 'EXTERNAL_POINT', 'Apskaitos taškas nėra savas', 'Apskaitos taškas nėra savas'),
	(5, 'Apskaitos taško nuskaitymas yra neleistinas', 'DISABLED_POINT', 'Apskaitos taško nuskaitymas yra neleistinas', 'Apskaitos taško nuskaitymas yra neleistinas'),
	(6, 'Apskaitos taškui nenustatytas automatinis nuskaitymas', 'POINT_AUTO_READ_DISABLED', 'Apskaitos taškui nenustatytas automatinis nuskaitymas', 'Apskaitos taškui nenustatytas automatinis nuskaitymas'),
	(7, 'Nėra nuskaityti skaitiklio parametravimo duomenys', 'MISSING_METER_PARAMETRATION_DATA', 'Nėra nuskaityti skaitiklio parametravimo duomenys', 'Nėra nuskaityti skaitiklio parametravimo duomenys'),
	(8, 'Įrašas nerastas', 'RECORD_NOT_FOUNT', 'Įrašas nerastas', 'Įrašas nerastas'),
	(9, 'Įrašas neištrintas', 'RECORD_NOT_DELETED', 'Įrašas neištrintas', 'Įrašas neištrintas'),
	(10, 'Įrašas nepakeistas', 'RECORD_NOT_UPDATED', 'Įrašas nepakeistas', 'Įrašas nepakeistas'),
	(11, 'Grupė nerasta', 'GROUP_NOT_FOUND', 'Grupė nerasta', 'Grupė nerasta'),
	(12, 'Šis taškas jau įtrauktas į grupę', 'GROUP_HAS_POINT', 'Šis taškas jau įtrauktas į grupę', 'Šis taškas jau įtrauktas į grupę'),
	(13, 'Parametro %1 reikšmė %2%3%4', 'PARAMETER_VALUE', 'Parametro reikšmė', 'Parametro %1 reikšmė %2%3%4'),
	(14, 'Aptikta, kad pakeistas prietaiso parametras "%1"', 'DEVICE_PARAMETER_CHANGE', 'Pakeistas prietaiso parametras', 'Aptikta, kad pakeistas prietaiso parametras "%1"'),
	(15, 'tuščią', 'EMPTY', 'tuščią', 'tuščią'),
	(16, 'Pasikeitus skaitiklio paskutinio parametravimo per optiką data: iš %1 į %2.', 'OPTIC_PARAMETRATION_DATE_UPDATED', 'Pasikeitus skaitiklio paskutinio parametravimo per optiką data', 'Pasikeitus skaitiklio paskutinio parametravimo per optiką data: iš %1 į %2.'),
	(17, 'Pasikeitus skaitiklio paskutinio parametravimo per kilpą data: iš %1 į %2.', 'LOOP_PARAMETRATION_DATE_UPDATED', 'Pasikeitus skaitiklio paskutinio parametravimo per kilpą data', 'Pasikeitus skaitiklio paskutinio parametravimo per kilpą data: iš %1 į %2.'),
	(18, 'Netinkamo tipo skaitiklis: %1', 'WRONG_METER_TYPE', 'Netinkamo tipo skaitiklis', 'Netinkamo tipo skaitiklis: %1'),
	(19, 'Netinkamas apdorojimui skaitiklio laikas: %1', 'WRONG_METER_TIME', 'Netinkamas apdorojimui skaitiklio laikas', 'Netinkamas apdorojimui skaitiklio laikas: %1'),
	(20, 'd', 'DAY', 'd', 'd'),
	(21, 'val', 'HOUR', 'val', 'val'),
	(22, 'min', 'MIN', 'min', 'min'),
	(23, 's', 'SECOND', 's', 's'),
	(24, 'Neleistinas masyvo ilgis: %1', 'WRONG_ARRAY_LENGTH', 'Neleistinas masyvo ilgis', 'Neleistinas masyvo ilgis: %1'),
	(25, 'Neteisingai nurodytas laukas', 'COLUMN_WRONG', 'Nurodytas laukas neteisingas', 'Neteisingai nurodytas laukas'),
	(26, 'Nepavyko ištrinti įrašo: %1', 'COULD_NOT_DELETE_RECORD', 'Nepavyko ištrinti įrašo', 'Nepavyko ištrinti įrašo: %1'),
	(27, 'Nežinomas skaitiklio integravimo laikas', 'UNKNOWN_METER_INTEGRATION_PERIOD', 'Nežinomas skaitiklio integravimo laikas', 'Nežinomas skaitiklio integravimo laikas'),
	(28, 'Įrašų neištrinta', 'RECORDS_NOT_DELETED', 'Įrašų neištrinta', 'Įrašų neištrinta'),
	(29, 'Nerasta krovimui tinkamų duomenų', 'RECORDS_NOT_FOUND', 'Nerasta krovimui tinkamų duomenų', 'Nerasta krovimui tinkamų duomenų'),
	(30, 'Nekorektiškas reikšmių skaičius', 'WRONG_VALUES_COUNT', 'Nekorektiškas reikšmių skaičius', 'Nekorektiškas reikšmių skaičius'),
	(31, 'Priskiriamas laiko intervalas per platus', 'PERIOD_TOO_LONG', 'Priskiriamas laiko intervalas per platus', 'Priskiriamas laiko intervalas per platus'),
	(32, 'Šiai grupei už %1 jau priskirtas šablonas %2', 'GROUP_HAS_TEMPLATE', 'Šiai grupei jau priskirtas šablonas', 'Šiai grupei už %1 jau priskirtas šablonas %2'),
	(33, 'Šiam šablonui nerastas valandinis grafikas', 'TEMPLATE_HOUR_SHEDULE_NOT_FOUND', 'Šiam šablonui nerastas valandinis grafikas', 'Šiam šablonui nerastas valandinis grafikas'),
	(34, 'Intervalas %1 - %2 yra ankstesnis už perparametravimą: %3', 'PERIOD_BEFORE_PARAMETRATION', 'Intervalas yra ankstesnis už perparametravimą', 'Intervalas %1 - %2 yra ankstesnis už perparametravimą: %3'),
	(35, 'Intervalas %1 - %2 yra ankstesnis už montavimo datą: %3', 'PERIOD_BEFORE_INSTALLATION', 'Intervalas yra ankstesnis už montavimo datą', 'Intervalas %1 - %2 yra ankstesnis už montavimo datą: %3'),
	(36, 'Panaikintas reikalavimas archyvuoti šią informaciją', 'REQUIREMENT_TO_ARCHIVE_DELETED', 'Panaikintas reikalavimas archyvuoti šią informaciją', 'Panaikintas reikalavimas archyvuoti šią informaciją'),
	(37, 'Intervalo ilgis nesutampa su apibrėžtu šiam skaitikliui integravimo periodu', 'WRONG_METER_PERIOD', 'Intervalo ilgis nesutampa su integravimo periodu', 'Intervalo ilgis nesutampa su apibrėžtu šiam skaitikliui integravimo periodu'),
	(38, 'Intervalo %1 - %2 duomenys paimti iš skaitiklio netinkamu laiku: %3', 'WRONG_TIME_FOR_METER_DATA', 'Intervalo duomenys paimti iš skaitiklio netinkamu laiku', 'Intervalo %1 - %2 duomenys paimti iš skaitiklio netinkamu laiku: %3'),
	(39, 'Neapibrežta energijos rūšis: %1', 'WRONG_TYPE_OF_ENERGY', 'Neapibrežta energijos rūšis', 'Neapibrežta energijos rūšis: %1'),
	(40, '%1 atsirado %2', 'APPEARED', 'atsirado', '%1 atsirado %2'),
	(41, '%1 dingo %2', 'DISAPPEARED', 'dingo', '%1 dingo %2'),
	(42, 'Aptikta, kad pakeista kontrolerio kilpų konfigūracija', 'CONTROLLER_LOOP_CONFIGURATION_CHANGED', 'Aptikta, kad pakeista kontrolerio kilpų konfigūracija', 'Aptikta, kad pakeista kontrolerio kilpų konfigūracija'),
	(43, 'Aptikta, kad pakeista kontrolerio konfigūracija', 'CONTROLLER_CONFIGURATION_CHANGED', 'Aptikta, kad pakeista kontrolerio konfigūracija', 'Aptikta, kad pakeista kontrolerio konfigūracija'),
	(44, 'Nerastas užsakymas skaitiklio laiko keitimui', 'TIME_UPDATING_REQUEST_NOT_FOUND', 'Nerastas užsakymas skaitiklio laiko keitimui', 'Nerastas užsakymas skaitiklio laiko keitimui'),
	(45, 'Maitinimas nuo %1 dingęs', 'POWER_LOST', 'Maitinimas dingęs', 'Maitinimas nuo %1 dingęs'),
	(46, 'Maitinimas nuo %1 iki %2 buvo dingęs', 'POWER_LOST_PERIOD', 'Maitinimas buvo dingęs', 'Maitinimas nuo %1 iki %2 buvo dingęs'),
	(47, 'Netinkami parametrai krovimui: SKNR=%1, DATA=%2, RSK=%3, masyvo ilgis=%4', 'WRONG_PARAMETERS_FOR_INSERT', 'Netinkami parametrai krovimui', 'Netinkami parametrai krovimui: SKNR=%1, DATA=%2, RSK=%3, masyvo ilgis=%4'),
	(48, 'Netinkami parametrai krovimui: SKNR=%1, DATA=%2, masyvo ilgis=%3', 'WRONG_PARAMETERS_FOR_INSERTS', 'Netinkami parametrai krovimams', 'Netinkami parametrai krovimui: SKNR=%1, DATA=%2, masyvo ilgis=%3'),
	(49, 'Pasikeitusi parametro "%1" reikšmė negali būti išsaugota su %2 laiku', 'WRONG_PARAMETER_VALUE_FOR_THIS_TIME', 'Pasikeitusi parametro reikšmė negali būti išsaugota su šituo laiku', 'Pasikeitusi parametro "%1" reikšmė negali būti išsaugota su %2 laiku'),
	(50, 'Aptikta, kad pakeistas skaitiklio parametras %1', 'METER_PARAMETER_CHANGED', 'Aptikta, kad pakeistas skaitiklio parametras', 'Aptikta, kad pakeistas skaitiklio parametras %1'),
	(51, 'Skaitiklio įvykių ir būsenų informacija nuo %1 iki %2 galimai prarasta', 'METER_EVENTS_AND_STATUSES_POSSIBLE_LOST', 'Skaitiklio įvykių ir būsenų informacija galimai prarasta', 'Skaitiklio įvykių ir būsenų informacija nuo %1 iki %2 galimai prarasta'),
	(52, 'Skaitiklyje nustatytas sistemos nepalaikomas energijos tarifų skaičius (%1)', 'WRONG_ENERGY_TARIFFS_COUNT', 'Skaitiklyje nustatytas sistemos nepalaikomas energijos tarifų skaičius', 'Skaitiklyje nustatytas sistemos nepalaikomas energijos tarifų skaičius (%1)'),
	(53, 'Pasikeitė poveikių magnetiniu lauku skaičius', 'MAGENTIC_FIELD_COUNT', 'Pasikeitė poveikių magnetiniu lauku skaičius', 'Pasikeitė poveikių magnetiniu lauku skaičius'),
	(54, 'Skaitiklyje %1 užfiksuota klaida FATAL', 'FATAL_ERROR', 'Skaitiklyje užfiksuota fatalinė klaida', 'Skaitiklyje %1 užfiksuota klaida FATAL'),
	(55, 'Duomenų bazėje nerasti ankstesnės skaitiklio konfigūracijos duomenys', 'EARLER_METER_CONFIGURATION_NOT_FOUND', 'Duomenų bazėje nerasti ankstesnės skaitiklio konfigūracijos duomenys', 'Duomenų bazėje nerasti ankstesnės skaitiklio konfigūracijos duomenys'),
	(56, 'Laikas %1 parametrui "%2" vėlesnis už dabartinį', 'PARAMETER_TIME_LATER_THAN_CURRENT', 'Laikas parametrui vėlesnis už dabartinį', 'Laikas %1 parametrui "%2" vėlesnis už dabartinį'),
	(57, 'Laikas %1 parametrui "%2" ankstenis už turimą (%3)', 'PARAMETER_TIME_EARLER_THAN_ASSIGNED', 'Laikas parametrui ankstenis už turimą', 'Laikas %1 parametrui "%2" ankstenis už turimą (%3)'),
	(58, 'Laikas %1 vėlesnis už dabartinį', 'TIME_LATER_THAN_CURRENT', 'Laikas vėlesnis už dabartinį', 'Laikas %1 vėlesnis už dabartinį'),
	(59, 'Nežinomas parametras: %1', 'UNKNOWN_PARAMETER', 'Nežinomas parametras', 'Nežinomas parametras: %1'),
	(60, 'Paros %1 %2 duomenys (%3) nesutampa su detaliais (%4)', 'DAY_DATA_MISMATCH_DETAILED_DATA', 'Paros duomenys nesutampa su detaliais', 'Paros %1 %2 duomenys (%3) nesutampa su detaliais (%4)'),
	(61, 'Paros %1 %2 duomenys (%3) pakartotinai nesutampa su detaliais (%4)', 'DAY_DATA_AGAIN_MISMATCH_DETAILED_DATA', 'Paros duomenys pakartotinai nesutampa su detaliais', 'Paros %1 %2 duomenys (%3) pakartotinai nesutampa su detaliais (%4)'),
	(62, '%1 %2 iniciavo parametravimą, apie kurio baigtį nėra informacijos', 'PARAMETRATION_FINISH_INFORMATION_NOT_FOUND', 'Parametravimas, apie kurio baigtį nėra informacijos', '%1 %2 iniciavo parametravimą, apie kurio baigtį nėra informacijos'),
	(63, '%1 %2 iniciavo laiko nustatymą, apie kurio baigtį nėra informacijos', 'TIME_CHANGE_FINISH_INFORMATION_NOT_FOUND', 'Laiko nustatymas, apie kurio baigtį nėra informacijos', '%1 %2 iniciavo laiko nustatymą, apie kurio baigtį nėra informacijos'),
	(64, '%1 %2 pasiuntė komandą, apie kurios baigtį nėra informacijos', 'COMMAND_FINISH_INFORMATION_NOT_FOUND', 'Komanda, apie kurios baigtį nėra informacijos', '%1 %2 pasiuntė komandą, apie kurios baigtį nėra informacijos'),
	(65, '%1 %2 iniciavo kilpų parametravimą, apie kurio baigtį nėra informacijos', 'LOOP_PARAMETRATION_FINISH_INFORMATION_NOT_FOUND', 'Kilpų parametravimas, apie kurio baigtį nėra informacijos', '%1 %2 iniciavo kilpų parametravimą, apie kurio baigtį nėra informacijos'),
	(66, 'Started broken Oracle job %1', 'STARTED_BROKEN_JOB', 'Started broken Oracle job', 'Started broken Oracle job %1'),
	(67, 'Nerasta parametro %1 reikšmė', 'PARAMETER_VALUE_NOT_FOUND', 'Nerasta parametro reikšmė', 'Nerasta parametro %1 reikšmė'),
	(68, 'Netinkamas skaitiklio numeris: %1', 'WRONG_METER_NUMBER', 'Netinkamas skaitiklio numeris', 'Netinkamas skaitiklio numeris: %1'),
	(69, 'Nebaigta ankstesnė laiko keitimo procedūra šiam skaitikliui', 'METER_TIME_UPDATING_PROCEDURE_NOT_FINISHED', 'Nebaigta ankstesnė laiko keitimo procedūra šiam skaitikliui', 'Nebaigta ankstesnė laiko keitimo procedūra šiam skaitikliui'),
	(70, 'Šių duomenų nuskaitymas yra neleistinas', 'DATA_READING_NOT_ALLOWED', 'Šių duomenų nuskaitymas yra neleistinas', 'Šių duomenų nuskaitymas yra neleistinas'),
	(71, 'Šių duomenų nuskaitymas yra neleistinas, kol nėra nuskaityti skaitiklio parametravimo duomenys', 'DATA_READING_NOT_ALLOWED_UNTILL_PARAMETRATION_READING_ENDS', 'Šių duomenų nuskaitymas yra neleistinas, kol nėra nuskaityti skaitiklio parametravimo duomenys', 'Šių duomenų nuskaitymas yra neleistinas, kol nėra nuskaityti skaitiklio parametravimo duomenys'),
	(72, 'Diena %1 yra ankstesnė už skaitiklio montavimo datą (%2)', 'METER_INSTALATION_DATE_LATER_THAN_DAY', 'Diena yra ankstesnė už skaitiklio montavimo datą', 'Diena %1 yra ankstesnė už skaitiklio montavimo datą (%2)'),
	(73, 'Diena %1 yra ankstesnė už skaitiklio perparametravimo datą (%2)', 'METER_PARAMETRATION_DATE_LATER_THAN_DAY', 'Diena yra ankstesnė už skaitiklio perparametravimo datą', 'Diena %1 yra ankstesnė už skaitiklio perparametravimo datą (%2)'),
	(74, 'Šių duomenų skaitiklyje nėra', 'MEASURING_DATA_NOT_FOUND', 'Šių duomenų skaitiklyje nėra', 'Šių duomenų skaitiklyje nėra'),
	(75, 'Diena %1 yra uždaryta šiam taškui', 'DAY_IS_CLOSED', 'Diena yra uždaryta šiam taškui', 'Diena %1 yra uždaryta šiam taškui'),
	(76, 'Mėnuo %1 yra ankstesnis už skaitiklio montavimo datą (%2)', 'METER_INSTALATION_DATE_LATER_THAN_MONTH', 'Mėnuo yra ankstesnis už skaitiklio montavimo datą', 'Mėnuo %1 yra ankstesnis už skaitiklio montavimo datą (%2)'),
	(77, 'Mėnuo %1 yra ankstesnis už skaitiklio perparametravimo datą (%2)', 'METER_PARAMETRATION_DATE_LATER_THAN_MONTH', 'Mėnuo yra ankstesnis už skaitiklio perparametravimo datą', 'Mėnuo %1 yra ankstesnis už skaitiklio perparametravimo datą (%2)'),
	(78, 'Mėnuo %1 yra uždarytas', 'MONTH_IS_CLOSED', 'Mėnuo yra uždarytas', 'Mėnuo %1 yra uždarytas'),
	(79, 'Duomenų bazėje nerasti esamos skaitiklio konfigūracijos duomenys', 'METER_CONFIGURATION_DATA_NOT_FOUND', 'Duomenų bazėje nerasti esamos skaitiklio konfigūracijos duomenys', 'Duomenų bazėje nerasti esamos skaitiklio konfigūracijos duomenys'),
	(80, 'Skaitiklis demontuotas', 'METER_DISMANTLED', 'Skaitiklis demontuotas', 'Skaitiklis demontuotas'),
	(81, 'Netinkami parametrai vykdymui', 'WRONG_PARAMETER_FOR_EXECUTION', 'Netinkami parametrai vykdymui', 'Netinkami parametrai vykdymui'),
	(82, '%1 dienos %2-os valandos %3reikšmė (%4) neatitinka nustatytai (%5) šablono "%6", priskirto grupei "%7", reikšmei', 'GROUP_TEMPLATE_VALUE_MISMATCH_DAY_HOUR_VALUE', 'Dienos valandos reikšmė neatitinka nustatytai šablono, priskirto grupei, reikšmei', '%1 dienos %2-os valandos %3reikšmė (%4) neatitinka nustatytai (%5) šablono "%6", priskirto grupei "%7", reikšmei'),
	(83, 'TESTINIS PRANEŠIMAS', 'TEST', 'TESTINIS PRANEŠIMAS', 'TESTINIS PRANEŠIMAS'),
	(84, 'Nerastas identifikatorius: %1', 'ID_NOT_FOUND', 'Nerastas identifikatorius', 'Nerastas identifikatorius: %1'),
	(85, 'Detalūs rodmenys', 'DETAILED_MEASURING_DATA', 'Detalūs rodmenys', 'Detalūs rodmenys'),
	(86, 'Paros rodmenys', 'DAY_MEASURING_DATA', 'Paros rodmenys', 'Paros rodmenys'),
	(87, 'Mėnesio rodmenys', 'MONTH_MEASURING_DATA', 'Mėnesio rodmenys', 'Mėnesio rodmenys'),
	(88, 'Suminiai rodmenys', 'SUM_MEASURING_DATA', 'Suminiai rodmenys', 'Suminiai rodmenys'),
	(89, '%1 vėluoja daugiau, nei %2', 'DELAYED', 'Vėluoja', '%1 vėluoja daugiau, nei %2'),
	(90, '%1 nebevėluoja', 'NOT_DELAYED', 'Nebevėluoja', '%1 nebevėluoja'),
	(91, 'Beapskaitinis laikotarpis', 'WRONG_ACCOUNTING_PERIOD', 'Beapskaitinis laikotarpis', 'Beapskaitinis laikotarpis'),
	(92, 'Sutampa', 'MATCHED', 'Sutampa', 'Sutampa'),
	(93, 'Nesutampa', 'MISMATCHED', 'Nesutampa', 'Nesutampa'),
	(94, 'Galima krauti', 'LOAD_PERMITTED', 'Galima krauti', 'Galima krauti'),
	(95, 'Para uždaryta', 'CLOSED_DAY', 'Para uždaryta', 'Para uždaryta'),
	(96, 'Rodmenys ankstesni už %1', 'MEASURING_DATA_EARLIER', 'Rodmenys ankstesni', 'Rodmenys ankstesni už %1'),
	(97, 'Rodmenys vėlesni už %1', 'MEASURING_DATA_LATER', 'Rodmenys vėlesni', 'Rodmenys vėlesni už %1'),
	(98, 'Reikšmė negalutinė', 'VALUE_NOT_FINAL', 'Reikšmė negalutinė', 'Reikšmė negalutinė'),
	(99, 'Mėnuo uždarytas', 'CLOSED_MONTH', 'Mėnuo uždarytas', 'Mėnuo uždarytas'),
	(100, 'Ne', 'NO', 'Ne', 'Ne'),
	(101, 'Taip', 'YES', 'Taip', 'Taip'),
	(102, 'Nepavyko atpažinti šaltinio tipo modifikacijos. %1', 'SRC_TYPE_MOD.UNKNOWN_MOD', 'Nepavyko atpažinti šaltinio tipo modifikacijos', 'Nepavyko atpažinti šaltinio tipo modifikacijos. %1'),
	(103, 'Pasikeitė prietaiso šaltinių tipų modifikacija. %1. Sukurkite naują duomenų šaltinį.', 'SRC_TYPE_MOD.OTHER_MOD', 'Pasikeitė prietaiso šaltinių tipų modifikacija', 'Pasikeitė prietaiso šaltinių tipų modifikacija. %1. Sukurkite naują duomenų šaltinį.'),
	(104, '%1 pakeitė prietaiso parametrą "%2"', 'AUTH_DEVICE_PARAMETER_CHANGE', 'Vartotojas pakeitė prietaiso parametrą', '%1 pakeitė prietaiso parametrą "%2"'),
	(105, '%1 pakeitė skaitiklio parametrą "%2"', 'AUTH_METER_PARAMETER_CHANGE', 'Vartotojas pakeitė skaitiklio parametrą', '%1 pakeitė skaitiklio parametrą "%2"'),
	(106, '%1 %2 bazėje nerastas', 'NOT_FOUND', 'Bazėje nerasta', '%1 %2 bazėje nerastas'),
	(107, 'Surastas susijęs įrašas lentelėje \'%1\'', 'RELATED_RECORD_FOUND', 'Surastas susijęs įrašas lentelėje', 'Surastas susijęs įrašas lentelėje \'%1\''),
	(108, 'Lauko \'%1\' reikšmė negali būti tuščia', 'EMPTY_VALUE', 'Lauko reikšmė negali būti tuščia', 'Lauko \'%1\' reikšmė negali būti tuščia'),
	(109, 'Lauko \'%1\' reikšmė turi būti unikali', 'DUBLICATE_VALUE', 'Lauko reikšmė turi būti unikali', 'Lauko \'%1\' reikšmė turi būti unikali'),
	(110, 'Įrašas su laiko žyme %1 jau egzistuoja', 'DUBLICATE_TIME_LABEL', 'Įrašas su laiko žyme jau egzistuoja', 'Įrašas su laiko žyme %1 jau egzistuoja'),
	(111, 'Įrašas neatitinka nustatytai redaguojamo atvaizdo sąlygai', 'WRONG_ENTRY_FOR_VIEW', 'Įrašas neatitinka nustatytai redaguojamo atvaizdo sąlygai', 'Įrašas neatitinka nustatytai redaguojamo atvaizdo sąlygai'),
	(112, 'Atnaujinimas blokuojamas, kai aktyvus taškų filtras, nes tai gali turėti netikėtų padarinių', 'UPDATE_BLOCKED_TO_EXCLUDE_UNEXPECTED_REZULTS', 'Atnaujinimas blokuojamas, kai aktyvus taškų filtras, nes tai gali turėti netikėtų padarinių', 'Atnaujinimas blokuojamas, kai aktyvus taškų filtras, nes tai gali turėti netikėtų padarinių'),
	(113, 'iki', 'BEFORE', 'iki', 'iki'),
	(114, 'po', 'AFTER', 'po', 'po'),
	(115, 'Nekorektiškas laikas: %1', 'WRONG_TIME', 'Nekorektiškas laikas', 'Nekorektiškas laikas: %1'),
	(116, 'Skaitiklio parametravimas nesukėlė duomenų numetimo', 'DATA_NOT_RESETED_AFTER_METER_PARAMETRATION', 'Skaitiklio parametravimas nesukėlė duomenų numetimo', 'Skaitiklio parametravimas nesukėlė duomenų numetimo'),
	(117, 'Nėra matavimo kanalo duomenų (area:%1) %2', 'MEASURING_CHANNEL_DATA_NOT_FOUND', 'Nėra matavimo kanalo duomenų', 'Nėra matavimo kanalo duomenų (area:%1) %2'),
	(118, 'Apskaitos mazgas %1 jau egzistuoja', 'DUBLICATE_ACCOUNT_NODE', 'Apskaitos mazgas jau egzistuoja', 'Apskaitos mazgas %1 jau egzistuoja'),
	(119, 'Nežinomas modulis %1', 'UNKNOWN_MODULE', 'Nežinomas modulis', 'Nežinomas modulis %1'),
	(120, 'Netinkamas periodas', 'WRONG_PERIOD', 'Netinkamas periodas', 'Netinkamas periodas'),
	(121, 'Persikertantys periodai', 'CROSSED_PERIODS', 'Persikertantys periodai', 'Persikertantys periodai'),
	(122, 'Ciklinė priklausomybė', 'CYCLIC_DEPENDENCY', 'Ciklinė priklausomybė', 'Ciklinė priklausomybė'),
	(123, 'Keitimas neleistinas dėl egzistuojančių susijusių rodmenų įrašų', 'RELATED_RECORDS_FOUND', 'Keitimas neleistinas dėl egzistuojančių susijusių rodmenų įrašų', 'Keitimas neleistinas dėl egzistuojančių susijusių rodmenų įrašų'),
	(124, 'Neleistinas sisteminio vartotojo modifikavimas', 'SYSTEM_USER_MODIFICATION_NOT_GRANTED', 'Neleistinas sisteminio vartotojo modifikavimas', 'Neleistinas sisteminio vartotojo modifikavimas'),
	(125, 'Skylių nerasta', 'HOLES_NOT_FOUND', 'Skylių nerasta', 'Skylių nerasta'),
	(126, 'Duomenų šaltiniai', 'DATA_SOURCES', 'Duomenų šaltiniai', 'Duomenų šaltiniai'),
	(127, 'Nuskaitomi duomenų elementai', 'READING_DATA_ELEMENTS', 'Nuskaitomi duomenų elementai', 'Nuskaitomi duomenų elementai'),
	(128, 'Duomenų šaltinio elementai', 'DATA_SOURCE_ELEMENTS', 'Duomenų šaltinio elementai', 'Duomenų šaltinio elementai'),
	(129, 'Duomenų šaltinio elementai, pasiekiami per ryšio kanalą', 'DATA_SOURCE_ELEMENTS_ON_COMMUNICATION_CHANNEL', 'Duomenų šaltinio elementai, pasiekiami per ryšio kanalą', 'Duomenų šaltinio elementai, pasiekiami per ryšio kanalą'),
	(130, 'Pasiekiamų per ryšio kanalą šaltinio elementų konfigūracija pagal nuskaitymo priežastį', 'READ_CAUSE_OF_DATA_SOURCE_ELEMENTS_ON_COMMUNICATION_CHANNEL', 'Pasiekiamų per ryšio kanalą šaltinio elementų konfigūracija pagal nuskaitymo priežastį', 'Pasiekiamų per ryšio kanalą šaltinio elementų konfigūracija pagal nuskaitymo priežastį'),
	(131, 'Keitimas', 'UPDATE', 'Keitimas', 'Keitimas'),
	(132, 'Pridėjimas', 'INSERT', 'Pridėjimas', 'Pridėjimas'),
	(133, 'Pašalinimas', 'DELETE', 'Pašalinimas', 'Pašalinimas'),
	(134, 'Nerasta nuskaitymo konfigūracija', 'READING_CONFIGURATION_NOT_FOUND', 'Nerasta nuskaitymo konfigūracija', 'Nerasta nuskaitymo konfigūracija'),
	(135, 'Grupės %1savybės reikšmė nėra skaitmeninė', 'GROUP_PROPERTY_NOT_DIGITAL', 'Grupės savybės reikšmė nėra skaitmeninė', 'Grupės %1savybės reikšmė nėra skaitmeninė'),
	(136, 'Sugrupuotų duomenų modifikacijai naudojamos tik tos apskaitos grupių savybės, kurioms nustatytas skaitmeninių reikšmių požymis', 'GROUPED_DATA_CHANGE_ALLOWED_FOR_DIGITAL_GROUP_PROPERTY_ONLY ', 'Sugrupuotų duomenų modifikacijai naudojamos tik apskaitos grupių savybės skaitmenės reikšmės', 'Sugrupuotų duomenų modifikacijai naudojamos tik tos apskaitos grupių savybės, kurioms nustatytas skaitmeninių reikšmių požymis'),
	(137, 'Neatitinka priskyrime naudojamų rodiklių diskretiškumai', 'WRONG_DISCRETION_OF_MONITORING_INDICATORS', 'Neatitinka priskyrime naudojamų rodiklių diskretiškumai', 'Neatitinka priskyrime naudojamų rodiklių diskretiškumai'),
	(138, 'Priskyrimo išeities ir paskirties rodikliai turi būti skirtingi', 'SOURCE_DESTINATION_ASSIGNMENT_NOT_DIFFERENT', 'Priskyrimo išeities ir paskirties rodikliai turi būti skirtingi', 'Priskyrimo išeities ir paskirties rodikliai turi būti skirtingi'),
	(139, 'Leistinas tik vienas kraštinės priskyrimas su galiojančiu atvaizdavimu vienam paskirties rodikliui', 'ALLOWED_ONLY_ONE_VERGE_ASSINGING_TO_ONE_TARGET', 'Leistinas tik vienas kraštinės priskyrimas su galiojančiu atvaizdavimu vienam paskirties rodikliui', 'Leistinas tik vienas kraštinės priskyrimas su galiojančiu atvaizdavimu vienam paskirties rodikliui'),
	(140, '%1 reikšmė %2', 'VALUE', 'reikšmė', '%1 reikšmė %2'),
	(141, 'matavimo', 'MEASURING', 'matavimo', 'matavimo'),
	(142, 'grupės', 'GROUP', 'grupės', 'grupės'),
	(143, 'šablono', 'TEMPLATE', 'šablono', 'šablono'),
	(144, '%1 \'%2\'', '1_\'2\'', '1 \'2\'', '%1 \'%2\''),
	(145, 'transformuota', 'TRANSFORMED', 'transformuota', 'transformuota'),
	(146, 'įvado', 'INPUT', 'įvado', 'įvado'),
	(147, 'išvado', 'OUTPUT', 'išvado', 'išvado'),
	(148, '%1 (%2)', '1_(2)', '1 (2)', '%1 (%2)'),
	(149, 'procentinė', 'PERCENT', 'procentinė', 'procentinė'),
	(150, '%1%2%3', '1_2_3', 'Trys reikšmės', '%1%2%3'),
	(151, 'Trūksta grupę sudarančių taškų matavimų duomenų', 'MEASURING_DATA_NOT_ENOUGH_FOR_GROUP', 'Trūksta grupę sudarančių taškų matavimų duomenų', 'Trūksta grupę sudarančių taškų matavimų duomenų'),
	(152, 'Duomenų šaltiniui \'%2\' jau egzistuoja \'%1\' tipo ryšio kanalas', 'DUBLICATE_COMMUNICATE_CHANNEL_FOR_SOURCE', 'Duomenų šaltiniui jau egzistuoja tipo ryšio kanalas', 'Duomenų šaltiniui \'%2\' jau egzistuoja \'%1\' tipo ryšio kanalas'),
	(153, 'Keitimas neleistinas, nes nežinomos pirminės reikšmės. Pasirinkite "Dauginimas: Draiveryje"', 'MULTIPLYING_IN_DEVICE_ONLY', 'Keitimas neleistinas, nes nežinomos pirminės reikšmės. Pasirinkite "Dauginimas: Draiveryje"', 'Keitimas neleistinas, nes nežinomos pirminės reikšmės. Pasirinkite "Dauginimas: Draiveryje"'),
	(154, 'Ši grupė jau įtraukta', 'GROUP_ALREADY_INCLUDED', 'Ši grupė jau įtraukta', 'Ši grupė jau įtraukta'),
	(155, 'Nepavyko suformuoti nuskaitymo užsakymo pagal signalą, gautą iš %1', 'READING_REQUEST_FROM_SIGNAL_NOT_PREPARED', 'Nepavyko suformuoti nuskaitymo užsakymo pagal signalą', 'Nepavyko suformuoti nuskaitymo užsakymo pagal signalą, gautą iš %1'),
	(156, 'Apskaitos būsenos signalo nuskaitymas yra neleistinas', 'ACCOUNTING_STATUS_SIGNAL_NOT_ALLOWED', 'Apskaitos būsenos signalo nuskaitymas yra neleistinas', 'Apskaitos būsenos signalo nuskaitymas yra neleistinas'),
	(157, 'Pasiekta maksimali apskaitos taškų kiekio riba', 'MAXIMUM_POINT_COUNT', 'Pasiekta maksimali apskaitos taškų kiekio riba', 'Pasiekta maksimali apskaitos taškų kiekio riba'),
	(158, 'sav', 'WEEK', 'sav', 'sav'),
	(159, 'Nerastas atitinkamas realaus laiko matavimų nuskaitymo profilis', 'REAL_TIME_MEASURING_READING_PROFILE_NOT_FOUND', 'Nerastas atitinkamas realaus laiko matavimų nuskaitymo profilis', 'Nerastas atitinkamas realaus laiko matavimų nuskaitymo profilis'),
	(160, 'Nerastas matavimas atitinkamame realaus laiko matavimų nuskaitymo profilyje', 'MEASURING_NOT_FOUND_IN_REAL_TIME_MEASURING_READING_PROFILE', 'Nerastas matavimas atitinkamame realaus laiko matavimų nuskaitymo profilyje', 'Nerastas matavimas atitinkamame realaus laiko matavimų nuskaitymo profilyje'),
	(161, 'Nuskaitymo taške gali būti įvestas tik vienas vieno tipo kanalas. Jau egzistuoja %1 tipo ryšio kanalas pavadinimu %2', 'DUBLICATE_COMMUNICATE_CHANNEL_TYPE', 'Jau egzistuoja tokio tipo ryšio kanalas', 'Jau egzistuoja tokio tipo ryšio kanalas'),
	(162, 'Patikrinkite, ar suvesta atitinkamų ryšio prioritetų profilių konfigūracija', 'CHECK_COMMUNICATION_PRIORITY_ON_CONFIGURATION_PROFILES ', 'Patikrinkite, ar suvesta atitinkamų ryšio prioritetų profilių konfigūracija', 'Patikrinkite, ar suvesta atitinkamų ryšio prioritetų profilių konfigūracija'),
	(163, 'mėn', 'MONTH', 'mėn', 'mėn'),
	(164, 'Ši foninė užduotis yra vykdoma šiuo metu. Pamėginkite vėliau.', 'BACKGROUND_TASK_EXECUTING', 'Ši foninė užduotis yra vykdoma šiuo metu. Pamėginkite vėliau.', 'Ši foninė užduotis yra vykdoma šiuo metu. Pamėginkite vėliau.'),
	(165, 'Apskaitos grupė su kodu %1 jau egzistuoja', 'DUBLICATE_GROUP_CODE', 'Apskaitos grupė su kodu jau egzistuoja', 'Apskaitos grupė su kodu %1 jau egzistuoja'),
	(166, 'Nerasta grupė-konteineris %1', 'GROUP-CONTAINER_NOT_FOUND', 'Nerasta grupė-konteineris', 'Nerasta grupė-konteineris %1'),
	(167, 'Matavimo taškas su kodu %1 jau egzistuoja', 'DUBLICATE_POINT_CODE', 'Matavimo taškas su kodu jau egzistuoja', 'Matavimo taškas su kodu %1 jau egzistuoja'),
	(168, 'Nerastas ekonominis profilis %1', 'ECONOMIC_PROFILE_NOT_FOUND', 'Nerastas ekonominis profilis', 'Nerastas ekonominis profilis %1'),
	(169, 'Nerastas apskaitos grupių tipas %1', 'GROUP_TYPE_NOT_FOUND', 'Nerastas apskaitos grupių tipas', 'Nerastas apskaitos grupių tipas %1'),
	(170, 'Nerastas matavimų rinkinys %1', 'MEASURING_LINE_SET_NOT_FOUND', 'Nerastas matavimų rinkinys', 'Nerastas matavimų rinkinys %1'),
	(171, 'Nerastas matavimo priemonių tipas %1', 'METER_TYPE_NOT_FOUND', 'Nerastas matavimo priemonių tipas', 'Nerastas matavimo priemonių tipas %1'),
	(172, 'Nerasta apskaitos grupių savybė %1', 'GROUP_PROPERTY_NOT_FOUND', 'Nerasta apskaitos grupių savybė', 'Nerasta apskaitos grupių savybė %1'),
	(173, 'Nerasta matavimo taškų savybė %1', 'POINT_PROPERTY_NOT_FOUND', 'Nerasta matavimo taškų savybė', 'Nerasta matavimo taškų savybė %1'),
	(174, 'Įvykdyta su įspėjimais. Peržiūrėkite Įvykių registrą.', 'EXECUTED_WITH_WARNINGS', 'Įvykdyta su įspėjimais. Peržiūrėkite Įvykių registrą.', 'Įvykdyta su įspėjimais. Peržiūrėkite Įvykių registrą.'),
	(175, 'Importo formai nerastas sukonfigūruoras duomenų šaltinis "%1"', 'SOURCE_NOT_FOUND_FOR_IMPORT_FORM', 'Importo formai nerastas sukonfigūruoras duomenų šaltinis', 'Importo formai nerastas sukonfigūruoras duomenų šaltinis "%1"'),
	(176, 'Negalima išsaugoti duomenų %1 elementui (forma - "%2")', 'FORM_ELEMENT_DATA_NOT_SAVED', 'Negalima išsaugoti duomenų formos elementui', 'Negalima išsaugoti duomenų %1 elementui (forma - "%2")'),
	(177, 'Šio tipo formų importas nepalaikomas', 'WRONG_FORM_TYPE_FOR_IMPORT', 'Šio tipo formų importas nepalaikomas', 'Šio tipo formų importas nepalaikomas'),
	(178, 'Taško %1 matavimai jau įtraukti į šaltinio "%2" elementus', 'DUBLICATE_POINT_MEASURING_IN_SOURCE_ELEMENTS', 'Taško matavimai jau įtraukti į šaltinio elementus', 'Taško %1 matavimai jau įtraukti į šaltinio "%2" elementus'),
	(179, 'Norint dinamiškai atnaujinti grupės sudėtį, reikia įvesti SQL užklausą foninių užduočių tipui', 'ENTER_SQL_QUERY_TO_UPDATE_GROUP_COMPOSITION', 'Norint dinamiškai atnaujinti grupės sudėtį, reikia įvesti SQL užklausą foninių užduočių tipui', 'Norint dinamiškai atnaujinti grupės sudėtį, reikia įvesti SQL užklausą foninių užduočių tipui'),
	(180, 'Taško %1 savybės reikšmė nėra skaitmeninė', 'POINT_PROPERTY_NOT_DIGITAL', 'Taško savybės reikšmė nėra skaitmeninė', 'Taško %1 savybės reikšmė nėra skaitmeninė'),
	(181, 'Šaltinis negali būti pervardintas, nes egzistuoja kitas šaltinis tokiu vardu: "%1"', 'DUBLICATE_SOURCE_NAME', 'Šaltinis negali būti pervardintas, nes egzistuoja kitas šaltinis tokiu vardu', 'Šaltinis negali būti pervardintas, nes egzistuoja kitas šaltinis tokiu vardu: "%1"'),
	(182, 'Nerastas matavimas su kodu %1', 'MEASURING_NOT_FOUND', 'Nerastas matavimas', 'Nerastas matavimas su kodu %1'),
	(183, 'Nerasta kryptis su kodu %1', 'DIRECTION_NOT_FOUND', 'Nerasta kryptis', 'Nerasta kryptis su kodu %1'),
	(184, 'Nerasta ekonominė kategorija su kodu %1', 'ECONOMIC_CATEGORY_CODE_NOT_FOUND', 'Nerasta ekonominė kategorija su kodu', 'Nerasta ekonominė kategorija su kodu %1'),
	(185, 'Nerastas taškų tipas su kodu %1', 'POINT_TYPE_NOT_FOUND', 'Nerastas taškų tipas su kodu', 'Nerastas taškų tipas su kodu %1'),
	(186, '%1%2%3%4%5', '1_2_3_4_5', 'Penkios reikšmės', '%1%2%3%4%5'),
	(187, '%1 %2', '1_2', 'Dvi reikšmės', '%1 %2'),
	(188, 'Išjungta', 'OFF', 'Išjungta', 'Išjungta'),
	(189, 'Įjungta', 'ONN', 'Įjungta', 'Įjungta'),
	(190, 'YYYY.MM.DD HH24:MI:SS', 'YYYY.MM.DD HH24:MI:SS', 'YYYY.MM.DD HH24:MI:SS', 'YYYY.MM.DD HH24:MI:SS'),
	(191, 'Keli skaitikliai', 'A_FEW_METERS', 'Keli skaitikliai', 'Keli skaitikliai'),
	(192, 'Nerasta matavimo priemonių savybė %1', 'PROPERTY_NOT_FOUND', 'Nerasta matavimo priemonių savybė', 'Nerasta matavimo priemonių savybė %1'),
	(193, 'Sistemos %1 savybės reikšmė nėra skaitmeninė', 'SYSTEM_PROPERTY_VALUE_NOT_DIGITAL', 'Sistemos savybės reikšmė nėra skaitmeninė', 'Sistemos %1 savybės reikšmė nėra skaitmeninė'),
	(194, 'Šaltinis tokiu vardu: "%1" jau priklauso nuskaitymo taškui "%2"', 'DUBLICATE_SOURCE_NAME_IN_DATAPOINT', 'Šaltinis jau priklauso nuskaitymo taškui', 'Šaltinis tokiu vardu: "%1" jau priklauso nuskaitymo taškui "%2"'),
	(195, 'Nerasta tinkamų matavimų generavimui', 'MEASURES_NOT_FOUND_FOR_GENERATION', 'Nerasta tinkamų matavimų generavimui', 'Nerasta tinkamų matavimų generavimui'),
	(196, 'Tvarkaraštis "%1" jau turi tokių pat parametrų paprastą tvarkaraštį %2', 'DUBLICATE_SIMPLE_SCHEDULE', 'Tvarkaraštis jau turi tokių pat parametrų paprastą tvarkaraštį', 'Tvarkaraštis "%1" jau turi tokių pat parametrų paprastą tvarkaraštį %2'),
	(197, 'KIO-3 formų failų vardai turi būti unikalūs. Pakeiskite %1', 'DUBLICATE_KIO-3_FORM_FILE_NAME', 'KIO-3 formų failų vardai turi būti unikalūs', 'KIO-3 formų failų vardai turi būti unikalūs. Pakeiskite %1'),
	(198, 'Šaltinių apjungimas neįmanomas, nes jie priklauso skirtingiems nuskaitymo taškams', 'SOURCES_WITH_DIFFERENT_DATA_POINTS', 'Šaltinių apjungimas neįmanomas, nes jie priklauso skirtingiems nuskaitymo taškams', 'Šaltinių apjungimas neįmanomas, nes jie priklauso skirtingiems nuskaitymo taškams'),
	(199, 'Šaltinių apjungimas neįmanomas, nes jie yra skirtingų tipų', 'SOURCES_WITH_DIFFERENT_TYPES', 'Šaltinių apjungimas neįmanomas, nes jie yra skirtingų tipų', 'Šaltinių apjungimas neįmanomas, nes jie yra skirtingų tipų'),
	(200, 'Šaltinių apjungimas neįmanomas, nes skiriasi jų duomenų išdėstymo tipai', 'SOURCES_WITH_DIFFERENT_DATA_LOCATIONS', 'Šaltinių apjungimas neįmanomas, nes skiriasi jų duomenų išdėstymo tipai', 'Šaltinių apjungimas neįmanomas, nes skiriasi jų duomenų išdėstymo tipai'),
	(201, 'Šaltinių apjungimas neįmanomas, nes skiriasi jų laiko zonos', 'SOURCES_WITH_DIFFERENT_TIME_ZONES', 'Šaltinių apjungimas neįmanomas, nes skiriasi jų laiko zonos', 'Šaltinių apjungimas neįmanomas, nes skiriasi jų laiko zonos'),
	(202, 'Šaltinio generavimas neįmanomas, nes skiriasi formos sekcijų laiko zonos', 'SOURCES_WITH_DIFFERENT_SECTION_TIME_ZONES', 'Šaltinio generavimas neįmanomas, nes skiriasi formos sekcijų laiko zonos', 'Šaltinio generavimas neįmanomas, nes skiriasi formos sekcijų laiko zonos'),
	(203, 'Sekcijos %1 laiko zona nesutampa su ASKP failo %2 laiko zona', 'SECTION_AND_ASKP_FILE_HAVE_DIFFERENT_TIME_ZONES', 'Sekcijos laiko zona nesutampa su ASKP failo laiko zona', 'Sekcijos %1 laiko zona nesutampa su ASKP failo %2 laiko zona'),
	(204, 'Matavimo prietaiso montavimo pradžios data negali būti ankstesnė už pagaminimo ar eksploatacijos pradžios datą', 'MOU_MADE_EXPL_DATA_CHECK', 'Matavimo prietaiso montavimo pradžios datos tikrinimas', 'Matavimo prietaiso montavimo pradžios data negali būti ankstesnė už pagaminimo ar eksploatacijos pradžios datą'),
	(205, 'Apsikeitimo duomenimis formos protokolas netinka šio tipo formai', 'FORM_PROTOCOL_CHECK', 'Apsikeitimo duomenimis formos protokolo tinkamumo tikrinimas', 'Apsikeitimo duomenimis formos protokolas netinka šio tipo formai'),
	(206, 'Licenzija negalioja', 'LICENSE_WRONG', 'Licenzija negalioja', 'Licenzija negalioja'),
	(207, 'Licenzija tinka', 'LICENSE_CHECKED', 'Licenzijos tinkamumas', 'Licenzija tinka'),
	(208, 'Licenzija priskirta', 'LICENSE_INSTALLED', 'Licenzijos įrasymas', 'Licenzija priskirta'),
	(209, 'Produkto naudojimo periodas baigtas', 'LICENSE_EXPIRATION', 'Produkto naudojimo periodas baigtas', 'Produkto naudojimo periodas baigtas'),
	(210, 'Licenzija nerasta', 'LICENSE_NOT_FOUND', 'Licenzija nerasta', 'Licenzija nerasta'),
	(211, 'Importo formos sekcijos %1 laiko zona nesutampa su importuojamų duomenų šaltinio %2 laiko zona', 'IMPORT_FORM_AND_SOURCE_WITH_DIFFERENT_TIME_ZONES', 'Importo formos sekcijos ir importuojamų duomenų šaltinio laiko zonų nesutapimas', 'Importo formos sekcijos %1 laiko zona nesutampa su importuojamų duomenų šaltinio %2 laiko zona'),
	(212, 'Apsikeitimo formos su vienetinio matavimo apskaitos mazgo požymiu apskaitos mazgas %1 gali turėti tik vieną matavimą', 'DUBLICATE_XFAU_MEASURING_IN_FORM', 'Apsikeitimo formos apskaitos mazgas gali turėti tik vieną matavimą', 'Apsikeitimo formos su vienetinio matavimo apskaitos mazgo požymiu apskaitos mazgas %1 gali turėti tik vieną matavimą'),
	(213, 'Nuskaitymo taške gali būti įvestas tik vienas vieno tipo kanalas. Jau egzistuoja (ištrintas) %1 tipo ryšio kanalas pavadinimu %2', 'DUBLICATE_COMMUNICATE_CHANNEL_TYPE_DEL', 'Jau egzistuoja tokio tipo ryšio kanalas (ištrintas)', 'Jau egzistuoja tokio tipo ryšio kanalas (ištrintas)'),
	(219, 'Suvedamas skaičius turi būti %1 kartotinis', 'LINK_CFG.SE_SUMMAND_ERROR1', 'Suvedamas skaičius turi būti kartotinis', 'Suvedamas skaičius turi būti %1 kartotinis'),
	(220, 'Persivertė matavimo \'%1\' reikšmė: %2%3 [%4] -> %5%6 [%7]', 'STORE_PL.GROWTH_LIMIT_EXCEEDED', 'Persivertė matavimo reikšmė', 'Persivertė matavimo \'%1\' reikšmė: %2%3 [%4] -> %5%6 [%7]'),
	(221, 'Išmesta nevykdytų ryšio užduočių, senesnių nei %2 val.: %1', 'READ_LTL.OLD_REMOVED', 'Išmestos senos nevykdytos ryšio užduotys', 'Išmesta nevykdytų ryšio užduočių, senesnių nei %2 val: %1'),
	(222, 'Atvaizduojamo profilio lauko indeksas turi būti numeruojamas nuo 1 iki 100', 'FFP_VAL_ROW_NUM_100', 'Atvaizduojamo profilio lauko indeksas turi būti numeruojamas nuo 1 iki 100', 'Atvaizduojamo profilio lauko indeksas turi būti numeruojamas nuo 1 iki 100'),
	(223, 'Nesutapo %1 %2 (%3) ir %4 (%5) už %6', 'CP.EV_MSG_1', 'Nesutapo suma', 'Nesutapo %1 %2 (%3) ir %4 (%5) už %6'),
	(224, 'Nesutapo %1 %2, visų tarifų suma (%3) ir %4 (%5) už %6', 'CP.EV_MSG_2', 'Nesutapo visų tarifų suma', 'Nesutapo %1 %2, visų tarifų suma (%3) ir %4 (%5) už %6'),
	(225, 'Nesutapo %1 %2 pagal %7 tarifą (%3) ir %4 (%5) už %6', 'CP.EV_MSG_3', 'Nesutapo tarifinė suma', 'Nesutapo %1 %2 pagal %7 tarifą (%3) ir %4 (%5) už %6'),
	(226, 'Pakartotinai nesutapo %1 %2 (%3) ir %4 (%5) už %6', 'CP.EV_MSG_4', 'Pakartotinai nesutapo suma', 'Pakartotinai nesutapo %1 %2 (%3) ir %4 (%5) už %6'),
	(227, 'Pakartotinai nesutapo %1 %2, visų tarifų suma (%3) ir %4 (%5) už %6', 'CP.EV_MSG_5', 'Pakartotinai nesutapo visų tarifų suma', 'Pakartotinai nesutapo %1 %2, visų tarifų suma (%3) ir %4 (%5) už %6'),
	(228, 'Pakartotinai nesutapo %1 %2 pagal %7 tarifą (%3) ir %4 (%5) už %6', 'CP.EV_MSG_6', 'Pakartotinai nesutapo tarifinė suma', 'Pakartotinai nesutapo %1 %2 pagal %7 tarifą (%3) ir %4 (%5) už %6'),
	(229, 'Nežinomas duomenų statusas %1', 'STORE_PL.UNKNOWN_SF', 'Nežinomas duomenų statusas', 'Nežinomas duomenų statusas %1'),
	(230, 'Vartotojas %1 užblokuotas nuo %2', 'CHECK_LOCKED_USERS', 'Vartotojas užblokuotas', 'Vartotojas %1 užblokuotas nuo %2'),
	(231, 'Nerastas išvardinimas %1', 'UNKNOWN_ENUM_CODE', 'Nerastas išvardinimas', 'Nerastas išvardinimas %1'),
	(232, 'Nerastas matavimo taškų savybių tipas %1', 'UNKNOWN_PPTY_TYPE_CODE', 'Nerastas matavimo taškų savybių tipas', 'Nerastas matavimo taškų savybių tipas %1'),
	(233, 'Nerastas matavimo prietaisų savybių tipas %1', 'UNKNOWN_MPTY_TYPE_CODE', 'Nerastas matavimo prietaisų savybių tipas', 'Nerastas matavimo prietaisų savybių tipas %1'),
	(234, 'Nerastas apskaitos grupių savybių tipas %1', 'UNKNOWN_GPTY_TYPE_CODE', 'Nerastas apskaitos grupių savybių tipas', 'Nerastas apskaitos grupių savybių tipas %1'),
	(235, 'Nerastas išvardinimų naudojimo tipas %1', 'UNKNOWN_ENUM_TYPE_CODE', 'Nerastas išvardinimų naudojimo tipas', 'Nerastas išvardinimų naudojimo tipas %1'),
	(236, 'Nerastas taško %2 matavimas %3 (mazgas %1)', 'PL_NOT_FOUND', 'Mazge nerastas taško matavimas', 'Nerastas taško %2 matavimas %3 (mazgas %1)'),
	(237, 'Nėra %2 "%3" reikšmių už %1', 'CP.CP_NOTE.A', 'Neužpildytos visos uždaromųjų rodmenų reikšmės', 'Nėra %2 "%3" reikšmių už %1'),
	(238, 'Nėra dalies %2 "%3" reikšmių už %1', 'CP.CP_NOTE.B', 'Neužpildyta dalis uždaromųjų rodmenų reikšmių', 'Nėra dalies %2 "%3" reikšmių už %1'),
	(239, 'Neuždarytas %2 "%4" periodas už %1', 'CP.CP_NOTE.C', 'Neuždarytas detalesnis palyginamasis periodas', 'Neuždarytas %2 "%4" periodas už %1'),
	(240, 'Nėra %2 "%4" reikšmių už %1', 'CP.CP_NOTE.D', 'Neužpildytos visos palyginamųjų detalesnių rodmenų reikšmės', 'Nėra %2 "%4" reikšmių už %1'),
	(241, 'Nėra dalies %2 "%4" reikšmių už %1', 'CP.CP_NOTE.E', 'Neužpildyta dalis palyginamųjų detalesnių rodmenų reikšmių', 'Nėra dalies %2 "%4" reikšmių už %1'),
	(242, 'Nesutampa %2 "%3" (%5) ir "%4" (%6) už %1', 'CP.CP_NOTE.F', 'Nesutampa uždaromųjų ir palyginamųjų detalesnių rodmenų reikšmės', 'Nesutampa %2 "%3" (%5) ir "%4" (%6) už %1'),
	(243, 'Pagal taškui priskirtą užpildymo profilį nėra dalies %2 "%3" rodmenų reikšmių už %1', 'CP.CP_NOTE.H', 'Pagal taškui priskirtą užpildymo profilį nėra dalies rodmenų reikšmių', 'Pagal taškui priskirtą užpildymo profilį nėra dalies %2 "%3" rodmenų reikšmių už %1'),
	(244, 'Pagal taškui priskirtą užpildymo profilį nėra %2 "%3" rodmenų reikšmių už %1', 'CP.CP_NOTE.G', 'Pagal taškui priskirtą užpildymo profilį nėra rodmenų reikšmių', 'Pagal taškui priskirtą užpildymo profilį nėra %2 "%3" rodmenų reikšmių už %1'),
	(245, 'Momentinis matavimas "%2" nepatenka į nuskaitomų duomenų elementų nuskaitytus periodus už %1', 'CP.CP_NOTE.I', 'Momentinis matavimas nepatenka į nuskaitomų duomenų elementų nuskaitytus periodus', 'Momentinis matavimas "%2" nepatenka į nuskaitomų duomenų elementų nuskaitytus periodus už %1'),
	(246, 'Suminės energijos "%2" rodmuo mažesnis, nei prieš tai buvęs už %1', 'CP.CP_NOTE.K', 'Suminės energijos rodmuo mažesnis, nei prieš tai buvęs', 'Suminės energijos "%2" rodmuo mažesnis, nei prieš tai buvęs už %1'),
	(247, 'Betarifė %2 "%3" suma (%5) nesutampa su bendra "%4" tarifų suma (%6) už %1', 'CP.CP_NOTE.J', 'Betarifė suma nesutampa su bendra tarifų suma', 'Betarifė %2 "%3" suma (%5) nesutampa su bendra "%4" tarifų suma (%6) už %1'),
	(248, 'Taškas nebuvo bandomas uždaryti', 'CP.NO_ATTEMPT_TO_CLOSE_THE_POINT', 'Taškas nebuvo bandomas uždaryti', 'Taškas nebuvo bandomas uždaryti'),
	(249, 'Taškui nepriskirtas užpildymo profilis', 'CP.POINT_HAS_NO_FP', 'Taškui nepriskirtas užpildymo profilis', 'Taškui nepriskirtas užpildymo profilis'),
	(250, 'Per %1 periodą iš %2 neuždaryta %3 taškų', 'CP.PRD_STATS', 'Per periodą neuždarytų taškų skaičius', 'Per %1 periodą iš %2 neuždaryta %3 taškų'),
	(251, 'Per %1 periodą nėra uždaromų taškų', 'CP.PRD_NO_POINTS', 'Per nurodytą periodą nėra uždaromų taškų', 'Per %1 periodą nėra uždaromų taškų'),
	(252, 'Taškui nerasta užpildymo profilį atitinkančių galiojančių matavimų', 'CP.ST_SE_INT_FP_IS_EMPTY', 'Taškui nerasta užpildymo profilį atitinkančių galiojančių matavimų', 'Taškui nerasta užpildymo profilį atitinkančių galiojančių matavimų'),
	(253, 'Taškui nerasta galiojančių matavimų', 'CP.ST_SE_IS_EMPTY', 'Taškui nerasta galiojančių matavimų', 'Taškui nerasta galiojančių matavimų'),
	(254, 'Taškas negaliojantis', 'CP.POINT_DISABLED', 'Taškas negaliojantis', 'Taškas negaliojantis'),
	(255, 'Duomenų šaltinių savybės', 'SRC_LPTY', 'Duomenų šaltinių savybės', 'Duomenų šaltinių savybės'),
	(256, 'Duomenų šaltinių, pasiekiamų per ryšio kanalą, savybės', 'SP_LPTY', 'Duomenų šaltinių, pasiekiamų per ryšio kanalą, savybės', 'Duomenų šaltinių, pasiekiamų per ryšio kanalą, savybės'),
	(257, 'Duomenų šaltinio elementų savybės', 'SE_LPTY', 'Duomenų šaltinio elementų savybės', 'Duomenų šaltinio elementų savybės'),
	(258, 'Duomenų pluoštų šaltinio elementų savybės', 'SE_SHEAF_LPTY', 'Duomenų pluoštų šaltinio elementų savybės', 'Duomenų pluoštų šaltinio elementų savybės'),
	(259, 'Duomenų pluoštų šaltinio elementai', 'SE_SHEAF', 'Duomenų pluoštų šaltinio elementai', 'Duomenų pluoštų šaltinio elementai'),
	(260, 'Duomenų pluoštų šaltinio elementai, pasiekiami per ryšio kanalą', 'SEP_SHEAF', 'Duomenų pluoštų šaltinio elementai, pasiekiami per ryšio kanalą', 'Duomenų pluoštų šaltinio elementai, pasiekiami per ryšio kanalą'),
	(261, 'Pasiekiamų per ryšio kanalą duomenų pluoštų šaltinių elementų konfigūracija pagal nuskaitymo priežastį', 'SEP_SHEAF_RC', 'Pasiekiamų per ryšio kanalą duomenų pluoštų šaltinių elementų konfigūracija pagal nuskaitymo priežastį', 'Pasiekiamų per ryšio kanalą duomenų pluoštų šaltinių elementų konfigūracija pagal nuskaitymo priežastį'),
	(262, 'Nuskaitomi duomenų pluoštų elementai', 'DI_SHEAF', 'Nuskaitomi duomenų pluoštų elementai', 'Nuskaitomi duomenų pluoštų elementai'),
	(263, 'Gautas pranešimas apie nežinomo ryšio prietaiso %1 prisijungimą prie %2:%3', 'STPROXY.UNKNOWN_TID_CONN_OPEN_RCVD', 'Gautas pranešimas apie nežinomo ryšio prietaiso prisijungimą', 'Gautas pranešimas apie nežinomo ryšio prietaiso %1 prisijungimą prie %2:%3'),
	(264, 'Gautas pranešimas apie nežinomo ryšio prietaiso %1 atsijungimą nuo %2:%3', 'STPROXY.UNKNOWN_TID_CONN_CLOSE_RCVD', 'Gautas pranešimas apie nežinomo ryšio prietaiso atsijungimą', 'Gautas pranešimas apie nežinomo ryšio prietaiso %1 atsijungimą nuo %2:%3'),
	(265, 'Gautas pranešimas apie ryšio prietaiso %1 prisijungimą prie %2:%3', 'STPROXY.TID_CONN_OPEN_RCVD', 'Gautas pranešimas apie ryšio prietaiso prisijungimą', 'Gautas pranešimas apie nežinomo ryšio prietaiso %1 prisijungimą prie %2:%3'),
	(266, 'Gautas pranešimas apie ryšio prietaiso %1 atsijungimą nuo %2:%3', 'STPROXY.TID_CONN_CLOSE_RCVD', 'Gautas pranešimas apie ryšio prietaiso atsijungimą', 'Gautas pranešimas apie nežinomo ryšio prietaiso %1 atsijungimą nuo %2:%3'),
	(267, 'Visiems parinktiems taškams neturite teisės modifikuoti surinkimo konfigūracijos', 'GRANT_NOT_FOUND_FOR_POINTS', 'Neturite teisės modifikuoti surinkimo konfigūracijos parinktiems taškams', 'Visiems parinktiems taškams neturite teisės modifikuoti surinkimo konfigūracijos'),
	(268, 'Neturite teisės modifikuoti surinkimo konfigūracijos parinktam šaltiniui', 'GRANT_NOT_FOUND_FOR_SOURCE', 'Neturite teisės modifikuoti surinkimo konfigūracijos parinktam šaltiniui', 'Neturite teisės modifikuoti surinkimo konfigūracijos parinktam šaltiniui'),
	(269, 'Nežinoma šaltinio tipo modifikacija. Pirma nuskaitykite prietaiso versiją', 'SRC_TYPE_MOD.VERSION_FIRST', 'Nežinoma šaltinio tipo modifikacija. Pirma nuskaitykite prietaiso versiją', 'Nežinoma šaltinio tipo modifikacija. Pirma nuskaitykite prietaiso versiją'),
	(272, 'Nuskaitymo taškų duomenų pluošto šaltinių elementai', 'SE_DP_SHEAF', 'Nuskaitymo taškų duomenų pluošto šaltinių elementai', 'Nuskaitymo taškų duomenų pluošto šaltinių elementai'),
	(273, 'Nuskaitymo taškų duomenų pluošto šaltinių elementų savybės', 'SE_DP_SHEAF_LPTY', 'Nuskaitymo taškų duomenų pluošto šaltinių elementų savybės', 'Nuskaitymo taškų duomenų pluošto šaltinių elementų savybės'),
	(274, 'Nuskaitymo taškų duomenų pluošto šaltinių elementai, nuskaitomi per ryšio kanalą', 'SEP_DP_SHEAF', 'Nuskaitymo taškų duomenų pluošto šaltinių elementai, nuskaitomi per ryšio kanalą', 'Nuskaitymo taškų duomenų pluošto šaltinių elementai, nuskaitomi per ryšio kanalą'),
	(275, 'Nuskaitymo taškų duomenų pluošto šaltinių elementų, nuskaitomų per ryšio kanalą, nuskaitymo priežastys', 'SEP_DP_SHEAF_RC', 'Nuskaitymo taškų duomenų pluošto šaltinių elementų, nuskaitomų per ryšio kanalą, nuskaitymo priežastys', 'Nuskaitymo taškų duomenų pluošto šaltinių elementų, nuskaitomų per ryšio kanalą, nuskaitymo priežastys'),
	(276, 'Nuskaitomi duomenų pluoštų elementai nuskaitymo taške', 'DI_DP_SHEAF', 'Nuskaitomi duomenų pluoštų elementai nuskaitymo taške', 'Nuskaitomi duomenų pluoštų elementai nuskaitymo taške'),
	(277, 'Dalis %2 "%4" duomenų už %1 turi negalutinį pagerinamų rodmenų statusą', 'CP.CP_NOTE.L0', 'Dalis palyginamųjų duomenų turi negalutinį pagerinamų rodmenų statusą', 'Dalis %2 "%4" duomenų už %1 turi negalutinį pagerinamų rodmenų statusą'),
	(278, 'Dalis %2 "%3" duomenų už %1 turi negalutinį pagerinamų rodmenų statusą', 'CP.CP_NOTE.L1', 'Dalis uždaromųjų duomenų turi negalutinį pagerinamų rodmenų statusą', 'Dalis %2 "%3" duomenų už %1 turi negalutinį pagerinamų rodmenų statusą'),
	(279, 'Daliai %2 "%4" duomenų už %1 yra nustatytas, bet nėra atliktas pakartotinis perrinkimas', 'CP.CP_NOTE.M0', 'Daliai palyginamųjų duomenų yra nustatytas, bet nėra atliktas pakartotinis perrinkimas', 'Daliai %2 "%4" duomenų už %1 yra nustatytas, bet nėra atliktas pakartotinis perrinkimas'),
	(280, 'Daliai %2 "%3" duomenų už %1 yra nustatytas, bet nėra atliktas pakartotinis perrinkimas', 'CP.CP_NOTE.M1', 'Daliai uždaromųjų duomenų yra nustatytas, bet nėra atliktas pakartotinis perrinkimas', 'Daliai %2 "%3" duomenų už %1 yra nustatytas, bet nėra atliktas pakartotinis perrinkimas'),
	(281, 'Šaltinio tipas nesutampa su šablone užduotu šaltinių tipu', 'STC_TYPE_TMPL_MISMATCH', 'Šaltinio tipas nesutampa su šablone užduotu šaltinių tipu', 'Šaltinio tipas nesutampa su šablone užduotu šaltinių tipu'),
	(282, 'Šaltinių apjungimas neįmanomas, nes turi skirtingus energijos tėkmės krypties invertavimo požymius', 'SOURCES_WITH_DIFFERENT_DIR', 'Šaltinių apjungimas neįmanomas, nes turi skirtingus energijos tėkmės krypties invertavimo požymius', 'Šaltinių apjungimas neįmanomas, nes turi skirtingus energijos tėkmės krypties invertavimo požymius'),
	(283, 'Keitimų neatlikta', 'NOT_CHANGED', 'Keitimų neatlikta', 'Keitimų neatlikta'),
	(284, 'Nerasta duomenų, laukiančių vartotojo sprendimo', 'NO_DOUBT_DATA_FOUND', 'Nerasta duomenų, laukiančių vartotojo sprendimo', 'Nerasta duomenų, laukiančių vartotojo sprendimo'),
	(285, '%2 "%3" reikšmėms už %1 nėra atliktas monitoringo testas "%8"', 'CP.CP_NOTE.N', 'Nėra atliktas monitoringo testas užpildymo profilyje numatytiems rodmenims', '%2 "%3" reikšmėms už %1 nėra atliktas monitoringo testas "%8"'),
	(286, '%2 "%3" reikšmėms už %1 nesėkmingas monitoringo testas "%8"', 'CP.CP_NOTE.P', 'Nesėkmingas monitoringo testas užpildymo profilyje numatytiems rodmenims', '%2 "%3" reikšmėms už %1 nesėkmingas monitoringo testas "%8"'),
	(287, '%2 "%3" reikšmėms už %1 aptiktas išimtinis duomenų statusas "%9"', 'CP.CP_NOTE.Q', 'Užpildymo profilyje numatytiems rodmenims aptiktas išimtinis duomenų statusas', '%2 "%3" reikšmėms už %1 aptiktas išimtinis duomenų statusas "%9"'),
	(288, 'Išmesta nevykdytų skubių ryšio užduočių, senesnių nei %2 sek.: %1', 'READ_UTL.OLD_REMOVED', 'Išmestos senos nevykdytos skubios ryšio užduotys', 'Išmesta nevykdytų skubių ryšio užduočių, senesnių nei %2 sek.: %1'),
	(289, 'Taške nerasta reikalingų išskaičiavimui matavimų', 'ACT_360.MEASURE_NOT_FOUND', 'Taške nerasta reikalingų išskaičiavimui matavimų', 'Taške nerasta reikalingų išskaičiavimui matavimų'),
	(290, 'Mėnesio matavimas jau turi aktu suvestą reikšmę', 'ACT_360.MONTH_ACT_EXISTS', 'Mėnesio matavimas jau turi aktu suvestą reikšmę', 'Mėnesio matavimas jau turi aktu suvestą reikšmę'),
	(291, 'Nebuvo atliktas sutikrinimas %1 parai', 'ACT_360.NO_ATTEMPT', 'Nebuvo atliktas sutikrinimas parai', 'Nebuvo atliktas sutikrinimas %1 parai'),
	(292, 'Visos mėnesio paros uždarytos', 'ACT_360.DAYS_CLOSED', 'Visos mėnesio paros uždarytos', 'Visos mėnesio paros uždarytos'),
	(293, 'Paros %1 sutikrinimo metu nerasta visų numatytų testų rezultatų', 'ACT_360.MT_MISSING', 'Paros sutikrinimo metu nerasta visų numatytų testų rezultatų', 'Paros %1 sutikrinimo metu nerasta visų numatytų testų rezultatų'),
	(294, 'Per mažai darbo valandų', 'ACT_360.SHORT', 'Per mažai darbo valandų', 'Per mažai darbo valandų'),
	(295, 'Nerasta valandų, kurioms reikia atlikti išskaičiavimą', 'ACT_360.NO_HOUR', 'Nerasta valandų, kurioms reikia atlikti išskaičiavimą', 'Nerasta valandų, kurioms reikia atlikti išskaičiavimą'),
	(296, 'Pasiektas vartotojui nustatytas mėnesinis pranešimų limitas', 'SMS_LIMIT_REACHED', 'Pasiektas vartotojui nustatytas mėnesinis pranešimų limitas', 'Pasiektas vartotojui nustatytas mėnesinis pranešimų limitas'),
	(297, 'Pranešimas siunčiamas viršijus mėnesinį pranešimų limitą', 'SMS_BEYOND_LIMIT', 'Pranešimas siunčiamas viršijus mėnesinį pranešimų limitą', 'Pranešimas siunčiamas viršijus mėnesinį pranešimų limitą'),
	(298, '%1 "%2" formos operacija("%3")', 'XO_EXPORT_FORM/ELEMENT', '%1 "%2" formos operacija("%3")', '%1 "%2" formos operacija("%3")'),
	(299, 'Neuždarytos %1 mėnesio paros', 'CP.CP_NOTE.R', 'Neuždarytos mėnesio paros', 'Neuždarytos %1 mėnesio paros'),
	(300, 'Signalo dvejetainių reikšmių požymis negali būti pakeistas, nes aptiktos netenkinančios reikšmės', 'DS.DS_BINARY_CANNOT_BE_SET', 'Signalo dvejetainių reikšmių požymis negali būti pakeistas', 'Signalo dvejetainių reikšmių požymis negali būti pakeistas, nes aptiktos netenkinančios reikšmės'),
	(301, 'Neleistina signalo reikšmė: %1', 'DS.DS_BINARY_VIOLATED', 'Neleistina signalo reikšmė', 'Neleistina signalo reikšmė: %1'),
	(302, 'Apeinamųjų taškų konfigūracijoje naudojami tik apskaitos būsenų signalai su dvejetainių reikšmių požymiu', 'BYP.DS_BINARY', 'Apeinamųjų taškų konfigūracijoje naudojami tik apskaitos būsenų signalai su dvejetainių reikšmių požymiu', 'Apeinamųjų taškų konfigūracijoje naudojami tik apskaitos būsenų signalai su dvejetainių reikšmių požymiu'),
	(303, 'Gauta skaitiklio parametro "%1" informacija', 'STORE_PW.SETTING_RECEIVED', 'Gauta skaitiklio parametro informacija', 'Gauta skaitiklio parametro "%1" informacija'),
	(304, 'Gauta duomenų koncentratoriaus parametro "%1" informacija', 'STORE_DW.SETTING_RECEIVED', 'Gauta duomenų koncentratoriaus parametro informacija', 'Gauta duomenų koncentratoriaus parametro "%1" informacija'),
	(305, 'Gautas pranešimas iš %1 nuo nežinomo ESMON prietaiso %2', 'STIPLISTENER.ESMON.UNKNOWN', 'Gautas pranešimas nuo nežinomo ESMON prietaiso', 'Gautas pranešimas iš %1 nuo nežinomo ESMON prietaiso %2'),
	(306, 'Gautas pranešimas iš %1 nuo žinomo ESMON prietaiso %2', 'STIPLISTENER.ESMON.KNOWN', 'Gautas pranešimas nuo žinomo ESMON prietaiso', 'Gautas pranešimas iš %1 nuo žinomo ESMON prietaiso %2'),
	(307, 'Gautas %4 siųstas pranešimas (IP=%1) nuo nežinomo skaitiklio %2 %3', 'STIPLISTENER.STORE_PA.UNKNOWN', 'Gautas pranešimas nuo nežinomo skaitiklio', 'Gautas %4 siųstas pranešimas (IP=%1) nuo nežinomo skaitiklio %2 %3'),
	(308, 'Gautas %4 siųstas pranešimas (IP=%1) nuo nesusieto su apskaitos tašku skaitiklio %2 %3', 'STIPLISTENER.STORE_PA.NO_MOU', 'Gautas pranešimas nuo nesusieto su apskaitos tašku skaitiklio', 'Gautas %4 siųstas pranešimas (IP=%1) nuo nesusieto su apskaitos tašku skaitiklio %2 %3'),
	(309, 'Gautas %4 siųstas pranešimas (IP=%1) nuo nepilnai nuskaitymui sukonfigūruoto skaitiklio %2 %3', 'STIPLISTENER.STORE_PA.NO_16', 'Gautas pranešimas nuo nepilnai nuskaitymui sukonfigūruoto skaitiklio', 'Gautas %4 siųstas pranešimas (IP=%1) nuo nepilnai nuskaitymui sukonfigūruoto skaitiklio %2 %3'),
	(310, 'Gautas %4 siųstas pranešimas (IP=%1) apie neregistruotą skaitiklį %2 %3', 'STIPLISTENER.STORE_PA.NEW_METER', 'Gautas pranešimas apie neregistruotą skaitiklį', 'Gautas %4 siųstas pranešimas (IP=%1) apie neregistruotą skaitiklį %2 %3'),
	(311, 'Gautas %4 siųstas pranešimas (IP=%1) apie užregistruotą skaitiklį %2 %3', 'STIPLISTENER.STORE_PA.METER_REGISTERED', 'Gautas pranešimas apie užregistruotą skaitiklį', 'Gautas %4 siųstas pranešimas (IP=%1) apie užregistruotą skaitiklį %2 %3'),
	(312, 'Konfigūracijos konfliktas su nuskaitymo tašku %5. Gautas %4 siųstas pranešimas (IP=%1) apie neregistruotą skaitiklį %2 %3', 'STIPLISTENER.STORE_PA.C_NEW_METER', 'Konfigūracijos konfliktas. Gautas pranešimas apie neregistruotą skaitiklį', 'Konfigūracijos konfliktas su nuskaitymo tašku %5. Gautas %4 siųstas pranešimas (IP=%1) apie neregistruotą skaitiklį %2 %3'),
	(313, 'Konfigūracijos konfliktas su nuskaitymo tašku %5. Gautas %4 siųstas pranešimas (IP=%1) apie užregistruotą skaitiklį %2 %3', 'STIPLISTENER.STORE_PA.C_METER_REGISTERED', 'Konfigūracijos konfliktas. Gautas pranešimas apie užregistruotą skaitiklį', 'Konfigūracijos konfliktas su nuskaitymo tašku %5. Gautas %4 siųstas pranešimas (IP=%1) apie užregistruotą skaitiklį %2 %3'),
	(314, 'Sukonfigūruota, bet neapklausiama. Gautas %4 siųstas pranešimas (IP=%1) apie neregistruotą skaitiklį %2 %3', 'STIPLISTENER.STORE_PA.R_NEW_METER', 'Sukonfigūruota, bet neapklausiama. Gautas pranešimas apie neregistruotą skaitiklį', 'Sukonfigūruota, bet neapklausiama. Gautas %4 siųstas pranešimas (IP=%1) apie neregistruotą skaitiklį %2 %3'),
	(315, 'Sukonfigūruota ir vėl apklausiama. Gautas %4 siųstas pranešimas (IP=%1) apie užregistruotą skaitiklį %2 %3', 'STIPLISTENER.STORE_PA.R_METER_REGISTERED', 'Sukonfigūruota ir vėl apklausiama. Gautas pranešimas apie užregistruotą skaitiklį', 'Sukonfigūruota ir vėl apklausiama. Gautas %4 siųstas pranešimas (IP=%1) apie užregistruotą skaitiklį %2 %3'),
	(316, 'Išsaugota pilna skaitiklio parametrų informacija', 'FULL_METER_CONFIG_SAVE', 'Išsaugota pilna skaitiklio parametrų informacija', 'Išsaugota pilna skaitiklio parametrų informacija'),
	(317, 'Matavimo taško ryšio konfigūracija užpildyta', 'POINT_READ_CONFIG_FILL', 'Matavimo taško ryšio konfigūracija užpildyta', 'Matavimo taško ryšio konfigūracija užpildyta'),
	(318, 'Neapibrėžta', 'EVAC.NVAL1.UNDEFINED', 'Neapibrėžta', 'Neapibrėžta'),
	(319, 'Neleistina konfigūracijos parametro %1 indekso Nr.%2 reikšmė: %3', 'RODO.SETTING.INDEX_OUT_OF_BOUNDS', 'Neleistina konfigūracijos parametro indekso reikšmė', 'Neleistina konfigūracijos parametro %1 indekso Nr.%2 reikšmė: %3'),
	(320, 'Siuntimas atmestas, nes aptikta trūkstamų formoje elementų', 'ACTION_61968_1', 'Siuntimas atmestas, nes aptikta trūkstamų formoje elementų', 'Siuntimas atmestas, nes aptikta trūkstamų formoje elementų'),
	(321, 'Vieno taško šaltinyje sukonfigūruoti keli apskaitos taškai', 'SRC_TMPL_MISM_SINGLE', 'Vieno taško šaltinyje sukonfigūruoti keli apskaitos taškai', 'Vieno taško šaltinyje sukonfigūruoti keli apskaitos taškai'),
	(322, 'Kelių taškų šaltiniui priskirtas vienas apskaitos taškas', 'SRC_TMPL_MISM_MULTI', 'Kelių taškų šaltiniui priskirtas vienas apskaitos taškas', 'Kelių taškų šaltiniui priskirtas vienas apskaitos taškas'),
	(323, '%1 %2 %3 %4', 'EV_REGISTRATION', '%1 %2 %3 %4', '%1 %2 %3 %4'),
	(324, 'Dalis duomenų nėra tinkami rašymui', 'SOME_RECORDS_NOT_FOUND', 'Dalis duomenų nėra tinkami rašymui', 'Dalis duomenų nėra tinkami rašymui'),
	(328, 'Pasikeitus skaitiklio paskutinio parametravimo data (%1): %2', 'METER_CONFIGURATION_DATE_UPDATED', 'Pasikeitus skaitiklio paskutinio parametravimo data', 'Pasikeitus skaitiklio paskutinio parametravimo data (%1): %2'),
	(329, 'Pasikeitus prietaiso paskutinio parametravimo data (%1): %2', 'DEVICE_CONFIGURATION_DATE_UPDATED', 'Pasikeitus prietaiso paskutinio parametravimo data', 'Pasikeitus prietaiso paskutinio parametravimo data (%1): %2'),
	(330, 'Nerastas nurodyto pavadinimo šaltinis', 'SRC_NOT_FOUND', 'Nerastas nurodyto pavadinimo šaltinis', 'Nerastas nurodyto pavadinimo šaltinis'),
	(331, 'Nerasti atitinkami nuskaitymo elementai', 'SDI_NOT_FOUND', 'Nerasti atitinkami nuskaitymo elementai', 'Nerasti atitinkami nuskaitymo elementai'),
	(332, 'Grupėje %1 yra keli apskaitos taškai su ekomoniniu profiliu %2', 'ECP_NOT_UNIQUE', 'Grupėje yra keli apskaitos taškai su ekomoniniu profiliu', 'Grupėje %1 yra keli apskaitos taškai su ekomoniniu profiliu %2'),
	(333, 'Nerastas nuskaitymo taškas, į kurį reikia pridėti šaltinį, susijusį su tašku %1', 'SRC_RULE_DP_NOT_FOUND', 'Nerastas nuskaitymo taškas, į kurį reikia pridėti šaltinį', 'Nerastas nuskaitymo taškas, į kurį reikia pridėti šaltinį, susijusį su tašku %1'),
	(334, 'Nerastas atitinkamas šaltinių šablonas taškui %1', 'SRC_RULE_SRC_TMPL_NOT_FOUND', 'Nerastas atitinkamas šaltinių šablonas', 'Nerastas atitinkamas šaltinių šablonas taškui %1'),
	(335, 'Taškui %1 jau sukurtas atitinkamas šaltinis', 'SRC_RULE_SRC_ALREADY_EXISTS', 'Taškui jau sukurtas atitinkamas šaltinis', 'Taškui %1 jau sukurtas atitinkamas šaltinis'),
	(336, 'Draudžiamas parametravimas: %1 "%2"', 'PARAMETRIZATION_NOT_ALLOWED', 'Draudžiamas parametravimas', 'Draudžiamas parametravimas: %1 "%2"'),
	(337, 'Generuoti duomenys', 'GENERATED_DATA', 'Generuoti duomenys', 'Generuoti duomenys'),
	(338, 'Importuoti duomenys', 'IMPORTED_DATA', 'Importuoti duomenys', 'Importuoti duomenys'),
	(339, 'Vartotojas %1 inicijavo skaitiklio relės nustatymą: %2', 'LOG.WRITE_POINT_RELAY', 'Vartotojas inicijavo skaitiklio relės nustatymą', 'Vartotojas %1 inicijavo skaitiklio relės nustatymą: %2'),
	(340, 'Vartotojas %1 inicijavo skaitiklio laiko nustatymą', 'LOG.WRITE_POINT_TIME', 'Vartotojas inicijavo skaitiklio laiko nustatymą', 'Vartotojas %1 inicijavo skaitiklio laiko nustatymą'),
	(341, 'Vartotojas %1 inicijavo skaitiklio laiko korekciją', 'LOG.WRITE_POINT_TIME_CORRECTION', 'Vartotojas inicijavo skaitiklio laiko korekciją', 'Vartotojas %1 inicijavo skaitiklio laiko korekciją'),
	(342, 'Vartotojas %1 inicijavo skaitiklio parametravimą', 'LOG.WRITE_POINT_CONFIGURATION', 'Vartotojas inicijavo skaitiklio parametravimą', 'Vartotojas %1 inicijavo skaitiklio parametravimą'),
	(343, 'Vartotojas %1 inicijavo kontrolerio laiko nustatymą', 'LOG.WRITE_DP_TIME', 'Vartotojas inicijavo kontrolerio laiko nustatymą', 'Vartotojas %1 inicijavo kontrolerio laiko nustatymą'),
	(344, 'Vartotojas %1 inicijavo kontrolerio laiko korekciją', 'LOG.WRITE_DP_TIME_CORRECTION', 'Vartotojas inicijavo kontrolerio laiko korekciją', 'Vartotojas %1 inicijavo kontrolerio laiko korekciją'),
	(345, 'Vartotojas %1 inicijavo kontrolerio parametravimą', 'LOG.WRITE_DP_CONFIGURATION', 'Vartotojas inicijavo kontrolerio parametravimą', 'Vartotojas %1 inicijavo kontrolerio parametravimą'),
	(346, 'Šablono taikymas šaltinių masyvui: ', 'SRC_FROM_TMPL_ARRAY', 'Šablono taikymas šaltinių masyvui', 'Šablono taikymas šaltinių masyvui: '),
	(347, 'Kol ryšio konfigūracija nesutikrinta pagal konfigūracinių parametrų duomenis, rodmenų nuskaitymas blokuojamas', 'BLOCK_PL', 'Kol ryšio konfigūracija nesutikrinta pagal konfigūracinių parametrų duomenis, rodmenų nuskaitymas blokuojamas', 'Kol ryšio konfigūracija nesutikrinta pagal konfigūracinių parametrų duomenis, rodmenų nuskaitymas blokuojamas'),
	(348, 'Vartotojas %1 pakrovė tekstinį failą intervalui %2, matavimui %3', 'LOG.WRITE_FIB', 'Vartotojas pakrovė tekstinį failą', 'Vartotojas %1 pakrovė tekstinį failą intervalui %2, matavimui %3'),
	(349, 'Aptikta daugiau nei viena importo forma (%1): "%2";"%3"', 'DUPLICATE_IMPORT_FORMS', 'Aptikta daugiau nei viena importo forma', 'Aptikta daugiau nei viena importo forma (%1): "%2";"%3"'),
	(350, 'Vartotojas %1 pakeitė šablono atnaujinimo modelį %2', 'SAM_TMPL_CHANGED', 'Vartotojas pakeitė šablono atnaujinimo modelį', 'Vartotojas %1 pakeitė šablono atnaujinimo modelį %2'),
	(351, 'Vartotojas %1 pakeitė šablono atnaujinimo modelio %2 skaičiavimo intervalą %3', 'SAM_TMPL_AI_CHANGED', 'Vartotojas pakeitė šablono atnaujinimo modelio skaičiavimo intervalą', 'Vartotojas %1 pakeitė šablono atnaujinimo modelio %2 skaičiavimo intervalą %3'),
	(352, 'Keitimas neleistinas dėl egzistuojančių susijusių šablonų įrašų', 'RELATED_SAM_FOUND', 'Keitimas neleistinas dėl egzistuojančių susijusių šablonų įrašų', 'Keitimas neleistinas dėl egzistuojančių susijusių šablonų įrašų'),
	(353, 'Skaitiklio konfigūracinių parametrų sutikrinimas nevykdomas dėl nepilnai nuskaityto skaitiklio žurnalo', 'INCOMPLETE_JOURNAL_METER_CONFIG_CHECK_DECLINED', 'Skaitiklio konfigūracinių parametrų sutikrinimas nevykdomas dėl nepilnai nuskaityto skaitiklio žurnalo', 'Skaitiklio konfigūracinių parametrų sutikrinimas nevykdomas dėl nepilnai nuskaityto skaitiklio žurnalo'),
	(354, 'Papildytas rodmuo', 'HAS_PL_CUSTOM', 'Papildytas rodmuo', 'Papildytas rodmuo'),
	(355, 'Daugiau nei %1 parametrų grupė', 'STA.MESSAGE_1', 'Daugiau nei kelių parametrų grupė', 'Daugiau nei %1 parametrų grupė'),
	(356, 'Nesutampa %2 "%3" (%5) ir "%4" prieaugis (%6) už %1', 'CP.CP_NOTE.S', 'Nesutampa suma už periodą ir suminių prieaugis', 'Nesutampa %2 "%3" (%5) ir "%4" prieaugis (%6) už %1'),
	(357, 'Neužpildyti %2 "%4" duomenys, todėl nežinomas prieaugis už %1', 'CP.CP_NOTE.T', 'Neužpildyti suminiai duomenys, todėl nežinomas prieaugis už periodą', 'Neužpildyti %2 "%4" duomenys, todėl nežinomas prieaugis už %1'),
	(358, 'Duomenų pakrovimo užsakymas %1 (%2) %3, pakeitimai negalimi', 'DMP.UPDATE', 'Duomenų pakrovimo užsakymo pakeitimai negalimi', 'Duomenų pakrovimo užsakymas %1 (%2) %3, pakeitimai negalimi'),
	(359, 'Duomenų pakrovimo užsakymas %1 nerastas', 'DMP.NORECORD', 'Duomenų pakrovimo užsakymas nerastas', 'Duomenų pakrovimo užsakymas %1 nerastas'),
	(360, 'Duomenų perkėlimas nutrauktas. Bandymas pakrauti %1 versijos failą į %2', 'DMP.VERSION', 'Duomenų perkėlimas nutrauktas. Bandymas kitos versijos failą', 'Duomenų perkėlimas nutrauktas. Bandymas pakrauti %1 versijos failą į %2'),
	(361, 'Duomenų perkėlimo klaida. Nepavyko įjungti išorinį raktą %1', 'DMP.CONSTRAINT', 'Duomenų perkėlimo klaida. Nepavyko įjungti išorinį raktą', 'Duomenų perkėlimo klaida. Nepavyko įjungti išorinį raktą %1'),
	(362, 'Duomenų perkėlimo klaida. Nepavyko įjungti trigerį %1', 'DMP.TRIGGER', 'Duomenų perkėlimo klaida. Nepavyko įjungti trigerį', 'Duomenų perkėlimo klaida. Nepavyko įjungti trigerį %1'),
	(363, 'Duomenų perkėlimo metu rasta %1 klaidų', 'DMP.ERRORS', 'Duomenų perkėlimo metu rasta klaidų', 'Duomenų perkėlimo metu rasta %1 klaidų'),
	(364, 'Duomenų perkėlimo klaida %1', 'DMP.ERROR', 'Duomenų perkėlimo klaida', 'Duomenų perkėlimo klaida %1'),
	(365, 'Pradėtas duomenų eksportas %1', 'DMP.EXPORT_START', 'Pradėtas duomenų eksportas', 'Pradėtas duomenų eksportas %1'),
	(366, 'Pradėtas duomenų importas iš failo %1', 'DMP.IMPORT_START', 'Pradėtas duomenų importas iš failo', 'Pradėtas duomenų importas iš failo %1'),
	(367, 'Duomenų perkėlimo pabaiga', 'DMP.FINISH', 'Duomenų perkėlimo pabaiga', 'Duomenų perkėlimo pabaiga'),
	(368, 'Duomenų pakrovimas atmestas', 'DMP.DENIED', 'Duomenų pakrovimas atmestas', 'Duomenų pakrovimas atmestas'),
	(369, 'Duomenys priimti. Duomenų pakrovimas sustabdytas', 'DMP.DELAYED', 'Duomenys priimti. Duomenų pakrovimas sustabdytas', 'Duomenys priimti. Duomenų pakrovimas sustabdytas'),
	(370, 'Eksportas nutrauktas. Duomenų perkėlimo užsakymo statusas turi būti Suformuotas', 'DMP.WRONG_STATUS', 'Eksportas nutrauktas. Duomenų perkėlimo užsakymo statusas turi būti Suformuotas', 'Eksportas nutrauktas. Duomenų perkėlimo užsakymo statusas turi būti Suformuotas'),
	(371, 'Apskaitos būsenų signalų šaltinio elementai', 'SE_DS', 'Apskaitos būsenų signalų šaltinio elementai', 'Apskaitos būsenų signalų šaltinio elementai'),
	(372, 'Apskaitos būsenų signalų šaltinio elementų savybės', 'SE_DS_LPTY', 'Apskaitos būsenų signalų šaltinio elementų savybės', 'Apskaitos būsenų signalų šaltinio elementų savybės'),
	(373, 'Apskaitos būsenų signalų šaltinio elementai, pasiekiami per ryšio kanalą', 'SEP_DS', 'Apskaitos būsenų signalų šaltinio elementai, pasiekiami per ryšio kanalą', 'Apskaitos būsenų signalų šaltinio elementai, pasiekiami per ryšio kanalą'),
	(374, 'Pasiekiamų per ryšio kanalą apskaitos būsenų signalų šaltinių elementų konfigūracija pagal nuskaitymo priežastį', 'SEP_DS_RC', 'Pasiekiamų per ryšio kanalą apskaitos būsenų signalų šaltinių elementų konfigūracija pagal nuskaitymo priežastį', 'Pasiekiamų per ryšio kanalą apskaitos būsenų signalų šaltinių elementų konfigūracija pagal nuskaitymo priežastį'),
	(1001, 'Akto aprašymas: %1', 'AUD.ACT_DESC', 'Akto aprašymas: %1', 'Akto aprašymas: %1'),
	(1002, 'Akto galiojimo požymis: %1', 'AUD.ACT_ENABLED', 'Akto galiojimo požymis: %1', 'Akto galiojimo požymis: %1'),
	(1003, 'Akto identifikatorius: %1', 'AUD.ACT_ID', 'Akto identifikatorius: %1', 'Akto identifikatorius: %1'),
	(1004, 'Mėnuo, kurio duomenys aktuojami: %1', 'AUD.ACT_MONTH', 'Mėnuo, kurio duomenys aktuojami: %1', 'Mėnuo, kurio duomenys aktuojami: %1'),
	(1005, 'Akto numeris: %1', 'AUD.ACT_NUMBER', 'Akto numeris: %1', 'Akto numeris: %1'),
	(1006, 'Aktų tipo identifikatorius: %1', 'AUD.ACT_TYPE_ID', 'Aktų tipo identifikatorius: %1', 'Aktų tipo identifikatorius: %1'),
	(1007, 'Aktų tipo pavadinimas: %1', 'AUD.ACT_TYPE_NAME', 'Aktų tipo pavadinimas: %1', 'Aktų tipo pavadinimas: %1'),
	(1008, 'Akto reikšmė: %1', 'AUD.ACT_VALUE', 'Akto reikšmė: %1', 'Akto reikšmė: %1'),
	(1009, 'Agregavimo funkcijos identifikatorius: %1', 'AUD.AGGF_ID', 'Agregavimo funkcijos identifikatorius: %1', 'Agregavimo funkcijos identifikatorius: %1'),
	(1010, 'Agregavimo segmento identifikatorius: %1', 'AUD.AGGS_ID', 'Agregavimo segmento identifikatorius: %1', 'Agregavimo segmento identifikatorius: %1'),
	(1011, 'Agregavimo segmento tipo identifikatorius: %1', 'AUD.AGGS_TYPE_ID', 'Agregavimo segmento tipo identifikatorius: %1', 'Agregavimo segmento tipo identifikatorius: %1'),
	(1012, 'Grupių prieigos lygio kodas: %1', 'AUD.ALGR_CODE', 'Grupių prieigos lygio kodas: %1', 'Grupių prieigos lygio kodas: %1'),
	(1013, 'Grupių prieigos lygio identifikatorius: %1', 'AUD.ALGR_ID', 'Grupių prieigos lygio identifikatorius: %1', 'Grupių prieigos lygio identifikatorius: %1'),
	(1014, 'Prieigos lygis (0-peržiūra,1-redagavimas): %1', 'AUD.AL_ID', 'Prieigos lygis (0-peržiūra,1-redagavimas): %1', 'Prieigos lygis (0-peržiūra,1-redagavimas): %1'),
	(1015, 'Periodo pradžios diena: %1', 'AUD.BDD', 'Periodo pradžios diena: %1', 'Periodo pradžios diena: %1'),
	(1016, 'DB aplikacijos foninių užduočių klasės kodas: %1', 'AUD.BGA_CLASS_CODE', 'DB aplikacijos foninių užduočių klasės kodas: %1', 'DB aplikacijos foninių užduočių klasės kodas: %1'),
	(1017, 'DB aplikacijos foninių užduočių klasės ID: %1', 'AUD.BGA_CLASS_ID', 'DB aplikacijos foninių užduočių klasės ID: %1', 'DB aplikacijos foninių užduočių klasės ID: %1'),
	(1018, 'DB aplikacijos foninių užduočių klasės pavadinimas: %1', 'AUD.BGA_CLASS_NAME', 'DB aplikacijos foninių užduočių klasės pavadinimas: %1', 'DB aplikacijos foninių užduočių klasės pavadinimas: %1'),
	(1019, 'DB aplikacijos foninės užduoties naudojimo požymis: %1', 'AUD.BGA_ENABLED', 'DB aplikacijos foninės užduoties naudojimo požymis: %1', 'DB aplikacijos foninės užduoties naudojimo požymis: %1'),
	(1020, 'DB aplikacijos foninės užduoties ID: %1', 'AUD.BGA_ID', 'DB aplikacijos foninės užduoties ID: %1', 'DB aplikacijos foninės užduoties ID: %1'),
	(1021, 'DB aplikacijos foninės užduoties pavadinimas: %1', 'AUD.BGA_NAME', 'DB aplikacijos foninės užduoties pavadinimas: %1', 'DB aplikacijos foninės užduoties pavadinimas: %1'),
	(1022, 'DB aplikacijos foninės užduoties parametro numeris: %1', 'AUD.BGA_PARAM_NR', 'DB aplikacijos foninės užduoties parametro numeris: %1', 'DB aplikacijos foninės užduoties parametro numeris: %1'),
	(1023, 'DB aplikacijos foninės užduoties parametro reikšmė: %1', 'AUD.BGA_PARAM_VALUE', 'DB aplikacijos foninės užduoties parametro reikšmė: %1', 'DB aplikacijos foninės užduoties parametro reikšmė: %1'),
	(1024, 'DB aplikacijos foninės užduoties parametro reikšmės aprašymas: %1', 'AUD.BGA_PARAM_VALUE_DESC', 'DB aplikacijos foninės užduoties parametro reikšmės aprašymas: %1', 'DB aplikacijos foninės užduoties parametro reikšmės aprašymas: %1'),
	(1025, 'DB aplikacijos foninių užduočių tipo kodas: %1', 'AUD.BGA_TYPE_CODE', 'DB aplikacijos foninių užduočių tipo kodas: %1', 'DB aplikacijos foninių užduočių tipo kodas: %1'),
	(1026, 'SQL bloko DECLARE dalis: %1', 'AUD.BGA_TYPE_DECLARE', 'SQL bloko DECLARE dalis: %1', 'SQL bloko DECLARE dalis: %1'),
	(1027, 'DB aplikacijos foninių užduočių tipo aprašymas: %1', 'AUD.BGA_TYPE_DESC', 'DB aplikacijos foninių užduočių tipo aprašymas: %1', 'DB aplikacijos foninių užduočių tipo aprašymas: %1'),
	(1028, 'DB aplikacijos foninių užduočių tipo ID: %1', 'AUD.BGA_TYPE_ID', 'DB aplikacijos foninių užduočių tipo ID: %1', 'DB aplikacijos foninių užduočių tipo ID: %1'),
	(1029, 'DB aplikacijos foninių užduočių tipo pavadinimas: %1', 'AUD.BGA_TYPE_NAME', 'DB aplikacijos foninių užduočių tipo pavadinimas: %1', 'DB aplikacijos foninių užduočių tipo pavadinimas: %1'),
	(1030, 'DB aplikacijos foninių užduočių tipo parametro aprašymas: %1', 'AUD.BGA_TYPE_PARAM_DESC', 'DB aplikacijos foninių užduočių tipo parametro aprašymas: %1', 'DB aplikacijos foninių užduočių tipo parametro aprašymas: %1'),
	(1031, 'DB aplikacijos foninių užduočių tipo parametro kodinis pavadinimas: %1', 'AUD.BGA_TYPE_PARAM_KEY', 'DB aplikacijos foninių užduočių tipo parametro kodinis pavadinimas: %1', 'DB aplikacijos foninių užduočių tipo parametro kodinis pavadinimas: %1'),
	(1032, 'DB aplikacijos foninių užduočių tipo parametro numeris: %1', 'AUD.BGA_TYPE_PARAM_NR', 'DB aplikacijos foninių užduočių tipo parametro numeris: %1', 'DB aplikacijos foninių užduočių tipo parametro numeris: %1'),
	(1033, 'DB aplikacijos foninių užduočių tipo įprastinio parametro požymis: %1', 'AUD.BGA_TYPE_PARAM_REGULAR', 'DB aplikacijos foninių užduočių tipo įprastinio parametro požymis: %1', 'DB aplikacijos foninių užduočių tipo įprastinio parametro požymis: %1'),
	(1034, 'SQL bloko pabaiga: %1', 'AUD.BGA_TYPE_POST_ACTION', 'SQL bloko pabaiga: %1', 'SQL bloko pabaiga: %1'),
	(1035, 'SQL bloko pradžia: %1', 'AUD.BGA_TYPE_PRE_ACTION', 'SQL bloko pradžia: %1', 'SQL bloko pradžia: %1'),
	(1036, 'SQL bloko iteracijos dalis: %1', 'AUD.BGA_TYPE_REC_ACTION', 'SQL bloko iteracijos dalis: %1', 'SQL bloko iteracijos dalis: %1'),
	(1037, 'Iteruojama SQL užklausa: %1', 'AUD.BGA_TYPE_SELECT', 'Iteruojama SQL užklausa: %1', 'Iteruojama SQL užklausa: %1'),
	(1038, 'Tarifo veikimo pradžia valandomis: %1', 'AUD.BHH', 'Tarifo veikimo pradžia valandomis: %1', 'Tarifo veikimo pradžia valandomis: %1'),
	(1039, 'Periodo pradžios mėnuo: %1', 'AUD.BMM', 'Periodo pradžios mėnuo: %1', 'Periodo pradžios mėnuo: %1'),
	(1040, 'Periodo pradžia: %1', 'AUD.BT', 'Periodo pradžia: %1', 'Periodo pradžia: %1'),
	(1041, 'Priešingos krypties matavimų naudojimo apeinamajame taške požymis: %1', 'AUD.BYP_DIR_INV', 'Priešingos krypties matavimų naudojimo apeinamajame taške požymis: %1', 'Priešingos krypties matavimų naudojimo apeinamajame taške požymis: %1'),
	(1042, 'Apėjimo naudojimo požymis: %1', 'AUD.BYP_ENABLED', 'Apėjimo naudojimo požymis: %1', 'Apėjimo naudojimo požymis: %1'),
	(1043, 'Požymis, ar naudojama invertuota signalo reikšmė apėjimo būsenai nustatyti: %1', 'AUD.BYP_INV', 'Požymis, ar naudojama invertuota signalo reikšmė apėjimo būsenai nustatyti: %1', 'Požymis, ar naudojama invertuota signalo reikšmė apėjimo būsenai nustatyti: %1'),
	(1044, 'Pagrindinio taško duomenų naudojimo ir apeinamojo taško naudojimo periodo dengiamuose intervaluose požymis: %1', 'AUD.BYP_MODE', 'Pagrindinio taško duomenų naudojimo ir apeinamojo taško naudojimo periodo dengiamuose intervaluose požymis: %1', 'Pagrindinio taško duomenų naudojimo ir apeinamojo taško naudojimo periodo dengiamuose intervaluose požymis: %1'),
	(1045, 'Apėjimui naudojamo matavimo taško identifikatorius: %1', 'AUD.BYP_POINT_ID', 'Apėjimui naudojamo matavimo taško identifikatorius: %1', 'Apėjimui naudojamo matavimo taško identifikatorius: %1'),
	(1046, 'Pranešimo kodas: %1', 'AUD.CAP_CODE', 'Pranešimo kodas: %1', 'Pranešimo kodas: %1'),
	(1047, 'Pranešimo identifikatorius: %1', 'AUD.CAP_ID', 'Pranešimo identifikatorius: %1', 'Pranešimo identifikatorius: %1'),
	(1048, 'Pranešimo pavadinimas: %1', 'AUD.CAP_NAME', 'Pranešimo pavadinimas: %1', 'Pranešimo pavadinimas: %1'),
	(1049, 'Pranešimo parametro apibūdinimas: %1', 'AUD.CAP_PARAM_DESC', 'Pranešimo parametro apibūdinimas: %1', 'Pranešimo parametro apibūdinimas: %1'),
	(1050, 'Pranešimo parametro numeris: %1', 'AUD.CAP_PARAM_NR', 'Pranešimo parametro numeris: %1', 'Pranešimo parametro numeris: %1'),
	(1051, 'Pranešimo tekstas: %1', 'AUD.CAP_TEXT', 'Pranešimo tekstas: %1', 'Pranešimo tekstas: %1'),
	(1052, 'Pranešimo tekstas pagal nutylėjimą: %1', 'AUD.CAP_TEXT_DEFAULT', 'Pranešimo tekstas pagal nutylėjimą: %1', 'Pranešimo tekstas pagal nutylėjimą: %1'),
	(1053, 'Įvykių atvejų kiekio tikrinimo požymis: %1', 'AUD.CH_CNT', 'Įvykių atvejų kiekio tikrinimo požymis: %1', 'Įvykių atvejų kiekio tikrinimo požymis: %1'),
	(1054, 'Susijusių nuskaitymo taškų kiekio tikrinimo požymis: %1', 'AUD.CH_DPT', 'Susijusių nuskaitymo taškų kiekio tikrinimo požymis: %1', 'Susijusių nuskaitymo taškų kiekio tikrinimo požymis: %1'),
	(1055, 'Susijusių apskaitos būsenų signalų kiekio tikrinimo požymis: %1', 'AUD.CH_DSC', 'Susijusių apskaitos būsenų signalų kiekio tikrinimo požymis: %1', 'Susijusių apskaitos būsenų signalų kiekio tikrinimo požymis: %1'),
	(1056, 'Susijusių grupių kiekio tikrinimo požymis: %1', 'AUD.CH_GRP', 'Susijusių grupių kiekio tikrinimo požymis: %1', 'Susijusių grupių kiekio tikrinimo požymis: %1'),
	(1057, 'Susijusių apskaitos taškų kiekio tikrinimo požymis: %1', 'AUD.CH_PNT', 'Susijusių apskaitos taškų kiekio tikrinimo požymis: %1', 'Susijusių apskaitos taškų kiekio tikrinimo požymis: %1'),
	(1058, 'Požymis, ar siųsti pranešimą tik nusistovėjus būsenai: %1', 'AUD.CH_STEADY', 'Požymis, ar siųsti pranešimą tik nusistovėjus būsenai: %1', 'Požymis, ar siųsti pranešimą tik nusistovėjus būsenai: %1'),
	(1059, 'Koeficientas: %1', 'AUD.COEF', 'Koeficientas: %1', 'Koeficientas: %1'),
	(1060, 'Lentelės laukas: %1', 'AUD.COLUMN_NAME', 'Lentelės laukas: %1', 'Lentelės laukas: %1'),
	(1061, 'Grupės-komponento matavimo krypties identifikatorius: %1', 'AUD.COMP_DIR_ID', 'Grupės-komponento matavimo krypties identifikatorius: %1', 'Grupės-komponento matavimo krypties identifikatorius: %1'),
	(1062, 'Grupės-komponento ekonominės kategorijos identifikatorius: %1', 'AUD.COMP_EC_ID', 'Grupės-komponento ekonominės kategorijos identifikatorius: %1', 'Grupės-komponento ekonominės kategorijos identifikatorius: %1'),
	(1063, 'Grupės-komponento identifikatorius: %1', 'AUD.COMP_ID', 'Grupės-komponento identifikatorius: %1', 'Grupės-komponento identifikatorius: %1'),
	(1064, 'Grupės-komponento matavimo identifikatorius: %1', 'AUD.COMP_MS_ID', 'Grupės-komponento matavimo identifikatorius: %1', 'Grupės-komponento matavimo identifikatorius: %1'),
	(1065, 'Pastovi reikšmė: %1', 'AUD.CONST_VAL', 'Pastovi reikšmė: %1', 'Pastovi reikšmė: %1'),
	(1066, 'Grupės-konteinerio matavimo krypties identifikatorius: %1', 'AUD.CONT_DIR_ID', 'Grupės-konteinerio matavimo krypties identifikatorius: %1', 'Grupės-konteinerio matavimo krypties identifikatorius: %1'),
	(1067, 'Grupės-konteinerio ekonominės kategorijos identifikatorius: %1', 'AUD.CONT_EC_ID', 'Grupės-konteinerio ekonominės kategorijos identifikatorius: %1', 'Grupės-konteinerio ekonominės kategorijos identifikatorius: %1'),
	(1068, 'Grupės-konteinerio identifikatorius: %1', 'AUD.CONT_ID', 'Grupės-konteinerio identifikatorius: %1', 'Grupės-konteinerio identifikatorius: %1'),
	(1069, 'Grupės-konteinerio matavimo identifikatorius: %1', 'AUD.CONT_MS_ID', 'Grupės-konteinerio matavimo identifikatorius: %1', 'Grupės-konteinerio matavimo identifikatorius: %1'),
	(1070, 'Ryšio būsenos kodas: %1', 'AUD.COSTA_CODE', 'Ryšio būsenos kodas: %1', 'Ryšio būsenos kodas: %1'),
	(1071, 'Ryšio būsenos ID: %1', 'AUD.COSTA_ID', 'Ryšio būsenos ID: %1', 'Ryšio būsenos ID: %1'),
	(1072, 'Tekstinė reikšmė: %1', 'AUD.CVAL', 'Tekstinė reikšmė: %1', 'Tekstinė reikšmė: %1'),
	(1073, 'Duomenų tipas: %1', 'AUD.DATA_TYPE', 'Duomenų tipas: %1', 'Duomenų tipas: %1'),
	(1074, 'Dienos komentaras: %1', 'AUD.DA_DESC', 'Dienos komentaras: %1', 'Dienos komentaras: %1'),
	(1075, 'Sistemos vartotojo DB vartotojo vardas: %1', 'AUD.DBU', 'Sistemos vartotojo DB vartotojo vardas: %1', 'Sistemos vartotojo DB vartotojo vardas: %1'),
	(1076, 'Registravimo duomenų bazėje laikas: %1', 'AUD.DB_TIME', 'Registravimo duomenų bazėje laikas: %1', 'Registravimo duomenų bazėje laikas: %1'),
	(1077, 'Dinaminio monitoringo šablonų atnaujinimo galiojimo požymis: %1', 'AUD.DC_ENABLED', 'Dinaminio monitoringo šablonų atnaujinimo galiojimo požymis: %1', 'Dinaminio monitoringo šablonų atnaujinimo galiojimo požymis: %1'),
	(1078, 'Sprendimo identifikatorius: %1', 'AUD.DC_ID', 'Sprendimo identifikatorius: %1', 'Sprendimo identifikatorius: %1'),
	(1079, 'Sprendimo pavadinimas: %1', 'AUD.DC_NAME', 'Sprendimo pavadinimas: %1', 'Sprendimo pavadinimas: %1'),
	(1080, 'Dienos numeris: %1', 'AUD.DD', 'Dienos numeris: %1', 'Dienos numeris: %1'),
	(1081, 'Koncentratoriaus periodo duomenų nuskaitymo taške identifikatorius: %1', 'AUD.DEVDP_ID', 'Koncentratoriaus periodo duomenų nuskaitymo taške identifikatorius: %1', 'Koncentratoriaus periodo duomenų nuskaitymo taške identifikatorius: %1'),
	(1082, 'Duomenų koncentratoriaus periodo pradžia duomenų nuskaitymo taške: %1', 'AUD.DEV_DP_BT', 'Duomenų koncentratoriaus periodo pradžia duomenų nuskaitymo taške: %1', 'Duomenų koncentratoriaus periodo pradžia duomenų nuskaitymo taške: %1'),
	(1083, 'Duomenų koncentratoriaus periodo pabaiga duomenų nuskaitymo taške: %1', 'AUD.DEV_DP_ET', 'Duomenų koncentratoriaus periodo pabaiga duomenų nuskaitymo taške: %1', 'Duomenų koncentratoriaus periodo pabaiga duomenų nuskaitymo taške: %1'),
	(1084, 'Duomenų koncentratoriaus identifikatorius: %1', 'AUD.DEV_ID', 'Duomenų koncentratoriaus identifikatorius: %1', 'Duomenų koncentratoriaus identifikatorius: %1'),
	(1085, 'Duomenų koncentratoriaus numeris: %1', 'AUD.DEV_NUMBER', 'Duomenų koncentratoriaus numeris: %1', 'Duomenų koncentratoriaus numeris: %1'),
	(1086, 'Duomenų koncentratoriaus tipo identifikatorius: %1', 'AUD.DEV_TYPE_ID', 'Duomenų koncentratoriaus tipo identifikatorius: %1', 'Duomenų koncentratoriaus tipo identifikatorius: %1'),
	(1087, 'Duomenų koncentratoriaus tipo pavadinimas: %1', 'AUD.DEV_TYPE_NAME', 'Duomenų koncentratoriaus tipo pavadinimas: %1', 'Duomenų koncentratoriaus tipo pavadinimas: %1'),
	(1088, 'Krypties kodas: %1', 'AUD.DIR_CODE', 'Krypties kodas: %1', 'Krypties kodas: %1'),
	(1089, 'Krypties identifikatorius: %1', 'AUD.DIR_ID', 'Krypties identifikatorius: %1', 'Krypties identifikatorius: %1'),
	(1090, 'Nuskaitymo požymis: %1', 'AUD.DI_ENABLED', 'Nuskaitymo požymis: %1', 'Nuskaitymo požymis: %1'),
	(1091, 'Nuskaitomų duomenų elemento identifikatorius: %1', 'AUD.DI_ID', 'Nuskaitomų duomenų elemento identifikatorius: %1', 'Nuskaitomų duomenų elemento identifikatorius: %1'),
	(1092, 'Duomenų išdėstymo tipo identifikatorius: %1', 'AUD.DL_TYPE_ID', 'Duomenų išdėstymo tipo identifikatorius: %1', 'Duomenų išdėstymo tipo identifikatorius: %1'),
	(1093, 'Duomenų išsidėstymo tipo pavadinimas: %1', 'AUD.DL_TYPE_NAME', 'Duomenų išsidėstymo tipo pavadinimas: %1', 'Duomenų išsidėstymo tipo pavadinimas: %1'),
	(1094, 'Tarifų plano dienų programos identifikatorius: %1', 'AUD.DPR_ID', 'Tarifų plano dienų programos identifikatorius: %1', 'Tarifų plano dienų programos identifikatorius: %1'),
	(1095, 'Tarifų plano dienų programos pavadinimas: %1', 'AUD.DPR_NAME', 'Tarifų plano dienų programos pavadinimas: %1', 'Tarifų plano dienų programos pavadinimas: %1'),
	(1096, 'Duomenų nuskaitymo taško kodas: %1', 'AUD.DP_CODE', 'Duomenų nuskaitymo taško kodas: %1', 'Duomenų nuskaitymo taško kodas: %1'),
	(1097, 'Ištrinto nuskaitymo taško požymis: %1', 'AUD.DP_DELETED', 'Ištrinto nuskaitymo taško požymis: %1', 'Ištrinto nuskaitymo taško požymis: %1'),
	(1098, 'Nuskaitymo taško naudojimo požymis: %1', 'AUD.DP_ENABLED', 'Nuskaitymo taško naudojimo požymis: %1', 'Nuskaitymo taško naudojimo požymis: %1'),
	(1099, 'Duomenų nuskaitymo taško identifikatorius: %1', 'AUD.DP_ID', 'Duomenų nuskaitymo taško identifikatorius: %1', 'Duomenų nuskaitymo taško identifikatorius: %1'),
	(1100, 'Duomenų nuskaitymo taško pavadinimas: %1', 'AUD.DP_NAME', 'Duomenų nuskaitymo taško pavadinimas: %1', 'Duomenų nuskaitymo taško pavadinimas: %1'),
	(1101, 'Duomenų nuskaitymo taškų tipo identifikatorius: %1', 'AUD.DP_TYPE_ID', 'Duomenų nuskaitymo taškų tipo identifikatorius: %1', 'Duomenų nuskaitymo taškų tipo identifikatorius: %1'),
	(1102, 'Duomenų nuskaitymo taškų tipo pavadinimas: %1', 'AUD.DP_TYPE_NAME', 'Duomenų nuskaitymo taškų tipo pavadinimas: %1', 'Duomenų nuskaitymo taškų tipo pavadinimas: %1'),
	(1103, 'Apskaitos būsenų signalo kodas: %1', 'AUD.DS_CODE', 'Apskaitos būsenų signalo kodas: %1', 'Apskaitos būsenų signalo kodas: %1'),
	(1104, 'Apskaitos būsenos signalo naudojimo požymis: %1', 'AUD.DS_ENABLED', 'Apskaitos būsenos signalo naudojimo požymis: %1', 'Apskaitos būsenos signalo naudojimo požymis: %1'),
	(1105, 'Apskaitos būsenos signalo pasikeitimų registravimo įvykių registre požymis: %1', 'AUD.DS_EVENT_LOG', 'Apskaitos būsenos signalo pasikeitimų registravimo įvykių registre požymis: %1', 'Apskaitos būsenos signalo pasikeitimų registravimo įvykių registre požymis: %1'),
	(1106, 'Apskaitos būsenos signalo identifikatorius: %1', 'AUD.DS_ID', 'Apskaitos būsenos signalo identifikatorius: %1', 'Apskaitos būsenos signalo identifikatorius: %1'),
	(1107, 'Požymis, ar duomenys ignoruojami: %1', 'AUD.DS_IGNORED', 'Požymis, ar duomenys ignoruojami: %1', 'Požymis, ar duomenys ignoruojami: %1'),
	(1108, 'Apskaitos būsenos signalo pavadinimas: %1', 'AUD.DS_NAME', 'Apskaitos būsenos signalo pavadinimas: %1', 'Apskaitos būsenos signalo pavadinimas: %1'),
	(1109, 'Apskaitos būsenos duomenų nuskaitymo UTC laikas: %1', 'AUD.DS_RT', 'Apskaitos būsenos duomenų nuskaitymo UTC laikas: %1', 'Apskaitos būsenos duomenų nuskaitymo UTC laikas: %1'),
	(1110, 'Apskaitos būsenos signalo naudojimo realaus laiko mnemoschemose požymis: %1', 'AUD.DS_RT_ENABLED', 'Apskaitos būsenos signalo naudojimo realaus laiko mnemoschemose požymis: %1', 'Apskaitos būsenos signalo naudojimo realaus laiko mnemoschemose požymis: %1'),
	(1111, 'Apskaitos būsenos duomenų UTC laikas: %1', 'AUD.DS_T', 'Apskaitos būsenos duomenų UTC laikas: %1', 'Apskaitos būsenos duomenų UTC laikas: %1'),
	(1112, 'Apskaitos būsenos reikšmė: %1', 'AUD.DS_V', 'Apskaitos būsenos reikšmė: %1', 'Apskaitos būsenos reikšmė: %1'),
	(1113, 'Intervalo, per kurį skaičiuojamas įvykių atvejų kiekis, trukmė, min: %1', 'AUD.DU_CNT', 'Intervalo, per kurį skaičiuojamas įvykių atvejų kiekis, trukmė, min: %1', 'Intervalo, per kurį skaičiuojamas įvykių atvejų kiekis, trukmė, min: %1'),
	(1114, 'Intervalo, per kurį skaičiuojamas susijusių nuskaitymo taškų kiekis, trukmė, min: %1', 'AUD.DU_DPT', 'Intervalo, per kurį skaičiuojamas susijusių nuskaitymo taškų kiekis, trukmė, min: %1', 'Intervalo, per kurį skaičiuojamas susijusių nuskaitymo taškų kiekis, trukmė, min: %1'),
	(1115, 'Intervalo, per kurį skaičiuojamas susijusių apskaitos būsenų signalų kiekis, trukmė, min: %1', 'AUD.DU_DSC', 'Intervalo, per kurį skaičiuojamas susijusių apskaitos būsenų signalų kiekis, trukmė, min: %1', 'Intervalo, per kurį skaičiuojamas susijusių apskaitos būsenų signalų kiekis, trukmė, min: %1'),
	(1116, 'Intervalo, per kurį skaičiuojamas susijusių grupių kiekis, trukmė, min: %1', 'AUD.DU_GRP', 'Intervalo, per kurį skaičiuojamas susijusių grupių kiekis, trukmė, min: %1', 'Intervalo, per kurį skaičiuojamas susijusių grupių kiekis, trukmė, min: %1'),
	(1117, 'Intervalo, per kurį skaičiuojamas susijusių apskaitos taškų kiekis, trukmė, min: %1', 'AUD.DU_PNT', 'Intervalo, per kurį skaičiuojamas susijusių apskaitos taškų kiekis, trukmė, min: %1', 'Intervalo, per kurį skaičiuojamas susijusių apskaitos taškų kiekis, trukmė, min: %1'),
	(1118, 'Būsenos nusistovėjimo trukmė, min: %1', 'AUD.DU_STEADY', 'Būsenos nusistovėjimo trukmė, min: %1', 'Būsenos nusistovėjimo trukmė, min: %1'),
	(1119, 'Taško ekonominio profilio kodas: %1', 'AUD.ECP_CODE', 'Taško ekonominio profilio kodas: %1', 'Taško ekonominio profilio kodas: %1'),
	(1120, 'Taško ekonominio profilio identifikatorius: %1', 'AUD.ECP_ID', 'Taško ekonominio profilio identifikatorius: %1', 'Taško ekonominio profilio identifikatorius: %1'),
	(1121, 'Taško ekonominio profilio pavadinimas: %1', 'AUD.ECP_NAME', 'Taško ekonominio profilio pavadinimas: %1', 'Taško ekonominio profilio pavadinimas: %1'),
	(1122, 'Ekonominės kategorijos kodas: %1', 'AUD.EC_CODE', 'Ekonominės kategorijos kodas: %1', 'Ekonominės kategorijos kodas: %1'),
	(1123, 'Ekonominės kategorijos identifikatorius: %1', 'AUD.EC_ID', 'Ekonominės kategorijos identifikatorius: %1', 'Ekonominės kategorijos identifikatorius: %1'),
	(1124, 'Ekonominės kategorijos pajamų/išlaidų požymis: %1', 'AUD.EC_IN', 'Ekonominės kategorijos pajamų/išlaidų požymis: %1', 'Ekonominės kategorijos pajamų/išlaidų požymis: %1'),
	(1125, 'Ekonominės kategorijos pavadinimas: %1', 'AUD.EC_NAME', 'Ekonominės kategorijos pavadinimas: %1', 'Ekonominės kategorijos pavadinimas: %1'),
	(1126, 'Pabaigos diena: %1', 'AUD.EDD', 'Pabaigos diena: %1', 'Pabaigos diena: %1'),
	(1127, 'Tarifo veikimo pabaiga valandomis: %1', 'AUD.EHH', 'Tarifo veikimo pabaiga valandomis: %1', 'Tarifo veikimo pabaiga valandomis: %1'),
	(1128, 'Tarifų plano neatitikimų tarifo identifikatorius: %1', 'AUD.ELSE_TFF_ID', 'Tarifų plano neatitikimų tarifo identifikatorius: %1', 'Tarifų plano neatitikimų tarifo identifikatorius: %1'),
	(1129, 'Pabaigos mėnuo: %1', 'AUD.EMM', 'Pabaigos mėnuo: %1', 'Pabaigos mėnuo: %1'),
	(1130, 'Išvardinimo kodas: %1', 'AUD.ENUM_CODE', 'Išvardinimo kodas: %1', 'Išvardinimo kodas: %1'),
	(1131, 'Išvardinimo reikšmės eilės numeris rušiavimui: %1', 'AUD.ENUM_DATA_NR', 'Išvardinimo reikšmės eilės numeris rušiavimui: %1', 'Išvardinimo reikšmės eilės numeris rušiavimui: %1'),
	(1132, 'Išvardinimo identifikatorius: %1', 'AUD.ENUM_ID', 'Išvardinimo identifikatorius: %1', 'Išvardinimo identifikatorius: %1'),
	(1133, 'Išvardinimo pavadinimas: %1', 'AUD.ENUM_NAME', 'Išvardinimo pavadinimas: %1', 'Išvardinimo pavadinimas: %1'),
	(1134, 'Išvardinimų naudojimo tipo kodas: %1', 'AUD.ENUM_TYPE_CODE', 'Išvardinimų naudojimo tipo kodas: %1', 'Išvardinimų naudojimo tipo kodas: %1'),
	(1135, 'Išvardinimų naudojimo tipo ID: %1', 'AUD.ENUM_TYPE_ID', 'Išvardinimų naudojimo tipo ID: %1', 'Išvardinimų naudojimo tipo ID: %1'),
	(1136, 'Išvardinimų naudojimo tipo pavadinimas: %1', 'AUD.ENUM_TYPE_NAME', 'Išvardinimų naudojimo tipo pavadinimas: %1', 'Išvardinimų naudojimo tipo pavadinimas: %1'),
	(1137, 'Išvardinimo reikšmė: %1', 'AUD.ENUM_VALUE', 'Išvardinimo reikšmė: %1', 'Išvardinimo reikšmė: %1'),
	(1138, 'Išvardinimo reikšmės aprašymas: %1', 'AUD.ENUM_VALUE_DESC', 'Išvardinimo reikšmės aprašymas: %1', 'Išvardinimo reikšmės aprašymas: %1'),
	(1139, 'Sąryšių savybės kodas: %1', 'AUD.EPTY_CODE', 'Sąryšių savybės kodas: %1', 'Sąryšių savybės kodas: %1'),
	(1140, 'Sąryšių savybės identifikatorius: %1', 'AUD.EPTY_ID', 'Sąryšių savybės identifikatorius: %1', 'Sąryšių savybės identifikatorius: %1'),
	(1141, 'Sąryšių savybės pavadinimas: %1', 'AUD.EPTY_NAME', 'Sąryšių savybės pavadinimas: %1', 'Sąryšių savybės pavadinimas: %1'),
	(1142, 'Sąryšių savybės eilės numeris: %1', 'AUD.EPTY_NR', 'Sąryšių savybės eilės numeris: %1', 'Sąryšių savybės eilės numeris: %1'),
	(1143, 'Požymis, ar sąryšio savybės reikšmė turi būti skaitmeninė: %1', 'AUD.EPTY_NUMERIC', 'Požymis, ar sąryšio savybės reikšmė turi būti skaitmeninė: %1', 'Požymis, ar sąryšio savybės reikšmė turi būti skaitmeninė: %1'),
	(1144, 'Sąryšių savybių tipo kodas: %1', 'AUD.EPTY_TYPE_CODE', 'Sąryšių savybių tipo kodas: %1', 'Sąryšių savybių tipo kodas: %1'),
	(1145, 'Sąryšių savybių tipo identifikatorius: %1', 'AUD.EPTY_TYPE_ID', 'Sąryšių savybių tipo identifikatorius: %1', 'Sąryšių savybių tipo identifikatorius: %1'),
	(1146, 'Sąryšių savybių tipo pavadinimas: %1', 'AUD.EPTY_TYPE_NAME', 'Sąryšių savybių tipo pavadinimas: %1', 'Sąryšių savybių tipo pavadinimas: %1'),
	(1147, 'Sąryšio savybės reikšmė: %1', 'AUD.EPTY_VALUE', 'Sąryšio savybės reikšmė: %1', 'Sąryšio savybės reikšmė: %1'),
	(1148, 'Periodo pabaiga: %1', 'AUD.ET', 'Periodo pabaiga: %1', 'Periodo pabaiga: %1'),
	(1149, 'Įvykių atvejo sąlygos invertavimo požymis: %1', 'AUD.EVAC_INV', 'Įvykių atvejo sąlygos invertavimo požymis: %1', 'Įvykių atvejo sąlygos invertavimo požymis: %1'),
	(1150, 'Įvykių atvejo sąlygos tikrinimo eilės numeris: %1', 'AUD.EVAC_NR', 'Įvykių atvejo sąlygos tikrinimo eilės numeris: %1', 'Įvykių atvejo sąlygos tikrinimo eilės numeris: %1'),
	(1151, 'Įvykių atvejų sąlygų tipo identifikatorius: %1', 'AUD.EVAC_TYPE_ID', 'Įvykių atvejų sąlygų tipo identifikatorius: %1', 'Įvykių atvejų sąlygų tipo identifikatorius: %1'),
	(1152, 'Įvykių atvejų sąlygų tipo pavadinimas: %1', 'AUD.EVAC_TYPE_NAME', 'Įvykių atvejų sąlygų tipo pavadinimas: %1', 'Įvykių atvejų sąlygų tipo pavadinimas: %1'),
	(1153, 'Įvykių atvejo požymis, ar laikinai blokuoti siuntimą po pranešimo išsiuntimo: %1', 'AUD.EVA_BLOCK', 'Įvykių atvejo požymis, ar laikinai blokuoti siuntimą po pranešimo išsiuntimo: %1', 'Įvykių atvejo požymis, ar laikinai blokuoti siuntimą po pranešimo išsiuntimo: %1'),
	(1154, 'Laikas, iki kurio blokuojamas įvykių atvejis: %1', 'AUD.EVA_BLOCKED_UNTIL', 'Laikas, iki kurio blokuojamas įvykių atvejis: %1', 'Laikas, iki kurio blokuojamas įvykių atvejis: %1'),
	(1155, 'Įvykių atvejo siuntimo blokavimo trukmė, min: %1', 'AUD.EVA_BLOCK_DURATION', 'Įvykių atvejo siuntimo blokavimo trukmė, min: %1', 'Įvykių atvejo siuntimo blokavimo trukmė, min: %1'),
	(1156, 'Įvykių atvejo kodas: %1', 'AUD.EVA_CODE', 'Įvykių atvejo kodas: %1', 'Įvykių atvejo kodas: %1'),
	(1157, 'Įvykių atvejo naudojimo požymis: %1', 'AUD.EVA_ENABLED', 'Įvykių atvejo naudojimo požymis: %1', 'Įvykių atvejo naudojimo požymis: %1'),
	(1158, 'Įvykių atvejo identifikatorius: %1', 'AUD.EVA_ID', 'Įvykių atvejo identifikatorius: %1', 'Įvykių atvejo identifikatorius: %1'),
	(1159, 'Įvykių atvejo požymis, ar siųsti pranešimą tuoj pat: %1', 'AUD.EVA_IMMEDIATE', 'Įvykių atvejo požymis, ar siųsti pranešimą tuoj pat: %1', 'Įvykių atvejo požymis, ar siųsti pranešimą tuoj pat: %1'),
	(1160, 'Įvykių atvejo pavadinimas: %1', 'AUD.EVA_NAME', 'Įvykių atvejo pavadinimas: %1', 'Įvykių atvejo pavadinimas: %1'),
	(1161, 'Įvykių atvejų tipo identifikatorius: %1', 'AUD.EVA_TYPE_ID', 'Įvykių atvejų tipo identifikatorius: %1', 'Įvykių atvejų tipo identifikatorius: %1'),
	(1162, 'Įvykių atvejų tipo pavadinimas: %1', 'AUD.EVA_TYPE_NAME', 'Įvykių atvejų tipo pavadinimas: %1', 'Įvykių atvejų tipo pavadinimas: %1'),
	(1163, 'Sistemos įvykių klasės pavadinimas: %1', 'AUD.EVC_NAME', 'Sistemos įvykių klasės pavadinimas: %1', 'Sistemos įvykių klasės pavadinimas: %1'),
	(1164, 'Laiko matavimo vienetų skaičius, nusakantis ryšio būsenos galiojimo trukmę: %1', 'AUD.EXPIRATION_INT_VALUE', 'Laiko matavimo vienetų skaičius, nusakantis ryšio būsenos galiojimo trukmę: %1', 'Laiko matavimo vienetų skaičius, nusakantis ryšio būsenos galiojimo trukmę: %1'),
	(1165, 'Eksploatacijos pradžia: %1', 'AUD.EXPL_START', 'Eksploatacijos pradžia: %1', 'Eksploatacijos pradžia: %1'),
	(1166, 'Profilio kodas: %1', 'AUD.FFP_CODE', 'Profilio kodas: %1', 'Profilio kodas: %1'),
	(1167, 'Profilio reikšmių idenfikatorius: %1', 'AUD.FFP_DATA_ID', 'Profilio reikšmių idenfikatorius: %1', 'Profilio reikšmių idenfikatorius: %1'),
	(1168, 'Profilio identifikatorius: %1', 'AUD.FFP_ID', 'Profilio identifikatorius: %1', 'Profilio identifikatorius: %1'),
	(1169, 'Profilio pavadinimas: %1', 'AUD.FFP_NAME', 'Profilio pavadinimas: %1', 'Profilio pavadinimas: %1'),
	(1170, 'Profilio tipas: %1', 'AUD.FFP_TYPE', 'Profilio tipas: %1', 'Profilio tipas: %1'),
	(1171, 'Profilio reikšmių pirmoji raktinė reikšmė: %1', 'AUD.FFP_VAL_KEY_1', 'Profilio reikšmių pirmoji raktinė reikšmė: %1', 'Profilio reikšmių pirmoji raktinė reikšmė: %1'),
	(1172, 'Profilio reikšmių antroji raktinė reikšmė: %1', 'AUD.FFP_VAL_KEY_2', 'Profilio reikšmių antroji raktinė reikšmė: %1', 'Profilio reikšmių antroji raktinė reikšmė: %1'),
	(1173, 'Profilio reikšmių trečioji raktinė reikšmė: %1', 'AUD.FFP_VAL_KEY_3', 'Profilio reikšmių trečioji raktinė reikšmė: %1', 'Profilio reikšmių trečioji raktinė reikšmė: %1'),
	(1174, 'Atvaizduojamos profilio reikšmių eiliškumo klasifikatorius: %1', 'AUD.FFP_VAL_ROW_NUM', 'Atvaizduojamos profilio reikšmių eiliškumo klasifikatorius: %1', 'Atvaizduojamos profilio reikšmių eiliškumo klasifikatorius: %1'),
	(1175, 'Profilio reikšmės tipo identifikatorius: %1', 'AUD.FFP_VT_ID', 'Profilio reikšmės tipo identifikatorius: %1', 'Profilio reikšmės tipo identifikatorius: %1'),
	(1176, 'Tarifų plano pastovaus tarifo identifikatorius: %1', 'AUD.FIXED_TFF_ID', 'Tarifų plano pastovaus tarifo identifikatorius: %1', 'Tarifų plano pastovaus tarifo identifikatorius: %1'),
	(1177, 'Automatizuotos ataskaitos katalogas: %1', 'AUD.FOLDER', 'Automatizuotos ataskaitos katalogas: %1', 'Automatizuotos ataskaitos katalogas: %1'),
	(1178, 'Forsavimo požymis: %1', 'AUD.FORCED', 'Forsavimo požymis: %1', 'Forsavimo požymis: %1'),
	(1179, 'Formuoti tuscia ataskaita: %1', 'AUD.FORM_IF_EMPTY', 'Formuoti tuscia ataskaita: %1', 'Formuoti tuscia ataskaita: %1'),
	(1180, 'Ataskaitos formato savybės kodas: %1', 'AUD.FPTY_CODE', 'Ataskaitos formato savybės kodas: %1', 'Ataskaitos formato savybės kodas: %1'),
	(1181, 'Ataskaitos formato savybės identifikatorius: %1', 'AUD.FPTY_ID', 'Ataskaitos formato savybės identifikatorius: %1', 'Ataskaitos formato savybės identifikatorius: %1'),
	(1182, 'Ataskaitos formato savybės reikšmė: %1', 'AUD.FPTY_VALUE', 'Ataskaitos formato savybės reikšmė: %1', 'Ataskaitos formato savybės reikšmė: %1'),
	(1183, 'Užpildymo profilio kodas: %1', 'AUD.FP_CODE', 'Užpildymo profilio kodas: %1', 'Užpildymo profilio kodas: %1'),
	(1184, 'Užpildymo profilio identifikatorius: %1', 'AUD.FP_ID', 'Užpildymo profilio identifikatorius: %1', 'Užpildymo profilio identifikatorius: %1'),
	(1185, 'Užpildymo profilio pavadinimas: %1', 'AUD.FP_NAME', 'Užpildymo profilio pavadinimas: %1', 'Užpildymo profilio pavadinimas: %1'),
	(1186, 'Užpildymo profilio sąlygos numeris: %1', 'AUD.FP_NR', 'Užpildymo profilio sąlygos numeris: %1', 'Užpildymo profilio sąlygos numeris: %1'),
	(1187, 'Sugrupuotų duomenų modifikacijos kodas: %1', 'AUD.GMOD_CODE', 'Sugrupuotų duomenų modifikacijos kodas: %1', 'Sugrupuotų duomenų modifikacijos kodas: %1'),
	(1188, 'Sugrupuotų duomenų modifikacijos parametro numeris: %1', 'AUD.GMOD_DATA_NR', 'Sugrupuotų duomenų modifikacijos parametro numeris: %1', 'Sugrupuotų duomenų modifikacijos parametro numeris: %1'),
	(1189, 'Grupės matavimo matavimo vienetų pakaitalas: %1', 'AUD.GMOD_EU_CODE', 'Grupės matavimo matavimo vienetų pakaitalas: %1', 'Grupės matavimo matavimo vienetų pakaitalas: %1'),
	(1190, 'Grupės matavimo matavimo vienetų pakaitalo naudojimo rėžimas: %1', 'AUD.GMOD_EU_CODE_USAGE', 'Grupės matavimo matavimo vienetų pakaitalo naudojimo rėžimas: %1', 'Grupės matavimo matavimo vienetų pakaitalo naudojimo rėžimas: %1'),
	(1191, 'Sugrupuotų duomenų modifikacijos ID: %1', 'AUD.GMOD_ID', 'Sugrupuotų duomenų modifikacijos ID: %1', 'Sugrupuotų duomenų modifikacijos ID: %1'),
	(1192, 'Sugrupuotų duomenų modifikacijos pavadinimas: %1', 'AUD.GMOD_NAME', 'Sugrupuotų duomenų modifikacijos pavadinimas: %1', 'Sugrupuotų duomenų modifikacijos pavadinimas: %1'),
	(1193, 'Grupės procentinės reikšmės naudojimo požymis: %1', 'AUD.GPRC', 'Grupės procentinės reikšmės naudojimo požymis: %1', 'Grupės procentinės reikšmės naudojimo požymis: %1'),
	(1194, 'Apskaitos grupių savybės kodas: %1', 'AUD.GPTY_CODE', 'Apskaitos grupių savybės kodas: %1', 'Apskaitos grupių savybės kodas: %1'),
	(1195, 'Apskaitos grupių savybės identifikatorius: %1', 'AUD.GPTY_ID', 'Apskaitos grupių savybės identifikatorius: %1', 'Apskaitos grupių savybės identifikatorius: %1'),
	(1196, 'Apskaitos grupių savybės pavadinimas: %1', 'AUD.GPTY_NAME', 'Apskaitos grupių savybės pavadinimas: %1', 'Apskaitos grupių savybės pavadinimas: %1'),
	(1197, 'Apskaitos grupių savybės eilės numeris rušiavimui: %1', 'AUD.GPTY_NR', 'Apskaitos grupių savybės eilės numeris rušiavimui: %1', 'Apskaitos grupių savybės eilės numeris rušiavimui: %1'),
	(1198, 'Požymis, ar grupės savybės reikšmė turi būti skaitmeninė: %1', 'AUD.GPTY_NUMERIC', 'Požymis, ar grupės savybės reikšmė turi būti skaitmeninė: %1', 'Požymis, ar grupės savybės reikšmė turi būti skaitmeninė: %1'),
	(1199, 'Galimų apskaitos grupių savybių sąrašų tipo kodas: %1', 'AUD.GPTY_TYPE_CODE', 'Galimų apskaitos grupių savybių sąrašų tipo kodas: %1', 'Galimų apskaitos grupių savybių sąrašų tipo kodas: %1'),
	(1200, 'Galimų apskaitos grupių savybių sąrašų tipo identifikatorius: %1', 'AUD.GPTY_TYPE_ID', 'Galimų apskaitos grupių savybių sąrašų tipo identifikatorius: %1', 'Galimų apskaitos grupių savybių sąrašų tipo identifikatorius: %1'),
	(1201, 'Galimų apskaitos grupių savybių sąrašų tipo pavadinimas: %1', 'AUD.GPTY_TYPE_NAME', 'Galimų apskaitos grupių savybių sąrašų tipo pavadinimas: %1', 'Galimų apskaitos grupių savybių sąrašų tipo pavadinimas: %1'),
	(1202, 'Apskaitos grupės savybės reikšmė: %1', 'AUD.GPTY_VALUE', 'Apskaitos grupės savybės reikšmė: %1', 'Apskaitos grupės savybės reikšmė: %1'),
	(1203, 'Grupės-komponento priklausomybės grupei-konteineriui periodo pradžia: %1', 'AUD.GRC_BT', 'Grupės-komponento priklausomybės grupei-konteineriui periodo pradžia: %1', 'Grupės-komponento priklausomybės grupei-konteineriui periodo pradžia: %1'),
	(1204, 'Grupės-komponento priklausomybės grupei-konteineriui periodo aprašymas: %1', 'AUD.GRC_DESC', 'Grupės-komponento priklausomybės grupei-konteineriui periodo aprašymas: %1', 'Grupės-komponento priklausomybės grupei-konteineriui periodo aprašymas: %1'),
	(1205, 'Grupės-komponento priklausomybės grupei-konteineriui periodo pabaiga: %1', 'AUD.GRC_ET', 'Grupės-komponento priklausomybės grupei-konteineriui periodo pabaiga: %1', 'Grupės-komponento priklausomybės grupei-konteineriui periodo pabaiga: %1'),
	(1206, 'Grupės-komponento eilės numeris: %1', 'AUD.GRC_NR', 'Grupės-komponento eilės numeris: %1', 'Grupės-komponento eilės numeris: %1'),
	(1207, 'Taško priklausomybės grupei periodo pradžia: %1', 'AUD.GRP_BT', 'Taško priklausomybės grupei periodo pradžia: %1', 'Taško priklausomybės grupei periodo pradžia: %1'),
	(1208, 'Taško priklausomybės grupei periodo aprašymas: %1', 'AUD.GRP_DESC', 'Taško priklausomybės grupei periodo aprašymas: %1', 'Taško priklausomybės grupei periodo aprašymas: %1'),
	(1209, 'Taško priklausomybės grupei periodo pabaiga: %1', 'AUD.GRP_ET', 'Taško priklausomybės grupei periodo pabaiga: %1', 'Taško priklausomybės grupei periodo pabaiga: %1'),
	(1210, 'Taško eilės numeris: %1', 'AUD.GRP_NR', 'Taško eilės numeris: %1', 'Taško eilės numeris: %1'),
	(1211, 'Grupės kodas: %1', 'AUD.GR_CODE', 'Grupės kodas: %1', 'Grupės kodas: %1'),
	(1212, 'Grupės matavimo krypties identifikatorius: %1', 'AUD.GR_DIR_ID', 'Grupės matavimo krypties identifikatorius: %1', 'Grupės matavimo krypties identifikatorius: %1'),
	(1213, 'Apskaitos grupės ekonominės kategorijos identifikatorius: %1', 'AUD.GR_EC_ID', 'Apskaitos grupės ekonominės kategorijos identifikatorius: %1', 'Apskaitos grupės ekonominės kategorijos identifikatorius: %1'),
	(1214, 'Grupės identifikatorius: %1', 'AUD.GR_ID', 'Grupės identifikatorius: %1', 'Grupės identifikatorius: %1'),
	(1215, 'Apskaitos grupės matavimo identifikatorius: %1', 'AUD.GR_MS_ID', 'Apskaitos grupės matavimo identifikatorius: %1', 'Apskaitos grupės matavimo identifikatorius: %1'),
	(1216, 'Grupės pavadinimas: %1', 'AUD.GR_NAME', 'Grupės pavadinimas: %1', 'Grupės pavadinimas: %1'),
	(1217, 'Apskaitos grupių tipo kodas: %1', 'AUD.GR_TYPE_CODE', 'Apskaitos grupių tipo kodas: %1', 'Apskaitos grupių tipo kodas: %1'),
	(1218, 'Apskaitos grupių tipo identifikatorius: %1', 'AUD.GR_TYPE_ID', 'Apskaitos grupių tipo identifikatorius: %1', 'Apskaitos grupių tipo identifikatorius: %1'),
	(1219, 'Apskaitos grupių tipo pavadinimas: %1', 'AUD.GR_TYPE_NAME', 'Apskaitos grupių tipo pavadinimas: %1', 'Apskaitos grupių tipo pavadinimas: %1'),
	(1220, 'Apskaitos grupei priskirto tarifų plano periodo pradžia: %1', 'AUD.GTP_BT', 'Apskaitos grupei priskirto tarifų plano periodo pradžia: %1', 'Apskaitos grupei priskirto tarifų plano periodo pradžia: %1'),
	(1221, 'Apskaitos grupei priskirto tarifų plano periodo pabaiga: %1', 'AUD.GTP_ET', 'Apskaitos grupei priskirto tarifų plano periodo pabaiga: %1', 'Apskaitos grupei priskirto tarifų plano periodo pabaiga: %1'),
	(1222, 'Apskaitos grupei priskirto tarifų plano identifikatorius: %1', 'AUD.GTP_ID', 'Apskaitos grupei priskirto tarifų plano identifikatorius: %1', 'Apskaitos grupei priskirto tarifų plano identifikatorius: %1'),
	(1223, 'Data: %1', 'AUD.HDAY', 'Data: %1', 'Data: %1'),
	(1224, 'Požymis, ar vykdyti 1-ą valandą: %1', 'AUD.HH1', 'Požymis, ar vykdyti 1-ą valandą: %1', 'Požymis, ar vykdyti 1-ą valandą: %1'),
	(1225, 'Požymis, ar vykdyti 10-ą valandą: %1', 'AUD.HH10', 'Požymis, ar vykdyti 10-ą valandą: %1', 'Požymis, ar vykdyti 10-ą valandą: %1'),
	(1226, 'Požymis, ar vykdyti 11-ą valandą: %1', 'AUD.HH11', 'Požymis, ar vykdyti 11-ą valandą: %1', 'Požymis, ar vykdyti 11-ą valandą: %1'),
	(1227, 'Požymis, ar vykdyti 12-ą valandą: %1', 'AUD.HH12', 'Požymis, ar vykdyti 12-ą valandą: %1', 'Požymis, ar vykdyti 12-ą valandą: %1'),
	(1228, 'Požymis, ar vykdyti 13-ą valandą: %1', 'AUD.HH13', 'Požymis, ar vykdyti 13-ą valandą: %1', 'Požymis, ar vykdyti 13-ą valandą: %1'),
	(1229, 'Požymis, ar vykdyti 14-ą valandą: %1', 'AUD.HH14', 'Požymis, ar vykdyti 14-ą valandą: %1', 'Požymis, ar vykdyti 14-ą valandą: %1'),
	(1230, 'Požymis, ar vykdyti 15-ą valandą: %1', 'AUD.HH15', 'Požymis, ar vykdyti 15-ą valandą: %1', 'Požymis, ar vykdyti 15-ą valandą: %1'),
	(1231, 'Požymis, ar vykdyti 16-ą valandą: %1', 'AUD.HH16', 'Požymis, ar vykdyti 16-ą valandą: %1', 'Požymis, ar vykdyti 16-ą valandą: %1'),
	(1232, 'Požymis, ar vykdyti 17-ą valandą: %1', 'AUD.HH17', 'Požymis, ar vykdyti 17-ą valandą: %1', 'Požymis, ar vykdyti 17-ą valandą: %1'),
	(1233, 'Požymis, ar vykdyti 18-ą valandą: %1', 'AUD.HH18', 'Požymis, ar vykdyti 18-ą valandą: %1', 'Požymis, ar vykdyti 18-ą valandą: %1'),
	(1234, 'Požymis, ar vykdyti 19-ą valandą: %1', 'AUD.HH19', 'Požymis, ar vykdyti 19-ą valandą: %1', 'Požymis, ar vykdyti 19-ą valandą: %1'),
	(1235, 'Požymis, ar vykdyti 2-ą valandą: %1', 'AUD.HH2', 'Požymis, ar vykdyti 2-ą valandą: %1', 'Požymis, ar vykdyti 2-ą valandą: %1'),
	(1236, 'Požymis, ar vykdyti 20-ą valandą: %1', 'AUD.HH20', 'Požymis, ar vykdyti 20-ą valandą: %1', 'Požymis, ar vykdyti 20-ą valandą: %1'),
	(1237, 'Požymis, ar vykdyti 21-ą valandą: %1', 'AUD.HH21', 'Požymis, ar vykdyti 21-ą valandą: %1', 'Požymis, ar vykdyti 21-ą valandą: %1'),
	(1238, 'Požymis, ar vykdyti 22-ą valandą: %1', 'AUD.HH22', 'Požymis, ar vykdyti 22-ą valandą: %1', 'Požymis, ar vykdyti 22-ą valandą: %1'),
	(1239, 'Požymis, ar vykdyti 23-ą valandą: %1', 'AUD.HH23', 'Požymis, ar vykdyti 23-ą valandą: %1', 'Požymis, ar vykdyti 23-ą valandą: %1'),
	(1240, 'Požymis, ar vykdyti 24-ą valandą: %1', 'AUD.HH24', 'Požymis, ar vykdyti 24-ą valandą: %1', 'Požymis, ar vykdyti 24-ą valandą: %1'),
	(1241, 'Požymis, ar vykdyti 3-ą valandą: %1', 'AUD.HH3', 'Požymis, ar vykdyti 3-ą valandą: %1', 'Požymis, ar vykdyti 3-ą valandą: %1'),
	(1242, 'Požymis, ar vykdyti 4-ą valandą: %1', 'AUD.HH4', 'Požymis, ar vykdyti 4-ą valandą: %1', 'Požymis, ar vykdyti 4-ą valandą: %1'),
	(1243, 'Požymis, ar vykdyti 5-ą valandą: %1', 'AUD.HH5', 'Požymis, ar vykdyti 5-ą valandą: %1', 'Požymis, ar vykdyti 5-ą valandą: %1'),
	(1244, 'Požymis, ar vykdyti 6-ą valandą: %1', 'AUD.HH6', 'Požymis, ar vykdyti 6-ą valandą: %1', 'Požymis, ar vykdyti 6-ą valandą: %1'),
	(1245, 'Požymis, ar vykdyti 7-ą valandą: %1', 'AUD.HH7', 'Požymis, ar vykdyti 7-ą valandą: %1', 'Požymis, ar vykdyti 7-ą valandą: %1'),
	(1246, 'Požymis, ar vykdyti 8-ą valandą: %1', 'AUD.HH8', 'Požymis, ar vykdyti 8-ą valandą: %1', 'Požymis, ar vykdyti 8-ą valandą: %1'),
	(1247, 'Požymis, ar vykdyti 9-ą valandą: %1', 'AUD.HH9', 'Požymis, ar vykdyti 9-ą valandą: %1', 'Požymis, ar vykdyti 9-ą valandą: %1'),
	(1248, 'Požymis, ar vykdyti specifiškai pagal valandas: %1', 'AUD.HH_SPECIFIC', 'Požymis, ar vykdyti specifiškai pagal valandas: %1', 'Požymis, ar vykdyti specifiškai pagal valandas: %1'),
	(1249, 'Šventinių dienų rinkinio identifikatorius: %1', 'AUD.HLD_ID', 'Šventinių dienų rinkinio identifikatorius: %1', 'Šventinių dienų rinkinio identifikatorius: %1'),
	(1250, 'Šventinių dienų rinkinio pavadinimas: %1', 'AUD.HLD_NAME', 'Šventinių dienų rinkinio pavadinimas: %1', 'Šventinių dienų rinkinio pavadinimas: %1'),
	(1251, 'Grupės reikšmės ignoravimo požymis: %1', 'AUD.IGNORE_GROUP_VALUE', 'Grupės reikšmės ignoravimo požymis: %1', 'Grupės reikšmės ignoravimo požymis: %1'),
	(1252, 'Pakeičiančio nuskaitytus duomenis akto požymis: %1', 'AUD.IGNORE_READ_DATA', 'Pakeičiančio nuskaitytus duomenis akto požymis: %1', 'Pakeičiančio nuskaitytus duomenis akto požymis: %1'),
	(1253, 'Šaltinio elemento koeficientų ignoravimo požymis: %1', 'AUD.IGNORE_SE_AB', 'Šaltinio elemento koeficientų ignoravimo požymis: %1', 'Šaltinio elemento koeficientų ignoravimo požymis: %1'),
	(1254, 'Kodo ir pavadinimo paveldėjimo požymis: %1', 'AUD.INHERIT_CN', 'Kodo ir pavadinimo paveldėjimo požymis: %1', 'Kodo ir pavadinimo paveldėjimo požymis: %1'),
	(1255, 'Viešos grupės požymis: %1', 'AUD.IS_PUBLIC', 'Viešos grupės požymis: %1', 'Viešos grupės požymis: %1'),
	(1256, 'Ryšio modulių savybių kodas: %1', 'AUD.LPTY_CODE', 'Ryšio modulių savybių kodas: %1', 'Ryšio modulių savybių kodas: %1'),
	(1257, 'Ryšio modulių savybės identifikatorius: %1', 'AUD.LPTY_ID', 'Ryšio modulių savybės identifikatorius: %1', 'Ryšio modulių savybės identifikatorius: %1'),
	(1258, 'Ryšio modulių savybės reikšmė: %1', 'AUD.LPTY_VALUE', 'Ryšio modulių savybės reikšmė: %1', 'Ryšio modulių savybės reikšmė: %1'),
	(1259, 'Ryšio prioritetų profilio identifikatorius: %1', 'AUD.LP_ID', 'Ryšio prioritetų profilio identifikatorius: %1', 'Ryšio prioritetų profilio identifikatorius: %1'),
	(1260, 'Ryšio prioritetų profilio pavadinimas: %1', 'AUD.LP_NAME', 'Ryšio prioritetų profilio pavadinimas: %1', 'Ryšio prioritetų profilio pavadinimas: %1'),
	(1261, 'Ryšio prioritetas: %1', 'AUD.LP_PRIORITY', 'Ryšio prioritetas: %1', 'Ryšio prioritetas: %1'),
	(1262, 'Tiesinės transformacijos koeficiento kodas: %1', 'AUD.LTC_CODE', 'Tiesinės transformacijos koeficiento kodas: %1', 'Tiesinės transformacijos koeficiento kodas: %1'),
	(1263, 'Pagaminimo data: %1', 'AUD.MADE', 'Pagaminimo data: %1', 'Pagaminimo data: %1'),
	(1264, 'Monitoringo priskyrimo automatinio tikrinimo periodui požymis: %1', 'AUD.MAP_ENABLED', 'Monitoringo priskyrimo automatinio tikrinimo periodui požymis: %1', 'Monitoringo priskyrimo automatinio tikrinimo periodui požymis: %1'),
	(1265, 'Monitoringo priskyrimo automatinio tikrinimo periodo ID: %1', 'AUD.MAP_ID', 'Monitoringo priskyrimo automatinio tikrinimo periodo ID: %1', 'Monitoringo priskyrimo automatinio tikrinimo periodo ID: %1'),
	(1266, 'Požymis, ar naudoti tiesinę transformaciją išeities rodiklio reikšmei: %1', 'AUD.MA_AB', 'Požymis, ar naudoti tiesinę transformaciją išeities rodiklio reikšmei: %1', 'Požymis, ar naudoti tiesinę transformaciją išeities rodiklio reikšmei: %1'),
	(1267, 'Požymis, ar automatiškai tikrinti rodiklių atitikimą nurodytuose perioduose: %1', 'AUD.MA_AUTO_CHECK', 'Požymis, ar automatiškai tikrinti rodiklių atitikimą nurodytuose perioduose: %1', 'Požymis, ar automatiškai tikrinti rodiklių atitikimą nurodytuose perioduose: %1'),
	(1268, 'Tiesinės transformacijos daugiklio vardiklis: %1', 'AUD.MA_A_DENOM', 'Tiesinės transformacijos daugiklio vardiklis: %1', 'Tiesinės transformacijos daugiklio vardiklis: %1'),
	(1269, 'Tiesinės transformacijos daugiklio skaitiklis: %1', 'AUD.MA_A_NOM', 'Tiesinės transformacijos daugiklio skaitiklis: %1', 'Tiesinės transformacijos daugiklio skaitiklis: %1'),
	(1270, 'Tiesinės transformacijos dėmuo: %1', 'AUD.MA_B', 'Tiesinės transformacijos dėmuo: %1', 'Tiesinės transformacijos dėmuo: %1'),
	(1271, 'Monitoringo priskyrimo naudojimo požymis: %1', 'AUD.MA_ENABLED', 'Monitoringo priskyrimo naudojimo požymis: %1', 'Monitoringo priskyrimo naudojimo požymis: %1'),
	(1272, 'Monitoringo priskyrimo identifikatorius: %1', 'AUD.MA_ID', 'Monitoringo priskyrimo identifikatorius: %1', 'Monitoringo priskyrimo identifikatorius: %1'),
	(1273, 'Požymis, ar tikrinama dėl viršijimo (ar dėl nusileidimo): %1', 'AUD.MA_REPORT_EXCEEDING', 'Požymis, ar tikrinama dėl viršijimo (ar dėl nusileidimo): %1', 'Požymis, ar tikrinama dėl viršijimo (ar dėl nusileidimo): %1'),
	(1274, 'Priskirtos kraštinės atvaizdavimo požymis: %1', 'AUD.MA_SHOW', 'Priskirtos kraštinės atvaizdavimo požymis: %1', 'Priskirtos kraštinės atvaizdavimo požymis: %1'),
	(1275, 'Matavimo diskretiškumo identifikatorius: %1', 'AUD.MD_ID', 'Matavimo diskretiškumo identifikatorius: %1', 'Matavimo diskretiškumo identifikatorius: %1'),
	(1276, 'Matavimų diskretiškumo pavadinimas: %1', 'AUD.MD_NAME', 'Matavimų diskretiškumo pavadinimas: %1', 'Matavimų diskretiškumo pavadinimas: %1'),
	(1277, 'Skaitiklio tikslumo klasė: %1', 'AUD.METER_CLASS', 'Skaitiklio tikslumo klasė: %1', 'Skaitiklio tikslumo klasė: %1'),
	(1278, 'Matavimo priemonės identifikatorius: %1', 'AUD.METER_ID', 'Matavimo priemonės identifikatorius: %1', 'Matavimo priemonės identifikatorius: %1'),
	(1279, 'Matavimo priemonės numeris: %1', 'AUD.METER_NUMBER', 'Matavimo priemonės numeris: %1', 'Matavimo priemonės numeris: %1'),
	(1280, 'Matavimo priemonių tipo identifikatorius: %1', 'AUD.METER_TYPE_ID', 'Matavimo priemonių tipo identifikatorius: %1', 'Matavimo priemonių tipo identifikatorius: %1'),
	(1281, 'Matavimo priemonių tipo pavadinimas: %1', 'AUD.METER_TYPE_NAME', 'Matavimo priemonių tipo pavadinimas: %1', 'Matavimo priemonių tipo pavadinimas: %1'),
	(1282, 'Matavimo priemonių tipo gamintojas: %1', 'AUD.METER_TYPE_PRODUCER', 'Matavimo priemonių tipo gamintojas: %1', 'Matavimo priemonių tipo gamintojas: %1'),
	(1283, 'Matavimo rinkinio kodas: %1', 'AUD.MLSET_CODE', 'Matavimo rinkinio kodas: %1', 'Matavimo rinkinio kodas: %1'),
	(1284, 'Matavimų rinkinio identifikatorius: %1', 'AUD.MLSET_ID', 'Matavimų rinkinio identifikatorius: %1', 'Matavimų rinkinio identifikatorius: %1'),
	(1285, 'Matavimų rinkinio pavadinimas: %1', 'AUD.MLSET_NAME', 'Matavimų rinkinio pavadinimas: %1', 'Matavimų rinkinio pavadinimas: %1'),
	(1286, 'Matavimo linijos identifikatorius: %1', 'AUD.ML_ID', 'Matavimo linijos identifikatorius: %1', 'Matavimo linijos identifikatorius: %1'),
	(1287, 'Matavimo linijos pavadinimas: %1', 'AUD.ML_NAME', 'Matavimo linijos pavadinimas: %1', 'Matavimo linijos pavadinimas: %1'),
	(1288, 'Mėnesio numeris: %1', 'AUD.MM', 'Mėnesio numeris: %1', 'Mėnesio numeris: %1'),
	(1289, 'Požymis, ar vykdyti sausį: %1', 'AUD.MO1', 'Požymis, ar vykdyti sausį: %1', 'Požymis, ar vykdyti sausį: %1'),
	(1290, 'Požymis, ar vykdyti spalį: %1', 'AUD.MO10', 'Požymis, ar vykdyti spalį: %1', 'Požymis, ar vykdyti spalį: %1'),
	(1291, 'Požymis, ar vykdyti lapkritį: %1', 'AUD.MO11', 'Požymis, ar vykdyti lapkritį: %1', 'Požymis, ar vykdyti lapkritį: %1'),
	(1292, 'Požymis, ar vykdyti gruodį: %1', 'AUD.MO12', 'Požymis, ar vykdyti gruodį: %1', 'Požymis, ar vykdyti gruodį: %1'),
	(1293, 'Požymis, ar vykdyti vasarį: %1', 'AUD.MO2', 'Požymis, ar vykdyti vasarį: %1', 'Požymis, ar vykdyti vasarį: %1'),
	(1294, 'Požymis, ar vykdyti kovą: %1', 'AUD.MO3', 'Požymis, ar vykdyti kovą: %1', 'Požymis, ar vykdyti kovą: %1'),
	(1295, 'Požymis, ar vykdyti balandį: %1', 'AUD.MO4', 'Požymis, ar vykdyti balandį: %1', 'Požymis, ar vykdyti balandį: %1'),
	(1296, 'Požymis, ar vykdyti gegužę: %1', 'AUD.MO5', 'Požymis, ar vykdyti gegužę: %1', 'Požymis, ar vykdyti gegužę: %1'),
	(1297, 'Požymis, ar vykdyti birželį: %1', 'AUD.MO6', 'Požymis, ar vykdyti birželį: %1', 'Požymis, ar vykdyti birželį: %1'),
	(1298, 'Požymis, ar vykdyti liepą: %1', 'AUD.MO7', 'Požymis, ar vykdyti liepą: %1', 'Požymis, ar vykdyti liepą: %1'),
	(1299, 'Požymis, ar vykdyti rugpjūtį: %1', 'AUD.MO8', 'Požymis, ar vykdyti rugpjūtį: %1', 'Požymis, ar vykdyti rugpjūtį: %1'),
	(1300, 'Požymis, ar vykdyti rugsėjį: %1', 'AUD.MO9', 'Požymis, ar vykdyti rugsėjį: %1', 'Požymis, ar vykdyti rugsėjį: %1'),
	(1301, 'Montavimo data: %1', 'AUD.MOU_BT', 'Montavimo data: %1', 'Montavimo data: %1'),
	(1302, 'Išmontavimo data: %1', 'AUD.MOU_ET', 'Išmontavimo data: %1', 'Išmontavimo data: %1'),
	(1303, 'Montažo identifikatorius: %1', 'AUD.MOU_ID', 'Montažo identifikatorius: %1', 'Montažo identifikatorius: %1'),
	(1304, 'Pajungimo schemos identifikatorius: %1', 'AUD.MOU_TYPE_ID', 'Pajungimo schemos identifikatorius: %1', 'Pajungimo schemos identifikatorius: %1'),
	(1305, 'Pajungimo schemos pavadinimas: %1', 'AUD.MOU_TYPE_NAME', 'Pajungimo schemos pavadinimas: %1', 'Pajungimo schemos pavadinimas: %1'),
	(1306, 'Požymis, ar vykdyti specifiškai pagal mėnesius: %1', 'AUD.MO_SPECIFIC', 'Požymis, ar vykdyti specifiškai pagal mėnesius: %1', 'Požymis, ar vykdyti specifiškai pagal mėnesius: %1'),
	(1307, 'Matavimo priemonių savybės kodas: %1', 'AUD.MPTY_CODE', 'Matavimo priemonių savybės kodas: %1', 'Matavimo priemonių savybės kodas: %1'),
	(1308, 'Matavimo priemonių savybės identifikatorius: %1', 'AUD.MPTY_ID', 'Matavimo priemonių savybės identifikatorius: %1', 'Matavimo priemonių savybės identifikatorius: %1'),
	(1309, 'Matavimo priemonių savybės pavadinimas: %1', 'AUD.MPTY_NAME', 'Matavimo priemonių savybės pavadinimas: %1', 'Matavimo priemonių savybės pavadinimas: %1'),
	(1310, 'Matavimo priemonių savybės eilės numeris rušiavimui: %1', 'AUD.MPTY_NR', 'Matavimo priemonių savybės eilės numeris rušiavimui: %1', 'Matavimo priemonių savybės eilės numeris rušiavimui: %1'),
	(1311, 'Galimų matavimo prietaisų savybių sąrašų tipo kodas: %1', 'AUD.MPTY_TYPE_CODE', 'Galimų matavimo prietaisų savybių sąrašų tipo kodas: %1', 'Galimų matavimo prietaisų savybių sąrašų tipo kodas: %1'),
	(1312, 'Galimų matavimo prietaisų savybių sąrašų tipo identifikatorius: %1', 'AUD.MPTY_TYPE_ID', 'Galimų matavimo prietaisų savybių sąrašų tipo identifikatorius: %1', 'Galimų matavimo prietaisų savybių sąrašų tipo identifikatorius: %1'),
	(1313, 'Galimų matavimo prietaisų savybių sąrašų tipo pavadinimas: %1', 'AUD.MPTY_TYPE_NAME', 'Galimų matavimo prietaisų savybių sąrašų tipo pavadinimas: %1', 'Galimų matavimo prietaisų savybių sąrašų tipo pavadinimas: %1'),
	(1314, 'Matavimo priemonės savybės reikšmė: %1', 'AUD.MPTY_VALUE', 'Matavimo priemonės savybės reikšmė: %1', 'Matavimo priemonės savybės reikšmė: %1'),
	(1315, 'Matavimo kodas: %1', 'AUD.MS_CODE', 'Matavimo kodas: %1', 'Matavimo kodas: %1'),
	(1316, 'Matavimo identifikatorius: %1', 'AUD.MS_ID', 'Matavimo identifikatorius: %1', 'Matavimo identifikatorius: %1'),
	(1317, 'Matavimų tipo identifikatorius: %1', 'AUD.MS_TYPE_ID', 'Matavimų tipo identifikatorius: %1', 'Matavimų tipo identifikatorius: %1'),
	(1318, 'Matavimų tipo pavadinimas: %1', 'AUD.MS_TYPE_NAME', 'Matavimų tipo pavadinimas: %1', 'Matavimų tipo pavadinimas: %1'),
	(1319, 'Monitoringe naudojamo rodiklio ID: %1', 'AUD.MT_ID', 'Monitoringe naudojamo rodiklio ID: %1', 'Monitoringe naudojamo rodiklio ID: %1'),
	(1320, 'Šablono elemento numeris: %1', 'AUD.NR', 'Šablono elemento numeris: %1', 'Šablono elemento numeris: %1'),
	(1321, 'Skaitinė reikšmė Nr.1: %1', 'AUD.NVAL1', 'Skaitinė reikšmė Nr.1: %1', 'Skaitinė reikšmė Nr.1: %1'),
	(1322, 'Skaitinė reikšmė Nr.2: %1', 'AUD.NVAL2', 'Skaitinė reikšmė Nr.2: %1', 'Skaitinė reikšmė Nr.2: %1'),
	(1323, 'Įvykių atvejų kiekio riba: %1', 'AUD.OC_CNT', 'Įvykių atvejų kiekio riba: %1', 'Įvykių atvejų kiekio riba: %1'),
	(1324, 'Susijusių nuskaitymo taškų kiekio riba: %1', 'AUD.OC_DPT', 'Susijusių nuskaitymo taškų kiekio riba: %1', 'Susijusių nuskaitymo taškų kiekio riba: %1'),
	(1325, 'Susijusių apskaitos būsenų signalų kiekio riba: %1', 'AUD.OC_DSC', 'Susijusių apskaitos būsenų signalų kiekio riba: %1', 'Susijusių apskaitos būsenų signalų kiekio riba: %1'),
	(1326, 'Susijusių grupių kiekio riba: %1', 'AUD.OC_GRP', 'Susijusių grupių kiekio riba: %1', 'Susijusių grupių kiekio riba: %1'),
	(1327, 'Susijusių apskaitos taškų kiekio riba: %1', 'AUD.OC_PNT', 'Susijusių apskaitos taškų kiekio riba: %1', 'Susijusių apskaitos taškų kiekio riba: %1'),
	(1328, 'Duomenų paketo laiko žymė: %1', 'AUD.PCK_T', 'Duomenų paketo laiko žymė: %1', 'Duomenų paketo laiko žymė: %1'),
	(1329, 'Periodo identifikatorius: %1', 'AUD.PER_ID', 'Periodo identifikatorius: %1', 'Periodo identifikatorius: %1'),
	(1330, 'Periodo pavadinimas: %1', 'AUD.PER_NAME', 'Periodo pavadinimas: %1', 'Periodo pavadinimas: %1'),
	(1331, 'Ištrinto ryšio kanalo požymis: %1', 'AUD.PH_DELETED', 'Ištrinto ryšio kanalo požymis: %1', 'Ištrinto ryšio kanalo požymis: %1'),
	(1332, 'Ryšio kanalo naudojimo požymis: %1', 'AUD.PH_ENABLED', 'Ryšio kanalo naudojimo požymis: %1', 'Ryšio kanalo naudojimo požymis: %1'),
	(1333, 'Nesėkmingų prisijungimo bandymų kiekis, po kurio kanalas laikomas neveikiančiu: %1', 'AUD.PH_FAILURE_COUNT', 'Nesėkmingų prisijungimo bandymų kiekis, po kurio kanalas laikomas neveikiančiu: %1', 'Nesėkmingų prisijungimo bandymų kiekis, po kurio kanalas laikomas neveikiančiu: %1'),
	(1334, 'Ryšio kanalo identifikatorius: %1', 'AUD.PH_ID', 'Ryšio kanalo identifikatorius: %1', 'Ryšio kanalo identifikatorius: %1'),
	(1335, 'Ryšio kanalų fizinio sluoksnio identifikatorius: %1', 'AUD.PH_LAYER_ID', 'Ryšio kanalų fizinio sluoksnio identifikatorius: %1', 'Ryšio kanalų fizinio sluoksnio identifikatorius: %1'),
	(1336, 'Ryšio kanalų fizinio sluoksnio pavadinimas: %1', 'AUD.PH_LAYER_NAME', 'Ryšio kanalų fizinio sluoksnio pavadinimas: %1', 'Ryšio kanalų fizinio sluoksnio pavadinimas: %1'),
	(1337, 'Ryšio kanalo pavadinimas: %1', 'AUD.PH_NAME', 'Ryšio kanalo pavadinimas: %1', 'Ryšio kanalo pavadinimas: %1'),
	(1338, 'Statistikos ryšio kanalui rinkimo požymis: %1', 'AUD.PH_SAVE_STATISTICS', 'Statistikos ryšio kanalui rinkimo požymis: %1', 'Statistikos ryšio kanalui rinkimo požymis: %1'),
	(1339, 'Ryšio kanalų tipo identifikatorius: %1', 'AUD.PH_TYPE_ID', 'Ryšio kanalų tipo identifikatorius: %1', 'Ryšio kanalų tipo identifikatorius: %1'),
	(1340, 'Ryšio kanalo tipo pavadinimas: %1', 'AUD.PH_TYPE_NAME', 'Ryšio kanalo tipo pavadinimas: %1', 'Ryšio kanalo tipo pavadinimas: %1'),
	(1341, 'Matavimo linijos naudojimo matavimo taške požymis: %1', 'AUD.PL_ENABLED', 'Matavimo linijos naudojimo matavimo taške požymis: %1', 'Matavimo linijos naudojimo matavimo taške požymis: %1'),
	(1342, 'Matavimo linijos matavimo taške identifikatorius: %1', 'AUD.PL_ID', 'Matavimo linijos matavimo taške identifikatorius: %1', 'Matavimo linijos matavimo taške identifikatorius: %1'),
	(1343, 'Matavimo linijos matavimo taške duomenų laikas: %1', 'AUD.PL_T', 'Matavimo linijos matavimo taške duomenų laikas: %1', 'Matavimo linijos matavimo taške duomenų laikas: %1'),
	(1344, 'Duomenų automatinio nuskaitymo požymis: %1', 'AUD.POINT_AUTO_READ_ENABLED', 'Duomenų automatinio nuskaitymo požymis: %1', 'Duomenų automatinio nuskaitymo požymis: %1'),
	(1345, 'Matavimo taško kodas: %1', 'AUD.POINT_CODE', 'Matavimo taško kodas: %1', 'Matavimo taško kodas: %1'),
	(1346, 'Komercinės apskaitos taško požymis: %1', 'AUD.POINT_COMMERCIAL', 'Komercinės apskaitos taško požymis: %1', 'Komercinės apskaitos taško požymis: %1'),
	(1347, 'Matavimo taško matavimo krypties identifikatorius: %1', 'AUD.POINT_DIR_ID', 'Matavimo taško matavimo krypties identifikatorius: %1', 'Matavimo taško matavimo krypties identifikatorius: %1'),
	(1348, 'Matavimo taško naudojimo požymis: %1', 'AUD.POINT_ENABLED', 'Matavimo taško naudojimo požymis: %1', 'Matavimo taško naudojimo požymis: %1'),
	(1349, 'Matavimo taško identifikatorius: %1', 'AUD.POINT_ID', 'Matavimo taško identifikatorius: %1', 'Matavimo taško identifikatorius: %1'),
	(1350, 'Vidinio taško požymis: %1', 'AUD.POINT_INTERNAL', 'Vidinio taško požymis: %1', 'Vidinio taško požymis: %1'),
	(1351, 'Matavimo taško matavimo identifikatorius: %1', 'AUD.POINT_MS_ID', 'Matavimo taško matavimo identifikatorius: %1', 'Matavimo taško matavimo identifikatorius: %1'),
	(1352, 'Matavimo taško pavadinimas: %1', 'AUD.POINT_NAME', 'Matavimo taško pavadinimas: %1', 'Matavimo taško pavadinimas: %1'),
	(1353, 'Matavimo taškų tipo kodas: %1', 'AUD.POINT_TYPE_CODE', 'Matavimo taškų tipo kodas: %1', 'Matavimo taškų tipo kodas: %1'),
	(1354, 'Matavimo taškų tipo identifikatorius: %1', 'AUD.POINT_TYPE_ID', 'Matavimo taškų tipo identifikatorius: %1', 'Matavimo taškų tipo identifikatorius: %1'),
	(1355, 'Matavimo taškų tipo pavadinimas: %1', 'AUD.POINT_TYPE_NAME', 'Matavimo taškų tipo pavadinimas: %1', 'Matavimo taškų tipo pavadinimas: %1'),
	(1356, 'Pozicijos kodas: %1', 'AUD.POS_CODE', 'Pozicijos kodas: %1', 'Pozicijos kodas: %1'),
	(1357, 'Pozicijos aprašymas: %1', 'AUD.POS_DESC', 'Pozicijos aprašymas: %1', 'Pozicijos aprašymas: %1'),
	(1358, 'Pozicijos numeris: %1', 'AUD.POS_NR', 'Pozicijos numeris: %1', 'Pozicijos numeris: %1'),
	(1359, 'Matavimo taškų savybės kodas: %1', 'AUD.PPTY_CODE', 'Matavimo taškų savybės kodas: %1', 'Matavimo taškų savybės kodas: %1'),
	(1360, 'Matavimo taškų savybės identifikatorius: %1', 'AUD.PPTY_ID', 'Matavimo taškų savybės identifikatorius: %1', 'Matavimo taškų savybės identifikatorius: %1'),
	(1361, 'Matavimo taškų savybės pavadinimas: %1', 'AUD.PPTY_NAME', 'Matavimo taškų savybės pavadinimas: %1', 'Matavimo taškų savybės pavadinimas: %1'),
	(1362, 'Matavimo taškų savybės eilės numeris rušiavimui: %1', 'AUD.PPTY_NR', 'Matavimo taškų savybės eilės numeris rušiavimui: %1', 'Matavimo taškų savybės eilės numeris rušiavimui: %1'),
	(1363, 'Požymis, ar taško savybės reikšmė turi būti skaitmeninė: %1', 'AUD.PPTY_NUMERIC', 'Požymis, ar taško savybės reikšmė turi būti skaitmeninė: %1', 'Požymis, ar taško savybės reikšmė turi būti skaitmeninė: %1'),
	(1364, 'Galimų matavimo taškų savybių sąrašų tipo kodas: %1', 'AUD.PPTY_TYPE_CODE', 'Galimų matavimo taškų savybių sąrašų tipo kodas: %1', 'Galimų matavimo taškų savybių sąrašų tipo kodas: %1'),
	(1365, 'Galimų matavimo taškų savybių sąrašų tipo identifikatorius: %1', 'AUD.PPTY_TYPE_ID', 'Galimų matavimo taškų savybių sąrašų tipo identifikatorius: %1', 'Galimų matavimo taškų savybių sąrašų tipo identifikatorius: %1'),
	(1366, 'Galimų matavimo taškų savybių sąrašų tipo pavadinimas: %1', 'AUD.PPTY_TYPE_NAME', 'Galimų matavimo taškų savybių sąrašų tipo pavadinimas: %1', 'Galimų matavimo taškų savybių sąrašų tipo pavadinimas: %1'),
	(1367, 'Matavimo taško savybės reikšmė: %1', 'AUD.PPTY_VALUE', 'Matavimo taško savybės reikšmė: %1', 'Matavimo taško savybės reikšmė: %1'),
	(1368, 'Tarifinio plano priskyrimo taškui pradžia: %1', 'AUD.PTP_BT', 'Tarifinio plano priskyrimo taškui pradžia: %1', 'Tarifinio plano priskyrimo taškui pradžia: %1'),
	(1369, 'Tarifinio plano priskyrimo taškui pabaiga: %1', 'AUD.PTP_ET', 'Tarifinio plano priskyrimo taškui pabaiga: %1', 'Tarifinio plano priskyrimo taškui pabaiga: %1'),
	(1370, 'Nustatyto tarifo plano identifikatorius matavimo taškui: %1', 'AUD.PTP_ID', 'Nustatyto tarifo plano identifikatorius matavimo taškui: %1', 'Nustatyto tarifo plano identifikatorius matavimo taškui: %1'),
	(1371, 'Užklausų priežasties kodas: %1', 'AUD.RC_CODE', 'Užklausų priežasties kodas: %1', 'Užklausų priežasties kodas: %1'),
	(1372, 'Užklausų priežasties identifikatorius: %1', 'AUD.RC_ID', 'Užklausų priežasties identifikatorius: %1', 'Užklausų priežasties identifikatorius: %1'),
	(1373, 'Sąryšio naudojimo požymis: %1', 'AUD.REL_ENABLED', 'Sąryšio naudojimo požymis: %1', 'Sąryšio naudojimo požymis: %1'),
	(1374, 'Sąryšio identifikatorius: %1', 'AUD.REL_ID', 'Sąryšio identifikatorius: %1', 'Sąryšio identifikatorius: %1'),
	(1375, 'Sąryšių tipo kodas: %1', 'AUD.REL_TYPE_CODE', 'Sąryšių tipo kodas: %1', 'Sąryšių tipo kodas: %1'),
	(1376, 'Sąryšių tipo identifikatorius: %1', 'AUD.REL_TYPE_ID', 'Sąryšių tipo identifikatorius: %1', 'Sąryšių tipo identifikatorius: %1'),
	(1377, 'Sąryšių tipo pavadinimas: %1', 'AUD.REL_TYPE_NAME', 'Sąryšių tipo pavadinimas: %1', 'Sąryšių tipo pavadinimas: %1'),
	(1378, 'Automatizuotos ataskaitos  užklausos sąlygos identifikatorius: %1', 'AUD.RPAPV_ID', 'Automatizuotos ataskaitos  užklausos sąlygos identifikatorius: %1', 'Automatizuotos ataskaitos  užklausos sąlygos identifikatorius: %1'),
	(1379, 'Atidėto automatizuotos ataskaitos siuntimo požymis: %1', 'AUD.RPA_DELAY_DELIVERY', 'Atidėto automatizuotos ataskaitos siuntimo požymis: %1', 'Atidėto automatizuotos ataskaitos siuntimo požymis: %1'),
	(1380, 'Automatizuotos ataskaitos galiojimo požymis: %1', 'AUD.RPA_ENABLED', 'Automatizuotos ataskaitos galiojimo požymis: %1', 'Automatizuotos ataskaitos galiojimo požymis: %1'),
	(1381, 'Automatizuotos ataskaitos identifikatorius: %1', 'AUD.RPA_ID', 'Automatizuotos ataskaitos identifikatorius: %1', 'Automatizuotos ataskaitos identifikatorius: %1'),
	(1382, 'Loginimo požymis: %1', 'AUD.RPA_LOG_ENABLED', 'Loginimo požymis: %1', 'Loginimo požymis: %1'),
	(1383, 'Automatizuotos ataskaitos pavadinimas: %1', 'AUD.RPA_NAME', 'Automatizuotos ataskaitos pavadinimas: %1', 'Automatizuotos ataskaitos pavadinimas: %1'),
	(1384, 'Ataskaitos formato kodas: %1', 'AUD.RPF_CODE', 'Ataskaitos formato kodas: %1', 'Ataskaitos formato kodas: %1'),
	(1385, 'Ataskaitos formato identifikatorius: %1', 'AUD.RPF_ID', 'Ataskaitos formato identifikatorius: %1', 'Ataskaitos formato identifikatorius: %1'),
	(1386, 'Automatizuotos ataskaitos protokolo kodas: %1', 'AUD.RPP_CODE', 'Automatizuotos ataskaitos protokolo kodas: %1', 'Automatizuotos ataskaitos protokolo kodas: %1'),
	(1387, 'Automatizuotos ataskaitos protokolo identifikatorius: %1', 'AUD.RPP_ID', 'Automatizuotos ataskaitos protokolo identifikatorius: %1', 'Automatizuotos ataskaitos protokolo identifikatorius: %1'),
	(1388, 'Rūšiavimo didėjančia tvarka požymis: %1', 'AUD.RPQC_ASC', 'Rūšiavimo didėjančia tvarka požymis: %1', 'Rūšiavimo didėjančia tvarka požymis: %1'),
	(1389, 'Užklausos stulpelio identifikatorius: %1', 'AUD.RPQC_ID', 'Užklausos stulpelio identifikatorius: %1', 'Užklausos stulpelio identifikatorius: %1'),
	(1390, 'Ataskaitos užklausos lauko numeris: %1', 'AUD.RPQC_NR', 'Ataskaitos užklausos lauko numeris: %1', 'Ataskaitos užklausos lauko numeris: %1'),
	(1391, 'Parametro tuščios reikšmės naudojimo požymis: %1', 'AUD.RPQF_ALLOW_EMPTY_VALUES', 'Parametro tuščios reikšmės naudojimo požymis: %1', 'Parametro tuščios reikšmės naudojimo požymis: %1'),
	(1392, 'Sąlygos aprašymas: %1', 'AUD.RPQF_DESC', 'Sąlygos aprašymas: %1', 'Sąlygos aprašymas: %1'),
	(1393, 'Būtinos sąlygos požymis: %1', 'AUD.RPQF_ESSENTIAL', 'Būtinos sąlygos požymis: %1', 'Būtinos sąlygos požymis: %1'),
	(1394, 'Ataskaitos užklausos sąlygos identifikatorius: %1', 'AUD.RPQF_ID', 'Ataskaitos užklausos sąlygos identifikatorius: %1', 'Ataskaitos užklausos sąlygos identifikatorius: %1'),
	(1395, 'Invertavimo požymis: %1', 'AUD.RPQF_INV', 'Invertavimo požymis: %1', 'Invertavimo požymis: %1'),
	(1396, 'Parametro eilės numeris: %1', 'AUD.RPQF_NR', 'Parametro eilės numeris: %1', 'Parametro eilės numeris: %1'),
	(1397, 'Užklausos sąlygos reikšmė: %1', 'AUD.RPQF_VALUE', 'Užklausos sąlygos reikšmė: %1', 'Užklausos sąlygos reikšmė: %1'),
	(1398, 'Užklausos sąlygų operatoriaus kodas: %1', 'AUD.RPQO_CODE', 'Užklausos sąlygų operatoriaus kodas: %1', 'Užklausos sąlygų operatoriaus kodas: %1'),
	(1399, 'Užklausos sąlygų operatoriaus identifikatorius: %1', 'AUD.RPQO_ID', 'Užklausos sąlygų operatoriaus identifikatorius: %1', 'Užklausos sąlygų operatoriaus identifikatorius: %1'),
	(1400, 'Užklausos funkcijos identifikatorius: %1', 'AUD.RPQU_ID', 'Užklausos funkcijos identifikatorius: %1', 'Užklausos funkcijos identifikatorius: %1'),
	(1401, 'Užklausos funkcijos pavadinimas: %1', 'AUD.RPQU_NAME', 'Užklausos funkcijos pavadinimas: %1', 'Užklausos funkcijos pavadinimas: %1'),
	(1402, 'Tiesiogiai įvestos SQL užklausos naudojimo požymis: %1', 'AUD.RPQ_ADVANCED', 'Tiesiogiai įvestos SQL užklausos naudojimo požymis: %1', 'Tiesiogiai įvestos SQL užklausos naudojimo požymis: %1'),
	(1403, 'Tik nepasikartojančių įrašų išrinkimo požymis: %1', 'AUD.RPQ_DISTINCT', 'Tik nepasikartojančių įrašų išrinkimo požymis: %1', 'Tik nepasikartojančių įrašų išrinkimo požymis: %1'),
	(1404, 'Ataskaitos užklausos identifikatorius: %1', 'AUD.RPQ_ID', 'Ataskaitos užklausos identifikatorius: %1', 'Ataskaitos užklausos identifikatorius: %1'),
	(1405, 'Užklausos įrašų kiekio apribojimas: %1', 'AUD.RPQ_MAXROWS', 'Užklausos įrašų kiekio apribojimas: %1', 'Užklausos įrašų kiekio apribojimas: %1'),
	(1406, 'Ataskaitos užklausos pavadinimas: %1', 'AUD.RPQ_NAME', 'Ataskaitos užklausos pavadinimas: %1', 'Ataskaitos užklausos pavadinimas: %1'),
	(1407, 'Tiesiogiai įvesta SQL užklausa: %1', 'AUD.RPQ_SLC', 'Tiesiogiai įvesta SQL užklausa: %1', 'Tiesiogiai įvesta SQL užklausa: %1'),
	(1408, 'Automatizuotos ataskaitos protokolo savybės identifikatorius: %1', 'AUD.RPTY_ID', 'Automatizuotos ataskaitos protokolo savybės identifikatorius: %1', 'Automatizuotos ataskaitos protokolo savybės identifikatorius: %1'),
	(1409, 'Automatizuotos ataskaitos protokolo savybės pavadinimas: %1', 'AUD.RPTY_NAME', 'Automatizuotos ataskaitos protokolo savybės pavadinimas: %1', 'Automatizuotos ataskaitos protokolo savybės pavadinimas: %1'),
	(1410, 'Automatizuotos ataskaitos savybės reikšmė: %1', 'AUD.RPTY_VALUE', 'Automatizuotos ataskaitos savybės reikšmė: %1', 'Automatizuotos ataskaitos savybės reikšmė: %1'),
	(1411, 'Ataskaitos aprašymas: %1', 'AUD.RP_DESCRIPTION', 'Ataskaitos aprašymas: %1', 'Ataskaitos aprašymas: %1'),
	(1412, 'Ataskaitos identifikatorius: %1', 'AUD.RP_ID', 'Ataskaitos identifikatorius: %1', 'Ataskaitos identifikatorius: %1'),
	(1413, 'Įrašų apie ataskaitą registravimo žurnale požymis: %1', 'AUD.RP_LOG_ENABLED', 'Įrašų apie ataskaitą registravimo žurnale požymis: %1', 'Įrašų apie ataskaitą registravimo žurnale požymis: %1'),
	(1414, 'Ataskaitos pavadinimas: %1', 'AUD.RP_NAME', 'Ataskaitos pavadinimas: %1', 'Ataskaitos pavadinimas: %1'),
	(1415, 'Viešos ataskaitos požymis: %1', 'AUD.RP_PUBLIC', 'Viešos ataskaitos požymis: %1', 'Viešos ataskaitos požymis: %1'),
	(1416, 'Ataskaitos tipo identifikatorius: %1', 'AUD.RP_TYPE_ID', 'Ataskaitos tipo identifikatorius: %1', 'Ataskaitos tipo identifikatorius: %1'),
	(1417, 'Ataskaitos tipo pavadinimas: %1', 'AUD.RP_TYPE_NAME', 'Ataskaitos tipo pavadinimas: %1', 'Ataskaitos tipo pavadinimas: %1'),
	(1418, 'Realaus laiko matavimų nuskaitymo profilio kodas: %1', 'AUD.RTP_CODE', 'Realaus laiko matavimų nuskaitymo profilio kodas: %1', 'Realaus laiko matavimų nuskaitymo profilio kodas: %1'),
	(1419, 'Realaus laiko matavimų nuskaitymo profilio identifikatorius: %1', 'AUD.RTP_ID', 'Realaus laiko matavimų nuskaitymo profilio identifikatorius: %1', 'Realaus laiko matavimų nuskaitymo profilio identifikatorius: %1'),
	(1420, 'Periodų kiekis apibrėžiantis trukmę, kurią matavimo reikšmė laikoma dabartine: %1', 'AUD.RTP_INT_VALUE', 'Periodų kiekis apibrėžiantis trukmę, kurią matavimo reikšmė laikoma dabartine: %1', 'Periodų kiekis apibrėžiantis trukmę, kurią matavimo reikšmė laikoma dabartine: %1'),
	(1421, 'Matavimo linijos naudojimo realaus laiko matavimų profilyje požymis: %1', 'AUD.RTP_ML_ENABLED', 'Matavimo linijos naudojimo realaus laiko matavimų profilyje požymis: %1', 'Matavimo linijos naudojimo realaus laiko matavimų profilyje požymis: %1'),
	(1422, 'Realaus laiko matavimų nuskaitymo profilio pavadinimas: %1', 'AUD.RTP_NAME', 'Realaus laiko matavimų nuskaitymo profilio pavadinimas: %1', 'Realaus laiko matavimų nuskaitymo profilio pavadinimas: %1'),
	(1423, 'Bendro naudojimo dienos programos požymis: %1', 'AUD.SAMD_COMMON', 'Bendro naudojimo dienos programos požymis: %1', 'Bendro naudojimo dienos programos požymis: %1'),
	(1424, 'Šablono dienos programos ID: %1', 'AUD.SAMD_ID', 'Šablono dienos programos ID: %1', 'Šablono dienos programos ID: %1'),
	(1425, 'Šablono dienos programos pavadinimas: %1', 'AUD.SAMD_NAME', 'Šablono dienos programos pavadinimas: %1', 'Šablono dienos programos pavadinimas: %1'),
	(1426, 'Šablono periodo ID: %1', 'AUD.SAMP_ID', 'Šablono periodo ID: %1', 'Šablono periodo ID: %1'),
	(1427, 'Periodų kiekis, nusakantis šablono periodo trukmę: %1', 'AUD.SAMP_INT_VALUE', 'Periodų kiekis, nusakantis šablono periodo trukmę: %1', 'Periodų kiekis, nusakantis šablono periodo trukmę: %1'),
	(1428, 'Periodų, kuriais nusakoma šablono periodo trukmė, identifikatorius: %1', 'AUD.SAMP_PER_ID', 'Periodų, kuriais nusakoma šablono periodo trukmė, identifikatorius: %1', 'Periodų, kuriais nusakoma šablono periodo trukmė, identifikatorius: %1'),
	(1429, 'Periodų kiekis, nusakantis nuskaitomos monitoringo rodiklio istorijos gylį: %1', 'AUD.SAMU_DEPTH', 'Periodų kiekis, nusakantis nuskaitomos monitoringo rodiklio istorijos gylį: %1', 'Periodų kiekis, nusakantis nuskaitomos monitoringo rodiklio istorijos gylį: %1'),
	(1430, 'Periodų, kuriais nusakomas nuskaitomos monitoringo rodiklio istorijos gylis, identifikatorius: %1', 'AUD.SAMU_DEPTH_PER_ID', 'Periodų, kuriais nusakomas nuskaitomos monitoringo rodiklio istorijos gylis, identifikatorius: %1', 'Periodų, kuriais nusakomas nuskaitomos monitoringo rodiklio istorijos gylis, identifikatorius: %1'),
	(1431, 'Automatinio šablono atnaujinimo pagal monitoringo rodiklio istoriją užduoties naudojimo požymis: %1', 'AUD.SAMU_ENABLED', 'Automatinio šablono atnaujinimo pagal monitoringo rodiklio istoriją užduoties naudojimo požymis: %1', 'Automatinio šablono atnaujinimo pagal monitoringo rodiklio istoriją užduoties naudojimo požymis: %1'),
	(1432, 'Periodų kiekis, nusakantis nuskaitomos monitoringo rodiklio istorijos poslinkį: %1', 'AUD.SAMU_LAG', 'Periodų kiekis, nusakantis nuskaitomos monitoringo rodiklio istorijos poslinkį: %1', 'Periodų kiekis, nusakantis nuskaitomos monitoringo rodiklio istorijos poslinkį: %1'),
	(1433, 'Periodų, kuriais nusakomas nuskaitomos monitoringo rodiklio istorijos poslinkis, identifikatorius: %1', 'AUD.SAMU_LAG_PER_ID', 'Periodų, kuriais nusakomas nuskaitomos monitoringo rodiklio istorijos poslinkis, identifikatorius: %1', 'Periodų, kuriais nusakomas nuskaitomos monitoringo rodiklio istorijos poslinkis, identifikatorius: %1'),
	(1434, 'Automatinio šablonų atnaujinimo pagal monitoringo rodiklių istoriją užduočių tipo identifikatorius: %1', 'AUD.SAMU_TYPE_ID', 'Automatinio šablonų atnaujinimo pagal monitoringo rodiklių istoriją užduočių tipo identifikatorius: %1', 'Automatinio šablonų atnaujinimo pagal monitoringo rodiklių istoriją užduočių tipo identifikatorius: %1'),
	(1435, 'Bendro naudojimo savaitės programos požymis: %1', 'AUD.SAMW_COMMON', 'Bendro naudojimo savaitės programos požymis: %1', 'Bendro naudojimo savaitės programos požymis: %1'),
	(1436, 'Šablono savaitės programos ID: %1', 'AUD.SAMW_ID', 'Šablono savaitės programos ID: %1', 'Šablono savaitės programos ID: %1'),
	(1437, 'Šablono savaitės programos pavadinimas: %1', 'AUD.SAMW_NAME', 'Šablono savaitės programos pavadinimas: %1', 'Šablono savaitės programos pavadinimas: %1'),
	(1438, 'Šablonų savaitės programų tipo identifikatorius: %1', 'AUD.SAMW_TYPE_ID', 'Šablonų savaitės programų tipo identifikatorius: %1', 'Šablonų savaitės programų tipo identifikatorius: %1'),
	(1439, 'Šablono kodas: %1', 'AUD.SAM_CODE', 'Šablono kodas: %1', 'Šablono kodas: %1'),
	(1440, 'Požymis, ar šablono periodai sudaro pastovų metų ciklą: %1', 'AUD.SAM_CYCLIC', 'Požymis, ar šablono periodai sudaro pastovų metų ciklą: %1', 'Požymis, ar šablono periodai sudaro pastovų metų ciklą: %1'),
	(1441, 'Šablono identifikatorius: %1', 'AUD.SAM_ID', 'Šablono identifikatorius: %1', 'Šablono identifikatorius: %1'),
	(1442, 'Šablono pavadinimas: %1', 'AUD.SAM_NAME', 'Šablono pavadinimas: %1', 'Šablono pavadinimas: %1'),
	(1443, 'Šablonų tipo ID: %1', 'AUD.SAM_TYPE_ID', 'Šablonų tipo ID: %1', 'Šablonų tipo ID: %1'),
	(1444, 'Šablonų tipo pavadinimas: %1', 'AUD.SAM_TYPE_NAME', 'Šablonų tipo pavadinimas: %1', 'Šablonų tipo pavadinimas: %1'),
	(1445, 'Šablono elemento reikšmė: %1', 'AUD.SAM_V', 'Šablono elemento reikšmė: %1', 'Šablono elemento reikšmė: %1'),
	(1446, 'Pakaitos duomenų daugiklis: %1', 'AUD.SBST_A', 'Pakaitos duomenų daugiklis: %1', 'Pakaitos duomenų daugiklis: %1'),
	(1447, 'Pakaitos duomenų tiesinio transformavimo požymis: %1', 'AUD.SBST_AB', 'Pakaitos duomenų tiesinio transformavimo požymis: %1', 'Pakaitos duomenų tiesinio transformavimo požymis: %1'),
	(1448, 'Pakaitos duomenų dedamoji: %1', 'AUD.SBST_B', 'Pakaitos duomenų dedamoji: %1', 'Pakaitos duomenų dedamoji: %1'),
	(1449, 'Pakaitos naudojimo požymis: %1', 'AUD.SBST_ENABLED', 'Pakaitos naudojimo požymis: %1', 'Pakaitos naudojimo požymis: %1'),
	(1450, 'Požymis, ar galimi geresni nei pakaitos duomenys: %1', 'AUD.SBST_IMPROVABLE', 'Požymis, ar galimi geresni nei pakaitos duomenys: %1', 'Požymis, ar galimi geresni nei pakaitos duomenys: %1'),
	(1451, 'Periodų kiekis, apibrėžiantis pakaitos užlaikymą: %1', 'AUD.SBST_LAG', 'Periodų kiekis, apibrėžiantis pakaitos užlaikymą: %1', 'Periodų kiekis, apibrėžiantis pakaitos užlaikymą: %1'),
	(1452, 'Pakaitai naudojamos matavimo linijos matavimo taške identifikatorius: %1', 'AUD.SBST_PL_ID', 'Pakaitai naudojamos matavimo linijos matavimo taške identifikatorius: %1', 'Pakaitai naudojamos matavimo linijos matavimo taške identifikatorius: %1'),
	(1453, 'Požymis, ar pakaitos duomenis pažymėti specialiu duomenų statuso požymiu: %1', 'AUD.SBST_SF', 'Požymis, ar pakaitos duomenis pažymėti specialiu duomenų statuso požymiu: %1', 'Požymis, ar pakaitos duomenis pažymėti specialiu duomenų statuso požymiu: %1'),
	(1454, 'Paprasto tvarkaraščio numeris: %1', 'AUD.SCHI_NR', 'Paprasto tvarkaraščio numeris: %1', 'Paprasto tvarkaraščio numeris: %1'),
	(1455, 'Tvarkaraščio identifikatorius: %1', 'AUD.SCH_ID', 'Tvarkaraščio identifikatorius: %1', 'Tvarkaraščio identifikatorius: %1'),
	(1456, 'Tvarkaraščių intervalo identifikatorius: %1', 'AUD.SCH_INT_ID', 'Tvarkaraščių intervalo identifikatorius: %1', 'Tvarkaraščių intervalo identifikatorius: %1'),
	(1457, 'Tvarkaraščių intervalo pavadinimas: %1', 'AUD.SCH_INT_NAME', 'Tvarkaraščių intervalo pavadinimas: %1', 'Tvarkaraščių intervalo pavadinimas: %1'),
	(1458, 'Laiko vienetų kiekis: %1', 'AUD.SCH_INT_VALUE', 'Laiko vienetų kiekis: %1', 'Laiko vienetų kiekis: %1'),
	(1459, 'Tvarkaraščio pavadinimas: %1', 'AUD.SCH_NAME', 'Tvarkaraščio pavadinimas: %1', 'Tvarkaraščio pavadinimas: %1'),
	(1460, 'Paprasto tvarkaraščio pakartojimų požymis: %1', 'AUD.SCH_REPEAT', 'Paprasto tvarkaraščio pakartojimų požymis: %1', 'Paprasto tvarkaraščio pakartojimų požymis: %1'),
	(1461, 'Paprasto tvarkaraščio pakartojimų kiekis: %1', 'AUD.SCH_REPEAT_TIMES', 'Paprasto tvarkaraščio pakartojimų kiekis: %1', 'Paprasto tvarkaraščio pakartojimų kiekis: %1'),
	(1462, 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, naudojimo požymis: %1', 'AUD.SEP_ENABLED', 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, naudojimo požymis: %1', 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, naudojimo požymis: %1'),
	(1463, 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius: %1', 'AUD.SEP_ID', 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius: %1', 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius: %1'),
	(1464, 'Periodų kiekis, apibrėžiantis nuskaitymo gylį: %1', 'AUD.SEP_RC_DEPTH', 'Periodų kiekis, apibrėžiantis nuskaitymo gylį: %1', 'Periodų kiekis, apibrėžiantis nuskaitymo gylį: %1'),
	(1465, 'Periodų kiekis, apibrėžiantis nuskaitymo poslinkį: %1', 'AUD.SEP_RC_LAG', 'Periodų kiekis, apibrėžiantis nuskaitymo poslinkį: %1', 'Periodų kiekis, apibrėžiantis nuskaitymo poslinkį: %1'),
	(1466, 'Duomenų šaltinio elemento daugiklis: %1', 'AUD.SE_A', 'Duomenų šaltinio elemento daugiklis: %1', 'Duomenų šaltinio elemento daugiklis: %1'),
	(1467, 'Šaltinio elemento duomenų tiesinio transformavimo ryšio modulyje požymis: %1', 'AUD.SE_AB', 'Šaltinio elemento duomenų tiesinio transformavimo ryšio modulyje požymis: %1', 'Šaltinio elemento duomenų tiesinio transformavimo ryšio modulyje požymis: %1'),
	(1468, 'Duomenų šaltinio elemento dedamoji: %1', 'AUD.SE_B', 'Duomenų šaltinio elemento dedamoji: %1', 'Duomenų šaltinio elemento dedamoji: %1'),
	(1469, 'Duomenų šaltinio elemento naudojimo požymis: %1', 'AUD.SE_ENABLED', 'Duomenų šaltinio elemento naudojimo požymis: %1', 'Duomenų šaltinio elemento naudojimo požymis: %1'),
	(1470, 'Duomenų šaltinio elemento priverstinio užpildymo požymis: %1', 'AUD.SE_FORCED', 'Duomenų šaltinio elemento priverstinio užpildymo požymis: %1', 'Duomenų šaltinio elemento priverstinio užpildymo požymis: %1'),
	(1471, 'Istorinių duomenų egzistavimo požymis: %1', 'AUD.SE_H', 'Istorinių duomenų egzistavimo požymis: %1', 'Istorinių duomenų egzistavimo požymis: %1'),
	(1472, 'Istorinių duomenų apribojimo laikas: %1', 'AUD.SE_H_BOUND', 'Istorinių duomenų apribojimo laikas: %1', 'Istorinių duomenų apribojimo laikas: %1'),
	(1473, 'Laiko periodų kiekis, apibrėžiantis istorinių duomenų gylį: %1', 'AUD.SE_H_DEPTH', 'Laiko periodų kiekis, apibrėžiantis istorinių duomenų gylį: %1', 'Laiko periodų kiekis, apibrėžiantis istorinių duomenų gylį: %1'),
	(1474, 'Istorinių duomenų gylio laiko vienetų identifikatorius : %1', 'AUD.SE_H_PER_ID', 'Istorinių duomenų gylio laiko vienetų identifikatorius : %1', 'Istorinių duomenų gylio laiko vienetų identifikatorius : %1'),
	(1475, 'Laiko periodų kiekis, apibrėžiantis istorinių duomenų, kurie gali būti atnaujinami šaltinyje, gylį: %1', 'AUD.SE_H_RESTORE_DEPTH', 'Laiko periodų kiekis, apibrėžiantis istorinių duomenų, kurie gali būti atnaujinami šaltinyje, gylį: %1', 'Laiko periodų kiekis, apibrėžiantis istorinių duomenų, kurie gali būti atnaujinami šaltinyje, gylį: %1'),
	(1476, 'Istorinių duomenų, kurie gali būti atnaujinami šaltinyje, gylio laiko vienetų identifikatorius: %1', 'AUD.SE_H_RESTORE_PER_ID', 'Istorinių duomenų, kurie gali būti atnaujinami šaltinyje, gylio laiko vienetų identifikatorius: %1', 'Istorinių duomenų, kurie gali būti atnaujinami šaltinyje, gylio laiko vienetų identifikatorius: %1'),
	(1477, 'Duomenų šaltinio elemento identifikatorius: %1', 'AUD.SE_ID', 'Duomenų šaltinio elemento identifikatorius: %1', 'Duomenų šaltinio elemento identifikatorius: %1'),
	(1478, 'Duomenų šaltinių šablono elemento ID: %1', 'AUD.SE_TMPL_ID', 'Duomenų šaltinių šablono elemento ID: %1', 'Duomenų šaltinių šablono elemento ID: %1'),
	(1479, 'Duomenų pluošto šaltinių šablono elemento ID: %1', 'AUD.SE_TMPL_SHEAF_ID', 'Duomenų pluošto šaltinių šablono elemento ID: %1', 'Duomenų pluošto šaltinių šablono elemento ID: %1'),
	(1480, 'Duomenų pluošto identifikatorius: %1', 'AUD.SHEAF_ID', 'Duomenų pluošto identifikatorius: %1', 'Duomenų pluošto identifikatorius: %1'),
	(1481, 'Duomenų pluošto pavadinimas: %1', 'AUD.SHEAF_NAME', 'Duomenų pluošto pavadinimas: %1', 'Duomenų pluošto pavadinimas: %1'),
	(1482, 'Įvykių atvejų kiekio lyginimo ženklas: %1', 'AUD.SI_CNT', 'Įvykių atvejų kiekio lyginimo ženklas: %1', 'Įvykių atvejų kiekio lyginimo ženklas: %1'),
	(1483, 'Susijusių nuskaitymo taškų kiekio lyginimo ženklas: %1', 'AUD.SI_DPT', 'Susijusių nuskaitymo taškų kiekio lyginimo ženklas: %1', 'Susijusių nuskaitymo taškų kiekio lyginimo ženklas: %1'),
	(1484, 'Susijusių apskaitos būsenų signalų kiekio lyginimo ženklas: %1', 'AUD.SI_DSC', 'Susijusių apskaitos būsenų signalų kiekio lyginimo ženklas: %1', 'Susijusių apskaitos būsenų signalų kiekio lyginimo ženklas: %1'),
	(1485, 'Susijusių grupių kiekio lyginimo ženklas: %1', 'AUD.SI_GRP', 'Susijusių grupių kiekio lyginimo ženklas: %1', 'Susijusių grupių kiekio lyginimo ženklas: %1'),
	(1486, 'Susijusių apskaitos taškų kiekio lyginimo ženklas: %1', 'AUD.SI_PNT', 'Susijusių apskaitos taškų kiekio lyginimo ženklas: %1', 'Susijusių apskaitos taškų kiekio lyginimo ženklas: %1'),
	(1487, 'Sistemos savybės kodas: %1', 'AUD.SPTY_CODE', 'Sistemos savybės kodas: %1', 'Sistemos savybės kodas: %1'),
	(1488, 'Sistemos savybės reikšmė pagal nutylėjimą: %1', 'AUD.SPTY_DEFAULT', 'Sistemos savybės reikšmė pagal nutylėjimą: %1', 'Sistemos savybės reikšmė pagal nutylėjimą: %1'),
	(1489, 'Sistemos savybės identifikatorius: %1', 'AUD.SPTY_ID', 'Sistemos savybės identifikatorius: %1', 'Sistemos savybės identifikatorius: %1'),
	(1490, 'Sistemos savybės pavadinimas: %1', 'AUD.SPTY_NAME', 'Sistemos savybės pavadinimas: %1', 'Sistemos savybės pavadinimas: %1'),
	(1491, 'Sistemos savybės eilės numeris rušiavimui: %1', 'AUD.SPTY_NR', 'Sistemos savybės eilės numeris rušiavimui: %1', 'Sistemos savybės eilės numeris rušiavimui: %1'),
	(1492, 'Požymis, ar sistemos savybės reikšmė turi būti skaitmeninė: %1', 'AUD.SPTY_NUMERIC', 'Požymis, ar sistemos savybės reikšmė turi būti skaitmeninė: %1', 'Požymis, ar sistemos savybės reikšmė turi būti skaitmeninė: %1'),
	(1493, 'Sistemos savybių tipo identifikatorius: %1', 'AUD.SPTY_TYPE_ID', 'Sistemos savybių tipo identifikatorius: %1', 'Sistemos savybių tipo identifikatorius: %1'),
	(1494, 'Sistemos savybės reikšmė: %1', 'AUD.SPTY_VALUE', 'Sistemos savybės reikšmė: %1', 'Sistemos savybės reikšmė: %1'),
	(1495, 'Ryšio kanalo ir duomenų šaltinio sąsajos identifikatorius: %1', 'AUD.SP_ID', 'Ryšio kanalo ir duomenų šaltinio sąsajos identifikatorius: %1', 'Ryšio kanalo ir duomenų šaltinio sąsajos identifikatorius: %1'),
	(1496, 'Šaltinio galiojimo pradžia: %1', 'AUD.SRC_BT', 'Šaltinio galiojimo pradžia: %1', 'Šaltinio galiojimo pradžia: %1'),
	(1497, 'Duomenų šaltinio naudojimo požymis: %1', 'AUD.SRC_ENABLED', 'Duomenų šaltinio naudojimo požymis: %1', 'Duomenų šaltinio naudojimo požymis: %1'),
	(1498, 'Šaltinio galiojimo pabaiga: %1', 'AUD.SRC_ET', 'Šaltinio galiojimo pabaiga: %1', 'Šaltinio galiojimo pabaiga: %1'),
	(1499, 'Duomenų šaltinio identifikatorius: %1', 'AUD.SRC_ID', 'Duomenų šaltinio identifikatorius: %1', 'Duomenų šaltinio identifikatorius: %1'),
	(1500, 'Šaltinio pavadinimas: %1', 'AUD.SRC_NAME', 'Šaltinio pavadinimas: %1', 'Šaltinio pavadinimas: %1'),
	(1501, 'Šaltinio numeris: %1', 'AUD.SRC_NUMBER', 'Šaltinio numeris: %1', 'Šaltinio numeris: %1'),
	(1502, 'Statistikos rinkimo požymis duomenų šaltiniui: %1', 'AUD.SRC_SAVE_STATISTICS', 'Statistikos rinkimo požymis duomenų šaltiniui: %1', 'Statistikos rinkimo požymis duomenų šaltiniui: %1'),
	(1503, 'Duomenų šaltinių šablono kodas: %1', 'AUD.SRC_TMPL_CODE', 'Duomenų šaltinių šablono kodas: %1', 'Duomenų šaltinių šablono kodas: %1'),
	(1504, 'Duomenų šaltinių šablono ID: %1', 'AUD.SRC_TMPL_ID', 'Duomenų šaltinių šablono ID: %1', 'Duomenų šaltinių šablono ID: %1'),
	(1505, 'Duomenų šaltinių šablono keletui taškų požymis: %1', 'AUD.SRC_TMPL_MULTIPOINT', 'Duomenų šaltinių šablono keletui taškų požymis: %1', 'Duomenų šaltinių šablono keletui taškų požymis: %1'),
	(1506, 'Duomenų šaltinių šablono pavadinimas: %1', 'AUD.SRC_TMPL_NAME', 'Duomenų šaltinių šablono pavadinimas: %1', 'Duomenų šaltinių šablono pavadinimas: %1'),
	(1507, 'Duomenų šaltinių tipo kodas: %1', 'AUD.SRC_TYPE_CODE', 'Duomenų šaltinių tipo kodas: %1', 'Duomenų šaltinių tipo kodas: %1'),
	(1508, 'Duomenų šaltinių tipo identifikatorius: %1', 'AUD.SRC_TYPE_ID', 'Duomenų šaltinių tipo identifikatorius: %1', 'Duomenų šaltinių tipo identifikatorius: %1'),
	(1509, 'Vasaros laiko naudojimo požymis: %1', 'AUD.SRC_TZ_DST_USED', 'Vasaros laiko naudojimo požymis: %1', 'Vasaros laiko naudojimo požymis: %1'),
	(1510, 'Objekto tipo, kuriam identifikuojama nusistovėjusi būsena, identifikatorius: %1', 'AUD.STEADY_TYPE_ID', 'Objekto tipo, kuriam identifikuojama nusistovėjusi būsena, identifikatorius: %1', 'Objekto tipo, kuriam identifikuojama nusistovėjusi būsena, identifikatorius: %1'),
	(1511, 'Požymis, ar duomenų reikšmė tinkama saugojimui: %1', 'AUD.STORABLE', 'Požymis, ar duomenų reikšmė tinkama saugojimui: %1', 'Požymis, ar duomenų reikšmė tinkama saugojimui: %1'),
	(1512, 'Lentelės vardas: %1', 'AUD.TABLE_NAME', 'Lentelės vardas: %1', 'Lentelės vardas: %1'),
	(1513, 'Tarifo spalva: %1', 'AUD.TFF_COLOR', 'Tarifo spalva: %1', 'Tarifo spalva: %1'),
	(1514, 'Tarifo naudojimo požymis: %1', 'AUD.TFF_ENABLED', 'Tarifo naudojimo požymis: %1', 'Tarifo naudojimo požymis: %1'),
	(1515, 'Tarifo identifikatorius: %1', 'AUD.TFF_ID', 'Tarifo identifikatorius: %1', 'Tarifo identifikatorius: %1'),
	(1516, 'Tarifo pavadinimas: %1', 'AUD.TFF_NAME', 'Tarifo pavadinimas: %1', 'Tarifo pavadinimas: %1'),
	(1517, 'Tarifų plano periodo identifikatorius: %1', 'AUD.TPP_ID', 'Tarifų plano periodo identifikatorius: %1', 'Tarifų plano periodo identifikatorius: %1'),
	(1518, 'Tarifų plano identifikatorius: %1', 'AUD.TP_ID', 'Tarifų plano identifikatorius: %1', 'Tarifų plano identifikatorius: %1'),
	(1519, 'Tarifų plano pavadinimas: %1', 'AUD.TP_NAME', 'Tarifų plano pavadinimas: %1', 'Tarifų plano pavadinimas: %1'),
	(1520, 'Paskirties požymis: %1', 'AUD.TS_ID', 'Paskirties požymis: %1', 'Paskirties požymis: %1'),
	(1521, 'Išeities paskirties požymio pavadinimas: %1', 'AUD.TS_NAME', 'Išeities paskirties požymio pavadinimas: %1', 'Išeities paskirties požymio pavadinimas: %1'),
	(1522, 'Laiko zonos kodas: %1', 'AUD.TZ_CODE', 'Laiko zonos kodas: %1', 'Laiko zonos kodas: %1'),
	(1523, 'Laiko zonos identifikatorius: %1', 'AUD.TZ_ID', 'Laiko zonos identifikatorius: %1', 'Laiko zonos identifikatorius: %1'),
	(1524, 'Vartotojų grupės identifikatorius: %1', 'AUD.UG_ID', 'Vartotojų grupės identifikatorius: %1', 'Vartotojų grupės identifikatorius: %1'),
	(1525, 'Vartotojų grupės pavadinimas: %1', 'AUD.UG_NAME', 'Vartotojų grupės pavadinimas: %1', 'Vartotojų grupės pavadinimas: %1'),
	(1526, 'Sistemos vartotojo organizacija: %1', 'AUD.USER_COMPANY', 'Sistemos vartotojo organizacija: %1', 'Sistemos vartotojo organizacija: %1'),
	(1527, 'Sistemos vartotojo skyrius: %1', 'AUD.USER_DEPARTMENT', 'Sistemos vartotojo skyrius: %1', 'Sistemos vartotojo skyrius: %1'),
	(1528, 'Sistemos vartotojo elektroninio pašto adresas: %1', 'AUD.USER_EMAIL', 'Sistemos vartotojo elektroninio pašto adresas: %1', 'Sistemos vartotojo elektroninio pašto adresas: %1'),
	(1529, 'Vartotojo galiojimo požymis: %1', 'AUD.USER_ENABLED', 'Vartotojo galiojimo požymis: %1', 'Vartotojo galiojimo požymis: %1'),
	(1530, 'Sistemos vartotojo mobilaus telefono numeris: %1', 'AUD.USER_GSM', 'Sistemos vartotojo mobilaus telefono numeris: %1', 'Sistemos vartotojo mobilaus telefono numeris: %1'),
	(1531, 'Vartotojo identifikatorius: %1', 'AUD.USER_ID', 'Vartotojo identifikatorius: %1', 'Vartotojo identifikatorius: %1'),
	(1532, 'Sistemos vartotojo vieta: %1', 'AUD.USER_LOCATION', 'Sistemos vartotojo vieta: %1', 'Sistemos vartotojo vieta: %1'),
	(1533, 'Sistemos vartotojo vardas, pavardė: %1', 'AUD.USER_NAME', 'Sistemos vartotojo vardas, pavardė: %1', 'Sistemos vartotojo vardas, pavardė: %1'),
	(1534, 'Sistemos vartotojo telefono numeris: %1', 'AUD.USER_PHONE', 'Sistemos vartotojo telefono numeris: %1', 'Sistemos vartotojo telefono numeris: %1'),
	(1535, 'Pastovios reikšmės naudojimo požymis: %1', 'AUD.USE_CONST_VAL', 'Pastovios reikšmės naudojimo požymis: %1', 'Pastovios reikšmės naudojimo požymis: %1'),
	(1536, 'Kraštinės kodas: %1', 'AUD.VERGE_CODE', 'Kraštinės kodas: %1', 'Kraštinės kodas: %1'),
	(1537, 'Kraštinės ID: %1', 'AUD.VERGE_ID', 'Kraštinės ID: %1', 'Kraštinės ID: %1'),
	(1538, 'Kraštinės pavadinimas: %1', 'AUD.VERGE_NAME', 'Kraštinės pavadinimas: %1', 'Kraštinės pavadinimas: %1'),
	(1539, 'Rodymo požymis: %1', 'AUD.VISIBLE', 'Rodymo požymis: %1', 'Rodymo požymis: %1'),
	(1540, 'Verifikacijos profilio maksimali leistinoji procentinė paklaida: %1', 'AUD.VP_BIAS', 'Verifikacijos profilio maksimali leistinoji procentinė paklaida: %1', 'Verifikacijos profilio maksimali leistinoji procentinė paklaida: %1'),
	(1541, 'Verifikacijos profilio kodas: %1', 'AUD.VP_CODE', 'Verifikacijos profilio kodas: %1', 'Verifikacijos profilio kodas: %1'),
	(1542, 'Verifikacijos profilio identifikatorius: %1', 'AUD.VP_ID', 'Verifikacijos profilio identifikatorius: %1', 'Verifikacijos profilio identifikatorius: %1'),
	(1543, 'Verifikacijos profilio pavadinimas: %1', 'AUD.VP_NAME', 'Verifikacijos profilio pavadinimas: %1', 'Verifikacijos profilio pavadinimas: %1'),
	(1544, 'Verifikacijos profilio sąlygos numeris: %1', 'AUD.VP_NR', 'Verifikacijos profilio sąlygos numeris: %1', 'Verifikacijos profilio sąlygos numeris: %1'),
	(1545, 'Verifikacijos profilio atskirų pagal tarifus tikrinimų požymis: %1', 'AUD.VP_SEPARATE_TFF', 'Verifikacijos profilio atskirų pagal tarifus tikrinimų požymis: %1', 'Verifikacijos profilio atskirų pagal tarifus tikrinimų požymis: %1'),
	(1546, 'Verifikacijos profilio tikrinimų taikymas tik smulkiausiems agregavimo segmento tipo intervalams: %1', 'AUD.VP_SMALLEST_INTERVAL', 'Verifikacijos profilio tikrinimų taikymas tik smulkiausiems agregavimo segmento tipo intervalams: %1', 'Verifikacijos profilio tikrinimų taikymas tik smulkiausiems agregavimo segmento tipo intervalams: %1'),
	(1547, 'Savaitės dienos numeris: %1', 'AUD.WD', 'Savaitės dienos numeris: %1', 'Savaitės dienos numeris: %1'),
	(1548, 'Požymis, ar vykdyti pirmadieniais: %1', 'AUD.WD1', 'Požymis, ar vykdyti pirmadieniais: %1', 'Požymis, ar vykdyti pirmadieniais: %1'),
	(1549, 'Požymis, ar vykdyti antradieniais: %1', 'AUD.WD2', 'Požymis, ar vykdyti antradieniais: %1', 'Požymis, ar vykdyti antradieniais: %1'),
	(1550, 'Požymis, ar vykdyti trečiadieniais: %1', 'AUD.WD3', 'Požymis, ar vykdyti trečiadieniais: %1', 'Požymis, ar vykdyti trečiadieniais: %1'),
	(1551, 'Požymis, ar vykdyti ketvirtadieniais: %1', 'AUD.WD4', 'Požymis, ar vykdyti ketvirtadieniais: %1', 'Požymis, ar vykdyti ketvirtadieniais: %1'),
	(1552, 'Požymis, ar vykdyti penktadieniais: %1', 'AUD.WD5', 'Požymis, ar vykdyti penktadieniais: %1', 'Požymis, ar vykdyti penktadieniais: %1'),
	(1553, 'Požymis, ar vykdyti šeštadieniais: %1', 'AUD.WD6', 'Požymis, ar vykdyti šeštadieniais: %1', 'Požymis, ar vykdyti šeštadieniais: %1'),
	(1554, 'Požymis, ar vykdyti sekmadieniais: %1', 'AUD.WD7', 'Požymis, ar vykdyti sekmadieniais: %1', 'Požymis, ar vykdyti sekmadieniais: %1'),
	(1555, 'Požymis, ar vykdyti šventinėmis dienomis: %1', 'AUD.WD8', 'Požymis, ar vykdyti šventinėmis dienomis: %1', 'Požymis, ar vykdyti šventinėmis dienomis: %1'),
	(1556, 'Požymis, ar vykdyti specifiškai pagal savaitės dienas: %1', 'AUD.WD_SPECIFIC', 'Požymis, ar vykdyti specifiškai pagal savaitės dienas: %1', 'Požymis, ar vykdyti specifiškai pagal savaitės dienas: %1'),
	(1557, 'Požymis, kad periodas - savaitė: %1', 'AUD.WEEK', 'Požymis, kad periodas - savaitė: %1', 'Požymis, kad periodas - savaitė: %1'),
	(1558, 'Tarifų plano savaitės programos identifikatorius: %1', 'AUD.WPR_ID', 'Tarifų plano savaitės programos identifikatorius: %1', 'Tarifų plano savaitės programos identifikatorius: %1'),
	(1559, 'Tarifų plano savaitės programos pavadinimas: %1', 'AUD.WPR_NAME', 'Tarifų plano savaitės programos pavadinimas: %1', 'Tarifų plano savaitės programos pavadinimas: %1'),
	(1560, 'Apsikeitimo duomenimis adresato naudojimo požymis: %1', 'AUD.XA_ENABLED', 'Apsikeitimo duomenimis adresato naudojimo požymis: %1', 'Apsikeitimo duomenimis adresato naudojimo požymis: %1'),
	(1561, 'Apsikeitimo duomenimis adresato identifikatorius: %1', 'AUD.XA_ID', 'Apsikeitimo duomenimis adresato identifikatorius: %1', 'Apsikeitimo duomenimis adresato identifikatorius: %1'),
	(1562, 'Apsikeitimo duomenimis adresato pavadinimas: %1', 'AUD.XA_NAME', 'Apsikeitimo duomenimis adresato pavadinimas: %1', 'Apsikeitimo duomenimis adresato pavadinimas: %1'),
	(1563, 'Apsikeitimo duomenimis elemento identifikatorius: %1', 'AUD.XE_ID', 'Apsikeitimo duomenimis elemento identifikatorius: %1', 'Apsikeitimo duomenimis elemento identifikatorius: %1'),
	(1564, 'Apsikeitimo duomenimis elemento pavadinimas: %1', 'AUD.XE_NAME', 'Apsikeitimo duomenimis elemento pavadinimas: %1', 'Apsikeitimo duomenimis elemento pavadinimas: %1'),
	(1565, 'Apsikeitimo duomenimis formos mazgo kodas: %1', 'AUD.XFAU_CODE', 'Apsikeitimo duomenimis formos mazgo kodas: %1', 'Apsikeitimo duomenimis formos mazgo kodas: %1'),
	(1566, 'Apsikeitimo duomenimis formos mazgo antras kodas: %1', 'AUD.XFAU_CODE2', 'Apsikeitimo duomenimis formos mazgo antras kodas: %1', 'Apsikeitimo duomenimis formos mazgo antras kodas: %1'),
	(1567, 'Apsikeitimo duomenimis formos mazgo naudojimo požymis: %1', 'AUD.XFAU_ENABLED', 'Apsikeitimo duomenimis formos mazgo naudojimo požymis: %1', 'Apsikeitimo duomenimis formos mazgo naudojimo požymis: %1'),
	(1568, 'Apsikeitimo duomenimis formos mazgo identifikatorius: %1', 'AUD.XFAU_ID', 'Apsikeitimo duomenimis formos mazgo identifikatorius: %1', 'Apsikeitimo duomenimis formos mazgo identifikatorius: %1'),
	(1569, 'Apsikeitimo duomenimis formos mazgo pavadinimas: %1', 'AUD.XFAU_NAME', 'Apsikeitimo duomenimis formos mazgo pavadinimas: %1', 'Apsikeitimo duomenimis formos mazgo pavadinimas: %1'),
	(1570, 'Apsikeitimo duomenimis formos mazgo antras pavadinimas: %1', 'AUD.XFAU_NAME2', 'Apsikeitimo duomenimis formos mazgo antras pavadinimas: %1', 'Apsikeitimo duomenimis formos mazgo antras pavadinimas: %1'),
	(1571, 'Apsikeitimo duomenimis formų mazgų tipo identifikatorius: %1', 'AUD.XFAU_TYPE_ID', 'Apsikeitimo duomenimis formų mazgų tipo identifikatorius: %1', 'Apsikeitimo duomenimis formų mazgų tipo identifikatorius: %1'),
	(1572, 'Apsikeitimo duomenimis formų mazgų tipo pavadinimas: %1', 'AUD.XFAU_TYPE_NAME', 'Apsikeitimo duomenimis formų mazgų tipo pavadinimas: %1', 'Apsikeitimo duomenimis formų mazgų tipo pavadinimas: %1'),
	(1573, 'Apsikeitimo duomenimis formos sekcijos kodas: %1', 'AUD.XFA_CODE', 'Apsikeitimo duomenimis formos sekcijos kodas: %1', 'Apsikeitimo duomenimis formos sekcijos kodas: %1'),
	(1574, 'Apsikeitimo duomenimis formos sekcijos naudojimo požymis: %1', 'AUD.XFA_ENABLED', 'Apsikeitimo duomenimis formos sekcijos naudojimo požymis: %1', 'Apsikeitimo duomenimis formos sekcijos naudojimo požymis: %1'),
	(1575, 'Apsikeitimo duomenimis formos sekcijos identifikatorius: %1', 'AUD.XFA_ID', 'Apsikeitimo duomenimis formos sekcijos identifikatorius: %1', 'Apsikeitimo duomenimis formos sekcijos identifikatorius: %1'),
	(1576, 'Apsikeitimo duomenimis formos sekcijos pavadinimas: %1', 'AUD.XFA_NAME', 'Apsikeitimo duomenimis formos sekcijos pavadinimas: %1', 'Apsikeitimo duomenimis formos sekcijos pavadinimas: %1'),
	(1577, 'Apsikeitimo duomenimis formos sekcijos laiko zona: %1', 'AUD.XFA_TZ', 'Apsikeitimo duomenimis formos sekcijos laiko zona: %1', 'Apsikeitimo duomenimis formos sekcijos laiko zona: %1'),
	(1578, 'Apsikeitimo duomenimis formos sekcijos vasaros laiko naudojimo požymis: %1', 'AUD.XFA_TZ_DST_USED', 'Apsikeitimo duomenimis formos sekcijos vasaros laiko naudojimo požymis: %1', 'Apsikeitimo duomenimis formos sekcijos vasaros laiko naudojimo požymis: %1'),
	(1579, 'Apsikeitimo duomenimis formos elemento naudojimo požymis: %1', 'AUD.XFE_ENABLED', 'Apsikeitimo duomenimis formos elemento naudojimo požymis: %1', 'Apsikeitimo duomenimis formos elemento naudojimo požymis: %1'),
	(1580, 'Apsikeitimo duomenimis formos elemento identifikatorius: %1', 'AUD.XFE_ID', 'Apsikeitimo duomenimis formos elemento identifikatorius: %1', 'Apsikeitimo duomenimis formos elemento identifikatorius: %1'),
	(1581, 'Apsikeitimo duomenimis formos elemento informacija: %1', 'AUD.XFE_INFO', 'Apsikeitimo duomenimis formos elemento informacija: %1', 'Apsikeitimo duomenimis formos elemento informacija: %1'),
	(1582, 'Apsikeitimo duomenimis formos naudojimo požymis: %1', 'AUD.XF_ENABLED', 'Apsikeitimo duomenimis formos naudojimo požymis: %1', 'Apsikeitimo duomenimis formos naudojimo požymis: %1'),
	(1583, 'Apsikeitimo duomenimis formos identifikatorius: %1', 'AUD.XF_ID', 'Apsikeitimo duomenimis formos identifikatorius: %1', 'Apsikeitimo duomenimis formos identifikatorius: %1'),
	(1584, 'Importo/eksporto formos požymis: %1', 'AUD.XF_IMPORT', 'Importo/eksporto formos požymis: %1', 'Importo/eksporto formos požymis: %1'),
	(1585, 'Apsikeitimo duomenimis formos pavadinimas: %1', 'AUD.XF_NAME', 'Apsikeitimo duomenimis formos pavadinimas: %1', 'Apsikeitimo duomenimis formos pavadinimas: %1'),
	(1586, 'Periodų kiekis, apibrėžiantis išsiuntimo gylį: %1', 'AUD.XF_RC_DEPTH', 'Periodų kiekis, apibrėžiantis išsiuntimo gylį: %1', 'Periodų kiekis, apibrėžiantis išsiuntimo gylį: %1'),
	(1587, 'Periodų kiekis, apibrėžiantis išsiuntimo poslinkį: %1', 'AUD.XF_RC_LAG', 'Periodų kiekis, apibrėžiantis išsiuntimo poslinkį: %1', 'Periodų kiekis, apibrėžiantis išsiuntimo poslinkį: %1'),
	(1588, 'Apsikeitimo duomenimis formų tipo kodas: %1', 'AUD.XF_TYPE_CODE', 'Apsikeitimo duomenimis formų tipo kodas: %1', 'Apsikeitimo duomenimis formų tipo kodas: %1'),
	(1589, 'Apsikeitimo duomenimis formų tipo identifikatorius: %1', 'AUD.XF_TYPE_ID', 'Apsikeitimo duomenimis formų tipo identifikatorius: %1', 'Apsikeitimo duomenimis formų tipo identifikatorius: %1'),
	(1590, 'Duomenų periodo pradžia: %1', 'AUD.XO_BT', 'Duomenų periodo pradžia: %1', 'Duomenų periodo pradžia: %1'),
	(1591, 'Duomenų periodo pabaiga: %1', 'AUD.XO_ET', 'Duomenų periodo pabaiga: %1', 'Duomenų periodo pabaiga: %1'),
	(1592, 'Apsikeitimo duomenimis formų savybės kodas: %1', 'AUD.XPTY_CODE', 'Apsikeitimo duomenimis formų savybės kodas: %1', 'Apsikeitimo duomenimis formų savybės kodas: %1'),
	(1593, 'Apsikeitimo duomenimis formų savybės identifikatorius: %1', 'AUD.XPTY_ID', 'Apsikeitimo duomenimis formų savybės identifikatorius: %1', 'Apsikeitimo duomenimis formų savybės identifikatorius: %1'),
	(1594, 'Apsikeitimo duomenimis formos savybės reikšmė: %1', 'AUD.XPTY_VALUE', 'Apsikeitimo duomenimis formos savybės reikšmė: %1', 'Apsikeitimo duomenimis formos savybės reikšmė: %1'),
	(1595, 'Duomenų nuskaitymo taškas: %1\nŠaltinio pav.: %2\nRyšio kanalo pav.: %3\nMatavimo taško kodas: %4\nDuomenų pluošto pav.: %5', 'AUD.DP_CODE.SRC_NAME.PH_NAME.POINT_CODE.SHEAF_NAME', 'Duomenų nuskaitymo taškas: %1\nŠaltinio pav.: %2\nRyšio kanalo pav.: %3\nMatavimo taško kodas: %4\nDuomenų pluošto pav.: %5', 'Duomenų nuskaitymo taškas: %1\nŠaltinio pav.: %2\nRyšio kanalo pav.: %3\nMatavimo taško kodas: %4\nDuomenų pluošto pav.: %5'),
	(1596, 'Kodo ir pavadinimo paveldėjimo požymis: %1\nApskaitos būsenų signalo kodas: %2', 'AUD.INHERIT_CN.DS_CODE', 'Kodo ir pavadinimo paveldėjimo požymis: %1\nApskaitos būsenų signalo kodas: %2', 'Kodo ir pavadinimo paveldėjimo požymis: %1\nApskaitos būsenų signalo kodas: %2'),
	(1597, 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2\nMatavimo taško kodas: %3\nMatavimo linijos pavadinimas: %4', 'AUD.DP_CODE.SRC_NAME.POINT_CODE.ML_NAME', 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2\nMatavimo taško kodas: %3\nMatavimo linijos pavadinimas: %4', 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2\nMatavimo taško kodas: %3\nMatavimo linijos pavadinimas: %4'),
	(1598, 'Matavimo taško kodas: %1\nMatavimo linijos pavadinimas: %2', 'AUD.POINT_CODE.ML_NAME', 'Matavimo taško kodas: %1\nMatavimo linijos pavadinimas: %2', 'Matavimo taško kodas: %1\nMatavimo linijos pavadinimas: %2'),
	(1599, 'Matavimo priemonės numeris: %1\nMatavimo priemonių tipo pavadinimas: %2', 'AUD.METER_NUMBER.METER_TYPE_NAME', 'Matavimo priemonės numeris: %1\nMatavimo priemonių tipo pavadinimas: %2', 'Matavimo priemonės numeris: %1\nMatavimo priemonių tipo pavadinimas: %2'),
	(1600, 'Matavimo taškas: %1\nMatavimo linija: %2\nEkonominės kat. pajamų/išlaidų pož.: %3\nGrupės proc. reikšmės naudojimo pož.: %4', 'AUD.POINT_CODE.ML_NAME.EC_IN.GPRC', 'Matavimo taškas: %1\nMatavimo linija: %2\nEkonominės kat. pajamų/išlaidų pož.: %3\nGrupės proc. reikšmės naudojimo pož.: %4', 'Matavimo taškas: %1\nMatavimo linija: %2\nEkonominės kat. pajamų/išlaidų pož.: %3\nGrupės proc. reikšmės naudojimo pož.: %4'),
	(1601, 'Akto numeris: %1\nMėnuo, kurio duomenys aktuojami: %2', 'AUD.ACT_NUMBER.ACT_MONTH', 'Akto numeris: %1\nMėnuo, kurio duomenys aktuojami: %2', 'Akto numeris: %1\nMėnuo, kurio duomenys aktuojami: %2'),
	(1602, 'Matavimo taško kodas: %1\nDuomenų pluošto pavadinimas: %2', 'AUD.POINT_CODE.SHEAF_NAME', 'Matavimo taško kodas: %1\nDuomenų pluošto pavadinimas: %2', 'Matavimo taško kodas: %1\nDuomenų pluošto pavadinimas: %2'),
	(1603, 'Duomenų nuskaitymo taško kodas: %1\nDuomenų pluošto pavadinimas: %2', 'AUD.DP_CODE.SHEAF_NAME', 'Duomenų nuskaitymo taško kodas: %1\nDuomenų pluošto pavadinimas: %2', 'Duomenų nuskaitymo taško kodas: %1\nDuomenų pluošto pavadinimas: %2'),
	(1604, 'Šaltinio pavadinimas: %1\nRyšio kanalo pavadinimas: %3', 'AUD.SRC_NAME.PH_NAME', 'Šaltinio pavadinimas: %1\nRyšio kanalo pavadinimas: %3', 'Šaltinio pavadinimas: %1\nRyšio kanalo pavadinimas: %3'),
	(1605, 'Kodo ir pavadinimo paveldėjimo požymis: %1\nGrupės kodas: %2', 'AUD.INHERIT_CN.GR_CODE', 'Kodo ir pavadinimo paveldėjimo požymis: %1\nGrupės kodas: %2', 'Kodo ir pavadinimo paveldėjimo požymis: %1\nGrupės kodas: %2'),
	(1606, 'Duomenų koncentratoriaus numeris: %1\nDuomenų koncentratoriaus tipo pavadinimas: %2', 'AUD.DEV_NUMBER.DEV_TYPE_NAME', 'Duomenų koncentratoriaus numeris: %1\nDuomenų koncentratoriaus tipo pavadinimas: %2', 'Duomenų koncentratoriaus numeris: %1\nDuomenų koncentratoriaus tipo pavadinimas: %2'),
	(1607, 'Duomenų šaltinių šablono kodas: %1\nMatavimo linijos pavadinimas: %2', 'AUD.SRC_TMPL_CODE.ML_NAME', 'Duomenų šaltinių šablono kodas: %1\nMatavimo linijos pavadinimas: %2', 'Duomenų šaltinių šablono kodas: %1\nMatavimo linijos pavadinimas: %2'),
	(1608, 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2\nMatavimo taško kodas: %3', 'AUD.DP_CODE.SRC_NAME.POINT_CODE', 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2\nMatavimo taško kodas: %3', 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2\nMatavimo taško kodas: %3'),
	(1609, 'Kodo ir pavadinimo paveldėjimo požymis: %1\nMatavimo taško kodas: %2', 'AUD.INHERIT_CN.POINT_CODE', 'Kodo ir pavadinimo paveldėjimo požymis: %1\nMatavimo taško kodas: %2', 'Kodo ir pavadinimo paveldėjimo požymis: %1\nMatavimo taško kodas: %2'),
	(1610, 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2\nRyšio kanalo pavadinimas: %3', 'AUD.DP_CODE.SRC_NAME.PH_NAME', 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2\nRyšio kanalo pavadinimas: %3', 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2\nRyšio kanalo pavadinimas: %3'),
	(1611, 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2\nApskaitos būsenų signalo kodas: %3', 'AUD.DP_CODE.SRC_NAME.DS_CODE', 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2\nApskaitos būsenų signalo kodas: %3', 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2\nApskaitos būsenų signalo kodas: %3'),
	(1612, 'Lentelės laukas: %1\nUžklausos sąlygų operatoriaus kodas: %2', 'AUD.COLUMN_NAME.RPQO_CODE', 'Lentelės laukas: %1\nUžklausos sąlygų operatoriaus kodas: %2', 'Lentelės laukas: %1\nUžklausos sąlygų operatoriaus kodas: %2'),
	(1613, 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2\nRyšio kanalo pavadinimas: %3\nDuomenų pluošto pavadinimas: %4', 'AUD.DP_CODE.SRC_NAME.PH_NAME.SHEAF_NAME', 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2\nRyšio kanalo pavadinimas: %3\nDuomenų pluošto pavadinimas: %4', 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2\nRyšio kanalo pavadinimas: %3\nDuomenų pluošto pavadinimas: %4'),
	(1614, 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pav.: %2\nRyšio kanalo pav.: %3\nApskaitos būsenų signalo kodas: %4', 'AUD.DP_CODE.SRC_NAME.PH_NAME.DS_CODE', 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pav.: %2\nRyšio kanalo pav.: %3\nApskaitos būsenų signalo kodas: %4', 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pav.: %2\nRyšio kanalo pav.: %3\nApskaitos būsenų signalo kodas: %4'),
	(1615, 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2', 'AUD.DP_CODE.SRC_NAME', 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2', 'Duomenų nuskaitymo taško kodas: %1\nŠaltinio pavadinimas: %2'),
	(1616, 'Matavimo taško kodas: %1\nSąryšių tipo kodas: %2', 'AUD.POINT_CODE.REL_TYPE_CODE', 'Matavimo taško kodas: %1\nSąryšių tipo kodas: %2', 'Matavimo taško kodas: %1\nSąryšių tipo kodas: %2'),
	(1619, 'Agregavimo segmento tipo pavadinimas: %1', 'AUD.AGGS_TYPE_NAME', 'Agregavimo segmento tipo pavadinimas', 'Agregavimo segmento tipo pavadinimas: %1'),
	(1620, 'Agregavimo funkcijos pavadinimas: %1', 'AUD.AGGF_NAME', 'Agregavimo funkcijos pavadinimas', 'Agregavimo funkcijos pavadinimas: %1'),
	(1621, 'Agregavimo segmento pavadinimas: %1', 'AUD.AGGS_NAME', 'Agregavimo segmento pavadinimas', 'Agregavimo segmento pavadinimas: %1'),
	(1622, 'Duomenų statuso kodinė išraiška: %1', 'AUD.DSTATUS', 'Duomenų statuso kodinė išraiška: %1', 'Duomenų statuso kodinė išraiška: %1'),
	(1623, 'Formulių ataskaitos požymis: %1', 'AUD.RP_FORMULA', 'Formulių ataskaitos požymis: %1', 'Formulių ataskaitos požymis: %1'),
	(1624, 'Pakaitos duomenų laiko išvedimas vietoj nuskaitymo laiko: %1', 'AUD.SBST_ALTER_READ_TIME', 'Pakaitos duomenų laiko išvedimas vietoj nuskaitymo laiko: %1', 'Pakaitos duomenų laiko išvedimas vietoj nuskaitymo laiko: %1'),
	(1625, 'Pakaitos siekinys (1-pirmas, 2-paskutinis, 3-artimiausias nuskaitymas): %1', 'AUD.SBST_FLN', 'Pakaitos siekinys (1-pirmas, 2-paskutinis, 3-artimiausias nuskaitymas): %1', 'Pakaitos siekinys (1-pirmas, 2-paskutinis, 3-artimiausias nuskaitymas): %1'),
	(1626, 'Pakaitos poslinkis: %1', 'AUD.SBST_OFFSET', 'Pakaitos poslinkis: %1', 'Pakaitos poslinkis: %1'),
	(1627, 'Periodų, kuriais nustatomas pakaitos poslinkis, identifikatorius: %1', 'AUD.SBST_OFFSET_PER_ID', 'Periodų, kuriais nustatomas pakaitos poslinkis, identifikatorius: %1', 'Periodų, kuriais nustatomas pakaitos poslinkis, identifikatorius: %1'),
	(1628, 'Pakaitos spindulys: %1', 'AUD.SBST_RADIUS', 'Pakaitos spindulys: %1', 'Pakaitos spindulys: %1'),
	(1629, 'Periodų, kuriais nustatomas pakaitos spindulys, identifikatorius: %1', 'AUD.SBST_RADIUS_PER_ID', 'Periodų, kuriais nustatomas pakaitos spindulys, identifikatorius: %1', 'Periodų, kuriais nustatomas pakaitos spindulys, identifikatorius: %1'),
	(1630, 'Transformuotas duomenų statusas: %1', 'AUD.TSTATUS', 'Transformuotas duomenų statusas: %1', 'Transformuotas duomenų statusas: %1'),
	(1631, 'Suformuota ataskaita "%1"%2', 'REPORT_GENERATED', 'Ataskaitų registravimas įvykių registre', 'Suformuota ataskaita "%1"%2'),
	(1632, 'už', 'FOR', 'už', 'už'),
	(1633, 'Visi pergeneravimui parinkti periodai uždaryti', 'INIT_GEN_POINT.ALL_PERIODS_CLOSE', 'Visi parinkti periodai uždaryti', 'Visi pergeneravimui parinkti periodai uždaryti'),
	(1634, 'Dalis periodų yra uždaryti ir pergeneruoti nebus', 'INIT_GEN_POINT.PART_PERIODS_CLOSE', 'Dalis parinktų periodų uždaryti', 'Dalis periodų yra uždaryti ir pergeneruoti nebus'),
	(1635, 'Nepavyko nurodytą specifinę užduotį atlikti serverinėje sesijoje', 'BACKGROUND_TASK_NOT_EXECUTING', 'Nepavyko užduotį atlikti serverinėje sesijoje', 'Nepavyko nurodytą specifinę užduotį atlikti serverinėje sesijoje');
/*!40000 ALTER TABLE `caption` ENABLE KEYS */;

-- Dumping structure for table emcor.cap_param
CREATE TABLE IF NOT EXISTS `cap_param` (
  `cap_id` mediumint(8) NOT NULL COMMENT 'Pranešimo identifikatorius',
  `cap_param_nr` tinyint(3) unsigned NOT NULL COMMENT 'Pranešimo parametro numeris',
  `cap_param_desc` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Pranešimo parametro apibūdinimas',
  PRIMARY KEY (`cap_id`,`cap_param_nr`),
  CONSTRAINT `cap_param_caption_fk` FOREIGN KEY (`cap_id`) REFERENCES `caption` (`cap_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Programinių pranešimų parametrai';

-- Dumping data for table emcor.cap_param: ~390 rows (approximately)
/*!40000 ALTER TABLE `cap_param` DISABLE KEYS */;
INSERT INTO `cap_param` (`cap_id`, `cap_param_nr`, `cap_param_desc`) VALUES
	(13, 1, 'parametro reikšmė 1'),
	(13, 2, 'parametro reikšmė 2'),
	(13, 3, 'parametro reikšmė 3'),
	(13, 4, 'parametro reikšmė 4'),
	(14, 1, 'Parametro pavadinimas'),
	(16, 1, 'data 1'),
	(16, 2, 'data 2'),
	(17, 1, 'data 1'),
	(17, 2, 'data 2'),
	(18, 1, 'skaitiklio tipas'),
	(19, 1, 'skaitiklio laikas'),
	(24, 1, 'masyvo ilgis'),
	(26, 1, 'įrašas'),
	(32, 1, 'grupė'),
	(32, 2, 'šablonas'),
	(34, 1, 'data 1'),
	(34, 2, 'data 2'),
	(34, 3, 'data 3'),
	(35, 1, 'data 1'),
	(35, 2, 'data 2'),
	(35, 3, 'data 3'),
	(38, 1, 'data 1'),
	(38, 2, 'data 2'),
	(38, 3, 'data 3'),
	(39, 1, 'energijos rūšis'),
	(40, 1, 'parametras 1'),
	(40, 2, 'parametras 2'),
	(41, 1, 'parametras 1'),
	(41, 2, 'parametras 2'),
	(45, 1, 'data'),
	(46, 1, 'data 1'),
	(46, 2, 'data 2'),
	(47, 1, 'numeris'),
	(47, 2, 'data'),
	(47, 3, 'rsk'),
	(47, 4, 'masyvo ilgis'),
	(48, 1, 'numeris'),
	(48, 2, 'data'),
	(48, 3, 'masyvo ilgis'),
	(49, 1, 'parametras'),
	(49, 2, 'laikas'),
	(50, 1, 'skaitiklio parametras'),
	(51, 1, 'data 1'),
	(51, 2, 'data 2'),
	(52, 1, 'tarifų skaičius'),
	(54, 1, 'skaitiklis'),
	(56, 1, 'data'),
	(56, 2, 'parametras'),
	(57, 1, 'data 1'),
	(57, 2, 'parametras'),
	(57, 3, 'data 2'),
	(58, 1, 'data'),
	(59, 1, 'parametras'),
	(60, 1, 'para 1'),
	(60, 2, 'para 2'),
	(60, 3, 'duomenys'),
	(60, 4, 'detalus duomenys'),
	(61, 1, 'para 1'),
	(61, 2, 'para 2'),
	(61, 3, 'duomenys'),
	(61, 4, 'detalus duomenys'),
	(62, 1, 'parametras 1'),
	(62, 2, 'parametras 2'),
	(63, 1, 'parametras 1'),
	(63, 2, 'parametras 2'),
	(64, 1, 'parametras 1'),
	(64, 2, 'parametras 2'),
	(65, 1, 'parametras 1'),
	(65, 2, 'parametras 2'),
	(66, 1, 'job number'),
	(67, 1, 'parametro reikšmė'),
	(68, 1, 'skaitiklio numeris'),
	(72, 1, 'data 1'),
	(72, 2, 'data 2'),
	(73, 1, 'data 1'),
	(73, 2, 'data 2'),
	(75, 1, 'data 1'),
	(76, 1, 'data 1'),
	(76, 2, 'data 2'),
	(77, 1, 'data 1'),
	(77, 2, 'data 2'),
	(78, 1, 'data 1'),
	(82, 1, 'diena'),
	(82, 2, 'valanda'),
	(82, 3, 'reikšmė 1'),
	(82, 4, 'reikšmė 2'),
	(82, 5, 'nustatyta reikšmė'),
	(82, 6, 'šablonas'),
	(82, 7, 'grupė'),
	(84, 1, 'identifikatorius'),
	(89, 1, 'parametras 1'),
	(89, 2, 'parametras 2'),
	(90, 1, 'parametras'),
	(96, 1, 'data'),
	(97, 1, 'data'),
	(102, 1, 'Rasti parametrai'),
	(103, 1, 'Rasti parametrai'),
	(104, 1, 'Vartotojas'),
	(104, 2, 'Parametro pavadinimas'),
	(105, 1, 'Vartotojas'),
	(105, 2, 'Parametro pavadinimas'),
	(106, 1, 'parametras 1'),
	(106, 2, 'parametras 2'),
	(107, 1, 'lentelė'),
	(108, 1, 'lauko reikšmė'),
	(109, 1, 'lauko reikšmė'),
	(110, 1, 'laiko žymė'),
	(115, 1, 'laikas'),
	(117, 1, 'area'),
	(117, 2, 'kanalas'),
	(118, 1, 'apskaitos mazgas'),
	(119, 1, 'modulis'),
	(135, 1, 'savybės reikšmė'),
	(140, 1, 'reikšmė 1'),
	(140, 2, 'reikšmė 2'),
	(144, 1, 'parametras 1'),
	(144, 2, 'parametras 2'),
	(148, 1, 'parametras 1'),
	(148, 2, 'parametras 2'),
	(150, 1, 'parametras 1'),
	(150, 2, 'parametras 2'),
	(150, 3, 'parametras3'),
	(152, 1, 'ryšio kanalo tipas'),
	(152, 2, 'duomenų šaltinis'),
	(155, 1, 'signalas'),
	(165, 1, 'apskaitos grupės kodas'),
	(166, 1, 'grupė-konteineris'),
	(167, 1, 'matavimo taško kodas'),
	(168, 1, 'ekonominis profilis'),
	(169, 1, 'apskaitos grupių tipas'),
	(170, 1, 'matavimų rinkinys'),
	(171, 1, 'matavimo priemonių tipas'),
	(172, 1, 'apskaitos grupių savybė'),
	(173, 1, 'matavimo taškų savybė'),
	(175, 1, 'duomenų šaltinis'),
	(176, 1, 'elementas'),
	(176, 2, 'forma'),
	(178, 1, 'taško kodas'),
	(178, 2, 'šaltinis'),
	(180, 1, 'taško kodas'),
	(181, 1, 'šaltinio vardas'),
	(182, 1, 'matavimo kodas'),
	(183, 1, 'kryptis'),
	(184, 1, 'ekonominė kategorija'),
	(185, 1, 'taškų tipas'),
	(186, 1, 'parametras 1'),
	(186, 2, 'parametras 2'),
	(186, 3, 'parametras 3'),
	(186, 4, 'parametras 4'),
	(186, 5, 'parametras 5'),
	(187, 1, 'parametras 1'),
	(187, 2, 'parametras 2'),
	(192, 1, 'matavimo priemonių savybė'),
	(193, 1, 'sistemos savybė'),
	(194, 1, 'šaltinio vardas'),
	(194, 2, 'taškas'),
	(196, 1, 'tvarkaraštis'),
	(196, 2, 'paprastas tvarkaraštis '),
	(197, 1, 'failo vardas'),
	(203, 1, 'sekcija'),
	(203, 2, 'failas'),
	(219, 1, 'Duomenų šaltinio elemento augimo riba'),
	(220, 1, 'Matavimo pavadinimas'),
	(220, 2, 'Sena reikšmė'),
	(220, 3, 'Sena pirminė reikšmė'),
	(220, 4, 'Sena laiko žymė'),
	(220, 5, 'Nauja reikšmė'),
	(220, 6, 'Nauja pirminė reikšmė'),
	(220, 7, 'Nauja laiko žymė'),
	(221, 1, 'Užduočių kiekis'),
	(221, 2, 'Valandų kiekis'),
	(223, 1, 'Matavimo ir krypties kodas'),
	(223, 2, 'Uždaromo agregavimo segmento tipo pavadinimas'),
	(223, 3, 'Uždaromo agregavimo segmento matavimo reikšmė'),
	(223, 4, 'Palyginamojo agregavimo segmento tipo pavadinimas'),
	(223, 5, 'Palyginamojo agregavimo segmento matavimo reikšmė'),
	(223, 6, 'Uždaromas periodas'),
	(224, 1, 'Matavimo ir krypties kodas'),
	(224, 2, 'Uždaromo agregavimo segmento tipo pavadinimas'),
	(224, 3, 'Uždaromo agregavimo segmento matavimo reikšmė'),
	(224, 4, 'Palyginamojo agregavimo segmento tipo pavadinimas'),
	(224, 5, 'Palyginamojo agregavimo segmento matavimo reikšmė'),
	(224, 6, 'Uždaromas periodas'),
	(225, 1, 'Matavimo ir krypties kodas'),
	(225, 2, 'Uždaromo agregavimo segmento tipo pavadinimas'),
	(225, 3, 'Uždaromo agregavimo segmento matavimo reikšmė'),
	(225, 4, 'Palyginamojo agregavimo segmento tipo pavadinimas'),
	(225, 5, 'Palyginamojo agregavimo segmento matavimo reikšmė'),
	(225, 6, 'Uždaromas periodas'),
	(225, 7, 'Tarifas'),
	(226, 1, 'Matavimo ir krypties kodas'),
	(226, 2, 'Uždaromo agregavimo segmento tipo pavadinimas'),
	(226, 3, 'Uždaromo agregavimo segmento matavimo reikšmė'),
	(226, 4, 'Palyginamojo agregavimo segmento tipo pavadinimas'),
	(226, 5, 'Palyginamojo agregavimo segmento matavimo reikšmė'),
	(226, 6, 'Uždaromas periodas'),
	(227, 1, 'Matavimo ir krypties kodas'),
	(227, 2, 'Uždaromo agregavimo segmento tipo pavadinimas'),
	(227, 3, 'Uždaromo agregavimo segmento matavimo reikšmė'),
	(227, 4, 'Palyginamojo agregavimo segmento tipo pavadinimas'),
	(227, 5, 'Palyginamojo agregavimo segmento matavimo reikšmė'),
	(227, 6, 'Uždaromas periodas'),
	(228, 1, 'Matavimo ir krypties kodas'),
	(228, 2, 'Uždaromo agregavimo segmento tipo pavadinimas'),
	(228, 3, 'Uždaromo agregavimo segmento matavimo reikšmė'),
	(228, 4, 'Palyginamojo agregavimo segmento tipo pavadinimas'),
	(228, 5, 'Palyginamojo agregavimo segmento matavimo reikšmė'),
	(228, 6, 'Uždaromas periodas'),
	(228, 7, 'Tarifas'),
	(229, 1, 'Duomenų statuso kodas'),
	(230, 1, 'Užblokuoto vartotojo vardas'),
	(230, 2, 'Vartotojo užblokavimo data'),
	(231, 1, 'Išvardinimas'),
	(232, 1, 'Matavimo taškų savybių tipas'),
	(233, 1, 'Matavimo prietaisų savybių tipas'),
	(234, 1, 'Nerastas apskaitos grupių savybių tipas'),
	(235, 1, 'Išvardinimų naudojimo tipas'),
	(236, 1, 'Apsikeitimo duomenimis formos mazgo kodas'),
	(236, 2, 'Matavimo taško kodas'),
	(236, 3, 'Matavimo linijos pavadinimas'),
	(237, 1, 'Periodas'),
	(237, 2, 'Matavimo ir krypties kodas'),
	(237, 3, 'Uždaromo agregavimo segmento pavadinimas'),
	(238, 1, 'Periodas'),
	(238, 2, 'Matavimo ir krypties kodas'),
	(238, 3, 'Uždaromo agregavimo segmento pavadinimas'),
	(239, 1, 'Periodas'),
	(239, 2, 'Matavimo ir krypties kodas'),
	(239, 4, 'Palyginamojo agregavimo segmento tipo pavadinimas'),
	(240, 1, 'Periodas'),
	(240, 2, 'Matavimo ir krypties kodas'),
	(240, 4, 'Palyginamojo agregavimo segmento tipo pavadinimas'),
	(241, 1, 'Periodas'),
	(241, 2, 'Matavimo ir krypties kodas'),
	(241, 4, 'Palyginamojo agregavimo segmento tipo pavadinimas'),
	(242, 1, 'Periodas'),
	(242, 2, 'Matavimo ir krypties kodas'),
	(242, 3, 'Uždaromo agregavimo segmento pavadinimas'),
	(242, 4, 'Palyginamojo agregavimo segmento tipo pavadinimas'),
	(242, 5, 'Uždaromo agregavimo segmento matavimo reikšmė'),
	(242, 6, 'Palyginamojo agregavimo segmento matavimo reikšmė'),
	(243, 1, 'Periodas'),
	(243, 2, 'Matavimo ir krypties kodas'),
	(243, 3, 'Uždaromo agregavimo segmento pavadinimas'),
	(244, 1, 'Periodas'),
	(244, 2, 'Matavimo ir krypties kodas'),
	(244, 3, 'Uždaromo agregavimo segmento pavadinimas'),
	(245, 1, 'Periodas'),
	(245, 2, 'Matavimo ir krypties kodas'),
	(246, 1, 'Periodas'),
	(246, 2, 'Matavimo ir krypties kodas'),
	(247, 1, 'Periodas'),
	(247, 2, 'Matavimo ir krypties kodas'),
	(247, 3, 'Uždaromo agregavimo segmento pavadinimas'),
	(247, 4, 'Palyginamojo agregavimo segmento tipo pavadinimas'),
	(247, 5, 'Uždaromo agregavimo segmento matavimo reikšmė'),
	(247, 6, 'Palyginamojo agregavimo segmento matavimo reikšmė'),
	(250, 1, 'Periodas'),
	(250, 2, 'Bendras uždaromų taškų skaičius'),
	(250, 3, 'Neuždarytų taškų skaičius'),
	(251, 1, 'Periodas'),
	(263, 1, 'Ryšio prietaiso identifikatorius'),
	(263, 2, 'Adresas'),
	(263, 3, 'Portas'),
	(264, 1, 'Ryšio prietaiso identifikatorius'),
	(264, 2, 'Adresas'),
	(264, 3, 'Portas'),
	(265, 1, 'Ryšio prietaiso identifikatorius'),
	(265, 2, 'Adresas'),
	(265, 3, 'Portas'),
	(266, 1, 'Ryšio prietaiso identifikatorius'),
	(266, 2, 'Adresas'),
	(266, 3, 'Portas'),
	(277, 1, 'Periodas'),
	(277, 2, 'Matavimo ir krypties kodas'),
	(277, 4, 'Palyginamojo agregavimo segmento pavadinimas'),
	(278, 1, 'Periodas'),
	(278, 2, 'Matavimo ir krypties kodas'),
	(278, 3, 'Uždaromo agregavimo segmento pavadinimas'),
	(279, 1, 'Periodas'),
	(279, 2, 'Matavimo ir krypties kodas'),
	(279, 4, 'Palyginamojo agregavimo segmento pavadinimas'),
	(280, 1, 'Periodas'),
	(280, 2, 'Matavimo ir krypties kodas'),
	(280, 3, 'Uždaromo agregavimo segmento pavadinimas'),
	(288, 1, 'Užduočių kiekis'),
	(288, 2, 'Sekundžių kiekis'),
	(291, 1, 'Para'),
	(293, 1, 'Para'),
	(299, 1, 'Periodas'),
	(301, 1, 'Signalo reikšmė'),
	(303, 1, 'Parametras'),
	(304, 1, 'Parametras'),
	(305, 1, 'IP adresas'),
	(305, 2, 'MAC adresas'),
	(306, 1, 'IP adresas'),
	(306, 2, 'MAC adresas'),
	(307, 1, 'IP adresas'),
	(307, 2, 'Skaitiklio numeris'),
	(307, 3, 'Prietaiso ID'),
	(307, 4, 'Išsiuntimo laikas'),
	(308, 1, 'IP adresas'),
	(308, 2, 'Skaitiklio numeris'),
	(308, 3, 'Prietaiso ID'),
	(308, 4, 'Išsiuntimo laikas'),
	(309, 1, 'IP adresas'),
	(309, 2, 'Skaitiklio numeris'),
	(309, 3, 'Prietaiso ID'),
	(309, 4, 'Išsiuntimo laikas'),
	(310, 1, 'IP adresas'),
	(310, 2, 'Skaitiklio numeris'),
	(310, 3, 'Prietaiso ID'),
	(310, 4, 'Išsiuntimo laikas'),
	(311, 1, 'IP adresas'),
	(311, 2, 'Skaitiklio numeris'),
	(311, 3, 'Prietaiso ID'),
	(311, 4, 'Išsiuntimo laikas'),
	(312, 1, 'IP adresas'),
	(312, 2, 'Skaitiklio numeris'),
	(312, 3, 'Prietaiso ID'),
	(312, 4, 'Išsiuntimo laikas'),
	(312, 5, 'Nuskaitymo taškas'),
	(313, 1, 'IP adresas'),
	(313, 2, 'Skaitiklio numeris'),
	(313, 3, 'Prietaiso ID'),
	(313, 4, 'Išsiuntimo laikas'),
	(313, 5, 'Nuskaitymo taškas'),
	(314, 1, 'IP adresas'),
	(314, 2, 'Skaitiklio numeris'),
	(314, 3, 'Prietaiso ID'),
	(314, 4, 'Išsiuntimo laikas'),
	(315, 1, 'IP adresas'),
	(315, 2, 'Skaitiklio numeris'),
	(315, 3, 'Prietaiso ID'),
	(315, 4, 'Išsiuntimo laikas'),
	(319, 1, 'Konfigūracijos parametro ID'),
	(319, 2, 'Indekso numeris'),
	(319, 3, 'Indekso reikšmė'),
	(328, 1, 'Parametravimo įvykio pavadinimas'),
	(328, 2, 'Parametravimo data'),
	(329, 1, 'Parametravimo įvykio pavadinimas'),
	(329, 2, 'Parametravimo data'),
	(333, 1, 'Apskaitos taško kodas'),
	(334, 1, 'Apskaitos taško kodas'),
	(335, 1, 'Apskaitos taško kodas'),
	(336, 1, 'Apskaitos taško kodas'),
	(336, 2, 'Duomenų vytelės pavadinimas'),
	(339, 1, 'Vartotojas'),
	(339, 2, 'Relės būklė'),
	(340, 1, 'Vartotojas'),
	(341, 1, 'Vartotojas'),
	(342, 1, 'Vartotojas'),
	(343, 1, 'Vartotojas'),
	(344, 1, 'Vartotojas'),
	(345, 1, 'Vartotojas'),
	(348, 1, 'Vartotojo ID'),
	(348, 2, 'Intervalas'),
	(348, 3, 'Matavimas'),
	(350, 1, 'Vartotojas'),
	(350, 2, 'Šablono atnaujinimo modelis'),
	(351, 1, 'Vartotojas'),
	(351, 2, 'Šablono atnaujinimo modelis'),
	(351, 3, 'Skaičiavimo intervlas'),
	(355, 1, 'Parametrų skaičius'),
	(356, 1, 'Periodas'),
	(356, 2, 'Matavimo ir krypties kodas'),
	(356, 3, 'Uždaromo agregavimo segmento pavadinimas'),
	(356, 4, 'Palyginamojo agregavimo segmento tipo pavadinimas'),
	(356, 5, 'Uždaromo agregavimo segmento matavimo reikšmė'),
	(356, 6, 'Palyginamojo agregavimo segmento matavimo reikšmė'),
	(357, 1, 'Periodas'),
	(357, 2, 'Matavimo ir krypties kodas'),
	(357, 3, 'Uždaromo agregavimo segmento pavadinimas'),
	(357, 4, 'Palyginamojo agregavimo segmento tipo pavadinimas'),
	(357, 5, 'Uždaromo agregavimo segmento matavimo reikšmė'),
	(357, 6, 'Palyginamojo agregavimo segmento matavimo reikšmė'),
	(358, 1, 'Užsakymo ID'),
	(358, 2, 'Užsakymo aprašas'),
	(358, 3, 'Užsakymo statusas'),
	(359, 1, 'Užsakymo ID'),
	(360, 1, 'Kraunama versija'),
	(360, 2, 'Esama versija'),
	(361, 1, 'Išorinio rakto pavadinimas'),
	(362, 1, 'Trigerio pavadinimas'),
	(363, 1, 'Klaidų skaičius'),
	(364, 1, 'Klaidos pranešimas'),
	(365, 1, 'Duomenų perkelimo užsakymo ID'),
	(366, 1, 'Failo pavadinimas'),
	(1631, 1, 'Ataskaitos pavadinimas'),
	(1631, 2, 'Ataskaitos datų intervalas');
/*!40000 ALTER TABLE `cap_param` ENABLE KEYS */;

-- Dumping structure for table emcor.catalog
CREATE TABLE IF NOT EXISTS `catalog` (
  `catalog_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Katalogo identifikatorius',
  `catalog_code` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'Katalogo kodas',
  `catalog_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Katalogo pavadinimas',
  PRIMARY KEY (`catalog_id`),
  UNIQUE KEY `catalog_code_u` (`catalog_code`)
) ENGINE=InnoDB AUTO_INCREMENT=14 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Katalogai';

-- Dumping data for table emcor.catalog: ~12 rows (approximately)
/*!40000 ALTER TABLE `catalog` DISABLE KEYS */;
INSERT INTO `catalog` (`catalog_id`, `catalog_code`, `catalog_name`) VALUES
	(1, '61968', '61968'),
	(2, '61968_ev', '61968 events'),
	(3, '80030_ev', '80030 events'),
	(4, '80030_ev_imp', '80030 events for import'),
	(5, 'GamaDlms', 'GamaDlms'),
	(6, 'EMS', 'EMS'),
	(7, 'LZQM', 'LZQM'),
	(8, 'EPQM', 'EPQM'),
	(9, 'LZKM', 'LZKM'),
	(10, 'EPQS', 'EPQS'),
	(11, 'SL_DLMS', 'SL_DLMS'),
	(13, 'DKK64', 'DKK64');
/*!40000 ALTER TABLE `catalog` ENABLE KEYS */;

-- Dumping structure for table emcor.catalog_ml
CREATE TABLE IF NOT EXISTS `catalog_ml` (
  `catalog_id` mediumint(8) unsigned NOT NULL COMMENT 'Katalogo identifikatorius',
  `ml_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo linijos identifikatorius',
  `item_code` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Katalogo elemento kodas',
  `item_valid` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Katalogo elemento galiojimo požymis',
  `item_type_id` int(10) unsigned DEFAULT NULL COMMENT 'Katalogo elementų tipo identifikatorius',
  PRIMARY KEY (`catalog_id`,`ml_id`),
  KEY `catalog_ml_item_i` (`catalog_id`,`item_code`),
  KEY `catalog_ml_item_type_fk` (`item_type_id`),
  KEY `catalog_ml_ml_fk` (`ml_id`),
  CONSTRAINT `catalog_ml_catalog_fk` FOREIGN KEY (`catalog_id`) REFERENCES `catalog` (`catalog_id`) ON DELETE CASCADE,
  CONSTRAINT `catalog_ml_item_type_fk` FOREIGN KEY (`item_type_id`) REFERENCES `item_type` (`item_type_id`) ON DELETE SET NULL,
  CONSTRAINT `catalog_ml_ml_fk` FOREIGN KEY (`ml_id`) REFERENCES `ml` (`ml_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Katalogo matavimų linijos';

-- Dumping data for table emcor.catalog_ml: ~6 257 rows (approximately)
/*!40000 ALTER TABLE `catalog_ml` DISABLE KEYS */;
INSERT INTO `catalog_ml` (`catalog_id`, `ml_id`, `item_code`, `item_valid`, `item_type_id`) VALUES
	(1, 1, '0.6.2.1.0.12.3.1.0.3.72', 1, 3),
	(1, 2, '0.6.2.19.0.12.3.1.0.3.72', 1, 3),
	(1, 3, '0.6.2.1.0.12.3.1.0.3.73', 1, 3),
	(1, 4, '0.6.2.19.0.12.3.1.0.3.73', 1, 3),
	(1, 5, '0.6.2.1.0.12.3.2.0.3.72', 1, 3),
	(1, 6, '0.6.2.19.0.12.3.2.0.3.72', 1, 3),
	(1, 7, '0.6.2.1.0.12.3.2.0.3.73', 1, 3),
	(1, 8, '0.6.2.19.0.12.3.2.0.3.73', 1, 3),
	(1, 9, '0.6.2.1.0.12.3.3.0.3.72', 1, 3),
	(1, 10, '0.6.2.19.0.12.3.3.0.3.72', 1, 3),
	(1, 11, '0.6.2.1.0.12.3.3.0.3.73', 1, 3),
	(1, 12, '0.6.2.19.0.12.3.3.0.3.73', 1, 3),
	(1, 13, '0.6.2.1.0.12.3.4.0.3.72', 1, 3),
	(1, 14, '0.6.2.19.0.12.3.4.0.3.72', 1, 3),
	(1, 15, '0.6.2.1.0.12.3.4.0.3.73', 1, 3),
	(1, 16, '0.6.2.19.0.12.3.4.0.3.73', 1, 3),
	(1, 17, '15.2.7.1.0.12.3.1.0.3.72', 1, NULL),
	(1, 18, '15.2.7.19.0.12.3.1.0.3.72', 1, NULL),
	(1, 19, '15.2.7.1.0.12.3.1.0.3.73', 1, NULL),
	(1, 20, '15.2.7.19.0.12.3.1.0.3.73', 1, NULL),
	(1, 21, '15.2.7.1.0.12.3.2.0.3.72', 1, NULL),
	(1, 22, '15.2.7.19.0.12.3.2.0.3.72', 1, NULL),
	(1, 23, '15.2.7.1.0.12.3.2.0.3.73', 1, NULL),
	(1, 24, '15.2.7.19.0.12.3.2.0.3.73', 1, NULL),
	(1, 25, '15.2.7.1.0.12.3.3.0.3.72', 1, NULL),
	(1, 26, '15.2.7.19.0.12.3.3.0.3.72', 1, NULL),
	(1, 27, '15.2.7.1.0.12.3.3.0.3.73', 1, NULL),
	(1, 28, '15.2.7.19.0.12.3.3.0.3.73', 1, NULL),
	(1, 29, '15.2.7.1.0.12.3.4.0.3.72', 1, NULL),
	(1, 30, '15.2.7.19.0.12.3.4.0.3.72', 1, NULL),
	(1, 31, '15.2.7.1.0.12.3.4.0.3.73', 1, NULL),
	(1, 32, '15.2.7.19.0.12.3.4.0.3.73', 1, NULL),
	(1, 33, '4.2.7.1.0.12.3.1.0.3.72', 1, NULL),
	(1, 34, '4.2.7.19.0.12.3.1.0.3.72', 1, NULL),
	(1, 35, '4.2.7.1.0.12.3.1.0.3.73', 1, NULL),
	(1, 36, '4.2.7.19.0.12.3.1.0.3.73', 1, NULL),
	(1, 37, '4.2.7.1.0.12.3.2.0.3.72', 1, NULL),
	(1, 38, '4.2.7.19.0.12.3.2.0.3.72', 1, NULL),
	(1, 39, '4.2.7.1.0.12.3.2.0.3.73', 1, NULL),
	(1, 40, '4.2.7.19.0.12.3.2.0.3.73', 1, NULL),
	(1, 41, '4.2.7.1.0.12.3.3.0.3.72', 1, NULL),
	(1, 42, '4.2.7.19.0.12.3.3.0.3.72', 1, NULL),
	(1, 43, '4.2.7.1.0.12.3.3.0.3.73', 1, NULL),
	(1, 44, '4.2.7.19.0.12.3.3.0.3.73', 1, NULL),
	(1, 45, '4.2.7.1.0.12.3.4.0.3.72', 1, NULL),
	(1, 46, '4.2.7.19.0.12.3.4.0.3.72', 1, NULL),
	(1, 47, '4.2.7.1.0.12.3.4.0.3.73', 1, NULL),
	(1, 48, '4.2.7.19.0.12.3.4.0.3.73', 1, NULL),
	(1, 49, '5.2.7.1.0.37.0.0.0.3.38', 1, 1),
	(1, 50, '5.2.7.19.0.37.0.0.0.3.38', 1, 1),
	(1, 51, '5.2.7.1.0.37.0.0.0.3.63', 1, 1),
	(1, 52, '5.2.7.19.0.37.0.0.0.3.63', 1, 1),
	(1, 53, '0.2.6.0.0.4.0.0.128.0.5', 1, 3),
	(1, 54, '0.2.6.0.0.54.0.0.128.0.29', 1, 3),
	(1, 55, '0.2.6.0.0.4.0.0.64.0.5', 1, 3),
	(1, 56, '0.2.6.0.0.54.0.0.64.0.29', 1, 3),
	(1, 57, '0.2.6.0.0.4.0.0.32.0.5', 1, 3),
	(1, 58, '0.2.6.0.0.54.0.0.32.0.29', 1, 3),
	(1, 59, '0.2.6.0.0.54.0.0.128.0.29', 1, 3),
	(1, 60, '0.2.6.0.0.54.0.0.64.0.29', 1, 3),
	(1, 61, '0.2.6.0.0.54.0.0.32.0.29', 1, 3),
	(1, 62, '0.2.6.0.0.37.0.0.128.3.38', 1, 3),
	(1, 63, '0.2.6.0.0.37.0.0.64.3.38', 1, 3),
	(1, 64, '0.2.6.0.0.37.0.0.32.3.38', 1, 3),
	(1, 65, '0.2.6.0.0.37.0.0.128.3.63', 1, 3),
	(1, 66, '0.2.6.0.0.37.0.0.64.3.63', 1, 3),
	(1, 67, '0.2.6.0.0.37.0.0.32.3.63', 1, 3),
	(1, 68, '0.2.6.0.0.37.0.0.128.3.61', 1, 3),
	(1, 69, '0.2.6.0.0.37.0.0.64.3.61', 1, 3),
	(1, 70, '0.2.6.0.0.37.0.0.32.3.61', 1, 3),
	(1, 71, '0.2.6.0.x.x.0.0.128.0.0', 1, 3),
	(1, 72, '0.2.6.0.x.x.0.0.64.0.0', 1, 3),
	(1, 73, '0.2.6.0.x.x.0.0.32.0.0', 1, 3),
	(1, 74, '0.2.6.0.x.x.0.0.128.0.0', 1, 3),
	(1, 75, '0.2.6.0.x.x.0.0.64.0.0', 1, 3),
	(1, 76, '0.2.6.0.x.x.0.0.32.0.0', 1, 3),
	(1, 77, '0.2.6.0.0.4.0.0.x.0.5', 1, 3),
	(1, 78, '0.2.6.0.0.54.0.0.x.0.29', 1, 3),
	(1, 79, '0.2.6.0.0.54.0.0.x.0.29', 1, 3),
	(1, 80, '0.2.6.0.0.37.0.0.0.3.38', 1, 3),
	(1, 81, '0.2.6.0.0.37.0.0.0.3.63', 1, 3),
	(1, 82, '0.2.6.0.0.37.0.0.0.3.61', 1, 3),
	(1, 83, '0.2.6.0.x.x.0.0.x.0.0', 1, 3),
	(1, 84, '0.2.6.0.x.x.0.0.x.0.0', 1, 3),
	(1, 85, '0.2.6.0.x.x.0.0.x.0.33', 1, 3),
	(1, 86, '0.2.6.0.x.x.0.0.x.0.0', 1, 3),
	(1, 377, '7.2.7.1.0.37.0.0.0.3.38', 1, 1),
	(1, 378, '7.2.7.19.0.37.0.0.0.3.38', 1, 1),
	(1, 379, '7.2.7.1.0.37.0.0.0.3.63', 1, 1),
	(1, 380, '7.2.7.19.0.37.0.0.0.3.63', 1, 1),
	(1, 381, '15.2.7.1.0.12.0.0.0.3.72', 1, NULL),
	(1, 382, '15.2.7.19.0.12.0.0.0.3.72', 1, NULL),
	(1, 383, '15.2.7.1.0.12.0.0.0.3.73', 1, NULL),
	(1, 384, '15.2.7.19.0.12.0.0.0.3.73', 1, NULL),
	(1, 385, '4.2.7.1.0.12.0.0.0.3.72', 1, NULL),
	(1, 386, '4.2.7.19.0.12.0.0.0.3.72', 1, NULL),
	(1, 387, '4.2.7.1.0.12.0.0.0.3.73', 1, NULL),
	(1, 388, '4.2.7.19.0.12.0.0.0.3.73', 1, NULL),
	(1, 389, '4.2.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 390, '4.2.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 391, '4.2.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 392, '4.2.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 458, '3.2.7.1.0.12.0.0.0.3.72', 1, NULL),
	(1, 459, '3.2.7.19.0.12.0.0.0.3.72', 1, NULL),
	(1, 460, '3.2.7.1.0.12.0.0.0.3.73', 1, NULL),
	(1, 461, '3.2.7.19.0.12.0.0.0.3.73', 1, NULL),
	(1, 462, '3.2.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 463, '3.2.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 464, '3.2.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 465, '3.2.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 555, '10.2.7.1.0.12.0.0.0.3.72', 1, NULL),
	(1, 556, '10.2.7.19.0.12.0.0.0.3.72', 1, NULL),
	(1, 557, '10.2.7.1.0.12.0.0.0.3.73', 1, NULL),
	(1, 558, '10.2.7.19.0.12.0.0.0.3.73', 1, NULL),
	(1, 559, '10.2.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 560, '10.2.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 561, '10.2.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 562, '10.2.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 652, '14.2.7.1.0.12.0.0.0.3.72', 1, NULL),
	(1, 653, '14.2.7.19.0.12.0.0.0.3.72', 1, NULL),
	(1, 654, '14.2.7.1.0.12.0.0.0.3.73', 1, NULL),
	(1, 655, '14.2.7.19.0.12.0.0.0.3.73', 1, NULL),
	(1, 656, '14.2.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 657, '14.2.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 658, '14.2.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 659, '14.2.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 749, 'x.2.7.1.0.12.0.0.0.3.72', 1, NULL),
	(1, 750, 'x.2.7.19.0.12.0.0.0.3.72', 1, NULL),
	(1, 751, 'x.2.7.1.0.12.0.0.0.3.73', 1, NULL),
	(1, 752, 'x.2.7.19.0.12.0.0.0.3.73', 1, NULL),
	(1, 753, 'x.2.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 754, 'x.2.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 755, 'x.2.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 756, 'x.2.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 846, '6.2.7.1.0.12.0.0.0.3.72', 1, NULL),
	(1, 847, '6.2.7.19.0.12.0.0.0.3.72', 1, NULL),
	(1, 848, '6.2.7.1.0.12.0.0.0.3.73', 1, NULL),
	(1, 849, '6.2.7.19.0.12.0.0.0.3.73', 1, NULL),
	(1, 850, '6.2.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 851, '6.2.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 852, '6.2.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 853, '6.2.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 943, '1.2.7.1.0.12.0.0.0.3.72', 1, NULL),
	(1, 944, '1.2.7.19.0.12.0.0.0.3.72', 1, NULL),
	(1, 945, '1.2.7.1.0.12.0.0.0.3.73', 1, NULL),
	(1, 946, '1.2.7.19.0.12.0.0.0.3.73', 1, NULL),
	(1, 947, '1.2.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 948, '1.2.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 949, '1.2.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 950, '1.2.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 1040, '2.2.7.1.0.12.0.0.0.3.72', 1, 1),
	(1, 1041, '2.2.7.19.0.12.0.0.0.3.72', 1, 1),
	(1, 1042, '2.2.7.1.0.12.0.0.0.3.73', 1, 1),
	(1, 1043, '2.2.7.19.0.12.0.0.0.3.73', 1, 1),
	(1, 1044, '2.2.7.1.0.37.0.0.0.3.38', 1, 1),
	(1, 1045, '2.2.7.19.0.37.0.0.0.3.38', 1, 1),
	(1, 1046, '2.2.7.1.0.37.0.0.0.3.63', 1, 1),
	(1, 1047, '2.2.7.19.0.37.0.0.0.3.63', 1, 1),
	(1, 1137, 'x.2.7.1.0.12.0.0.0.3.72', 1, 1),
	(1, 1138, 'x.2.7.19.0.12.0.0.0.3.72', 1, 1),
	(1, 1139, 'x.2.7.1.0.12.0.0.0.3.73', 1, 1),
	(1, 1140, 'x.2.7.19.0.12.0.0.0.3.73', 1, 1),
	(1, 1141, 'x.2.7.1.0.37.0.0.0.3.38', 1, 1),
	(1, 1142, 'x.2.7.19.0.37.0.0.0.3.38', 1, 1),
	(1, 1143, 'x.2.7.1.0.37.0.0.0.3.63', 1, 1),
	(1, 1144, 'x.2.7.19.0.37.0.0.0.3.63', 1, 1),
	(1, 1234, '5.2.7.1.0.12.0.0.0.3.72', 1, 1),
	(1, 1235, '5.2.7.19.0.12.0.0.0.3.72', 1, 1),
	(1, 1236, '5.2.7.1.0.12.0.0.0.3.73', 1, 1),
	(1, 1237, '5.2.7.19.0.12.0.0.0.3.73', 1, 1),
	(1, 1294, '7.2.7.15.0.37.0.0.0.3.63', 1, 1),
	(1, 1295, '15.2.7.15.0.12.0.0.0.3.73', 1, NULL),
	(1, 1296, '4.2.7.15.0.12.0.0.0.3.73', 1, NULL),
	(1, 1297, '4.2.7.15.0.37.0.0.0.3.63', 1, NULL),
	(1, 1298, 'x.6.2.15.0.12.3.1.0.3.73', 1, 3),
	(1, 1299, 'x.6.2.15.0.12.3.2.0.3.73', 1, 3),
	(1, 1300, 'x.6.2.15.0.12.3.3.0.3.73', 1, 3),
	(1, 1301, 'x.6.2.15.0.12.3.4.0.3.73', 1, 3),
	(1, 1302, '15.2.7.15.0.12.3.1.0.3.73', 1, NULL),
	(1, 1303, '15.2.7.15.0.12.3.2.0.3.73', 1, NULL),
	(1, 1304, '15.2.7.15.0.12.3.3.0.3.73', 1, NULL),
	(1, 1305, '15.2.7.15.0.12.3.4.0.3.73', 1, NULL),
	(1, 1306, '4.2.7.15.0.12.3.1.0.3.73', 1, NULL),
	(1, 1307, '4.2.7.15.0.12.3.2.0.3.73', 1, NULL),
	(1, 1308, '4.2.7.15.0.12.3.3.0.3.73', 1, NULL),
	(1, 1309, '4.2.7.15.0.12.3.4.0.3.73', 1, NULL),
	(1, 1310, '5.2.7.15.0.37.0.0.0.3.63', 1, 1),
	(1, 1311, 'x.2.7.15.0.12.0.0.0.3.73', 1, 1),
	(1, 1312, 'x.2.7.15.0.37.0.0.0.3.63', 1, 1),
	(1, 1313, '3.2.7.15.0.12.0.0.0.3.73', 1, NULL),
	(1, 1314, '3.2.7.15.0.37.0.0.0.3.63', 1, NULL),
	(1, 1315, '10.2.7.15.0.12.0.0.0.3.73', 1, NULL),
	(1, 1316, '10.2.7.15.0.37.0.0.0.3.63', 1, NULL),
	(1, 1317, '14.2.7.15.0.12.0.0.0.3.73', 1, NULL),
	(1, 1318, '14.2.7.15.0.37.0.0.0.3.63', 1, NULL),
	(1, 1319, 'x.2.7.15.0.12.0.0.0.3.73', 1, NULL),
	(1, 1320, 'x.2.7.15.0.37.0.0.0.3.63', 1, NULL),
	(1, 1321, '6.2.7.15.0.12.0.0.0.3.73', 1, NULL),
	(1, 1322, '6.2.7.15.0.37.0.0.0.3.63', 1, NULL),
	(1, 1323, '1.2.7.15.0.12.0.0.0.3.73', 1, NULL),
	(1, 1324, '1.2.7.15.0.37.0.0.0.3.63', 1, NULL),
	(1, 1325, '2.2.7.15.0.12.0.0.0.3.73', 1, 1),
	(1, 1326, '2.2.7.15.0.37.0.0.0.3.63', 1, 1),
	(1, 1327, '5.2.7.15.0.12.0.0.0.3.73', 1, 1),
	(1, 1328, '7.2.7.16.0.37.0.0.0.3.63', 1, 1),
	(1, 1329, '15.2.7.16.0.12.0.0.0.3.73', 1, NULL),
	(1, 1330, '4.2.7.16.0.12.0.0.0.3.73', 1, NULL),
	(1, 1331, '4.2.7.16.0.37.0.0.0.3.63', 1, NULL),
	(1, 1332, 'x.6.2.16.0.12.3.1.0.3.73', 1, 3),
	(1, 1333, 'x.6.2.16.0.12.3.2.0.3.73', 1, 3),
	(1, 1334, 'x.6.2.16.0.12.3.3.0.3.73', 1, 3),
	(1, 1335, 'x.6.2.16.0.12.3.4.0.3.73', 1, 3),
	(1, 1336, '15.2.7.16.0.12.3.1.0.3.73', 1, NULL),
	(1, 1337, '15.2.7.16.0.12.3.2.0.3.73', 1, NULL),
	(1, 1338, '15.2.7.16.0.12.3.3.0.3.73', 1, NULL),
	(1, 1339, '15.2.7.16.0.12.3.4.0.3.73', 1, NULL),
	(1, 1340, '4.2.7.16.0.12.3.1.0.3.73', 1, NULL),
	(1, 1341, '4.2.7.16.0.12.3.2.0.3.73', 1, NULL),
	(1, 1342, '4.2.7.16.0.12.3.3.0.3.73', 1, NULL),
	(1, 1343, '4.2.7.16.0.12.3.4.0.3.73', 1, NULL),
	(1, 1344, '5.2.7.16.0.37.0.0.0.3.63', 1, 1),
	(1, 1345, 'x.2.7.16.0.12.0.0.0.3.73', 1, 1),
	(1, 1346, 'x.2.7.16.0.37.0.0.0.3.63', 1, 1),
	(1, 1347, '3.2.7.16.0.12.0.0.0.3.73', 1, NULL),
	(1, 1348, '3.2.7.16.0.37.0.0.0.3.63', 1, NULL),
	(1, 1349, '10.2.7.16.0.12.0.0.0.3.73', 1, NULL),
	(1, 1350, '10.2.7.16.0.37.0.0.0.3.63', 1, NULL),
	(1, 1351, '14.2.7.16.0.12.0.0.0.3.73', 1, NULL),
	(1, 1352, '14.2.7.16.0.37.0.0.0.3.63', 1, NULL),
	(1, 1353, 'x.2.7.16.0.12.0.0.0.3.73', 1, NULL),
	(1, 1354, 'x.2.7.16.0.37.0.0.0.3.63', 1, NULL),
	(1, 1355, '6.2.7.16.0.12.0.0.0.3.73', 1, NULL),
	(1, 1356, '6.2.7.16.0.37.0.0.0.3.63', 1, NULL),
	(1, 1357, '1.2.7.16.0.12.0.0.0.3.73', 1, NULL),
	(1, 1358, '1.2.7.16.0.37.0.0.0.3.63', 1, NULL),
	(1, 1359, '2.2.7.16.0.12.0.0.0.3.73', 1, 1),
	(1, 1360, '2.2.7.16.0.37.0.0.0.3.63', 1, 1),
	(1, 1361, '5.2.7.16.0.12.0.0.0.3.73', 1, 1),
	(1, 1362, '7.2.7.17.0.37.0.0.0.3.63', 1, 1),
	(1, 1363, '15.2.7.17.0.12.0.0.0.3.73', 1, NULL),
	(1, 1364, '4.2.7.17.0.12.0.0.0.3.73', 1, NULL),
	(1, 1365, '4.2.7.17.0.37.0.0.0.3.63', 1, NULL),
	(1, 1366, 'x.6.2.17.0.12.3.1.0.3.73', 1, 3),
	(1, 1367, 'x.6.2.17.0.12.3.2.0.3.73', 1, 3),
	(1, 1368, 'x.6.2.17.0.12.3.3.0.3.73', 1, 3),
	(1, 1369, 'x.6.2.17.0.12.3.4.0.3.73', 1, 3),
	(1, 1370, '15.2.7.17.0.12.3.1.0.3.73', 1, NULL),
	(1, 1371, '15.2.7.17.0.12.3.2.0.3.73', 1, NULL),
	(1, 1372, '15.2.7.17.0.12.3.3.0.3.73', 1, NULL),
	(1, 1373, '15.2.7.17.0.12.3.4.0.3.73', 1, NULL),
	(1, 1374, '4.2.7.17.0.12.3.1.0.3.73', 1, NULL),
	(1, 1375, '4.2.7.17.0.12.3.2.0.3.73', 1, NULL),
	(1, 1376, '4.2.7.17.0.12.3.3.0.3.73', 1, NULL),
	(1, 1377, '4.2.7.17.0.12.3.4.0.3.73', 1, NULL),
	(1, 1378, '5.2.7.17.0.37.0.0.0.3.63', 1, 1),
	(1, 1379, 'x.2.7.17.0.12.0.0.0.3.73', 1, 1),
	(1, 1380, 'x.2.7.17.0.37.0.0.0.3.63', 1, 1),
	(1, 1381, '3.2.7.17.0.12.0.0.0.3.73', 1, NULL),
	(1, 1382, '3.2.7.17.0.37.0.0.0.3.63', 1, NULL),
	(1, 1383, '10.2.7.17.0.12.0.0.0.3.73', 1, NULL),
	(1, 1384, '10.2.7.17.0.37.0.0.0.3.63', 1, NULL),
	(1, 1385, '14.2.7.17.0.12.0.0.0.3.73', 1, NULL),
	(1, 1386, '14.2.7.17.0.37.0.0.0.3.63', 1, NULL),
	(1, 1387, 'x.2.7.17.0.12.0.0.0.3.73', 1, NULL),
	(1, 1388, 'x.2.7.17.0.37.0.0.0.3.63', 1, NULL),
	(1, 1389, '6.2.7.17.0.12.0.0.0.3.73', 1, NULL),
	(1, 1390, '6.2.7.17.0.37.0.0.0.3.63', 1, NULL),
	(1, 1391, '1.2.7.17.0.12.0.0.0.3.73', 1, NULL),
	(1, 1392, '1.2.7.17.0.37.0.0.0.3.63', 1, NULL),
	(1, 1393, '2.2.7.17.0.12.0.0.0.3.73', 1, 1),
	(1, 1394, '2.2.7.17.0.37.0.0.0.3.63', 1, 1),
	(1, 1395, '5.2.7.17.0.12.0.0.0.3.73', 1, 1),
	(1, 1396, '7.2.7.18.0.37.0.0.0.3.63', 1, 1),
	(1, 1397, '15.2.7.18.0.12.0.0.0.3.73', 1, NULL),
	(1, 1398, '4.2.7.18.0.12.0.0.0.3.73', 1, NULL),
	(1, 1399, '4.2.7.18.0.37.0.0.0.3.63', 1, NULL),
	(1, 1400, 'x.6.2.18.0.12.3.1.0.3.73', 1, 3),
	(1, 1401, 'x.6.2.18.0.12.3.2.0.3.73', 1, 3),
	(1, 1402, 'x.6.2.18.0.12.3.3.0.3.73', 1, 3),
	(1, 1403, 'x.6.2.18.0.12.3.4.0.3.73', 1, 3),
	(1, 1404, '15.2.7.18.0.12.3.1.0.3.73', 1, NULL),
	(1, 1405, '15.2.7.18.0.12.3.2.0.3.73', 1, NULL),
	(1, 1406, '15.2.7.18.0.12.3.3.0.3.73', 1, NULL),
	(1, 1407, '15.2.7.18.0.12.3.4.0.3.73', 1, NULL),
	(1, 1408, '4.2.7.18.0.12.3.1.0.3.73', 1, NULL),
	(1, 1409, '4.2.7.18.0.12.3.2.0.3.73', 1, NULL),
	(1, 1410, '4.2.7.18.0.12.3.3.0.3.73', 1, NULL),
	(1, 1411, '4.2.7.18.0.12.3.4.0.3.73', 1, NULL),
	(1, 1412, '5.2.7.18.0.37.0.0.0.3.63', 1, 1),
	(1, 1413, 'x.2.7.18.0.12.0.0.0.3.73', 1, 1),
	(1, 1414, 'x.2.7.18.0.37.0.0.0.3.63', 1, 1),
	(1, 1415, '3.2.7.18.0.12.0.0.0.3.73', 1, NULL),
	(1, 1416, '3.2.7.18.0.37.0.0.0.3.63', 1, NULL),
	(1, 1417, '10.2.7.18.0.12.0.0.0.3.73', 1, NULL),
	(1, 1418, '10.2.7.18.0.37.0.0.0.3.63', 1, NULL),
	(1, 1419, '14.2.7.18.0.12.0.0.0.3.73', 1, NULL),
	(1, 1420, '14.2.7.18.0.37.0.0.0.3.63', 1, NULL),
	(1, 1421, 'x.2.7.18.0.12.0.0.0.3.73', 1, NULL),
	(1, 1422, 'x.2.7.18.0.37.0.0.0.3.63', 1, NULL),
	(1, 1423, '6.2.7.18.0.12.0.0.0.3.73', 1, NULL),
	(1, 1424, '6.2.7.18.0.37.0.0.0.3.63', 1, NULL),
	(1, 1425, '1.2.7.18.0.12.0.0.0.3.73', 1, NULL),
	(1, 1426, '1.2.7.18.0.37.0.0.0.3.63', 1, NULL),
	(1, 1427, '2.2.7.18.0.12.0.0.0.3.73', 1, 1),
	(1, 1428, '2.2.7.18.0.37.0.0.0.3.63', 1, 1),
	(1, 1429, '5.2.7.18.0.12.0.0.0.3.73', 1, 1),
	(1, 1430, '7.2.7.1.0.37.0.0.0.3.61', 1, 1),
	(1, 1431, '7.2.7.19.0.37.0.0.0.3.61', 1, 1),
	(1, 1432, '15.2.7.1.0.12.0.0.0.3.71', 1, NULL),
	(1, 1433, '15.2.7.19.0.12.0.0.0.3.71', 1, NULL),
	(1, 1434, '4.2.7.1.0.12.0.0.0.3.71', 1, NULL),
	(1, 1435, '4.2.7.19.0.12.0.0.0.3.71', 1, NULL),
	(1, 1436, '4.2.7.1.0.37.0.0.0.3.61', 1, NULL),
	(1, 1437, '4.2.7.19.0.37.0.0.0.3.61', 1, NULL),
	(1, 1438, 'x.6.2.1.0.12.3.1.0.3.71', 1, 3),
	(1, 1439, 'x.6.2.19.0.12.3.1.0.3.71', 1, 3),
	(1, 1440, 'x.6.2.1.0.12.3.2.0.3.71', 1, 3),
	(1, 1441, 'x.6.2.19.0.12.3.2.0.3.71', 1, 3),
	(1, 1442, 'x.6.2.1.0.12.3.3.0.3.71', 1, 3),
	(1, 1443, 'x.6.2.19.0.12.3.3.0.3.71', 1, 3),
	(1, 1444, 'x.6.2.1.0.12.3.4.0.3.71', 1, 3),
	(1, 1445, 'x.6.2.19.0.12.3.4.0.3.71', 1, 3),
	(1, 1446, '15.2.7.1.0.12.3.1.0.3.71', 1, NULL),
	(1, 1447, '15.2.7.19.0.12.3.1.0.3.71', 1, NULL),
	(1, 1448, '15.2.7.1.0.12.3.2.0.3.71', 1, NULL),
	(1, 1449, '15.2.7.19.0.12.3.2.0.3.71', 1, NULL),
	(1, 1450, '15.2.7.1.0.12.3.3.0.3.71', 1, NULL),
	(1, 1451, '15.2.7.19.0.12.3.3.0.3.71', 1, NULL),
	(1, 1452, '15.2.7.1.0.12.3.4.0.3.71', 1, NULL),
	(1, 1453, '15.2.7.19.0.12.3.4.0.3.71', 1, NULL),
	(1, 1454, '4.2.7.1.0.12.3.1.0.3.71', 1, NULL),
	(1, 1455, '4.2.7.19.0.12.3.1.0.3.71', 1, NULL),
	(1, 1456, '4.2.7.1.0.12.3.2.0.3.71', 1, NULL),
	(1, 1457, '4.2.7.19.0.12.3.2.0.3.71', 1, NULL),
	(1, 1458, '4.2.7.1.0.12.3.3.0.3.71', 1, NULL),
	(1, 1459, '4.2.7.19.0.12.3.3.0.3.71', 1, NULL),
	(1, 1460, '4.2.7.1.0.12.3.4.0.3.71', 1, NULL),
	(1, 1461, '4.2.7.19.0.12.3.4.0.3.71', 1, NULL),
	(1, 1462, '5.2.7.1.0.37.0.0.0.3.61', 1, 1),
	(1, 1463, '5.2.7.19.0.37.0.0.0.3.61', 1, 1),
	(1, 1464, 'x.2.7.1.0.12.0.0.0.3.71', 1, 1),
	(1, 1465, 'x.2.7.19.0.12.0.0.0.3.71', 1, 1),
	(1, 1466, 'x.2.7.1.0.37.0.0.0.3.61', 1, 1),
	(1, 1467, 'x.2.7.19.0.37.0.0.0.3.61', 1, 1),
	(1, 1468, '3.2.7.1.0.12.0.0.0.3.71', 1, NULL),
	(1, 1469, '3.2.7.19.0.12.0.0.0.3.71', 1, NULL),
	(1, 1470, '3.2.7.1.0.37.0.0.0.3.61', 1, NULL),
	(1, 1471, '3.2.7.19.0.37.0.0.0.3.61', 1, NULL),
	(1, 1472, '10.2.7.1.0.12.0.0.0.3.71', 1, NULL),
	(1, 1473, '10.2.7.19.0.12.0.0.0.3.71', 1, NULL),
	(1, 1474, '10.2.7.1.0.37.0.0.0.3.61', 1, NULL),
	(1, 1475, '10.2.7.19.0.37.0.0.0.3.61', 1, NULL),
	(1, 1476, '14.2.7.1.0.12.0.0.0.3.71', 1, NULL),
	(1, 1477, '14.2.7.19.0.12.0.0.0.3.71', 1, NULL),
	(1, 1478, '14.2.7.1.0.37.0.0.0.3.61', 1, NULL),
	(1, 1479, '14.2.7.19.0.37.0.0.0.3.61', 1, NULL),
	(1, 1480, 'x.2.7.1.0.12.0.0.0.3.71', 1, NULL),
	(1, 1481, 'x.2.7.19.0.12.0.0.0.3.71', 1, NULL),
	(1, 1482, 'x.2.7.1.0.37.0.0.0.3.61', 1, NULL),
	(1, 1483, 'x.2.7.19.0.37.0.0.0.3.61', 1, NULL),
	(1, 1484, '6.2.7.1.0.12.0.0.0.3.71', 1, NULL),
	(1, 1485, '6.2.7.19.0.12.0.0.0.3.71', 1, NULL),
	(1, 1486, '6.2.7.1.0.37.0.0.0.3.61', 1, NULL),
	(1, 1487, '6.2.7.19.0.37.0.0.0.3.61', 1, NULL),
	(1, 1488, '1.2.7.1.0.12.0.0.0.3.71', 1, NULL),
	(1, 1489, '1.2.7.19.0.12.0.0.0.3.71', 1, NULL),
	(1, 1490, '1.2.7.1.0.37.0.0.0.3.61', 1, NULL),
	(1, 1491, '1.2.7.19.0.37.0.0.0.3.61', 1, NULL),
	(1, 1492, '2.2.7.1.0.12.0.0.0.3.71', 1, 1),
	(1, 1493, '2.2.7.19.0.12.0.0.0.3.71', 1, 1),
	(1, 1494, '2.2.7.1.0.37.0.0.0.3.61', 1, 1),
	(1, 1495, '2.2.7.19.0.37.0.0.0.3.61', 1, 1),
	(1, 1496, '5.2.7.1.0.12.0.0.0.3.71', 1, 1),
	(1, 1497, '5.2.7.19.0.12.0.0.0.3.71', 1, 1),
	(1, 1498, '0.6.2.1.0.12.0.0.0.3.72', 1, 3),
	(1, 1499, '0.6.2.19.0.12.0.0.0.3.72', 1, 3),
	(1, 1500, '0.6.2.1.0.12.0.0.0.3.73', 1, 3),
	(1, 1501, '0.6.2.19.0.12.0.0.0.3.73', 1, 3),
	(1, 1502, '0.6.2.15.0.12.0.0.0.3.73', 1, 3),
	(1, 1503, '0.6.2.16.0.12.0.0.0.3.73', 1, 3),
	(1, 1504, '0.6.2.17.0.12.0.0.0.3.73', 1, 3),
	(1, 1505, '0.6.2.18.0.12.0.0.0.3.73', 1, 3),
	(1, 1506, '0.6.2.1.0.12.0.0.0.3.71', 1, 3),
	(1, 1507, '0.6.2.19.0.12.0.0.0.3.71', 1, 3),
	(1, 1765, '5.6.3.1.0.12.0.0.0.3.72', 1, 3),
	(1, 1766, '2.6.3.1.0.12.3.4.0.3.72', 1, 3),
	(1, 1767, '5.6.3.1.0.12.3.3.0.3.72', 1, 3),
	(1, 1768, '5.6.3.1.0.12.3.2.0.3.72', 1, 3),
	(1, 1769, '5.6.3.1.0.12.3.1.0.3.72', 1, 3),
	(1, 1770, 'x.6.3.1.0.12.0.0.0.3.72', 1, 3),
	(1, 1771, 'x.6.3.1.0.12.3.4.0.3.72', 1, 3),
	(1, 1772, 'x.6.3.1.0.12.3.3.0.3.72', 1, 3),
	(1, 1773, 'x.6.3.1.0.12.3.2.0.3.72', 1, 3),
	(1, 1774, 'x.6.3.1.0.12.3.1.0.3.72', 1, 3),
	(1, 1775, '2.6.3.1.0.12.0.0.0.3.72', 1, 3),
	(1, 1776, '5.6.3.1.0.12.3.4.0.3.72', 1, 3),
	(1, 1777, '2.6.3.1.0.12.3.3.0.3.72', 1, 3),
	(1, 1778, '2.6.3.1.0.12.3.2.0.3.72', 1, 3),
	(1, 1779, '2.6.3.1.0.12.3.1.0.3.72', 1, 3),
	(1, 1780, '7.6.3.1.0.12.0.0.0.3.72', 1, 3),
	(1, 1781, '7.6.3.1.0.12.3.4.0.3.72', 1, 3),
	(1, 1782, '7.6.3.1.0.12.3.3.0.3.72', 1, 3),
	(1, 1783, '7.6.3.1.0.12.3.2.0.3.72', 1, 3),
	(1, 1784, '7.6.3.1.0.12.3.1.0.3.72', 1, 3),
	(1, 1785, 'x.6.3.19.0.12.0.0.0.3.72', 1, 3),
	(1, 1786, '5.6.3.19.0.12.3.1.0.3.72', 1, 3),
	(1, 1787, 'x.6.3.19.0.12.3.3.0.3.72', 1, 3),
	(1, 1788, 'x.6.3.19.0.12.3.2.0.3.72', 1, 3),
	(1, 1789, 'x.6.3.19.0.12.3.1.0.3.72', 1, 3),
	(1, 1790, '7.6.3.19.0.12.0.0.0.3.72', 1, 3),
	(1, 1791, '7.6.3.19.0.12.3.4.0.3.72', 1, 3),
	(1, 1792, '7.6.3.19.0.12.3.3.0.3.72', 1, 3),
	(1, 1793, '7.6.3.19.0.12.3.2.0.3.72', 1, 3),
	(1, 1794, '7.6.3.19.0.12.3.1.0.3.72', 1, 3),
	(1, 1795, '2.6.3.19.0.12.0.0.0.3.72', 1, 3),
	(1, 1796, '2.6.3.19.0.12.3.4.0.3.72', 1, 3),
	(1, 1797, '2.6.3.19.0.12.3.3.0.3.72', 1, 3),
	(1, 1798, '2.6.3.19.0.12.3.2.0.3.72', 1, 3),
	(1, 1799, '2.6.3.19.0.12.3.1.0.3.72', 1, 3),
	(1, 1800, '5.6.3.19.0.12.0.0.0.3.72', 1, 3),
	(1, 1801, '5.6.3.19.0.12.3.4.0.3.72', 1, 3),
	(1, 1802, '5.6.3.19.0.12.3.3.0.3.72', 1, 3),
	(1, 1803, '5.6.3.19.0.12.3.2.0.3.72', 1, 3),
	(1, 1804, 'x.6.3.19.0.12.3.4.0.3.72', 1, 3),
	(1, 1805, '5.6.3.1.0.12.3.4.0.3.73', 1, 3),
	(1, 1806, '5.6.3.1.0.12.0.0.0.3.73', 1, 3),
	(1, 1807, '5.6.3.1.0.12.3.2.0.3.73', 1, 3),
	(1, 1808, '5.6.3.1.0.12.3.1.0.3.73', 1, 3),
	(1, 1809, 'x.6.3.1.0.12.0.0.0.3.73', 1, 3),
	(1, 1810, 'x.6.3.1.0.12.3.4.0.3.73', 1, 3),
	(1, 1811, 'x.6.3.1.0.12.3.3.0.3.73', 1, 3),
	(1, 1812, 'x.6.3.1.0.12.3.2.0.3.73', 1, 3),
	(1, 1813, 'x.6.3.1.0.12.3.1.0.3.73', 1, 3),
	(1, 1814, '7.6.3.1.0.12.0.0.0.3.73', 1, 3),
	(1, 1815, '7.6.3.1.0.12.3.4.0.3.73', 1, 3),
	(1, 1816, '7.6.3.1.0.12.3.3.0.3.73', 1, 3),
	(1, 1817, '7.6.3.1.0.12.3.2.0.3.73', 1, 3),
	(1, 1818, '7.6.3.1.0.12.3.1.0.3.73', 1, 3),
	(1, 1819, '2.6.3.1.0.12.0.0.0.3.73', 1, 3),
	(1, 1820, '2.6.3.1.0.12.3.4.0.3.73', 1, 3),
	(1, 1821, '2.6.3.1.0.12.3.3.0.3.73', 1, 3),
	(1, 1822, '2.6.3.1.0.12.3.2.0.3.73', 1, 3),
	(1, 1823, '2.6.3.1.0.12.3.1.0.3.73', 1, 3),
	(1, 1824, '5.6.3.1.0.12.3.3.0.3.73', 1, 3),
	(1, 1825, 'x.6.3.19.0.12.3.4.0.3.73', 1, 3),
	(1, 1826, 'x.6.3.19.0.12.3.3.0.3.73', 1, 3),
	(1, 1827, 'x.6.3.19.0.12.3.2.0.3.73', 1, 3),
	(1, 1828, 'x.6.3.19.0.12.3.1.0.3.73', 1, 3),
	(1, 1829, '2.6.3.19.0.12.0.0.0.3.73', 1, 3),
	(1, 1830, '2.6.3.19.0.12.3.4.0.3.73', 1, 3),
	(1, 1831, '2.6.3.19.0.12.3.3.0.3.73', 1, 3),
	(1, 1832, '2.6.3.19.0.12.3.2.0.3.73', 1, 3),
	(1, 1833, '2.6.3.19.0.12.3.1.0.3.73', 1, 3),
	(1, 1834, 'x.6.3.19.0.12.0.0.0.3.73', 1, 3),
	(1, 1835, '7.6.3.19.0.12.3.4.0.3.73', 1, 3),
	(1, 1836, '7.6.3.19.0.12.3.3.0.3.73', 1, 3),
	(1, 1837, '7.6.3.19.0.12.3.2.0.3.73', 1, 3),
	(1, 1838, '7.6.3.19.0.12.3.1.0.3.73', 1, 3),
	(1, 1839, '5.6.3.19.0.12.0.0.0.3.73', 1, 3),
	(1, 1840, '5.6.3.19.0.12.3.4.0.3.73', 1, 3),
	(1, 1841, '5.6.3.19.0.12.3.3.0.3.73', 1, 3),
	(1, 1842, '5.6.3.19.0.12.3.2.0.3.73', 1, 3),
	(1, 1843, '5.6.3.19.0.12.3.1.0.3.73', 1, 3),
	(1, 1844, '7.6.3.19.0.12.0.0.0.3.73', 1, 3),
	(1, 1845, '7.6.3.15.0.12.3.1.0.3.73', 1, 3),
	(1, 1846, '7.6.3.15.0.12.3.2.0.3.73', 1, 3),
	(1, 1847, '7.6.3.15.0.12.3.3.0.3.73', 1, 3),
	(1, 1848, '7.6.3.15.0.12.3.4.0.3.73', 1, 3),
	(1, 1849, '7.6.3.15.0.12.0.0.0.3.73', 1, 3),
	(1, 1850, 'x.6.3.15.0.12.3.1.0.3.73', 1, 3),
	(1, 1851, 'x.6.3.15.0.12.3.2.0.3.73', 1, 3),
	(1, 1852, 'x.6.3.15.0.12.3.3.0.3.73', 1, 3),
	(1, 1853, 'x.6.3.15.0.12.3.4.0.3.73', 1, 3),
	(1, 1854, 'x.6.3.15.0.12.0.0.0.3.73', 1, 3),
	(1, 1855, '2.6.3.15.0.12.3.1.0.3.73', 1, 3),
	(1, 1856, '2.6.3.15.0.12.3.2.0.3.73', 1, 3),
	(1, 1857, '2.6.3.15.0.12.3.3.0.3.73', 1, 3),
	(1, 1858, '2.6.3.15.0.12.3.4.0.3.73', 1, 3),
	(1, 1859, '2.6.3.15.0.12.0.0.0.3.73', 1, 3),
	(1, 1860, '5.6.3.15.0.12.3.1.0.3.73', 1, 3),
	(1, 1861, '5.6.3.15.0.12.3.2.0.3.73', 1, 3),
	(1, 1862, '5.6.3.15.0.12.3.3.0.3.73', 1, 3),
	(1, 1863, '5.6.3.15.0.12.3.4.0.3.73', 1, 3),
	(1, 1864, '5.6.3.15.0.12.0.0.0.3.73', 1, 3),
	(1, 1865, '7.6.3.16.0.12.3.1.0.3.73', 1, 3),
	(1, 1866, '2.6.3.16.0.12.3.3.0.3.73', 1, 3),
	(1, 1867, '7.6.3.16.0.12.3.3.0.3.73', 1, 3),
	(1, 1868, '7.6.3.16.0.12.3.4.0.3.73', 1, 3),
	(1, 1869, '7.6.3.16.0.12.0.0.0.3.73', 1, 3),
	(1, 1870, 'x.6.3.16.0.12.3.1.0.3.73', 1, 3),
	(1, 1871, 'x.6.3.16.0.12.3.2.0.3.73', 1, 3),
	(1, 1872, 'x.6.3.16.0.12.3.3.0.3.73', 1, 3),
	(1, 1873, 'x.6.3.16.0.12.3.4.0.3.73', 1, 3),
	(1, 1874, 'x.6.3.16.0.12.0.0.0.3.73', 1, 3),
	(1, 1875, '2.6.3.16.0.12.3.1.0.3.73', 1, 3),
	(1, 1876, '2.6.3.16.0.12.3.2.0.3.73', 1, 3),
	(1, 1877, '5.6.3.16.0.12.0.0.0.3.73', 1, 3),
	(1, 1878, '5.6.3.16.0.12.3.4.0.3.73', 1, 3),
	(1, 1879, '5.6.3.16.0.12.3.3.0.3.73', 1, 3),
	(1, 1880, '5.6.3.16.0.12.3.2.0.3.73', 1, 3),
	(1, 1881, '5.6.3.16.0.12.3.1.0.3.73', 1, 3),
	(1, 1882, '2.6.3.16.0.12.0.0.0.3.73', 1, 3),
	(1, 1883, '2.6.3.16.0.12.3.4.0.3.73', 1, 3),
	(1, 1884, '7.6.3.16.0.12.3.2.0.3.73', 1, 3),
	(1, 1885, '5.6.3.17.0.12.0.0.0.3.73', 1, 3),
	(1, 1886, '5.6.3.17.0.12.3.4.0.3.73', 1, 3),
	(1, 1887, '5.6.3.17.0.12.3.3.0.3.73', 1, 3),
	(1, 1888, '5.6.3.17.0.12.3.2.0.3.73', 1, 3),
	(1, 1889, '5.6.3.17.0.12.3.1.0.3.73', 1, 3),
	(1, 1890, '2.6.3.17.0.12.0.0.0.3.73', 1, 3),
	(1, 1891, '2.6.3.17.0.12.3.4.0.3.73', 1, 3),
	(1, 1892, '2.6.3.17.0.12.3.3.0.3.73', 1, 3),
	(1, 1893, '2.6.3.17.0.12.3.2.0.3.73', 1, 3),
	(1, 1894, '2.6.3.17.0.12.3.1.0.3.73', 1, 3),
	(1, 1895, 'x.6.3.17.0.12.3.3.0.3.73', 1, 3),
	(1, 1896, 'x.6.3.17.0.12.3.4.0.3.73', 1, 3),
	(1, 1897, 'x.6.3.17.0.12.0.0.0.3.73', 1, 3),
	(1, 1898, 'x.6.3.17.0.12.3.2.0.3.73', 1, 3),
	(1, 1899, 'x.6.3.17.0.12.3.1.0.3.73', 1, 3),
	(1, 1900, '7.6.3.17.0.12.0.0.0.3.73', 1, 3),
	(1, 1901, '7.6.3.17.0.12.3.4.0.3.73', 1, 3),
	(1, 1902, '7.6.3.17.0.12.3.3.0.3.73', 1, 3),
	(1, 1903, '7.6.3.17.0.12.3.2.0.3.73', 1, 3),
	(1, 1904, '7.6.3.17.0.12.3.1.0.3.73', 1, 3),
	(1, 1905, '2.6.3.18.0.12.3.2.0.3.73', 1, 3),
	(1, 1906, '5.6.3.18.0.12.0.0.0.3.73', 1, 3),
	(1, 1907, 'x.6.3.18.0.12.0.0.0.3.73', 1, 3),
	(1, 1908, 'x.6.3.18.0.12.3.4.0.3.73', 1, 3),
	(1, 1909, 'x.6.3.18.0.12.3.3.0.3.73', 1, 3),
	(1, 1910, 'x.6.3.18.0.12.3.2.0.3.73', 1, 3),
	(1, 1911, 'x.6.3.18.0.12.3.1.0.3.73', 1, 3),
	(1, 1912, '7.6.3.18.0.12.0.0.0.3.73', 1, 3),
	(1, 1913, '7.6.3.18.0.12.3.4.0.3.73', 1, 3),
	(1, 1914, '7.6.3.18.0.12.3.3.0.3.73', 1, 3),
	(1, 1915, '7.6.3.18.0.12.3.2.0.3.73', 1, 3),
	(1, 1916, '7.6.3.18.0.12.3.1.0.3.73', 1, 3),
	(1, 1917, '2.6.3.18.0.12.3.3.0.3.73', 1, 3),
	(1, 1918, '2.6.3.18.0.12.3.4.0.3.73', 1, 3),
	(1, 1919, '2.6.3.18.0.12.0.0.0.3.73', 1, 3),
	(1, 1920, '5.6.3.18.0.12.3.1.0.3.73', 1, 3),
	(1, 1921, '5.6.3.18.0.12.3.2.0.3.73', 1, 3),
	(1, 1922, '5.6.3.18.0.12.3.3.0.3.73', 1, 3),
	(1, 1923, '5.6.3.18.0.12.3.4.0.3.73', 1, 3),
	(1, 1924, '2.6.3.18.0.12.3.1.0.3.73', 1, 3),
	(1, 1925, '5.6.3.1.0.12.3.3.0.3.71', 1, 3),
	(1, 1926, '5.6.3.1.0.12.3.2.0.3.71', 1, 3),
	(1, 1927, '5.6.3.1.0.12.0.0.0.3.71', 1, 3),
	(1, 1928, '5.6.3.1.0.12.3.4.0.3.71', 1, 3),
	(1, 1929, '5.6.3.1.0.12.3.1.0.3.71', 1, 3),
	(1, 1930, '2.6.3.1.0.12.0.0.0.3.71', 1, 3),
	(1, 1931, '2.6.3.1.0.12.3.4.0.3.71', 1, 3),
	(1, 1932, '2.6.3.1.0.12.3.3.0.3.71', 1, 3),
	(1, 1933, '2.6.3.1.0.12.3.2.0.3.71', 1, 3),
	(1, 1934, '2.6.3.1.0.12.3.1.0.3.71', 1, 3),
	(1, 1935, 'x.6.3.1.0.12.0.0.0.3.71', 1, 3),
	(1, 1936, 'x.6.3.1.0.12.3.4.0.3.71', 1, 3),
	(1, 1937, 'x.6.3.1.0.12.3.3.0.3.71', 1, 3),
	(1, 1938, 'x.6.3.1.0.12.3.2.0.3.71', 1, 3),
	(1, 1939, 'x.6.3.1.0.12.3.1.0.3.71', 1, 3),
	(1, 1940, '7.6.3.1.0.12.0.0.0.3.71', 1, 3),
	(1, 1941, '7.6.3.1.0.12.3.4.0.3.71', 1, 3),
	(1, 1942, '7.6.3.1.0.12.3.3.0.3.71', 1, 3),
	(1, 1943, '7.6.3.1.0.12.3.2.0.3.71', 1, 3),
	(1, 1944, '7.6.3.1.0.12.3.1.0.3.71', 1, 3),
	(1, 1945, '2.6.3.19.0.12.3.3.0.3.71', 1, 3),
	(1, 1946, '5.6.3.19.0.12.3.1.0.3.71', 1, 3),
	(1, 1947, '2.6.3.19.0.12.0.0.0.3.71', 1, 3),
	(1, 1948, '2.6.3.19.0.12.3.2.0.3.71', 1, 3),
	(1, 1949, '2.6.3.19.0.12.3.1.0.3.71', 1, 3),
	(1, 1950, '7.6.3.19.0.12.0.0.0.3.71', 1, 3),
	(1, 1951, '7.6.3.19.0.12.3.4.0.3.71', 1, 3),
	(1, 1952, '7.6.3.19.0.12.3.3.0.3.71', 1, 3),
	(1, 1953, '7.6.3.19.0.12.3.2.0.3.71', 1, 3),
	(1, 1954, '7.6.3.19.0.12.3.1.0.3.71', 1, 3),
	(1, 1955, 'x.6.3.19.0.12.0.0.0.3.71', 1, 3),
	(1, 1956, 'x.6.3.19.0.12.3.4.0.3.71', 1, 3),
	(1, 1957, 'x.6.3.19.0.12.3.3.0.3.71', 1, 3),
	(1, 1958, 'x.6.3.19.0.12.3.2.0.3.71', 1, 3),
	(1, 1959, 'x.6.3.19.0.12.3.1.0.3.71', 1, 3),
	(1, 1960, '5.6.3.19.0.12.0.0.0.3.71', 1, 3),
	(1, 1961, '5.6.3.19.0.12.3.4.0.3.71', 1, 3),
	(1, 1962, '5.6.3.19.0.12.3.3.0.3.71', 1, 3),
	(1, 1963, '5.6.3.19.0.12.3.2.0.3.71', 1, 3),
	(1, 1964, '2.6.3.19.0.12.3.4.0.3.71', 1, 3),
	(1, 2093, '15.6.3.1.0.12.3.4.0.3.72', 1, 3),
	(1, 2094, '4.6.3.1.0.12.3.1.0.3.72', 1, 3),
	(1, 2095, '15.6.3.1.0.12.0.0.0.3.72', 1, 3),
	(1, 2096, '4.6.3.1.0.12.3.4.0.3.72', 1, 3),
	(1, 2097, '4.6.3.1.0.12.0.0.0.3.72', 1, 3),
	(1, 2098, '15.6.3.1.0.12.3.1.0.3.72', 1, 3),
	(1, 2099, '4.6.3.1.0.12.3.3.0.3.72', 1, 3),
	(1, 2100, '4.6.3.1.0.12.3.2.0.3.72', 1, 3),
	(1, 2101, '15.6.3.1.0.12.3.3.0.3.72', 1, 3),
	(1, 2102, '15.6.3.1.0.12.3.2.0.3.72', 1, 3),
	(1, 2103, '15.6.3.19.0.12.3.3.0.3.72', 1, 3),
	(1, 2104, '15.6.3.19.0.12.3.2.0.3.72', 1, 3),
	(1, 2105, '15.6.3.19.0.12.3.1.0.3.72', 1, 3),
	(1, 2106, '4.6.3.19.0.12.0.0.0.3.72', 1, 3),
	(1, 2107, '15.6.3.19.0.12.0.0.0.3.72', 1, 3),
	(1, 2108, '4.6.3.19.0.12.3.4.0.3.72', 1, 3),
	(1, 2109, '4.6.3.19.0.12.3.3.0.3.72', 1, 3),
	(1, 2110, '4.6.3.19.0.12.3.2.0.3.72', 1, 3),
	(1, 2111, '4.6.3.19.0.12.3.1.0.3.72', 1, 3),
	(1, 2112, '15.6.3.19.0.12.3.4.0.3.72', 1, 3),
	(1, 2113, '15.6.3.1.0.12.3.4.0.3.73', 1, 3),
	(1, 2114, '4.6.3.1.0.12.0.0.0.3.73', 1, 3),
	(1, 2115, '15.6.3.1.0.12.3.2.0.3.73', 1, 3),
	(1, 2116, '15.6.3.1.0.12.0.0.0.3.73', 1, 3),
	(1, 2117, '4.6.3.1.0.12.3.2.0.3.73', 1, 3),
	(1, 2118, '15.6.3.1.0.12.3.1.0.3.73', 1, 3),
	(1, 2119, '4.6.3.1.0.12.3.4.0.3.73', 1, 3),
	(1, 2120, '4.6.3.1.0.12.3.3.0.3.73', 1, 3),
	(1, 2121, '4.6.3.1.0.12.3.1.0.3.73', 1, 3),
	(1, 2122, '15.6.3.1.0.12.3.3.0.3.73', 1, 3),
	(1, 2123, '4.6.3.19.0.12.3.4.0.3.73', 1, 3),
	(1, 2124, '15.6.3.19.0.12.3.4.0.3.73', 1, 3),
	(1, 2125, '4.6.3.19.0.12.3.3.0.3.73', 1, 3),
	(1, 2126, '4.6.3.19.0.12.3.1.0.3.73', 1, 3),
	(1, 2127, '15.6.3.19.0.12.3.2.0.3.73', 1, 3),
	(1, 2128, '15.6.3.19.0.12.3.3.0.3.73', 1, 3),
	(1, 2129, '4.6.3.19.0.12.0.0.0.3.73', 1, 3),
	(1, 2130, '4.6.3.19.0.12.3.2.0.3.73', 1, 3),
	(1, 2131, '15.6.3.19.0.12.0.0.0.3.73', 1, 3),
	(1, 2132, '15.6.3.19.0.12.3.1.0.3.73', 1, 3),
	(1, 2133, '15.6.3.15.0.12.0.0.0.3.73', 1, 3),
	(1, 2134, '4.6.3.15.0.12.3.3.0.3.73', 1, 3),
	(1, 2135, '4.6.3.15.0.12.3.2.0.3.73', 1, 3),
	(1, 2136, '15.6.3.15.0.12.3.1.0.3.73', 1, 3),
	(1, 2137, '15.6.3.15.0.12.3.2.0.3.73', 1, 3),
	(1, 2138, '4.6.3.15.0.12.3.1.0.3.73', 1, 3),
	(1, 2139, '15.6.3.15.0.12.3.4.0.3.73', 1, 3),
	(1, 2140, '15.6.3.15.0.12.3.3.0.3.73', 1, 3),
	(1, 2141, '4.6.3.15.0.12.0.0.0.3.73', 1, 3),
	(1, 2142, '4.6.3.15.0.12.3.4.0.3.73', 1, 3),
	(1, 2143, '15.6.3.16.0.12.3.1.0.3.73', 1, 3),
	(1, 2144, '15.6.3.16.0.12.3.2.0.3.73', 1, 3),
	(1, 2145, '4.6.3.16.0.12.0.0.0.3.73', 1, 3),
	(1, 2146, '15.6.3.16.0.12.0.0.0.3.73', 1, 3),
	(1, 2147, '4.6.3.16.0.12.3.3.0.3.73', 1, 3),
	(1, 2148, '4.6.3.16.0.12.3.4.0.3.73', 1, 3),
	(1, 2149, '4.6.3.16.0.12.3.2.0.3.73', 1, 3),
	(1, 2150, '4.6.3.16.0.12.3.1.0.3.73', 1, 3),
	(1, 2151, '15.6.3.16.0.12.3.4.0.3.73', 1, 3),
	(1, 2152, '15.6.3.16.0.12.3.3.0.3.73', 1, 3),
	(1, 2153, '15.6.3.17.0.12.3.3.0.3.73', 1, 3),
	(1, 2154, '15.6.3.17.0.12.3.4.0.3.73', 1, 3),
	(1, 2155, '4.6.3.17.0.12.3.1.0.3.73', 1, 3),
	(1, 2156, '4.6.3.17.0.12.3.2.0.3.73', 1, 3),
	(1, 2157, '4.6.3.17.0.12.3.3.0.3.73', 1, 3),
	(1, 2158, '4.6.3.17.0.12.3.4.0.3.73', 1, 3),
	(1, 2159, '15.6.3.17.0.12.0.0.0.3.73', 1, 3),
	(1, 2160, '4.6.3.17.0.12.0.0.0.3.73', 1, 3),
	(1, 2161, '15.6.3.17.0.12.3.1.0.3.73', 1, 3),
	(1, 2162, '15.6.3.17.0.12.3.2.0.3.73', 1, 3),
	(1, 2163, '15.6.3.18.0.12.0.0.0.3.73', 1, 3),
	(1, 2164, '4.6.3.18.0.12.0.0.0.3.73', 1, 3),
	(1, 2165, '15.6.3.18.0.12.3.1.0.3.73', 1, 3),
	(1, 2166, '15.6.3.18.0.12.3.2.0.3.73', 1, 3),
	(1, 2167, '4.6.3.18.0.12.3.4.0.3.73', 1, 3),
	(1, 2168, '15.6.3.18.0.12.3.4.0.3.73', 1, 3),
	(1, 2169, '4.6.3.18.0.12.3.1.0.3.73', 1, 3),
	(1, 2170, '4.6.3.18.0.12.3.2.0.3.73', 1, 3),
	(1, 2171, '4.6.3.18.0.12.3.3.0.3.73', 1, 3),
	(1, 2172, '15.6.3.18.0.12.3.3.0.3.73', 1, 3),
	(1, 2173, '15.6.3.1.0.12.0.0.0.3.71', 1, 3),
	(1, 2174, '15.6.3.1.0.12.3.1.0.3.71', 1, 3),
	(1, 2175, '4.6.3.1.0.12.3.4.0.3.71', 1, 3),
	(1, 2176, '4.6.3.1.0.12.3.3.0.3.71', 1, 3),
	(1, 2177, '4.6.3.1.0.12.3.2.0.3.71', 1, 3),
	(1, 2178, '4.6.3.1.0.12.3.1.0.3.71', 1, 3),
	(1, 2179, '15.6.3.1.0.12.3.4.0.3.71', 1, 3),
	(1, 2180, '15.6.3.1.0.12.3.3.0.3.71', 1, 3),
	(1, 2181, '15.6.3.1.0.12.3.2.0.3.71', 1, 3),
	(1, 2182, '4.6.3.1.0.12.0.0.0.3.71', 1, 3),
	(1, 2183, '4.6.3.19.0.12.3.3.0.3.71', 1, 3),
	(1, 2184, '15.6.3.19.0.12.3.3.0.3.71', 1, 3),
	(1, 2185, '4.6.3.19.0.12.3.1.0.3.71', 1, 3),
	(1, 2186, '15.6.3.19.0.12.3.2.0.3.71', 1, 3),
	(1, 2187, '15.6.3.19.0.12.0.0.0.3.71', 1, 3),
	(1, 2188, '15.6.3.19.0.12.3.1.0.3.71', 1, 3),
	(1, 2189, '4.6.3.19.0.12.3.4.0.3.71', 1, 3),
	(1, 2190, '4.6.3.19.0.12.0.0.0.3.71', 1, 3),
	(1, 2191, '15.6.3.19.0.12.3.4.0.3.71', 1, 3),
	(1, 2192, '4.6.3.19.0.12.3.2.0.3.71', 1, 3),
	(1, 2301, '4.8.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 2302, '4.9.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 2303, '15.8.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 2304, '15.9.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 2305, '4.8.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 2306, '4.9.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 2307, '15.8.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 2308, '15.9.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 2329, 'x.6.2.1.0.12.3.5.0.3.72', 1, 3),
	(1, 2330, 'x.6.2.1.0.12.3.6.0.3.72', 1, 3),
	(1, 2331, 'x.6.2.1.0.12.3.7.0.3.72', 1, 3),
	(1, 2332, 'x.6.2.1.0.12.3.8.0.3.72', 1, 3),
	(1, 2333, 'x.6.2.19.0.12.3.5.0.3.72', 1, 3),
	(1, 2334, 'x.6.2.19.0.12.3.6.0.3.72', 1, 3),
	(1, 2335, 'x.6.2.19.0.12.3.7.0.3.72', 1, 3),
	(1, 2336, 'x.6.2.19.0.12.3.8.0.3.72', 1, 3),
	(1, 2337, 'x.6.2.1.0.12.3.5.0.3.73', 1, 3),
	(1, 2338, 'x.6.2.1.0.12.3.6.0.3.73', 1, 3),
	(1, 2339, 'x.6.2.1.0.12.3.7.0.3.73', 1, 3),
	(1, 2340, 'x.6.2.1.0.12.3.8.0.3.73', 1, 3),
	(1, 2341, 'x.6.2.19.0.12.3.5.0.3.73', 1, 3),
	(1, 2342, 'x.6.2.19.0.12.3.6.0.3.73', 1, 3),
	(1, 2343, 'x.6.2.19.0.12.3.7.0.3.73', 1, 3),
	(1, 2344, 'x.6.2.19.0.12.3.8.0.3.73', 1, 3),
	(1, 2345, '15.2.7.1.0.12.3.5.0.3.72', 1, NULL),
	(1, 2346, '15.2.7.1.0.12.3.6.0.3.72', 1, NULL),
	(1, 2347, '15.2.7.1.0.12.3.7.0.3.72', 1, NULL),
	(1, 2348, '15.2.7.1.0.12.3.8.0.3.72', 1, NULL),
	(1, 2349, '15.2.7.19.0.12.3.5.0.3.72', 1, NULL),
	(1, 2350, '15.2.7.19.0.12.3.6.0.3.72', 1, NULL),
	(1, 2351, '15.2.7.19.0.12.3.7.0.3.72', 1, NULL),
	(1, 2352, '15.2.7.19.0.12.3.8.0.3.72', 1, NULL),
	(1, 2353, '15.2.7.1.0.12.3.5.0.3.73', 1, NULL),
	(1, 2354, '15.2.7.1.0.12.3.6.0.3.73', 1, NULL),
	(1, 2355, '15.2.7.1.0.12.3.7.0.3.73', 1, NULL),
	(1, 2356, '15.2.7.1.0.12.3.8.0.3.73', 1, NULL),
	(1, 2357, '15.2.7.19.0.12.3.5.0.3.73', 1, NULL),
	(1, 2358, '15.2.7.19.0.12.3.6.0.3.73', 1, NULL),
	(1, 2359, '15.2.7.19.0.12.3.7.0.3.73', 1, NULL),
	(1, 2360, '15.2.7.19.0.12.3.8.0.3.73', 1, NULL),
	(1, 2361, '4.2.7.1.0.12.3.5.0.3.72', 1, NULL),
	(1, 2362, '4.2.7.1.0.12.3.6.0.3.72', 1, NULL),
	(1, 2363, '4.2.7.1.0.12.3.7.0.3.72', 1, NULL),
	(1, 2364, '4.2.7.1.0.12.3.8.0.3.72', 1, NULL),
	(1, 2365, '4.2.7.19.0.12.3.5.0.3.72', 1, NULL),
	(1, 2366, '4.2.7.19.0.12.3.6.0.3.72', 1, NULL),
	(1, 2367, '4.2.7.19.0.12.3.7.0.3.72', 1, NULL),
	(1, 2368, '4.2.7.19.0.12.3.8.0.3.72', 1, NULL),
	(1, 2369, '4.2.7.1.0.12.3.5.0.3.73', 1, NULL),
	(1, 2370, '4.2.7.1.0.12.3.6.0.3.73', 1, NULL),
	(1, 2371, '4.2.7.1.0.12.3.7.0.3.73', 1, NULL),
	(1, 2372, '4.2.7.1.0.12.3.8.0.3.73', 1, NULL),
	(1, 2373, '4.2.7.19.0.12.3.5.0.3.73', 1, NULL),
	(1, 2374, '4.2.7.19.0.12.3.6.0.3.73', 1, NULL),
	(1, 2375, '4.2.7.19.0.12.3.7.0.3.73', 1, NULL),
	(1, 2376, '4.2.7.19.0.12.3.8.0.3.73', 1, NULL),
	(1, 2377, 'x.6.2.15.0.12.3.5.0.3.73', 1, 3),
	(1, 2378, 'x.6.2.15.0.12.3.6.0.3.73', 1, 3),
	(1, 2379, 'x.6.2.15.0.12.3.7.0.3.73', 1, 3),
	(1, 2380, 'x.6.2.15.0.12.3.8.0.3.73', 1, 3),
	(1, 2381, '15.2.7.15.0.12.3.5.0.3.73', 1, NULL),
	(1, 2382, '15.2.7.15.0.12.3.6.0.3.73', 1, NULL),
	(1, 2383, '15.2.7.15.0.12.3.7.0.3.73', 1, NULL),
	(1, 2384, '15.2.7.15.0.12.3.8.0.3.73', 1, NULL),
	(1, 2385, '4.2.7.15.0.12.3.5.0.3.73', 1, NULL),
	(1, 2386, '4.2.7.15.0.12.3.6.0.3.73', 1, NULL),
	(1, 2387, '4.2.7.15.0.12.3.7.0.3.73', 1, NULL),
	(1, 2388, '4.2.7.15.0.12.3.8.0.3.73', 1, NULL),
	(1, 2389, 'x.6.2.16.0.12.3.5.0.3.73', 1, 3),
	(1, 2390, 'x.6.2.16.0.12.3.6.0.3.73', 1, 3),
	(1, 2391, 'x.6.2.16.0.12.3.7.0.3.73', 1, 3),
	(1, 2392, 'x.6.2.16.0.12.3.8.0.3.73', 1, 3),
	(1, 2393, '15.2.7.16.0.12.3.5.0.3.73', 1, NULL),
	(1, 2394, '15.2.7.16.0.12.3.6.0.3.73', 1, NULL),
	(1, 2395, '15.2.7.16.0.12.3.7.0.3.73', 1, NULL),
	(1, 2396, '15.2.7.16.0.12.3.8.0.3.73', 1, NULL),
	(1, 2397, '4.2.7.16.0.12.3.5.0.3.73', 1, NULL),
	(1, 2398, '4.2.7.16.0.12.3.6.0.3.73', 1, NULL),
	(1, 2399, '4.2.7.16.0.12.3.7.0.3.73', 1, NULL),
	(1, 2400, '4.2.7.16.0.12.3.8.0.3.73', 1, NULL),
	(1, 2401, 'x.6.2.17.0.12.3.5.0.3.73', 1, 3),
	(1, 2402, 'x.6.2.17.0.12.3.6.0.3.73', 1, 3),
	(1, 2403, 'x.6.2.17.0.12.3.7.0.3.73', 1, 3),
	(1, 2404, 'x.6.2.17.0.12.3.8.0.3.73', 1, 3),
	(1, 2405, '15.2.7.17.0.12.3.5.0.3.73', 1, NULL),
	(1, 2406, '15.2.7.17.0.12.3.6.0.3.73', 1, NULL),
	(1, 2407, '15.2.7.17.0.12.3.7.0.3.73', 1, NULL),
	(1, 2408, '15.2.7.17.0.12.3.8.0.3.73', 1, NULL),
	(1, 2409, '4.2.7.17.0.12.3.5.0.3.73', 1, NULL),
	(1, 2410, '4.2.7.17.0.12.3.6.0.3.73', 1, NULL),
	(1, 2411, '4.2.7.17.0.12.3.7.0.3.73', 1, NULL),
	(1, 2412, '4.2.7.17.0.12.3.8.0.3.73', 1, NULL),
	(1, 2413, 'x.6.2.18.0.12.3.5.0.3.73', 1, 3),
	(1, 2414, 'x.6.2.18.0.12.3.6.0.3.73', 1, 3),
	(1, 2415, 'x.6.2.18.0.12.3.7.0.3.73', 1, 3),
	(1, 2416, 'x.6.2.18.0.12.3.8.0.3.73', 1, 3),
	(1, 2417, '15.2.7.18.0.12.3.5.0.3.73', 1, NULL),
	(1, 2418, '15.2.7.18.0.12.3.6.0.3.73', 1, NULL),
	(1, 2419, '15.2.7.18.0.12.3.7.0.3.73', 1, NULL),
	(1, 2420, '15.2.7.18.0.12.3.8.0.3.73', 1, NULL),
	(1, 2421, '4.2.7.18.0.12.3.5.0.3.73', 1, NULL),
	(1, 2422, '4.2.7.18.0.12.3.6.0.3.73', 1, NULL),
	(1, 2423, '4.2.7.18.0.12.3.7.0.3.73', 1, NULL),
	(1, 2424, '4.2.7.18.0.12.3.8.0.3.73', 1, NULL),
	(1, 2425, 'x.6.2.1.0.12.3.5.0.3.71', 1, 3),
	(1, 2426, 'x.6.2.1.0.12.3.6.0.3.71', 1, 3),
	(1, 2427, 'x.6.2.1.0.12.3.7.0.3.71', 1, 3),
	(1, 2428, 'x.6.2.1.0.12.3.8.0.3.71', 1, 3),
	(1, 2429, 'x.6.2.19.0.12.3.5.0.3.71', 1, 3),
	(1, 2430, 'x.6.2.19.0.12.3.6.0.3.71', 1, 3),
	(1, 2431, 'x.6.2.19.0.12.3.7.0.3.71', 1, 3),
	(1, 2432, 'x.6.2.19.0.12.3.8.0.3.71', 1, 3),
	(1, 2433, '15.2.7.1.0.12.3.5.0.3.71', 1, NULL),
	(1, 2434, '15.2.7.1.0.12.3.6.0.3.71', 1, NULL),
	(1, 2435, '15.2.7.1.0.12.3.7.0.3.71', 1, NULL),
	(1, 2436, '15.2.7.1.0.12.3.8.0.3.71', 1, NULL),
	(1, 2437, '15.2.7.19.0.12.3.5.0.3.71', 1, NULL),
	(1, 2438, '15.2.7.19.0.12.3.6.0.3.71', 1, NULL),
	(1, 2439, '15.2.7.19.0.12.3.7.0.3.71', 1, NULL),
	(1, 2440, '15.2.7.19.0.12.3.8.0.3.71', 1, NULL),
	(1, 2441, '4.2.7.1.0.12.3.5.0.3.71', 1, NULL),
	(1, 2442, '4.2.7.1.0.12.3.6.0.3.71', 1, NULL),
	(1, 2443, '4.2.7.1.0.12.3.7.0.3.71', 1, NULL),
	(1, 2444, '4.2.7.1.0.12.3.8.0.3.71', 1, NULL),
	(1, 2445, '4.2.7.19.0.12.3.5.0.3.71', 1, NULL),
	(1, 2446, '4.2.7.19.0.12.3.6.0.3.71', 1, NULL),
	(1, 2447, '4.2.7.19.0.12.3.7.0.3.71', 1, NULL),
	(1, 2448, '4.2.7.19.0.12.3.8.0.3.71', 1, NULL),
	(1, 2449, '5.6.3.1.0.12.3.5.0.3.72', 1, 3),
	(1, 2450, '5.6.3.1.0.12.3.6.0.3.72', 1, 3),
	(1, 2451, '5.6.3.1.0.12.3.7.0.3.72', 1, 3),
	(1, 2452, '5.6.3.1.0.12.3.8.0.3.72', 1, 3),
	(1, 2453, 'x.6.3.1.0.12.3.5.0.3.72', 1, 3),
	(1, 2454, 'x.6.3.1.0.12.3.6.0.3.72', 1, 3),
	(1, 2455, 'x.6.3.1.0.12.3.7.0.3.72', 1, 3),
	(1, 2456, 'x.6.3.1.0.12.3.8.0.3.72', 1, 3),
	(1, 2457, '2.6.3.1.0.12.3.5.0.3.72', 1, 3),
	(1, 2458, '2.6.3.1.0.12.3.6.0.3.72', 1, 3),
	(1, 2459, '2.6.3.1.0.12.3.7.0.3.72', 1, 3),
	(1, 2460, '2.6.3.1.0.12.3.8.0.3.72', 1, 3),
	(1, 2461, '7.6.3.1.0.12.3.5.0.3.72', 1, 3),
	(1, 2462, '7.6.3.1.0.12.3.6.0.3.72', 1, 3),
	(1, 2463, '7.6.3.1.0.12.3.7.0.3.72', 1, 3),
	(1, 2464, '7.6.3.1.0.12.3.8.0.3.72', 1, 3),
	(1, 2465, '5.6.3.19.0.12.3.5.0.3.72', 1, 3),
	(1, 2466, '5.6.3.19.0.12.3.6.0.3.72', 1, 3),
	(1, 2467, '5.6.3.19.0.12.3.7.0.3.72', 1, 3),
	(1, 2468, '5.6.3.19.0.12.3.8.0.3.72', 1, 3),
	(1, 2469, 'x.6.3.19.0.12.3.5.0.3.72', 1, 3),
	(1, 2470, 'x.6.3.19.0.12.3.6.0.3.72', 1, 3),
	(1, 2471, 'x.6.3.19.0.12.3.7.0.3.72', 1, 3),
	(1, 2472, 'x.6.3.19.0.12.3.8.0.3.72', 1, 3),
	(1, 2473, '7.6.3.19.0.12.3.5.0.3.72', 1, 3),
	(1, 2474, '7.6.3.19.0.12.3.6.0.3.72', 1, 3),
	(1, 2475, '7.6.3.19.0.12.3.7.0.3.72', 1, 3),
	(1, 2476, '7.6.3.19.0.12.3.8.0.3.72', 1, 3),
	(1, 2477, '2.6.3.19.0.12.3.5.0.3.72', 1, 3),
	(1, 2478, '2.6.3.19.0.12.3.6.0.3.72', 1, 3),
	(1, 2479, '2.6.3.19.0.12.3.7.0.3.72', 1, 3),
	(1, 2480, '2.6.3.19.0.12.3.8.0.3.72', 1, 3),
	(1, 2481, '5.6.3.1.0.12.3.5.0.3.73', 1, 3),
	(1, 2482, '5.6.3.1.0.12.3.6.0.3.73', 1, 3),
	(1, 2483, '5.6.3.1.0.12.3.7.0.3.73', 1, 3),
	(1, 2484, '5.6.3.1.0.12.3.8.0.3.73', 1, 3),
	(1, 2485, 'x.6.3.1.0.12.3.5.0.3.73', 1, 3),
	(1, 2486, 'x.6.3.1.0.12.3.6.0.3.73', 1, 3),
	(1, 2487, 'x.6.3.1.0.12.3.7.0.3.73', 1, 3),
	(1, 2488, 'x.6.3.1.0.12.3.8.0.3.73', 1, 3),
	(1, 2489, '7.6.3.1.0.12.3.5.0.3.73', 1, 3),
	(1, 2490, '7.6.3.1.0.12.3.6.0.3.73', 1, 3),
	(1, 2491, '7.6.3.1.0.12.3.7.0.3.73', 1, 3),
	(1, 2492, '7.6.3.1.0.12.3.8.0.3.73', 1, 3),
	(1, 2493, '2.6.3.1.0.12.3.5.0.3.73', 1, 3),
	(1, 2494, '2.6.3.1.0.12.3.6.0.3.73', 1, 3),
	(1, 2495, '2.6.3.1.0.12.3.7.0.3.73', 1, 3),
	(1, 2496, '2.6.3.1.0.12.3.8.0.3.73', 1, 3),
	(1, 2497, 'x.6.3.19.0.12.3.5.0.3.73', 1, 3),
	(1, 2498, 'x.6.3.19.0.12.3.6.0.3.73', 1, 3),
	(1, 2499, 'x.6.3.19.0.12.3.7.0.3.73', 1, 3),
	(1, 2500, 'x.6.3.19.0.12.3.8.0.3.73', 1, 3),
	(1, 2501, '2.6.3.19.0.12.3.5.0.3.73', 1, 3),
	(1, 2502, '2.6.3.19.0.12.3.6.0.3.73', 1, 3),
	(1, 2503, '2.6.3.19.0.12.3.7.0.3.73', 1, 3),
	(1, 2504, '2.6.3.19.0.12.3.8.0.3.73', 1, 3),
	(1, 2505, '7.6.3.19.0.12.3.5.0.3.73', 1, 3),
	(1, 2506, '7.6.3.19.0.12.3.6.0.3.73', 1, 3),
	(1, 2507, '7.6.3.19.0.12.3.7.0.3.73', 1, 3),
	(1, 2508, '7.6.3.19.0.12.3.8.0.3.73', 1, 3),
	(1, 2509, '5.6.3.19.0.12.3.5.0.3.73', 1, 3),
	(1, 2510, '5.6.3.19.0.12.3.6.0.3.73', 1, 3),
	(1, 2511, '5.6.3.19.0.12.3.7.0.3.73', 1, 3),
	(1, 2512, '5.6.3.19.0.12.3.8.0.3.73', 1, 3),
	(1, 2513, '7.6.3.15.0.12.3.5.0.3.73', 1, 3),
	(1, 2514, '7.6.3.15.0.12.3.6.0.3.73', 1, 3),
	(1, 2515, '7.6.3.15.0.12.3.7.0.3.73', 1, 3),
	(1, 2516, '7.6.3.15.0.12.3.8.0.3.73', 1, 3),
	(1, 2517, 'x.6.3.15.0.12.3.5.0.3.73', 1, 3),
	(1, 2518, 'x.6.3.15.0.12.3.6.0.3.73', 1, 3),
	(1, 2519, 'x.6.3.15.0.12.3.7.0.3.73', 1, 3),
	(1, 2520, 'x.6.3.15.0.12.3.8.0.3.73', 1, 3),
	(1, 2521, '2.6.3.15.0.12.3.5.0.3.73', 1, 3),
	(1, 2522, '2.6.3.15.0.12.3.6.0.3.73', 1, 3),
	(1, 2523, '2.6.3.15.0.12.3.7.0.3.73', 1, 3),
	(1, 2524, '2.6.3.15.0.12.3.8.0.3.73', 1, 3),
	(1, 2525, '5.6.3.15.0.12.3.5.0.3.73', 1, 3),
	(1, 2526, '5.6.3.15.0.12.3.6.0.3.73', 1, 3),
	(1, 2527, '5.6.3.15.0.12.3.7.0.3.73', 1, 3),
	(1, 2528, '5.6.3.15.0.12.3.8.0.3.73', 1, 3),
	(1, 2529, '7.6.3.16.0.12.3.5.0.3.73', 1, 3),
	(1, 2530, '7.6.3.16.0.12.3.6.0.3.73', 1, 3),
	(1, 2531, '7.6.3.16.0.12.3.7.0.3.73', 1, 3),
	(1, 2532, '7.6.3.16.0.12.3.8.0.3.73', 1, 3),
	(1, 2533, 'x.6.3.16.0.12.3.5.0.3.73', 1, 3),
	(1, 2534, 'x.6.3.16.0.12.3.6.0.3.73', 1, 3),
	(1, 2535, 'x.6.3.16.0.12.3.7.0.3.73', 1, 3),
	(1, 2536, 'x.6.3.16.0.12.3.8.0.3.73', 1, 3),
	(1, 2537, '2.6.3.16.0.12.3.5.0.3.73', 1, 3),
	(1, 2538, '2.6.3.16.0.12.3.6.0.3.73', 1, 3),
	(1, 2539, '2.6.3.16.0.12.3.7.0.3.73', 1, 3),
	(1, 2540, '2.6.3.16.0.12.3.8.0.3.73', 1, 3),
	(1, 2541, '5.6.3.16.0.12.3.5.0.3.73', 1, 3),
	(1, 2542, '5.6.3.16.0.12.3.6.0.3.73', 1, 3),
	(1, 2543, '5.6.3.16.0.12.3.7.0.3.73', 1, 3),
	(1, 2544, '5.6.3.16.0.12.3.8.0.3.73', 1, 3),
	(1, 2545, '5.6.3.17.0.12.3.5.0.3.73', 1, 3),
	(1, 2546, '5.6.3.17.0.12.3.6.0.3.73', 1, 3),
	(1, 2547, '5.6.3.17.0.12.3.7.0.3.73', 1, 3),
	(1, 2548, '5.6.3.17.0.12.3.8.0.3.73', 1, 3),
	(1, 2549, '2.6.3.17.0.12.3.5.0.3.73', 1, 3),
	(1, 2550, '2.6.3.17.0.12.3.6.0.3.73', 1, 3),
	(1, 2551, '2.6.3.17.0.12.3.7.0.3.73', 1, 3),
	(1, 2552, '2.6.3.17.0.12.3.8.0.3.73', 1, 3),
	(1, 2553, 'x.6.3.17.0.12.3.5.0.3.73', 1, 3),
	(1, 2554, 'x.6.3.17.0.12.3.6.0.3.73', 1, 3),
	(1, 2555, 'x.6.3.17.0.12.3.7.0.3.73', 1, 3),
	(1, 2556, 'x.6.3.17.0.12.3.8.0.3.73', 1, 3),
	(1, 2557, '7.6.3.17.0.12.3.5.0.3.73', 1, 3),
	(1, 2558, '7.6.3.17.0.12.3.6.0.3.73', 1, 3),
	(1, 2559, '7.6.3.17.0.12.3.7.0.3.73', 1, 3),
	(1, 2560, '7.6.3.17.0.12.3.8.0.3.73', 1, 3),
	(1, 2561, 'x.6.3.18.0.12.3.5.0.3.73', 1, 3),
	(1, 2562, 'x.6.3.18.0.12.3.6.0.3.73', 1, 3),
	(1, 2563, 'x.6.3.18.0.12.3.7.0.3.73', 1, 3),
	(1, 2564, 'x.6.3.18.0.12.3.8.0.3.73', 1, 3),
	(1, 2565, '7.6.3.18.0.12.3.5.0.3.73', 1, 3),
	(1, 2566, '7.6.3.18.0.12.3.6.0.3.73', 1, 3),
	(1, 2567, '7.6.3.18.0.12.3.7.0.3.73', 1, 3),
	(1, 2568, '7.6.3.18.0.12.3.8.0.3.73', 1, 3),
	(1, 2569, '5.6.3.18.0.12.3.5.0.3.73', 1, 3),
	(1, 2570, '5.6.3.18.0.12.3.6.0.3.73', 1, 3),
	(1, 2571, '5.6.3.18.0.12.3.7.0.3.73', 1, 3),
	(1, 2572, '5.6.3.18.0.12.3.8.0.3.73', 1, 3),
	(1, 2573, '2.6.3.18.0.12.3.5.0.3.73', 1, 3),
	(1, 2574, '2.6.3.18.0.12.3.6.0.3.73', 1, 3),
	(1, 2575, '2.6.3.18.0.12.3.7.0.3.73', 1, 3),
	(1, 2576, '2.6.3.18.0.12.3.8.0.3.73', 1, 3),
	(1, 2577, '5.6.3.1.0.12.3.5.0.3.71', 1, 3),
	(1, 2578, '5.6.3.1.0.12.3.6.0.3.71', 1, 3),
	(1, 2579, '5.6.3.1.0.12.3.7.0.3.71', 1, 3),
	(1, 2580, '5.6.3.1.0.12.3.8.0.3.71', 1, 3),
	(1, 2581, '2.6.3.1.0.12.3.5.0.3.71', 1, 3),
	(1, 2582, '2.6.3.1.0.12.3.6.0.3.71', 1, 3),
	(1, 2583, '2.6.3.1.0.12.3.7.0.3.71', 1, 3),
	(1, 2584, '2.6.3.1.0.12.3.8.0.3.71', 1, 3),
	(1, 2585, 'x.6.3.1.0.12.3.5.0.3.71', 1, 3),
	(1, 2586, 'x.6.3.1.0.12.3.6.0.3.71', 1, 3),
	(1, 2587, 'x.6.3.1.0.12.3.7.0.3.71', 1, 3),
	(1, 2588, 'x.6.3.1.0.12.3.8.0.3.71', 1, 3),
	(1, 2589, '7.6.3.1.0.12.3.5.0.3.71', 1, 3),
	(1, 2590, '7.6.3.1.0.12.3.6.0.3.71', 1, 3),
	(1, 2591, '7.6.3.1.0.12.3.7.0.3.71', 1, 3),
	(1, 2592, '7.6.3.1.0.12.3.8.0.3.71', 1, 3),
	(1, 2593, '5.6.3.19.0.12.3.5.0.3.71', 1, 3),
	(1, 2594, '5.6.3.19.0.12.3.6.0.3.71', 1, 3),
	(1, 2595, '5.6.3.19.0.12.3.7.0.3.71', 1, 3),
	(1, 2596, '5.6.3.19.0.12.3.8.0.3.71', 1, 3),
	(1, 2597, '2.6.3.19.0.12.3.5.0.3.71', 1, 3),
	(1, 2598, '2.6.3.19.0.12.3.6.0.3.71', 1, 3),
	(1, 2599, '2.6.3.19.0.12.3.7.0.3.71', 1, 3),
	(1, 2600, '2.6.3.19.0.12.3.8.0.3.71', 1, 3),
	(1, 2601, '7.6.3.19.0.12.3.5.0.3.71', 1, 3),
	(1, 2602, '7.6.3.19.0.12.3.6.0.3.71', 1, 3),
	(1, 2603, '7.6.3.19.0.12.3.7.0.3.71', 1, 3),
	(1, 2604, '7.6.3.19.0.12.3.8.0.3.71', 1, 3),
	(1, 2605, 'x.6.3.19.0.12.3.5.0.3.71', 1, 3),
	(1, 2606, 'x.6.3.19.0.12.3.6.0.3.71', 1, 3),
	(1, 2607, 'x.6.3.19.0.12.3.7.0.3.71', 1, 3),
	(1, 2608, 'x.6.3.19.0.12.3.8.0.3.71', 1, 3),
	(1, 2609, '4.6.3.1.0.12.3.5.0.3.72', 1, 3),
	(1, 2610, '4.6.3.1.0.12.3.6.0.3.72', 1, 3),
	(1, 2611, '4.6.3.1.0.12.3.7.0.3.72', 1, 3),
	(1, 2612, '4.6.3.1.0.12.3.8.0.3.72', 1, 3),
	(1, 2613, '15.6.3.1.0.12.3.5.0.3.72', 1, 3),
	(1, 2614, '15.6.3.1.0.12.3.6.0.3.72', 1, 3),
	(1, 2615, '15.6.3.1.0.12.3.7.0.3.72', 1, 3),
	(1, 2616, '15.6.3.1.0.12.3.8.0.3.72', 1, 3),
	(1, 2617, '15.6.3.19.0.12.3.5.0.3.72', 1, 3),
	(1, 2618, '15.6.3.19.0.12.3.6.0.3.72', 1, 3),
	(1, 2619, '15.6.3.19.0.12.3.7.0.3.72', 1, 3),
	(1, 2620, '15.6.3.19.0.12.3.8.0.3.72', 1, 3),
	(1, 2621, '4.6.3.19.0.12.3.5.0.3.72', 1, 3),
	(1, 2622, '4.6.3.19.0.12.3.6.0.3.72', 1, 3),
	(1, 2623, '4.6.3.19.0.12.3.7.0.3.72', 1, 3),
	(1, 2624, '4.6.3.19.0.12.3.8.0.3.72', 1, 3),
	(1, 2625, '15.6.3.1.0.12.3.5.0.3.73', 1, 3),
	(1, 2626, '15.6.3.1.0.12.3.6.0.3.73', 1, 3),
	(1, 2627, '15.6.3.1.0.12.3.7.0.3.73', 1, 3),
	(1, 2628, '15.6.3.1.0.12.3.8.0.3.73', 1, 3),
	(1, 2629, '4.6.3.1.0.12.3.5.0.3.73', 1, 3),
	(1, 2630, '4.6.3.1.0.12.3.6.0.3.73', 1, 3),
	(1, 2631, '4.6.3.1.0.12.3.7.0.3.73', 1, 3),
	(1, 2632, '4.6.3.1.0.12.3.8.0.3.73', 1, 3),
	(1, 2633, '4.6.3.19.0.12.3.5.0.3.73', 1, 3),
	(1, 2634, '4.6.3.19.0.12.3.6.0.3.73', 1, 3),
	(1, 2635, '4.6.3.19.0.12.3.7.0.3.73', 1, 3),
	(1, 2636, '4.6.3.19.0.12.3.8.0.3.73', 1, 3),
	(1, 2637, '15.6.3.19.0.12.3.5.0.3.73', 1, 3),
	(1, 2638, '15.6.3.19.0.12.3.6.0.3.73', 1, 3),
	(1, 2639, '15.6.3.19.0.12.3.7.0.3.73', 1, 3),
	(1, 2640, '15.6.3.19.0.12.3.8.0.3.73', 1, 3),
	(1, 2641, '15.6.3.15.0.12.3.5.0.3.73', 1, 3),
	(1, 2642, '15.6.3.15.0.12.3.6.0.3.73', 1, 3),
	(1, 2643, '15.6.3.15.0.12.3.7.0.3.73', 1, 3),
	(1, 2644, '15.6.3.15.0.12.3.8.0.3.73', 1, 3),
	(1, 2645, '4.6.3.15.0.12.3.5.0.3.73', 1, 3),
	(1, 2646, '4.6.3.15.0.12.3.6.0.3.73', 1, 3),
	(1, 2647, '4.6.3.15.0.12.3.7.0.3.73', 1, 3),
	(1, 2648, '4.6.3.15.0.12.3.8.0.3.73', 1, 3),
	(1, 2649, '15.6.3.16.0.12.3.5.0.3.73', 1, 3),
	(1, 2650, '15.6.3.16.0.12.3.6.0.3.73', 1, 3),
	(1, 2651, '15.6.3.16.0.12.3.7.0.3.73', 1, 3),
	(1, 2652, '15.6.3.16.0.12.3.8.0.3.73', 1, 3),
	(1, 2653, '4.6.3.16.0.12.3.5.0.3.73', 1, 3),
	(1, 2654, '4.6.3.16.0.12.3.6.0.3.73', 1, 3),
	(1, 2655, '4.6.3.16.0.12.3.7.0.3.73', 1, 3),
	(1, 2656, '4.6.3.16.0.12.3.8.0.3.73', 1, 3),
	(1, 2657, '4.6.3.17.0.12.3.5.0.3.73', 1, 3),
	(1, 2658, '4.6.3.17.0.12.3.6.0.3.73', 1, 3),
	(1, 2659, '4.6.3.17.0.12.3.7.0.3.73', 1, 3),
	(1, 2660, '4.6.3.17.0.12.3.8.0.3.73', 1, 3),
	(1, 2661, '15.6.3.17.0.12.3.5.0.3.73', 1, 3),
	(1, 2662, '15.6.3.17.0.12.3.6.0.3.73', 1, 3),
	(1, 2663, '15.6.3.17.0.12.3.7.0.3.73', 1, 3),
	(1, 2664, '15.6.3.17.0.12.3.8.0.3.73', 1, 3),
	(1, 2665, '15.6.3.18.0.12.3.5.0.3.73', 1, 3),
	(1, 2666, '15.6.3.18.0.12.3.6.0.3.73', 1, 3),
	(1, 2667, '15.6.3.18.0.12.3.7.0.3.73', 1, 3),
	(1, 2668, '15.6.3.18.0.12.3.8.0.3.73', 1, 3),
	(1, 2669, '4.6.3.18.0.12.3.5.0.3.73', 1, 3),
	(1, 2670, '4.6.3.18.0.12.3.6.0.3.73', 1, 3),
	(1, 2671, '4.6.3.18.0.12.3.7.0.3.73', 1, 3),
	(1, 2672, '4.6.3.18.0.12.3.8.0.3.73', 1, 3),
	(1, 2673, '15.6.3.1.0.12.3.5.0.3.71', 1, 3),
	(1, 2674, '15.6.3.1.0.12.3.6.0.3.71', 1, 3),
	(1, 2675, '15.6.3.1.0.12.3.7.0.3.71', 1, 3),
	(1, 2676, '15.6.3.1.0.12.3.8.0.3.71', 1, 3),
	(1, 2677, '4.6.3.1.0.12.3.5.0.3.71', 1, 3),
	(1, 2678, '4.6.3.1.0.12.3.6.0.3.71', 1, 3),
	(1, 2679, '4.6.3.1.0.12.3.7.0.3.71', 1, 3),
	(1, 2680, '4.6.3.1.0.12.3.8.0.3.71', 1, 3),
	(1, 2681, '4.6.3.19.0.12.3.5.0.3.71', 1, 3),
	(1, 2682, '4.6.3.19.0.12.3.6.0.3.71', 1, 3),
	(1, 2683, '4.6.3.19.0.12.3.7.0.3.71', 1, 3),
	(1, 2684, '4.6.3.19.0.12.3.8.0.3.71', 1, 3),
	(1, 2685, '15.6.3.19.0.12.3.5.0.3.71', 1, 3),
	(1, 2686, '15.6.3.19.0.12.3.6.0.3.71', 1, 3),
	(1, 2687, '15.6.3.19.0.12.3.7.0.3.71', 1, 3),
	(1, 2688, '15.6.3.19.0.12.3.8.0.3.71', 1, 3),
	(1, 2689, '3.2.7.0.0.15.0.0.x.0.33', 1, NULL),
	(1, 2690, '3.2.7.0.0.15.0.0.128.0.33', 1, NULL),
	(1, 2691, '3.2.7.0.0.15.0.0.64.0.33', 1, NULL),
	(1, 2692, '3.2.7.0.0.15.0.0.32.0.33', 1, NULL),
	(1, 2693, '3.2.7.0.x.x.0.0.x.0.29', 1, NULL),
	(1, 2694, '3.2.7.0.x.x.0.0.128.0.29', 1, NULL),
	(1, 2695, '3.2.7.0.x.x.0.0.64.0.29', 1, NULL),
	(1, 2696, '3.2.7.0.x.x.0.0.32.0.29', 1, NULL),
	(1, 2697, 'x.2.7.0.x.x.0.0.x.2.0', 1, NULL),
	(1, 2698, 'x.2.7.0.x.x.0.0.x.2.0', 1, NULL),
	(1, 2699, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2700, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2701, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2702, '3.2.7.0.x.x.0.0.128.0.29', 1, NULL),
	(1, 2703, '3.2.7.0.x.x.0.0.64.0.29', 1, NULL),
	(1, 2704, '3.2.7.0.x.x.0.0.32.0.29', 1, NULL),
	(1, 2705, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2706, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2707, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2708, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2709, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2710, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2711, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2712, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2713, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2714, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2715, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2716, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2717, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2718, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2719, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2720, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2721, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2722, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2723, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2724, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2725, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2726, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2727, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2728, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2729, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2730, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2731, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2732, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2733, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2734, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2735, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2736, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2737, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2738, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2739, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2740, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2741, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2742, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2743, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2744, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2745, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2746, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2747, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2748, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2749, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2750, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2751, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2752, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2753, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2754, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2755, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2756, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2757, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2758, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2759, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2760, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2761, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2762, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2763, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2764, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2765, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2766, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2767, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2768, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2769, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2770, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2771, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2772, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2773, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2774, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2775, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2776, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2777, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2778, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2779, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2780, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2781, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2782, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2783, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2784, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2785, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2786, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2787, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2788, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2789, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2790, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2791, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2792, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2793, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2794, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2795, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2796, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2797, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2798, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2799, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2800, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2801, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2802, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2803, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2804, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2805, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2806, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2807, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2808, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2809, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2810, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2811, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2812, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2813, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2814, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2815, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2816, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2817, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2818, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2819, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2820, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2821, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2822, '3.2.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 2823, '3.2.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 2824, '3.2.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 2825, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2826, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2827, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2828, '3.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2829, '3.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2830, '3.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2831, '3.2.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 2832, '3.2.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 2833, '3.2.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 2834, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2835, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2836, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2837, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2838, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2839, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2840, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2841, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2842, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2843, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2844, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2845, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2846, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2847, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2848, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2849, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2850, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2851, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2852, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2853, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2854, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2855, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2856, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2857, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2858, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2859, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2860, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2861, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2862, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2863, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2864, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2865, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2866, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2867, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2868, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2869, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2870, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2871, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2872, 'x.2.7.0.x.x.0.0.128.2.0', 1, NULL),
	(1, 2873, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2874, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2875, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2876, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2877, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2878, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2879, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2880, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2881, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2882, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2883, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2884, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2885, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2886, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2887, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2888, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2889, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2890, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2891, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2892, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2893, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2894, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2895, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2896, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2897, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2898, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2899, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2900, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2901, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2902, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2903, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2904, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2905, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2906, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2907, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2908, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2909, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2910, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2911, 'x.2.7.0.x.x.0.0.64.2.0', 1, NULL),
	(1, 2912, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2913, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2914, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2915, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2916, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2917, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2918, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2919, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2920, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2921, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2922, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2923, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2924, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2925, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2926, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2927, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2928, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2929, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2930, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2931, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2932, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2933, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2934, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2935, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2936, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2937, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2938, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2939, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2940, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2941, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2942, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2943, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2944, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2945, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2946, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2947, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2948, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2949, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2950, 'x.2.7.0.x.x.0.0.32.2.0', 1, NULL),
	(1, 2951, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2952, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2953, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2954, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2955, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2956, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2957, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2958, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2959, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2960, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2961, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2962, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2963, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2964, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2965, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2966, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2967, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2968, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2969, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2970, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2971, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2972, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2973, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2974, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2975, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2976, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2977, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2978, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2979, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2980, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2981, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2982, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2983, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2984, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2985, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2986, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2987, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2988, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2989, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 2990, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 2991, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 2992, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 2993, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 2994, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 2995, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 2996, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 2997, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 2998, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 2999, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3000, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3001, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3002, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3003, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3004, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3005, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3006, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3007, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3008, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3009, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3010, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3011, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3012, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3013, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3014, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3015, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3016, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3017, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3018, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3019, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3020, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3021, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3022, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3023, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3024, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3025, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3026, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3027, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3028, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3029, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3030, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3031, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3032, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3033, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3034, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3035, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3036, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3037, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3038, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3039, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3040, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3041, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3042, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3043, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3044, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3045, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3046, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3047, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3048, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3049, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3050, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3051, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3052, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3053, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3054, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3055, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3056, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3057, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3058, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3059, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3060, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3061, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3062, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3063, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3064, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3065, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3066, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3067, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3068, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3069, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3070, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3071, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3072, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3073, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3074, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3075, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3076, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3077, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3078, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3079, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3080, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3081, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3082, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3083, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3084, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3085, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3086, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3087, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3088, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3089, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3090, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3091, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3092, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3093, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3094, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3095, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3096, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3097, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3098, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3099, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3100, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3101, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3102, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3103, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3104, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3105, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3106, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3107, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3108, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3109, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3110, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3111, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3112, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3113, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3114, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3115, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3116, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3117, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3118, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3119, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3120, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3121, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3122, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3123, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3124, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3125, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3126, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3127, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3128, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3129, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3130, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3131, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3132, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3133, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3134, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3135, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3136, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3137, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3138, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3139, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3140, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3141, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3142, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3143, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3144, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3145, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3146, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3147, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3148, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3149, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3150, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3151, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3152, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3153, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3154, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3155, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3156, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3157, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3158, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3159, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3160, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3161, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3162, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3163, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3164, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3165, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3166, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3167, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3168, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3169, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3170, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3171, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3172, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3173, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3174, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3175, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3176, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3177, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3178, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3179, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3180, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3181, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3182, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3183, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3184, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3185, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3186, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3187, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3188, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3189, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3190, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3191, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3192, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3193, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3194, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3195, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3196, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3197, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3198, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3199, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3200, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3201, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3202, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3203, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3204, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3205, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3206, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3207, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3208, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3209, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3210, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3211, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3212, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3213, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3214, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3215, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3216, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3217, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3218, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3219, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3220, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3221, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3222, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3223, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3224, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3225, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3226, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3227, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3228, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3229, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3230, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3231, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3232, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3233, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3234, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3235, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3236, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3237, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3238, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3239, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3240, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3241, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3242, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3243, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3244, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3245, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3246, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3247, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3248, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3249, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3250, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3251, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3252, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3253, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3254, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3255, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3256, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3257, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3258, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3259, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3260, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3261, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3262, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3263, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3264, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3265, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3266, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3267, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3268, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3269, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3270, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3271, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3272, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3273, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3274, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3275, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3276, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3277, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3278, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3279, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3280, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3281, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3282, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3283, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3284, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3285, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3286, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3287, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3288, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3289, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3290, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3291, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3292, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3293, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3294, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3295, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3296, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3297, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3298, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3299, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3300, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3301, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3302, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3303, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3304, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3305, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3306, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3307, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3308, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3309, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3310, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3311, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3312, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3313, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3314, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3315, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3316, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3317, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3318, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3319, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3320, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3321, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3322, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3323, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3324, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3325, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3326, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3327, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3328, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3329, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3330, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3331, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3332, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3333, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3334, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3335, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3336, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3337, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3338, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3339, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3340, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3341, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3342, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3343, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3344, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3345, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3346, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3347, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3348, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3349, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3350, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3351, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3352, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3353, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3354, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3355, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3356, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3357, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3358, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3359, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3360, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3361, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3362, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3363, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3364, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3365, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3366, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3367, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3368, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3369, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3370, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3371, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3372, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3373, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3374, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3375, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3376, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3377, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3378, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3379, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3380, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3381, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3382, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3383, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3384, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3385, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3386, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3387, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3388, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3389, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3390, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3391, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3392, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3393, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3394, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3395, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3396, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3397, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3398, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3399, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3400, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3401, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3402, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3403, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3404, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3405, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3406, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3407, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3408, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3409, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3410, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3411, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3412, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3413, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3414, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3415, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3416, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3417, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3418, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3419, '4.2.7.0.0.15.3.2.0.2.0', 1, NULL),
	(1, 3420, '4.2.7.0.0.15.3.2.0.2.0', 1, NULL),
	(1, 3421, '4.2.7.0.0.15.3.2.128.2.0', 1, NULL),
	(1, 3422, '4.2.7.0.0.15.3.2.128.2.0', 1, NULL),
	(1, 3423, '4.2.7.0.0.15.3.2.64.2.0', 1, NULL),
	(1, 3424, '4.2.7.0.0.15.3.2.64.2.0', 1, NULL),
	(1, 3425, '4.2.7.0.0.15.3.2.32.2.0', 1, NULL),
	(1, 3426, '4.2.7.0.0.15.3.2.32.2.0', 1, NULL),
	(1, 3427, '4.2.7.0.x.x.3.2.0.2.0', 1, NULL),
	(1, 3428, '4.2.7.0.x.x.3.2.0.2.0', 1, NULL),
	(1, 3429, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3430, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3431, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3432, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3433, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3434, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3435, '4.2.7.0.x.x.3.2.0.2.0', 1, NULL),
	(1, 3436, '4.2.7.0.x.x.3.2.0.2.0', 1, NULL),
	(1, 3437, '4.2.7.0.x.x.3.2.0.2.0', 1, NULL),
	(1, 3438, '4.2.7.0.x.x.3.2.0.2.0', 1, NULL),
	(1, 3439, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3440, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3441, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3442, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3443, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3444, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3445, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3446, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3447, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3448, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3449, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3450, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3451, '4.2.7.0.x.x.3.2.128.2.0', 1, NULL),
	(1, 3452, '4.2.7.0.x.x.3.2.64.2.0', 1, NULL),
	(1, 3453, '4.2.7.0.x.x.3.2.32.2.0', 1, NULL),
	(1, 3454, '4.2.7.0.0.15.3.1.0.2.0', 1, NULL),
	(1, 3455, '4.2.7.0.0.15.3.1.0.2.0', 1, NULL),
	(1, 3456, '4.2.7.0.0.15.3.1.128.2.0', 1, NULL),
	(1, 3457, '4.2.7.0.0.15.3.1.128.2.0', 1, NULL),
	(1, 3458, '4.2.7.0.0.15.3.1.64.2.0', 1, NULL),
	(1, 3459, '4.2.7.0.0.15.3.1.64.2.0', 1, NULL),
	(1, 3460, '4.2.7.0.0.15.3.1.32.2.0', 1, NULL),
	(1, 3461, '4.2.7.0.0.15.3.1.32.2.0', 1, NULL),
	(1, 3462, '4.2.7.0.x.x.3.1.0.2.0', 1, NULL),
	(1, 3463, '4.2.7.0.x.x.3.1.0.2.0', 1, NULL),
	(1, 3464, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3465, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3466, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3467, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3468, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3469, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3470, '4.2.7.0.x.x.3.1.0.2.0', 1, NULL),
	(1, 3471, '4.2.7.0.x.x.3.1.0.2.0', 1, NULL),
	(1, 3472, '4.2.7.0.x.x.3.1.0.2.0', 1, NULL),
	(1, 3473, '4.2.7.0.x.x.3.1.0.2.0', 1, NULL),
	(1, 3474, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3475, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3476, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3477, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3478, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3479, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3480, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3481, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3482, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3483, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3484, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3485, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3486, '4.2.7.0.x.x.3.1.128.2.0', 1, NULL),
	(1, 3487, '4.2.7.0.x.x.3.1.64.2.0', 1, NULL),
	(1, 3488, '4.2.7.0.x.x.3.1.32.2.0', 1, NULL),
	(1, 3489, '4.8.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 3490, '15.8.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 3491, '4.8.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 3492, '15.8.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 3493, '4.9.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 3494, '15.9.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 3495, '4.9.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 3496, '15.9.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 3497, '4.8.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 3498, '15.8.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 3499, '4.8.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 3500, '15.8.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 3501, '4.9.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 3502, '15.9.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 3503, '4.9.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 3504, '15.9.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 3505, '4.8.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 3506, '15.8.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 3507, '4.8.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 3508, '15.8.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 3509, '4.9.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 3510, '15.9.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 3511, '4.9.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 3512, '15.9.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 3513, '4.8.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 3514, '4.9.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 3515, '4.8.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 3516, '4.9.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 3517, '4.8.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 3518, '4.9.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 3519, '4.8.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 3520, '4.9.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 3521, '4.2.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 3605, '7.2.7.1.0.12.0.0.0.3.72', 1, 1),
	(1, 3606, '7.2.7.19.0.12.0.0.0.3.72', 1, 1),
	(1, 3607, '7.2.7.1.0.12.0.0.0.3.73', 1, 1),
	(1, 3608, '7.2.7.19.0.12.0.0.0.3.73', 1, 1),
	(1, 3609, '7.2.7.15.0.12.0.0.0.3.73', 1, 1),
	(1, 3610, '7.2.7.16.0.12.0.0.0.3.73', 1, 1),
	(1, 3611, '7.2.7.17.0.12.0.0.0.3.73', 1, 1),
	(1, 3612, '7.2.7.18.0.12.0.0.0.3.73', 1, 1),
	(1, 3613, '7.2.7.1.0.12.0.0.0.3.71', 1, 1),
	(1, 3614, '7.2.7.19.0.12.0.0.0.3.71', 1, 1),
	(1, 3624, '4.2.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 3625, '4.2.7.0.0.15.0.0.x.0.0', 1, NULL),
	(1, 3626, '4.2.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 3627, '4.2.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 3628, '4.2.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 3629, '4.2.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 3630, '4.2.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 3631, '4.2.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 3632, '4.2.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 3633, '4.2.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 3634, '4.2.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 3635, '4.2.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 3636, '4.2.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 3637, '4.2.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 3638, '4.2.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 3639, '4.2.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 3642, '0.2.6.0.x.x.0.0.128.0.9', 1, 3),
	(1, 3643, '0.2.6.0.x.x.0.0.64.0.9', 1, 3),
	(1, 3644, '0.2.6.0.x.x.0.0.32.0.9', 1, 3),
	(1, 3645, '0.2.6.0.x.x.0.0.128.0.9', 1, 3),
	(1, 3646, '0.2.6.0.x.x.0.0.64.0.9', 1, 3),
	(1, 3647, '0.2.6.0.x.x.0.0.32.0.9', 1, 3),
	(1, 3648, '15.8.7.1.0.37.3.1.0.3.38', 1, NULL),
	(1, 3649, '15.8.7.19.0.37.3.1.0.3.38', 1, NULL),
	(1, 3650, '15.8.7.1.0.37.3.1.0.3.63', 1, NULL),
	(1, 3651, '15.8.7.19.0.37.3.1.0.3.63', 1, NULL),
	(1, 3652, '15.8.7.1.0.37.3.1.0.3.38', 1, NULL),
	(1, 3653, '15.8.7.19.0.37.3.1.0.3.38', 1, NULL),
	(1, 3654, '15.8.7.1.0.37.3.1.0.3.63', 1, NULL),
	(1, 3655, '15.8.7.19.0.37.3.1.0.3.63', 1, NULL),
	(1, 3656, '15.8.7.1.0.37.3.1.0.3.38', 1, NULL),
	(1, 3657, '15.8.7.19.0.37.3.1.0.3.38', 1, NULL),
	(1, 3658, '15.8.7.1.0.37.3.1.0.3.63', 1, NULL),
	(1, 3659, '15.8.7.19.0.37.3.1.0.3.63', 1, NULL),
	(1, 3660, '15.8.7.1.0.37.3.1.0.3.38', 1, NULL),
	(1, 3661, '15.8.7.19.0.37.3.1.0.3.38', 1, NULL),
	(1, 3662, '15.8.7.1.0.37.3.1.0.3.63', 1, NULL),
	(1, 3663, '15.8.7.19.0.37.3.1.0.3.63', 1, NULL),
	(1, 3664, '15.8.7.1.0.37.3.2.0.3.38', 1, NULL),
	(1, 3665, '15.8.7.19.0.37.3.2.0.3.38', 1, NULL),
	(1, 3666, '15.8.7.1.0.37.3.2.0.3.63', 1, NULL),
	(1, 3667, '15.8.7.19.0.37.3.2.0.3.63', 1, NULL),
	(1, 3668, '15.8.7.1.0.37.3.2.0.3.38', 1, NULL),
	(1, 3669, '15.8.7.19.0.37.3.2.0.3.38', 1, NULL),
	(1, 3670, '15.8.7.1.0.37.3.2.0.3.63', 1, NULL),
	(1, 3671, '15.8.7.19.0.37.3.2.0.3.63', 1, NULL),
	(1, 3672, '15.8.7.1.0.37.3.2.0.3.38', 1, NULL),
	(1, 3673, '15.8.7.19.0.37.3.2.0.3.38', 1, NULL),
	(1, 3674, '15.8.7.1.0.37.3.2.0.3.63', 1, NULL),
	(1, 3675, '15.8.7.19.0.37.3.2.0.3.63', 1, NULL),
	(1, 3676, '15.8.7.1.0.37.3.2.0.3.38', 1, NULL),
	(1, 3677, '15.8.7.19.0.37.3.2.0.3.38', 1, NULL),
	(1, 3678, '15.8.7.1.0.37.3.2.0.3.63', 1, NULL),
	(1, 3679, '15.8.7.19.0.37.3.2.0.3.63', 1, NULL),
	(1, 3680, '15.8.7.1.0.37.3.3.0.3.38', 1, NULL),
	(1, 3681, '15.8.7.19.0.37.3.3.0.3.38', 1, NULL),
	(1, 3682, '15.8.7.1.0.37.3.3.0.3.63', 1, NULL),
	(1, 3683, '15.8.7.19.0.37.3.3.0.3.63', 1, NULL),
	(1, 3684, '15.8.7.1.0.37.3.3.0.3.38', 1, NULL),
	(1, 3685, '15.8.7.19.0.37.3.3.0.3.38', 1, NULL),
	(1, 3686, '15.8.7.1.0.37.3.3.0.3.63', 1, NULL),
	(1, 3687, '15.8.7.19.0.37.3.3.0.3.63', 1, NULL),
	(1, 3688, '15.8.7.1.0.37.3.3.0.3.38', 1, NULL),
	(1, 3689, '15.8.7.19.0.37.3.3.0.3.38', 1, NULL),
	(1, 3690, '15.8.7.1.0.37.3.3.0.3.63', 1, NULL),
	(1, 3691, '15.8.7.19.0.37.3.3.0.3.63', 1, NULL),
	(1, 3692, '15.8.7.1.0.37.3.3.0.3.38', 1, NULL),
	(1, 3693, '15.8.7.19.0.37.3.3.0.3.38', 1, NULL),
	(1, 3694, '15.8.7.1.0.37.3.3.0.3.63', 1, NULL),
	(1, 3695, '15.8.7.19.0.37.3.3.0.3.63', 1, NULL),
	(1, 3696, '15.8.7.1.0.37.3.4.0.3.38', 1, NULL),
	(1, 3697, '15.8.7.19.0.37.3.4.0.3.38', 1, NULL),
	(1, 3698, '15.8.7.1.0.37.3.4.0.3.63', 1, NULL),
	(1, 3699, '15.8.7.19.0.37.3.4.0.3.63', 1, NULL),
	(1, 3700, '15.8.7.1.0.37.3.4.0.3.38', 1, NULL),
	(1, 3701, '15.8.7.19.0.37.3.4.0.3.38', 1, NULL),
	(1, 3702, '15.8.7.1.0.37.3.4.0.3.63', 1, NULL),
	(1, 3703, '15.8.7.19.0.37.3.4.0.3.63', 1, NULL),
	(1, 3704, '15.8.7.1.0.37.3.4.0.3.38', 1, NULL),
	(1, 3705, '15.8.7.19.0.37.3.4.0.3.38', 1, NULL),
	(1, 3706, '15.8.7.1.0.37.3.4.0.3.63', 1, NULL),
	(1, 3707, '15.8.7.19.0.37.3.4.0.3.63', 1, NULL),
	(1, 3708, '15.8.7.1.0.37.3.4.0.3.38', 1, NULL),
	(1, 3709, '15.8.7.19.0.37.3.4.0.3.38', 1, NULL),
	(1, 3710, '15.8.7.1.0.37.3.4.0.3.63', 1, NULL),
	(1, 3711, '15.8.7.19.0.37.3.4.0.3.63', 1, NULL),
	(1, 3712, '4.8.7.1.0.37.3.1.0.3.38', 1, NULL),
	(1, 3713, '4.8.7.19.0.37.3.1.0.3.38', 1, NULL),
	(1, 3714, '4.8.7.1.0.37.3.1.0.3.63', 1, NULL),
	(1, 3715, '4.8.7.19.0.37.3.1.0.3.63', 1, NULL),
	(1, 3716, '4.8.7.1.0.37.3.1.0.3.38', 1, NULL),
	(1, 3717, '4.8.7.19.0.37.3.1.0.3.38', 1, NULL),
	(1, 3718, '4.8.7.1.0.37.3.1.0.3.63', 1, NULL),
	(1, 3719, '4.8.7.19.0.37.3.1.0.3.63', 1, NULL),
	(1, 3720, '4.8.7.1.0.37.3.1.0.3.38', 1, NULL),
	(1, 3721, '4.8.7.19.0.37.3.1.0.3.38', 1, NULL),
	(1, 3722, '4.8.7.1.0.37.3.1.0.3.63', 1, NULL),
	(1, 3723, '4.8.7.19.0.37.3.1.0.3.63', 1, NULL),
	(1, 3724, '4.8.7.1.0.37.3.1.0.3.38', 1, NULL),
	(1, 3725, '4.8.7.19.0.37.3.1.0.3.38', 1, NULL),
	(1, 3726, '4.8.7.1.0.37.3.1.0.3.63', 1, NULL),
	(1, 3727, '4.8.7.19.0.37.3.1.0.3.63', 1, NULL),
	(1, 3728, '4.8.7.1.0.37.3.2.0.3.38', 1, NULL),
	(1, 3729, '4.8.7.19.0.37.3.2.0.3.38', 1, NULL),
	(1, 3730, '4.8.7.1.0.37.3.2.0.3.63', 1, NULL),
	(1, 3731, '4.8.7.19.0.37.3.2.0.3.63', 1, NULL),
	(1, 3732, '4.8.7.1.0.37.3.2.0.3.38', 1, NULL),
	(1, 3733, '4.8.7.19.0.37.3.2.0.3.38', 1, NULL),
	(1, 3734, '4.8.7.1.0.37.3.2.0.3.63', 1, NULL),
	(1, 3735, '4.8.7.19.0.37.3.2.0.3.63', 1, NULL),
	(1, 3736, '4.8.7.1.0.37.3.2.0.3.38', 1, NULL),
	(1, 3737, '4.8.7.19.0.37.3.2.0.3.38', 1, NULL),
	(1, 3738, '4.8.7.1.0.37.3.2.0.3.63', 1, NULL),
	(1, 3739, '4.8.7.19.0.37.3.2.0.3.63', 1, NULL),
	(1, 3740, '4.8.7.1.0.37.3.2.0.3.38', 1, NULL),
	(1, 3741, '4.8.7.19.0.37.3.2.0.3.38', 1, NULL),
	(1, 3742, '4.8.7.1.0.37.3.2.0.3.63', 1, NULL),
	(1, 3743, '4.8.7.19.0.37.3.2.0.3.63', 1, NULL),
	(1, 3744, '4.8.7.1.0.37.3.3.0.3.38', 1, NULL),
	(1, 3745, '4.8.7.19.0.37.3.3.0.3.38', 1, NULL),
	(1, 3746, '4.8.7.1.0.37.3.3.0.3.63', 1, NULL),
	(1, 3747, '4.8.7.19.0.37.3.3.0.3.63', 1, NULL),
	(1, 3748, '4.8.7.1.0.37.3.3.0.3.38', 1, NULL),
	(1, 3749, '4.8.7.19.0.37.3.3.0.3.38', 1, NULL),
	(1, 3750, '4.8.7.1.0.37.3.3.0.3.63', 1, NULL),
	(1, 3751, '4.8.7.19.0.37.3.3.0.3.63', 1, NULL),
	(1, 3752, '4.8.7.1.0.37.3.3.0.3.38', 1, NULL),
	(1, 3753, '4.8.7.19.0.37.3.3.0.3.38', 1, NULL),
	(1, 3754, '4.8.7.1.0.37.3.3.0.3.63', 1, NULL),
	(1, 3755, '4.8.7.19.0.37.3.3.0.3.63', 1, NULL),
	(1, 3756, '4.8.7.1.0.37.3.3.0.3.38', 1, NULL),
	(1, 3757, '4.8.7.19.0.37.3.3.0.3.38', 1, NULL),
	(1, 3758, '4.8.7.1.0.37.3.3.0.3.63', 1, NULL),
	(1, 3759, '4.8.7.19.0.37.3.3.0.3.63', 1, NULL),
	(1, 3760, '4.8.7.1.0.37.3.4.0.3.38', 1, NULL),
	(1, 3761, '4.8.7.19.0.37.3.4.0.3.38', 1, NULL),
	(1, 3762, '4.8.7.1.0.37.3.4.0.3.63', 1, NULL),
	(1, 3763, '4.8.7.19.0.37.3.4.0.3.63', 1, NULL),
	(1, 3764, '4.8.7.1.0.37.3.4.0.3.38', 1, NULL),
	(1, 3765, '4.8.7.19.0.37.3.4.0.3.38', 1, NULL),
	(1, 3766, '4.8.7.1.0.37.3.4.0.3.63', 1, NULL),
	(1, 3767, '4.8.7.19.0.37.3.4.0.3.63', 1, NULL),
	(1, 3768, '4.8.7.1.0.37.3.4.0.3.38', 1, NULL),
	(1, 3769, '4.8.7.19.0.37.3.4.0.3.38', 1, NULL),
	(1, 3770, '4.8.7.1.0.37.3.4.0.3.63', 1, NULL),
	(1, 3771, '4.8.7.19.0.37.3.4.0.3.63', 1, NULL),
	(1, 3772, '4.8.7.1.0.37.3.4.0.3.38', 1, NULL),
	(1, 3773, '4.8.7.19.0.37.3.4.0.3.38', 1, NULL),
	(1, 3774, '4.8.7.1.0.37.3.4.0.3.63', 1, NULL),
	(1, 3775, '4.8.7.19.0.37.3.4.0.3.63', 1, NULL),
	(1, 3776, '15.8.7.15.0.37.3.1.0.3.63', 1, NULL),
	(1, 3777, '15.8.7.16.0.37.3.1.0.3.63', 1, NULL),
	(1, 3778, '15.8.7.17.0.37.3.1.0.3.63', 1, NULL),
	(1, 3779, '15.8.7.18.0.37.3.1.0.3.63', 1, NULL),
	(1, 3780, '15.8.7.1.0.37.3.1.0.3.61', 1, NULL),
	(1, 3781, '15.8.7.19.0.37.3.1.0.3.61', 1, NULL),
	(1, 3782, '15.8.7.15.0.37.3.1.0.3.63', 1, NULL),
	(1, 3783, '15.8.7.16.0.37.3.1.0.3.63', 1, NULL),
	(1, 3784, '15.8.7.17.0.37.3.1.0.3.63', 1, NULL),
	(1, 3785, '15.8.7.18.0.37.3.1.0.3.63', 1, NULL),
	(1, 3786, '15.8.7.1.0.37.3.1.0.3.61', 1, NULL),
	(1, 3787, '15.8.7.19.0.37.3.1.0.3.61', 1, NULL),
	(1, 3788, '15.8.7.15.0.37.3.1.0.3.63', 1, NULL),
	(1, 3789, '15.8.7.16.0.37.3.1.0.3.63', 1, NULL),
	(1, 3790, '15.8.7.17.0.37.3.1.0.3.63', 1, NULL),
	(1, 3791, '15.8.7.18.0.37.3.1.0.3.63', 1, NULL),
	(1, 3792, '15.8.7.1.0.37.3.1.0.3.61', 1, NULL),
	(1, 3793, '15.8.7.19.0.37.3.1.0.3.61', 1, NULL),
	(1, 3794, '15.8.7.15.0.37.3.1.0.3.63', 1, NULL),
	(1, 3795, '15.8.7.16.0.37.3.1.0.3.63', 1, NULL),
	(1, 3796, '15.8.7.17.0.37.3.1.0.3.63', 1, NULL),
	(1, 3797, '15.8.7.18.0.37.3.1.0.3.63', 1, NULL),
	(1, 3798, '15.8.7.1.0.37.3.1.0.3.61', 1, NULL),
	(1, 3799, '15.8.7.19.0.37.3.1.0.3.61', 1, NULL),
	(1, 3800, '15.8.7.15.0.37.3.2.0.3.63', 1, NULL),
	(1, 3801, '15.8.7.16.0.37.3.2.0.3.63', 1, NULL),
	(1, 3802, '15.8.7.17.0.37.3.2.0.3.63', 1, NULL),
	(1, 3803, '15.8.7.18.0.37.3.2.0.3.63', 1, NULL),
	(1, 3804, '15.8.7.1.0.37.3.2.0.3.61', 1, NULL),
	(1, 3805, '15.8.7.19.0.37.3.2.0.3.61', 1, NULL),
	(1, 3806, '15.8.7.15.0.37.3.2.0.3.63', 1, NULL),
	(1, 3807, '15.8.7.16.0.37.3.2.0.3.63', 1, NULL),
	(1, 3808, '15.8.7.17.0.37.3.2.0.3.63', 1, NULL),
	(1, 3809, '15.8.7.18.0.37.3.2.0.3.63', 1, NULL),
	(1, 3810, '15.8.7.1.0.37.3.2.0.3.61', 1, NULL),
	(1, 3811, '15.8.7.19.0.37.3.2.0.3.61', 1, NULL),
	(1, 3812, '15.8.7.15.0.37.3.2.0.3.63', 1, NULL),
	(1, 3813, '15.8.7.16.0.37.3.2.0.3.63', 1, NULL),
	(1, 3814, '15.8.7.17.0.37.3.2.0.3.63', 1, NULL),
	(1, 3815, '15.8.7.18.0.37.3.2.0.3.63', 1, NULL),
	(1, 3816, '15.8.7.1.0.37.3.2.0.3.61', 1, NULL),
	(1, 3817, '15.8.7.19.0.37.3.2.0.3.61', 1, NULL),
	(1, 3818, '15.8.7.15.0.37.3.2.0.3.63', 1, NULL),
	(1, 3819, '15.8.7.16.0.37.3.2.0.3.63', 1, NULL),
	(1, 3820, '15.8.7.17.0.37.3.2.0.3.63', 1, NULL),
	(1, 3821, '15.8.7.18.0.37.3.2.0.3.63', 1, NULL),
	(1, 3822, '15.8.7.1.0.37.3.2.0.3.61', 1, NULL),
	(1, 3823, '15.8.7.19.0.37.3.2.0.3.61', 1, NULL),
	(1, 3824, '15.8.7.15.0.37.3.3.0.3.63', 1, NULL),
	(1, 3825, '15.8.7.16.0.37.3.3.0.3.63', 1, NULL),
	(1, 3826, '15.8.7.17.0.37.3.3.0.3.63', 1, NULL),
	(1, 3827, '15.8.7.18.0.37.3.3.0.3.63', 1, NULL),
	(1, 3828, '15.8.7.1.0.37.3.3.0.3.61', 1, NULL),
	(1, 3829, '15.8.7.19.0.37.3.3.0.3.61', 1, NULL),
	(1, 3830, '15.8.7.15.0.37.3.3.0.3.63', 1, NULL),
	(1, 3831, '15.8.7.16.0.37.3.3.0.3.63', 1, NULL),
	(1, 3832, '15.8.7.17.0.37.3.3.0.3.63', 1, NULL),
	(1, 3833, '15.8.7.18.0.37.3.3.0.3.63', 1, NULL),
	(1, 3834, '15.8.7.1.0.37.3.3.0.3.61', 1, NULL),
	(1, 3835, '15.8.7.19.0.37.3.3.0.3.61', 1, NULL),
	(1, 3836, '15.8.7.15.0.37.3.3.0.3.63', 1, NULL),
	(1, 3837, '15.8.7.16.0.37.3.3.0.3.63', 1, NULL),
	(1, 3838, '15.8.7.17.0.37.3.3.0.3.63', 1, NULL),
	(1, 3839, '15.8.7.18.0.37.3.3.0.3.63', 1, NULL),
	(1, 3840, '15.8.7.1.0.37.3.3.0.3.61', 1, NULL),
	(1, 3841, '15.8.7.19.0.37.3.3.0.3.61', 1, NULL),
	(1, 3842, '15.8.7.15.0.37.3.3.0.3.63', 1, NULL),
	(1, 3843, '15.8.7.16.0.37.3.3.0.3.63', 1, NULL),
	(1, 3844, '15.8.7.17.0.37.3.3.0.3.63', 1, NULL),
	(1, 3845, '15.8.7.18.0.37.3.3.0.3.63', 1, NULL),
	(1, 3846, '15.8.7.1.0.37.3.3.0.3.61', 1, NULL),
	(1, 3847, '15.8.7.19.0.37.3.3.0.3.61', 1, NULL),
	(1, 3848, '15.8.7.15.0.37.3.4.0.3.63', 1, NULL),
	(1, 3849, '15.8.7.16.0.37.3.4.0.3.63', 1, NULL),
	(1, 3850, '15.8.7.17.0.37.3.4.0.3.63', 1, NULL),
	(1, 3851, '15.8.7.18.0.37.3.4.0.3.63', 1, NULL),
	(1, 3852, '15.8.7.1.0.37.3.4.0.3.61', 1, NULL),
	(1, 3853, '15.8.7.19.0.37.3.4.0.3.61', 1, NULL),
	(1, 3854, '15.8.7.15.0.37.3.4.0.3.63', 1, NULL),
	(1, 3855, '15.8.7.16.0.37.3.4.0.3.63', 1, NULL),
	(1, 3856, '15.8.7.17.0.37.3.4.0.3.63', 1, NULL),
	(1, 3857, '15.8.7.18.0.37.3.4.0.3.63', 1, NULL),
	(1, 3858, '15.8.7.1.0.37.3.4.0.3.61', 1, NULL),
	(1, 3859, '15.8.7.19.0.37.3.4.0.3.61', 1, NULL),
	(1, 3860, '15.8.7.15.0.37.3.4.0.3.63', 1, NULL),
	(1, 3861, '15.8.7.16.0.37.3.4.0.3.63', 1, NULL),
	(1, 3862, '15.8.7.17.0.37.3.4.0.3.63', 1, NULL),
	(1, 3863, '15.8.7.18.0.37.3.4.0.3.63', 1, NULL),
	(1, 3864, '15.8.7.1.0.37.3.4.0.3.61', 1, NULL),
	(1, 3865, '15.8.7.19.0.37.3.4.0.3.61', 1, NULL),
	(1, 3866, '15.8.7.15.0.37.3.4.0.3.63', 1, NULL),
	(1, 3867, '15.8.7.16.0.37.3.4.0.3.63', 1, NULL),
	(1, 3868, '15.8.7.17.0.37.3.4.0.3.63', 1, NULL),
	(1, 3869, '15.8.7.18.0.37.3.4.0.3.63', 1, NULL),
	(1, 3870, '15.8.7.1.0.37.3.4.0.3.61', 1, NULL),
	(1, 3871, '15.8.7.19.0.37.3.4.0.3.61', 1, NULL),
	(1, 3872, '4.8.7.15.0.37.3.1.0.3.63', 1, NULL),
	(1, 3873, '4.8.7.16.0.37.3.1.0.3.63', 1, NULL),
	(1, 3874, '4.8.7.17.0.37.3.1.0.3.63', 1, NULL),
	(1, 3875, '4.8.7.18.0.37.3.1.0.3.63', 1, NULL),
	(1, 3876, '4.8.7.1.0.37.3.1.0.3.61', 1, NULL),
	(1, 3877, '4.8.7.19.0.37.3.1.0.3.61', 1, NULL),
	(1, 3878, '4.8.7.15.0.37.3.1.0.3.63', 1, NULL),
	(1, 3879, '4.8.7.16.0.37.3.1.0.3.63', 1, NULL),
	(1, 3880, '4.8.7.17.0.37.3.1.0.3.63', 1, NULL),
	(1, 3881, '4.8.7.18.0.37.3.1.0.3.63', 1, NULL),
	(1, 3882, '4.8.7.1.0.37.3.1.0.3.61', 1, NULL),
	(1, 3883, '4.8.7.19.0.37.3.1.0.3.61', 1, NULL),
	(1, 3884, '4.8.7.15.0.37.3.1.0.3.63', 1, NULL),
	(1, 3885, '4.8.7.16.0.37.3.1.0.3.63', 1, NULL),
	(1, 3886, '4.8.7.17.0.37.3.1.0.3.63', 1, NULL),
	(1, 3887, '4.8.7.18.0.37.3.1.0.3.63', 1, NULL),
	(1, 3888, '4.8.7.1.0.37.3.1.0.3.61', 1, NULL),
	(1, 3889, '4.8.7.19.0.37.3.1.0.3.61', 1, NULL),
	(1, 3890, '4.8.7.15.0.37.3.1.0.3.63', 1, NULL),
	(1, 3891, '4.8.7.16.0.37.3.1.0.3.63', 1, NULL),
	(1, 3892, '4.8.7.17.0.37.3.1.0.3.63', 1, NULL),
	(1, 3893, '4.8.7.18.0.37.3.1.0.3.63', 1, NULL),
	(1, 3894, '4.8.7.1.0.37.3.1.0.3.61', 1, NULL),
	(1, 3895, '4.8.7.19.0.37.3.1.0.3.61', 1, NULL),
	(1, 3896, '4.8.7.15.0.37.3.2.0.3.63', 1, NULL),
	(1, 3897, '4.8.7.16.0.37.3.2.0.3.63', 1, NULL),
	(1, 3898, '4.8.7.17.0.37.3.2.0.3.63', 1, NULL),
	(1, 3899, '4.8.7.18.0.37.3.2.0.3.63', 1, NULL),
	(1, 3900, '4.8.7.1.0.37.3.2.0.3.61', 1, NULL),
	(1, 3901, '4.8.7.19.0.37.3.2.0.3.61', 1, NULL),
	(1, 3902, '4.8.7.15.0.37.3.2.0.3.63', 1, NULL),
	(1, 3903, '4.8.7.16.0.37.3.2.0.3.63', 1, NULL),
	(1, 3904, '4.8.7.17.0.37.3.2.0.3.63', 1, NULL),
	(1, 3905, '4.8.7.18.0.37.3.2.0.3.63', 1, NULL),
	(1, 3906, '4.8.7.1.0.37.3.2.0.3.61', 1, NULL),
	(1, 3907, '4.8.7.19.0.37.3.2.0.3.61', 1, NULL),
	(1, 3908, '4.8.7.15.0.37.3.2.0.3.63', 1, NULL),
	(1, 3909, '4.8.7.16.0.37.3.2.0.3.63', 1, NULL),
	(1, 3910, '4.8.7.17.0.37.3.2.0.3.63', 1, NULL),
	(1, 3911, '4.8.7.18.0.37.3.2.0.3.63', 1, NULL),
	(1, 3912, '4.8.7.1.0.37.3.2.0.3.61', 1, NULL),
	(1, 3913, '4.8.7.19.0.37.3.2.0.3.61', 1, NULL),
	(1, 3914, '4.8.7.15.0.37.3.2.0.3.63', 1, NULL),
	(1, 3915, '4.8.7.16.0.37.3.2.0.3.63', 1, NULL),
	(1, 3916, '4.8.7.17.0.37.3.2.0.3.63', 1, NULL),
	(1, 3917, '4.8.7.18.0.37.3.2.0.3.63', 1, NULL),
	(1, 3918, '4.8.7.1.0.37.3.2.0.3.61', 1, NULL),
	(1, 3919, '4.8.7.19.0.37.3.2.0.3.61', 1, NULL),
	(1, 3920, '4.8.7.15.0.37.3.3.0.3.63', 1, NULL),
	(1, 3921, '4.8.7.16.0.37.3.3.0.3.63', 1, NULL),
	(1, 3922, '4.8.7.17.0.37.3.3.0.3.63', 1, NULL),
	(1, 3923, '4.8.7.18.0.37.3.3.0.3.63', 1, NULL),
	(1, 3924, '4.8.7.1.0.37.3.3.0.3.61', 1, NULL),
	(1, 3925, '4.8.7.19.0.37.3.3.0.3.61', 1, NULL),
	(1, 3926, '4.8.7.15.0.37.3.3.0.3.63', 1, NULL),
	(1, 3927, '4.8.7.16.0.37.3.3.0.3.63', 1, NULL),
	(1, 3928, '4.8.7.17.0.37.3.3.0.3.63', 1, NULL),
	(1, 3929, '4.8.7.18.0.37.3.3.0.3.63', 1, NULL),
	(1, 3930, '4.8.7.1.0.37.3.3.0.3.61', 1, NULL),
	(1, 3931, '4.8.7.19.0.37.3.3.0.3.61', 1, NULL),
	(1, 3932, '4.8.7.15.0.37.3.3.0.3.63', 1, NULL),
	(1, 3933, '4.8.7.16.0.37.3.3.0.3.63', 1, NULL),
	(1, 3934, '4.8.7.17.0.37.3.3.0.3.63', 1, NULL),
	(1, 3935, '4.8.7.18.0.37.3.3.0.3.63', 1, NULL),
	(1, 3936, '4.8.7.1.0.37.3.3.0.3.61', 1, NULL),
	(1, 3937, '4.8.7.19.0.37.3.3.0.3.61', 1, NULL),
	(1, 3938, '4.8.7.15.0.37.3.3.0.3.63', 1, NULL),
	(1, 3939, '4.8.7.16.0.37.3.3.0.3.63', 1, NULL),
	(1, 3940, '4.8.7.17.0.37.3.3.0.3.63', 1, NULL),
	(1, 3941, '4.8.7.18.0.37.3.3.0.3.63', 1, NULL),
	(1, 3942, '4.8.7.1.0.37.3.3.0.3.61', 1, NULL),
	(1, 3943, '4.8.7.19.0.37.3.3.0.3.61', 1, NULL),
	(1, 3944, '4.8.7.15.0.37.3.4.0.3.63', 1, NULL),
	(1, 3945, '4.8.7.16.0.37.3.4.0.3.63', 1, NULL),
	(1, 3946, '4.8.7.17.0.37.3.4.0.3.63', 1, NULL),
	(1, 3947, '4.8.7.18.0.37.3.4.0.3.63', 1, NULL),
	(1, 3948, '4.8.7.1.0.37.3.4.0.3.61', 1, NULL),
	(1, 3949, '4.8.7.19.0.37.3.4.0.3.61', 1, NULL),
	(1, 3950, '4.8.7.15.0.37.3.4.0.3.63', 1, NULL),
	(1, 3951, '4.8.7.16.0.37.3.4.0.3.63', 1, NULL),
	(1, 3952, '4.8.7.17.0.37.3.4.0.3.63', 1, NULL),
	(1, 3953, '4.8.7.18.0.37.3.4.0.3.63', 1, NULL),
	(1, 3954, '4.8.7.1.0.37.3.4.0.3.61', 1, NULL),
	(1, 3955, '4.8.7.19.0.37.3.4.0.3.61', 1, NULL),
	(1, 3956, '4.8.7.15.0.37.3.4.0.3.63', 1, NULL),
	(1, 3957, '4.8.7.16.0.37.3.4.0.3.63', 1, NULL),
	(1, 3958, '4.8.7.17.0.37.3.4.0.3.63', 1, NULL),
	(1, 3959, '4.8.7.18.0.37.3.4.0.3.63', 1, NULL),
	(1, 3960, '4.8.7.1.0.37.3.4.0.3.61', 1, NULL),
	(1, 3961, '4.8.7.19.0.37.3.4.0.3.61', 1, NULL),
	(1, 3962, '4.8.7.15.0.37.3.4.0.3.63', 1, NULL),
	(1, 3963, '4.8.7.16.0.37.3.4.0.3.63', 1, NULL),
	(1, 3964, '4.8.7.17.0.37.3.4.0.3.63', 1, NULL),
	(1, 3965, '4.8.7.18.0.37.3.4.0.3.63', 1, NULL),
	(1, 3966, '4.8.7.1.0.37.3.4.0.3.61', 1, NULL),
	(1, 3967, '4.8.7.19.0.37.3.4.0.3.61', 1, NULL),
	(1, 3990, '0.2.6.0.x.x.0.0.x.0.9', 1, 3),
	(1, 3991, '0.2.6.0.x.x.0.0.x.0.9', 1, 3),
	(1, 3992, '0.2.6.0.x.x.0.0.x.0.9', 1, 3),
	(1, 3993, '0.2.6.0.x.x.0.0.128.0.9', 1, 3),
	(1, 3994, '0.2.6.0.x.x.0.0.64.0.9', 1, 3),
	(1, 3995, '0.2.6.0.x.x.0.0.32.0.9', 1, 3),
	(1, 3996, '0.2.6.0.0.38.0.0.128.0.0', 1, 3),
	(1, 3997, '0.2.6.0.0.38.0.0.64.0.0', 1, 3),
	(1, 3998, '0.2.6.0.0.38.0.0.32.0.0', 1, 3),
	(1, 3999, '5.2.7.0.0.12.0.0.0.3.72', 1, 1),
	(1, 4000, '5.2.7.0.0.37.0.0.0.3.38', 1, 1),
	(1, 4001, '4.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4002, '15.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4003, '4.8.7.0.0.37.3.1.0.3.38', 1, NULL),
	(1, 4004, '15.8.7.0.0.37.3.1.0.3.38', 1, NULL),
	(1, 4005, '4.8.7.0.0.37.3.2.0.3.38', 1, NULL),
	(1, 4006, '15.8.7.0.0.37.3.2.0.3.38', 1, NULL),
	(1, 4007, '4.8.7.0.0.37.3.3.0.3.38', 1, NULL),
	(1, 4008, '15.8.7.0.0.37.3.3.0.3.38', 1, NULL),
	(1, 4009, '4.8.7.0.0.37.3.4.0.3.38', 1, NULL),
	(1, 4010, '15.8.7.0.0.37.3.4.0.3.38', 1, NULL),
	(1, 4011, '4.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4012, '15.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4013, '5.2.7.0.0.12.0.0.0.3.73', 1, 1),
	(1, 4014, '5.2.7.0.0.37.0.0.0.3.63', 1, 1),
	(1, 4015, '4.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4016, '15.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4017, '4.8.7.0.0.37.3.1.0.3.63', 1, NULL),
	(1, 4018, '15.8.7.0.0.37.3.1.0.3.63', 1, NULL),
	(1, 4019, '4.8.7.0.0.37.3.2.0.3.63', 1, NULL),
	(1, 4020, '15.8.7.0.0.37.3.2.0.3.63', 1, NULL),
	(1, 4021, '4.8.7.0.0.37.3.3.0.3.63', 1, NULL),
	(1, 4022, '15.8.7.0.0.37.3.3.0.3.63', 1, NULL),
	(1, 4023, '4.8.7.0.0.37.3.4.0.3.63', 1, NULL),
	(1, 4024, '15.8.7.0.0.37.3.4.0.3.63', 1, NULL),
	(1, 4025, '4.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4026, '15.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4027, '5.2.7.0.0.12.0.0.0.3.71', 1, 1),
	(1, 4028, '5.2.7.0.0.37.0.0.0.3.61', 1, 1),
	(1, 4029, '4.8.7.0.0.37.3.1.0.3.61', 1, NULL),
	(1, 4030, '15.8.7.0.0.37.3.1.0.3.61', 1, NULL),
	(1, 4031, '4.8.7.0.0.37.3.2.0.3.61', 1, NULL),
	(1, 4032, '15.8.7.0.0.37.3.2.0.3.61', 1, NULL),
	(1, 4033, '4.8.7.0.0.37.3.3.0.3.61', 1, NULL),
	(1, 4034, '15.8.7.0.0.37.3.3.0.3.61', 1, NULL),
	(1, 4035, '4.8.7.0.0.37.3.4.0.3.61', 1, NULL),
	(1, 4036, '15.8.7.0.0.37.3.4.0.3.61', 1, NULL),
	(1, 4037, '4.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4038, '15.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4039, '4.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4040, '15.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4041, '7.2.7.0.0.12.0.0.0.3.72', 1, 1),
	(1, 4042, '7.2.7.0.0.37.0.0.0.3.38', 1, 1),
	(1, 4043, '4.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4044, '15.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4045, '4.8.7.0.0.37.3.1.0.3.38', 1, NULL),
	(1, 4046, '15.8.7.0.0.37.3.1.0.3.38', 1, NULL),
	(1, 4047, '4.8.7.0.0.37.3.2.0.3.38', 1, NULL),
	(1, 4048, '15.8.7.0.0.37.3.2.0.3.38', 1, NULL),
	(1, 4049, '4.8.7.0.0.37.3.3.0.3.38', 1, NULL),
	(1, 4050, '15.8.7.0.0.37.3.3.0.3.38', 1, NULL),
	(1, 4051, '4.8.7.0.0.37.3.4.0.3.38', 1, NULL),
	(1, 4052, '15.8.7.0.0.37.3.4.0.3.38', 1, NULL),
	(1, 4053, '4.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4054, '15.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4055, '7.2.7.0.0.12.0.0.0.3.73', 1, 1),
	(1, 4056, '7.2.7.0.0.37.0.0.0.3.63', 1, 1),
	(1, 4057, '4.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4058, '15.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4059, '4.8.7.0.0.37.3.1.0.3.63', 1, NULL),
	(1, 4060, '15.8.7.0.0.37.3.1.0.3.63', 1, NULL),
	(1, 4061, '4.8.7.0.0.37.3.2.0.3.63', 1, NULL),
	(1, 4062, '15.8.7.0.0.37.3.2.0.3.63', 1, NULL),
	(1, 4063, '4.8.7.0.0.37.3.3.0.3.63', 1, NULL),
	(1, 4064, '15.8.7.0.0.37.3.3.0.3.63', 1, NULL),
	(1, 4065, '4.8.7.0.0.37.3.4.0.3.63', 1, NULL),
	(1, 4066, '15.8.7.0.0.37.3.4.0.3.63', 1, NULL),
	(1, 4067, '4.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4068, '15.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4069, '7.2.7.0.0.12.0.0.0.3.71', 1, 1),
	(1, 4070, '7.2.7.0.0.37.0.0.0.3.61', 1, 1),
	(1, 4071, '4.8.7.0.0.37.3.4.0.3.61', 1, NULL),
	(1, 4072, '15.8.7.0.0.37.3.4.0.3.61', 1, NULL),
	(1, 4073, '4.8.7.0.0.37.3.3.0.3.61', 1, NULL),
	(1, 4074, '15.8.7.0.0.37.3.3.0.3.61', 1, NULL),
	(1, 4075, '4.8.7.0.0.37.3.2.0.3.61', 1, NULL),
	(1, 4076, '15.8.7.0.0.37.3.2.0.3.61', 1, NULL),
	(1, 4077, '4.8.7.0.0.37.3.1.0.3.61', 1, NULL),
	(1, 4078, '15.8.7.0.0.37.3.1.0.3.61', 1, NULL),
	(1, 4079, '4.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4080, '15.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4081, '4.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4082, '15.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4083, '3.2.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4084, '3.2.7.0.0.12.0.0.0.3.73', 1, NULL),
	(1, 4085, '4.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4086, '15.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4087, '4.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4088, '15.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4089, '3.2.7.0.0.12.0.0.0.3.72', 1, NULL),
	(1, 4090, '3.2.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4091, '4.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4092, '15.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4093, '4.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4094, '15.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4095, '3.2.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4096, '3.2.7.0.0.12.0.0.0.3.71', 1, NULL),
	(1, 4097, '4.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4098, '15.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4099, '4.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4100, '15.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4101, '10.2.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4102, '10.2.7.0.0.12.0.0.0.3.72', 1, NULL),
	(1, 4103, '4.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4104, '15.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4105, '4.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4106, '15.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4107, '10.2.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4108, '10.2.7.0.0.12.0.0.0.3.73', 1, NULL),
	(1, 4109, '4.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4110, '15.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4111, '4.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4112, '15.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4113, '10.2.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4114, '10.2.7.0.0.12.0.0.0.3.71', 1, NULL),
	(1, 4115, '4.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4116, '15.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4117, '4.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4118, '15.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4119, '14.2.7.0.0.12.0.0.0.3.72', 1, NULL),
	(1, 4120, '14.2.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4121, '4.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4122, '15.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4123, '4.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4124, '15.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4125, '4.8.7.0.0.37.3.1.0.3.38', 1, NULL),
	(1, 4126, '15.8.7.0.0.37.3.1.0.3.38', 1, NULL),
	(1, 4127, '4.8.7.0.0.37.3.2.0.3.38', 1, NULL),
	(1, 4128, '15.8.7.0.0.37.3.2.0.3.38', 1, NULL),
	(1, 4129, '4.8.7.0.0.37.3.3.0.3.38', 1, NULL),
	(1, 4130, '15.8.7.0.0.37.3.3.0.3.38', 1, NULL),
	(1, 4131, '4.8.7.0.0.37.3.4.0.3.38', 1, NULL),
	(1, 4132, '15.8.7.0.0.37.3.4.0.3.38', 1, NULL),
	(1, 4133, '14.2.7.0.0.12.0.0.0.3.73', 1, NULL),
	(1, 4134, '14.2.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4135, '4.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4136, '15.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4137, '4.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4138, '15.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4139, '4.8.7.0.0.37.3.1.0.3.63', 1, NULL),
	(1, 4140, '15.8.7.0.0.37.3.1.0.3.63', 1, NULL),
	(1, 4141, '4.8.7.0.0.37.3.2.0.3.63', 1, NULL),
	(1, 4142, '15.8.7.0.0.37.3.2.0.3.63', 1, NULL),
	(1, 4143, '4.8.7.0.0.37.3.3.0.3.63', 1, NULL),
	(1, 4144, '15.8.7.0.0.37.3.3.0.3.63', 1, NULL),
	(1, 4145, '4.8.7.0.0.37.3.4.0.3.63', 1, NULL),
	(1, 4146, '15.8.7.0.0.37.3.4.0.3.63', 1, NULL),
	(1, 4147, '14.2.7.0.0.12.0.0.0.3.71', 1, NULL),
	(1, 4148, '14.2.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4149, '4.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4150, '15.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4151, '4.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4152, '15.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4153, '4.8.7.0.0.37.3.1.0.3.61', 1, NULL),
	(1, 4154, '15.8.7.0.0.37.3.1.0.3.61', 1, NULL),
	(1, 4155, '4.8.7.0.0.37.3.2.0.3.61', 1, NULL),
	(1, 4156, '15.8.7.0.0.37.3.2.0.3.61', 1, NULL),
	(1, 4157, '4.8.7.0.0.37.3.3.0.3.61', 1, NULL),
	(1, 4158, '15.8.7.0.0.37.3.3.0.3.61', 1, NULL),
	(1, 4159, '4.8.7.0.0.37.3.4.0.3.61', 1, NULL),
	(1, 4160, '15.8.7.0.0.37.3.4.0.3.61', 1, NULL),
	(1, 4161, '1.2.7.0.0.12.0.0.0.3.72', 1, NULL),
	(1, 4162, '1.2.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4163, '4.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4164, '15.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4165, '4.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4166, '15.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4167, '1.2.7.0.0.12.0.0.0.3.73', 1, NULL),
	(1, 4168, '1.2.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4169, '4.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4170, '15.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4171, '4.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4172, '15.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4173, '1.2.7.0.0.12.0.0.0.3.71', 1, NULL),
	(1, 4174, '1.2.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4175, '4.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4176, '15.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4177, '4.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4178, '15.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4179, '4.2.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4181, '15.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4183, '15.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4184, '4.2.7.0.0.12.0.0.0.3.72', 1, NULL),
	(1, 4185, '4.2.7.0.0.12.3.6.0.3.72', 1, NULL),
	(1, 4187, '15.8.7.0.0.12.3.6.0.3.72', 1, NULL),
	(1, 4189, '15.9.7.0.0.12.3.6.0.3.72', 1, NULL),
	(1, 4190, '4.2.7.0.0.12.3.7.0.3.72', 1, NULL),
	(1, 4192, '15.8.7.0.0.12.3.7.0.3.72', 1, NULL),
	(1, 4194, '15.9.7.0.0.12.3.7.0.3.72', 1, NULL),
	(1, 4195, '4.2.7.0.0.12.3.1.0.3.72', 1, NULL),
	(1, 4197, '15.8.7.0.0.12.3.1.0.3.72', 1, NULL),
	(1, 4199, '15.9.7.0.0.12.3.1.0.3.72', 1, NULL),
	(1, 4200, '4.2.7.0.0.12.3.8.0.3.72', 1, NULL),
	(1, 4202, '15.8.7.0.0.12.3.8.0.3.72', 1, NULL),
	(1, 4204, '15.9.7.0.0.12.3.8.0.3.72', 1, NULL),
	(1, 4205, '4.2.7.0.0.12.3.2.0.3.72', 1, NULL),
	(1, 4207, '15.8.7.0.0.12.3.2.0.3.72', 1, NULL),
	(1, 4209, '15.9.7.0.0.12.3.2.0.3.72', 1, NULL),
	(1, 4210, '4.2.7.0.0.12.3.3.0.3.72', 1, NULL),
	(1, 4212, '15.8.7.0.0.12.3.3.0.3.72', 1, NULL),
	(1, 4214, '15.9.7.0.0.12.3.3.0.3.72', 1, NULL),
	(1, 4215, '4.2.7.0.0.12.3.5.0.3.72', 1, NULL),
	(1, 4217, '15.8.7.0.0.12.3.5.0.3.72', 1, NULL),
	(1, 4219, '15.9.7.0.0.12.3.5.0.3.72', 1, NULL),
	(1, 4220, '4.2.7.0.0.12.3.4.0.3.72', 1, NULL),
	(1, 4222, '15.8.7.0.0.12.3.4.0.3.72', 1, NULL),
	(1, 4224, '15.9.7.0.0.12.3.4.0.3.72', 1, NULL),
	(1, 4225, '4.2.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4227, '15.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4229, '15.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4230, '4.2.7.0.0.12.0.0.0.3.73', 1, NULL),
	(1, 4231, '4.2.7.0.0.12.3.6.0.3.73', 1, NULL),
	(1, 4233, '15.8.7.0.0.12.3.6.0.3.73', 1, NULL),
	(1, 4235, '15.9.7.0.0.12.3.6.0.3.73', 1, NULL),
	(1, 4236, '4.2.7.0.0.12.3.7.0.3.73', 1, NULL),
	(1, 4238, '15.8.7.0.0.12.3.7.0.3.73', 1, NULL),
	(1, 4240, '15.9.7.0.0.12.3.7.0.3.73', 1, NULL),
	(1, 4241, '4.2.7.0.0.12.3.1.0.3.73', 1, NULL),
	(1, 4243, '15.8.7.0.0.12.3.1.0.3.73', 1, NULL),
	(1, 4245, '15.9.7.0.0.12.3.1.0.3.73', 1, NULL),
	(1, 4246, '4.2.7.0.0.12.3.8.0.3.73', 1, NULL),
	(1, 4248, '15.8.7.0.0.12.3.8.0.3.73', 1, NULL),
	(1, 4250, '15.9.7.0.0.12.3.8.0.3.73', 1, NULL),
	(1, 4251, '4.2.7.0.0.12.3.2.0.3.73', 1, NULL),
	(1, 4253, '15.8.7.0.0.12.3.2.0.3.73', 1, NULL),
	(1, 4255, '15.9.7.0.0.12.3.2.0.3.73', 1, NULL),
	(1, 4256, '4.2.7.0.0.12.3.3.0.3.73', 1, NULL),
	(1, 4258, '15.8.7.0.0.12.3.3.0.3.73', 1, NULL),
	(1, 4260, '15.9.7.0.0.12.3.3.0.3.73', 1, NULL),
	(1, 4261, '4.2.7.0.0.12.3.5.0.3.73', 1, NULL),
	(1, 4263, '15.8.7.0.0.12.3.5.0.3.73', 1, NULL),
	(1, 4265, '15.9.7.0.0.12.3.5.0.3.73', 1, NULL),
	(1, 4266, '4.2.7.0.0.12.3.4.0.3.73', 1, NULL),
	(1, 4268, '15.8.7.0.0.12.3.4.0.3.73', 1, NULL),
	(1, 4270, '15.9.7.0.0.12.3.4.0.3.73', 1, NULL),
	(1, 4271, '4.2.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4272, '4.2.7.0.0.12.0.0.0.3.71', 1, NULL),
	(1, 4273, '4.2.7.0.0.12.3.6.0.3.71', 1, NULL),
	(1, 4275, '15.8.7.0.0.12.3.6.0.3.71', 1, NULL),
	(1, 4277, '15.9.7.0.0.12.3.6.0.3.71', 1, NULL),
	(1, 4278, '4.2.7.0.0.12.3.7.0.3.71', 1, NULL),
	(1, 4280, '15.8.7.0.0.12.3.7.0.3.71', 1, NULL),
	(1, 4282, '15.9.7.0.0.12.3.7.0.3.71', 1, NULL),
	(1, 4283, '4.2.7.0.0.12.3.1.0.3.71', 1, NULL),
	(1, 4285, '15.8.7.0.0.12.3.1.0.3.71', 1, NULL),
	(1, 4287, '15.9.7.0.0.12.3.1.0.3.71', 1, NULL),
	(1, 4288, '4.2.7.0.0.12.3.8.0.3.71', 1, NULL),
	(1, 4290, '15.8.7.0.0.12.3.8.0.3.71', 1, NULL),
	(1, 4292, '15.9.7.0.0.12.3.8.0.3.71', 1, NULL),
	(1, 4293, '4.2.7.0.0.12.3.2.0.3.71', 1, NULL),
	(1, 4295, '15.8.7.0.0.12.3.2.0.3.71', 1, NULL),
	(1, 4297, '15.9.7.0.0.12.3.2.0.3.71', 1, NULL),
	(1, 4298, '4.2.7.0.0.12.3.3.0.3.71', 1, NULL),
	(1, 4300, '15.8.7.0.0.12.3.3.0.3.71', 1, NULL),
	(1, 4302, '15.9.7.0.0.12.3.3.0.3.71', 1, NULL),
	(1, 4303, '4.2.7.0.0.12.3.5.0.3.71', 1, NULL),
	(1, 4305, '15.8.7.0.0.12.3.5.0.3.71', 1, NULL),
	(1, 4307, '15.9.7.0.0.12.3.5.0.3.71', 1, NULL),
	(1, 4308, '4.2.7.0.0.12.3.4.0.3.71', 1, NULL),
	(1, 4310, '15.8.7.0.0.12.3.4.0.3.71', 1, NULL),
	(1, 4312, '15.9.7.0.0.12.3.4.0.3.71', 1, NULL),
	(1, 4313, '15.2.7.0.0.12.0.0.0.3.72', 1, NULL),
	(1, 4316, '15.2.7.0.0.12.3.6.0.3.72', 1, NULL),
	(1, 4319, '15.2.7.0.0.12.3.7.0.3.72', 1, NULL),
	(1, 4322, '15.2.7.0.0.12.3.1.0.3.72', 1, NULL),
	(1, 4325, '15.2.7.0.0.12.3.8.0.3.72', 1, NULL),
	(1, 4328, '15.2.7.0.0.12.3.2.0.3.72', 1, NULL),
	(1, 4331, '15.2.7.0.0.12.3.3.0.3.72', 1, NULL),
	(1, 4334, '15.2.7.0.0.12.3.5.0.3.72', 1, NULL),
	(1, 4337, '15.2.7.0.0.12.3.4.0.3.72', 1, NULL),
	(1, 4340, '15.2.7.0.0.12.0.0.0.3.73', 1, NULL),
	(1, 4343, '15.2.7.0.0.12.3.6.0.3.73', 1, NULL),
	(1, 4346, '15.2.7.0.0.12.3.7.0.3.73', 1, NULL),
	(1, 4349, '15.2.7.0.0.12.3.1.0.3.73', 1, NULL),
	(1, 4352, '15.2.7.0.0.12.3.8.0.3.73', 1, NULL),
	(1, 4355, '15.2.7.0.0.12.3.2.0.3.73', 1, NULL),
	(1, 4358, '15.2.7.0.0.12.3.3.0.3.73', 1, NULL),
	(1, 4361, '15.2.7.0.0.12.3.5.0.3.73', 1, NULL),
	(1, 4364, '15.2.7.0.0.12.3.4.0.3.73', 1, NULL),
	(1, 4367, '15.2.7.0.0.12.0.0.0.3.71', 1, NULL),
	(1, 4370, '15.2.7.0.0.12.3.6.0.3.71', 1, NULL),
	(1, 4373, '15.2.7.0.0.12.3.7.0.3.71', 1, NULL),
	(1, 4376, '15.2.7.0.0.12.3.1.0.3.71', 1, NULL),
	(1, 4379, '15.2.7.0.0.12.3.8.0.3.71', 1, NULL),
	(1, 4382, '15.2.7.0.0.12.3.2.0.3.71', 1, NULL),
	(1, 4385, '15.2.7.0.0.12.3.3.0.3.71', 1, NULL),
	(1, 4388, '15.2.7.0.0.12.3.5.0.3.71', 1, NULL),
	(1, 4391, '15.2.7.0.0.12.3.4.0.3.71', 1, NULL),
	(1, 4394, '6.2.7.0.0.12.0.0.0.3.72', 1, NULL),
	(1, 4395, '6.2.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4396, '4.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4397, '15.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4398, '4.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4399, '15.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4400, '6.2.7.0.0.12.0.0.0.3.73', 1, NULL),
	(1, 4401, '6.2.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4402, '4.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4403, '15.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4404, '4.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4405, '15.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4406, '6.2.7.0.0.12.0.0.0.3.71', 1, NULL),
	(1, 4407, '6.2.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4408, '4.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4409, '15.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4410, '4.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4411, '15.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4412, 'x.2.7.0.0.12.0.0.0.3.72', 1, NULL),
	(1, 4413, 'x.2.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4414, '4.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4415, '15.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4416, '4.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4417, '15.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4418, 'x.2.7.0.0.12.0.0.0.3.73', 1, NULL),
	(1, 4419, 'x.2.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4420, '4.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4421, '15.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4422, '4.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4423, '15.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4424, 'x.2.7.0.0.12.0.0.0.3.71', 1, NULL),
	(1, 4425, 'x.2.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4426, '4.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4427, '15.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4428, '4.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4429, '15.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4430, '2.2.7.0.0.12.0.0.0.3.72', 1, 1),
	(1, 4431, '2.2.7.0.0.37.0.0.0.3.38', 1, 1),
	(1, 4432, '4.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4433, '15.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4434, '4.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4435, '15.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4436, '4.8.7.0.0.37.3.1.0.3.38', 1, NULL),
	(1, 4437, '15.8.7.0.0.37.3.1.0.3.38', 1, NULL),
	(1, 4438, '4.8.7.0.0.37.3.2.0.3.38', 1, NULL),
	(1, 4439, '15.8.7.0.0.37.3.2.0.3.38', 1, NULL),
	(1, 4440, '4.8.7.0.0.37.3.3.0.3.38', 1, NULL),
	(1, 4441, '15.8.7.0.0.37.3.3.0.3.38', 1, NULL),
	(1, 4442, '4.8.7.0.0.37.3.4.0.3.38', 1, NULL),
	(1, 4443, '15.8.7.0.0.37.3.4.0.3.38', 1, NULL),
	(1, 4444, '2.2.7.0.0.12.0.0.0.3.73', 1, 1),
	(1, 4445, '2.2.7.0.0.37.0.0.0.3.63', 1, 1),
	(1, 4446, '4.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4447, '15.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4448, '4.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4449, '15.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4450, '4.8.7.0.0.37.3.1.0.3.63', 1, NULL),
	(1, 4451, '15.8.7.0.0.37.3.1.0.3.63', 1, NULL),
	(1, 4452, '4.8.7.0.0.37.3.2.0.3.63', 1, NULL),
	(1, 4453, '15.8.7.0.0.37.3.2.0.3.63', 1, NULL),
	(1, 4454, '4.8.7.0.0.37.3.3.0.3.63', 1, NULL),
	(1, 4455, '15.8.7.0.0.37.3.3.0.3.63', 1, NULL),
	(1, 4456, '4.8.7.0.0.37.3.4.0.3.63', 1, NULL),
	(1, 4457, '15.8.7.0.0.37.3.4.0.3.63', 1, NULL),
	(1, 4458, '2.2.7.0.0.12.0.0.0.3.71', 1, 1),
	(1, 4459, '2.2.7.0.0.37.0.0.0.3.61', 1, 1),
	(1, 4460, '4.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4461, '15.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4462, '4.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4463, '15.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4464, '4.8.7.0.0.37.3.1.0.3.61', 1, NULL),
	(1, 4465, '15.8.7.0.0.37.3.1.0.3.61', 1, NULL),
	(1, 4466, '4.8.7.0.0.37.3.2.0.3.61', 1, NULL),
	(1, 4467, '15.8.7.0.0.37.3.2.0.3.61', 1, NULL),
	(1, 4468, '4.8.7.0.0.37.3.3.0.3.61', 1, NULL),
	(1, 4469, '15.8.7.0.0.37.3.3.0.3.61', 1, NULL),
	(1, 4470, '4.8.7.0.0.37.3.4.0.3.61', 1, NULL),
	(1, 4471, '15.8.7.0.0.37.3.4.0.3.61', 1, NULL),
	(1, 4472, 'x.2.7.0.0.12.0.0.0.3.72', 1, 1),
	(1, 4473, 'x.2.7.0.0.37.0.0.0.3.38', 1, 1),
	(1, 4474, '4.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4475, '15.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4476, '4.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4477, '15.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4478, 'x.2.7.0.0.12.0.0.0.3.73', 1, 1),
	(1, 4479, 'x.2.7.0.0.37.0.0.0.3.63', 1, 1),
	(1, 4480, '4.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4481, '15.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4482, '4.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4483, '15.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4484, 'x.2.7.0.0.12.0.0.0.3.71', 1, 1),
	(1, 4485, 'x.2.7.0.0.37.0.0.0.3.61', 1, 1),
	(1, 4486, '4.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4487, '15.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4488, '4.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4489, '15.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4490, '10.2.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 4491, 'x.2.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 4492, 'x.2.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 4493, '10.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4494, 'x.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4495, 'x.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4496, '10.2.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 4497, 'x.2.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 4498, 'x.2.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 4499, '10.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4500, 'x.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4501, 'x.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4502, '10.2.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 4503, 'x.2.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 4504, 'x.2.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 4505, '10.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4506, 'x.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4507, 'x.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4508, '10.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4509, 'x.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4510, 'x.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4511, '10.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4512, 'x.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4513, 'x.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4514, '10.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4515, 'x.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4516, 'x.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4517, '10.2.7.0.0.37.0.0.128.3.38', 1, NULL),
	(1, 4518, 'x.2.7.0.0.37.0.0.128.3.38', 1, NULL),
	(1, 4519, 'x.2.7.0.0.37.0.0.128.3.38', 1, NULL),
	(1, 4520, '10.2.7.0.0.37.0.0.64.3.38', 1, NULL),
	(1, 4521, 'x.2.7.0.0.37.0.0.64.3.38', 1, NULL),
	(1, 4522, 'x.2.7.0.0.37.0.0.64.3.38', 1, NULL),
	(1, 4523, '10.2.7.0.0.37.0.0.32.3.38', 1, NULL),
	(1, 4524, 'x.2.7.0.0.37.0.0.32.3.38', 1, NULL),
	(1, 4525, 'x.2.7.0.0.37.0.0.32.3.38', 1, NULL),
	(1, 4526, '10.2.7.0.0.37.0.0.128.3.63', 1, NULL),
	(1, 4527, 'x.2.7.0.0.37.0.0.128.3.63', 1, NULL),
	(1, 4528, 'x.2.7.0.0.37.0.0.128.3.63', 1, NULL),
	(1, 4529, '10.2.7.0.0.37.0.0.64.3.63', 1, NULL),
	(1, 4530, 'x.2.7.0.0.37.0.0.64.3.63', 1, NULL),
	(1, 4531, 'x.2.7.0.0.37.0.0.64.3.63', 1, NULL),
	(1, 4532, '10.2.7.0.0.37.0.0.32.3.63', 1, NULL),
	(1, 4533, 'x.2.7.0.0.37.0.0.32.3.63', 1, NULL),
	(1, 4534, 'x.2.7.0.0.37.0.0.32.3.63', 1, NULL),
	(1, 4535, '10.2.7.0.0.37.0.0.128.3.61', 1, NULL),
	(1, 4536, 'x.2.7.0.0.37.0.0.128.3.61', 1, NULL),
	(1, 4537, 'x.2.7.0.0.37.0.0.128.3.61', 1, NULL),
	(1, 4538, '10.2.7.0.0.37.0.0.64.3.61', 1, NULL),
	(1, 4539, 'x.2.7.0.0.37.0.0.64.3.61', 1, NULL),
	(1, 4540, 'x.2.7.0.0.37.0.0.64.3.61', 1, NULL),
	(1, 4541, '10.2.7.0.0.37.0.0.32.3.61', 1, NULL),
	(1, 4542, 'x.2.7.0.0.37.0.0.32.3.61', 1, NULL),
	(1, 4543, 'x.2.7.0.0.37.0.0.32.3.61', 1, NULL),
	(1, 4544, '10.2.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4545, 'x.2.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4546, 'x.2.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4547, '10.2.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4548, 'x.2.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4549, 'x.2.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4550, '10.2.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4551, 'x.2.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4552, 'x.2.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4553, '10.2.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4554, 'x.2.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4555, 'x.2.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4556, '10.2.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4557, 'x.2.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4558, 'x.2.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4559, '10.2.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4560, 'x.2.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4561, 'x.2.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4562, '10.2.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 4563, 'x.2.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 4564, 'x.2.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 4565, '10.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4566, 'x.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4567, 'x.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4568, '10.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4569, 'x.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4570, 'x.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4571, '10.2.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4572, 'x.2.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4573, 'x.2.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4574, '10.2.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4575, 'x.2.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4576, 'x.2.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4577, '10.2.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4578, 'x.2.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4579, 'x.2.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4580, '10.2.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4581, 'x.2.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4582, 'x.2.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4583, '10.2.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4584, 'x.2.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4585, 'x.2.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4586, '10.2.7.0.x.x.0.0.x.0.33', 1, NULL),
	(1, 4587, 'x.2.7.0.x.x.0.0.x.0.33', 1, NULL),
	(1, 4588, 'x.2.7.0.x.x.0.0.x.0.33', 1, NULL),
	(1, 4589, '10.2.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4590, 'x.2.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4591, 'x.2.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4592, '7.8.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 4593, '7.9.7.1.0.37.0.0.0.3.38', 1, NULL),
	(1, 4594, '7.8.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 4595, '7.9.7.19.0.37.0.0.0.3.38', 1, NULL),
	(1, 4596, '7.8.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 4597, '7.9.7.1.0.37.0.0.0.3.63', 1, NULL),
	(1, 4598, '7.8.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 4599, '7.9.7.19.0.37.0.0.0.3.63', 1, NULL),
	(1, 4600, '7.8.7.1.0.37.3.1.0.3.38', 1, NULL),
	(1, 4601, '7.8.7.19.0.37.3.1.0.3.38', 1, NULL),
	(1, 4602, '7.8.7.1.0.37.3.1.0.3.63', 1, NULL),
	(1, 4603, '7.8.7.19.0.37.3.1.0.3.63', 1, NULL),
	(1, 4604, '7.8.7.1.0.37.3.2.0.3.38', 1, NULL),
	(1, 4605, '7.8.7.19.0.37.3.2.0.3.38', 1, NULL),
	(1, 4606, '7.8.7.1.0.37.3.2.0.3.63', 1, NULL),
	(1, 4607, '7.8.7.19.0.37.3.2.0.3.63', 1, NULL),
	(1, 4608, '7.8.7.1.0.37.3.3.0.3.38', 1, NULL),
	(1, 4609, '7.8.7.19.0.37.3.3.0.3.38', 1, NULL),
	(1, 4610, '7.8.7.1.0.37.3.3.0.3.63', 1, NULL),
	(1, 4611, '7.8.7.19.0.37.3.3.0.3.63', 1, NULL),
	(1, 4612, '7.8.7.1.0.37.3.4.0.3.38', 1, NULL),
	(1, 4613, '7.8.7.19.0.37.3.4.0.3.38', 1, NULL),
	(1, 4614, '7.8.7.1.0.37.3.4.0.3.63', 1, NULL),
	(1, 4615, '7.8.7.19.0.37.3.4.0.3.63', 1, NULL),
	(1, 4616, '7.8.7.15.0.37.3.1.0.3.63', 1, NULL),
	(1, 4617, '7.8.7.16.0.37.3.1.0.3.63', 1, NULL),
	(1, 4618, '7.8.7.17.0.37.3.1.0.3.63', 1, NULL),
	(1, 4619, '7.8.7.18.0.37.3.1.0.3.63', 1, NULL),
	(1, 4620, '7.8.7.1.0.37.3.1.0.3.61', 1, NULL),
	(1, 4621, '7.8.7.19.0.37.3.1.0.3.61', 1, NULL),
	(1, 4622, '7.8.7.15.0.37.3.2.0.3.63', 1, NULL),
	(1, 4623, '7.8.7.16.0.37.3.2.0.3.63', 1, NULL),
	(1, 4624, '7.8.7.17.0.37.3.2.0.3.63', 1, NULL),
	(1, 4625, '7.8.7.18.0.37.3.2.0.3.63', 1, NULL),
	(1, 4626, '7.8.7.1.0.37.3.2.0.3.61', 1, NULL),
	(1, 4627, '7.8.7.19.0.37.3.2.0.3.61', 1, NULL),
	(1, 4628, '7.8.7.15.0.37.3.3.0.3.63', 1, NULL),
	(1, 4629, '7.8.7.16.0.37.3.3.0.3.63', 1, NULL),
	(1, 4630, '7.8.7.17.0.37.3.3.0.3.63', 1, NULL),
	(1, 4631, '7.8.7.18.0.37.3.3.0.3.63', 1, NULL),
	(1, 4632, '7.8.7.1.0.37.3.3.0.3.61', 1, NULL),
	(1, 4633, '7.8.7.19.0.37.3.3.0.3.61', 1, NULL),
	(1, 4634, '7.8.7.15.0.37.3.4.0.3.63', 1, NULL),
	(1, 4635, '7.8.7.16.0.37.3.4.0.3.63', 1, NULL),
	(1, 4636, '7.8.7.17.0.37.3.4.0.3.63', 1, NULL),
	(1, 4637, '7.8.7.18.0.37.3.4.0.3.63', 1, NULL),
	(1, 4638, '7.8.7.1.0.37.3.4.0.3.61', 1, NULL),
	(1, 4639, '7.8.7.19.0.37.3.4.0.3.61', 1, NULL),
	(1, 4640, '7.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4641, '7.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4642, '7.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4643, '7.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4644, '7.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4645, '7.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4646, '7.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4647, '7.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4648, '7.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4649, '7.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4650, '7.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4651, '7.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4652, '7.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4653, '7.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4654, '7.8.7.0.0.37.3.1.0.3.38', 1, NULL),
	(1, 4655, '7.8.7.0.0.37.3.2.0.3.38', 1, NULL),
	(1, 4656, '7.8.7.0.0.37.3.3.0.3.38', 1, NULL),
	(1, 4657, '7.8.7.0.0.37.3.4.0.3.38', 1, NULL),
	(1, 4658, '7.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4659, '7.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4660, '7.8.7.0.0.37.3.1.0.3.63', 1, NULL),
	(1, 4661, '7.8.7.0.0.37.3.2.0.3.63', 1, NULL),
	(1, 4662, '7.8.7.0.0.37.3.3.0.3.63', 1, NULL),
	(1, 4663, '7.8.7.0.0.37.3.4.0.3.63', 1, NULL),
	(1, 4664, '7.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4665, '7.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4666, '7.8.7.0.0.37.3.1.0.3.61', 1, NULL),
	(1, 4667, '7.8.7.0.0.37.3.2.0.3.61', 1, NULL),
	(1, 4668, '7.8.7.0.0.37.3.3.0.3.61', 1, NULL),
	(1, 4669, '7.8.7.0.0.37.3.4.0.3.61', 1, NULL),
	(1, 4670, '7.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4671, '7.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4672, '7.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4673, '7.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4674, '7.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4675, '7.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4676, '7.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4677, '7.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4678, '7.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4679, '7.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4680, '7.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4681, '7.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4682, '7.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4683, '7.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4684, '7.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4685, '7.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4686, '7.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4687, '7.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4688, '7.8.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 4689, '7.9.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 4690, '4.8.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 4691, '4.9.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 4692, '15.8.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 4693, '15.9.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 4694, '7.8.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4695, '7.9.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4696, '4.8.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4697, '4.9.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4698, '15.8.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4699, '15.9.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4700, '7.8.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 4701, '7.9.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 4702, '4.8.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 4703, '4.9.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 4704, '15.8.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 4705, '15.9.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 4706, '7.8.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4707, '7.9.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4708, '4.8.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4709, '4.9.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4710, '15.8.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4711, '15.9.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4712, '7.8.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 4713, '7.9.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 4714, '4.8.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 4715, '4.9.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 4716, '15.8.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 4717, '15.9.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 4718, '7.8.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4719, '7.9.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4720, '4.8.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4721, '4.9.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4722, '15.8.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4723, '15.9.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4724, '7.8.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4725, '7.9.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4726, '4.8.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4727, '4.9.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4728, '15.8.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4729, '15.9.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 4730, '7.8.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4731, '7.9.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4732, '4.8.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4733, '4.9.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4734, '15.8.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4735, '15.9.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 4736, '7.8.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4737, '7.9.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4738, '4.8.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4739, '4.9.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4740, '15.8.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4741, '15.9.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 4742, '7.8.7.0.0.37.0.0.128.3.38', 1, NULL),
	(1, 4743, '7.9.7.0.0.37.0.0.128.3.38', 1, NULL),
	(1, 4744, '4.8.7.0.0.37.0.0.128.3.38', 1, NULL),
	(1, 4745, '4.9.7.0.0.37.0.0.128.3.38', 1, NULL),
	(1, 4746, '15.8.7.0.0.37.0.0.128.3.38', 1, NULL),
	(1, 4747, '15.9.7.0.0.37.0.0.128.3.38', 1, NULL),
	(1, 4748, '7.8.7.0.0.37.0.0.64.3.38', 1, NULL),
	(1, 4749, '7.9.7.0.0.37.0.0.64.3.38', 1, NULL),
	(1, 4750, '4.8.7.0.0.37.0.0.64.3.38', 1, NULL),
	(1, 4751, '4.9.7.0.0.37.0.0.64.3.38', 1, NULL),
	(1, 4752, '15.8.7.0.0.37.0.0.64.3.38', 1, NULL),
	(1, 4753, '15.9.7.0.0.37.0.0.64.3.38', 1, NULL),
	(1, 4754, '7.8.7.0.0.37.0.0.32.3.38', 1, NULL),
	(1, 4755, '7.9.7.0.0.37.0.0.32.3.38', 1, NULL),
	(1, 4756, '4.8.7.0.0.37.0.0.32.3.38', 1, NULL),
	(1, 4757, '4.9.7.0.0.37.0.0.32.3.38', 1, NULL),
	(1, 4758, '15.8.7.0.0.37.0.0.32.3.38', 1, NULL),
	(1, 4759, '15.9.7.0.0.37.0.0.32.3.38', 1, NULL),
	(1, 4760, '7.8.7.0.0.37.0.0.128.3.63', 1, NULL),
	(1, 4761, '7.9.7.0.0.37.0.0.128.3.63', 1, NULL),
	(1, 4762, '4.8.7.0.0.37.0.0.128.3.63', 1, NULL),
	(1, 4763, '4.9.7.0.0.37.0.0.128.3.63', 1, NULL),
	(1, 4764, '15.8.7.0.0.37.0.0.128.3.63', 1, NULL),
	(1, 4765, '15.9.7.0.0.37.0.0.128.3.63', 1, NULL),
	(1, 4766, '7.8.7.0.0.37.0.0.64.3.63', 1, NULL),
	(1, 4767, '7.9.7.0.0.37.0.0.64.3.63', 1, NULL),
	(1, 4768, '4.8.7.0.0.37.0.0.64.3.63', 1, NULL),
	(1, 4769, '4.9.7.0.0.37.0.0.64.3.63', 1, NULL),
	(1, 4770, '15.8.7.0.0.37.0.0.64.3.63', 1, NULL),
	(1, 4771, '15.9.7.0.0.37.0.0.64.3.63', 1, NULL),
	(1, 4772, '7.8.7.0.0.37.0.0.32.3.63', 1, NULL),
	(1, 4773, '7.9.7.0.0.37.0.0.32.3.63', 1, NULL),
	(1, 4774, '4.8.7.0.0.37.0.0.32.3.63', 1, NULL),
	(1, 4775, '4.9.7.0.0.37.0.0.32.3.63', 1, NULL),
	(1, 4776, '15.8.7.0.0.37.0.0.32.3.63', 1, NULL),
	(1, 4777, '15.9.7.0.0.37.0.0.32.3.63', 1, NULL),
	(1, 4778, '7.8.7.0.0.37.0.0.128.3.61', 1, NULL),
	(1, 4779, '7.9.7.0.0.37.0.0.128.3.61', 1, NULL),
	(1, 4780, '4.8.7.0.0.37.0.0.128.3.61', 1, NULL),
	(1, 4781, '4.9.7.0.0.37.0.0.128.3.61', 1, NULL),
	(1, 4782, '15.8.7.0.0.37.0.0.128.3.61', 1, NULL),
	(1, 4783, '15.9.7.0.0.37.0.0.128.3.61', 1, NULL),
	(1, 4784, '7.8.7.0.0.37.0.0.64.3.61', 1, NULL),
	(1, 4785, '7.9.7.0.0.37.0.0.64.3.61', 1, NULL),
	(1, 4786, '4.8.7.0.0.37.0.0.64.3.61', 1, NULL),
	(1, 4787, '4.9.7.0.0.37.0.0.64.3.61', 1, NULL),
	(1, 4788, '15.8.7.0.0.37.0.0.64.3.61', 1, NULL),
	(1, 4789, '15.9.7.0.0.37.0.0.64.3.61', 1, NULL),
	(1, 4790, '7.8.7.0.0.37.0.0.32.3.61', 1, NULL),
	(1, 4791, '7.9.7.0.0.37.0.0.32.3.61', 1, NULL),
	(1, 4792, '4.8.7.0.0.37.0.0.32.3.61', 1, NULL),
	(1, 4793, '4.9.7.0.0.37.0.0.32.3.61', 1, NULL),
	(1, 4794, '15.8.7.0.0.37.0.0.32.3.61', 1, NULL),
	(1, 4795, '15.9.7.0.0.37.0.0.32.3.61', 1, NULL),
	(1, 4796, '7.8.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4797, '7.9.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4798, '4.8.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4799, '4.9.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4800, '15.8.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4801, '15.9.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4802, '7.8.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4803, '7.9.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4804, '4.8.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4805, '4.9.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4806, '15.8.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4807, '15.9.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4808, '7.8.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4809, '7.9.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4810, '4.8.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4811, '4.9.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4812, '15.8.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4813, '15.9.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4814, '7.8.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4815, '7.9.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4816, '4.8.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4817, '4.9.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4818, '15.8.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4819, '15.9.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4820, '7.8.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4821, '7.9.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4822, '4.8.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4823, '4.9.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4824, '15.8.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4825, '15.9.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4826, '7.8.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4827, '7.9.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4828, '4.8.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4829, '4.9.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4830, '15.8.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4831, '15.9.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4832, '7.8.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 4833, '7.9.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 4834, '4.8.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 4835, '4.9.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 4836, '15.8.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 4837, '15.9.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 4838, '7.8.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4839, '7.9.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4840, '4.8.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4841, '4.9.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4842, '15.8.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4843, '15.9.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4844, '7.8.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4845, '7.9.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4846, '4.8.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4847, '4.9.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4848, '15.8.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4849, '15.9.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 4850, '7.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4851, '7.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4852, '4.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4853, '4.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4854, '15.8.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4855, '15.9.7.0.0.37.0.0.0.3.38', 1, NULL),
	(1, 4856, '7.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4857, '7.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4858, '4.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4859, '4.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4860, '15.8.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4861, '15.9.7.0.0.37.0.0.0.3.63', 1, NULL),
	(1, 4862, '7.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4863, '7.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4864, '4.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4865, '4.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4866, '15.8.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4867, '15.9.7.0.0.37.0.0.0.3.61', 1, NULL),
	(1, 4868, '7.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4869, '7.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4870, '4.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4871, '4.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4872, '15.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4873, '15.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4874, '7.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4875, '7.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4876, '4.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4877, '4.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4878, '15.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4879, '15.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4880, '7.8.7.0.x.x.0.0.x.0.33', 1, NULL),
	(1, 4881, '7.9.7.0.x.x.0.0.x.0.33', 1, NULL),
	(1, 4882, '4.8.7.0.x.x.0.0.x.0.33', 1, NULL),
	(1, 4883, '4.9.7.0.x.x.0.0.x.0.33', 1, NULL),
	(1, 4884, '15.8.7.0.x.x.0.0.x.0.33', 1, NULL),
	(1, 4885, '15.9.7.0.x.x.0.0.x.0.33', 1, NULL),
	(1, 4886, '7.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4887, '7.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4888, '4.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4889, '4.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4890, '15.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4891, '15.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4892, '0.2.6.0.x.x.0.0.128.0.0', 1, 3),
	(1, 4893, '0.2.6.0.x.x.0.0.64.0.0', 1, 3),
	(1, 4894, '0.2.6.0.x.x.0.0.32.0.0', 1, 3),
	(1, 4895, '0.2.6.0.x.x.0.0.128.0.0', 1, 3),
	(1, 4896, '0.2.6.0.x.x.0.0.64.0.0', 1, 3),
	(1, 4897, '0.2.6.0.x.x.0.0.32.0.0', 1, 3),
	(1, 4898, '0.2.6.0.x.x.0.0.x.0.0', 1, 3),
	(1, 4899, '0.2.6.0.x.x.0.0.x.0.0', 1, 3),
	(1, 4904, '0.2.6.0.0.38.0.0.x.0.0', 1, 3),
	(1, 4905, '7.8.7.0.0.38.0.0.x.0.0', 1, NULL),
	(1, 4906, '7.9.7.0.0.38.0.0.x.0.0', 1, NULL),
	(1, 4907, '4.8.7.0.0.38.0.0.x.0.0', 1, NULL),
	(1, 4908, '4.9.7.0.0.38.0.0.x.0.0', 1, NULL),
	(1, 4909, '15.8.7.0.0.38.0.0.x.0.0', 1, NULL),
	(1, 4910, '15.9.7.0.0.38.0.0.x.0.0', 1, NULL),
	(1, 4911, '7.8.7.0.0.38.0.0.128.0.0', 1, NULL),
	(1, 4912, '7.9.7.0.0.38.0.0.128.0.0', 1, NULL),
	(1, 4913, '4.8.7.0.0.38.0.0.128.0.0', 1, NULL),
	(1, 4914, '4.9.7.0.0.38.0.0.128.0.0', 1, NULL),
	(1, 4915, '15.8.7.0.0.38.0.0.128.0.0', 1, NULL),
	(1, 4916, '15.9.7.0.0.38.0.0.128.0.0', 1, NULL),
	(1, 4917, '7.8.7.0.0.38.0.0.64.0.0', 1, NULL),
	(1, 4918, '7.9.7.0.0.38.0.0.64.0.0', 1, NULL),
	(1, 4919, '4.8.7.0.0.38.0.0.64.0.0', 1, NULL),
	(1, 4920, '4.9.7.0.0.38.0.0.64.0.0', 1, NULL),
	(1, 4921, '15.8.7.0.0.38.0.0.64.0.0', 1, NULL),
	(1, 4922, '15.9.7.0.0.38.0.0.64.0.0', 1, NULL),
	(1, 4923, '7.8.7.0.0.38.0.0.32.0.0', 1, NULL),
	(1, 4924, '7.9.7.0.0.38.0.0.32.0.0', 1, NULL),
	(1, 4925, '4.8.7.0.0.38.0.0.32.0.0', 1, NULL),
	(1, 4926, '4.9.7.0.0.38.0.0.32.0.0', 1, NULL),
	(1, 4927, '15.8.7.0.0.38.0.0.32.0.0', 1, NULL),
	(1, 4928, '15.9.7.0.0.38.0.0.32.0.0', 1, NULL),
	(1, 4929, '0.6.2.1.0.12.0.0.128.3.72', 1, 3),
	(1, 4930, '0.6.2.1.0.12.0.0.64.3.72', 1, 3),
	(1, 4931, '0.6.2.1.0.12.0.0.32.3.72', 1, 3),
	(1, 4932, '0.6.2.19.0.12.0.0.128.3.72', 1, 3),
	(1, 4933, '0.6.2.19.0.12.0.0.64.3.72', 1, 3),
	(1, 4934, '0.6.2.19.0.12.0.0.32.3.72', 1, 3),
	(1, 4935, '0.6.2.1.0.12.0.0.128.3.73', 1, 3),
	(1, 4936, '0.6.2.1.0.12.0.0.64.3.73', 1, 3),
	(1, 4937, '0.6.2.1.0.12.0.0.32.3.73', 1, 3),
	(1, 4938, '0.6.2.19.0.12.0.0.128.3.73', 1, 3),
	(1, 4939, '0.6.2.19.0.12.0.0.64.3.73', 1, 3),
	(1, 4940, '0.6.2.19.0.12.0.0.32.3.73', 1, 3),
	(1, 4941, '0.6.2.0.0.12.0.0.128.3.71', 1, 3),
	(1, 4942, '0.6.2.0.0.12.0.0.64.3.71', 1, 3),
	(1, 4943, '0.6.2.0.0.12.0.0.32.3.71', 1, 3),
	(1, 4947, '0.2.6.0.x.x.0.0.x.0.0', 1, 3),
	(1, 4948, '7.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4949, '7.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4950, '4.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4951, '4.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4952, '15.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4953, '15.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4954, '0.2.6.0.x.x.0.0.128.0.0', 1, 3),
	(1, 4955, '7.8.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4956, '7.9.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4957, '4.8.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4958, '4.9.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4959, '15.8.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4960, '15.9.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4961, '0.2.6.0.x.x.0.0.64.0.0', 1, 3),
	(1, 4962, '7.8.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4963, '7.9.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4964, '4.8.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4965, '4.9.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4966, '15.8.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4967, '15.9.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 4968, '0.2.6.0.x.x.0.0.32.0.0', 1, 3),
	(1, 4969, '7.8.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4970, '7.9.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4971, '4.8.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4972, '4.9.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4973, '15.8.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4974, '15.9.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 4975, '7.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4976, '7.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4977, '4.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4978, '4.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4979, '15.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4980, '15.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4981, '7.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4982, '7.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4983, '4.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4984, '4.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4985, '15.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4986, '15.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4987, '7.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4988, '7.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4989, '4.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4990, '4.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4991, '15.8.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4992, '15.9.7.0.x.x.0.0.x.0.0', 1, NULL),
	(1, 4993, '7.8.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4994, '7.9.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4995, '4.8.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4996, '4.9.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4997, '15.8.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4998, '15.9.7.0.x.x.0.0.128.0.0', 1, NULL),
	(1, 4999, '7.8.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 5000, '7.9.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 5001, '4.8.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 5002, '4.9.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 5003, '15.8.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 5004, '15.9.7.0.x.x.0.0.64.0.0', 1, NULL),
	(1, 5005, '7.8.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 5006, '7.9.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 5007, '4.8.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 5008, '4.9.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 5009, '15.8.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 5010, '15.9.7.0.x.x.0.0.32.0.0', 1, NULL),
	(1, 5011, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5012, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5013, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5014, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5015, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5016, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5017, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5018, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5019, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5020, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5021, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5022, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5023, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5024, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5025, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5026, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5027, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5028, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5029, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5030, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5031, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5032, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5033, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5034, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5035, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5036, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5037, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5038, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5039, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5040, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5041, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5042, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5043, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5044, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5045, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5046, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5047, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5048, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5049, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5050, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5051, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5052, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5053, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5054, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5055, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5056, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5057, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5058, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5059, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5060, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5061, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5062, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5063, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5064, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5065, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5066, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5067, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5068, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5069, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5070, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5071, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5072, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5073, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5074, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5075, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5076, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5077, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5078, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5079, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5080, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5081, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5082, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5083, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5084, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5085, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5086, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5087, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5088, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5089, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5090, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5091, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5092, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5093, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5094, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5095, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5096, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5097, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5098, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5099, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5100, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5101, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5102, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5103, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5104, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5105, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5106, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5107, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5108, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5109, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5110, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5111, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5112, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5113, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5114, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5115, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5116, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5117, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5118, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5119, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5120, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5121, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5122, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5123, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5124, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5125, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5126, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5127, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5128, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5129, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5130, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5131, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5132, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5133, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5134, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5135, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5136, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5137, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5138, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5139, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5140, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5141, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5142, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5143, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5144, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5145, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5146, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5147, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5148, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5149, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5150, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5151, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5152, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5153, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5154, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5155, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5156, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5157, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5158, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5159, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5160, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5161, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5162, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5163, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5164, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5165, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5166, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5167, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5168, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5169, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5170, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5171, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5172, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5173, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5174, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5175, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5176, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5177, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5178, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5179, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5180, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5181, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5182, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5183, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5184, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5185, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5186, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5187, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5188, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5189, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5190, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5191, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5192, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5193, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5194, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5195, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5196, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5197, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5198, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5199, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5200, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5201, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5202, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5203, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5204, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5205, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5206, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5207, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5208, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5209, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5210, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5211, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5212, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5213, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5214, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5215, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5216, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5217, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5218, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5219, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5220, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5221, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5222, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5223, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5224, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5225, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5226, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5227, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5228, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5229, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5230, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5231, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5232, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5233, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5234, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5235, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5236, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5237, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5238, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5239, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5240, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5241, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5242, '0.2.6.0.x.x.0.0.128.2.0', 1, 3),
	(1, 5243, '0.2.6.0.x.x.0.0.64.2.0', 1, 3),
	(1, 5244, '0.2.6.0.x.x.0.0.32.2.0', 1, 3),
	(1, 5294, '0.6.2.11.0.12.0.0.0.3.73', 1, 3),
	(1, 5295, '4.6.3.11.0.12.0.0.0.3.73', 1, 3),
	(1, 5296, '15.6.3.11.0.12.0.0.0.3.73', 1, 3),
	(1, 5297, '5.6.3.11.0.12.0.0.0.3.73', 1, 3),
	(1, 5298, 'x.6.3.11.0.12.0.0.0.3.73', 1, 3),
	(1, 5299, '7.6.3.11.0.12.0.0.0.3.73', 1, 3),
	(1, 5300, '2.6.3.11.0.12.0.0.0.3.73', 1, 3),
	(1, 5301, '0.6.2.7.0.12.0.0.0.3.73', 1, 3),
	(1, 5302, '4.6.3.7.0.12.0.0.0.3.73', 1, 3),
	(1, 5303, '15.6.3.7.0.12.0.0.0.3.73', 1, 3),
	(1, 5304, '5.6.3.7.0.12.0.0.0.3.73', 1, 3),
	(1, 5305, 'x.6.3.7.0.12.0.0.0.3.73', 1, 3),
	(1, 5306, '7.6.3.7.0.12.0.0.0.3.73', 1, 3),
	(1, 5307, '2.6.3.7.0.12.0.0.0.3.73', 1, 3),
	(1, 5308, '7.8.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5309, '4.8.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5310, '15.8.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5311, '7.9.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5312, '4.9.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5313, '15.9.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5314, '7.8.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5315, '4.8.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5316, '15.8.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5317, '7.9.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5318, '4.9.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5319, '15.9.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5320, '7.8.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5321, '4.8.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5322, '15.8.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5323, '7.9.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5324, '4.9.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5325, '15.9.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5326, '5.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5327, '7.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5328, '3.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5329, '10.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5330, '14.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5331, '1.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5332, '4.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5333, '6.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5334, 'x.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5335, '2.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5336, 'x.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5337, '5.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5338, '7.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5339, '3.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5340, '10.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5341, '14.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5342, '1.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5343, '4.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5344, '6.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5345, 'x.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5346, '2.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5347, 'x.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5348, '5.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5349, '7.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5350, '3.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5351, '10.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5352, '14.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5353, '1.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5354, '4.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5355, '6.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5356, 'x.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5357, '2.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5358, 'x.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5359, '5.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5360, '7.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5361, '3.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5362, '10.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5363, '14.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5364, '1.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5365, '4.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5366, '6.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5367, 'x.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5368, '2.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5369, 'x.2.7.0.0.54.0.0.128.0.29', 1, NULL),
	(1, 5370, '5.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5371, '7.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5372, '3.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5373, '10.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5374, '14.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5375, '1.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5376, '4.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5377, '6.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5378, 'x.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5379, '2.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5380, 'x.2.7.0.0.54.0.0.64.0.29', 1, NULL),
	(1, 5381, '5.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5382, '7.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5383, '3.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5384, '10.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5385, '14.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5386, '1.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5387, '4.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5388, '6.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5389, 'x.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5390, '2.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5391, 'x.2.7.0.0.54.0.0.32.0.29', 1, NULL),
	(1, 5392, '5.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5393, '7.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5394, '3.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5395, '10.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5396, '14.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5397, '1.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5398, '4.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5399, '6.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5400, 'x.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5401, '2.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5402, 'x.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5403, '5.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5404, '7.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5405, '3.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5406, '10.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5407, '14.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5408, '1.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5409, '4.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5410, '6.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5411, 'x.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5412, '2.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5413, 'x.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5414, '5.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5415, '7.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5416, '3.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5417, '10.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5418, '14.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5419, '1.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5420, '4.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5421, '6.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5422, 'x.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5423, '2.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5424, 'x.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5425, '5.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5426, '7.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5427, '3.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5428, '10.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5429, '14.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5430, '1.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5431, '4.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5432, '6.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5433, 'x.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5434, '2.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5435, 'x.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5436, '5.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5437, '7.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5438, '3.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5439, '10.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5440, '14.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5441, '1.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5442, '4.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5443, '6.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5444, 'x.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5445, '2.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5446, 'x.2.7.0.0.54.0.0.x.0.29', 1, NULL),
	(1, 5491, '10.2.7.0.0.15.0.0.128.0.33', 1, NULL),
	(1, 5492, '0.2.6.0.0.15.0.0.128.0.33', 1, 3),
	(1, 5493, 'x.2.7.0.0.15.0.0.128.0.33', 1, NULL),
	(1, 5494, 'x.2.7.0.0.15.0.0.128.0.33', 1, NULL),
	(1, 5495, '10.2.7.0.0.15.0.0.64.0.33', 1, NULL),
	(1, 5496, '0.2.6.0.0.15.0.0.64.0.33', 1, 3),
	(1, 5497, 'x.2.7.0.0.15.0.0.64.0.33', 1, NULL),
	(1, 5498, 'x.2.7.0.0.15.0.0.64.0.33', 1, NULL),
	(1, 5499, '10.2.7.0.0.15.0.0.32.0.33', 1, NULL),
	(1, 5500, '0.2.6.0.0.15.0.0.32.0.33', 1, 3),
	(1, 5501, 'x.2.7.0.0.15.0.0.32.0.33', 1, NULL),
	(1, 5502, 'x.2.7.0.0.15.0.0.32.0.33', 1, NULL),
	(1, 5503, '3.2.7.1.0.37.0.0.128.3.38', 1, NULL),
	(1, 5504, '10.2.7.1.0.37.0.0.128.3.38', 1, NULL),
	(1, 5505, '5.2.7.1.0.37.0.0.128.3.38', 1, NULL),
	(1, 5506, '7.2.7.1.0.37.0.0.128.3.38', 1, NULL),
	(1, 5507, '4.2.7.1.0.37.0.0.128.3.38', 1, NULL),
	(1, 5508, '14.2.7.1.0.37.0.0.128.3.38', 1, NULL),
	(1, 5509, 'x.2.7.1.0.37.0.0.128.3.38', 1, NULL),
	(1, 5510, '6.2.7.1.0.37.0.0.128.3.38', 1, NULL),
	(1, 5511, '1.2.7.1.0.37.0.0.128.3.38', 1, NULL),
	(1, 5512, '2.2.7.1.0.37.0.0.128.3.38', 1, NULL),
	(1, 5513, 'x.2.7.1.0.37.0.0.128.3.38', 1, NULL),
	(1, 5514, '3.2.7.19.0.37.0.0.128.3.38', 1, NULL),
	(1, 5515, '10.2.7.19.0.37.0.0.128.3.38', 1, NULL),
	(1, 5516, '5.2.7.19.0.37.0.0.128.3.38', 1, NULL),
	(1, 5517, '7.2.7.19.0.37.0.0.128.3.38', 1, NULL),
	(1, 5518, '4.2.7.19.0.37.0.0.128.3.38', 1, NULL),
	(1, 5519, '14.2.7.19.0.37.0.0.128.3.38', 1, NULL),
	(1, 5520, 'x.2.7.19.0.37.0.0.128.3.38', 1, NULL),
	(1, 5521, '6.2.7.19.0.37.0.0.128.3.38', 1, NULL),
	(1, 5522, '1.2.7.19.0.37.0.0.128.3.38', 1, NULL),
	(1, 5523, '2.2.7.19.0.37.0.0.128.3.38', 1, NULL),
	(1, 5524, 'x.2.7.19.0.37.0.0.128.3.38', 1, NULL),
	(1, 5525, '3.2.7.1.0.37.0.0.128.3.63', 1, NULL),
	(1, 5526, '10.2.7.1.0.37.0.0.128.3.63', 1, NULL),
	(1, 5527, '5.2.7.1.0.37.0.0.128.3.63', 1, NULL),
	(1, 5528, '7.2.7.1.0.37.0.0.128.3.63', 1, NULL),
	(1, 5529, '4.2.7.1.0.37.0.0.128.3.63', 1, NULL),
	(1, 5530, '14.2.7.1.0.37.0.0.128.3.63', 1, NULL),
	(1, 5531, 'x.2.7.1.0.37.0.0.128.3.63', 1, NULL),
	(1, 5532, '6.2.7.1.0.37.0.0.128.3.63', 1, NULL),
	(1, 5533, '1.2.7.1.0.37.0.0.128.3.63', 1, NULL),
	(1, 5534, '2.2.7.1.0.37.0.0.128.3.63', 1, NULL),
	(1, 5535, 'x.2.7.1.0.37.0.0.128.3.63', 1, NULL),
	(1, 5536, '3.2.7.19.0.37.0.0.128.3.63', 1, NULL),
	(1, 5537, '10.2.7.19.0.37.0.0.128.3.63', 1, NULL),
	(1, 5538, '5.2.7.19.0.37.0.0.128.3.63', 1, NULL),
	(1, 5539, '7.2.7.19.0.37.0.0.128.3.63', 1, NULL),
	(1, 5540, '4.2.7.19.0.37.0.0.128.3.63', 1, NULL),
	(1, 5541, '14.2.7.19.0.37.0.0.128.3.63', 1, NULL),
	(1, 5542, 'x.2.7.19.0.37.0.0.128.3.63', 1, NULL),
	(1, 5543, '6.2.7.19.0.37.0.0.128.3.63', 1, NULL),
	(1, 5544, '1.2.7.19.0.37.0.0.128.3.63', 1, NULL),
	(1, 5545, '2.2.7.19.0.37.0.0.128.3.63', 1, NULL),
	(1, 5546, 'x.2.7.19.0.37.0.0.128.3.63', 1, NULL),
	(1, 5547, '3.2.7.1.0.37.0.0.64.3.38', 1, NULL),
	(1, 5548, '10.2.7.1.0.37.0.0.64.3.38', 1, NULL),
	(1, 5549, '5.2.7.1.0.37.0.0.64.3.38', 1, NULL),
	(1, 5550, '7.2.7.1.0.37.0.0.64.3.38', 1, NULL),
	(1, 5551, '4.2.7.1.0.37.0.0.64.3.38', 1, NULL),
	(1, 5552, '14.2.7.1.0.37.0.0.64.3.38', 1, NULL),
	(1, 5553, 'x.2.7.1.0.37.0.0.64.3.38', 1, NULL),
	(1, 5554, '6.2.7.1.0.37.0.0.64.3.38', 1, NULL),
	(1, 5555, '1.2.7.1.0.37.0.0.64.3.38', 1, NULL),
	(1, 5556, '2.2.7.1.0.37.0.0.64.3.38', 1, NULL),
	(1, 5557, 'x.2.7.1.0.37.0.0.64.3.38', 1, NULL),
	(1, 5558, '3.2.7.19.0.37.0.0.64.3.38', 1, NULL),
	(1, 5559, '10.2.7.19.0.37.0.0.64.3.38', 1, NULL),
	(1, 5560, '5.2.7.19.0.37.0.0.64.3.38', 1, NULL),
	(1, 5561, '7.2.7.19.0.37.0.0.64.3.38', 1, NULL),
	(1, 5562, '4.2.7.19.0.37.0.0.64.3.38', 1, NULL),
	(1, 5563, '14.2.7.19.0.37.0.0.64.3.38', 1, NULL),
	(1, 5564, 'x.2.7.19.0.37.0.0.64.3.38', 1, NULL),
	(1, 5565, '6.2.7.19.0.37.0.0.64.3.38', 1, NULL),
	(1, 5566, '1.2.7.19.0.37.0.0.64.3.38', 1, NULL),
	(1, 5567, '2.2.7.19.0.37.0.0.64.3.38', 1, NULL),
	(1, 5568, 'x.2.7.19.0.37.0.0.64.3.38', 1, NULL),
	(1, 5569, '3.2.7.1.0.37.0.0.64.3.63', 1, NULL),
	(1, 5570, '10.2.7.1.0.37.0.0.64.3.63', 1, NULL),
	(1, 5571, '5.2.7.1.0.37.0.0.64.3.63', 1, NULL),
	(1, 5572, '7.2.7.1.0.37.0.0.64.3.63', 1, NULL),
	(1, 5573, '4.2.7.1.0.37.0.0.64.3.63', 1, NULL),
	(1, 5574, '14.2.7.1.0.37.0.0.64.3.63', 1, NULL),
	(1, 5575, 'x.2.7.1.0.37.0.0.64.3.63', 1, NULL),
	(1, 5576, '6.2.7.1.0.37.0.0.64.3.63', 1, NULL),
	(1, 5577, '1.2.7.1.0.37.0.0.64.3.63', 1, NULL),
	(1, 5578, '2.2.7.1.0.37.0.0.64.3.63', 1, NULL),
	(1, 5579, 'x.2.7.1.0.37.0.0.64.3.63', 1, NULL),
	(1, 5580, '3.2.7.19.0.37.0.0.64.3.63', 1, NULL),
	(1, 5581, '10.2.7.19.0.37.0.0.64.3.63', 1, NULL),
	(1, 5582, '5.2.7.19.0.37.0.0.64.3.63', 1, NULL),
	(1, 5583, '7.2.7.19.0.37.0.0.64.3.63', 1, NULL),
	(1, 5584, '4.2.7.19.0.37.0.0.64.3.63', 1, NULL),
	(1, 5585, '14.2.7.19.0.37.0.0.64.3.63', 1, NULL),
	(1, 5586, 'x.2.7.19.0.37.0.0.64.3.63', 1, NULL),
	(1, 5587, '6.2.7.19.0.37.0.0.64.3.63', 1, NULL),
	(1, 5588, '1.2.7.19.0.37.0.0.64.3.63', 1, NULL),
	(1, 5589, '2.2.7.19.0.37.0.0.64.3.63', 1, NULL),
	(1, 5590, 'x.2.7.19.0.37.0.0.64.3.63', 1, NULL),
	(1, 5591, '3.2.7.1.0.37.0.0.32.3.38', 1, NULL),
	(1, 5592, '10.2.7.1.0.37.0.0.32.3.38', 1, NULL),
	(1, 5593, '5.2.7.1.0.37.0.0.32.3.38', 1, NULL),
	(1, 5594, '7.2.7.1.0.37.0.0.32.3.38', 1, NULL),
	(1, 5595, '4.2.7.1.0.37.0.0.32.3.38', 1, NULL),
	(1, 5596, '14.2.7.1.0.37.0.0.32.3.38', 1, NULL),
	(1, 5597, 'x.2.7.1.0.37.0.0.32.3.38', 1, NULL),
	(1, 5598, '6.2.7.1.0.37.0.0.32.3.38', 1, NULL),
	(1, 5599, '1.2.7.1.0.37.0.0.32.3.38', 1, NULL),
	(1, 5600, '2.2.7.1.0.37.0.0.32.3.38', 1, NULL),
	(1, 5601, 'x.2.7.1.0.37.0.0.32.3.38', 1, NULL),
	(1, 5602, '3.2.7.19.0.37.0.0.32.3.38', 1, NULL),
	(1, 5603, '10.2.7.19.0.37.0.0.32.3.38', 1, NULL),
	(1, 5604, '5.2.7.19.0.37.0.0.32.3.38', 1, NULL),
	(1, 5605, '7.2.7.19.0.37.0.0.32.3.38', 1, NULL),
	(1, 5606, '4.2.7.19.0.37.0.0.32.3.38', 1, NULL),
	(1, 5607, '14.2.7.19.0.37.0.0.32.3.38', 1, NULL),
	(1, 5608, 'x.2.7.19.0.37.0.0.32.3.38', 1, NULL),
	(1, 5609, '6.2.7.19.0.37.0.0.32.3.38', 1, NULL),
	(1, 5610, '1.2.7.19.0.37.0.0.32.3.38', 1, NULL),
	(1, 5611, '2.2.7.19.0.37.0.0.32.3.38', 1, NULL),
	(1, 5612, 'x.2.7.19.0.37.0.0.32.3.38', 1, NULL),
	(1, 5613, '3.2.7.1.0.37.0.0.32.3.63', 1, NULL),
	(1, 5614, '10.2.7.1.0.37.0.0.32.3.63', 1, NULL),
	(1, 5615, '5.2.7.1.0.37.0.0.32.3.63', 1, NULL),
	(1, 5616, '7.2.7.1.0.37.0.0.32.3.63', 1, NULL),
	(1, 5617, '4.2.7.1.0.37.0.0.32.3.63', 1, NULL),
	(1, 5618, '14.2.7.1.0.37.0.0.32.3.63', 1, NULL),
	(1, 5619, 'x.2.7.1.0.37.0.0.32.3.63', 1, NULL),
	(1, 5620, '6.2.7.1.0.37.0.0.32.3.63', 1, NULL),
	(1, 5621, '1.2.7.1.0.37.0.0.32.3.63', 1, NULL),
	(1, 5622, '2.2.7.1.0.37.0.0.32.3.63', 1, NULL),
	(1, 5623, 'x.2.7.1.0.37.0.0.32.3.63', 1, NULL),
	(1, 5624, '3.2.7.19.0.37.0.0.32.3.63', 1, NULL),
	(1, 5625, '10.2.7.19.0.37.0.0.32.3.63', 1, NULL),
	(1, 5626, '5.2.7.19.0.37.0.0.32.3.63', 1, NULL),
	(1, 5627, '7.2.7.19.0.37.0.0.32.3.63', 1, NULL),
	(1, 5628, '4.2.7.19.0.37.0.0.32.3.63', 1, NULL),
	(1, 5629, '14.2.7.19.0.37.0.0.32.3.63', 1, NULL),
	(1, 5630, 'x.2.7.19.0.37.0.0.32.3.63', 1, NULL),
	(1, 5631, '6.2.7.19.0.37.0.0.32.3.63', 1, NULL),
	(1, 5632, '1.2.7.19.0.37.0.0.32.3.63', 1, NULL),
	(1, 5633, '2.2.7.19.0.37.0.0.32.3.63', 1, NULL),
	(1, 5634, 'x.2.7.19.0.37.0.0.32.3.63', 1, NULL),
	(1, 5635, '3.2.7.15.0.37.0.0.128.3.63', 1, NULL),
	(1, 5636, '10.2.7.15.0.37.0.0.128.3.63', 1, NULL),
	(1, 5637, '5.2.7.15.0.37.0.0.128.3.63', 1, NULL),
	(1, 5638, '7.2.7.15.0.37.0.0.128.3.63', 1, NULL),
	(1, 5639, '4.2.7.15.0.37.0.0.128.3.63', 1, NULL),
	(1, 5640, '14.2.7.15.0.37.0.0.128.3.63', 1, NULL),
	(1, 5641, 'x.2.7.15.0.37.0.0.128.3.63', 1, NULL),
	(1, 5642, '6.2.7.15.0.37.0.0.128.3.63', 1, NULL),
	(1, 5643, '1.2.7.15.0.37.0.0.128.3.63', 1, NULL),
	(1, 5644, '2.2.7.15.0.37.0.0.128.3.63', 1, NULL),
	(1, 5645, 'x.2.7.15.0.37.0.0.128.3.63', 1, NULL),
	(1, 5646, '3.2.7.16.0.37.0.0.128.3.63', 1, NULL),
	(1, 5647, '10.2.7.16.0.37.0.0.128.3.63', 1, NULL),
	(1, 5648, '5.2.7.16.0.37.0.0.128.3.63', 1, NULL),
	(1, 5649, '7.2.7.16.0.37.0.0.128.3.63', 1, NULL),
	(1, 5650, '4.2.7.16.0.37.0.0.128.3.63', 1, NULL),
	(1, 5651, '14.2.7.16.0.37.0.0.128.3.63', 1, NULL),
	(1, 5652, 'x.2.7.16.0.37.0.0.128.3.63', 1, NULL),
	(1, 5653, '6.2.7.16.0.37.0.0.128.3.63', 1, NULL),
	(1, 5654, '1.2.7.16.0.37.0.0.128.3.63', 1, NULL),
	(1, 5655, '2.2.7.16.0.37.0.0.128.3.63', 1, NULL),
	(1, 5656, 'x.2.7.16.0.37.0.0.128.3.63', 1, NULL),
	(1, 5657, '3.2.7.17.0.37.0.0.128.3.63', 1, NULL),
	(1, 5658, '10.2.7.17.0.37.0.0.128.3.63', 1, NULL),
	(1, 5659, '5.2.7.17.0.37.0.0.128.3.63', 1, NULL),
	(1, 5660, '7.2.7.17.0.37.0.0.128.3.63', 1, NULL),
	(1, 5661, '4.2.7.17.0.37.0.0.128.3.63', 1, NULL),
	(1, 5662, '14.2.7.17.0.37.0.0.128.3.63', 1, NULL),
	(1, 5663, 'x.2.7.17.0.37.0.0.128.3.63', 1, NULL),
	(1, 5664, '6.2.7.17.0.37.0.0.128.3.63', 1, NULL),
	(1, 5665, '1.2.7.17.0.37.0.0.128.3.63', 1, NULL),
	(1, 5666, '2.2.7.17.0.37.0.0.128.3.63', 1, NULL),
	(1, 5667, 'x.2.7.17.0.37.0.0.128.3.63', 1, NULL),
	(1, 5668, '3.2.7.18.0.37.0.0.128.3.63', 1, NULL),
	(1, 5669, '10.2.7.18.0.37.0.0.128.3.63', 1, NULL),
	(1, 5670, '5.2.7.18.0.37.0.0.128.3.63', 1, NULL),
	(1, 5671, '7.2.7.18.0.37.0.0.128.3.63', 1, NULL),
	(1, 5672, '4.2.7.18.0.37.0.0.128.3.63', 1, NULL),
	(1, 5673, '14.2.7.18.0.37.0.0.128.3.63', 1, NULL),
	(1, 5674, 'x.2.7.18.0.37.0.0.128.3.63', 1, NULL),
	(1, 5675, '6.2.7.18.0.37.0.0.128.3.63', 1, NULL),
	(1, 5676, '1.2.7.18.0.37.0.0.128.3.63', 1, NULL),
	(1, 5677, '2.2.7.18.0.37.0.0.128.3.63', 1, NULL),
	(1, 5678, 'x.2.7.18.0.37.0.0.128.3.63', 1, NULL),
	(1, 5679, '3.2.7.15.0.37.0.0.64.3.63', 1, NULL),
	(1, 5680, '10.2.7.15.0.37.0.0.64.3.63', 1, NULL),
	(1, 5681, '5.2.7.15.0.37.0.0.64.3.63', 1, NULL),
	(1, 5682, '7.2.7.15.0.37.0.0.64.3.63', 1, NULL),
	(1, 5683, '4.2.7.15.0.37.0.0.64.3.63', 1, NULL),
	(1, 5684, '14.2.7.15.0.37.0.0.64.3.63', 1, NULL),
	(1, 5685, 'x.2.7.15.0.37.0.0.64.3.63', 1, NULL),
	(1, 5686, '6.2.7.15.0.37.0.0.64.3.63', 1, NULL),
	(1, 5687, '1.2.7.15.0.37.0.0.64.3.63', 1, NULL),
	(1, 5688, '2.2.7.15.0.37.0.0.64.3.63', 1, NULL),
	(1, 5689, 'x.2.7.15.0.37.0.0.64.3.63', 1, NULL),
	(1, 5690, '3.2.7.16.0.37.0.0.64.3.63', 1, NULL),
	(1, 5691, '10.2.7.16.0.37.0.0.64.3.63', 1, NULL),
	(1, 5692, '5.2.7.16.0.37.0.0.64.3.63', 1, NULL),
	(1, 5693, '7.2.7.16.0.37.0.0.64.3.63', 1, NULL),
	(1, 5694, '4.2.7.16.0.37.0.0.64.3.63', 1, NULL),
	(1, 5695, '14.2.7.16.0.37.0.0.64.3.63', 1, NULL),
	(1, 5696, 'x.2.7.16.0.37.0.0.64.3.63', 1, NULL),
	(1, 5697, '6.2.7.16.0.37.0.0.64.3.63', 1, NULL),
	(1, 5698, '1.2.7.16.0.37.0.0.64.3.63', 1, NULL),
	(1, 5699, '2.2.7.16.0.37.0.0.64.3.63', 1, NULL),
	(1, 5700, 'x.2.7.16.0.37.0.0.64.3.63', 1, NULL),
	(1, 5701, '3.2.7.17.0.37.0.0.64.3.63', 1, NULL),
	(1, 5702, '10.2.7.17.0.37.0.0.64.3.63', 1, NULL),
	(1, 5703, '5.2.7.17.0.37.0.0.64.3.63', 1, NULL),
	(1, 5704, '7.2.7.17.0.37.0.0.64.3.63', 1, NULL),
	(1, 5705, '4.2.7.17.0.37.0.0.64.3.63', 1, NULL),
	(1, 5706, '14.2.7.17.0.37.0.0.64.3.63', 1, NULL),
	(1, 5707, 'x.2.7.17.0.37.0.0.64.3.63', 1, NULL),
	(1, 5708, '6.2.7.17.0.37.0.0.64.3.63', 1, NULL),
	(1, 5709, '1.2.7.17.0.37.0.0.64.3.63', 1, NULL),
	(1, 5710, '2.2.7.17.0.37.0.0.64.3.63', 1, NULL),
	(1, 5711, 'x.2.7.17.0.37.0.0.64.3.63', 1, NULL),
	(1, 5712, '3.2.7.18.0.37.0.0.64.3.63', 1, NULL),
	(1, 5713, '10.2.7.18.0.37.0.0.64.3.63', 1, NULL),
	(1, 5714, '5.2.7.18.0.37.0.0.64.3.63', 1, NULL),
	(1, 5715, '7.2.7.18.0.37.0.0.64.3.63', 1, NULL),
	(1, 5716, '4.2.7.18.0.37.0.0.64.3.63', 1, NULL),
	(1, 5717, '14.2.7.18.0.37.0.0.64.3.63', 1, NULL),
	(1, 5718, 'x.2.7.18.0.37.0.0.64.3.63', 1, NULL),
	(1, 5719, '6.2.7.18.0.37.0.0.64.3.63', 1, NULL),
	(1, 5720, '1.2.7.18.0.37.0.0.64.3.63', 1, NULL),
	(1, 5721, '2.2.7.18.0.37.0.0.64.3.63', 1, NULL),
	(1, 5722, 'x.2.7.18.0.37.0.0.64.3.63', 1, NULL),
	(1, 5723, '3.2.7.15.0.37.0.0.32.3.63', 1, NULL),
	(1, 5724, '10.2.7.15.0.37.0.0.32.3.63', 1, NULL),
	(1, 5725, '5.2.7.15.0.37.0.0.32.3.63', 1, NULL),
	(1, 5726, '7.2.7.15.0.37.0.0.32.3.63', 1, NULL),
	(1, 5727, '4.2.7.15.0.37.0.0.32.3.63', 1, NULL),
	(1, 5728, '14.2.7.15.0.37.0.0.32.3.63', 1, NULL),
	(1, 5729, 'x.2.7.15.0.37.0.0.32.3.63', 1, NULL),
	(1, 5730, '6.2.7.15.0.37.0.0.32.3.63', 1, NULL),
	(1, 5731, '1.2.7.15.0.37.0.0.32.3.63', 1, NULL),
	(1, 5732, '2.2.7.15.0.37.0.0.32.3.63', 1, NULL),
	(1, 5733, 'x.2.7.15.0.37.0.0.32.3.63', 1, NULL),
	(1, 5734, '3.2.7.16.0.37.0.0.32.3.63', 1, NULL),
	(1, 5735, '10.2.7.16.0.37.0.0.32.3.63', 1, NULL),
	(1, 5736, '5.2.7.16.0.37.0.0.32.3.63', 1, NULL),
	(1, 5737, '7.2.7.16.0.37.0.0.32.3.63', 1, NULL),
	(1, 5738, '4.2.7.16.0.37.0.0.32.3.63', 1, NULL),
	(1, 5739, '14.2.7.16.0.37.0.0.32.3.63', 1, NULL),
	(1, 5740, 'x.2.7.16.0.37.0.0.32.3.63', 1, NULL),
	(1, 5741, '6.2.7.16.0.37.0.0.32.3.63', 1, NULL),
	(1, 5742, '1.2.7.16.0.37.0.0.32.3.63', 1, NULL),
	(1, 5743, '2.2.7.16.0.37.0.0.32.3.63', 1, NULL),
	(1, 5744, 'x.2.7.16.0.37.0.0.32.3.63', 1, NULL),
	(1, 5745, '3.2.7.17.0.37.0.0.32.3.63', 1, NULL),
	(1, 5746, '10.2.7.17.0.37.0.0.32.3.63', 1, NULL),
	(1, 5747, '5.2.7.17.0.37.0.0.32.3.63', 1, NULL),
	(1, 5748, '7.2.7.17.0.37.0.0.32.3.63', 1, NULL),
	(1, 5749, '4.2.7.17.0.37.0.0.32.3.63', 1, NULL),
	(1, 5750, '14.2.7.17.0.37.0.0.32.3.63', 1, NULL),
	(1, 5751, 'x.2.7.17.0.37.0.0.32.3.63', 1, NULL),
	(1, 5752, '6.2.7.17.0.37.0.0.32.3.63', 1, NULL),
	(1, 5753, '1.2.7.17.0.37.0.0.32.3.63', 1, NULL),
	(1, 5754, '2.2.7.17.0.37.0.0.32.3.63', 1, NULL),
	(1, 5755, 'x.2.7.17.0.37.0.0.32.3.63', 1, NULL),
	(1, 5756, '3.2.7.18.0.37.0.0.32.3.63', 1, NULL),
	(1, 5757, '10.2.7.18.0.37.0.0.32.3.63', 1, NULL),
	(1, 5758, '5.2.7.18.0.37.0.0.32.3.63', 1, NULL),
	(1, 5759, '7.2.7.18.0.37.0.0.32.3.63', 1, NULL),
	(1, 5760, '4.2.7.18.0.37.0.0.32.3.63', 1, NULL),
	(1, 5761, '14.2.7.18.0.37.0.0.32.3.63', 1, NULL),
	(1, 5762, 'x.2.7.18.0.37.0.0.32.3.63', 1, NULL),
	(1, 5763, '6.2.7.18.0.37.0.0.32.3.63', 1, NULL),
	(1, 5764, '1.2.7.18.0.37.0.0.32.3.63', 1, NULL),
	(1, 5765, '2.2.7.18.0.37.0.0.32.3.63', 1, NULL),
	(1, 5766, 'x.2.7.18.0.37.0.0.32.3.63', 1, NULL),
	(1, 5767, '3.2.7.1.0.37.0.0.128.3.61', 1, NULL),
	(1, 5768, '10.2.7.1.0.37.0.0.128.3.61', 1, NULL),
	(1, 5769, '5.2.7.1.0.37.0.0.128.3.61', 1, NULL),
	(1, 5770, '7.2.7.1.0.37.0.0.128.3.61', 1, NULL),
	(1, 5771, '4.2.7.1.0.37.0.0.128.3.61', 1, NULL),
	(1, 5772, '14.2.7.1.0.37.0.0.128.3.61', 1, NULL),
	(1, 5773, 'x.2.7.1.0.37.0.0.128.3.61', 1, NULL),
	(1, 5774, '6.2.7.1.0.37.0.0.128.3.61', 1, NULL),
	(1, 5775, '1.2.7.1.0.37.0.0.128.3.61', 1, NULL),
	(1, 5776, '2.2.7.1.0.37.0.0.128.3.61', 1, NULL),
	(1, 5777, 'x.2.7.1.0.37.0.0.128.3.61', 1, NULL),
	(1, 5778, '3.2.7.19.0.37.0.0.128.3.61', 1, NULL),
	(1, 5779, '10.2.7.19.0.37.0.0.128.3.61', 1, NULL),
	(1, 5780, '5.2.7.19.0.37.0.0.128.3.61', 1, NULL),
	(1, 5781, '7.2.7.19.0.37.0.0.128.3.61', 1, NULL),
	(1, 5782, '4.2.7.19.0.37.0.0.128.3.61', 1, NULL),
	(1, 5783, '14.2.7.19.0.37.0.0.128.3.61', 1, NULL),
	(1, 5784, 'x.2.7.19.0.37.0.0.128.3.61', 1, NULL),
	(1, 5785, '6.2.7.19.0.37.0.0.128.3.61', 1, NULL),
	(1, 5786, '1.2.7.19.0.37.0.0.128.3.61', 1, NULL),
	(1, 5787, '2.2.7.19.0.37.0.0.128.3.61', 1, NULL),
	(1, 5788, 'x.2.7.19.0.37.0.0.128.3.61', 1, NULL),
	(1, 5789, '3.2.7.1.0.37.0.0.64.3.61', 1, NULL),
	(1, 5790, '10.2.7.1.0.37.0.0.64.3.61', 1, NULL),
	(1, 5791, '5.2.7.1.0.37.0.0.64.3.61', 1, NULL),
	(1, 5792, '7.2.7.1.0.37.0.0.64.3.61', 1, NULL),
	(1, 5793, '4.2.7.1.0.37.0.0.64.3.61', 1, NULL),
	(1, 5794, '14.2.7.1.0.37.0.0.64.3.61', 1, NULL),
	(1, 5795, 'x.2.7.1.0.37.0.0.64.3.61', 1, NULL),
	(1, 5796, '6.2.7.1.0.37.0.0.64.3.61', 1, NULL),
	(1, 5797, '1.2.7.1.0.37.0.0.64.3.61', 1, NULL),
	(1, 5798, '2.2.7.1.0.37.0.0.64.3.61', 1, NULL),
	(1, 5799, 'x.2.7.1.0.37.0.0.64.3.61', 1, NULL),
	(1, 5800, '3.2.7.19.0.37.0.0.64.3.61', 1, NULL),
	(1, 5801, '10.2.7.19.0.37.0.0.64.3.61', 1, NULL),
	(1, 5802, '5.2.7.19.0.37.0.0.64.3.61', 1, NULL),
	(1, 5803, '7.2.7.19.0.37.0.0.64.3.61', 1, NULL),
	(1, 5804, '4.2.7.19.0.37.0.0.64.3.61', 1, NULL),
	(1, 5805, '14.2.7.19.0.37.0.0.64.3.61', 1, NULL),
	(1, 5806, 'x.2.7.19.0.37.0.0.64.3.61', 1, NULL),
	(1, 5807, '6.2.7.19.0.37.0.0.64.3.61', 1, NULL),
	(1, 5808, '1.2.7.19.0.37.0.0.64.3.61', 1, NULL),
	(1, 5809, '2.2.7.19.0.37.0.0.64.3.61', 1, NULL),
	(1, 5810, 'x.2.7.19.0.37.0.0.64.3.61', 1, NULL),
	(1, 5811, '3.2.7.1.0.37.0.0.32.3.61', 1, NULL),
	(1, 5812, '10.2.7.1.0.37.0.0.32.3.61', 1, NULL),
	(1, 5813, '5.2.7.1.0.37.0.0.32.3.61', 1, NULL),
	(1, 5814, '7.2.7.1.0.37.0.0.32.3.61', 1, NULL),
	(1, 5815, '4.2.7.1.0.37.0.0.32.3.61', 1, NULL),
	(1, 5816, '14.2.7.1.0.37.0.0.32.3.61', 1, NULL),
	(1, 5817, 'x.2.7.1.0.37.0.0.32.3.61', 1, NULL),
	(1, 5818, '6.2.7.1.0.37.0.0.32.3.61', 1, NULL),
	(1, 5819, '1.2.7.1.0.37.0.0.32.3.61', 1, NULL),
	(1, 5820, '2.2.7.1.0.37.0.0.32.3.61', 1, NULL),
	(1, 5821, 'x.2.7.1.0.37.0.0.32.3.61', 1, NULL),
	(1, 5822, '3.2.7.19.0.37.0.0.32.3.61', 1, NULL),
	(1, 5823, '10.2.7.19.0.37.0.0.32.3.61', 1, NULL),
	(1, 5824, '5.2.7.19.0.37.0.0.32.3.61', 1, NULL),
	(1, 5825, '7.2.7.19.0.37.0.0.32.3.61', 1, NULL),
	(1, 5826, '4.2.7.19.0.37.0.0.32.3.61', 1, NULL),
	(1, 5827, '14.2.7.19.0.37.0.0.32.3.61', 1, NULL),
	(1, 5828, 'x.2.7.19.0.37.0.0.32.3.61', 1, NULL),
	(1, 5829, '6.2.7.19.0.37.0.0.32.3.61', 1, NULL),
	(1, 5830, '1.2.7.19.0.37.0.0.32.3.61', 1, NULL),
	(1, 5831, '2.2.7.19.0.37.0.0.32.3.61', 1, NULL),
	(1, 5832, 'x.2.7.19.0.37.0.0.32.3.61', 1, NULL),
	(1, 5833, '3.2.7.7.0.37.0.0.128.3.63', 1, NULL),
	(1, 5834, '10.2.7.7.0.37.0.0.128.3.63', 1, NULL),
	(1, 5835, '5.2.7.7.0.37.0.0.128.3.63', 1, NULL),
	(1, 5836, '7.2.7.7.0.37.0.0.128.3.63', 1, NULL),
	(1, 5837, '4.2.7.7.0.37.0.0.128.3.63', 1, NULL),
	(1, 5838, '14.2.7.7.0.37.0.0.128.3.63', 1, NULL),
	(1, 5839, 'x.2.7.7.0.37.0.0.128.3.63', 1, NULL),
	(1, 5840, '6.2.7.7.0.37.0.0.128.3.63', 1, NULL),
	(1, 5841, '1.2.7.7.0.37.0.0.128.3.63', 1, NULL),
	(1, 5842, '2.2.7.7.0.37.0.0.128.3.63', 1, NULL),
	(1, 5843, 'x.2.7.7.0.37.0.0.128.3.63', 1, NULL),
	(1, 5844, '3.2.7.11.0.37.0.0.128.3.63', 1, NULL),
	(1, 5845, '10.2.7.11.0.37.0.0.128.3.63', 1, NULL),
	(1, 5846, '5.2.7.11.0.37.0.0.128.3.63', 1, NULL),
	(1, 5847, '7.2.7.11.0.37.0.0.128.3.63', 1, NULL),
	(1, 5848, '4.2.7.11.0.37.0.0.128.3.63', 1, NULL),
	(1, 5849, '14.2.7.11.0.37.0.0.128.3.63', 1, NULL),
	(1, 5850, 'x.2.7.11.0.37.0.0.128.3.63', 1, NULL),
	(1, 5851, '6.2.7.11.0.37.0.0.128.3.63', 1, NULL),
	(1, 5852, '1.2.7.11.0.37.0.0.128.3.63', 1, NULL),
	(1, 5853, '2.2.7.11.0.37.0.0.128.3.63', 1, NULL),
	(1, 5854, 'x.2.7.11.0.37.0.0.128.3.63', 1, NULL),
	(1, 5855, '3.2.7.7.0.37.0.0.64.3.63', 1, NULL),
	(1, 5856, '10.2.7.7.0.37.0.0.64.3.63', 1, NULL),
	(1, 5857, '5.2.7.7.0.37.0.0.64.3.63', 1, NULL),
	(1, 5858, '7.2.7.7.0.37.0.0.64.3.63', 1, NULL),
	(1, 5859, '4.2.7.7.0.37.0.0.64.3.63', 1, NULL),
	(1, 5860, '14.2.7.7.0.37.0.0.64.3.63', 1, NULL),
	(1, 5861, 'x.2.7.7.0.37.0.0.64.3.63', 1, NULL),
	(1, 5862, '6.2.7.7.0.37.0.0.64.3.63', 1, NULL),
	(1, 5863, '1.2.7.7.0.37.0.0.64.3.63', 1, NULL),
	(1, 5864, '2.2.7.7.0.37.0.0.64.3.63', 1, NULL),
	(1, 5865, 'x.2.7.7.0.37.0.0.64.3.63', 1, NULL),
	(1, 5866, '3.2.7.11.0.37.0.0.64.3.63', 1, NULL),
	(1, 5867, '10.2.7.11.0.37.0.0.64.3.63', 1, NULL),
	(1, 5868, '5.2.7.11.0.37.0.0.64.3.63', 1, NULL),
	(1, 5869, '7.2.7.11.0.37.0.0.64.3.63', 1, NULL),
	(1, 5870, '4.2.7.11.0.37.0.0.64.3.63', 1, NULL),
	(1, 5871, '14.2.7.11.0.37.0.0.64.3.63', 1, NULL),
	(1, 5872, 'x.2.7.11.0.37.0.0.64.3.63', 1, NULL),
	(1, 5873, '6.2.7.11.0.37.0.0.64.3.63', 1, NULL),
	(1, 5874, '1.2.7.11.0.37.0.0.64.3.63', 1, NULL),
	(1, 5875, '2.2.7.11.0.37.0.0.64.3.63', 1, NULL),
	(1, 5876, 'x.2.7.11.0.37.0.0.64.3.63', 1, NULL),
	(1, 5877, '3.2.7.11.0.37.0.0.32.3.63', 1, NULL),
	(1, 5878, '10.2.7.11.0.37.0.0.32.3.63', 1, NULL),
	(1, 5879, '5.2.7.11.0.37.0.0.32.3.63', 1, NULL),
	(1, 5880, '7.2.7.11.0.37.0.0.32.3.63', 1, NULL),
	(1, 5881, '4.2.7.11.0.37.0.0.32.3.63', 1, NULL),
	(1, 5882, '14.2.7.11.0.37.0.0.32.3.63', 1, NULL),
	(1, 5883, 'x.2.7.11.0.37.0.0.32.3.63', 1, NULL),
	(1, 5884, '6.2.7.11.0.37.0.0.32.3.63', 1, NULL),
	(1, 5885, '1.2.7.11.0.37.0.0.32.3.63', 1, NULL),
	(1, 5886, '2.2.7.11.0.37.0.0.32.3.63', 1, NULL),
	(1, 5887, 'x.2.7.11.0.37.0.0.32.3.63', 1, NULL),
	(1, 5888, '3.2.7.7.0.37.0.0.32.3.63', 1, NULL),
	(1, 5889, '10.2.7.7.0.37.0.0.32.3.63', 1, NULL),
	(1, 5890, '5.2.7.7.0.37.0.0.32.3.63', 1, NULL),
	(1, 5891, '7.2.7.7.0.37.0.0.32.3.63', 1, NULL),
	(1, 5892, '4.2.7.7.0.37.0.0.32.3.63', 1, NULL),
	(1, 5893, '14.2.7.7.0.37.0.0.32.3.63', 1, NULL),
	(1, 5894, 'x.2.7.7.0.37.0.0.32.3.63', 1, NULL),
	(1, 5895, '6.2.7.7.0.37.0.0.32.3.63', 1, NULL),
	(1, 5896, '1.2.7.7.0.37.0.0.32.3.63', 1, NULL),
	(1, 5897, '2.2.7.7.0.37.0.0.32.3.63', 1, NULL),
	(1, 5898, 'x.2.7.7.0.37.0.0.32.3.63', 1, NULL),
	(1, 5899, '3.2.7.7.0.37.0.0.0.3.38', 1, NULL),
	(1, 5900, '10.2.7.7.0.37.0.0.0.3.38', 1, NULL),
	(1, 5901, '5.2.7.7.0.37.0.0.0.3.38', 1, 1),
	(1, 5902, '7.2.7.7.0.37.0.0.0.3.38', 1, 1),
	(1, 5903, '4.2.7.7.0.37.0.0.0.3.38', 1, NULL),
	(1, 5904, '14.2.7.7.0.37.0.0.0.3.38', 1, NULL),
	(1, 5905, 'x.2.7.7.0.37.0.0.0.3.38', 1, NULL),
	(1, 5906, '6.2.7.7.0.37.0.0.0.3.38', 1, NULL),
	(1, 5907, '1.2.7.7.0.37.0.0.0.3.38', 1, NULL),
	(1, 5908, '2.2.7.7.0.37.0.0.0.3.38', 1, 1),
	(1, 5909, 'x.2.7.7.0.37.0.0.0.3.38', 1, 1),
	(1, 5910, '3.2.7.11.0.37.0.0.0.3.38', 1, NULL),
	(1, 5911, '10.2.7.11.0.37.0.0.0.3.38', 1, NULL),
	(1, 5912, '5.2.7.11.0.37.0.0.0.3.38', 1, 1),
	(1, 5913, '7.2.7.11.0.37.0.0.0.3.38', 1, 1),
	(1, 5914, '4.2.7.11.0.37.0.0.0.3.38', 1, NULL),
	(1, 5915, '14.2.7.11.0.37.0.0.0.3.38', 1, NULL),
	(1, 5916, 'x.2.7.11.0.37.0.0.0.3.38', 1, NULL),
	(1, 5917, '6.2.7.11.0.37.0.0.0.3.38', 1, NULL),
	(1, 5918, '1.2.7.11.0.37.0.0.0.3.38', 1, NULL),
	(1, 5919, '2.2.7.11.0.37.0.0.0.3.38', 1, 1),
	(1, 5920, 'x.2.7.11.0.37.0.0.0.3.38', 1, 1),
	(1, 5921, '15.8.7.1.0.37.0.0.0.3.61', 1, NULL),
	(1, 5922, '15.8.7.1.0.37.0.0.0.3.61', 1, NULL),
	(1, 5923, '15.8.7.1.0.37.0.0.0.3.61', 1, NULL),
	(1, 5924, '15.8.7.1.0.37.0.0.0.3.61', 1, NULL),
	(1, 5925, '4.8.7.1.0.37.0.0.0.3.61', 1, NULL),
	(1, 5926, '4.8.7.1.0.37.0.0.0.3.61', 1, NULL),
	(1, 5927, '4.8.7.1.0.37.0.0.0.3.61', 1, NULL),
	(1, 5928, '4.8.7.1.0.37.0.0.0.3.61', 1, NULL),
	(1, 5929, '15.8.7.19.0.37.0.0.0.3.61', 1, NULL),
	(1, 5930, '15.8.7.19.0.37.0.0.0.3.61', 1, NULL),
	(1, 5931, '15.8.7.19.0.37.0.0.0.3.61', 1, NULL),
	(1, 5932, '15.8.7.19.0.37.0.0.0.3.61', 1, NULL),
	(1, 5933, '4.8.7.19.0.37.0.0.0.3.61', 1, NULL),
	(1, 5934, '4.8.7.19.0.37.0.0.0.3.61', 1, NULL),
	(1, 5935, '4.8.7.19.0.37.0.0.0.3.61', 1, NULL),
	(1, 5936, '4.8.7.19.0.37.0.0.0.3.61', 1, NULL),
	(1, 5937, '15.8.7.15.0.37.0.0.0.3.63', 1, NULL),
	(1, 5938, '15.8.7.16.0.37.0.0.0.3.63', 1, NULL),
	(1, 5939, '15.8.7.17.0.37.0.0.0.3.63', 1, NULL),
	(1, 5940, '15.8.7.18.0.37.0.0.0.3.63', 1, NULL),
	(1, 5941, '15.8.7.15.0.37.0.0.0.3.63', 1, NULL),
	(1, 5942, '15.8.7.16.0.37.0.0.0.3.63', 1, NULL),
	(1, 5943, '15.8.7.17.0.37.0.0.0.3.63', 1, NULL),
	(1, 5944, '15.8.7.18.0.37.0.0.0.3.63', 1, NULL),
	(1, 5945, '15.8.7.15.0.37.0.0.0.3.63', 1, NULL),
	(1, 5946, '15.8.7.16.0.37.0.0.0.3.63', 1, NULL),
	(1, 5947, '15.8.7.17.0.37.0.0.0.3.63', 1, NULL),
	(1, 5948, '15.8.7.18.0.37.0.0.0.3.63', 1, NULL),
	(1, 5949, '15.8.7.15.0.37.0.0.0.3.63', 1, NULL),
	(1, 5950, '15.8.7.16.0.37.0.0.0.3.63', 1, NULL),
	(1, 5951, '15.8.7.17.0.37.0.0.0.3.63', 1, NULL),
	(1, 5952, '15.8.7.18.0.37.0.0.0.3.63', 1, NULL),
	(1, 5953, '4.8.7.15.0.37.0.0.0.3.63', 1, NULL),
	(1, 5954, '4.8.7.16.0.37.0.0.0.3.63', 1, NULL),
	(1, 5955, '4.8.7.17.0.37.0.0.0.3.63', 1, NULL),
	(1, 5956, '4.8.7.18.0.37.0.0.0.3.63', 1, NULL),
	(1, 5957, '4.8.7.15.0.37.0.0.0.3.63', 1, NULL),
	(1, 5958, '4.8.7.16.0.37.0.0.0.3.63', 1, NULL),
	(1, 5959, '4.8.7.17.0.37.0.0.0.3.63', 1, NULL),
	(1, 5960, '4.8.7.18.0.37.0.0.0.3.63', 1, NULL),
	(1, 5961, '4.8.7.15.0.37.0.0.0.3.63', 1, NULL),
	(1, 5962, '4.8.7.16.0.37.0.0.0.3.63', 1, NULL),
	(1, 5963, '4.8.7.17.0.37.0.0.0.3.63', 1, NULL),
	(1, 5964, '4.8.7.18.0.37.0.0.0.3.63', 1, NULL),
	(1, 5965, '4.8.7.15.0.37.0.0.0.3.63', 1, NULL),
	(1, 5966, '4.8.7.16.0.37.0.0.0.3.63', 1, NULL),
	(1, 5967, '4.8.7.17.0.37.0.0.0.3.63', 1, NULL),
	(1, 5968, '4.8.7.18.0.37.0.0.0.3.63', 1, NULL),
	(1, 5969, '0.6.2.0.0.12.0.0.0.3.72', 1, 3),
	(1, 5970, '15.6.3.0.0.12.0.0.0.3.72', 1, 3),
	(1, 5971, '4.6.3.0.0.12.0.0.0.3.72', 1, 3),
	(1, 5972, '7.6.3.0.0.12.0.0.0.3.72', 1, 3),
	(1, 5973, '2.6.3.0.0.12.0.0.0.3.72', 1, 3),
	(1, 5974, 'x.6.3.0.0.12.0.0.0.3.72', 1, 3),
	(1, 5975, '5.6.3.0.0.12.0.0.0.3.72', 1, 3),
	(1, 5976, 'x.6.2.0.0.12.3.1.0.3.72', 1, 3),
	(1, 5977, '15.6.3.0.0.12.3.1.0.3.72', 1, 3),
	(1, 5978, '4.6.3.0.0.12.3.1.0.3.72', 1, 3),
	(1, 5979, '7.6.3.0.0.12.3.1.0.3.72', 1, 3),
	(1, 5980, '2.6.3.0.0.12.3.1.0.3.72', 1, 3),
	(1, 5981, 'x.6.3.0.0.12.3.1.0.3.72', 1, 3),
	(1, 5982, '5.6.3.0.0.12.3.1.0.3.72', 1, 3),
	(1, 5983, 'x.6.2.0.0.12.3.2.0.3.72', 1, 3),
	(1, 5984, '15.6.3.0.0.12.3.2.0.3.72', 1, 3),
	(1, 5985, '4.6.3.0.0.12.3.2.0.3.72', 1, 3),
	(1, 5986, '7.6.3.0.0.12.3.2.0.3.72', 1, 3),
	(1, 5987, '2.6.3.0.0.12.3.2.0.3.72', 1, 3),
	(1, 5988, 'x.6.3.0.0.12.3.2.0.3.72', 1, 3),
	(1, 5989, '5.6.3.0.0.12.3.2.0.3.72', 1, 3),
	(1, 5990, 'x.6.2.0.0.12.3.3.0.3.72', 1, 3),
	(1, 5991, '15.6.3.0.0.12.3.3.0.3.72', 1, 3),
	(1, 5992, '4.6.3.0.0.12.3.3.0.3.72', 1, 3),
	(1, 5993, '7.6.3.0.0.12.3.3.0.3.72', 1, 3),
	(1, 5994, '2.6.3.0.0.12.3.3.0.3.72', 1, 3),
	(1, 5995, 'x.6.3.0.0.12.3.3.0.3.72', 1, 3),
	(1, 5996, '5.6.3.0.0.12.3.3.0.3.72', 1, 3),
	(1, 5997, 'x.6.2.0.0.12.3.4.0.3.72', 1, 3),
	(1, 5998, '15.6.3.0.0.12.3.4.0.3.72', 1, 3),
	(1, 5999, '4.6.3.0.0.12.3.4.0.3.72', 1, 3),
	(1, 6000, '7.6.3.0.0.12.3.4.0.3.72', 1, 3),
	(1, 6001, '2.6.3.0.0.12.3.4.0.3.72', 1, 3),
	(1, 6002, 'x.6.3.0.0.12.3.4.0.3.72', 1, 3),
	(1, 6003, '5.6.3.0.0.12.3.4.0.3.72', 1, 3),
	(1, 6004, 'x.6.2.0.0.12.3.5.0.3.72', 1, 3),
	(1, 6005, '15.6.3.0.0.12.3.5.0.3.72', 1, 3),
	(1, 6006, '4.6.3.0.0.12.3.5.0.3.72', 1, 3),
	(1, 6007, '7.6.3.0.0.12.3.5.0.3.72', 1, 3),
	(1, 6008, '2.6.3.0.0.12.3.5.0.3.72', 1, 3),
	(1, 6009, 'x.6.3.0.0.12.3.5.0.3.72', 1, 3),
	(1, 6010, '5.6.3.0.0.12.3.5.0.3.72', 1, 3),
	(1, 6011, 'x.6.2.0.0.12.3.6.0.3.72', 1, 3),
	(1, 6012, '15.6.3.0.0.12.3.6.0.3.72', 1, 3),
	(1, 6013, '4.6.3.0.0.12.3.6.0.3.72', 1, 3),
	(1, 6014, '7.6.3.0.0.12.3.6.0.3.72', 1, 3),
	(1, 6015, '2.6.3.0.0.12.3.6.0.3.72', 1, 3),
	(1, 6016, 'x.6.3.0.0.12.3.6.0.3.72', 1, 3),
	(1, 6017, '5.6.3.0.0.12.3.6.0.3.72', 1, 3),
	(1, 6018, 'x.6.2.0.0.12.3.7.0.3.72', 1, 3),
	(1, 6019, '15.6.3.0.0.12.3.7.0.3.72', 1, 3),
	(1, 6020, '4.6.3.0.0.12.3.7.0.3.72', 1, 3),
	(1, 6021, '7.6.3.0.0.12.3.7.0.3.72', 1, 3),
	(1, 6022, '2.6.3.0.0.12.3.7.0.3.72', 1, 3),
	(1, 6023, 'x.6.3.0.0.12.3.7.0.3.72', 1, 3),
	(1, 6024, '5.6.3.0.0.12.3.7.0.3.72', 1, 3),
	(1, 6025, 'x.6.2.0.0.12.3.8.0.3.72', 1, 3),
	(1, 6026, '15.6.3.0.0.12.3.8.0.3.72', 1, 3),
	(1, 6027, '4.6.3.0.0.12.3.8.0.3.72', 1, 3),
	(1, 6028, '7.6.3.0.0.12.3.8.0.3.72', 1, 3),
	(1, 6029, '2.6.3.0.0.12.3.8.0.3.72', 1, 3),
	(1, 6030, 'x.6.3.0.0.12.3.8.0.3.72', 1, 3),
	(1, 6031, '5.6.3.0.0.12.3.8.0.3.72', 1, 3),
	(1, 6032, '5.2.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 6033, '7.2.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 6034, '3.2.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 6035, '10.2.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 6036, '14.2.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 6037, '1.2.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 6038, '4.2.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 6039, '6.2.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 6040, 'x.2.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 6041, '2.2.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 6042, 'x.2.7.0.0.4.0.0.128.0.5', 1, NULL),
	(1, 6043, '5.2.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 6044, '7.2.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 6045, '3.2.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 6046, '10.2.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 6047, '14.2.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 6048, '1.2.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 6049, '4.2.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 6050, '6.2.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 6051, 'x.2.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 6052, '2.2.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 6053, 'x.2.7.0.0.4.0.0.64.0.5', 1, NULL),
	(1, 6054, '5.2.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 6055, '7.2.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 6056, '3.2.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 6057, '10.2.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 6058, '14.2.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 6059, '1.2.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 6060, '4.2.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 6061, '6.2.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 6062, 'x.2.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 6063, '2.2.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 6064, 'x.2.7.0.0.4.0.0.32.0.5', 1, NULL),
	(1, 6065, '5.2.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 6066, '7.2.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 6067, '3.2.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 6068, '10.2.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 6069, '14.2.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 6070, '1.2.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 6071, '4.2.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 6072, '6.2.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 6073, 'x.2.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 6074, '2.2.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 6075, 'x.2.7.0.0.4.0.0.x.0.5', 1, NULL),
	(1, 6076, '0.2.6.0.x.x.0.0.x.0.5', 1, 3),
	(1, 6077, 'x.2.7.0.x.x.0.0.x.0.5', 1, NULL),
	(1, 6078, 'x.2.7.0.x.x.0.0.x.0.5', 1, NULL),
	(1, 6079, '5.2.7.x.0.37.0.0.0.3.38', 1, 1),
	(1, 6080, '7.2.7.x.0.37.0.0.0.3.38', 1, 1),
	(1, 6081, '2.2.7.x.0.37.0.0.0.3.38', 1, 1),
	(1, 6082, 'x.2.7.x.0.37.0.0.0.3.38', 1, 1),
	(1, 6083, '7.9.7.0.x.x.0.0.x.0.5', 1, NULL),
	(1, 6084, '7.8.7.0.x.x.0.0.x.0.5', 1, NULL),
	(1, 6085, '4.8.7.0.x.x.0.0.x.0.5', 1, NULL),
	(1, 6086, '15.8.7.0.x.x.0.0.x.0.5', 1, NULL),
	(1, 6087, '5.2.7.x.0.37.0.0.0.3.63', 1, 1),
	(1, 6088, '7.2.7.x.0.37.0.0.0.3.63', 1, 1),
	(1, 6089, '2.2.7.x.0.37.0.0.0.3.63', 1, 1),
	(1, 6090, 'x.2.7.x.0.37.0.0.0.3.63', 1, 1),
	(1, 6091, '5.2.7.8.0.37.0.0.0.3.63', 1, 1),
	(1, 6092, '7.2.7.8.0.37.0.0.0.3.63', 1, 1),
	(1, 6093, '2.2.7.8.0.37.0.0.0.3.63', 1, 1),
	(1, 6094, 'x.2.7.8.0.37.0.0.0.3.63', 1, 1),
	(1, 6095, '5.2.7.10.0.37.0.0.0.3.63', 1, 1),
	(1, 6096, '7.2.7.10.0.37.0.0.0.3.63', 1, 1),
	(1, 6097, '2.2.7.10.0.37.0.0.0.3.63', 1, 1),
	(1, 6098, 'x.2.7.10.0.37.0.0.0.3.63', 1, 1),
	(1, 6099, '4.9.7.0.x.x.0.0.x.0.5', 1, NULL),
	(1, 6100, '15.9.7.0.x.x.0.0.x.0.5', 1, NULL),
	(1, 6103, '5.2.7.x.0.37.0.0.0.3.61', 1, 1),
	(1, 6104, '7.2.7.x.0.37.0.0.0.3.61', 1, 1),
	(1, 6105, '2.2.7.x.0.37.0.0.0.3.61', 1, 1),
	(1, 6106, 'x.2.7.x.0.37.0.0.0.3.61', 1, 1),
	(1, 6111, '5.2.7.x.0.12.0.0.0.3.72', 1, 1),
	(1, 6112, '7.2.7.x.0.12.0.0.0.3.72', 1, 1),
	(1, 6113, '2.2.7.x.0.12.0.0.0.3.72', 1, 1),
	(1, 6114, 'x.2.7.x.0.12.0.0.0.3.72', 1, 1),
	(1, 6119, '5.2.7.x.0.12.0.0.0.3.73', 1, 1),
	(1, 6120, '7.2.7.x.0.12.0.0.0.3.73', 1, 1),
	(1, 6121, '2.2.7.x.0.12.0.0.0.3.73', 1, 1),
	(1, 6122, 'x.2.7.x.0.12.0.0.0.3.73', 1, 1),
	(1, 6123, '5.2.7.8.0.12.0.0.0.3.73', 1, 1),
	(1, 6124, '7.2.7.8.0.12.0.0.0.3.73', 1, 1),
	(1, 6125, '2.2.7.8.0.12.0.0.0.3.73', 1, 1),
	(1, 6126, 'x.2.7.8.0.12.0.0.0.3.73', 1, 1),
	(1, 6127, '5.2.7.10.0.12.0.0.0.3.73', 1, 1),
	(1, 6128, '7.2.7.10.0.12.0.0.0.3.73', 1, 1),
	(1, 6129, '2.2.7.10.0.12.0.0.0.3.73', 1, 1),
	(1, 6130, 'x.2.7.10.0.12.0.0.0.3.73', 1, 1),
	(1, 6135, '5.2.7.x.0.12.0.0.0.3.71', 1, 1),
	(1, 6136, '7.2.7.x.0.12.0.0.0.3.71', 1, 1),
	(1, 6137, '2.2.7.x.0.12.0.0.0.3.71', 1, 1),
	(1, 6138, 'x.2.7.x.0.12.0.0.0.3.71', 1, 1),
	(1, 6139, '5.2.7.1.0.12.0.0.128.3.72', 1, NULL),
	(1, 6140, '7.2.7.1.0.12.0.0.128.3.72', 1, NULL),
	(1, 6141, '2.2.7.1.0.12.0.0.128.3.72', 1, NULL),
	(1, 6142, 'x.2.7.1.0.12.0.0.128.3.72', 1, NULL),
	(1, 6143, '5.2.7.19.0.12.0.0.128.3.72', 1, NULL),
	(1, 6144, '7.2.7.19.0.12.0.0.128.3.72', 1, NULL),
	(1, 6145, '2.2.7.19.0.12.0.0.128.3.72', 1, NULL),
	(1, 6146, 'x.2.7.19.0.12.0.0.128.3.72', 1, NULL),
	(1, 6147, '5.2.7.1.0.12.0.0.128.3.73', 1, NULL),
	(1, 6148, '7.2.7.1.0.12.0.0.128.3.73', 1, NULL),
	(1, 6149, '2.2.7.1.0.12.0.0.128.3.73', 1, NULL),
	(1, 6150, 'x.2.7.1.0.12.0.0.128.3.73', 1, NULL),
	(1, 6151, '5.2.7.19.0.12.0.0.128.3.73', 1, NULL),
	(1, 6152, '7.2.7.19.0.12.0.0.128.3.73', 1, NULL),
	(1, 6153, '2.2.7.19.0.12.0.0.128.3.73', 1, NULL),
	(1, 6154, 'x.2.7.19.0.12.0.0.128.3.73', 1, NULL),
	(1, 6155, '5.2.7.1.0.12.0.0.64.3.72', 1, NULL),
	(1, 6156, '7.2.7.1.0.12.0.0.64.3.72', 1, NULL),
	(1, 6157, '2.2.7.1.0.12.0.0.64.3.72', 1, NULL),
	(1, 6158, 'x.2.7.1.0.12.0.0.64.3.72', 1, NULL),
	(1, 6159, '5.2.7.19.0.12.0.0.64.3.72', 1, NULL),
	(1, 6160, '7.2.7.19.0.12.0.0.64.3.72', 1, NULL),
	(1, 6161, '2.2.7.19.0.12.0.0.64.3.72', 1, NULL),
	(1, 6162, 'x.2.7.19.0.12.0.0.64.3.72', 1, NULL),
	(1, 6163, '5.2.7.1.0.12.0.0.64.3.73', 1, NULL),
	(1, 6164, '7.2.7.1.0.12.0.0.64.3.73', 1, NULL),
	(1, 6165, '2.2.7.1.0.12.0.0.64.3.73', 1, NULL),
	(1, 6166, 'x.2.7.1.0.12.0.0.64.3.73', 1, NULL),
	(1, 6167, '5.2.7.19.0.12.0.0.64.3.73', 1, NULL),
	(1, 6168, '7.2.7.19.0.12.0.0.64.3.73', 1, NULL),
	(1, 6169, '2.2.7.19.0.12.0.0.64.3.73', 1, NULL),
	(1, 6170, 'x.2.7.19.0.12.0.0.64.3.73', 1, NULL),
	(1, 6171, '5.2.7.1.0.12.0.0.32.3.72', 1, NULL),
	(1, 6172, '7.2.7.1.0.12.0.0.32.3.72', 1, NULL),
	(1, 6173, '2.2.7.1.0.12.0.0.32.3.72', 1, NULL),
	(1, 6174, 'x.2.7.1.0.12.0.0.32.3.72', 1, NULL),
	(1, 6175, '5.2.7.19.0.12.0.0.32.3.72', 1, NULL),
	(1, 6176, '7.2.7.19.0.12.0.0.32.3.72', 1, NULL),
	(1, 6177, '2.2.7.19.0.12.0.0.32.3.72', 1, NULL),
	(1, 6178, 'x.2.7.19.0.12.0.0.32.3.72', 1, NULL),
	(1, 6179, '5.2.7.1.0.12.0.0.32.3.73', 1, NULL),
	(1, 6180, '7.2.7.1.0.12.0.0.32.3.73', 1, NULL),
	(1, 6181, '2.2.7.1.0.12.0.0.32.3.73', 1, NULL),
	(1, 6182, 'x.2.7.1.0.12.0.0.32.3.73', 1, NULL),
	(1, 6183, '5.2.7.19.0.12.0.0.32.3.73', 1, NULL),
	(1, 6184, '7.2.7.19.0.12.0.0.32.3.73', 1, NULL),
	(1, 6185, '2.2.7.19.0.12.0.0.32.3.73', 1, NULL),
	(1, 6186, 'x.2.7.19.0.12.0.0.32.3.73', 1, NULL),
	(1, 6187, '5.2.7.15.0.12.0.0.128.3.73', 1, NULL),
	(1, 6188, '7.2.7.15.0.12.0.0.128.3.73', 1, NULL),
	(1, 6189, '2.2.7.15.0.12.0.0.128.3.73', 1, NULL),
	(1, 6190, 'x.2.7.15.0.12.0.0.128.3.73', 1, NULL),
	(1, 6191, '5.2.7.16.0.12.0.0.128.3.73', 1, NULL),
	(1, 6192, '7.2.7.16.0.12.0.0.128.3.73', 1, NULL),
	(1, 6193, '2.2.7.16.0.12.0.0.128.3.73', 1, NULL),
	(1, 6194, 'x.2.7.16.0.12.0.0.128.3.73', 1, NULL),
	(1, 6195, '5.2.7.17.0.12.0.0.128.3.73', 1, NULL),
	(1, 6196, '7.2.7.17.0.12.0.0.128.3.73', 1, NULL),
	(1, 6197, '2.2.7.17.0.12.0.0.128.3.73', 1, NULL),
	(1, 6198, 'x.2.7.17.0.12.0.0.128.3.73', 1, NULL),
	(1, 6199, '5.2.7.18.0.12.0.0.128.3.73', 1, NULL),
	(1, 6200, '7.2.7.18.0.12.0.0.128.3.73', 1, NULL),
	(1, 6201, '2.2.7.18.0.12.0.0.128.3.73', 1, NULL),
	(1, 6202, 'x.2.7.18.0.12.0.0.128.3.73', 1, NULL),
	(1, 6203, '5.2.7.15.0.12.0.0.64.3.73', 1, NULL),
	(1, 6204, '7.2.7.15.0.12.0.0.64.3.73', 1, NULL),
	(1, 6205, '2.2.7.15.0.12.0.0.64.3.73', 1, NULL),
	(1, 6206, 'x.2.7.15.0.12.0.0.64.3.73', 1, NULL),
	(1, 6207, '5.2.7.16.0.12.0.0.64.3.73', 1, NULL),
	(1, 6208, '7.2.7.16.0.12.0.0.64.3.73', 1, NULL),
	(1, 6209, '2.2.7.16.0.12.0.0.64.3.73', 1, NULL),
	(1, 6210, 'x.2.7.16.0.12.0.0.64.3.73', 1, NULL),
	(1, 6211, '5.2.7.17.0.12.0.0.64.3.73', 1, NULL),
	(1, 6212, '7.2.7.17.0.12.0.0.64.3.73', 1, NULL),
	(1, 6213, '2.2.7.17.0.12.0.0.64.3.73', 1, NULL),
	(1, 6214, 'x.2.7.17.0.12.0.0.64.3.73', 1, NULL),
	(1, 6215, '5.2.7.18.0.12.0.0.64.3.73', 1, NULL),
	(1, 6216, '7.2.7.18.0.12.0.0.64.3.73', 1, NULL),
	(1, 6217, '2.2.7.18.0.12.0.0.64.3.73', 1, NULL),
	(1, 6218, 'x.2.7.18.0.12.0.0.64.3.73', 1, NULL),
	(1, 6219, '5.2.7.15.0.12.0.0.32.3.73', 1, NULL),
	(1, 6220, '7.2.7.15.0.12.0.0.32.3.73', 1, NULL),
	(1, 6221, '2.2.7.15.0.12.0.0.32.3.73', 1, NULL),
	(1, 6222, 'x.2.7.15.0.12.0.0.32.3.73', 1, NULL),
	(1, 6223, '5.2.7.16.0.12.0.0.32.3.73', 1, NULL),
	(1, 6224, '7.2.7.16.0.12.0.0.32.3.73', 1, NULL),
	(1, 6225, '2.2.7.16.0.12.0.0.32.3.73', 1, NULL),
	(1, 6226, 'x.2.7.16.0.12.0.0.32.3.73', 1, NULL),
	(1, 6227, '5.2.7.17.0.12.0.0.32.3.73', 1, NULL),
	(1, 6228, '7.2.7.17.0.12.0.0.32.3.73', 1, NULL),
	(1, 6229, '2.2.7.17.0.12.0.0.32.3.73', 1, NULL),
	(1, 6230, 'x.2.7.17.0.12.0.0.32.3.73', 1, NULL),
	(1, 6231, '5.2.7.18.0.12.0.0.32.3.73', 1, NULL),
	(1, 6232, '7.2.7.18.0.12.0.0.32.3.73', 1, NULL),
	(1, 6233, '2.2.7.18.0.12.0.0.32.3.73', 1, NULL),
	(1, 6234, 'x.2.7.18.0.12.0.0.32.3.73', 1, NULL),
	(1, 6235, '5.2.7.1.0.12.0.0.128.3.71', 1, NULL),
	(1, 6236, '7.2.7.1.0.12.0.0.128.3.71', 1, NULL),
	(1, 6237, '2.2.7.1.0.12.0.0.128.3.71', 1, NULL),
	(1, 6238, 'x.2.7.1.0.12.0.0.128.3.71', 1, NULL),
	(1, 6239, '5.2.7.19.0.12.0.0.128.3.71', 1, NULL),
	(1, 6240, '7.2.7.19.0.12.0.0.128.3.71', 1, NULL),
	(1, 6241, '2.2.7.19.0.12.0.0.128.3.71', 1, NULL),
	(1, 6242, 'x.2.7.19.0.12.0.0.128.3.71', 1, NULL),
	(1, 6243, '5.2.7.1.0.12.0.0.64.3.71', 1, NULL),
	(1, 6244, '7.2.7.1.0.12.0.0.64.3.71', 1, NULL),
	(1, 6245, '2.2.7.1.0.12.0.0.64.3.71', 1, NULL),
	(1, 6246, 'x.2.7.1.0.12.0.0.64.3.71', 1, NULL),
	(1, 6247, '5.2.7.19.0.12.0.0.64.3.71', 1, NULL),
	(1, 6248, '7.2.7.19.0.12.0.0.64.3.71', 1, NULL),
	(1, 6249, '2.2.7.19.0.12.0.0.64.3.71', 1, NULL),
	(1, 6250, 'x.2.7.19.0.12.0.0.64.3.71', 1, NULL),
	(1, 6251, '5.2.7.19.0.12.0.0.32.3.71', 1, NULL),
	(1, 6252, '7.2.7.19.0.12.0.0.32.3.71', 1, NULL),
	(1, 6253, '2.2.7.19.0.12.0.0.32.3.71', 1, NULL),
	(1, 6254, 'x.2.7.19.0.12.0.0.32.3.71', 1, NULL),
	(1, 6255, '5.2.7.1.0.12.0.0.32.3.71', 1, NULL),
	(1, 6256, '7.2.7.1.0.12.0.0.32.3.71', 1, NULL),
	(1, 6257, '2.2.7.1.0.12.0.0.32.3.71', 1, NULL),
	(1, 6258, 'x.2.7.1.0.12.0.0.32.3.71', 1, NULL),
	(1, 6259, '5.2.7.7.0.12.0.0.128.3.73', 1, NULL),
	(1, 6260, '7.2.7.7.0.12.0.0.128.3.73', 1, NULL),
	(1, 6261, '2.2.7.7.0.12.0.0.128.3.73', 1, NULL),
	(1, 6262, 'x.2.7.7.0.12.0.0.128.3.73', 1, NULL),
	(1, 6263, '5.2.7.11.0.12.0.0.128.3.73', 1, NULL),
	(1, 6264, '7.2.7.11.0.12.0.0.128.3.73', 1, NULL),
	(1, 6265, '2.2.7.11.0.12.0.0.128.3.73', 1, NULL),
	(1, 6266, 'x.2.7.11.0.12.0.0.128.3.73', 1, NULL),
	(1, 6267, '5.2.7.7.0.12.0.0.64.3.73', 1, NULL),
	(1, 6268, '7.2.7.7.0.12.0.0.64.3.73', 1, NULL),
	(1, 6269, '2.2.7.7.0.12.0.0.64.3.73', 1, NULL),
	(1, 6270, 'x.2.7.7.0.12.0.0.64.3.73', 1, NULL),
	(1, 6271, '5.2.7.11.0.12.0.0.64.3.73', 1, NULL),
	(1, 6272, '7.2.7.11.0.12.0.0.64.3.73', 1, NULL),
	(1, 6273, '2.2.7.11.0.12.0.0.64.3.73', 1, NULL),
	(1, 6274, 'x.2.7.11.0.12.0.0.64.3.73', 1, NULL),
	(1, 6275, '5.2.7.11.0.12.0.0.32.3.73', 1, NULL),
	(1, 6276, '7.2.7.11.0.12.0.0.32.3.73', 1, NULL),
	(1, 6277, '2.2.7.11.0.12.0.0.32.3.73', 1, NULL),
	(1, 6278, 'x.2.7.11.0.12.0.0.32.3.73', 1, NULL),
	(1, 6279, '5.2.7.7.0.12.0.0.32.3.73', 1, NULL),
	(1, 6280, '7.2.7.7.0.12.0.0.32.3.73', 1, NULL),
	(1, 6281, '2.2.7.7.0.12.0.0.32.3.73', 1, NULL),
	(1, 6282, 'x.2.7.7.0.12.0.0.32.3.73', 1, NULL),
	(1, 6283, '5.2.7.11.0.12.0.0.0.3.73', 1, 1),
	(1, 6284, '7.2.7.11.0.12.0.0.0.3.73', 1, 1),
	(1, 6285, '2.2.7.11.0.12.0.0.0.3.73', 1, 1),
	(1, 6286, 'x.2.7.11.0.12.0.0.0.3.73', 1, 1),
	(1, 6287, '5.2.7.7.0.12.0.0.0.3.73', 1, 1),
	(1, 6288, '7.2.7.7.0.12.0.0.0.3.73', 1, 1),
	(1, 6289, '2.2.7.7.0.12.0.0.0.3.73', 1, 1),
	(1, 6290, 'x.2.7.7.0.12.0.0.0.3.73', 1, 1),
	(1, 6312, '0.6.2.15.0.12.0.0.128.3.73', 1, 3),
	(1, 6313, '0.6.2.15.0.12.0.0.64.3.73', 1, 3),
	(1, 6314, '0.6.2.15.0.12.0.0.32.3.73', 1, 3),
	(1, 6315, '0.6.2.16.0.12.0.0.128.3.73', 1, 3),
	(1, 6316, '0.6.2.16.0.12.0.0.64.3.73', 1, 3),
	(1, 6317, '0.6.2.16.0.12.0.0.32.3.73', 1, 3),
	(1, 6318, '0.6.2.17.0.12.0.0.128.3.73', 1, 3),
	(1, 6319, '0.6.2.17.0.12.0.0.64.3.73', 1, 3),
	(1, 6320, '0.6.2.17.0.12.0.0.32.3.73', 1, 3),
	(1, 6321, '0.6.2.18.0.12.0.0.128.3.73', 1, 3),
	(1, 6322, '0.6.2.18.0.12.0.0.64.3.73', 1, 3),
	(1, 6323, '0.6.2.18.0.12.0.0.32.3.73', 1, 3),
	(1, 6324, '0.6.2.0.0.12.0.0.128.3.72', 1, 3),
	(1, 6325, '0.6.2.0.0.12.0.0.64.3.72', 1, 3),
	(1, 6326, '0.6.2.0.0.12.0.0.32.3.72', 1, 3),
	(1, 6327, '0.6.2.0.0.12.0.0.0.3.72', 1, 3),
	(5, 1, '1.0.1.8.1.255', 1, NULL),
	(5, 2, '1.0.2.8.1.255', 1, NULL),
	(5, 3, '1.0.3.8.1.255', 1, NULL),
	(5, 4, '1.0.4.8.1.255', 1, NULL),
	(5, 5, '1.0.1.8.2.255', 1, NULL),
	(5, 6, '1.0.2.8.2.255', 1, NULL),
	(5, 7, '1.0.3.8.2.255', 1, NULL),
	(5, 8, '1.0.4.8.2.255', 1, NULL),
	(5, 9, '1.0.1.8.3.255', 1, NULL),
	(5, 10, '1.0.2.8.3.255', 1, NULL),
	(5, 11, '1.0.3.8.3.255', 1, NULL),
	(5, 12, '1.0.4.8.3.255', 1, NULL),
	(5, 13, '1.0.1.8.4.255', 1, NULL),
	(5, 14, '1.0.2.8.4.255', 1, NULL),
	(5, 15, '1.0.3.8.4.255', 1, NULL),
	(5, 16, '1.0.4.8.4.255', 1, NULL),
	(5, 17, '1.0.1.9.1.255', 1, NULL),
	(5, 18, '1.0.2.9.1.255', 1, NULL),
	(5, 19, '1.0.3.9.1.255', 1, NULL),
	(5, 20, '1.0.4.9.1.255', 1, NULL),
	(5, 21, '1.0.1.9.2.255', 1, NULL),
	(5, 22, '1.0.2.9.2.255', 1, NULL),
	(5, 23, '1.0.3.9.2.255', 1, NULL),
	(5, 24, '1.0.4.9.2.255', 1, NULL),
	(5, 25, '1.0.1.9.3.255', 1, NULL),
	(5, 26, '1.0.2.9.3.255', 1, NULL),
	(5, 27, '1.0.3.9.3.255', 1, NULL),
	(5, 28, '1.0.4.9.3.255', 1, NULL),
	(5, 29, '1.0.1.9.4.255', 1, NULL),
	(5, 30, '1.0.2.9.4.255', 1, NULL),
	(5, 31, '1.0.3.9.4.255', 1, NULL),
	(5, 32, '1.0.4.9.4.255', 1, NULL),
	(5, 49, '1.0.1.5.0.255', 1, NULL),
	(5, 50, '1.0.2.5.0.255', 1, NULL),
	(5, 51, '1.0.3.5.0.255', 1, NULL),
	(5, 52, '1.0.4.5.0.255', 1, NULL),
	(5, 53, '1.0.31.7.0.255', 1, NULL),
	(5, 54, '1.0.32.7.0.255', 1, NULL),
	(5, 55, '1.0.51.7.0.255', 1, NULL),
	(5, 56, '1.0.52.7.0.255', 1, NULL),
	(5, 57, '1.0.71.7.0.255', 1, NULL),
	(5, 58, '1.0.72.7.0.255', 1, NULL),
	(5, 62, '1.0.36.7.0.255', 1, NULL),
	(5, 63, '1.0.56.7.0.255', 1, NULL),
	(5, 64, '1.0.76.7.0.255', 1, NULL),
	(5, 68, '1.0.29.7.0.255', 1, NULL),
	(5, 69, '1.0.49.7.0.255', 1, NULL),
	(5, 70, '1.0.69.7.0.255', 1, NULL),
	(5, 77, '1.0.11.7.0.255', 1, NULL),
	(5, 78, '1.0.12.7.0.255', 1, NULL),
	(5, 80, '1.0.16.7.0.255', 1, NULL),
	(5, 82, '1.0.9.7.0.255', 1, NULL),
	(5, 85, '1.0.14.7.0.255', 1, NULL),
	(5, 377, '1.0.1.5.0.255', 1, NULL),
	(5, 378, '1.0.2.5.0.255', 1, NULL),
	(5, 379, '1.0.3.5.0.255', 1, NULL),
	(5, 380, '1.0.4.5.0.255', 1, NULL),
	(5, 381, '1.0.1.9.0.255', 1, NULL),
	(5, 382, '1.0.2.9.0.255', 1, NULL),
	(5, 383, '1.0.3.9.0.255', 1, NULL),
	(5, 384, '1.0.4.9.0.255', 1, NULL),
	(5, 462, '1.0.1.5.0.255', 1, NULL),
	(5, 463, '1.0.2.5.0.255', 1, NULL),
	(5, 464, '1.0.3.5.0.255', 1, NULL),
	(5, 465, '1.0.4.5.0.255', 1, NULL),
	(5, 559, '1.0.1.5.0.255', 1, NULL),
	(5, 560, '1.0.2.5.0.255', 1, NULL),
	(5, 561, '1.0.3.5.0.255', 1, NULL),
	(5, 562, '1.0.4.5.0.255', 1, NULL),
	(5, 656, '1.0.1.5.0.255', 1, NULL),
	(5, 657, '1.0.2.5.0.255', 1, NULL),
	(5, 658, '1.0.3.5.0.255', 1, NULL),
	(5, 659, '1.0.4.5.0.255', 1, NULL),
	(5, 753, '1.0.1.5.0.255', 1, NULL),
	(5, 754, '1.0.2.5.0.255', 1, NULL),
	(5, 755, '1.0.3.5.0.255', 1, NULL),
	(5, 756, '1.0.4.5.0.255', 1, NULL),
	(5, 850, '1.0.1.5.0.255', 1, NULL),
	(5, 851, '1.0.2.5.0.255', 1, NULL),
	(5, 852, '1.0.3.5.0.255', 1, NULL),
	(5, 853, '1.0.4.5.0.255', 1, NULL),
	(5, 947, '1.0.1.5.0.255', 1, NULL),
	(5, 948, '1.0.2.5.0.255', 1, NULL),
	(5, 949, '1.0.3.5.0.255', 1, NULL),
	(5, 950, '1.0.4.5.0.255', 1, NULL),
	(5, 1044, '1.0.1.5.0.255', 1, NULL),
	(5, 1045, '1.0.2.5.0.255', 1, NULL),
	(5, 1046, '1.0.3.5.0.255', 1, NULL),
	(5, 1047, '1.0.4.5.0.255', 1, NULL),
	(5, 1141, '1.0.1.5.0.255', 1, NULL),
	(5, 1142, '1.0.2.5.0.255', 1, NULL),
	(5, 1143, '1.0.3.5.0.255', 1, NULL),
	(5, 1144, '1.0.4.5.0.255', 1, NULL),
	(5, 1498, '1.0.1.8.0.255', 1, NULL),
	(5, 1499, '1.0.2.8.0.255', 1, NULL),
	(5, 1500, '1.0.3.8.0.255', 1, NULL),
	(5, 1501, '1.0.4.8.0.255', 1, NULL),
	(5, 1765, '1.0.1.8.0.255', 1, NULL),
	(5, 1766, '1.0.1.8.4.255', 1, NULL),
	(5, 1767, '1.0.1.8.3.255', 1, NULL),
	(5, 1768, '1.0.1.8.2.255', 1, NULL),
	(5, 1769, '1.0.1.8.1.255', 1, NULL),
	(5, 1770, '1.0.1.8.0.255', 1, NULL),
	(5, 1771, '1.0.1.8.4.255', 1, NULL),
	(5, 1772, '1.0.1.8.3.255', 1, NULL),
	(5, 1773, '1.0.1.8.2.255', 1, NULL),
	(5, 1774, '1.0.1.8.1.255', 1, NULL),
	(5, 1775, '1.0.1.8.0.255', 1, NULL),
	(5, 1776, '1.0.1.8.4.255', 1, NULL),
	(5, 1777, '1.0.1.8.3.255', 1, NULL),
	(5, 1778, '1.0.1.8.2.255', 1, NULL),
	(5, 1779, '1.0.1.8.1.255', 1, NULL),
	(5, 1780, '1.0.1.8.0.255', 1, NULL),
	(5, 1781, '1.0.1.8.4.255', 1, NULL),
	(5, 1782, '1.0.1.8.3.255', 1, NULL),
	(5, 1783, '1.0.1.8.2.255', 1, NULL),
	(5, 1784, '1.0.1.8.1.255', 1, NULL),
	(5, 1785, '1.0.2.8.0.255', 1, NULL),
	(5, 1786, '1.0.2.8.1.255', 1, NULL),
	(5, 1787, '1.0.2.8.3.255', 1, NULL),
	(5, 1788, '1.0.2.8.2.255', 1, NULL),
	(5, 1789, '1.0.2.8.1.255', 1, NULL),
	(5, 1790, '1.0.2.8.0.255', 1, NULL),
	(5, 1791, '1.0.2.8.4.255', 1, NULL),
	(5, 1792, '1.0.2.8.3.255', 1, NULL),
	(5, 1793, '1.0.2.8.2.255', 1, NULL),
	(5, 1794, '1.0.2.8.1.255', 1, NULL),
	(5, 1795, '1.0.2.8.0.255', 1, NULL),
	(5, 1796, '1.0.2.8.4.255', 1, NULL),
	(5, 1797, '1.0.2.8.3.255', 1, NULL),
	(5, 1798, '1.0.2.8.2.255', 1, NULL),
	(5, 1799, '1.0.2.8.1.255', 1, NULL),
	(5, 1800, '1.0.2.8.0.255', 1, NULL),
	(5, 1801, '1.0.2.8.4.255', 1, NULL),
	(5, 1802, '1.0.2.8.3.255', 1, NULL),
	(5, 1803, '1.0.2.8.2.255', 1, NULL),
	(5, 1804, '1.0.2.8.4.255', 1, NULL),
	(5, 1805, '1.0.3.8.4.255', 1, NULL),
	(5, 1806, '1.0.3.8.0.255', 1, NULL),
	(5, 1807, '1.0.3.8.2.255', 1, NULL),
	(5, 1808, '1.0.3.8.1.255', 1, NULL),
	(5, 1809, '1.0.3.8.0.255', 1, NULL),
	(5, 1810, '1.0.3.8.4.255', 1, NULL),
	(5, 1811, '1.0.3.8.3.255', 1, NULL),
	(5, 1812, '1.0.3.8.2.255', 1, NULL),
	(5, 1813, '1.0.3.8.1.255', 1, NULL),
	(5, 1814, '1.0.3.8.0.255', 1, NULL),
	(5, 1815, '1.0.3.8.4.255', 1, NULL),
	(5, 1816, '1.0.3.8.3.255', 1, NULL),
	(5, 1817, '1.0.3.8.2.255', 1, NULL),
	(5, 1818, '1.0.3.8.1.255', 1, NULL),
	(5, 1819, '1.0.3.8.0.255', 1, NULL),
	(5, 1820, '1.0.3.8.4.255', 1, NULL),
	(5, 1821, '1.0.3.8.3.255', 1, NULL),
	(5, 1822, '1.0.3.8.2.255', 1, NULL),
	(5, 1823, '1.0.3.8.1.255', 1, NULL),
	(5, 1824, '1.0.3.8.3.255', 1, NULL),
	(5, 1825, '1.0.4.8.4.255', 1, NULL),
	(5, 1826, '1.0.4.8.3.255', 1, NULL),
	(5, 1827, '1.0.4.8.2.255', 1, NULL),
	(5, 1828, '1.0.4.8.1.255', 1, NULL),
	(5, 1829, '1.0.4.8.0.255', 1, NULL),
	(5, 1830, '1.0.4.8.4.255', 1, NULL),
	(5, 1831, '1.0.4.8.3.255', 1, NULL),
	(5, 1832, '1.0.4.8.2.255', 1, NULL),
	(5, 1833, '1.0.4.8.1.255', 1, NULL),
	(5, 1834, '1.0.4.8.0.255', 1, NULL),
	(5, 1835, '1.0.4.8.4.255', 1, NULL),
	(5, 1836, '1.0.4.8.3.255', 1, NULL),
	(5, 1837, '1.0.4.8.2.255', 1, NULL),
	(5, 1838, '1.0.4.8.1.255', 1, NULL),
	(5, 1839, '1.0.4.8.0.255', 1, NULL),
	(5, 1840, '1.0.4.8.4.255', 1, NULL),
	(5, 1841, '1.0.4.8.3.255', 1, NULL),
	(5, 1842, '1.0.4.8.2.255', 1, NULL),
	(5, 1843, '1.0.4.8.1.255', 1, NULL),
	(5, 1844, '1.0.4.8.0.255', 1, NULL),
	(5, 2093, '1.0.1.8.4.255', 1, NULL),
	(5, 2094, '1.0.1.8.1.255', 1, NULL),
	(5, 2095, '1.0.1.8.0.255', 1, NULL),
	(5, 2096, '1.0.1.8.4.255', 1, NULL),
	(5, 2097, '1.0.1.8.0.255', 1, NULL),
	(5, 2098, '1.0.1.8.1.255', 1, NULL),
	(5, 2099, '1.0.1.8.3.255', 1, NULL),
	(5, 2100, '1.0.1.8.2.255', 1, NULL),
	(5, 2101, '1.0.1.8.3.255', 1, NULL),
	(5, 2102, '1.0.1.8.2.255', 1, NULL),
	(5, 2103, '1.0.2.8.3.255', 1, NULL),
	(5, 2104, '1.0.2.8.2.255', 1, NULL),
	(5, 2105, '1.0.2.8.1.255', 1, NULL),
	(5, 2106, '1.0.2.8.0.255', 1, NULL),
	(5, 2107, '1.0.2.8.0.255', 1, NULL),
	(5, 2108, '1.0.2.8.4.255', 1, NULL),
	(5, 2109, '1.0.2.8.3.255', 1, NULL),
	(5, 2110, '1.0.2.8.2.255', 1, NULL),
	(5, 2111, '1.0.2.8.1.255', 1, NULL),
	(5, 2112, '1.0.2.8.4.255', 1, NULL),
	(5, 2113, '1.0.3.8.4.255', 1, NULL),
	(5, 2114, '1.0.3.8.0.255', 1, NULL),
	(5, 2115, '1.0.3.8.2.255', 1, NULL),
	(5, 2116, '1.0.3.8.0.255', 1, NULL),
	(5, 2117, '1.0.3.8.2.255', 1, NULL),
	(5, 2118, '1.0.3.8.1.255', 1, NULL),
	(5, 2119, '1.0.3.8.4.255', 1, NULL),
	(5, 2120, '1.0.3.8.3.255', 1, NULL),
	(5, 2121, '1.0.3.8.1.255', 1, NULL),
	(5, 2122, '1.0.3.8.3.255', 1, NULL),
	(5, 2123, '1.0.4.8.4.255', 1, NULL),
	(5, 2124, '1.0.4.8.4.255', 1, NULL),
	(5, 2125, '1.0.4.8.3.255', 1, NULL),
	(5, 2126, '1.0.4.8.1.255', 1, NULL),
	(5, 2127, '1.0.4.8.2.255', 1, NULL),
	(5, 2128, '1.0.4.8.3.255', 1, NULL),
	(5, 2129, '1.0.4.8.0.255', 1, NULL),
	(5, 2130, '1.0.4.8.2.255', 1, NULL),
	(5, 2131, '1.0.4.8.0.255', 1, NULL),
	(5, 2132, '1.0.4.8.1.255', 1, NULL),
	(5, 2303, '1.0.1.6.0.255', 1, NULL),
	(5, 2307, '1.0.1.6.0.255', 1, NULL),
	(5, 3490, '1.0.2.6.0.255', 1, NULL),
	(5, 3492, '1.0.2.6.0.255', 1, NULL),
	(5, 3498, '1.0.3.6.0.255', 1, NULL),
	(5, 3500, '1.0.3.6.0.255', 1, NULL),
	(5, 3506, '1.0.4.6.0.255', 1, NULL),
	(5, 3508, '1.0.4.6.0.255', 1, NULL),
	(5, 3648, '1.0.1.6.1.255', 1, NULL),
	(5, 3649, '1.0.2.6.1.255', 1, NULL),
	(5, 3650, '1.0.3.6.1.255', 1, NULL),
	(5, 3651, '1.0.4.6.1.255', 1, NULL),
	(5, 3652, '1.0.1.6.1.255', 1, NULL),
	(5, 3653, '1.0.2.6.1.255', 1, NULL),
	(5, 3654, '1.0.3.6.1.255', 1, NULL),
	(5, 3655, '1.0.4.6.1.255', 1, NULL),
	(5, 3656, '1.0.1.6.1.255', 1, NULL),
	(5, 3657, '1.0.2.6.1.255', 1, NULL),
	(5, 3658, '1.0.3.6.1.255', 1, NULL),
	(5, 3659, '1.0.4.6.1.255', 1, NULL),
	(5, 3660, '1.0.1.6.1.255', 1, NULL),
	(5, 3661, '1.0.2.6.1.255', 1, NULL),
	(5, 3662, '1.0.3.6.1.255', 1, NULL),
	(5, 3663, '1.0.4.6.1.255', 1, NULL),
	(5, 3664, '1.0.1.6.2.255', 1, NULL),
	(5, 3665, '1.0.2.6.2.255', 1, NULL),
	(5, 3666, '1.0.3.6.2.255', 1, NULL),
	(5, 3667, '1.0.4.6.2.255', 1, NULL),
	(5, 3668, '1.0.1.6.2.255', 1, NULL),
	(5, 3669, '1.0.2.6.2.255', 1, NULL),
	(5, 3670, '1.0.3.6.2.255', 1, NULL),
	(5, 3671, '1.0.4.6.2.255', 1, NULL),
	(5, 3672, '1.0.1.6.2.255', 1, NULL),
	(5, 3673, '1.0.2.6.2.255', 1, NULL),
	(5, 3674, '1.0.3.6.2.255', 1, NULL),
	(5, 3675, '1.0.4.6.2.255', 1, NULL),
	(5, 3676, '1.0.1.6.2.255', 1, NULL),
	(5, 3677, '1.0.2.6.2.255', 1, NULL),
	(5, 3678, '1.0.3.6.2.255', 1, NULL),
	(5, 3679, '1.0.4.6.2.255', 1, NULL),
	(5, 3680, '1.0.1.6.3.255', 1, NULL),
	(5, 3681, '1.0.2.6.3.255', 1, NULL),
	(5, 3682, '1.0.3.6.3.255', 1, NULL),
	(5, 3683, '1.0.4.6.3.255', 1, NULL),
	(5, 3684, '1.0.1.6.3.255', 1, NULL),
	(5, 3685, '1.0.2.6.3.255', 1, NULL),
	(5, 3686, '1.0.3.6.3.255', 1, NULL),
	(5, 3687, '1.0.4.6.3.255', 1, NULL),
	(5, 3688, '1.0.1.6.3.255', 1, NULL),
	(5, 3689, '1.0.2.6.3.255', 1, NULL),
	(5, 3690, '1.0.3.6.3.255', 1, NULL),
	(5, 3691, '1.0.4.6.3.255', 1, NULL),
	(5, 3692, '1.0.1.6.3.255', 1, NULL),
	(5, 3693, '1.0.2.6.3.255', 1, NULL),
	(5, 3694, '1.0.3.6.3.255', 1, NULL),
	(5, 3695, '1.0.4.6.3.255', 1, NULL),
	(5, 3696, '1.0.1.6.4.255', 1, NULL),
	(5, 3697, '1.0.2.6.4.255', 1, NULL),
	(5, 3698, '1.0.3.6.4.255', 1, NULL),
	(5, 3699, '1.0.4.6.4.255', 1, NULL),
	(5, 3700, '1.0.1.6.4.255', 1, NULL),
	(5, 3701, '1.0.2.6.4.255', 1, NULL),
	(5, 3702, '1.0.3.6.4.255', 1, NULL),
	(5, 3703, '1.0.4.6.4.255', 1, NULL),
	(5, 3704, '1.0.1.6.4.255', 1, NULL),
	(5, 3705, '1.0.2.6.4.255', 1, NULL),
	(5, 3706, '1.0.3.6.4.255', 1, NULL),
	(5, 3707, '1.0.4.6.4.255', 1, NULL),
	(5, 3708, '1.0.1.6.4.255', 1, NULL),
	(5, 3709, '1.0.2.6.4.255', 1, NULL),
	(5, 3710, '1.0.3.6.4.255', 1, NULL),
	(5, 3711, '1.0.4.6.4.255', 1, NULL),
	(5, 3996, '1.0.33.7.0.255', 1, NULL),
	(5, 3997, '1.0.53.7.0.255', 1, NULL),
	(5, 3998, '1.0.73.7.0.255', 1, NULL),
	(5, 4000, '1.0.15.5.0.255', 1, NULL),
	(5, 4042, '1.0.15.5.0.255', 1, NULL),
	(5, 4313, '1.0.15.9.0.255', 1, NULL),
	(5, 4322, '1.0.15.9.1.255', 1, NULL),
	(5, 4328, '1.0.15.9.2.255', 1, NULL),
	(5, 4331, '1.0.15.9.3.255', 1, NULL),
	(5, 4337, '1.0.15.9.4.255', 1, NULL),
	(5, 4431, '1.0.15.5.0.255', 1, NULL),
	(5, 4473, '1.0.15.5.0.255', 1, NULL),
	(5, 4490, '1.0.31.7.0.255', 1, NULL),
	(5, 4491, '1.0.31.7.0.255', 1, NULL),
	(5, 4492, '1.0.31.7.0.255', 1, NULL),
	(5, 4493, '1.0.32.7.0.255', 1, NULL),
	(5, 4494, '1.0.32.7.0.255', 1, NULL),
	(5, 4495, '1.0.32.7.0.255', 1, NULL),
	(5, 4496, '1.0.51.7.0.255', 1, NULL),
	(5, 4497, '1.0.51.7.0.255', 1, NULL),
	(5, 4498, '1.0.51.7.0.255', 1, NULL),
	(5, 4499, '1.0.52.7.0.255', 1, NULL),
	(5, 4500, '1.0.52.7.0.255', 1, NULL),
	(5, 4501, '1.0.52.7.0.255', 1, NULL),
	(5, 4502, '1.0.71.7.0.255', 1, NULL),
	(5, 4503, '1.0.71.7.0.255', 1, NULL),
	(5, 4504, '1.0.71.7.0.255', 1, NULL),
	(5, 4505, '1.0.72.7.0.255', 1, NULL),
	(5, 4506, '1.0.72.7.0.255', 1, NULL),
	(5, 4507, '1.0.72.7.0.255', 1, NULL),
	(5, 4517, '1.0.36.7.0.255', 1, NULL),
	(5, 4518, '1.0.36.7.0.255', 1, NULL),
	(5, 4519, '1.0.36.7.0.255', 1, NULL),
	(5, 4520, '1.0.56.7.0.255', 1, NULL),
	(5, 4521, '1.0.56.7.0.255', 1, NULL),
	(5, 4522, '1.0.56.7.0.255', 1, NULL),
	(5, 4523, '1.0.76.7.0.255', 1, NULL),
	(5, 4524, '1.0.76.7.0.255', 1, NULL),
	(5, 4525, '1.0.76.7.0.255', 1, NULL),
	(5, 4535, '1.0.29.7.0.255', 1, NULL),
	(5, 4536, '1.0.29.7.0.255', 1, NULL),
	(5, 4537, '1.0.29.7.0.255', 1, NULL),
	(5, 4538, '1.0.49.7.0.255', 1, NULL),
	(5, 4539, '1.0.49.7.0.255', 1, NULL),
	(5, 4540, '1.0.49.7.0.255', 1, NULL),
	(5, 4541, '1.0.69.7.0.255', 1, NULL),
	(5, 4542, '1.0.69.7.0.255', 1, NULL),
	(5, 4543, '1.0.69.7.0.255', 1, NULL),
	(5, 4562, '1.0.11.7.0.255', 1, NULL),
	(5, 4563, '1.0.11.7.0.255', 1, NULL),
	(5, 4564, '1.0.11.7.0.255', 1, NULL),
	(5, 4565, '1.0.12.7.0.255', 1, NULL),
	(5, 4566, '1.0.12.7.0.255', 1, NULL),
	(5, 4567, '1.0.12.7.0.255', 1, NULL),
	(5, 4571, '1.0.16.7.0.255', 1, NULL),
	(5, 4572, '1.0.16.7.0.255', 1, NULL),
	(5, 4573, '1.0.16.7.0.255', 1, NULL),
	(5, 4577, '1.0.9.7.0.255', 1, NULL),
	(5, 4578, '1.0.9.7.0.255', 1, NULL),
	(5, 4579, '1.0.9.7.0.255', 1, NULL),
	(5, 4586, '1.0.14.7.0.255', 1, NULL),
	(5, 4587, '1.0.14.7.0.255', 1, NULL),
	(5, 4588, '1.0.14.7.0.255', 1, NULL),
	(5, 4904, '1.0.13.7.0.255', 1, NULL),
	(5, 5326, '1.0.32.5.0.255', 1, NULL),
	(5, 5327, '1.0.32.5.0.255', 1, NULL),
	(5, 5328, '1.0.32.5.0.255', 1, NULL),
	(5, 5329, '1.0.32.5.0.255', 1, NULL),
	(5, 5330, '1.0.32.5.0.255', 1, NULL),
	(5, 5331, '1.0.32.5.0.255', 1, NULL),
	(5, 5332, '1.0.32.5.0.255', 1, NULL),
	(5, 5333, '1.0.32.5.0.255', 1, NULL),
	(5, 5334, '1.0.32.5.0.255', 1, NULL),
	(5, 5335, '1.0.32.5.0.255', 1, NULL),
	(5, 5336, '1.0.32.5.0.255', 1, NULL),
	(5, 5337, '1.0.52.5.0.255', 1, NULL),
	(5, 5338, '1.0.52.5.0.255', 1, NULL),
	(5, 5339, '1.0.52.5.0.255', 1, NULL),
	(5, 5340, '1.0.52.5.0.255', 1, NULL),
	(5, 5341, '1.0.52.5.0.255', 1, NULL),
	(5, 5342, '1.0.52.5.0.255', 1, NULL),
	(5, 5343, '1.0.52.5.0.255', 1, NULL),
	(5, 5344, '1.0.52.5.0.255', 1, NULL),
	(5, 5345, '1.0.52.5.0.255', 1, NULL),
	(5, 5346, '1.0.52.5.0.255', 1, NULL),
	(5, 5347, '1.0.52.5.0.255', 1, NULL),
	(5, 5348, '1.0.72.5.0.255', 1, NULL),
	(5, 5349, '1.0.72.5.0.255', 1, NULL),
	(5, 5350, '1.0.72.5.0.255', 1, NULL),
	(5, 5351, '1.0.72.5.0.255', 1, NULL),
	(5, 5352, '1.0.72.5.0.255', 1, NULL),
	(5, 5353, '1.0.72.5.0.255', 1, NULL),
	(5, 5354, '1.0.72.5.0.255', 1, NULL),
	(5, 5355, '1.0.72.5.0.255', 1, NULL),
	(5, 5356, '1.0.72.5.0.255', 1, NULL),
	(5, 5357, '1.0.72.5.0.255', 1, NULL),
	(5, 5358, '1.0.72.5.0.255', 1, NULL),
	(5, 5392, '1.0.12.5.0.255', 1, NULL),
	(5, 5393, '1.0.12.5.0.255', 1, NULL),
	(5, 5394, '1.0.12.5.0.255', 1, NULL),
	(5, 5395, '1.0.12.5.0.255', 1, NULL),
	(5, 5396, '1.0.12.5.0.255', 1, NULL),
	(5, 5397, '1.0.12.5.0.255', 1, NULL),
	(5, 5398, '1.0.12.5.0.255', 1, NULL),
	(5, 5399, '1.0.12.5.0.255', 1, NULL),
	(5, 5400, '1.0.12.5.0.255', 1, NULL),
	(5, 5401, '1.0.12.5.0.255', 1, NULL),
	(5, 5402, '1.0.12.5.0.255', 1, NULL),
	(5, 5969, '1.0.15.8.0.255', 1, NULL),
	(5, 5970, '1.0.15.8.0.255', 1, NULL),
	(5, 5971, '1.0.15.8.0.255', 1, NULL),
	(5, 5972, '1.0.15.8.0.255', 1, NULL),
	(5, 5973, '1.0.15.8.0.255', 1, NULL),
	(5, 5974, '1.0.15.8.0.255', 1, NULL),
	(5, 5975, '1.0.15.8.0.255', 1, NULL),
	(5, 5976, '1.0.15.8.1.255', 1, NULL),
	(5, 5977, '1.0.15.8.1.255', 1, NULL),
	(5, 5978, '1.0.15.8.1.255', 1, NULL),
	(5, 5979, '1.0.15.8.1.255', 1, NULL),
	(5, 5980, '1.0.15.8.1.255', 1, NULL),
	(5, 5981, '1.0.15.8.1.255', 1, NULL),
	(5, 5982, '1.0.15.8.1.255', 1, NULL),
	(5, 5983, '1.0.15.8.2.255', 1, NULL),
	(5, 5984, '1.0.15.8.2.255', 1, NULL),
	(5, 5985, '1.0.15.8.2.255', 1, NULL),
	(5, 5986, '1.0.15.8.2.255', 1, NULL),
	(5, 5987, '1.0.15.8.2.255', 1, NULL),
	(5, 5988, '1.0.15.8.2.255', 1, NULL),
	(5, 5989, '1.0.15.8.2.255', 1, NULL),
	(5, 5990, '1.0.15.8.3.255', 1, NULL),
	(5, 5991, '1.0.15.8.3.255', 1, NULL),
	(5, 5992, '1.0.15.8.3.255', 1, NULL),
	(5, 5993, '1.0.15.8.3.255', 1, NULL),
	(5, 5994, '1.0.15.8.3.255', 1, NULL),
	(5, 5995, '1.0.15.8.3.255', 1, NULL),
	(5, 5996, '1.0.15.8.3.255', 1, NULL),
	(5, 5997, '1.0.15.8.4.255', 1, NULL),
	(5, 5998, '1.0.15.8.4.255', 1, NULL),
	(5, 5999, '1.0.15.8.4.255', 1, NULL),
	(5, 6000, '1.0.15.8.4.255', 1, NULL),
	(5, 6001, '1.0.15.8.4.255', 1, NULL),
	(5, 6002, '1.0.15.8.4.255', 1, NULL),
	(5, 6003, '1.0.15.8.4.255', 1, NULL),
	(5, 6032, '1.0.31.5.0.255', 1, NULL),
	(5, 6033, '1.0.31.5.0.255', 1, NULL),
	(5, 6034, '1.0.31.5.0.255', 1, NULL),
	(5, 6035, '1.0.31.5.0.255', 1, NULL),
	(5, 6036, '1.0.31.5.0.255', 1, NULL),
	(5, 6037, '1.0.31.5.0.255', 1, NULL),
	(5, 6038, '1.0.31.5.0.255', 1, NULL),
	(5, 6039, '1.0.31.5.0.255', 1, NULL),
	(5, 6040, '1.0.31.5.0.255', 1, NULL),
	(5, 6041, '1.0.31.5.0.255', 1, NULL),
	(5, 6042, '1.0.31.5.0.255', 1, NULL),
	(5, 6043, '1.0.51.5.0.255', 1, NULL),
	(5, 6044, '1.0.51.5.0.255', 1, NULL),
	(5, 6045, '1.0.51.5.0.255', 1, NULL),
	(5, 6046, '1.0.51.5.0.255', 1, NULL),
	(5, 6047, '1.0.51.5.0.255', 1, NULL),
	(5, 6048, '1.0.51.5.0.255', 1, NULL),
	(5, 6049, '1.0.51.5.0.255', 1, NULL),
	(5, 6050, '1.0.51.5.0.255', 1, NULL),
	(5, 6051, '1.0.51.5.0.255', 1, NULL),
	(5, 6052, '1.0.51.5.0.255', 1, NULL),
	(5, 6053, '1.0.51.5.0.255', 1, NULL),
	(5, 6054, '1.0.71.5.0.255', 1, NULL),
	(5, 6055, '1.0.71.5.0.255', 1, NULL),
	(5, 6056, '1.0.71.5.0.255', 1, NULL),
	(5, 6057, '1.0.71.5.0.255', 1, NULL),
	(5, 6058, '1.0.71.5.0.255', 1, NULL),
	(5, 6059, '1.0.71.5.0.255', 1, NULL),
	(5, 6060, '1.0.71.5.0.255', 1, NULL),
	(5, 6061, '1.0.71.5.0.255', 1, NULL),
	(5, 6062, '1.0.71.5.0.255', 1, NULL),
	(5, 6063, '1.0.71.5.0.255', 1, NULL),
	(5, 6064, '1.0.71.5.0.255', 1, NULL),
	(5, 6065, '1.0.11.5.0.255', 1, NULL),
	(5, 6066, '1.0.11.5.0.255', 1, NULL),
	(5, 6067, '1.0.11.5.0.255', 1, NULL),
	(5, 6068, '1.0.11.5.0.255', 1, NULL),
	(5, 6069, '1.0.11.5.0.255', 1, NULL),
	(5, 6070, '1.0.11.5.0.255', 1, NULL),
	(5, 6071, '1.0.11.5.0.255', 1, NULL),
	(5, 6072, '1.0.11.5.0.255', 1, NULL),
	(5, 6073, '1.0.11.5.0.255', 1, NULL),
	(5, 6074, '1.0.11.5.0.255', 1, NULL),
	(5, 6075, '1.0.11.5.0.255', 1, NULL),
	(5, 6474, '1.0.3.7.0.255', 1, NULL),
	(5, 6475, '1.0.3.7.0.255', 1, NULL),
	(5, 6476, '1.0.3.7.0.255', 1, NULL),
	(5, 6477, '1.0.3.7.0.255', 1, NULL),
	(5, 6478, '1.0.4.7.0.255', 1, NULL),
	(5, 6479, '1.0.4.7.0.255', 1, NULL),
	(5, 6480, '1.0.4.7.0.255', 1, NULL),
	(5, 6481, '1.0.4.7.0.255', 1, NULL),
	(5, 6494, '1.0.23.7.0.255', 1, NULL),
	(5, 6495, '1.0.23.7.0.255', 1, NULL),
	(5, 6496, '1.0.23.7.0.255', 1, NULL),
	(5, 6497, '1.0.23.7.0.255', 1, NULL),
	(5, 6498, '1.0.43.7.0.255', 1, NULL),
	(5, 6499, '1.0.43.7.0.255', 1, NULL),
	(5, 6500, '1.0.43.7.0.255', 1, NULL),
	(5, 6501, '1.0.43.7.0.255', 1, NULL),
	(5, 6502, '1.0.63.7.0.255', 1, NULL),
	(5, 6503, '1.0.63.7.0.255', 1, NULL),
	(5, 6504, '1.0.63.7.0.255', 1, NULL),
	(5, 6505, '1.0.63.7.0.255', 1, NULL),
	(5, 6518, '1.0.24.7.0.255', 1, NULL),
	(5, 6519, '1.0.24.7.0.255', 1, NULL),
	(5, 6520, '1.0.24.7.0.255', 1, NULL),
	(5, 6521, '1.0.24.7.0.255', 1, NULL),
	(5, 6522, '1.0.44.7.0.255', 1, NULL),
	(5, 6523, '1.0.44.7.0.255', 1, NULL),
	(5, 6524, '1.0.44.7.0.255', 1, NULL),
	(5, 6525, '1.0.44.7.0.255', 1, NULL),
	(5, 6526, '1.0.64.7.0.255', 1, NULL),
	(5, 6527, '1.0.64.7.0.255', 1, NULL),
	(5, 6528, '1.0.64.7.0.255', 1, NULL),
	(5, 6529, '1.0.64.7.0.255', 1, NULL),
	(5, 6642, '1.0.15.7.0.255', 1, NULL),
	(5, 6655, '1.0.1.8.4.255', 1, NULL),
	(5, 6656, '1.0.1.8.0.255', 1, NULL),
	(5, 6657, '1.0.1.8.3.255', 1, NULL),
	(5, 6658, '1.0.1.8.2.255', 1, NULL),
	(5, 6659, '1.0.1.8.1.255', 1, NULL),
	(5, 6660, '1.0.2.8.0.255', 1, NULL),
	(5, 6661, '1.0.2.8.4.255', 1, NULL),
	(5, 6662, '1.0.2.8.3.255', 1, NULL),
	(5, 6663, '1.0.2.8.2.255', 1, NULL),
	(5, 6664, '1.0.2.8.1.255', 1, NULL),
	(5, 6673, '1.0.1.6.1.255', 1, NULL),
	(5, 6674, '1.0.2.6.1.255', 1, NULL),
	(5, 6675, '1.0.1.6.2.255', 1, NULL),
	(5, 6676, '1.0.2.6.2.255', 1, NULL),
	(5, 6677, '1.0.1.6.3.255', 1, NULL),
	(5, 6678, '1.0.2.6.3.255', 1, NULL),
	(5, 6679, '1.0.1.6.4.255', 1, NULL),
	(5, 6680, '1.0.2.6.4.255', 1, NULL),
	(5, 6699, '1.0.15.8.0.255', 1, NULL),
	(5, 6700, '1.0.15.8.1.255', 1, NULL),
	(5, 6701, '1.0.15.8.2.255', 1, NULL),
	(5, 6702, '1.0.15.8.3.255', 1, NULL),
	(5, 6703, '1.0.15.8.4.255', 1, NULL),
	(5, 6710, '1.0.3.8.0.255', 1, NULL),
	(5, 6711, '1.0.3.8.4.255', 1, NULL),
	(5, 6712, '1.0.3.8.3.255', 1, NULL),
	(5, 6713, '1.0.3.8.2.255', 1, NULL),
	(5, 6714, '1.0.3.8.1.255', 1, NULL),
	(5, 6715, '1.0.4.8.0.255', 1, NULL),
	(5, 6716, '1.0.4.8.4.255', 1, NULL),
	(5, 6717, '1.0.4.8.3.255', 1, NULL),
	(5, 6718, '1.0.4.8.2.255', 1, NULL),
	(5, 6719, '1.0.4.8.1.255', 1, NULL),
	(5, 6764, '1.0.3.6.1.255', 1, NULL),
	(5, 6765, '1.0.4.6.1.255', 1, NULL),
	(5, 6766, '1.0.3.6.2.255', 1, NULL),
	(5, 6767, '1.0.4.6.2.255', 1, NULL),
	(5, 6768, '1.0.3.6.3.255', 1, NULL),
	(5, 6769, '1.0.4.6.3.255', 1, NULL),
	(5, 6770, '1.0.3.6.4.255', 1, NULL),
	(5, 6771, '1.0.4.6.4.255', 1, NULL),
	(5, 7169, '1.0.15.6.0.255', 1, NULL),
	(5, 7170, '1.0.15.6.1.255', 1, NULL),
	(5, 7171, '1.0.15.6.2.255', 1, NULL),
	(5, 7172, '1.0.15.6.3.255', 1, NULL),
	(5, 7173, '1.0.15.6.4.255', 1, NULL),
	(5, 7174, '1.0.15.6.0.255', 1, NULL),
	(5, 7175, '1.0.15.6.1.255', 1, NULL),
	(5, 7176, '1.0.15.6.2.255', 1, NULL),
	(5, 7177, '1.0.15.6.3.255', 1, NULL),
	(5, 7178, '1.0.15.6.4.255', 1, NULL),
	(5, 7214, '1.0.36.7.0.255', 1, NULL),
	(5, 7215, '1.0.36.7.0.255', 1, NULL),
	(5, 7216, '1.0.36.7.0.255', 1, NULL),
	(5, 7217, '1.0.36.7.0.255', 1, NULL),
	(5, 7218, '1.0.56.7.0.255', 1, NULL),
	(5, 7219, '1.0.56.7.0.255', 1, NULL),
	(5, 7220, '1.0.56.7.0.255', 1, NULL),
	(5, 7221, '1.0.56.7.0.255', 1, NULL),
	(5, 7222, '1.0.76.7.0.255', 1, NULL),
	(5, 7223, '1.0.76.7.0.255', 1, NULL),
	(5, 7224, '1.0.76.7.0.255', 1, NULL),
	(5, 7225, '1.0.76.7.0.255', 1, NULL),
	(5, 7226, '1.0.16.7.0.255', 1, NULL),
	(5, 7227, '1.0.16.7.0.255', 1, NULL),
	(5, 7228, '1.0.16.7.0.255', 1, NULL),
	(5, 7229, '1.0.16.7.0.255', 1, NULL),
	(5, 7246, '1.0.12.7.0.255', 1, NULL),
	(5, 7247, '1.0.12.7.0.255', 1, NULL),
	(5, 7248, '1.0.12.7.0.255', 1, NULL),
	(5, 7249, '1.0.12.7.0.255', 1, NULL),
	(5, 7250, '1.0.32.7.0.255', 1, NULL),
	(5, 7251, '1.0.32.7.0.255', 1, NULL),
	(5, 7252, '1.0.32.7.0.255', 1, NULL),
	(5, 7253, '1.0.32.7.0.255', 1, NULL),
	(5, 7254, '1.0.52.7.0.255', 1, NULL),
	(5, 7255, '1.0.52.7.0.255', 1, NULL),
	(5, 7256, '1.0.52.7.0.255', 1, NULL),
	(5, 7257, '1.0.52.7.0.255', 1, NULL),
	(5, 7258, '1.0.72.7.0.255', 1, NULL),
	(5, 7259, '1.0.72.7.0.255', 1, NULL),
	(5, 7260, '1.0.72.7.0.255', 1, NULL),
	(5, 7261, '1.0.72.7.0.255', 1, NULL),
	(5, 7262, '1.0.14.7.0.255', 1, NULL),
	(5, 7263, '1.0.14.7.0.255', 1, NULL),
	(5, 7264, '1.0.14.7.0.255', 1, NULL),
	(5, 7265, '1.0.14.7.0.255', 1, NULL),
	(5, 7278, '1.0.29.7.0.255', 1, NULL),
	(5, 7279, '1.0.29.7.0.255', 1, NULL),
	(5, 7280, '1.0.29.7.0.255', 1, NULL),
	(5, 7281, '1.0.29.7.0.255', 1, NULL),
	(5, 7282, '1.0.49.7.0.255', 1, NULL),
	(5, 7283, '1.0.49.7.0.255', 1, NULL),
	(5, 7284, '1.0.49.7.0.255', 1, NULL),
	(5, 7285, '1.0.49.7.0.255', 1, NULL),
	(5, 7286, '1.0.69.7.0.255', 1, NULL),
	(5, 7287, '1.0.69.7.0.255', 1, NULL),
	(5, 7288, '1.0.69.7.0.255', 1, NULL),
	(5, 7289, '1.0.69.7.0.255', 1, NULL),
	(5, 7290, '1.0.9.7.0.255', 1, NULL),
	(5, 7291, '1.0.9.7.0.255', 1, NULL),
	(5, 7292, '1.0.9.7.0.255', 1, NULL),
	(5, 7293, '1.0.9.7.0.255', 1, NULL),
	(5, 7294, '1.0.31.7.0.255', 1, NULL),
	(5, 7295, '1.0.31.7.0.255', 1, NULL),
	(5, 7296, '1.0.31.7.0.255', 1, NULL),
	(5, 7297, '1.0.31.7.0.255', 1, NULL),
	(5, 7298, '1.0.51.7.0.255', 1, NULL),
	(5, 7299, '1.0.51.7.0.255', 1, NULL),
	(5, 7300, '1.0.51.7.0.255', 1, NULL),
	(5, 7301, '1.0.51.7.0.255', 1, NULL),
	(5, 7302, '1.0.71.7.0.255', 1, NULL),
	(5, 7303, '1.0.71.7.0.255', 1, NULL),
	(5, 7304, '1.0.71.7.0.255', 1, NULL),
	(5, 7305, '1.0.71.7.0.255', 1, NULL),
	(5, 7330, '1.0.15.7.0.255', 1, NULL),
	(5, 7331, '1.0.15.7.0.255', 1, NULL),
	(5, 7332, '1.0.15.7.0.255', 1, NULL),
	(5, 7333, '1.0.15.7.0.255', 1, NULL),
	(5, 7334, '1.0.15.7.0.255', 1, NULL),
	(5, 7335, '1.0.3.7.0.255', 1, NULL),
	(5, 7336, '1.0.3.7.0.255', 1, NULL),
	(5, 7337, '1.0.3.7.0.255', 1, NULL),
	(5, 7338, '1.0.3.7.0.255', 1, NULL),
	(5, 7339, '1.0.3.7.0.255', 1, NULL),
	(5, 7340, '1.0.4.7.0.255', 1, NULL),
	(5, 7341, '1.0.4.7.0.255', 1, NULL),
	(5, 7342, '1.0.4.7.0.255', 1, NULL),
	(5, 7343, '1.0.4.7.0.255', 1, NULL),
	(5, 7344, '1.0.4.7.0.255', 1, NULL),
	(5, 7360, '1.0.31.7.0.255', 1, NULL),
	(5, 7361, '1.0.32.7.0.255', 1, NULL),
	(5, 7362, '1.0.51.7.0.255', 1, NULL),
	(5, 7363, '1.0.52.7.0.255', 1, NULL),
	(5, 7364, '1.0.71.7.0.255', 1, NULL),
	(5, 7365, '1.0.72.7.0.255', 1, NULL),
	(5, 7577, '1.0.16.7.0.255', 1, NULL),
	(5, 7578, '1.0.16.7.0.255', 1, NULL),
	(5, 7579, '1.0.16.7.0.255', 1, NULL),
	(5, 7583, '1.0.3.7.0.255', 1, NULL),
	(5, 7584, '1.0.3.7.0.255', 1, NULL),
	(5, 7585, '1.0.4.7.0.255', 1, NULL),
	(5, 7586, '1.0.4.7.0.255', 1, NULL),
	(5, 7587, '1.0.31.7.0.255', 1, NULL),
	(5, 7588, '1.0.31.7.0.255', 1, NULL),
	(5, 7589, '1.0.32.7.0.255', 1, NULL),
	(5, 7590, '1.0.32.7.0.255', 1, NULL),
	(5, 7591, '1.0.51.7.0.255', 1, NULL),
	(5, 7592, '1.0.51.7.0.255', 1, NULL),
	(5, 7593, '1.0.52.7.0.255', 1, NULL),
	(5, 7594, '1.0.52.7.0.255', 1, NULL),
	(5, 7595, '1.0.71.7.0.255', 1, NULL),
	(5, 7596, '1.0.71.7.0.255', 1, NULL),
	(5, 7597, '1.0.72.7.0.255', 1, NULL),
	(5, 7598, '1.0.72.7.0.255', 1, NULL),
	(5, 7620, '1.0.36.7.0.255', 1, NULL),
	(5, 7621, '1.0.36.7.0.255', 1, NULL),
	(5, 7622, '1.0.36.7.0.255', 1, NULL),
	(5, 7632, '1.0.56.7.0.255', 1, NULL),
	(5, 7633, '1.0.56.7.0.255', 1, NULL),
	(5, 7634, '1.0.56.7.0.255', 1, NULL),
	(5, 7644, '1.0.76.7.0.255', 1, NULL),
	(5, 7645, '1.0.76.7.0.255', 1, NULL),
	(5, 7646, '1.0.76.7.0.255', 1, NULL),
	(5, 7658, '1.0.23.7.0.255', 1, NULL),
	(5, 7659, '1.0.23.7.0.255', 1, NULL),
	(5, 7660, '1.0.23.7.0.255', 1, NULL),
	(5, 7661, '1.0.23.7.0.255', 1, NULL),
	(5, 7662, '1.0.23.7.0.255', 1, NULL),
	(5, 7663, '1.0.23.7.0.255', 1, NULL),
	(5, 7664, '1.0.23.7.0.255', 1, NULL),
	(5, 7665, '1.0.24.7.0.255', 1, NULL),
	(5, 7666, '1.0.24.7.0.255', 1, NULL),
	(5, 7667, '1.0.24.7.0.255', 1, NULL),
	(5, 7668, '1.0.24.7.0.255', 1, NULL),
	(5, 7669, '1.0.24.7.0.255', 1, NULL),
	(5, 7670, '1.0.24.7.0.255', 1, NULL),
	(5, 7671, '1.0.24.7.0.255', 1, NULL),
	(5, 7674, '1.0.43.7.0.255', 1, NULL),
	(5, 7675, '1.0.43.7.0.255', 1, NULL),
	(5, 7676, '1.0.43.7.0.255', 1, NULL),
	(5, 7677, '1.0.43.7.0.255', 1, NULL),
	(5, 7678, '1.0.43.7.0.255', 1, NULL),
	(5, 7679, '1.0.43.7.0.255', 1, NULL),
	(5, 7680, '1.0.43.7.0.255', 1, NULL),
	(5, 7681, '1.0.44.7.0.255', 1, NULL),
	(5, 7682, '1.0.44.7.0.255', 1, NULL),
	(5, 7683, '1.0.44.7.0.255', 1, NULL),
	(5, 7684, '1.0.44.7.0.255', 1, NULL),
	(5, 7685, '1.0.44.7.0.255', 1, NULL),
	(5, 7686, '1.0.44.7.0.255', 1, NULL),
	(5, 7687, '1.0.44.7.0.255', 1, NULL),
	(5, 7690, '1.0.63.7.0.255', 1, NULL),
	(5, 7691, '1.0.63.7.0.255', 1, NULL),
	(5, 7692, '1.0.63.7.0.255', 1, NULL),
	(5, 7693, '1.0.63.7.0.255', 1, NULL),
	(5, 7694, '1.0.63.7.0.255', 1, NULL),
	(5, 7695, '1.0.63.7.0.255', 1, NULL),
	(5, 7696, '1.0.63.7.0.255', 1, NULL),
	(5, 7697, '1.0.64.7.0.255', 1, NULL),
	(5, 7698, '1.0.64.7.0.255', 1, NULL),
	(5, 7699, '1.0.64.7.0.255', 1, NULL),
	(5, 7700, '1.0.64.7.0.255', 1, NULL),
	(5, 7701, '1.0.64.7.0.255', 1, NULL),
	(5, 7702, '1.0.64.7.0.255', 1, NULL),
	(5, 7703, '1.0.64.7.0.255', 1, NULL),
	(5, 7704, '1.0.29.7.0.255', 1, NULL),
	(5, 7705, '1.0.29.7.0.255', 1, NULL),
	(5, 7706, '1.0.29.7.0.255', 1, NULL),
	(5, 7721, '1.0.49.7.0.255', 1, NULL),
	(5, 7722, '1.0.49.7.0.255', 1, NULL),
	(5, 7723, '1.0.49.7.0.255', 1, NULL),
	(5, 7738, '1.0.69.7.0.255', 1, NULL),
	(5, 7739, '1.0.69.7.0.255', 1, NULL),
	(5, 7740, '1.0.69.7.0.255', 1, NULL),
	(5, 7797, '1.0.11.7.0.255', 1, NULL),
	(5, 7798, '1.0.11.7.0.255', 1, NULL),
	(5, 7799, '1.0.11.7.0.255', 1, NULL),
	(5, 7800, '1.0.11.7.0.255', 1, NULL),
	(5, 7801, '1.0.11.7.0.255', 1, NULL),
	(5, 7802, '1.0.11.7.0.255', 1, NULL),
	(5, 7803, '1.0.11.7.0.255', 1, NULL),
	(5, 7804, '1.0.12.7.0.255', 1, NULL),
	(5, 7805, '1.0.12.7.0.255', 1, NULL),
	(5, 7806, '1.0.12.7.0.255', 1, NULL),
	(5, 7814, '1.0.9.7.0.255', 1, NULL),
	(5, 7815, '1.0.9.7.0.255', 1, NULL),
	(5, 7816, '1.0.9.7.0.255', 1, NULL),
	(5, 7831, '1.0.14.7.0.255', 1, NULL),
	(5, 7832, '1.0.14.7.0.255', 1, NULL),
	(5, 7833, '1.0.14.7.0.255', 1, NULL),
	(5, 7886, '1.0.15.7.0.255', 1, NULL),
	(5, 7887, '1.0.15.7.0.255', 1, NULL),
	(5, 7888, '1.0.15.7.0.255', 1, NULL),
	(5, 7889, '1.0.15.7.0.255', 1, NULL),
	(5, 9079, '1.0.1.6.0.255', 1, NULL),
	(5, 9080, '1.0.2.6.0.255', 1, NULL),
	(5, 9081, '1.0.3.6.0.255', 1, NULL),
	(5, 9082, '1.0.4.6.0.255', 1, NULL),
	(6, 1, 'ABCDEFGZ', 1, NULL),
	(6, 2, 'BCDG', 1, NULL),
	(6, 3, 'DEFZ', 1, NULL),
	(6, 4, 'DEFZ', 1, NULL),
	(6, 5, 'ABCDEFGZ', 1, NULL),
	(6, 6, 'BCDG', 1, NULL),
	(6, 7, 'DEFZ', 1, NULL),
	(6, 8, 'DEFZ', 1, NULL),
	(6, 9, 'ABCDEFGZ', 1, NULL),
	(6, 10, 'BCDG', 1, NULL),
	(6, 11, 'DEFZ', 1, NULL),
	(6, 12, 'DEFZ', 1, NULL),
	(6, 13, 'ABCDEFGZ', 1, NULL),
	(6, 14, 'BCDG', 1, NULL),
	(6, 15, 'DEFZ', 1, NULL),
	(6, 16, 'DEFZ', 1, NULL),
	(6, 17, 'ABCDEFGZ', 1, NULL),
	(6, 18, 'BCDG', 1, NULL),
	(6, 19, 'DEFZ', 1, NULL),
	(6, 20, 'DEFZ', 1, NULL),
	(6, 21, 'ABCDEFGZ', 1, NULL),
	(6, 22, 'BCDG', 1, NULL),
	(6, 23, 'DEFZ', 1, NULL),
	(6, 24, 'DEFZ', 1, NULL),
	(6, 25, 'ABCDEFGZ', 1, NULL),
	(6, 26, 'BCDG', 1, NULL),
	(6, 27, 'DEFZ', 1, NULL),
	(6, 28, 'DEFZ', 1, NULL),
	(6, 29, 'ABCDEFGZ', 1, NULL),
	(6, 30, 'BCDG', 1, NULL),
	(6, 31, 'DEFZ', 1, NULL),
	(6, 32, 'DEFZ', 1, NULL),
	(6, 49, 'ABCDEFGZ', 1, NULL),
	(6, 50, 'BCDG', 1, NULL),
	(6, 51, 'DEFZ', 1, NULL),
	(6, 52, 'DEFZ', 1, NULL),
	(6, 53, 'CE', 1, NULL),
	(6, 54, 'CE', 1, NULL),
	(6, 55, 'CE', 1, NULL),
	(6, 56, 'CE', 1, NULL),
	(6, 57, 'CE', 1, NULL),
	(6, 58, 'CE', 1, NULL),
	(6, 62, 'CEFG', 1, NULL),
	(6, 63, 'CEFG', 1, NULL),
	(6, 64, 'CEFG', 1, NULL),
	(6, 65, 'EF', 1, NULL),
	(6, 66, 'EF', 1, NULL),
	(6, 67, 'EF', 1, NULL),
	(6, 71, 'EF', 1, NULL),
	(6, 72, 'EF', 1, NULL),
	(6, 73, 'EF', 1, NULL),
	(6, 77, 'E', 1, NULL),
	(6, 79, 'E', 1, NULL),
	(6, 80, 'CEFG', 1, NULL),
	(6, 81, 'EF', 1, NULL),
	(6, 83, 'EF', 1, NULL),
	(6, 85, 'E', 1, NULL),
	(6, 377, 'ABCDEFGZ', 1, NULL),
	(6, 378, 'BCDG', 1, NULL),
	(6, 379, 'DEFZ', 1, NULL),
	(6, 380, 'DEFZ', 1, NULL),
	(6, 1044, 'ABCDEFGZ', 1, NULL),
	(6, 1045, 'BCDG', 1, NULL),
	(6, 1046, 'DEFZ', 1, NULL),
	(6, 1047, 'DEFZ', 1, NULL),
	(6, 3648, 'ABCDEFGZ', 1, NULL),
	(6, 3649, 'BCDG', 1, NULL),
	(6, 3650, 'DEFZ', 1, NULL),
	(6, 3651, 'DEFZ', 1, NULL),
	(6, 3652, 'ABCDEFGZ', 1, NULL),
	(6, 3653, 'BCDG', 1, NULL),
	(6, 3654, 'DEFZ', 1, NULL),
	(6, 3655, 'DEFZ', 1, NULL),
	(6, 3660, 'ABCDEFGZ', 1, NULL),
	(6, 3661, 'BCDG', 1, NULL),
	(6, 3662, 'DEFZ', 1, NULL),
	(6, 3663, 'DEFZ', 1, NULL),
	(6, 3664, 'ABCDEFGZ', 1, NULL),
	(6, 3665, 'BCDG', 1, NULL),
	(6, 3666, 'DEFZ', 1, NULL),
	(6, 3667, 'DEFZ', 1, NULL),
	(6, 3668, 'ABCDEFGZ', 1, NULL),
	(6, 3669, 'BCDG', 1, NULL),
	(6, 3670, 'DEFZ', 1, NULL),
	(6, 3671, 'DEFZ', 1, NULL),
	(6, 3676, 'ABCDEFGZ', 1, NULL),
	(6, 3677, 'BCDG', 1, NULL),
	(6, 3678, 'DEFZ', 1, NULL),
	(6, 3679, 'DEFZ', 1, NULL),
	(6, 3680, 'ABCDEFGZ', 1, NULL),
	(6, 3681, 'BCDG', 1, NULL),
	(6, 3682, 'DEFZ', 1, NULL),
	(6, 3683, 'DEFZ', 1, NULL),
	(6, 3684, 'ABCDEFGZ', 1, NULL),
	(6, 3685, 'BCDG', 1, NULL),
	(6, 3686, 'DEFZ', 1, NULL),
	(6, 3687, 'DEFZ', 1, NULL),
	(6, 3692, 'ABCDEFGZ', 1, NULL),
	(6, 3693, 'BCDG', 1, NULL),
	(6, 3694, 'DEFZ', 1, NULL),
	(6, 3695, 'DEFZ', 1, NULL),
	(6, 3696, 'ABCDEFGZ', 1, NULL),
	(6, 3697, 'BCDG', 1, NULL),
	(6, 3698, 'DEFZ', 1, NULL),
	(6, 3699, 'DEFZ', 1, NULL),
	(6, 3700, 'ABCDEFGZ', 1, NULL),
	(6, 3701, 'BCDG', 1, NULL),
	(6, 3702, 'DEFZ', 1, NULL),
	(6, 3703, 'DEFZ', 1, NULL),
	(6, 3708, 'ABCDEFGZ', 1, NULL),
	(6, 3709, 'BCDG', 1, NULL),
	(6, 3710, 'DEFZ', 1, NULL),
	(6, 3711, 'DEFZ', 1, NULL),
	(6, 3712, 'ABCDEFGZ', 1, NULL),
	(6, 3713, 'BCDG', 1, NULL),
	(6, 3714, 'DEFZ', 1, NULL),
	(6, 3715, 'DEFZ', 1, NULL),
	(6, 3716, 'ABCDEFGZ', 1, NULL),
	(6, 3717, 'BCDG', 1, NULL),
	(6, 3718, 'DEFZ', 1, NULL),
	(6, 3719, 'DEFZ', 1, NULL),
	(6, 3724, 'ABCDEFGZ', 1, NULL),
	(6, 3725, 'BCDG', 1, NULL),
	(6, 3726, 'DEFZ', 1, NULL),
	(6, 3727, 'DEFZ', 1, NULL),
	(6, 3728, 'ABCDEFGZ', 1, NULL),
	(6, 3729, 'BCDG', 1, NULL),
	(6, 3730, 'DEFZ', 1, NULL),
	(6, 3731, 'DEFZ', 1, NULL),
	(6, 3732, 'ABCDEFGZ', 1, NULL),
	(6, 3733, 'BCDG', 1, NULL),
	(6, 3734, 'DEFZ', 1, NULL),
	(6, 3735, 'DEFZ', 1, NULL),
	(6, 3740, 'ABCDEFGZ', 1, NULL),
	(6, 3741, 'BCDG', 1, NULL),
	(6, 3742, 'DEFZ', 1, NULL),
	(6, 3743, 'DEFZ', 1, NULL),
	(6, 3744, 'ABCDEFGZ', 1, NULL),
	(6, 3745, 'BCDG', 1, NULL),
	(6, 3746, 'DEFZ', 1, NULL),
	(6, 3747, 'DEFZ', 1, NULL),
	(6, 3748, 'ABCDEFGZ', 1, NULL),
	(6, 3749, 'BCDG', 1, NULL),
	(6, 3750, 'DEFZ', 1, NULL),
	(6, 3751, 'DEFZ', 1, NULL),
	(6, 3756, 'ABCDEFGZ', 1, NULL),
	(6, 3757, 'BCDG', 1, NULL),
	(6, 3758, 'DEFZ', 1, NULL),
	(6, 3759, 'DEFZ', 1, NULL),
	(6, 3760, 'ABCDEFGZ', 1, NULL),
	(6, 3761, 'BCDG', 1, NULL),
	(6, 3762, 'DEFZ', 1, NULL),
	(6, 3763, 'DEFZ', 1, NULL),
	(6, 3764, 'ABCDEFGZ', 1, NULL),
	(6, 3765, 'BCDG', 1, NULL),
	(6, 3766, 'DEFZ', 1, NULL),
	(6, 3767, 'DEFZ', 1, NULL),
	(6, 3772, 'ABCDEFGZ', 1, NULL),
	(6, 3773, 'BCDG', 1, NULL),
	(6, 3774, 'DEFZ', 1, NULL),
	(6, 3775, 'DEFZ', 1, NULL),
	(7, 1, '1', 1, NULL),
	(7, 2, '2', 1, NULL),
	(7, 3, '3', 1, NULL),
	(7, 4, '4', 1, NULL),
	(7, 5, '5', 1, NULL),
	(7, 6, '6', 1, NULL),
	(7, 7, '7', 1, NULL),
	(7, 8, '8', 1, NULL),
	(7, 9, '9', 1, NULL),
	(7, 10, '10', 1, NULL),
	(7, 11, '11', 1, NULL),
	(7, 12, '12', 1, NULL),
	(7, 13, '13', 1, NULL),
	(7, 14, '14', 1, NULL),
	(7, 15, '15', 1, NULL),
	(7, 16, '16', 1, NULL),
	(7, 17, '17', 1, NULL),
	(7, 18, '18', 1, NULL),
	(7, 19, '19', 1, NULL),
	(7, 20, '20', 1, NULL),
	(7, 21, '21', 1, NULL),
	(7, 22, '22', 1, NULL),
	(7, 23, '23', 1, NULL),
	(7, 24, '24', 1, NULL),
	(7, 25, '25', 1, NULL),
	(7, 26, '26', 1, NULL),
	(7, 27, '27', 1, NULL),
	(7, 28, '28', 1, NULL),
	(7, 29, '29', 1, NULL),
	(7, 30, '30', 1, NULL),
	(7, 31, '31', 1, NULL),
	(7, 32, '32', 1, NULL),
	(7, 33, '33', 1, NULL),
	(7, 34, '34', 1, NULL),
	(7, 35, '35', 1, NULL),
	(7, 36, '36', 1, NULL),
	(7, 37, '37', 1, NULL),
	(7, 38, '38', 1, NULL),
	(7, 39, '39', 1, NULL),
	(7, 40, '40', 1, NULL),
	(7, 41, '41', 1, NULL),
	(7, 42, '42', 1, NULL),
	(7, 43, '43', 1, NULL),
	(7, 44, '44', 1, NULL),
	(7, 45, '45', 1, NULL),
	(7, 46, '46', 1, NULL),
	(7, 47, '47', 1, NULL),
	(7, 48, '48', 1, NULL),
	(7, 49, '49', 1, NULL),
	(7, 50, '50', 1, NULL),
	(7, 51, '51', 1, NULL),
	(7, 52, '52', 1, NULL),
	(7, 53, '53', 1, NULL),
	(7, 54, '54', 1, NULL),
	(7, 55, '55', 1, NULL),
	(7, 56, '56', 1, NULL),
	(7, 57, '57', 1, NULL),
	(7, 58, '58', 1, NULL),
	(7, 62, '62', 1, NULL),
	(7, 63, '63', 1, NULL),
	(7, 64, '64', 1, NULL),
	(7, 65, '65', 1, NULL),
	(7, 66, '66', 1, NULL),
	(7, 67, '67', 1, NULL),
	(7, 71, '71', 1, NULL),
	(7, 72, '72', 1, NULL),
	(7, 73, '73', 1, NULL),
	(7, 77, '77', 1, NULL),
	(7, 79, '79', 1, NULL),
	(7, 80, '80', 1, NULL),
	(7, 81, '81', 1, NULL),
	(7, 83, '83', 1, NULL),
	(7, 84, '84', 1, NULL),
	(7, 85, '85', 1, NULL),
	(7, 377, '49', 1, NULL),
	(7, 378, '50', 1, NULL),
	(7, 379, '51', 1, NULL),
	(7, 380, '52', 1, NULL),
	(7, 1044, '49', 1, NULL),
	(7, 1045, '50', 1, NULL),
	(7, 1046, '51', 1, NULL),
	(7, 1047, '52', 1, NULL),
	(7, 3648, '358', 1, NULL),
	(7, 3649, '359', 1, NULL),
	(7, 3650, '360', 1, NULL),
	(7, 3651, '361', 1, NULL),
	(7, 3652, '358', 1, NULL),
	(7, 3653, '359', 1, NULL),
	(7, 3654, '360', 1, NULL),
	(7, 3655, '361', 1, NULL),
	(7, 3660, '358', 1, NULL),
	(7, 3661, '359', 1, NULL),
	(7, 3662, '360', 1, NULL),
	(7, 3663, '361', 1, NULL),
	(7, 3664, '362', 1, NULL),
	(7, 3665, '363', 1, NULL),
	(7, 3666, '364', 1, NULL),
	(7, 3667, '365', 1, NULL),
	(7, 3668, '362', 1, NULL),
	(7, 3669, '363', 1, NULL),
	(7, 3670, '364', 1, NULL),
	(7, 3671, '365', 1, NULL),
	(7, 3676, '362', 1, NULL),
	(7, 3677, '363', 1, NULL),
	(7, 3678, '364', 1, NULL),
	(7, 3679, '365', 1, NULL),
	(7, 3680, '366', 1, NULL),
	(7, 3681, '367', 1, NULL),
	(7, 3682, '368', 1, NULL),
	(7, 3683, '369', 1, NULL),
	(7, 3684, '366', 1, NULL),
	(7, 3685, '367', 1, NULL),
	(7, 3686, '368', 1, NULL),
	(7, 3687, '369', 1, NULL),
	(7, 3692, '366', 1, NULL),
	(7, 3693, '367', 1, NULL),
	(7, 3694, '368', 1, NULL),
	(7, 3695, '369', 1, NULL),
	(7, 3696, '370', 1, NULL),
	(7, 3697, '371', 1, NULL),
	(7, 3698, '372', 1, NULL),
	(7, 3699, '373', 1, NULL),
	(7, 3700, '370', 1, NULL),
	(7, 3701, '371', 1, NULL),
	(7, 3702, '372', 1, NULL),
	(7, 3703, '373', 1, NULL),
	(7, 3708, '370', 1, NULL),
	(7, 3709, '371', 1, NULL),
	(7, 3710, '372', 1, NULL),
	(7, 3711, '373', 1, NULL),
	(7, 3712, '378', 1, NULL),
	(7, 3713, '379', 1, NULL),
	(7, 3714, '380', 1, NULL),
	(7, 3715, '381', 1, NULL),
	(7, 3716, '378', 1, NULL),
	(7, 3717, '379', 1, NULL),
	(7, 3718, '380', 1, NULL),
	(7, 3719, '381', 1, NULL),
	(7, 3724, '378', 1, NULL),
	(7, 3725, '379', 1, NULL),
	(7, 3726, '380', 1, NULL),
	(7, 3727, '381', 1, NULL),
	(7, 3728, '382', 1, NULL),
	(7, 3729, '383', 1, NULL),
	(7, 3730, '384', 1, NULL),
	(7, 3731, '385', 1, NULL),
	(7, 3732, '382', 1, NULL),
	(7, 3733, '383', 1, NULL),
	(7, 3734, '384', 1, NULL),
	(7, 3735, '385', 1, NULL),
	(7, 3740, '382', 1, NULL),
	(7, 3741, '383', 1, NULL),
	(7, 3742, '384', 1, NULL),
	(7, 3743, '385', 1, NULL),
	(7, 3744, '386', 1, NULL),
	(7, 3745, '387', 1, NULL),
	(7, 3746, '388', 1, NULL),
	(7, 3747, '389', 1, NULL),
	(7, 3748, '386', 1, NULL),
	(7, 3749, '387', 1, NULL),
	(7, 3750, '388', 1, NULL),
	(7, 3751, '389', 1, NULL),
	(7, 3756, '386', 1, NULL),
	(7, 3757, '387', 1, NULL),
	(7, 3758, '388', 1, NULL),
	(7, 3759, '389', 1, NULL),
	(7, 3760, '390', 1, NULL),
	(7, 3761, '391', 1, NULL),
	(7, 3762, '392', 1, NULL),
	(7, 3763, '393', 1, NULL),
	(7, 3764, '390', 1, NULL),
	(7, 3765, '391', 1, NULL),
	(7, 3766, '392', 1, NULL),
	(7, 3767, '393', 1, NULL),
	(7, 3772, '390', 1, NULL),
	(7, 3773, '391', 1, NULL),
	(7, 3774, '392', 1, NULL),
	(7, 3775, '393', 1, NULL),
	(8, 1, '1', 1, NULL),
	(8, 2, '2', 1, NULL),
	(8, 3, '3', 1, NULL),
	(8, 4, '4', 1, NULL),
	(8, 5, '5', 1, NULL),
	(8, 6, '6', 1, NULL),
	(8, 7, '7', 1, NULL),
	(8, 8, '8', 1, NULL),
	(8, 9, '9', 1, NULL),
	(8, 10, '10', 1, NULL),
	(8, 11, '11', 1, NULL),
	(8, 12, '12', 1, NULL),
	(8, 13, '13', 1, NULL),
	(8, 14, '14', 1, NULL),
	(8, 15, '15', 1, NULL),
	(8, 16, '16', 1, NULL),
	(8, 17, '17', 1, NULL),
	(8, 18, '18', 1, NULL),
	(8, 19, '19', 1, NULL),
	(8, 20, '20', 1, NULL),
	(8, 21, '21', 1, NULL),
	(8, 22, '22', 1, NULL),
	(8, 23, '23', 1, NULL),
	(8, 24, '24', 1, NULL),
	(8, 25, '25', 1, NULL),
	(8, 26, '26', 1, NULL),
	(8, 27, '27', 1, NULL),
	(8, 28, '28', 1, NULL),
	(8, 29, '29', 1, NULL),
	(8, 30, '30', 1, NULL),
	(8, 31, '31', 1, NULL),
	(8, 32, '32', 1, NULL),
	(8, 33, '33', 1, NULL),
	(8, 34, '34', 1, NULL),
	(8, 35, '35', 1, NULL),
	(8, 36, '36', 1, NULL),
	(8, 37, '37', 1, NULL),
	(8, 38, '38', 1, NULL),
	(8, 39, '39', 1, NULL),
	(8, 40, '40', 1, NULL),
	(8, 41, '41', 1, NULL),
	(8, 42, '42', 1, NULL),
	(8, 43, '43', 1, NULL),
	(8, 44, '44', 1, NULL),
	(8, 45, '45', 1, NULL),
	(8, 46, '46', 1, NULL),
	(8, 47, '47', 1, NULL),
	(8, 48, '48', 1, NULL),
	(8, 49, '49', 1, NULL),
	(8, 50, '50', 1, NULL),
	(8, 51, '51', 1, NULL),
	(8, 52, '52', 1, NULL),
	(8, 53, '53', 1, NULL),
	(8, 54, '54', 1, NULL),
	(8, 55, '55', 1, NULL),
	(8, 56, '56', 1, NULL),
	(8, 57, '57', 1, NULL),
	(8, 58, '58', 1, NULL),
	(8, 62, '62', 1, NULL),
	(8, 63, '63', 1, NULL),
	(8, 64, '64', 1, NULL),
	(8, 65, '65', 1, NULL),
	(8, 66, '66', 1, NULL),
	(8, 67, '67', 1, NULL),
	(8, 71, '71', 1, NULL),
	(8, 72, '72', 1, NULL),
	(8, 73, '73', 1, NULL),
	(8, 77, '77', 1, NULL),
	(8, 79, '79', 1, NULL),
	(8, 80, '80', 1, NULL),
	(8, 81, '81', 1, NULL),
	(8, 83, '83', 1, NULL),
	(8, 84, '84', 1, NULL),
	(8, 85, '85', 1, NULL),
	(8, 377, '49', 1, NULL),
	(8, 378, '50', 1, NULL),
	(8, 379, '51', 1, NULL),
	(8, 380, '52', 1, NULL),
	(8, 1044, '49', 1, NULL),
	(8, 1045, '50', 1, NULL),
	(8, 1046, '51', 1, NULL),
	(8, 1047, '52', 1, NULL),
	(8, 3648, '358', 1, NULL),
	(8, 3649, '359', 1, NULL),
	(8, 3650, '360', 1, NULL),
	(8, 3651, '361', 1, NULL),
	(8, 3652, '358', 1, NULL),
	(8, 3653, '359', 1, NULL),
	(8, 3654, '360', 1, NULL),
	(8, 3655, '361', 1, NULL),
	(8, 3660, '358', 1, NULL),
	(8, 3661, '359', 1, NULL),
	(8, 3662, '360', 1, NULL),
	(8, 3663, '361', 1, NULL),
	(8, 3664, '362', 1, NULL),
	(8, 3665, '363', 1, NULL),
	(8, 3666, '364', 1, NULL),
	(8, 3667, '365', 1, NULL),
	(8, 3668, '362', 1, NULL),
	(8, 3669, '363', 1, NULL),
	(8, 3670, '364', 1, NULL),
	(8, 3671, '365', 1, NULL),
	(8, 3676, '362', 1, NULL),
	(8, 3677, '363', 1, NULL),
	(8, 3678, '364', 1, NULL),
	(8, 3679, '365', 1, NULL),
	(8, 3680, '366', 1, NULL),
	(8, 3681, '367', 1, NULL),
	(8, 3682, '368', 1, NULL),
	(8, 3683, '369', 1, NULL),
	(8, 3684, '366', 1, NULL),
	(8, 3685, '367', 1, NULL),
	(8, 3686, '368', 1, NULL),
	(8, 3687, '369', 1, NULL),
	(8, 3692, '366', 1, NULL),
	(8, 3693, '367', 1, NULL),
	(8, 3694, '368', 1, NULL),
	(8, 3695, '369', 1, NULL),
	(8, 3696, '370', 1, NULL),
	(8, 3697, '371', 1, NULL),
	(8, 3698, '372', 1, NULL),
	(8, 3699, '373', 1, NULL),
	(8, 3700, '370', 1, NULL),
	(8, 3701, '371', 1, NULL),
	(8, 3702, '372', 1, NULL),
	(8, 3703, '373', 1, NULL),
	(8, 3708, '370', 1, NULL),
	(8, 3709, '371', 1, NULL),
	(8, 3710, '372', 1, NULL),
	(8, 3711, '373', 1, NULL),
	(8, 3712, '378', 1, NULL),
	(8, 3713, '379', 1, NULL),
	(8, 3714, '380', 1, NULL),
	(8, 3715, '381', 1, NULL),
	(8, 3716, '378', 1, NULL),
	(8, 3717, '379', 1, NULL),
	(8, 3718, '380', 1, NULL),
	(8, 3719, '381', 1, NULL),
	(8, 3724, '378', 1, NULL),
	(8, 3725, '379', 1, NULL),
	(8, 3726, '380', 1, NULL),
	(8, 3727, '381', 1, NULL),
	(8, 3728, '382', 1, NULL),
	(8, 3729, '383', 1, NULL),
	(8, 3730, '384', 1, NULL),
	(8, 3731, '385', 1, NULL),
	(8, 3732, '382', 1, NULL),
	(8, 3733, '383', 1, NULL),
	(8, 3734, '384', 1, NULL),
	(8, 3735, '385', 1, NULL),
	(8, 3740, '382', 1, NULL),
	(8, 3741, '383', 1, NULL),
	(8, 3742, '384', 1, NULL),
	(8, 3743, '385', 1, NULL),
	(8, 3744, '386', 1, NULL),
	(8, 3745, '387', 1, NULL),
	(8, 3746, '388', 1, NULL),
	(8, 3747, '389', 1, NULL),
	(8, 3748, '386', 1, NULL),
	(8, 3749, '387', 1, NULL),
	(8, 3750, '388', 1, NULL),
	(8, 3751, '389', 1, NULL),
	(8, 3756, '386', 1, NULL),
	(8, 3757, '387', 1, NULL),
	(8, 3758, '388', 1, NULL),
	(8, 3759, '389', 1, NULL),
	(8, 3760, '390', 1, NULL),
	(8, 3761, '391', 1, NULL),
	(8, 3762, '392', 1, NULL),
	(8, 3763, '393', 1, NULL),
	(8, 3764, '390', 1, NULL),
	(8, 3765, '391', 1, NULL),
	(8, 3766, '392', 1, NULL),
	(8, 3767, '393', 1, NULL),
	(8, 3772, '390', 1, NULL),
	(8, 3773, '391', 1, NULL),
	(8, 3774, '392', 1, NULL),
	(8, 3775, '393', 1, NULL),
	(9, 1, '1', 1, NULL),
	(9, 3, '3', 1, NULL),
	(9, 4, '4', 1, NULL),
	(9, 5, '5', 1, NULL),
	(9, 7, '7', 1, NULL),
	(9, 8, '8', 1, NULL),
	(9, 9, '9', 1, NULL),
	(9, 11, '11', 1, NULL),
	(9, 12, '12', 1, NULL),
	(9, 13, '13', 1, NULL),
	(9, 15, '15', 1, NULL),
	(9, 16, '16', 1, NULL),
	(9, 17, '17', 1, NULL),
	(9, 19, '19', 1, NULL),
	(9, 20, '20', 1, NULL),
	(9, 21, '21', 1, NULL),
	(9, 23, '23', 1, NULL),
	(9, 24, '24', 1, NULL),
	(9, 25, '25', 1, NULL),
	(9, 27, '27', 1, NULL),
	(9, 28, '28', 1, NULL),
	(9, 29, '29', 1, NULL),
	(9, 31, '31', 1, NULL),
	(9, 32, '32', 1, NULL),
	(9, 33, '33', 1, NULL),
	(9, 35, '35', 1, NULL),
	(9, 36, '36', 1, NULL),
	(9, 37, '37', 1, NULL),
	(9, 39, '39', 1, NULL),
	(9, 40, '40', 1, NULL),
	(9, 41, '41', 1, NULL),
	(9, 43, '43', 1, NULL),
	(9, 44, '44', 1, NULL),
	(9, 45, '45', 1, NULL),
	(9, 47, '47', 1, NULL),
	(9, 48, '48', 1, NULL),
	(9, 49, '49', 1, NULL),
	(9, 51, '51', 1, NULL),
	(9, 52, '52', 1, NULL),
	(9, 53, '53', 1, NULL),
	(9, 54, '54', 1, NULL),
	(9, 55, '55', 1, NULL),
	(9, 56, '56', 1, NULL),
	(9, 57, '57', 1, NULL),
	(9, 58, '58', 1, NULL),
	(9, 62, '62', 1, NULL),
	(9, 63, '63', 1, NULL),
	(9, 64, '64', 1, NULL),
	(9, 65, '65', 1, NULL),
	(9, 66, '66', 1, NULL),
	(9, 67, '67', 1, NULL),
	(9, 71, '71', 1, NULL),
	(9, 72, '72', 1, NULL),
	(9, 73, '73', 1, NULL),
	(9, 77, '77', 1, NULL),
	(9, 79, '79', 1, NULL),
	(9, 80, '80', 1, NULL),
	(9, 81, '81', 1, NULL),
	(9, 83, '83', 1, NULL),
	(9, 84, '84', 1, NULL),
	(9, 85, '85', 1, NULL),
	(9, 377, '49', 1, NULL),
	(9, 379, '51', 1, NULL),
	(9, 380, '52', 1, NULL),
	(9, 1044, '49', 1, NULL),
	(9, 1046, '51', 1, NULL),
	(9, 1047, '52', 1, NULL),
	(9, 3648, '358', 1, NULL),
	(9, 3650, '360', 1, NULL),
	(9, 3651, '361', 1, NULL),
	(9, 3652, '358', 1, NULL),
	(9, 3654, '360', 1, NULL),
	(9, 3655, '361', 1, NULL),
	(9, 3660, '358', 1, NULL),
	(9, 3662, '360', 1, NULL),
	(9, 3663, '361', 1, NULL),
	(9, 3664, '362', 1, NULL),
	(9, 3666, '364', 1, NULL),
	(9, 3667, '365', 1, NULL),
	(9, 3668, '362', 1, NULL),
	(9, 3670, '364', 1, NULL),
	(9, 3671, '365', 1, NULL),
	(9, 3676, '362', 1, NULL),
	(9, 3678, '364', 1, NULL),
	(9, 3679, '365', 1, NULL),
	(9, 3680, '366', 1, NULL),
	(9, 3682, '368', 1, NULL),
	(9, 3683, '369', 1, NULL),
	(9, 3684, '366', 1, NULL),
	(9, 3686, '368', 1, NULL),
	(9, 3687, '369', 1, NULL),
	(9, 3692, '366', 1, NULL),
	(9, 3694, '368', 1, NULL),
	(9, 3695, '369', 1, NULL),
	(9, 3696, '370', 1, NULL),
	(9, 3698, '372', 1, NULL),
	(9, 3699, '373', 1, NULL),
	(9, 3700, '370', 1, NULL),
	(9, 3702, '372', 1, NULL),
	(9, 3703, '373', 1, NULL),
	(9, 3708, '370', 1, NULL),
	(9, 3710, '372', 1, NULL),
	(9, 3711, '373', 1, NULL),
	(9, 3712, '378', 1, NULL),
	(9, 3714, '380', 1, NULL),
	(9, 3715, '381', 1, NULL),
	(9, 3716, '378', 1, NULL),
	(9, 3718, '380', 1, NULL),
	(9, 3719, '381', 1, NULL),
	(9, 3724, '378', 1, NULL),
	(9, 3726, '380', 1, NULL),
	(9, 3727, '381', 1, NULL),
	(9, 3728, '382', 1, NULL),
	(9, 3730, '384', 1, NULL),
	(9, 3731, '385', 1, NULL),
	(9, 3732, '382', 1, NULL),
	(9, 3734, '384', 1, NULL),
	(9, 3735, '385', 1, NULL),
	(9, 3740, '382', 1, NULL),
	(9, 3742, '384', 1, NULL),
	(9, 3743, '385', 1, NULL),
	(9, 3744, '386', 1, NULL),
	(9, 3746, '388', 1, NULL),
	(9, 3747, '389', 1, NULL),
	(9, 3748, '386', 1, NULL),
	(9, 3750, '388', 1, NULL),
	(9, 3751, '389', 1, NULL),
	(9, 3756, '386', 1, NULL),
	(9, 3758, '388', 1, NULL),
	(9, 3759, '389', 1, NULL),
	(9, 3760, '390', 1, NULL),
	(9, 3762, '392', 1, NULL),
	(9, 3763, '393', 1, NULL),
	(9, 3764, '390', 1, NULL),
	(9, 3766, '392', 1, NULL),
	(9, 3767, '393', 1, NULL),
	(9, 3772, '390', 1, NULL),
	(9, 3774, '392', 1, NULL),
	(9, 3775, '393', 1, NULL),
	(10, 1, 'AB', 1, NULL),
	(10, 2, 'AB', 1, NULL),
	(10, 3, 'B', 1, NULL),
	(10, 4, 'B', 1, NULL),
	(10, 5, 'AB', 1, NULL),
	(10, 6, 'AB', 1, NULL),
	(10, 7, 'B', 1, NULL),
	(10, 8, 'B', 1, NULL),
	(10, 9, 'AB', 1, NULL),
	(10, 10, 'AB', 1, NULL),
	(10, 11, 'B', 1, NULL),
	(10, 12, 'B', 1, NULL),
	(10, 13, 'AB', 1, NULL),
	(10, 14, 'AB', 1, NULL),
	(10, 15, 'B', 1, NULL),
	(10, 16, 'B', 1, NULL),
	(10, 17, 'AB', 1, NULL),
	(10, 18, 'AB', 1, NULL),
	(10, 19, 'B', 1, NULL),
	(10, 20, 'B', 1, NULL),
	(10, 21, 'AB', 1, NULL),
	(10, 22, 'AB', 1, NULL),
	(10, 23, 'B', 1, NULL),
	(10, 24, 'B', 1, NULL),
	(10, 25, 'AB', 1, NULL),
	(10, 26, 'AB', 1, NULL),
	(10, 27, 'B', 1, NULL),
	(10, 28, 'B', 1, NULL),
	(10, 29, 'AB', 1, NULL),
	(10, 30, 'AB', 1, NULL),
	(10, 31, 'B', 1, NULL),
	(10, 32, 'B', 1, NULL),
	(10, 33, 'AB', 1, NULL),
	(10, 34, 'AB', 1, NULL),
	(10, 35, 'B', 1, NULL),
	(10, 36, 'B', 1, NULL),
	(10, 37, 'AB', 1, NULL),
	(10, 38, 'AB', 1, NULL),
	(10, 39, 'B', 1, NULL),
	(10, 40, 'B', 1, NULL),
	(10, 41, 'AB', 1, NULL),
	(10, 42, 'AB', 1, NULL),
	(10, 43, 'B', 1, NULL),
	(10, 44, 'B', 1, NULL),
	(10, 45, 'AB', 1, NULL),
	(10, 46, 'AB', 1, NULL),
	(10, 47, 'B', 1, NULL),
	(10, 48, 'B', 1, NULL),
	(10, 49, 'AB', 1, NULL),
	(10, 50, 'AB', 1, NULL),
	(10, 51, 'B', 1, NULL),
	(10, 52, 'B', 1, NULL),
	(10, 53, 'AB', 1, NULL),
	(10, 54, 'AB', 1, NULL),
	(10, 55, 'AB', 1, NULL),
	(10, 56, 'AB', 1, NULL),
	(10, 57, 'AB', 1, NULL),
	(10, 58, 'AB', 1, NULL),
	(10, 59, 'AB', 1, NULL),
	(10, 60, 'AB', 1, NULL),
	(10, 61, 'AB', 1, NULL),
	(10, 62, 'AB', 1, NULL),
	(10, 63, 'AB', 1, NULL),
	(10, 64, 'AB', 1, NULL),
	(10, 65, 'AB', 1, NULL),
	(10, 66, 'AB', 1, NULL),
	(10, 67, 'AB', 1, NULL),
	(10, 68, 'AB', 1, NULL),
	(10, 69, 'AB', 1, NULL),
	(10, 70, 'AB', 1, NULL),
	(10, 71, 'AB', 1, NULL),
	(10, 72, 'AB', 1, NULL),
	(10, 73, 'AB', 1, NULL),
	(10, 74, 'AB', 1, NULL),
	(10, 75, 'AB', 1, NULL),
	(10, 76, 'AB', 1, NULL),
	(10, 77, 'AB', 1, NULL),
	(10, 79, 'AB', 1, NULL),
	(10, 80, 'AB', 1, NULL),
	(10, 81, 'AB', 1, NULL),
	(10, 83, 'AB', 1, NULL),
	(10, 85, 'AB', 1, NULL),
	(10, 86, 'AB', 1, NULL),
	(10, 377, 'AB', 1, NULL),
	(10, 378, 'AB', 1, NULL),
	(10, 379, 'B', 1, NULL),
	(10, 380, 'B', 1, NULL),
	(10, 1044, 'AB', 1, NULL),
	(10, 1045, 'AB', 1, NULL),
	(10, 1046, 'B', 1, NULL),
	(10, 1047, 'B', 1, NULL),
	(10, 1294, 'AB', 1, NULL),
	(10, 1298, 'AB', 1, NULL),
	(10, 1299, 'AB', 1, NULL),
	(10, 1300, 'AB', 1, NULL),
	(10, 1301, 'AB', 1, NULL),
	(10, 1302, 'AB', 1, NULL),
	(10, 1303, 'AB', 1, NULL),
	(10, 1304, 'AB', 1, NULL),
	(10, 1305, 'AB', 1, NULL),
	(10, 1306, 'AB', 1, NULL),
	(10, 1307, 'AB', 1, NULL),
	(10, 1308, 'AB', 1, NULL),
	(10, 1309, 'AB', 1, NULL),
	(10, 1310, 'AB', 1, NULL),
	(10, 1326, 'AB', 1, NULL),
	(10, 1328, 'AB', 1, NULL),
	(10, 1332, 'AB', 1, NULL),
	(10, 1333, 'AB', 1, NULL),
	(10, 1334, 'AB', 1, NULL),
	(10, 1335, 'AB', 1, NULL),
	(10, 1336, 'AB', 1, NULL),
	(10, 1337, 'AB', 1, NULL),
	(10, 1338, 'AB', 1, NULL),
	(10, 1339, 'AB', 1, NULL),
	(10, 1340, 'AB', 1, NULL),
	(10, 1341, 'AB', 1, NULL),
	(10, 1342, 'AB', 1, NULL),
	(10, 1343, 'AB', 1, NULL),
	(10, 1344, 'AB', 1, NULL),
	(10, 1360, 'AB', 1, NULL),
	(10, 1362, 'AB', 1, NULL),
	(10, 1366, 'AB', 1, NULL),
	(10, 1367, 'AB', 1, NULL),
	(10, 1368, 'AB', 1, NULL),
	(10, 1369, 'AB', 1, NULL),
	(10, 1370, 'AB', 1, NULL),
	(10, 1371, 'AB', 1, NULL),
	(10, 1372, 'AB', 1, NULL),
	(10, 1373, 'AB', 1, NULL),
	(10, 1374, 'AB', 1, NULL),
	(10, 1375, 'AB', 1, NULL),
	(10, 1376, 'AB', 1, NULL),
	(10, 1377, 'AB', 1, NULL),
	(10, 1378, 'AB', 1, NULL),
	(10, 1394, 'AB', 1, NULL),
	(10, 1396, 'AB', 1, NULL),
	(10, 1400, 'AB', 1, NULL),
	(10, 1401, 'AB', 1, NULL),
	(10, 1402, 'AB', 1, NULL),
	(10, 1403, 'AB', 1, NULL),
	(10, 1404, 'AB', 1, NULL),
	(10, 1405, 'AB', 1, NULL),
	(10, 1406, 'AB', 1, NULL),
	(10, 1407, 'AB', 1, NULL),
	(10, 1408, 'AB', 1, NULL),
	(10, 1409, 'AB', 1, NULL),
	(10, 1410, 'AB', 1, NULL),
	(10, 1411, 'AB', 1, NULL),
	(10, 1412, 'AB', 1, NULL),
	(10, 1428, 'AB', 1, NULL),
	(10, 1430, 'AB', 1, NULL),
	(10, 1431, 'AB', 1, NULL),
	(10, 1438, 'AB', 1, NULL),
	(10, 1439, 'AB', 1, NULL),
	(10, 1440, 'AB', 1, NULL),
	(10, 1441, 'AB', 1, NULL),
	(10, 1442, 'AB', 1, NULL),
	(10, 1443, 'AB', 1, NULL),
	(10, 1444, 'AB', 1, NULL),
	(10, 1445, 'AB', 1, NULL),
	(10, 1446, 'AB', 1, NULL),
	(10, 1447, 'AB', 1, NULL),
	(10, 1448, 'AB', 1, NULL),
	(10, 1449, 'AB', 1, NULL),
	(10, 1450, 'AB', 1, NULL),
	(10, 1451, 'AB', 1, NULL),
	(10, 1452, 'AB', 1, NULL),
	(10, 1453, 'AB', 1, NULL),
	(10, 1454, 'AB', 1, NULL),
	(10, 1455, 'AB', 1, NULL),
	(10, 1456, 'AB', 1, NULL),
	(10, 1457, 'AB', 1, NULL),
	(10, 1458, 'AB', 1, NULL),
	(10, 1459, 'AB', 1, NULL),
	(10, 1460, 'AB', 1, NULL),
	(10, 1461, 'AB', 1, NULL),
	(10, 1462, 'AB', 1, NULL),
	(10, 1463, 'AB', 1, NULL),
	(10, 1494, 'AB', 1, NULL),
	(10, 1495, 'AB', 1, NULL),
	(10, 2093, 'AB', 1, NULL),
	(10, 2098, 'AB', 1, NULL),
	(10, 2101, 'AB', 1, NULL),
	(10, 2102, 'AB', 1, NULL),
	(10, 2103, 'AB', 1, NULL),
	(10, 2104, 'AB', 1, NULL),
	(10, 2105, 'AB', 1, NULL),
	(10, 2112, 'AB', 1, NULL),
	(10, 2113, 'B', 1, NULL),
	(10, 2115, 'B', 1, NULL),
	(10, 2118, 'B', 1, NULL),
	(10, 2122, 'B', 1, NULL),
	(10, 2124, 'B', 1, NULL),
	(10, 2127, 'B', 1, NULL),
	(10, 2128, 'B', 1, NULL),
	(10, 2132, 'B', 1, NULL),
	(10, 2136, 'AB', 1, NULL),
	(10, 2137, 'AB', 1, NULL),
	(10, 2139, 'AB', 1, NULL),
	(10, 2140, 'AB', 1, NULL),
	(10, 2143, 'AB', 1, NULL),
	(10, 2144, 'AB', 1, NULL),
	(10, 2151, 'AB', 1, NULL),
	(10, 2152, 'AB', 1, NULL),
	(10, 2153, 'AB', 1, NULL),
	(10, 2154, 'AB', 1, NULL),
	(10, 2161, 'AB', 1, NULL),
	(10, 2162, 'AB', 1, NULL),
	(10, 2165, 'AB', 1, NULL),
	(10, 2166, 'AB', 1, NULL),
	(10, 2168, 'AB', 1, NULL),
	(10, 2172, 'AB', 1, NULL),
	(10, 2174, 'AB', 1, NULL),
	(10, 2179, 'AB', 1, NULL),
	(10, 2180, 'AB', 1, NULL),
	(10, 2181, 'AB', 1, NULL),
	(10, 2184, 'AB', 1, NULL),
	(10, 2186, 'AB', 1, NULL),
	(10, 2188, 'AB', 1, NULL),
	(10, 2191, 'AB', 1, NULL),
	(10, 3648, 'AB', 1, NULL),
	(10, 3649, 'AB', 1, NULL),
	(10, 3650, 'B', 1, NULL),
	(10, 3651, 'B', 1, NULL),
	(10, 3652, 'AB', 1, NULL),
	(10, 3653, 'AB', 1, NULL),
	(10, 3654, 'B', 1, NULL),
	(10, 3655, 'B', 1, NULL),
	(10, 3660, 'AB', 1, NULL),
	(10, 3661, 'AB', 1, NULL),
	(10, 3662, 'B', 1, NULL),
	(10, 3663, 'B', 1, NULL),
	(10, 3664, 'AB', 1, NULL),
	(10, 3665, 'AB', 1, NULL),
	(10, 3666, 'B', 1, NULL),
	(10, 3667, 'B', 1, NULL),
	(10, 3668, 'AB', 1, NULL),
	(10, 3669, 'AB', 1, NULL),
	(10, 3670, 'B', 1, NULL),
	(10, 3671, 'B', 1, NULL),
	(10, 3676, 'AB', 1, NULL),
	(10, 3677, 'AB', 1, NULL),
	(10, 3678, 'B', 1, NULL),
	(10, 3679, 'B', 1, NULL),
	(10, 3680, 'AB', 1, NULL),
	(10, 3681, 'AB', 1, NULL),
	(10, 3682, 'B', 1, NULL),
	(10, 3683, 'B', 1, NULL),
	(10, 3684, 'AB', 1, NULL),
	(10, 3685, 'AB', 1, NULL),
	(10, 3686, 'B', 1, NULL),
	(10, 3687, 'B', 1, NULL),
	(10, 3692, 'AB', 1, NULL),
	(10, 3693, 'AB', 1, NULL),
	(10, 3694, 'B', 1, NULL),
	(10, 3695, 'B', 1, NULL),
	(10, 3696, 'AB', 1, NULL),
	(10, 3697, 'AB', 1, NULL),
	(10, 3698, 'B', 1, NULL),
	(10, 3699, 'B', 1, NULL),
	(10, 3700, 'AB', 1, NULL),
	(10, 3701, 'AB', 1, NULL),
	(10, 3702, 'B', 1, NULL),
	(10, 3703, 'B', 1, NULL),
	(10, 3708, 'AB', 1, NULL),
	(10, 3709, 'AB', 1, NULL),
	(10, 3710, 'B', 1, NULL),
	(10, 3711, 'B', 1, NULL),
	(10, 3712, 'AB', 1, NULL),
	(10, 3713, 'AB', 1, NULL),
	(10, 3714, 'B', 1, NULL),
	(10, 3715, 'B', 1, NULL),
	(10, 3716, 'AB', 1, NULL),
	(10, 3717, 'AB', 1, NULL),
	(10, 3718, 'B', 1, NULL),
	(10, 3719, 'B', 1, NULL),
	(10, 3724, 'AB', 1, NULL),
	(10, 3725, 'AB', 1, NULL),
	(10, 3726, 'B', 1, NULL),
	(10, 3727, 'B', 1, NULL),
	(10, 3728, 'AB', 1, NULL),
	(10, 3729, 'AB', 1, NULL),
	(10, 3730, 'B', 1, NULL),
	(10, 3731, 'B', 1, NULL),
	(10, 3732, 'AB', 1, NULL),
	(10, 3733, 'AB', 1, NULL),
	(10, 3734, 'B', 1, NULL),
	(10, 3735, 'B', 1, NULL),
	(10, 3740, 'AB', 1, NULL),
	(10, 3741, 'AB', 1, NULL),
	(10, 3742, 'B', 1, NULL),
	(10, 3743, 'B', 1, NULL),
	(10, 3744, 'AB', 1, NULL),
	(10, 3745, 'AB', 1, NULL),
	(10, 3746, 'B', 1, NULL),
	(10, 3747, 'B', 1, NULL),
	(10, 3748, 'AB', 1, NULL),
	(10, 3749, 'AB', 1, NULL),
	(10, 3750, 'B', 1, NULL),
	(10, 3751, 'B', 1, NULL),
	(10, 3756, 'AB', 1, NULL),
	(10, 3757, 'AB', 1, NULL),
	(10, 3758, 'B', 1, NULL),
	(10, 3759, 'B', 1, NULL),
	(10, 3760, 'AB', 1, NULL),
	(10, 3761, 'AB', 1, NULL),
	(10, 3762, 'AB', 1, NULL),
	(10, 3763, 'AB', 1, NULL),
	(10, 3764, 'AB', 1, NULL),
	(10, 3765, 'AB', 1, NULL),
	(10, 3766, 'AB', 1, NULL),
	(10, 3767, 'AB', 1, NULL),
	(10, 3772, 'AB', 1, NULL),
	(10, 3773, 'AB', 1, NULL),
	(10, 3774, 'AB', 1, NULL),
	(10, 3775, 'AB', 1, NULL),
	(10, 3776, 'AB', 1, NULL),
	(10, 3777, 'AB', 1, NULL),
	(10, 3778, 'AB', 1, NULL),
	(10, 3779, 'AB', 1, NULL),
	(10, 3780, 'AB', 1, NULL),
	(10, 3781, 'AB', 1, NULL),
	(10, 3782, 'AB', 1, NULL),
	(10, 3783, 'AB', 1, NULL),
	(10, 3784, 'AB', 1, NULL),
	(10, 3785, 'AB', 1, NULL),
	(10, 3786, 'AB', 1, NULL),
	(10, 3787, 'AB', 1, NULL),
	(10, 3794, 'AB', 1, NULL),
	(10, 3795, 'AB', 1, NULL),
	(10, 3796, 'AB', 1, NULL),
	(10, 3797, 'AB', 1, NULL),
	(10, 3798, 'AB', 1, NULL),
	(10, 3799, 'AB', 1, NULL),
	(10, 3800, 'AB', 1, NULL),
	(10, 3801, 'AB', 1, NULL),
	(10, 3802, 'AB', 1, NULL),
	(10, 3803, 'AB', 1, NULL),
	(10, 3804, 'AB', 1, NULL),
	(10, 3805, 'AB', 1, NULL),
	(10, 3806, 'AB', 1, NULL),
	(10, 3807, 'AB', 1, NULL),
	(10, 3808, 'AB', 1, NULL),
	(10, 3809, 'AB', 1, NULL),
	(10, 3810, 'AB', 1, NULL),
	(10, 3811, 'AB', 1, NULL),
	(10, 3818, 'AB', 1, NULL),
	(10, 3819, 'AB', 1, NULL),
	(10, 3820, 'AB', 1, NULL),
	(10, 3821, 'AB', 1, NULL),
	(10, 3822, 'AB', 1, NULL),
	(10, 3823, 'AB', 1, NULL),
	(10, 3824, 'AB', 1, NULL),
	(10, 3825, 'AB', 1, NULL),
	(10, 3826, 'AB', 1, NULL),
	(10, 3827, 'AB', 1, NULL),
	(10, 3828, 'AB', 1, NULL),
	(10, 3829, 'AB', 1, NULL),
	(10, 3830, 'AB', 1, NULL),
	(10, 3831, 'AB', 1, NULL),
	(10, 3832, 'AB', 1, NULL),
	(10, 3833, 'AB', 1, NULL),
	(10, 3834, 'AB', 1, NULL),
	(10, 3835, 'AB', 1, NULL),
	(10, 3842, 'AB', 1, NULL),
	(10, 3843, 'AB', 1, NULL),
	(10, 3844, 'AB', 1, NULL),
	(10, 3845, 'AB', 1, NULL),
	(10, 3846, 'AB', 1, NULL),
	(10, 3847, 'AB', 1, NULL),
	(10, 3848, 'AB', 1, NULL),
	(10, 3849, 'AB', 1, NULL),
	(10, 3850, 'AB', 1, NULL),
	(10, 3851, 'AB', 1, NULL),
	(10, 3852, 'AB', 1, NULL),
	(10, 3853, 'AB', 1, NULL),
	(10, 3854, 'AB', 1, NULL),
	(10, 3855, 'AB', 1, NULL),
	(10, 3856, 'AB', 1, NULL),
	(10, 3857, 'AB', 1, NULL),
	(10, 3858, 'AB', 1, NULL),
	(10, 3859, 'AB', 1, NULL),
	(10, 3866, 'AB', 1, NULL),
	(10, 3867, 'AB', 1, NULL),
	(10, 3868, 'AB', 1, NULL),
	(10, 3869, 'AB', 1, NULL),
	(10, 3870, 'AB', 1, NULL),
	(10, 3871, 'AB', 1, NULL),
	(10, 3872, 'AB', 1, NULL),
	(10, 3873, 'AB', 1, NULL),
	(10, 3874, 'AB', 1, NULL),
	(10, 3875, 'AB', 1, NULL),
	(10, 3876, 'AB', 1, NULL),
	(10, 3877, 'AB', 1, NULL),
	(10, 3878, 'AB', 1, NULL),
	(10, 3879, 'AB', 1, NULL),
	(10, 3880, 'AB', 1, NULL),
	(10, 3881, 'AB', 1, NULL),
	(10, 3882, 'AB', 1, NULL),
	(10, 3883, 'AB', 1, NULL),
	(10, 3890, 'AB', 1, NULL),
	(10, 3891, 'AB', 1, NULL),
	(10, 3892, 'AB', 1, NULL),
	(10, 3893, 'AB', 1, NULL),
	(10, 3894, 'AB', 1, NULL),
	(10, 3895, 'AB', 1, NULL),
	(10, 3896, 'AB', 1, NULL),
	(10, 3897, 'AB', 1, NULL),
	(10, 3898, 'AB', 1, NULL),
	(10, 3899, 'AB', 1, NULL),
	(10, 3900, 'AB', 1, NULL),
	(10, 3901, 'AB', 1, NULL),
	(10, 3902, 'AB', 1, NULL),
	(10, 3903, 'AB', 1, NULL),
	(10, 3904, 'AB', 1, NULL),
	(10, 3905, 'AB', 1, NULL),
	(10, 3906, 'AB', 1, NULL),
	(10, 3907, 'AB', 1, NULL),
	(10, 3914, 'AB', 1, NULL),
	(10, 3915, 'AB', 1, NULL),
	(10, 3916, 'AB', 1, NULL),
	(10, 3917, 'AB', 1, NULL),
	(10, 3918, 'AB', 1, NULL),
	(10, 3919, 'AB', 1, NULL),
	(10, 3920, 'AB', 1, NULL),
	(10, 3921, 'AB', 1, NULL),
	(10, 3922, 'AB', 1, NULL),
	(10, 3923, 'AB', 1, NULL),
	(10, 3924, 'AB', 1, NULL),
	(10, 3925, 'AB', 1, NULL),
	(10, 3926, 'AB', 1, NULL),
	(10, 3927, 'AB', 1, NULL),
	(10, 3928, 'AB', 1, NULL),
	(10, 3929, 'AB', 1, NULL),
	(10, 3930, 'AB', 1, NULL),
	(10, 3931, 'AB', 1, NULL),
	(10, 3938, 'AB', 1, NULL),
	(10, 3939, 'AB', 1, NULL),
	(10, 3940, 'AB', 1, NULL),
	(10, 3941, 'AB', 1, NULL),
	(10, 3942, 'AB', 1, NULL),
	(10, 3943, 'AB', 1, NULL),
	(10, 3944, 'AB', 1, NULL),
	(10, 3945, 'AB', 1, NULL),
	(10, 3946, 'AB', 1, NULL),
	(10, 3947, 'AB', 1, NULL),
	(10, 3948, 'AB', 1, NULL),
	(10, 3949, 'AB', 1, NULL),
	(10, 3950, 'AB', 1, NULL),
	(10, 3951, 'AB', 1, NULL),
	(10, 3952, 'AB', 1, NULL),
	(10, 3953, 'AB', 1, NULL),
	(10, 3954, 'AB', 1, NULL),
	(10, 3955, 'AB', 1, NULL),
	(10, 3962, 'AB', 1, NULL),
	(10, 3963, 'AB', 1, NULL),
	(10, 3964, 'AB', 1, NULL),
	(10, 3965, 'AB', 1, NULL),
	(10, 3966, 'AB', 1, NULL),
	(10, 3967, 'AB', 1, NULL),
	(11, 49, '1.1.1.27.0.255', 1, 3),
	(11, 50, '1.1.2.27.0.255', 1, 3),
	(11, 51, '1.1.3.27.0.255', 1, 3),
	(11, 52, '1.1.4.27.0.255', 1, 3),
	(11, 377, '1.1.1.27.0.255', 1, 3),
	(11, 378, '1.1.2.27.0.255', 1, 3),
	(11, 379, '1.1.3.27.0.255', 1, 3),
	(11, 380, '1.1.4.27.0.255', 1, 3),
	(11, 850, '1.1.1.27.0.255', 1, 3),
	(11, 851, '1.1.2.27.0.255', 1, 3),
	(11, 852, '1.1.3.27.0.255', 1, 3),
	(11, 853, '1.1.4.27.0.255', 1, 3),
	(11, 1044, '1.1.1.27.0.255', 1, 3),
	(11, 1045, '1.1.2.27.0.255', 1, 3),
	(11, 1046, '1.1.3.27.0.255', 1, 3),
	(11, 1047, '1.1.4.27.0.255', 1, 3),
	(13, 98, 'A', 1, 3),
	(13, 108, 'A', 1, 3),
	(13, 118, 'A', 1, 3),
	(13, 1763, 'A', 1, 3),
	(13, 2029, 'B', 1, 3),
	(13, 2030, 'B', 1, 3),
	(13, 2031, 'A', 1, 3),
	(13, 2032, 'B', 1, 3),
	(13, 2225, 'B', 1, 3),
	(13, 2226, 'B', 1, 3),
	(13, 6891, 'B', 1, 3),
	(13, 8508, 'B', 1, 3),
	(13, 12432, 'B', 1, 3),
	(13, 12441, 'B', 1, 3),
	(13, 12450, 'B', 1, 3),
	(13, 12451, 'B', 1, 3),
	(13, 12452, 'B', 1, 3),
	(13, 12453, 'B', 1, 3),
	(13, 12454, 'B', 1, 3),
	(13, 12455, 'B', 1, 3),
	(13, 12456, 'B', 1, 3),
	(13, 12457, 'B', 1, 3),
	(13, 12458, 'B', 1, 3),
	(13, 12459, 'B', 1, 3),
	(13, 12460, 'B', 1, 3),
	(13, 12461, 'B', 1, 3),
	(13, 12462, 'B', 1, 3),
	(13, 12463, 'B', 1, 3),
	(13, 12464, 'B', 1, 3),
	(13, 12465, 'B', 1, 3),
	(13, 12466, 'B', 1, 3),
	(13, 12467, 'B', 1, 3),
	(13, 12468, 'B', 1, 3),
	(13, 12469, 'B', 1, 3),
	(13, 12470, 'B', 1, 3),
	(13, 12471, 'B', 1, 3),
	(13, 12472, 'B', 1, 3),
	(13, 12473, 'B', 1, 3),
	(13, 12474, 'B', 1, 3),
	(13, 12477, 'B', 1, 3),
	(13, 12478, 'B', 1, 3),
	(13, 12479, 'B', 1, 3);
/*!40000 ALTER TABLE `catalog_ml` ENABLE KEYS */;

-- Dumping structure for table emcor.catalog_sheaf
CREATE TABLE IF NOT EXISTS `catalog_sheaf` (
  `catalog_id` mediumint(8) unsigned NOT NULL COMMENT 'Katalogo identifikatorius',
  `sheaf_id` mediumint(8) unsigned NOT NULL COMMENT 'Duomenų pluošto identifikatorius',
  `is_point` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  `item_code` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Katalogo elemento kodas',
  PRIMARY KEY (`catalog_id`,`sheaf_id`,`is_point`),
  KEY `catalog_sheaf_i` (`catalog_id`,`item_code`),
  KEY `catalog_sheaf_sheaf_fk` (`sheaf_id`),
  CONSTRAINT `catalog_sheaf_catalog_fk` FOREIGN KEY (`catalog_id`) REFERENCES `catalog` (`catalog_id`) ON DELETE CASCADE,
  CONSTRAINT `catalog_sheaf_sheaf_fk` FOREIGN KEY (`sheaf_id`) REFERENCES `sheaf` (`sheaf_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Katalogo duomenų pluoštai';

-- Dumping data for table emcor.catalog_sheaf: ~2 rows (approximately)
/*!40000 ALTER TABLE `catalog_sheaf` DISABLE KEYS */;
INSERT INTO `catalog_sheaf` (`catalog_id`, `sheaf_id`, `is_point`, `item_code`) VALUES
	(5, 14, 1, '1.0.96.130.3.255'),
	(5, 10010, 1, '1.0.96.62.0.255');
/*!40000 ALTER TABLE `catalog_sheaf` ENABLE KEYS */;

-- Dumping structure for table emcor.catalog_withe
CREATE TABLE IF NOT EXISTS `catalog_withe` (
  `catalog_id` mediumint(8) unsigned NOT NULL COMMENT 'Katalogo identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `item_code` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Katalogo elemento kodas',
  `is_point` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar susiję su matavimo tašku',
  PRIMARY KEY (`catalog_id`,`withe_id`,`is_point`),
  KEY `catalog_withe_item_i` (`catalog_id`,`item_code`),
  KEY `catalog_withe_withe_fk` (`withe_id`),
  CONSTRAINT `catalog_withe_catalog_fk` FOREIGN KEY (`catalog_id`) REFERENCES `catalog` (`catalog_id`) ON DELETE CASCADE,
  CONSTRAINT `catalog_withe_withe_fk` FOREIGN KEY (`withe_id`) REFERENCES `withe` (`withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Katalogo duomenų vytelės';

-- Dumping data for table emcor.catalog_withe: ~336 rows (approximately)
/*!40000 ALTER TABLE `catalog_withe` DISABLE KEYS */;
INSERT INTO `catalog_withe` (`catalog_id`, `withe_id`, `item_code`, `is_point`) VALUES
	(2, 10031, '3.1.1.127', 0),
	(2, 10031, '3.1.1.127', 1),
	(2, 10050, '3.1.15.202', 0),
	(2, 10050, '3.1.15.202', 1),
	(2, 10018, '3.1.7.179', 0),
	(2, 10018, '3.1.7.179', 1),
	(2, 10763, '3.1.7.179', 0),
	(2, 10763, '3.1.7.179', 1),
	(2, 10014, '3.10.1.44', 1),
	(2, 10553, '3.10.1.44', 1),
	(2, 10886, '3.11.16.244', 1),
	(2, 10883, '3.11.19.76', 1),
	(2, 10884, '3.11.7.4', 1),
	(2, 10098, '3.12.1.139', 1),
	(2, 10099, '3.12.1.150', 0),
	(2, 10099, '3.12.1.150', 1),
	(2, 10753, '3.16.17.104', 0),
	(2, 10753, '3.16.17.104', 1),
	(2, 10750, '3.16.17.52', 0),
	(2, 10750, '3.16.17.52', 1),
	(2, 10751, '3.16.17.52', 0),
	(2, 10751, '3.16.17.52', 1),
	(2, 10880, '3.17.16.214', 1),
	(2, 10881, '3.17.16.214', 1),
	(2, 10890, '3.17.16.6', 1),
	(2, 10892, '3.17.16.6', 1),
	(2, 10044, '3.17.16.81', 1),
	(2, 10766, '3.17.5.52', 0),
	(2, 10766, '3.17.5.52', 1),
	(2, 10752, '3.18.17.52', 0),
	(2, 10752, '3.18.17.52', 1),
	(2, 10878, '3.2.1.17', 1),
	(2, 10012, '3.2.17.17', 0),
	(2, 10012, '3.2.17.17', 1),
	(2, 10838, '3.2.17.17', 0),
	(2, 10838, '3.2.17.17', 1),
	(2, 10030, '3.2.17.276', 0),
	(2, 10030, '3.2.17.276', 1),
	(2, 10294, '3.2.18.17', 0),
	(2, 10294, '3.2.18.17', 1),
	(2, 10839, '3.20.7.24', 0),
	(2, 10839, '3.20.7.24', 1),
	(2, 10882, '3.21.12.157', 1),
	(2, 10085, '3.21.7.214', 0),
	(2, 10085, '3.21.7.214', 1),
	(2, 10465, '3.22.1.1', 0),
	(2, 10465, '3.22.1.1', 1),
	(2, 10485, '3.22.1.1', 0),
	(2, 10485, '3.22.1.1', 1),
	(2, 10076, '3.22.1.185', 0),
	(2, 10076, '3.22.1.185', 1),
	(2, 10910, '3.22.11.4', 1),
	(2, 10291, '3.22.12.179', 0),
	(2, 10291, '3.22.12.179', 1),
	(2, 10764, '3.22.12.185', 0),
	(2, 10764, '3.22.12.185', 1),
	(2, 10765, '3.22.12.185', 0),
	(2, 10765, '3.22.12.185', 1),
	(2, 10038, '3.22.16.5', 1),
	(2, 10885, '3.23.10.4', 1),
	(2, 10748, '3.23.17.159', 0),
	(2, 10748, '3.23.17.159', 1),
	(2, 10252, '3.23.17.179', 0),
	(2, 10252, '3.23.17.179', 1),
	(2, 10065, '3.23.17.8', 0),
	(2, 10065, '3.23.17.8', 1),
	(2, 10759, '3.24.10.214', 0),
	(2, 10759, '3.24.10.214', 1),
	(2, 10432, '3.24.10.24', 0),
	(2, 10432, '3.24.10.24', 1),
	(2, 10029, '3.25.13.185', 1),
	(2, 10000, '3.25.13.273', 1),
	(2, 10450, '3.25.13.273', 0),
	(2, 10450, '3.25.13.273', 1),
	(2, 10001, '3.25.13.274', 1),
	(2, 10451, '3.25.13.274', 0),
	(2, 10451, '3.25.13.274', 1),
	(2, 10002, '3.25.13.275', 1),
	(2, 10452, '3.25.13.275', 0),
	(2, 10452, '3.25.13.275', 1),
	(2, 10761, '3.25.14.159', 0),
	(2, 10761, '3.25.14.159', 1),
	(2, 10007, '3.25.9.45', 1),
	(2, 10113, '3.26.16.214', 0),
	(2, 10113, '3.26.16.214', 1),
	(2, 10114, '3.26.16.214', 0),
	(2, 10114, '3.26.16.214', 1),
	(2, 10048, '3.26.16.61', 0),
	(2, 10048, '3.26.16.61', 1),
	(2, 10898, '3.26.5.288', 1),
	(2, 10899, '3.26.5.288', 1),
	(2, 10900, '3.26.5.288', 1),
	(2, 10901, '3.26.5.288', 1),
	(2, 10902, '3.26.5.288', 1),
	(2, 10903, '3.26.5.288', 1),
	(2, 10904, '3.26.5.288', 1),
	(2, 10905, '3.26.5.288', 1),
	(2, 10912, '3.27.5.150', 1),
	(2, 10914, '3.27.5.150', 1),
	(2, 10084, '3.28.1.139', 0),
	(2, 10084, '3.28.1.139', 1),
	(2, 10418, '3.28.4.78', 0),
	(2, 10418, '3.28.4.78', 1),
	(2, 10762, '3.28.5.85', 0),
	(2, 10762, '3.28.5.85', 1),
	(2, 10840, '3.30.1.242', 0),
	(2, 10840, '3.30.1.242', 1),
	(2, 10749, '3.30.3.242', 0),
	(2, 10749, '3.30.3.242', 1),
	(2, 10893, '3.30.8.261', 1),
	(2, 10003, '3.33.1.152', 1),
	(2, 10109, '3.34.16.281', 0),
	(2, 10109, '3.34.16.281', 1),
	(2, 10108, '3.34.16.97', 0),
	(2, 10108, '3.34.16.97', 1),
	(2, 10110, '3.34.16.97', 0),
	(2, 10110, '3.34.16.97', 1),
	(2, 10755, '3.34.17.193', 0),
	(2, 10755, '3.34.17.193', 1),
	(2, 10756, '3.34.17.193', 0),
	(2, 10756, '3.34.17.193', 1),
	(2, 10757, '3.34.17.193', 0),
	(2, 10757, '3.34.17.193', 1),
	(2, 10758, '3.34.17.193', 0),
	(2, 10758, '3.34.17.193', 1),
	(2, 10754, '3.34.17.228', 0),
	(2, 10754, '3.34.17.228', 1),
	(2, 10879, '3.34.17.4', 1),
	(2, 10590, '3.34.7.228', 0),
	(2, 10590, '3.34.7.228', 1),
	(2, 10896, '3.35.1.139', 1),
	(2, 10004, '3.35.1.242', 1),
	(2, 10015, '3.36.16.167', 0),
	(2, 10015, '3.36.16.167', 1),
	(2, 10767, '3.36.17.246', 0),
	(2, 10767, '3.36.17.246', 1),
	(2, 10008, '3.36.17.29', 0),
	(2, 10008, '3.36.17.29', 1),
	(2, 10877, '3.36.17.29', 1),
	(2, 10013, '3.36.21.228', 0),
	(2, 10013, '3.36.21.228', 1),
	(2, 10771, '3.36.21.228', 1),
	(2, 10213, '3.36.6.105', 0),
	(2, 10213, '3.36.6.105', 1),
	(2, 10045, '3.36.6.5', 0),
	(2, 10045, '3.36.6.5', 1),
	(2, 10041, '3.37.16.179', 0),
	(2, 10041, '3.37.16.179', 1),
	(2, 10102, '3.38.1.139', 0),
	(2, 10102, '3.38.1.139', 1),
	(2, 10104, '3.38.1.139', 0),
	(2, 10104, '3.38.1.139', 1),
	(2, 10106, '3.38.1.139', 0),
	(2, 10106, '3.38.1.139', 1),
	(2, 10105, '3.38.1.150', 0),
	(2, 10105, '3.38.1.150', 1),
	(2, 10107, '3.38.1.150', 0),
	(2, 10107, '3.38.1.150', 1),
	(2, 10530, '3.38.14.139', 1),
	(2, 10531, '3.38.14.139', 1),
	(2, 10532, '3.38.14.139', 1),
	(2, 10533, '3.38.14.150', 1),
	(2, 10534, '3.38.14.150', 1),
	(2, 10535, '3.38.14.150', 1),
	(2, 10583, '3.38.9.218', 0),
	(2, 10583, '3.38.9.218', 1),
	(2, 10584, '3.38.9.218', 0),
	(2, 10584, '3.38.9.218', 1),
	(2, 10585, '3.38.9.218', 0),
	(2, 10585, '3.38.9.218', 1),
	(2, 10768, '3.4.5.20', 0),
	(2, 10768, '3.4.5.20', 1),
	(2, 10033, '3.5.12.24', 0),
	(2, 10033, '3.5.12.24', 1),
	(2, 10034, '3.5.12.24', 0),
	(2, 10034, '3.5.12.24', 1),
	(2, 10854, '3.5.13.185', 1),
	(2, 10837, '3.5.13.284', 0),
	(2, 10837, '3.5.13.284', 1),
	(2, 10873, '3.5.13.284', 0),
	(2, 10873, '3.5.13.284', 1),
	(2, 10112, '3.5.16.141', 0),
	(2, 10112, '3.5.16.141', 1),
	(2, 10257, '3.5.17.179', 0),
	(2, 10257, '3.5.17.179', 1),
	(2, 10053, '3.5.17.242', 0),
	(2, 10053, '3.5.17.242', 1),
	(2, 10010, '3.5.6.185', 0),
	(2, 10010, '3.5.6.185', 1),
	(2, 10011, '3.5.6.185', 0),
	(2, 10011, '3.5.6.185', 1),
	(2, 10760, '3.5.7.55', 0),
	(2, 10760, '3.5.7.55', 1),
	(2, 10554, '3.6.13.185', 1),
	(2, 10591, '3.6.13.273', 0),
	(2, 10591, '3.6.13.273', 1),
	(2, 10592, '3.6.13.274', 0),
	(2, 10592, '3.6.13.274', 1),
	(2, 10593, '3.6.13.275', 0),
	(2, 10593, '3.6.13.275', 1),
	(2, 10849, '3.6.14.139', 1),
	(2, 10745, '3.6.14.178', 1),
	(2, 10746, '3.6.14.178', 1),
	(2, 10747, '3.6.14.178', 1),
	(2, 10733, '3.8.20.178', 1),
	(3, 10046, '0001', 1),
	(3, 10047, '0002', 1),
	(3, 10014, '0003.0004', 1),
	(3, 10015, '0006', 1),
	(3, 10213, '0006', 1),
	(3, 10224, '0006', 1),
	(3, 10031, '0007', 1),
	(3, 10051, '0007', 1),
	(3, 10055, '0007', 1),
	(3, 10077, '0007', 1),
	(3, 10017, '0008', 1),
	(3, 10018, '0008', 1),
	(3, 10032, '0008', 1),
	(3, 10033, '0008', 1),
	(3, 10034, '0008', 1),
	(3, 10036, '0008', 1),
	(3, 10037, '0008', 1),
	(3, 10038, '0008', 1),
	(3, 10039, '0008', 1),
	(3, 10040, '0008', 1),
	(3, 10041, '0008', 1),
	(3, 10044, '0008', 1),
	(3, 10048, '0008', 1),
	(3, 10059, '0008', 1),
	(3, 10060, '0008', 1),
	(3, 10069, '0008', 1),
	(3, 10085, '0008', 1),
	(3, 10086, '0008', 1),
	(3, 10087, '0008', 1),
	(3, 10088, '0008', 1),
	(3, 10089, '0008', 1),
	(3, 10090, '0008', 1),
	(3, 10091, '0008', 1),
	(3, 10108, '0008', 1),
	(3, 10109, '0008', 1),
	(3, 10110, '0008', 1),
	(3, 10111, '0008', 1),
	(3, 10112, '0008', 1),
	(3, 10113, '0008', 1),
	(3, 10114, '0008', 1),
	(3, 10042, '0009', 1),
	(3, 10023, '0100', 1),
	(3, 10028, '0100', 1),
	(3, 10045, '0100', 1),
	(3, 10081, '0100', 1),
	(3, 10082, '0100', 1),
	(3, 10083, '0100', 1),
	(3, 10214, '0100', 1),
	(3, 10220, '0100', 1),
	(3, 10272, '0100', 1),
	(3, 10273, '0100', 1),
	(3, 10274, '0100', 1),
	(3, 10000, '0200.0203', 1),
	(3, 10001, '0201.0204', 1),
	(3, 10002, '0202.0205', 1),
	(3, 10029, '0300.0301', 1),
	(3, 10030, '0303.0302', 1),
	(3, 10076, '0304', 1),
	(3, 10053, '0304.0305', 1),
	(3, 10078, '0304.0305', 1),
	(4, 10046, '0001', 1),
	(4, 10047, '0002', 1),
	(4, 10015, '0006', 1),
	(4, 10031, '0007', 1),
	(4, 10032, '0008', 1),
	(4, 10042, '0009', 1),
	(4, 10045, '0100', 1),
	(4, 10000, '0200.0203', 1),
	(4, 10001, '0201.0204', 1),
	(4, 10002, '0202.0205', 1),
	(4, 10029, '0300.0301', 1),
	(4, 10030, '0303.0302', 1),
	(4, 10053, '0304.0305', 1),
	(5, -50079, '0.0.1.0.0.255', 1),
	(5, -50003, '0.0.1.0.0.255', 1),
	(5, -50002, '0.0.1.0.0.255', 1),
	(5, -50359, '0.0.11.0.0.255', 1),
	(5, -50358, '0.0.11.0.0.255', 1),
	(5, -50357, '0.0.13.0.0.255', 1),
	(5, -50356, '0.0.13.0.0.255', 1),
	(5, -50355, '0.0.13.0.0.255', 1),
	(5, -50352, '0.0.13.0.0.255', 1),
	(5, -50351, '0.0.13.0.0.255', 1),
	(5, -50348, '0.0.13.0.0.255', 1),
	(5, -50347, '0.0.13.0.0.255', 1),
	(5, -50344, '0.0.13.0.0.255', 1),
	(5, -50343, '0.0.13.0.0.255', 1),
	(5, -50342, '0.0.13.0.0.255', 1),
	(5, -50341, '0.0.13.0.0.255', 1),
	(5, -50338, '0.0.13.0.0.255', 1),
	(5, -50337, '0.0.13.0.0.255', 1),
	(5, 10881, '0.0.97.98.0.255', 1),
	(5, -5, '1.0.0.0.0.255', 1),
	(5, -50022, '1.0.0.0.1.255', 1),
	(5, -50078, '1.0.0.0.2.255', 1),
	(5, -3, '1.0.0.2.0.255', 1),
	(5, -50073, '1.0.0.3.0.255', 1),
	(5, -50336, '1.0.0.3.3.255', 1),
	(5, -8, '1.0.0.8.4.255', 1),
	(5, -50077, '1.0.96.1.1.255', 1),
	(5, -7, '1.0.96.1.2.255', 1),
	(5, -50407, '1.0.96.69.2.0', 1),
	(5, -50406, '1.0.96.69.2.0', 1),
	(5, -50405, '1.0.96.69.2.0', 1),
	(5, -50404, '1.0.96.69.2.0', 1),
	(5, -50411, '1.0.96.69.2.1', 1),
	(5, -50410, '1.0.96.69.2.1', 1),
	(5, -50409, '1.0.96.69.2.1', 1),
	(5, -50408, '1.0.96.69.2.1', 1),
	(5, -50415, '1.0.96.69.2.2', 1),
	(5, -50414, '1.0.96.69.2.2', 1),
	(5, -50413, '1.0.96.69.2.2', 1),
	(5, -50412, '1.0.96.69.2.2', 1),
	(5, -50319, '1.0.96.69.3.0', 1),
	(5, -50403, '1.0.96.69.6.255', 1),
	(5, -50402, '1.0.96.69.6.255', 1),
	(5, -50388, '1.0.96.69.6.255', 1),
	(5, -50217, '1.0.96.81.0.255', 1),
	(5, -50416, '1.0.96.82.0.255', 1),
	(5, -50222, '1.0.96.82.0.255', 1),
	(5, 10010, '1.0.96.90.10.255', 1),
	(5, -50511, '1.0.98.1.0.126', 1),
	(5, -50500, '1.0.98.1.0.126', 1),
	(5, -50499, '1.0.98.1.0.126', 1),
	(5, -50498, '1.0.98.1.0.126', 1),
	(5, -50497, '1.0.98.1.0.126', 1),
	(5, -50496, '1.0.99.1.0.255', 1),
	(5, -50495, '1.0.99.1.0.255', 1),
	(5, -50494, '1.0.99.1.0.255', 1),
	(5, -50493, '1.0.99.1.0.255', 1),
	(5, -50304, '1.0.99.1.0.255', 1);
/*!40000 ALTER TABLE `catalog_withe` ENABLE KEYS */;

-- Dumping structure for table emcor.ci_lob
CREATE TABLE IF NOT EXISTS `ci_lob` (
  `data` longtext COLLATE utf8_bin DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- Dumping data for table emcor.ci_lob: ~0 rows (approximately)
/*!40000 ALTER TABLE `ci_lob` DISABLE KEYS */;
INSERT INTO `ci_lob` (`data`) VALUES
	('<?xml version="1.0" encoding="Windows-1257"?>\r\n\n<Gp>\r\n\n    <Gr code="PAKR" name="Pakruojo rajonas" type_code="REGION" parent_code="ALL.ROOT">\r\n\n    </Gr>\r\n\n    <Gr code="PAKR.PAKR" name="Pakruojis" type_code="TOWN" parent_code="PAKR">\r\n\n    </Gr>\r\n\n    <Gr code="PAKR.PAKR.GIRIA" name="Giria" type_code="OBJ" parent_code="PAKR.PAKR"  parent_bt="2008-12-30">\r\n\n     <Point code=" PAKR.PAKR.GIRIA.G-1" name="Generatorius Nr.1" ecp_code="ĮVADAS" mlset_code="EKOM-3000">\r\n\n      <Meter number="256896" type_name="LZQM" bt="2008-12-24T14:34:57">\r\n\n	 <Pty code="LAST_TEST_DATE" value="2009-04-15"/>\r\n\n	 <Pty code="NEXT_TEST_DATE" value="2010-04-15"/>\r\n\n	 </Meter>\r\n\n     </Point>\r\n\n     <Point code="PAKR.PAKR.GIRIA.F-1" name="Fideris Nr.1" ecp_code="NUOM" mlset_code="ELEKTRA.LZQM.30">\r\n\n	 <Pty code="POINT_LOCATION_DESC" value="Prie griovio"/>\r\n\n	</Point>\r\n\n     <Point code="PAKR.PAKR.GIRIA.F-2" name="Fideris Nr.2" ecp_code="NUOM" mlset_code="ELEKTRA.LZQM.30"/>\r\n\n    </Gr>\r\n\n    <Gr code="PAKR.KOK" name="Kokis" type_code="TOWN" parent_code="PAKR">\r\n\n    </Gr>\r\n\n</Gp>\r\n\n');
/*!40000 ALTER TABLE `ci_lob` ENABLE KEYS */;

-- Dumping structure for table emcor.col
CREATE TABLE IF NOT EXISTS `col` (
  `col_id` mediumint(8) unsigned NOT NULL COMMENT 'Lauko identifikatorius',
  `col_typ` varchar(1) COLLATE utf8_bin NOT NULL COMMENT 'Lauko tipo kodas',
  `col_name` varchar(30) COLLATE utf8_bin NOT NULL COMMENT 'Lauko vardas',
  PRIMARY KEY (`col_id`),
  UNIQUE KEY `col_name_u` (`col_name`),
  CONSTRAINT `COL_COL_TYP_CHK` CHECK (`col_typ` in ('D','I','N','C'))
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Laukai';

-- Dumping data for table emcor.col: ~766 rows (approximately)
/*!40000 ALTER TABLE `col` DISABLE KEYS */;
INSERT INTO `col` (`col_id`, `col_typ`, `col_name`) VALUES
	(1, 'C', 'ACT_DESC'),
	(2, 'I', 'ACT_ENABLED'),
	(3, 'I', 'ACT_ID'),
	(4, 'D', 'ACT_MONTH'),
	(5, 'C', 'ACT_NUMBER'),
	(6, 'I', 'ACT_TYPE_ID'),
	(7, 'C', 'ACT_TYPE_NAME'),
	(8, 'N', 'ACT_VALUE'),
	(9, 'I', 'AGGF_ID'),
	(10, 'C', 'AGGF_NAME'),
	(11, 'I', 'AGGS_ID'),
	(12, 'C', 'AGGS_NAME'),
	(13, 'I', 'AGGS_TYPE_ID'),
	(14, 'C', 'AGGS_TYPE_NAME'),
	(15, 'I', 'AI_DEPTH'),
	(16, 'I', 'AI_DEPTH_PER_ID'),
	(17, 'I', 'AI_LAG'),
	(18, 'I', 'AI_LAG_PER_ID'),
	(19, 'N', 'AI_WEIGHT'),
	(20, 'C', 'ALGR_CODE'),
	(21, 'I', 'ALGR_ID'),
	(22, 'I', 'AL_ID'),
	(23, 'I', 'BDD'),
	(24, 'C', 'BGA_CLASS_CODE'),
	(25, 'I', 'BGA_CLASS_ID'),
	(26, 'C', 'BGA_CLASS_NAME'),
	(27, 'I', 'BGA_ENABLED'),
	(28, 'I', 'BGA_ID'),
	(29, 'C', 'BGA_NAME'),
	(30, 'I', 'BGAO_STATUS'),
	(31, 'C', 'BGA_PARAM_DEFAULT_VALUE'),
	(32, 'I', 'BGA_PARAM_NR'),
	(33, 'C', 'BGA_PARAM_VALUE'),
	(34, 'C', 'BGA_PARAM_VALUE_DESC'),
	(35, 'C', 'BGAQ_CODE'),
	(36, 'I', 'BGAQ_ID'),
	(37, 'C', 'BGAQ_NAME'),
	(38, 'C', 'BGA_TYPE_CODE'),
	(39, 'C', 'BGA_TYPE_DECLARE'),
	(40, 'C', 'BGA_TYPE_DESC'),
	(41, 'I', 'BGA_TYPE_ID'),
	(42, 'C', 'BGA_TYPE_NAME'),
	(43, 'C', 'BGA_TYPE_PARAM_DESC'),
	(44, 'C', 'BGA_TYPE_PARAM_KEY'),
	(45, 'I', 'BGA_TYPE_PARAM_NR'),
	(46, 'I', 'BGA_TYPE_PARAM_REGULAR'),
	(47, 'C', 'BGA_TYPE_POST_ACTION'),
	(48, 'C', 'BGA_TYPE_PRE_ACTION'),
	(49, 'C', 'BGA_TYPE_REC_ACTION'),
	(50, 'C', 'BGA_TYPE_SELECT'),
	(51, 'I', 'BHH'),
	(52, 'I', 'BYP_DIR_INV'),
	(53, 'I', 'BYP_ENABLED'),
	(54, 'I', 'BYP_INV'),
	(55, 'I', 'BYP_MODE'),
	(56, 'I', 'BYP_POINT_ID'),
	(57, 'I', 'BMM'),
	(58, 'D', 'BT'),
	(59, 'I', 'CALC_LAG'),
	(60, 'I', 'CALC_LAG_PER_ID'),
	(61, 'C', 'CAP_CODE'),
	(62, 'I', 'CAP_ID'),
	(63, 'C', 'CAP_NAME'),
	(64, 'C', 'CAP_PARAM_DESC'),
	(65, 'I', 'CAP_PARAM_NR'),
	(66, 'C', 'CAP_TEXT'),
	(67, 'C', 'CAP_TEXT_DEFAULT'),
	(68, 'I', 'CH_CNT'),
	(69, 'I', 'CH_DPT'),
	(70, 'I', 'CH_DSC'),
	(71, 'I', 'CH_GRP'),
	(72, 'I', 'CH_PNT'),
	(73, 'I', 'CH_STEADY'),
	(74, 'N', 'COEF'),
	(75, 'N', 'COEF_I_DENOMINATOR'),
	(76, 'N', 'COEF_I_NUMERATOR'),
	(77, 'N', 'COEF_U_DENOMINATOR'),
	(78, 'N', 'COEF_U_NUMERATOR'),
	(79, 'C', 'COLUMN_NAME'),
	(80, 'I', 'COMP_DIR_ID'),
	(81, 'I', 'COMP_EC_ID'),
	(82, 'I', 'COMP_ID'),
	(83, 'I', 'COMP_MS_ID'),
	(84, 'I', 'COMP_TYPE_ID'),
	(85, 'N', 'CONST_VAL'),
	(86, 'I', 'CONT_DIR_ID'),
	(87, 'I', 'CONT_EC_ID'),
	(88, 'I', 'CONT_ID'),
	(89, 'I', 'CONT_MS_ID'),
	(90, 'I', 'CONT_TYPE_ID'),
	(91, 'I', 'COSTA_B_EXP_VALUE'),
	(92, 'I', 'COSTA_B_PER_ID'),
	(93, 'I', 'COSTA_G_EXP_VALUE'),
	(94, 'I', 'COSTA_G_PER_ID'),
	(95, 'C', 'CUSTOMER_NAME'),
	(96, 'C', 'CVAL'),
	(97, 'C', 'DA_DESC'),
	(98, 'I', 'DAS_ENABLED'),
	(99, 'I', 'DAS_ID'),
	(100, 'C', 'DAS_NAME'),
	(101, 'C', 'DATA_TYPE'),
	(102, 'D', 'DB_TIME'),
	(103, 'C', 'DBU'),
	(104, 'I', 'DC_ENABLED'),
	(105, 'I', 'DC_ID'),
	(106, 'C', 'DC_NAME'),
	(107, 'I', 'DD'),
	(108, 'D', 'DEV_DP_BT'),
	(109, 'D', 'DEV_DP_ET'),
	(110, 'I', 'DEVDP_ID'),
	(111, 'I', 'DEV_ID'),
	(112, 'C', 'DEV_NUMBER'),
	(113, 'I', 'DEV_TYPE_ID'),
	(114, 'C', 'DEV_TYPE_NAME'),
	(115, 'I', 'DEW_DEPTH'),
	(116, 'I', 'DEW_ENABLED'),
	(117, 'I', 'DEW_ID'),
	(118, 'C', 'DEW_NAME'),
	(119, 'I', 'DI_ENABLED'),
	(120, 'I', 'DI_ID'),
	(121, 'C', 'DIR_CODE'),
	(122, 'I', 'DIR_ID'),
	(123, 'I', 'DL_TYPE_ID'),
	(124, 'C', 'DL_TYPE_NAME'),
	(125, 'C', 'DP_CODE'),
	(126, 'I', 'DP_DELETED'),
	(127, 'I', 'DP_ENABLED'),
	(128, 'I', 'DP_ID'),
	(129, 'I', 'DP_INTERNAL'),
	(130, 'C', 'DP_NAME'),
	(131, 'I', 'DPR_ID'),
	(132, 'C', 'DPR_NAME'),
	(133, 'I', 'DP_TYPE_ID'),
	(134, 'C', 'DP_TYPE_NAME'),
	(135, 'I', 'DS_BINARY'),
	(136, 'C', 'DS_CODE'),
	(137, 'C', 'DS_DATA_DESC'),
	(138, 'I', 'DS_ENABLED'),
	(139, 'I', 'DS_EVENT_LOG'),
	(140, 'I', 'DS_ID'),
	(141, 'C', 'DS_NAME'),
	(142, 'I', 'DS_NR'),
	(143, 'D', 'DS_RT'),
	(144, 'I', 'DS_RT_ENABLED'),
	(145, 'D', 'DS_T'),
	(146, 'I', 'DST'),
	(147, 'C', 'DSTATUS'),
	(148, 'C', 'DS_TYPE_CODE'),
	(149, 'I', 'DS_TYPE_GR_PRIORITY'),
	(150, 'I', 'DS_TYPE_ID'),
	(151, 'C', 'DS_TYPE_NAME'),
	(152, 'I', 'DS_V'),
	(153, 'I', 'DU_CNT'),
	(154, 'I', 'DU_DPT'),
	(155, 'I', 'DU_DSC'),
	(156, 'I', 'DU_GRP'),
	(157, 'I', 'DU_PNT'),
	(158, 'I', 'DU_STEADY'),
	(159, 'C', 'EC_CODE'),
	(160, 'I', 'EC_ID'),
	(161, 'C', 'EC_IN'),
	(162, 'C', 'EC_NAME'),
	(163, 'C', 'ECP_CODE'),
	(164, 'I', 'ECP_ID'),
	(165, 'C', 'ECP_NAME'),
	(166, 'I', 'EDD'),
	(167, 'I', 'EHH'),
	(168, 'I', 'ELSE_TFF_ID'),
	(169, 'I', 'EMM'),
	(170, 'C', 'ENUM_CODE'),
	(171, 'I', 'ENUM_DATA_NR'),
	(172, 'I', 'ENUM_ID'),
	(173, 'C', 'ENUM_NAME'),
	(174, 'C', 'ENUM_TYPE_CODE'),
	(175, 'I', 'ENUM_TYPE_ID'),
	(176, 'C', 'ENUM_TYPE_NAME'),
	(177, 'C', 'ENUM_VALUE'),
	(178, 'C', 'ENUM_VALUE_DESC'),
	(179, 'C', 'EPTY_CODE'),
	(180, 'I', 'EPTY_ID'),
	(181, 'C', 'EPTY_NAME'),
	(182, 'I', 'EPTY_NR'),
	(183, 'I', 'EPTY_NUMERIC'),
	(184, 'C', 'EPTY_TYPE_CODE'),
	(185, 'I', 'EPTY_TYPE_ID'),
	(186, 'C', 'EPTY_TYPE_NAME'),
	(187, 'C', 'EPTY_VALUE'),
	(188, 'D', 'ET'),
	(189, 'I', 'EVA_BLOCK'),
	(190, 'I', 'EVA_BLOCK_DURATION'),
	(191, 'D', 'EVA_BLOCKED_UNTIL'),
	(192, 'I', 'EVA_BLOCK_TYPE_ID'),
	(193, 'I', 'EVAC_INV'),
	(194, 'I', 'EVAC_NR'),
	(195, 'C', 'EVA_CODE'),
	(196, 'I', 'EVAC_TYPE_ID'),
	(197, 'C', 'EVAC_TYPE_NAME'),
	(198, 'I', 'EVA_ENABLED'),
	(199, 'I', 'EVA_ID'),
	(200, 'I', 'EVA_IMMEDIATE'),
	(201, 'C', 'EVA_NAME'),
	(202, 'I', 'EVA_TYPE_ID'),
	(203, 'C', 'EVA_TYPE_NAME'),
	(204, 'D', 'EXPIRATION'),
	(205, 'D', 'EXPL_START'),
	(206, 'C', 'FFP_CODE'),
	(207, 'I', 'FFP_DATA_ID'),
	(208, 'C', 'FFP_DATA_NAME'),
	(209, 'I', 'FFP_ID'),
	(210, 'C', 'FFP_NAME'),
	(211, 'C', 'FFP_TYPE'),
	(212, 'I', 'FFP_VAL_KEY_1'),
	(213, 'I', 'FFP_VAL_KEY_2'),
	(214, 'C', 'FFP_VAL_KEY_3'),
	(215, 'I', 'FFP_VAL_ROW_NUM'),
	(216, 'I', 'FFP_VAL_SORT_NUM'),
	(217, 'C', 'FFP_VT_CODE'),
	(218, 'I', 'FFP_VT_ID'),
	(219, 'I', 'FIB_ID'),
	(220, 'I', 'FIXED_TFF_ID'),
	(221, 'C', 'FOLDER'),
	(222, 'I', 'FORCED'),
	(223, 'I', 'FORM_IF_EMPTY'),
	(224, 'C', 'FP_CODE'),
	(225, 'I', 'FP_ID'),
	(226, 'C', 'FP_NAME'),
	(227, 'I', 'FP_NR'),
	(228, 'C', 'FPTY_CODE'),
	(229, 'I', 'FPTY_ID'),
	(230, 'C', 'FPTY_VALUE'),
	(231, 'I', 'GEW_DEPTH'),
	(232, 'I', 'GEW_ENABLED'),
	(233, 'I', 'GEW_ID'),
	(234, 'C', 'GEW_NAME'),
	(235, 'I', 'GMA_MA_TMPL_ID'),
	(236, 'C', 'GMA_TMPL_CODE'),
	(237, 'I', 'GMA_TMPL_ID'),
	(238, 'C', 'GMA_TMPL_NAME'),
	(239, 'C', 'GMOD_CODE'),
	(240, 'N', 'GMOD_CONST'),
	(241, 'I', 'GMOD_DATA_NR'),
	(242, 'C', 'GMOD_EU_CODE'),
	(243, 'I', 'GMOD_EU_CODE_USAGE'),
	(244, 'I', 'GMOD_ID'),
	(245, 'C', 'GMOD_NAME'),
	(246, 'C', 'GPRC'),
	(247, 'C', 'GPTY_CODE'),
	(248, 'I', 'GPTY_ID'),
	(249, 'N', 'GPTY_MA_A_DENOM'),
	(250, 'N', 'GPTY_MA_A_NOM'),
	(251, 'N', 'GPTY_MA_B'),
	(252, 'C', 'GPTY_NAME'),
	(253, 'I', 'GPTY_NR'),
	(254, 'I', 'GPTY_NUMERIC'),
	(255, 'C', 'GPTY_TYPE_CODE'),
	(256, 'I', 'GPTY_TYPE_ID'),
	(257, 'C', 'GPTY_TYPE_NAME'),
	(258, 'C', 'GPTY_VALUE'),
	(259, 'D', 'GRC_BT'),
	(260, 'C', 'GRC_DESC'),
	(261, 'D', 'GRC_ET'),
	(262, 'I', 'GRC_NR'),
	(263, 'C', 'GR_CODE'),
	(264, 'I', 'GR_DIR_ID'),
	(265, 'I', 'GR_EC_ID'),
	(266, 'I', 'GR_ID'),
	(267, 'I', 'GR_MS_ID'),
	(268, 'C', 'GR_NAME'),
	(269, 'D', 'GRP_BT'),
	(270, 'C', 'GRP_DESC'),
	(271, 'D', 'GRP_ET'),
	(272, 'I', 'GRP_NR'),
	(273, 'C', 'GR_TYPE_CODE'),
	(274, 'I', 'GR_TYPE_ID'),
	(275, 'C', 'GR_TYPE_NAME'),
	(276, 'D', 'GTP_BT'),
	(277, 'D', 'GTP_ET'),
	(278, 'I', 'GTP_ID'),
	(279, 'D', 'HDAY'),
	(280, 'I', 'HH_SPECIFIC'),
	(281, 'I', 'HH1'),
	(282, 'I', 'HH10'),
	(283, 'I', 'HH11'),
	(284, 'I', 'HH12'),
	(285, 'I', 'HH13'),
	(286, 'I', 'HH14'),
	(287, 'I', 'HH15'),
	(288, 'I', 'HH16'),
	(289, 'I', 'HH17'),
	(290, 'I', 'HH18'),
	(291, 'I', 'HH19'),
	(292, 'I', 'HH2'),
	(293, 'I', 'HH20'),
	(294, 'I', 'HH21'),
	(295, 'I', 'HH22'),
	(296, 'I', 'HH23'),
	(297, 'I', 'HH24'),
	(298, 'I', 'HH3'),
	(299, 'I', 'HH4'),
	(300, 'I', 'HH5'),
	(301, 'I', 'HH6'),
	(302, 'I', 'HH7'),
	(303, 'I', 'HH8'),
	(304, 'I', 'HH9'),
	(305, 'I', 'HLD_ID'),
	(306, 'C', 'HLD_NAME'),
	(307, 'I', 'IGNORE_GROUP_VALUE'),
	(308, 'I', 'IGNORE_MA_AB'),
	(309, 'I', 'IGNORE_READ_DATA'),
	(310, 'I', 'IGNORE_SE_AB'),
	(311, 'I', 'IGNORE_STEADY_VAL_RESTORE'),
	(312, 'I', 'INHERIT_CN'),
	(313, 'I', 'INHERIT_SRC_NUMBER'),
	(314, 'I', 'IS_POINT'),
	(315, 'I', 'IS_PUBLIC'),
	(316, 'I', 'LC_ENABLED'),
	(317, 'C', 'LICENSE_KEY'),
	(318, 'C', 'LICENSE_KEY2'),
	(319, 'I', 'LP_ID'),
	(320, 'C', 'LP_NAME'),
	(321, 'I', 'LP_PRIORITY'),
	(322, 'C', 'LPTY_CODE'),
	(323, 'I', 'LPTY_ID'),
	(324, 'C', 'LPTY_VALUE'),
	(325, 'C', 'LTC_CODE'),
	(326, 'I', 'LTC_ID'),
	(327, 'I', 'MA_AB'),
	(328, 'N', 'MA_A_DENOM'),
	(329, 'N', 'MA_A_NOM'),
	(330, 'I', 'MA_AUTO_CCS'),
	(331, 'I', 'MA_AUTO_CHECK'),
	(332, 'I', 'MA_AUTO_NULL_ACT'),
	(333, 'N', 'MA_B'),
	(334, 'D', 'MADE'),
	(335, 'I', 'MA_ENABLED'),
	(336, 'I', 'MA_ID'),
	(337, 'I', 'MA_LAG'),
	(338, 'I', 'MA_LAG_PER_ID'),
	(339, 'I', 'MAP_ENABLED'),
	(340, 'I', 'MAP_ID'),
	(341, 'I', 'MA_REPORT_EXCEEDING'),
	(342, 'I', 'MA_SHOW'),
	(343, 'D', 'MCC_T'),
	(344, 'I', 'MD_CNT'),
	(345, 'C', 'MD_CODE'),
	(346, 'I', 'MD_ID'),
	(347, 'I', 'MD_ID_FOR_INSTANT'),
	(348, 'C', 'METER_CLASS'),
	(349, 'I', 'METER_ID'),
	(350, 'C', 'METER_NUMBER'),
	(351, 'I', 'METER_TYPE_ID'),
	(352, 'C', 'METER_TYPE_NAME'),
	(353, 'C', 'METER_TYPE_PRODUCER'),
	(354, 'C', 'ML_NAME'),
	(355, 'I', 'ML_ID'),
	(356, 'C', 'MLSET_CODE'),
	(357, 'I', 'MLSET_ID'),
	(358, 'C', 'MLSET_NAME'),
	(359, 'I', 'MM'),
	(360, 'I', 'MO_SPECIFIC'),
	(361, 'D', 'MOU_BT'),
	(362, 'D', 'MOU_BT_DB_TIME'),
	(363, 'C', 'MOU_BT_NUMBER'),
	(364, 'D', 'MOU_ET'),
	(365, 'D', 'MOU_ET_DB_TIME'),
	(366, 'C', 'MOU_ET_NUMBER'),
	(367, 'I', 'MOU_ID'),
	(368, 'I', 'MOU_TYPE_ID'),
	(369, 'C', 'MOU_TYPE_NAME'),
	(370, 'I', 'MO1'),
	(371, 'I', 'MO10'),
	(372, 'I', 'MO11'),
	(373, 'I', 'MO12'),
	(374, 'I', 'MO2'),
	(375, 'I', 'MO3'),
	(376, 'I', 'MO4'),
	(377, 'I', 'MO5'),
	(378, 'I', 'MO6'),
	(379, 'I', 'MO7'),
	(380, 'I', 'MO8'),
	(381, 'I', 'MO9'),
	(382, 'C', 'MPTY_CODE'),
	(383, 'I', 'MPTY_ID'),
	(384, 'C', 'MPTY_NAME'),
	(385, 'I', 'MPTY_NR'),
	(386, 'C', 'MPTY_TYPE_CODE'),
	(387, 'I', 'MPTY_TYPE_ID'),
	(388, 'C', 'MPTY_TYPE_NAME'),
	(389, 'C', 'MPTY_VALUE'),
	(390, 'C', 'MS_CODE'),
	(391, 'I', 'MS_ID'),
	(392, 'I', 'MS_TYPE_ID'),
	(393, 'C', 'MS_TYPE_NAME'),
	(394, 'I', 'MT_ID'),
	(395, 'I', 'NR'),
	(396, 'I', 'NVAL1'),
	(397, 'I', 'NVAL2'),
	(398, 'I', 'OC_CNT'),
	(399, 'I', 'OC_DPT'),
	(400, 'I', 'OC_DSC'),
	(401, 'I', 'OC_GRP'),
	(402, 'I', 'OC_PNT'),
	(403, 'I', 'PASSED_SAMP_COUNT'),
	(404, 'D', 'PCK_T'),
	(405, 'C', 'PER_CODE'),
	(406, 'I', 'PER_ID'),
	(407, 'I', 'PH_DELETED'),
	(408, 'I', 'PH_ENABLED'),
	(409, 'I', 'PH_FAILURE_COUNT'),
	(410, 'I', 'PH_ID'),
	(411, 'C', 'PH_LAYER_CODE'),
	(412, 'I', 'PH_LAYER_ID'),
	(413, 'C', 'PH_NAME'),
	(414, 'I', 'PH_SAVE_STATISTICS'),
	(415, 'I', 'PH_TYPE_ID'),
	(416, 'C', 'PH_TYPE_NAME'),
	(417, 'I', 'PL_DL'),
	(418, 'I', 'PL_ENABLED'),
	(419, 'I', 'PL_ID'),
	(420, 'D', 'PL_RT'),
	(421, 'D', 'PL_T'),
	(422, 'N', 'PL_V'),
	(423, 'I', 'PMA_MA_TMPL_ID'),
	(424, 'C', 'PMA_TMPL_CODE'),
	(425, 'I', 'PMA_TMPL_ID'),
	(426, 'C', 'PMA_TMPL_NAME'),
	(427, 'I', 'POINT_AUTO_READ_ENABLED'),
	(428, 'C', 'POINT_CODE'),
	(429, 'I', 'POINT_COMMERCIAL'),
	(430, 'C', 'POINT_C01'),
	(431, 'C', 'POINT_C02'),
	(432, 'C', 'POINT_C03'),
	(433, 'C', 'POINT_C04'),
	(434, 'C', 'POINT_C05'),
	(435, 'C', 'POINT_C06'),
	(436, 'C', 'POINT_C07'),
	(437, 'C', 'POINT_C08'),
	(438, 'C', 'POINT_C09'),
	(439, 'C', 'POINT_C10'),
	(440, 'I', 'POINT_DIR_ID'),
	(441, 'I', 'POINT_ENABLED'),
	(442, 'I', 'POINT_ID'),
	(443, 'I', 'POINT_INTERNAL'),
	(444, 'I', 'POINT_LIMIT'),
	(445, 'I', 'POINT_MS_ID'),
	(446, 'C', 'POINT_NAME'),
	(447, 'C', 'POINT_TYPE_CODE'),
	(448, 'I', 'POINT_TYPE_ID'),
	(449, 'C', 'POINT_TYPE_NAME'),
	(450, 'C', 'POS_CODE'),
	(451, 'C', 'POS_DESC'),
	(452, 'I', 'POS_NR'),
	(453, 'C', 'PPTY_CODE'),
	(454, 'I', 'PPTY_ID'),
	(455, 'N', 'PPTY_MA_A_DENOM'),
	(456, 'N', 'PPTY_MA_A_NOM'),
	(457, 'N', 'PPTY_MA_B'),
	(458, 'C', 'PPTY_NAME'),
	(459, 'I', 'PPTY_NR'),
	(460, 'I', 'PPTY_NUMERIC'),
	(461, 'C', 'PPTY_TYPE_CODE'),
	(462, 'I', 'PPTY_TYPE_ID'),
	(463, 'C', 'PPTY_TYPE_NAME'),
	(464, 'C', 'PPTY_VALUE'),
	(465, 'D', 'PTP_BT'),
	(466, 'D', 'PTP_ET'),
	(467, 'I', 'PTP_ID'),
	(468, 'C', 'PWW_DESC'),
	(469, 'I', 'PWW_ID'),
	(470, 'C', 'RC_CODE'),
	(471, 'I', 'RC_ID'),
	(472, 'I', 'REL_ENABLED'),
	(473, 'I', 'REL_ID'),
	(474, 'C', 'REL_TYPE_CODE'),
	(475, 'I', 'REL_TYPE_ID'),
	(476, 'C', 'REL_TYPE_NAME'),
	(477, 'C', 'ROLE'),
	(478, 'I', 'RPA_DELAY_DELIVERY'),
	(479, 'I', 'RPA_ENABLED'),
	(480, 'I', 'RPA_ID'),
	(481, 'I', 'RPA_LOG_ENABLED'),
	(482, 'C', 'RPA_NAME'),
	(483, 'I', 'RPAPV_ID'),
	(484, 'C', 'RP_DESCRIPTION'),
	(485, 'C', 'RPF_CODE'),
	(486, 'I', 'RPF_ID'),
	(487, 'I', 'RP_FORMULA'),
	(488, 'I', 'RP_ID'),
	(489, 'I', 'RP_LOG_ENABLED'),
	(490, 'C', 'RP_NAME'),
	(491, 'C', 'RPP_CODE'),
	(492, 'I', 'RPP_ID'),
	(493, 'I', 'RP_PUBLIC'),
	(494, 'I', 'RPQ_ADVANCED'),
	(495, 'I', 'RPQC_ASC'),
	(496, 'I', 'RPQC_ID'),
	(497, 'I', 'RPQC_NR'),
	(498, 'I', 'RPQ_DISTINCT'),
	(499, 'I', 'RPQF_ALLOW_EMPTY_VALUES'),
	(500, 'C', 'RPQF_DESC'),
	(501, 'I', 'RPQF_ESSENTIAL'),
	(502, 'I', 'RPQF_ID'),
	(503, 'I', 'RPQF_INV'),
	(504, 'I', 'RPQF_NR'),
	(505, 'C', 'RPQF_VALUE'),
	(506, 'I', 'RPQ_ID'),
	(507, 'I', 'RPQ_MAXROWS'),
	(508, 'C', 'RPQ_NAME'),
	(509, 'C', 'RPQO_CODE'),
	(510, 'I', 'RPQO_ID'),
	(511, 'C', 'RPQ_SLC'),
	(512, 'I', 'RPQU_ID'),
	(513, 'C', 'RPQU_NAME'),
	(514, 'C', 'RPTY_CODE'),
	(515, 'I', 'RPTY_ID'),
	(516, 'I', 'RP_TYPE_ID'),
	(517, 'C', 'RP_TYPE_NAME'),
	(518, 'C', 'RPTY_VALUE'),
	(519, 'C', 'RTP_CODE'),
	(520, 'I', 'RTP_ID'),
	(521, 'I', 'RTP_INT_VALUE'),
	(522, 'I', 'RTP_ML_ENABLED'),
	(523, 'C', 'RTP_NAME'),
	(524, 'I', 'RULE_ENABLED'),
	(525, 'I', 'SAM_AUTO_CALC'),
	(528, 'I', 'SAM_CYCLIC'),
	(529, 'C', 'SAM_CODE'),
	(530, 'D', 'SAM_CONST_VAL_CALC_DATE'),
	(531, 'D', 'SAM_CONST_VAL_CALC_DATE_REQ'),
	(533, 'I', 'SAMD_COMMON'),
	(534, 'I', 'SAMD_ID'),
	(535, 'C', 'SAMD_NAME'),
	(536, 'I', 'SAM_ID'),
	(537, 'C', 'SAM_NAME'),
	(538, 'I', 'SAMP_ID'),
	(539, 'I', 'SAMP_INT_VALUE'),
	(540, 'I', 'SAMP_PER_ID'),
	(541, 'I', 'SAM_TYPE_ID'),
	(542, 'C', 'SAM_TYPE_NAME'),
	(543, 'I', 'SAM_TMPL_AI_NR'),
	(544, 'I', 'SAM_TMPL_CALC_SCH_ID'),
	(545, 'C', 'SAM_TMPL_CODE'),
	(546, 'I', 'SAM_TMPL_DEPTH'),
	(547, 'I', 'SAM_TMPL_DEPTH_PER_ID'),
	(548, 'I', 'SAM_TMPL_ID'),
	(549, 'C', 'SAM_TMPL_NAME'),
	(550, 'I', 'SAM_TMPL_PREP'),
	(551, 'I', 'SAM_TMPL_PREP_PER_ID'),
	(552, 'I', 'SAMU_DEPTH'),
	(553, 'I', 'SAMU_DEPTH_PER_ID'),
	(554, 'I', 'SAMU_ENABLED'),
	(555, 'I', 'SAMU_LAG'),
	(556, 'I', 'SAMU_LAG_PER_ID'),
	(557, 'C', 'SAMU_TYPE_CODE'),
	(558, 'I', 'SAMU_TYPE_ID'),
	(559, 'N', 'SAM_V'),
	(560, 'I', 'SAMW_COMMON'),
	(561, 'I', 'SAMW_ID'),
	(562, 'C', 'SAMW_NAME'),
	(563, 'C', 'SAMW_TYPE_CODE'),
	(564, 'I', 'SAMW_TYPE_ID'),
	(565, 'N', 'SBST_A'),
	(566, 'I', 'SBST_AB'),
	(567, 'I', 'SBST_ALTER_READ_TIME'),
	(568, 'N', 'SBST_B'),
	(569, 'I', 'SBST_ENABLED'),
	(570, 'I', 'SBST_EXCLUDE_FLN'),
	(571, 'I', 'SBST_FLN'),
	(572, 'I', 'SBST_IMPROVABLE'),
	(573, 'I', 'SBST_LAG'),
	(574, 'I', 'SBST_OFFSET'),
	(575, 'I', 'SBST_OFFSET_PER_ID'),
	(576, 'I', 'SBST_PL_ID'),
	(577, 'I', 'SBST_RADIUS'),
	(578, 'I', 'SBST_RADIUS_PER_ID'),
	(579, 'I', 'SBST_SF'),
	(580, 'I', 'SBST_SRC_TMPL_ID'),
	(581, 'I', 'SBST_SRC_TMPL_PRIORITY'),
	(582, 'I', 'SCH_ID'),
	(583, 'I', 'SCHI_NR'),
	(584, 'I', 'SCH_INT_ID'),
	(585, 'C', 'SCH_INT_NAME'),
	(586, 'I', 'SCH_INT_VALUE'),
	(587, 'C', 'SCH_NAME'),
	(588, 'I', 'SCH_REPEAT'),
	(589, 'I', 'SCH_REPEAT_TIMES'),
	(590, 'N', 'SE_A'),
	(591, 'I', 'SE_AB'),
	(592, 'N', 'SE_B'),
	(593, 'I', 'SE_ENABLED'),
	(594, 'I', 'SE_FORCED'),
	(595, 'I', 'SE_H'),
	(596, 'D', 'SE_H_BOUND'),
	(597, 'I', 'SE_H_DEPTH'),
	(598, 'I', 'SE_H_PER_ID'),
	(599, 'I', 'SE_H_RESTORE_DEPTH'),
	(600, 'I', 'SE_H_RESTORE_PER_ID'),
	(601, 'I', 'SE_ID'),
	(602, 'I', 'SEP_ENABLED'),
	(603, 'I', 'SEP_ID'),
	(604, 'I', 'SEP_RC_DEPTH'),
	(605, 'I', 'SEP_RC_LAG'),
	(606, 'I', 'SE_TMPL_DP_SHEAF_ID'),
	(607, 'I', 'SE_TMPL_EXTEND_PL'),
	(608, 'I', 'SE_TMPL_ID'),
	(609, 'I', 'SE_TMPL_SHEAF_ID'),
	(610, 'I', 'SF_AUTO_NULL_ACT'),
	(611, 'C', 'SF_CODE'),
	(612, 'I', 'SF_ID'),
	(613, 'C', 'SHEAF_NAME'),
	(614, 'I', 'SHEAF_ID'),
	(615, 'I', 'SI_CNT'),
	(616, 'I', 'SI_DPT'),
	(617, 'I', 'SI_DSC'),
	(618, 'I', 'SI_GRP'),
	(619, 'I', 'SI_PNT'),
	(620, 'I', 'SOURCE_EC_ID'),
	(621, 'I', 'SOURCE_EC_IN'),
	(622, 'I', 'SOURCE_ECP_ID'),
	(623, 'I', 'SOURCE_GMOD_ID'),
	(624, 'I', 'SOURCE_GPRC'),
	(625, 'I', 'SOURCE_ML_ID'),
	(626, 'I', 'SOURCE_MT_ID'),
	(627, 'I', 'SOURCE_SAM_TMPL_ID'),
	(628, 'I', 'SP_ID'),
	(629, 'C', 'SPTY_CODE'),
	(630, 'C', 'SPTY_DEFAULT'),
	(631, 'I', 'SPTY_ID'),
	(632, 'C', 'SPTY_NAME'),
	(633, 'I', 'SPTY_NR'),
	(634, 'I', 'SPTY_NUMERIC'),
	(635, 'C', 'SPTY_TYPE_CODE'),
	(636, 'I', 'SPTY_TYPE_ID'),
	(637, 'C', 'SPTY_VALUE'),
	(638, 'D', 'SRC_BT'),
	(639, 'I', 'SRC_DIR_INV'),
	(640, 'I', 'SRC_ENABLED'),
	(641, 'D', 'SRC_ET'),
	(642, 'I', 'SRC_ID'),
	(643, 'I', 'SRC_MT_ID'),
	(644, 'C', 'SRC_NAME'),
	(645, 'C', 'SRC_NUMBER'),
	(646, 'I', 'SRC_RULE_ID'),
	(647, 'I', 'SRC_SAVE_STATISTICS'),
	(648, 'C', 'SRC_TYPE_CODE'),
	(649, 'I', 'SRC_TYPE_ID'),
	(650, 'C', 'SRC_TMPL_CODE'),
	(651, 'I', 'SRC_TMPL_ID'),
	(652, 'I', 'SRC_TMPL_MULTIPOINT'),
	(653, 'C', 'SRC_TMPL_NAME'),
	(654, 'I', 'SRC_TZ_DST_USED'),
	(655, 'I', 'STEADY_TYPE_ID'),
	(656, 'I', 'STOBIS'),
	(657, 'C', 'TABLE_NAME'),
	(658, 'I', 'TARGET_EC_ID'),
	(659, 'I', 'TARGET_EC_IN'),
	(660, 'I', 'TARGET_GMOD_ID'),
	(661, 'I', 'TARGET_GPRC'),
	(662, 'I', 'TARGET_ML_ID'),
	(663, 'C', 'TFF_COLOR'),
	(664, 'I', 'TFF_ENABLED'),
	(665, 'I', 'TFF_ID'),
	(666, 'C', 'TFF_NAME'),
	(667, 'I', 'TP_ID'),
	(668, 'C', 'TP_NAME'),
	(669, 'I', 'TPP_ID'),
	(670, 'I', 'TS_ID'),
	(671, 'C', 'TS_NAME'),
	(672, 'I', 'TSTATUS'),
	(673, 'C', 'TZ_CODE'),
	(674, 'I', 'TZ_ID'),
	(675, 'I', 'UG_ID'),
	(676, 'C', 'UG_NAME'),
	(677, 'I', 'USE_CONST_VAL'),
	(678, 'C', 'USER_COMPANY'),
	(679, 'I', 'USER_DELETED'),
	(680, 'C', 'USER_DEPARTMENT'),
	(681, 'C', 'USER_EMAIL'),
	(682, 'I', 'USER_ENABLED'),
	(683, 'C', 'USER_GSM'),
	(684, 'I', 'USER_ID'),
	(685, 'C', 'USER_LOCATION'),
	(686, 'C', 'USER_NAME'),
	(687, 'C', 'USER_PHONE'),
	(688, 'I', 'USER_SMS_LIMIT'),
	(689, 'C', 'VERGE_CODE'),
	(690, 'I', 'VERGE_ID'),
	(691, 'C', 'VERGE_NAME'),
	(692, 'I', 'VISIBLE'),
	(693, 'N', 'VP_ALLOWED_SCALAR_ERROR'),
	(694, 'N', 'VP_BIAS'),
	(695, 'C', 'VP_CODE'),
	(696, 'I', 'VP_ID'),
	(697, 'N', 'VP_MAX_SCALAR_ERROR'),
	(698, 'C', 'VP_NAME'),
	(699, 'I', 'VP_NR'),
	(700, 'I', 'VP_SEPARATE_TFF'),
	(701, 'I', 'VP_SMALLEST_INTERVAL'),
	(702, 'I', 'WD'),
	(703, 'I', 'WD_SPECIFIC'),
	(704, 'I', 'WD1'),
	(705, 'I', 'WD2'),
	(706, 'I', 'WD3'),
	(707, 'I', 'WD4'),
	(708, 'I', 'WD5'),
	(709, 'I', 'WD6'),
	(710, 'I', 'WD7'),
	(711, 'I', 'WD8'),
	(712, 'I', 'WEEK'),
	(713, 'C', 'WITHE_CODE'),
	(714, 'I', 'WITHE_ID'),
	(715, 'C', 'WITHESET_CODE'),
	(716, 'I', 'WITHESET_ID'),
	(717, 'C', 'WITHESET_NAME'),
	(718, 'C', 'WITHE_TYPE_CODE'),
	(719, 'I', 'WITHE_TYPE_ID'),
	(720, 'I', 'WPR_ID'),
	(721, 'C', 'WPR_NAME'),
	(722, 'I', 'XA_ENABLED'),
	(723, 'I', 'XA_ID'),
	(724, 'C', 'XA_NAME'),
	(725, 'C', 'XE_NAME'),
	(726, 'I', 'XE_ID'),
	(727, 'C', 'XFA_CODE'),
	(728, 'I', 'XFA_ENABLED'),
	(729, 'I', 'XFA_ID'),
	(730, 'C', 'XFA_NAME'),
	(731, 'C', 'XFA_TZ'),
	(732, 'I', 'XFA_TZ_DST_USED'),
	(733, 'C', 'XFAU_CODE'),
	(734, 'C', 'XFAU_CODE2'),
	(735, 'I', 'XFAU_ENABLED'),
	(736, 'I', 'XFAU_ID'),
	(737, 'C', 'XFAU_NAME'),
	(738, 'C', 'XFAU_NAME2'),
	(739, 'I', 'XFAU_TYPE_ID'),
	(740, 'C', 'XFAU_TYPE_NAME'),
	(741, 'I', 'XFE_ENABLED'),
	(742, 'I', 'XFE_ID'),
	(743, 'C', 'XFE_INFO'),
	(744, 'I', 'XF_ENABLED'),
	(745, 'I', 'XF_ID'),
	(746, 'I', 'XF_IMPORT'),
	(747, 'C', 'XF_NAME'),
	(748, 'I', 'XF_RC_DEPTH'),
	(749, 'I', 'XF_RC_LAG'),
	(750, 'C', 'XF_TYPE_CODE'),
	(751, 'I', 'XF_TYPE_ID'),
	(752, 'D', 'XO_BT'),
	(753, 'D', 'XO_ET'),
	(754, 'C', 'XPTY_CODE'),
	(755, 'I', 'XPTY_ID'),
	(756, 'C', 'XPTY_VALUE'),
	(757, 'N', 'SE_SUMMAND'),
	(758, 'C', 'GRANT_REVOKE'),
	(759, 'C', 'ROLE_NAME'),
	(760, 'I', 'MSF_ID'),
	(761, 'D', 'FROM_DA'),
	(762, 'D', 'TO_DA'),
	(763, 'D', 'DI_BT'),
	(764, 'D', 'DI_ET'),
	(765, 'C', 'IMEI'),
	(766, 'N', 'WITHESET_JOURNAL'),
	(767, 'I', 'BGA_PRIORITY'),
	(768, 'I', 'SE_TMPL_DS_TYPE_ID'),
	(769, 'I', 'SE_TMPL_DS_TYPE_EXTEND_DS');
/*!40000 ALTER TABLE `col` ENABLE KEYS */;

-- Dumping structure for table emcor.colc
CREATE TABLE IF NOT EXISTS `colc` (
  `col_id` mediumint(8) unsigned NOT NULL COMMENT 'Lauko identifikatorius',
  `nr` smallint(5) unsigned NOT NULL COMMENT 'Numeris',
  `cont_col_id` mediumint(8) unsigned NOT NULL COMMENT 'Konteinerį apibūdinančio lauko identifikatorius',
  PRIMARY KEY (`col_id`,`nr`),
  KEY `colc_cont_col_i` (`cont_col_id`),
  CONSTRAINT `colc_col_fk` FOREIGN KEY (`col_id`) REFERENCES `col` (`col_id`) ON DELETE CASCADE,
  CONSTRAINT `colc_cont_col_fk` FOREIGN KEY (`cont_col_id`) REFERENCES `col` (`col_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Lentelių laukus-identifikatorius apibūdinantys kiti laukai-identifikatoriai';

-- Dumping data for table emcor.colc: ~51 rows (approximately)
/*!40000 ALTER TABLE `colc` DISABLE KEYS */;
INSERT INTO `colc` (`col_id`, `nr`, `cont_col_id`) VALUES
	(111, 2, 113),
	(601, 2, 120),
	(120, 5, 128),
	(410, 1, 128),
	(642, 1, 128),
	(120, 2, 140),
	(736, 3, 140),
	(394, 7, 160),
	(218, 1, 218),
	(394, 5, 244),
	(394, 4, 266),
	(736, 4, 266),
	(340, 1, 336),
	(349, 2, 351),
	(394, 2, 355),
	(419, 1, 355),
	(608, 1, 355),
	(742, 1, 355),
	(628, 1, 410),
	(120, 1, 419),
	(120, 4, 442),
	(394, 1, 442),
	(419, 2, 442),
	(736, 2, 442),
	(473, 1, 475),
	(506, 2, 488),
	(502, 1, 506),
	(502, 2, 510),
	(394, 3, 536),
	(538, 1, 536),
	(603, 2, 601),
	(120, 3, 614),
	(606, 2, 614),
	(609, 2, 614),
	(603, 1, 628),
	(601, 1, 642),
	(628, 2, 642),
	(606, 1, 651),
	(608, 2, 651),
	(609, 1, 651),
	(665, 1, 665),
	(336, 1, 690),
	(120, 6, 716),
	(606, 3, 716),
	(609, 3, 716),
	(745, 2, 723),
	(742, 3, 726),
	(736, 5, 729),
	(742, 2, 736),
	(736, 1, 739),
	(729, 1, 745);
/*!40000 ALTER TABLE `colc` ENABLE KEYS */;

-- Dumping structure for table emcor.colc_data
CREATE TABLE IF NOT EXISTS `colc_data` (
  `col_id` mediumint(8) unsigned NOT NULL COMMENT 'Lauko identifikatorius',
  `col_val` bigint(20) NOT NULL COMMENT 'Lauko reikšmė',
  `nr` smallint(5) unsigned NOT NULL COMMENT 'Numeris',
  `cont_col_id` mediumint(8) unsigned NOT NULL COMMENT 'Konteinerį apibūdinančio lauko identifikatorius',
  `cont_col_val` int(10) unsigned NOT NULL COMMENT 'Konteinerį apibūdinančio lauko reikšmė',
  PRIMARY KEY (`col_id`,`col_val`,`nr`),
  KEY `colc_data_cont_i` (`cont_col_id`,`cont_col_val`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Lentelių identifikatorius apibūdinantys kiti identifikatoriai';

-- Dumping data for table emcor.colc_data: ~1 345 rows (approximately)
/*!40000 ALTER TABLE `colc_data` DISABLE KEYS */;
INSERT INTO `colc_data` (`col_id`, `col_val`, `nr`, `cont_col_id`, `cont_col_val`) VALUES
	(601, 38, 2, 120, 38),
	(410, 457, 1, 128, 454),
	(642, 467, 1, 128, 454),
	(642, 468, 1, 128, 454),
	(642, 470, 1, 128, 454),
	(642, 471, 1, 128, 454),
	(642, 472, 1, 128, 454),
	(642, 473, 1, 128, 454),
	(642, 474, 1, 128, 454),
	(642, 475, 1, 128, 454),
	(642, 476, 1, 128, 454),
	(642, 477, 1, 128, 454),
	(642, 478, 1, 128, 454),
	(642, 479, 1, 128, 454),
	(642, 480, 1, 128, 454),
	(642, 481, 1, 128, 454),
	(642, 482, 1, 128, 454),
	(642, 483, 1, 128, 454),
	(642, 484, 1, 128, 454),
	(642, 485, 1, 128, 454),
	(642, 486, 1, 128, 454),
	(642, 487, 1, 128, 454),
	(642, 488, 1, 128, 454),
	(642, 489, 1, 128, 454),
	(642, 490, 1, 128, 454),
	(642, 491, 1, 128, 454),
	(642, 492, 1, 128, 454),
	(642, 493, 1, 128, 454),
	(642, 522, 1, 128, 454),
	(642, 523, 1, 128, 454),
	(642, 524, 1, 128, 454),
	(642, 525, 1, 128, 454),
	(642, 526, 1, 128, 454),
	(642, 527, 1, 128, 454),
	(642, 544, 1, 128, 454),
	(642, 545, 1, 128, 454),
	(642, 565, 1, 128, 454),
	(642, 622, 1, 128, 454),
	(642, 623, 1, 128, 454),
	(642, 626, 1, 128, 454),
	(642, 627, 1, 128, 454),
	(642, 628, 1, 128, 454),
	(642, 629, 1, 128, 454),
	(642, 652, 1, 128, 454),
	(642, 653, 1, 128, 454),
	(642, 654, 1, 128, 454),
	(642, 667, 1, 128, 454),
	(642, 668, 1, 128, 454),
	(642, 702, 1, 128, 454),
	(642, 703, 1, 128, 454),
	(642, 704, 1, 128, 454),
	(642, 705, 1, 128, 454),
	(642, 706, 1, 128, 454),
	(642, 712, 1, 128, 454),
	(642, 713, 1, 128, 454),
	(642, 732, 1, 128, 454),
	(642, 733, 1, 128, 454),
	(642, 734, 1, 128, 454),
	(642, 735, 1, 128, 454),
	(642, 736, 1, 128, 454),
	(642, 758, 1, 128, 454),
	(642, 759, 1, 128, 454),
	(642, 760, 1, 128, 454),
	(642, 761, 1, 128, 454),
	(642, 762, 1, 128, 454),
	(642, 763, 1, 128, 454),
	(642, 764, 1, 128, 454),
	(642, 766, 1, 128, 454),
	(642, 767, 1, 128, 454),
	(642, 768, 1, 128, 454),
	(642, 769, 1, 128, 454),
	(642, 770, 1, 128, 454),
	(642, 771, 1, 128, 454),
	(642, 772, 1, 128, 454),
	(642, 777, 1, 128, 454),
	(642, 778, 1, 128, 454),
	(642, 779, 1, 128, 454),
	(642, 782, 1, 128, 454),
	(642, 783, 1, 128, 454),
	(642, 784, 1, 128, 454),
	(642, 833, 1, 128, 454),
	(642, 834, 1, 128, 454),
	(642, 835, 1, 128, 454),
	(642, 842, 1, 128, 454),
	(642, 912, 1, 128, 454),
	(642, 937, 1, 128, 454),
	(642, 942, 1, 128, 454),
	(642, 962, 1, 128, 454),
	(642, 963, 1, 128, 454),
	(642, 964, 1, 128, 454),
	(642, 994, 1, 128, 454),
	(642, 1002, 1, 128, 454),
	(642, 1003, 1, 128, 454),
	(642, 1004, 1, 128, 454),
	(642, 1005, 1, 128, 454),
	(642, 1006, 1, 128, 454),
	(642, 1007, 1, 128, 454),
	(642, 1008, 1, 128, 454),
	(642, 1012, 1, 128, 454),
	(642, 1013, 1, 128, 454),
	(642, 1014, 1, 128, 454),
	(642, 1017, 1, 128, 454),
	(642, 1018, 1, 128, 454),
	(642, 1019, 1, 128, 454),
	(642, 1020, 1, 128, 454),
	(642, 1021, 1, 128, 454),
	(642, 1022, 1, 128, 454),
	(642, 1023, 1, 128, 454),
	(642, 1024, 1, 128, 454),
	(642, 1025, 1, 128, 454),
	(642, 1026, 1, 128, 454),
	(642, 1027, 1, 128, 454),
	(642, 1028, 1, 128, 454),
	(642, 1029, 1, 128, 454),
	(642, 1030, 1, 128, 454),
	(642, 1031, 1, 128, 454),
	(642, 1032, 1, 128, 454),
	(642, 1033, 1, 128, 454),
	(642, 1034, 1, 128, 454),
	(642, 1035, 1, 128, 454),
	(642, 1036, 1, 128, 454),
	(642, 1037, 1, 128, 454),
	(642, 1038, 1, 128, 454),
	(642, 1039, 1, 128, 454),
	(642, 1040, 1, 128, 454),
	(642, 1041, 1, 128, 454),
	(642, 1042, 1, 128, 454),
	(642, 1043, 1, 128, 454),
	(642, 1044, 1, 128, 454),
	(642, 1045, 1, 128, 454),
	(642, 1046, 1, 128, 454),
	(642, 1047, 1, 128, 454),
	(642, 1048, 1, 128, 454),
	(642, 1049, 1, 128, 454),
	(642, 1051, 1, 128, 454),
	(642, 1052, 1, 128, 454),
	(642, 1053, 1, 128, 454),
	(642, 1056, 1, 128, 454),
	(642, 1061, 1, 128, 454),
	(642, 1062, 1, 128, 454),
	(642, 1063, 1, 128, 454),
	(642, 1064, 1, 128, 454),
	(642, 1065, 1, 128, 454),
	(642, 1066, 1, 128, 454),
	(642, 1067, 1, 128, 454),
	(642, 1068, 1, 128, 454),
	(642, 1069, 1, 128, 454),
	(642, 1070, 1, 128, 454),
	(642, 1071, 1, 128, 454),
	(642, 1072, 1, 128, 454),
	(642, 1073, 1, 128, 454),
	(642, 1074, 1, 128, 454),
	(642, 1075, 1, 128, 454),
	(642, 1076, 1, 128, 454),
	(642, 1077, 1, 128, 454),
	(642, 1078, 1, 128, 454),
	(642, 1079, 1, 128, 454),
	(642, 1080, 1, 128, 454),
	(642, 1081, 1, 128, 454),
	(642, 1082, 1, 128, 454),
	(642, 1083, 1, 128, 454),
	(642, 1084, 1, 128, 454),
	(642, 1085, 1, 128, 454),
	(642, 1086, 1, 128, 454),
	(642, 1087, 1, 128, 454),
	(642, 1088, 1, 128, 454),
	(642, 1091, 1, 128, 454),
	(642, 1092, 1, 128, 454),
	(642, 1093, 1, 128, 454),
	(642, 1094, 1, 128, 454),
	(642, 1095, 1, 128, 454),
	(642, 1096, 1, 128, 454),
	(642, 1097, 1, 128, 454),
	(642, 1098, 1, 128, 454),
	(642, 1099, 1, 128, 454),
	(642, 1100, 1, 128, 454),
	(642, 1101, 1, 128, 454),
	(642, 1102, 1, 128, 454),
	(642, 1103, 1, 128, 454),
	(642, 1104, 1, 128, 454),
	(642, 1105, 1, 128, 454),
	(642, 1106, 1, 128, 454),
	(642, 1107, 1, 128, 454),
	(642, 1108, 1, 128, 454),
	(642, 1109, 1, 128, 454),
	(642, 1110, 1, 128, 454),
	(642, 1111, 1, 128, 454),
	(642, 1112, 1, 128, 454),
	(642, 1113, 1, 128, 454),
	(642, 1114, 1, 128, 454),
	(642, 1115, 1, 128, 454),
	(642, 1116, 1, 128, 454),
	(642, 1117, 1, 128, 454),
	(642, 1118, 1, 128, 454),
	(642, 1119, 1, 128, 454),
	(642, 1120, 1, 128, 454),
	(642, 1121, 1, 128, 454),
	(642, 1122, 1, 128, 454),
	(642, 1123, 1, 128, 454),
	(642, 1124, 1, 128, 454),
	(642, 1125, 1, 128, 454),
	(642, 1126, 1, 128, 454),
	(642, 1131, 1, 128, 454),
	(642, 1132, 1, 128, 454),
	(642, 1133, 1, 128, 454),
	(642, 1134, 1, 128, 454),
	(642, 1135, 1, 128, 454),
	(642, 1136, 1, 128, 454),
	(642, 1137, 1, 128, 454),
	(642, 1138, 1, 128, 454),
	(642, 1139, 1, 128, 454),
	(642, 1140, 1, 128, 454),
	(642, 1141, 1, 128, 454),
	(642, 1142, 1, 128, 454),
	(642, 1143, 1, 128, 454),
	(642, 1144, 1, 128, 454),
	(642, 1145, 1, 128, 454),
	(642, 1146, 1, 128, 454),
	(642, 1147, 1, 128, 454),
	(642, 1148, 1, 128, 454),
	(642, 1149, 1, 128, 454),
	(642, 1150, 1, 128, 454),
	(642, 1151, 1, 128, 454),
	(642, 1152, 1, 128, 454),
	(642, 1153, 1, 128, 454),
	(642, 1154, 1, 128, 454),
	(642, 1155, 1, 128, 454),
	(642, 1156, 1, 128, 454),
	(642, 1157, 1, 128, 454),
	(642, 1158, 1, 128, 454),
	(642, 1159, 1, 128, 454),
	(642, 1160, 1, 128, 454),
	(642, 1161, 1, 128, 454),
	(642, 1162, 1, 128, 454),
	(642, 1163, 1, 128, 454),
	(642, 1164, 1, 128, 454),
	(642, 1165, 1, 128, 454),
	(642, 1166, 1, 128, 454),
	(642, 1167, 1, 128, 454),
	(642, 1168, 1, 128, 454),
	(642, 1169, 1, 128, 454),
	(642, 1170, 1, 128, 454),
	(642, 1171, 1, 128, 454),
	(642, 1172, 1, 128, 454),
	(642, 1173, 1, 128, 454),
	(642, 1174, 1, 128, 454),
	(642, 1175, 1, 128, 454),
	(642, 1176, 1, 128, 454),
	(642, 1177, 1, 128, 454),
	(642, 1178, 1, 128, 454),
	(642, 1179, 1, 128, 454),
	(642, 1180, 1, 128, 454),
	(642, 1181, 1, 128, 454),
	(642, 1183, 1, 128, 454),
	(642, 1184, 1, 128, 454),
	(642, 1185, 1, 128, 454),
	(642, 1186, 1, 128, 454),
	(642, 1187, 1, 128, 454),
	(642, 1188, 1, 128, 454),
	(642, 1189, 1, 128, 454),
	(642, 1190, 1, 128, 454),
	(642, 1191, 1, 128, 454),
	(642, 1192, 1, 128, 454),
	(642, 1193, 1, 128, 454),
	(642, 1194, 1, 128, 454),
	(642, 1195, 1, 128, 454),
	(642, 1196, 1, 128, 454),
	(642, 1197, 1, 128, 454),
	(642, 1198, 1, 128, 454),
	(642, 1199, 1, 128, 454),
	(642, 1200, 1, 128, 454),
	(642, 1201, 1, 128, 454),
	(642, 1202, 1, 128, 454),
	(642, 1203, 1, 128, 454),
	(642, 1204, 1, 128, 454),
	(642, 1205, 1, 128, 454),
	(642, 1206, 1, 128, 454),
	(642, 1207, 1, 128, 454),
	(642, 1208, 1, 128, 454),
	(642, 1209, 1, 128, 454),
	(642, 1210, 1, 128, 454),
	(642, 1211, 1, 128, 454),
	(642, 1212, 1, 128, 454),
	(642, 1213, 1, 128, 454),
	(642, 1214, 1, 128, 454),
	(642, 1215, 1, 128, 454),
	(642, 1216, 1, 128, 454),
	(642, 1217, 1, 128, 454),
	(642, 1218, 1, 128, 454),
	(642, 1219, 1, 128, 454),
	(642, 1220, 1, 128, 454),
	(642, 1221, 1, 128, 454),
	(642, 1222, 1, 128, 454),
	(642, 1223, 1, 128, 454),
	(642, 1224, 1, 128, 454),
	(642, 1225, 1, 128, 454),
	(642, 1226, 1, 128, 454),
	(642, 1227, 1, 128, 454),
	(642, 1228, 1, 128, 454),
	(642, 1229, 1, 128, 454),
	(642, 1230, 1, 128, 454),
	(642, 1231, 1, 128, 454),
	(642, 1232, 1, 128, 454),
	(642, 1233, 1, 128, 454),
	(642, 1234, 1, 128, 454),
	(642, 1235, 1, 128, 454),
	(642, 1236, 1, 128, 454),
	(642, 1237, 1, 128, 454),
	(642, 1238, 1, 128, 454),
	(642, 1239, 1, 128, 454),
	(642, 1240, 1, 128, 454),
	(642, 1241, 1, 128, 454),
	(642, 1242, 1, 128, 454),
	(642, 1243, 1, 128, 454),
	(642, 1244, 1, 128, 454),
	(642, 1245, 1, 128, 454),
	(642, 1246, 1, 128, 454),
	(642, 1247, 1, 128, 454),
	(642, 1248, 1, 128, 454),
	(642, 1249, 1, 128, 454),
	(642, 1250, 1, 128, 454),
	(642, 1251, 1, 128, 454),
	(642, 1252, 1, 128, 454),
	(642, 1253, 1, 128, 454),
	(642, 1254, 1, 128, 454),
	(642, 1255, 1, 128, 454),
	(642, 1256, 1, 128, 454),
	(642, 1257, 1, 128, 454),
	(642, 1258, 1, 128, 454),
	(642, 1259, 1, 128, 454),
	(642, 1260, 1, 128, 454),
	(642, 1261, 1, 128, 454),
	(642, 1262, 1, 128, 454),
	(642, 1263, 1, 128, 454),
	(642, 1264, 1, 128, 454),
	(642, 1265, 1, 128, 454),
	(642, 1266, 1, 128, 454),
	(642, 1267, 1, 128, 454),
	(642, 1268, 1, 128, 454),
	(642, 1269, 1, 128, 454),
	(642, 1270, 1, 128, 454),
	(642, 1271, 1, 128, 454),
	(642, 1272, 1, 128, 454),
	(642, 1273, 1, 128, 454),
	(642, 1274, 1, 128, 454),
	(642, 1275, 1, 128, 454),
	(642, 1276, 1, 128, 454),
	(642, 1277, 1, 128, 454),
	(642, 1278, 1, 128, 454),
	(642, 1279, 1, 128, 454),
	(642, 1280, 1, 128, 454),
	(642, 1281, 1, 128, 454),
	(642, 1282, 1, 128, 454),
	(642, 1283, 1, 128, 454),
	(642, 1284, 1, 128, 454),
	(642, 1285, 1, 128, 454),
	(642, 1286, 1, 128, 454),
	(642, 1287, 1, 128, 454),
	(642, 1288, 1, 128, 454),
	(642, 1289, 1, 128, 454),
	(642, 1290, 1, 128, 454),
	(642, 1291, 1, 128, 454),
	(642, 1292, 1, 128, 454),
	(642, 1293, 1, 128, 454),
	(642, 1294, 1, 128, 454),
	(642, 1295, 1, 128, 454),
	(642, 1296, 1, 128, 454),
	(642, 1297, 1, 128, 454),
	(642, 1298, 1, 128, 454),
	(642, 1299, 1, 128, 454),
	(642, 1300, 1, 128, 454),
	(642, 1301, 1, 128, 454),
	(642, 1302, 1, 128, 454),
	(642, 1303, 1, 128, 454),
	(642, 1304, 1, 128, 454),
	(642, 1305, 1, 128, 454),
	(642, 1306, 1, 128, 454),
	(642, 1307, 1, 128, 454),
	(642, 1308, 1, 128, 454),
	(642, 1309, 1, 128, 454),
	(642, 1310, 1, 128, 454),
	(642, 1311, 1, 128, 454),
	(642, 1312, 1, 128, 454),
	(642, 1313, 1, 128, 454),
	(642, 1314, 1, 128, 454),
	(642, 1315, 1, 128, 454),
	(642, 1316, 1, 128, 454),
	(642, 1317, 1, 128, 454),
	(642, 1318, 1, 128, 454),
	(642, 1319, 1, 128, 454),
	(642, 1320, 1, 128, 454),
	(642, 1321, 1, 128, 454),
	(642, 1322, 1, 128, 454),
	(642, 1323, 1, 128, 454),
	(642, 1324, 1, 128, 454),
	(642, 1325, 1, 128, 454),
	(642, 1326, 1, 128, 454),
	(642, 1327, 1, 128, 454),
	(642, 1328, 1, 128, 454),
	(642, 1329, 1, 128, 454),
	(642, 1330, 1, 128, 454),
	(642, 1331, 1, 128, 454),
	(642, 1332, 1, 128, 454),
	(642, 1333, 1, 128, 454),
	(642, 1334, 1, 128, 454),
	(642, 1335, 1, 128, 454),
	(642, 1336, 1, 128, 454),
	(642, 1337, 1, 128, 454),
	(642, 1338, 1, 128, 454),
	(642, 1339, 1, 128, 454),
	(642, 1340, 1, 128, 454),
	(642, 1341, 1, 128, 454),
	(642, 1342, 1, 128, 454),
	(642, 1343, 1, 128, 454),
	(642, 1344, 1, 128, 454),
	(642, 1345, 1, 128, 454),
	(642, 1346, 1, 128, 454),
	(642, 1347, 1, 128, 454),
	(642, 1348, 1, 128, 454),
	(642, 1349, 1, 128, 454),
	(642, 1350, 1, 128, 454),
	(642, 1351, 1, 128, 454),
	(642, 1352, 1, 128, 454),
	(642, 1353, 1, 128, 454),
	(642, 1354, 1, 128, 454),
	(642, 1355, 1, 128, 454),
	(642, 1356, 1, 128, 454),
	(642, 1357, 1, 128, 454),
	(642, 1358, 1, 128, 454),
	(642, 1359, 1, 128, 454),
	(642, 1360, 1, 128, 454),
	(642, 1361, 1, 128, 454),
	(642, 1362, 1, 128, 454),
	(642, 1363, 1, 128, 454),
	(642, 1364, 1, 128, 454),
	(642, 1365, 1, 128, 454),
	(642, 1366, 1, 128, 454),
	(642, 1368, 1, 128, 454),
	(642, 1373, 1, 128, 454),
	(642, 1374, 1, 128, 454),
	(642, 1375, 1, 128, 454),
	(642, 1376, 1, 128, 454),
	(642, 1377, 1, 128, 454),
	(642, 1378, 1, 128, 454),
	(642, 1379, 1, 128, 454),
	(642, 1380, 1, 128, 454),
	(642, 1381, 1, 128, 454),
	(642, 1382, 1, 128, 454),
	(642, 1383, 1, 128, 454),
	(642, 1384, 1, 128, 454),
	(642, 1388, 1, 128, 454),
	(642, 1389, 1, 128, 454),
	(642, 1393, 1, 128, 454),
	(642, 1394, 1, 128, 454),
	(642, 1395, 1, 128, 454),
	(642, 1396, 1, 128, 454),
	(642, 1397, 1, 128, 454),
	(642, 1398, 1, 128, 454),
	(642, 1399, 1, 128, 454),
	(642, 1400, 1, 128, 454),
	(642, 1401, 1, 128, 454),
	(642, 1402, 1, 128, 454),
	(642, 1403, 1, 128, 454),
	(642, 1404, 1, 128, 454),
	(642, 1405, 1, 128, 454),
	(642, 1406, 1, 128, 454),
	(642, 1407, 1, 128, 454),
	(642, 1408, 1, 128, 454),
	(642, 1409, 1, 128, 454),
	(642, 1410, 1, 128, 454),
	(642, 1413, 1, 128, 454),
	(642, 1414, 1, 128, 454),
	(410, 593, 1, 128, 600),
	(218, 1, 1, 218, 1),
	(218, 2, 1, 218, 2),
	(218, 3, 1, 218, 3),
	(218, 4, 1, 218, 4),
	(218, 5, 1, 218, 5),
	(218, 6, 1, 218, 6),
	(218, 7, 1, 218, 7),
	(218, 8, 1, 218, 8),
	(218, 9, 1, 218, 9),
	(218, 10, 1, 218, 10),
	(218, 11, 1, 218, 11),
	(218, 12, 1, 218, 12),
	(218, 13, 1, 218, 13),
	(218, 14, 1, 218, 14),
	(218, 15, 1, 218, 15),
	(218, 16, 1, 218, 16),
	(218, 17, 1, 218, 17),
	(218, 18, 1, 218, 18),
	(218, 19, 1, 218, 19),
	(218, 20, 1, 218, 20),
	(218, 21, 1, 218, 21),
	(218, 22, 1, 218, 22),
	(218, 23, 1, 218, 23),
	(218, 24, 1, 218, 24),
	(218, 25, 1, 218, 25),
	(218, 26, 1, 218, 26),
	(218, 27, 1, 218, 27),
	(218, 28, 1, 218, 28),
	(218, 29, 1, 218, 29),
	(218, 30, 1, 218, 30),
	(218, 31, 1, 218, 31),
	(218, 32, 1, 218, 32),
	(218, 33, 1, 218, 33),
	(218, 34, 1, 218, 34),
	(218, 35, 1, 218, 35),
	(218, 36, 1, 218, 36),
	(218, 37, 1, 218, 37),
	(218, 38, 1, 218, 38),
	(218, 39, 1, 218, 39),
	(218, 40, 1, 218, 40),
	(218, 41, 1, 218, 41),
	(218, 42, 1, 218, 42),
	(218, 43, 1, 218, 43),
	(218, 44, 1, 218, 44),
	(608, 399, 1, 355, 1),
	(608, 400, 1, 355, 2),
	(608, 391, 1, 355, 3),
	(608, 392, 1, 355, 4),
	(608, 401, 1, 355, 5),
	(608, 402, 1, 355, 6),
	(608, 393, 1, 355, 7),
	(608, 394, 1, 355, 8),
	(608, 403, 1, 355, 9),
	(608, 404, 1, 355, 10),
	(608, 395, 1, 355, 11),
	(608, 396, 1, 355, 12),
	(608, 405, 1, 355, 13),
	(608, 406, 1, 355, 14),
	(608, 397, 1, 355, 15),
	(608, 398, 1, 355, 16),
	(608, 363, 1, 355, 17),
	(608, 364, 1, 355, 18),
	(608, 355, 1, 355, 19),
	(608, 356, 1, 355, 20),
	(608, 365, 1, 355, 21),
	(608, 366, 1, 355, 22),
	(608, 357, 1, 355, 23),
	(608, 358, 1, 355, 24),
	(608, 367, 1, 355, 25),
	(608, 368, 1, 355, 26),
	(608, 359, 1, 355, 27),
	(608, 360, 1, 355, 28),
	(608, 369, 1, 355, 29),
	(608, 370, 1, 355, 30),
	(608, 361, 1, 355, 31),
	(608, 362, 1, 355, 32),
	(608, 379, 1, 355, 33),
	(608, 380, 1, 355, 34),
	(608, 371, 1, 355, 35),
	(608, 372, 1, 355, 36),
	(608, 381, 1, 355, 37),
	(608, 382, 1, 355, 38),
	(608, 373, 1, 355, 39),
	(608, 374, 1, 355, 40),
	(608, 383, 1, 355, 41),
	(608, 384, 1, 355, 42),
	(608, 375, 1, 355, 43),
	(608, 376, 1, 355, 44),
	(608, 385, 1, 355, 45),
	(608, 386, 1, 355, 46),
	(608, 377, 1, 355, 47),
	(608, 378, 1, 355, 48),
	(608, 389, 1, 355, 49),
	(608, 390, 1, 355, 50),
	(608, 387, 1, 355, 51),
	(608, 388, 1, 355, 52),
	(608, 345, 1, 355, 53),
	(608, 344, 1, 355, 54),
	(608, 343, 1, 355, 55),
	(608, 342, 1, 355, 56),
	(608, 341, 1, 355, 57),
	(608, 354, 1, 355, 58),
	(608, 353, 1, 355, 62),
	(608, 352, 1, 355, 63),
	(608, 351, 1, 355, 64),
	(608, 350, 1, 355, 65),
	(608, 349, 1, 355, 66),
	(608, 348, 1, 355, 67),
	(608, 347, 1, 355, 84),
	(608, 346, 1, 355, 85),
	(608, 413, 1, 355, 377),
	(608, 414, 1, 355, 378),
	(608, 411, 1, 355, 379),
	(608, 412, 1, 355, 380),
	(608, 409, 1, 355, 1044),
	(608, 410, 1, 355, 1045),
	(608, 407, 1, 355, 1046),
	(608, 408, 1, 355, 1047),
	(419, 3, 1, 355, 4902),
	(419, 13, 1, 355, 8672),
	(419, 15, 1, 355, 8678),
	(419, 4, 1, 355, 8696),
	(419, 5, 1, 355, 8702),
	(419, 7, 1, 355, 8708),
	(419, 8, 1, 355, 8714),
	(419, 9, 1, 355, 8720),
	(419, 10, 1, 355, 8836),
	(419, 14, 1, 355, 8842),
	(419, 18, 1, 355, 8848),
	(419, 19, 1, 355, 8854),
	(419, 20, 1, 355, 8860),
	(419, 11, 1, 355, 8867),
	(419, 12, 1, 355, 8868),
	(419, 16, 1, 355, 8869),
	(419, 17, 1, 355, 8870),
	(419, 38, 1, 355, 8871),
	(419, 1, 1, 355, 8884),
	(419, 2, 1, 355, 8885),
	(419, 6, 1, 355, 8886),
	(419, 21, 1, 355, 8887),
	(419, 26, 1, 355, 8888),
	(419, 27, 1, 355, 8889),
	(419, 28, 1, 355, 8890),
	(419, 29, 1, 355, 8891),
	(419, 30, 1, 355, 8894),
	(419, 36, 1, 355, 8895),
	(419, 37, 1, 355, 8899),
	(419, 34, 1, 355, 8902),
	(419, 32, 1, 355, 8903),
	(419, 35, 1, 355, 8930),
	(419, 31, 1, 355, 8974),
	(419, 33, 1, 355, 8977),
	(628, 714, 1, 410, 457),
	(628, 715, 1, 410, 457),
	(628, 717, 1, 410, 457),
	(628, 718, 1, 410, 457),
	(628, 719, 1, 410, 457),
	(628, 720, 1, 410, 457),
	(628, 721, 1, 410, 457),
	(628, 722, 1, 410, 457),
	(628, 723, 1, 410, 457),
	(628, 724, 1, 410, 457),
	(628, 725, 1, 410, 457),
	(628, 726, 1, 410, 457),
	(628, 727, 1, 410, 457),
	(628, 728, 1, 410, 457),
	(628, 729, 1, 410, 457),
	(628, 730, 1, 410, 457),
	(628, 731, 1, 410, 457),
	(628, 732, 1, 410, 457),
	(628, 733, 1, 410, 457),
	(628, 734, 1, 410, 457),
	(628, 735, 1, 410, 457),
	(628, 736, 1, 410, 457),
	(628, 737, 1, 410, 457),
	(628, 738, 1, 410, 457),
	(628, 739, 1, 410, 457),
	(628, 740, 1, 410, 457),
	(628, 774, 1, 410, 457),
	(628, 775, 1, 410, 457),
	(628, 776, 1, 410, 457),
	(628, 777, 1, 410, 457),
	(628, 778, 1, 410, 457),
	(628, 779, 1, 410, 457),
	(628, 796, 1, 410, 457),
	(628, 797, 1, 410, 457),
	(628, 817, 1, 410, 457),
	(628, 879, 1, 410, 457),
	(628, 880, 1, 410, 457),
	(628, 883, 1, 410, 457),
	(628, 884, 1, 410, 457),
	(628, 885, 1, 410, 457),
	(628, 886, 1, 410, 457),
	(628, 909, 1, 410, 457),
	(628, 910, 1, 410, 457),
	(628, 911, 1, 410, 457),
	(628, 921, 1, 410, 457),
	(628, 922, 1, 410, 457),
	(628, 954, 1, 410, 457),
	(628, 955, 1, 410, 457),
	(628, 956, 1, 410, 457),
	(628, 957, 1, 410, 457),
	(628, 958, 1, 410, 457),
	(628, 962, 1, 410, 457),
	(628, 963, 1, 410, 457),
	(628, 979, 1, 410, 457),
	(628, 980, 1, 410, 457),
	(628, 981, 1, 410, 457),
	(628, 982, 1, 410, 457),
	(628, 983, 1, 410, 457),
	(628, 1000, 1, 410, 457),
	(628, 1001, 1, 410, 457),
	(628, 1002, 1, 410, 457),
	(628, 1003, 1, 410, 457),
	(628, 1004, 1, 410, 457),
	(628, 1005, 1, 410, 457),
	(628, 1006, 1, 410, 457),
	(628, 1008, 1, 410, 457),
	(628, 1009, 1, 410, 457),
	(628, 1010, 1, 410, 457),
	(628, 1011, 1, 410, 457),
	(628, 1012, 1, 410, 457),
	(628, 1013, 1, 410, 457),
	(628, 1014, 1, 410, 457),
	(628, 1024, 1, 410, 457),
	(628, 1025, 1, 410, 457),
	(628, 1026, 1, 410, 457),
	(628, 1029, 1, 410, 457),
	(628, 1030, 1, 410, 457),
	(628, 1031, 1, 410, 457),
	(628, 1070, 1, 410, 457),
	(628, 1071, 1, 410, 457),
	(628, 1072, 1, 410, 457),
	(628, 1080, 1, 410, 457),
	(628, 1854, 1, 410, 457),
	(628, 1879, 1, 410, 457),
	(628, 1884, 1, 410, 457),
	(628, 1904, 1, 410, 457),
	(628, 1905, 1, 410, 457),
	(628, 1906, 1, 410, 457),
	(628, 1936, 1, 410, 457),
	(628, 1944, 1, 410, 457),
	(628, 1945, 1, 410, 457),
	(628, 1946, 1, 410, 457),
	(628, 1947, 1, 410, 457),
	(628, 1948, 1, 410, 457),
	(628, 1949, 1, 410, 457),
	(628, 1950, 1, 410, 457),
	(628, 1954, 1, 410, 457),
	(628, 1955, 1, 410, 457),
	(628, 1956, 1, 410, 457),
	(628, 1959, 1, 410, 457),
	(628, 1960, 1, 410, 457),
	(628, 1961, 1, 410, 457),
	(628, 1962, 1, 410, 457),
	(628, 1963, 1, 410, 457),
	(628, 1964, 1, 410, 457),
	(628, 1965, 1, 410, 457),
	(628, 1966, 1, 410, 457),
	(628, 1967, 1, 410, 457),
	(628, 1968, 1, 410, 457),
	(628, 1969, 1, 410, 457),
	(628, 1970, 1, 410, 457),
	(628, 1971, 1, 410, 457),
	(628, 1972, 1, 410, 457),
	(628, 1973, 1, 410, 457),
	(628, 1974, 1, 410, 457),
	(628, 1975, 1, 410, 457),
	(628, 1976, 1, 410, 457),
	(628, 1977, 1, 410, 457),
	(628, 1978, 1, 410, 457),
	(628, 1979, 1, 410, 457),
	(628, 1980, 1, 410, 457),
	(628, 1981, 1, 410, 457),
	(628, 1982, 1, 410, 457),
	(628, 1983, 1, 410, 457),
	(628, 1984, 1, 410, 457),
	(628, 1985, 1, 410, 457),
	(628, 1986, 1, 410, 457),
	(628, 1987, 1, 410, 457),
	(628, 1988, 1, 410, 457),
	(628, 1989, 1, 410, 457),
	(628, 1990, 1, 410, 457),
	(628, 1991, 1, 410, 457),
	(628, 1993, 1, 410, 457),
	(628, 1994, 1, 410, 457),
	(628, 1995, 1, 410, 457),
	(628, 1998, 1, 410, 457),
	(628, 2003, 1, 410, 457),
	(628, 2004, 1, 410, 457),
	(628, 2005, 1, 410, 457),
	(628, 2006, 1, 410, 457),
	(628, 2007, 1, 410, 457),
	(628, 2008, 1, 410, 457),
	(628, 2009, 1, 410, 457),
	(628, 2010, 1, 410, 457),
	(628, 2011, 1, 410, 457),
	(628, 2012, 1, 410, 457),
	(628, 2013, 1, 410, 457),
	(628, 2014, 1, 410, 457),
	(628, 2015, 1, 410, 457),
	(628, 2016, 1, 410, 457),
	(628, 2017, 1, 410, 457),
	(628, 2018, 1, 410, 457),
	(628, 2019, 1, 410, 457),
	(628, 2020, 1, 410, 457),
	(628, 2021, 1, 410, 457),
	(628, 2022, 1, 410, 457),
	(628, 2023, 1, 410, 457),
	(628, 2024, 1, 410, 457),
	(628, 2025, 1, 410, 457),
	(628, 2026, 1, 410, 457),
	(628, 2027, 1, 410, 457),
	(628, 2028, 1, 410, 457),
	(628, 2029, 1, 410, 457),
	(628, 2030, 1, 410, 457),
	(628, 2033, 1, 410, 457),
	(628, 2034, 1, 410, 457),
	(628, 2035, 1, 410, 457),
	(628, 2036, 1, 410, 457),
	(628, 2037, 1, 410, 457),
	(628, 2038, 1, 410, 457),
	(628, 2039, 1, 410, 457),
	(628, 2040, 1, 410, 457),
	(628, 2041, 1, 410, 457),
	(628, 2042, 1, 410, 457),
	(628, 2043, 1, 410, 457),
	(628, 2044, 1, 410, 457),
	(628, 2045, 1, 410, 457),
	(628, 2046, 1, 410, 457),
	(628, 2047, 1, 410, 457),
	(628, 2048, 1, 410, 457),
	(628, 2049, 1, 410, 457),
	(628, 2050, 1, 410, 457),
	(628, 2051, 1, 410, 457),
	(628, 2052, 1, 410, 457),
	(628, 2053, 1, 410, 457),
	(628, 2054, 1, 410, 457),
	(628, 2055, 1, 410, 457),
	(628, 2056, 1, 410, 457),
	(628, 2057, 1, 410, 457),
	(628, 2058, 1, 410, 457),
	(628, 2059, 1, 410, 457),
	(628, 2060, 1, 410, 457),
	(628, 2061, 1, 410, 457),
	(628, 2062, 1, 410, 457),
	(628, 2063, 1, 410, 457),
	(628, 2064, 1, 410, 457),
	(628, 2065, 1, 410, 457),
	(628, 2066, 1, 410, 457),
	(628, 2067, 1, 410, 457),
	(628, 2068, 1, 410, 457),
	(628, 2073, 1, 410, 457),
	(628, 2074, 1, 410, 457),
	(628, 2075, 1, 410, 457),
	(628, 2076, 1, 410, 457),
	(628, 2077, 1, 410, 457),
	(628, 2078, 1, 410, 457),
	(628, 2079, 1, 410, 457),
	(628, 2080, 1, 410, 457),
	(628, 2081, 1, 410, 457),
	(628, 2082, 1, 410, 457),
	(628, 2083, 1, 410, 457),
	(628, 2084, 1, 410, 457),
	(628, 2085, 1, 410, 457),
	(628, 2086, 1, 410, 457),
	(628, 2087, 1, 410, 457),
	(628, 2088, 1, 410, 457),
	(628, 2089, 1, 410, 457),
	(628, 2090, 1, 410, 457),
	(628, 2091, 1, 410, 457),
	(628, 2092, 1, 410, 457),
	(628, 2093, 1, 410, 457),
	(628, 2094, 1, 410, 457),
	(628, 2095, 1, 410, 457),
	(628, 2096, 1, 410, 457),
	(628, 2097, 1, 410, 457),
	(628, 2098, 1, 410, 457),
	(628, 2099, 1, 410, 457),
	(628, 2100, 1, 410, 457),
	(628, 2101, 1, 410, 457),
	(628, 2102, 1, 410, 457),
	(628, 2103, 1, 410, 457),
	(628, 2104, 1, 410, 457),
	(628, 2105, 1, 410, 457),
	(628, 2106, 1, 410, 457),
	(628, 2107, 1, 410, 457),
	(628, 2108, 1, 410, 457),
	(628, 2109, 1, 410, 457),
	(628, 2110, 1, 410, 457),
	(628, 2111, 1, 410, 457),
	(628, 2112, 1, 410, 457),
	(628, 2113, 1, 410, 457),
	(628, 2114, 1, 410, 457),
	(628, 2115, 1, 410, 457),
	(628, 2116, 1, 410, 457),
	(628, 2117, 1, 410, 457),
	(628, 2118, 1, 410, 457),
	(628, 2119, 1, 410, 457),
	(628, 2120, 1, 410, 457),
	(628, 2121, 1, 410, 457),
	(628, 2122, 1, 410, 457),
	(628, 2123, 1, 410, 457),
	(628, 2125, 1, 410, 457),
	(628, 2126, 1, 410, 457),
	(628, 2127, 1, 410, 457),
	(628, 2128, 1, 410, 457),
	(628, 2129, 1, 410, 457),
	(628, 2130, 1, 410, 457),
	(628, 2131, 1, 410, 457),
	(628, 2132, 1, 410, 457),
	(628, 2133, 1, 410, 457),
	(628, 2134, 1, 410, 457),
	(628, 2135, 1, 410, 457),
	(628, 2136, 1, 410, 457),
	(628, 2137, 1, 410, 457),
	(628, 2138, 1, 410, 457),
	(628, 2139, 1, 410, 457),
	(628, 2140, 1, 410, 457),
	(628, 2141, 1, 410, 457),
	(628, 2142, 1, 410, 457),
	(628, 2143, 1, 410, 457),
	(628, 2144, 1, 410, 457),
	(628, 2145, 1, 410, 457),
	(628, 2146, 1, 410, 457),
	(628, 2147, 1, 410, 457),
	(628, 2148, 1, 410, 457),
	(628, 2149, 1, 410, 457),
	(628, 2150, 1, 410, 457),
	(628, 2151, 1, 410, 457),
	(628, 2152, 1, 410, 457),
	(628, 2153, 1, 410, 457),
	(628, 2154, 1, 410, 457),
	(628, 2155, 1, 410, 457),
	(628, 2156, 1, 410, 457),
	(628, 2157, 1, 410, 457),
	(628, 2158, 1, 410, 457),
	(628, 2159, 1, 410, 457),
	(628, 2160, 1, 410, 457),
	(628, 2161, 1, 410, 457),
	(628, 2162, 1, 410, 457),
	(628, 2163, 1, 410, 457),
	(628, 2164, 1, 410, 457),
	(628, 2165, 1, 410, 457),
	(628, 2166, 1, 410, 457),
	(628, 2167, 1, 410, 457),
	(628, 2168, 1, 410, 457),
	(628, 2169, 1, 410, 457),
	(628, 2170, 1, 410, 457),
	(628, 2171, 1, 410, 457),
	(628, 2172, 1, 410, 457),
	(628, 2173, 1, 410, 457),
	(628, 2174, 1, 410, 457),
	(628, 2175, 1, 410, 457),
	(628, 2176, 1, 410, 457),
	(628, 2177, 1, 410, 457),
	(628, 2178, 1, 410, 457),
	(628, 2179, 1, 410, 457),
	(628, 2180, 1, 410, 457),
	(628, 2181, 1, 410, 457),
	(628, 2182, 1, 410, 457),
	(628, 2183, 1, 410, 457),
	(628, 2184, 1, 410, 457),
	(628, 2185, 1, 410, 457),
	(628, 2186, 1, 410, 457),
	(628, 2187, 1, 410, 457),
	(628, 2188, 1, 410, 457),
	(628, 2189, 1, 410, 457),
	(628, 2190, 1, 410, 457),
	(628, 2191, 1, 410, 457),
	(628, 2192, 1, 410, 457),
	(628, 2193, 1, 410, 457),
	(628, 2194, 1, 410, 457),
	(628, 2195, 1, 410, 457),
	(628, 2196, 1, 410, 457),
	(628, 2197, 1, 410, 457),
	(628, 2198, 1, 410, 457),
	(628, 2199, 1, 410, 457),
	(628, 2200, 1, 410, 457),
	(628, 2201, 1, 410, 457),
	(628, 2202, 1, 410, 457),
	(628, 2203, 1, 410, 457),
	(628, 2204, 1, 410, 457),
	(628, 2205, 1, 410, 457),
	(628, 2206, 1, 410, 457),
	(628, 2207, 1, 410, 457),
	(628, 2208, 1, 410, 457),
	(628, 2209, 1, 410, 457),
	(628, 2210, 1, 410, 457),
	(628, 2211, 1, 410, 457),
	(628, 2212, 1, 410, 457),
	(628, 2213, 1, 410, 457),
	(628, 2214, 1, 410, 457),
	(628, 2215, 1, 410, 457),
	(628, 2216, 1, 410, 457),
	(628, 2217, 1, 410, 457),
	(628, 2218, 1, 410, 457),
	(628, 2219, 1, 410, 457),
	(628, 2220, 1, 410, 457),
	(628, 2221, 1, 410, 457),
	(628, 2222, 1, 410, 457),
	(628, 2223, 1, 410, 457),
	(628, 2224, 1, 410, 457),
	(628, 2225, 1, 410, 457),
	(628, 2226, 1, 410, 457),
	(628, 2227, 1, 410, 457),
	(628, 2228, 1, 410, 457),
	(628, 2229, 1, 410, 457),
	(628, 2230, 1, 410, 457),
	(628, 2231, 1, 410, 457),
	(628, 2232, 1, 410, 457),
	(628, 2233, 1, 410, 457),
	(628, 2234, 1, 410, 457),
	(628, 2235, 1, 410, 457),
	(628, 2236, 1, 410, 457),
	(628, 2237, 1, 410, 457),
	(628, 2238, 1, 410, 457),
	(628, 2239, 1, 410, 457),
	(628, 2240, 1, 410, 457),
	(628, 2241, 1, 410, 457),
	(628, 2242, 1, 410, 457),
	(628, 2243, 1, 410, 457),
	(628, 2244, 1, 410, 457),
	(628, 2245, 1, 410, 457),
	(628, 2246, 1, 410, 457),
	(628, 2247, 1, 410, 457),
	(628, 2248, 1, 410, 457),
	(628, 2249, 1, 410, 457),
	(628, 2250, 1, 410, 457),
	(628, 2251, 1, 410, 457),
	(628, 2252, 1, 410, 457),
	(628, 2253, 1, 410, 457),
	(628, 2254, 1, 410, 457),
	(628, 2255, 1, 410, 457),
	(628, 2256, 1, 410, 457),
	(628, 2257, 1, 410, 457),
	(628, 2258, 1, 410, 457),
	(628, 2259, 1, 410, 457),
	(628, 2260, 1, 410, 457),
	(628, 2261, 1, 410, 457),
	(628, 2262, 1, 410, 457),
	(628, 2263, 1, 410, 457),
	(628, 2264, 1, 410, 457),
	(628, 2265, 1, 410, 457),
	(628, 2266, 1, 410, 457),
	(628, 2267, 1, 410, 457),
	(628, 2268, 1, 410, 457),
	(628, 2269, 1, 410, 457),
	(628, 2270, 1, 410, 457),
	(628, 2271, 1, 410, 457),
	(628, 2272, 1, 410, 457),
	(628, 2273, 1, 410, 457),
	(628, 2274, 1, 410, 457),
	(628, 2275, 1, 410, 457),
	(628, 2276, 1, 410, 457),
	(628, 2277, 1, 410, 457),
	(628, 2278, 1, 410, 457),
	(628, 2279, 1, 410, 457),
	(628, 2280, 1, 410, 457),
	(628, 2281, 1, 410, 457),
	(628, 2282, 1, 410, 457),
	(628, 2283, 1, 410, 457),
	(628, 2284, 1, 410, 457),
	(628, 2285, 1, 410, 457),
	(628, 2286, 1, 410, 457),
	(628, 2287, 1, 410, 457),
	(628, 2288, 1, 410, 457),
	(628, 2289, 1, 410, 457),
	(628, 2290, 1, 410, 457),
	(628, 2291, 1, 410, 457),
	(628, 2292, 1, 410, 457),
	(628, 2293, 1, 410, 457),
	(628, 2294, 1, 410, 457),
	(628, 2295, 1, 410, 457),
	(628, 2296, 1, 410, 457),
	(628, 2297, 1, 410, 457),
	(628, 2298, 1, 410, 457),
	(628, 2299, 1, 410, 457),
	(628, 2300, 1, 410, 457),
	(628, 2301, 1, 410, 457),
	(628, 2302, 1, 410, 457),
	(628, 2303, 1, 410, 457),
	(628, 2304, 1, 410, 457),
	(628, 2305, 1, 410, 457),
	(628, 2306, 1, 410, 457),
	(628, 2307, 1, 410, 457),
	(628, 2308, 1, 410, 457),
	(628, 2310, 1, 410, 457),
	(628, 2315, 1, 410, 457),
	(628, 2316, 1, 410, 457),
	(628, 2317, 1, 410, 457),
	(628, 2318, 1, 410, 457),
	(628, 2319, 1, 410, 457),
	(628, 2320, 1, 410, 457),
	(628, 2321, 1, 410, 457),
	(628, 2322, 1, 410, 457),
	(628, 2323, 1, 410, 457),
	(628, 2324, 1, 410, 457),
	(628, 2325, 1, 410, 457),
	(628, 2326, 1, 410, 457),
	(628, 2330, 1, 410, 457),
	(628, 2331, 1, 410, 457),
	(628, 2335, 1, 410, 457),
	(628, 2336, 1, 410, 457),
	(628, 2337, 1, 410, 457),
	(628, 2338, 1, 410, 457),
	(628, 2339, 1, 410, 457),
	(628, 2340, 1, 410, 457),
	(628, 2341, 1, 410, 457),
	(628, 2342, 1, 410, 457),
	(628, 2343, 1, 410, 457),
	(628, 2344, 1, 410, 457),
	(628, 2345, 1, 410, 457),
	(628, 2346, 1, 410, 457),
	(628, 2347, 1, 410, 457),
	(628, 2348, 1, 410, 457),
	(628, 2349, 1, 410, 457),
	(628, 2350, 1, 410, 457),
	(628, 2351, 1, 410, 457),
	(628, 2352, 1, 410, 457),
	(628, 2355, 1, 410, 457),
	(628, 2356, 1, 410, 457),
	(120, 1, 1, 419, 1),
	(120, 2, 1, 419, 2),
	(120, 3, 1, 419, 3),
	(120, 4, 1, 419, 4),
	(120, 5, 1, 419, 5),
	(120, 6, 1, 419, 6),
	(120, 7, 1, 419, 7),
	(120, 8, 1, 419, 8),
	(120, 9, 1, 419, 9),
	(120, 10, 1, 419, 10),
	(120, 11, 1, 419, 11),
	(120, 12, 1, 419, 12),
	(120, 13, 1, 419, 13),
	(120, 14, 1, 419, 14),
	(120, 15, 1, 419, 15),
	(120, 16, 1, 419, 16),
	(120, 17, 1, 419, 17),
	(120, 18, 1, 419, 18),
	(120, 19, 1, 419, 19),
	(120, 20, 1, 419, 20),
	(120, 21, 1, 419, 21),
	(120, 26, 1, 419, 26),
	(120, 27, 1, 419, 27),
	(120, 28, 1, 419, 28),
	(120, 29, 1, 419, 29),
	(120, 30, 1, 419, 30),
	(120, 31, 1, 419, 31),
	(120, 32, 1, 419, 32),
	(120, 33, 1, 419, 33),
	(120, 34, 1, 419, 34),
	(120, 35, 1, 419, 35),
	(120, 36, 1, 419, 36),
	(120, 37, 1, 419, 37),
	(120, 38, 1, 419, 38),
	(419, 38, 2, 442, 1),
	(506, 1, 2, 488, 1),
	(506, 6, 2, 488, 6),
	(506, 11, 2, 488, 11),
	(506, 12, 2, 488, 12),
	(506, 13, 2, 488, 13),
	(506, 14, 2, 488, 14),
	(506, 16, 2, 488, 16),
	(506, 17, 2, 488, 17),
	(506, 18, 2, 488, 18),
	(506, 19, 2, 488, 19),
	(506, 20, 2, 488, 20),
	(506, 21, 2, 488, 21),
	(506, 22, 2, 488, 22),
	(506, 23, 2, 488, 23),
	(506, 24, 2, 488, 24),
	(506, 25, 2, 488, 25),
	(506, 26, 2, 488, 26),
	(506, 27, 2, 488, 27),
	(506, 28, 2, 488, 28),
	(506, 29, 2, 488, 29),
	(506, 30, 2, 488, 30),
	(506, 31, 2, 488, 31),
	(506, 32, 2, 488, 32),
	(506, 33, 2, 488, 33),
	(506, 34, 2, 488, 34),
	(506, 35, 2, 488, 35),
	(506, 36, 2, 488, 36),
	(506, 41, 2, 488, 41),
	(506, 42, 2, 488, 42),
	(506, 46, 2, 488, 46),
	(506, 51, 2, 488, 51),
	(506, 52, 2, 488, 52),
	(506, 53, 2, 488, 53),
	(506, 54, 2, 488, 54),
	(506, 55, 2, 488, 55),
	(506, 56, 2, 488, 56),
	(506, 57, 2, 488, 57),
	(506, 58, 2, 488, 58),
	(506, 59, 2, 488, 59),
	(506, 60, 2, 488, 60),
	(506, 61, 2, 488, 61),
	(506, 62, 2, 488, 62),
	(506, 63, 2, 488, 63),
	(502, 6, 1, 506, 6),
	(502, 11, 1, 506, 14),
	(502, 16, 1, 506, 16),
	(603, 38, 2, 601, 38),
	(603, 1, 1, 628, 2330),
	(603, 2, 1, 628, 2330),
	(603, 3, 1, 628, 2330),
	(603, 4, 1, 628, 2330),
	(603, 5, 1, 628, 2330),
	(603, 6, 1, 628, 2330),
	(603, 7, 1, 628, 2330),
	(603, 8, 1, 628, 2330),
	(603, 9, 1, 628, 2330),
	(603, 10, 1, 628, 2330),
	(603, 11, 1, 628, 2330),
	(603, 12, 1, 628, 2330),
	(603, 13, 1, 628, 2330),
	(603, 18, 1, 628, 2330),
	(603, 19, 1, 628, 2330),
	(603, 20, 1, 628, 2330),
	(603, 21, 1, 628, 2330),
	(603, 26, 1, 628, 2330),
	(603, 27, 1, 628, 2330),
	(603, 28, 1, 628, 2330),
	(603, 29, 1, 628, 2330),
	(603, 30, 1, 628, 2330),
	(603, 31, 1, 628, 2330),
	(603, 32, 1, 628, 2330),
	(603, 33, 1, 628, 2330),
	(603, 34, 1, 628, 2330),
	(603, 35, 1, 628, 2330),
	(603, 36, 1, 628, 2330),
	(603, 37, 1, 628, 2330),
	(603, 14, 1, 628, 2331),
	(603, 15, 1, 628, 2331),
	(603, 16, 1, 628, 2331),
	(603, 17, 1, 628, 2331),
	(603, 38, 1, 628, 2331),
	(601, 1, 1, 642, 1388),
	(601, 2, 1, 642, 1388),
	(601, 3, 1, 642, 1388),
	(601, 4, 1, 642, 1388),
	(601, 5, 1, 642, 1388),
	(601, 6, 1, 642, 1388),
	(601, 7, 1, 642, 1388),
	(601, 8, 1, 642, 1388),
	(601, 9, 1, 642, 1388),
	(601, 10, 1, 642, 1388),
	(601, 11, 1, 642, 1388),
	(601, 12, 1, 642, 1388),
	(601, 13, 1, 642, 1388),
	(601, 18, 1, 642, 1388),
	(601, 19, 1, 642, 1388),
	(601, 20, 1, 642, 1388),
	(601, 21, 1, 642, 1388),
	(601, 26, 1, 642, 1388),
	(601, 27, 1, 642, 1388),
	(601, 28, 1, 642, 1388),
	(601, 29, 1, 642, 1388),
	(601, 30, 1, 642, 1388),
	(601, 31, 1, 642, 1388),
	(601, 32, 1, 642, 1388),
	(601, 33, 1, 642, 1388),
	(601, 34, 1, 642, 1388),
	(601, 35, 1, 642, 1388),
	(601, 36, 1, 642, 1388),
	(601, 37, 1, 642, 1388),
	(601, 14, 1, 642, 1389),
	(601, 15, 1, 642, 1389),
	(601, 16, 1, 642, 1389),
	(601, 17, 1, 642, 1389),
	(601, 38, 1, 642, 1389),
	(665, 0, 1, 665, 0),
	(665, 1, 1, 665, 1),
	(665, 2, 1, 665, 2),
	(665, 3, 1, 665, 3),
	(665, 4, 1, 665, 4),
	(665, 5, 1, 665, 5),
	(665, 6, 1, 665, 6),
	(665, 7, 1, 665, 7),
	(665, 8, 1, 665, 8),
	(665, 9, 1, 665, 9),
	(665, 10, 1, 665, 10),
	(665, 11, 1, 665, 11),
	(665, 12, 1, 665, 12),
	(665, 13, 1, 665, 13),
	(665, 14, 1, 665, 14),
	(665, 15, 1, 665, 15),
	(665, 16, 1, 665, 16),
	(665, 17, 1, 665, 17),
	(665, 18, 1, 665, 18),
	(665, 19, 1, 665, 19),
	(665, 20, 1, 665, 20),
	(665, 21, 1, 665, 21),
	(665, 22, 1, 665, 22),
	(665, 23, 1, 665, 23),
	(665, 24, 1, 665, 24),
	(665, 25, 1, 665, 25),
	(665, 26, 1, 665, 26),
	(665, 27, 1, 665, 27),
	(665, 28, 1, 665, 28),
	(665, 29, 1, 665, 29),
	(665, 30, 1, 665, 30),
	(665, 31, 1, 665, 31),
	(665, 32, 1, 665, 32),
	(665, 33, 1, 665, 33),
	(665, 34, 1, 665, 34),
	(665, 35, 1, 665, 35),
	(665, 36, 1, 665, 36),
	(665, 37, 1, 665, 37),
	(665, 38, 1, 665, 38),
	(665, 39, 1, 665, 39),
	(665, 40, 1, 665, 40),
	(665, 41, 1, 665, 41),
	(665, 42, 1, 665, 42),
	(665, 43, 1, 665, 43),
	(665, 44, 1, 665, 44),
	(665, 45, 1, 665, 45),
	(665, 46, 1, 665, 46),
	(665, 47, 1, 665, 47),
	(665, 48, 1, 665, 48),
	(665, 49, 1, 665, 49),
	(665, 50, 1, 665, 50),
	(665, 51, 1, 665, 51),
	(665, 52, 1, 665, 52),
	(665, 53, 1, 665, 53),
	(665, 54, 1, 665, 54),
	(665, 55, 1, 665, 55),
	(665, 56, 1, 665, 56),
	(665, 57, 1, 665, 57),
	(665, 58, 1, 665, 58),
	(665, 59, 1, 665, 59),
	(665, 60, 1, 665, 60),
	(665, 61, 1, 665, 61),
	(665, 62, 1, 665, 62),
	(665, 63, 1, 665, 63),
	(665, 64, 1, 665, 64),
	(665, 65, 1, 665, 65),
	(665, 66, 1, 665, 66),
	(665, 67, 1, 665, 67),
	(665, 68, 1, 665, 68),
	(665, 69, 1, 665, 69),
	(665, 70, 1, 665, 70),
	(665, 71, 1, 665, 71),
	(665, 72, 1, 665, 72),
	(665, 73, 1, 665, 73),
	(665, 74, 1, 665, 74),
	(665, 75, 1, 665, 75),
	(665, 76, 1, 665, 76),
	(665, 77, 1, 665, 77),
	(665, 78, 1, 665, 78),
	(665, 79, 1, 665, 79),
	(665, 80, 1, 665, 80),
	(665, 81, 1, 665, 81),
	(665, 82, 1, 665, 82),
	(665, 83, 1, 665, 83),
	(665, 84, 1, 665, 84),
	(665, 85, 1, 665, 85),
	(665, 86, 1, 665, 86),
	(665, 87, 1, 665, 87),
	(665, 88, 1, 665, 88),
	(665, 89, 1, 665, 89),
	(665, 90, 1, 665, 90),
	(665, 91, 1, 665, 91),
	(665, 92, 1, 665, 92),
	(665, 93, 1, 665, 93),
	(665, 94, 1, 665, 94),
	(665, 95, 1, 665, 95),
	(665, 96, 1, 665, 96),
	(665, 97, 1, 665, 97),
	(665, 98, 1, 665, 98),
	(665, 99, 1, 665, 99);
/*!40000 ALTER TABLE `colc_data` ENABLE KEYS */;

-- Dumping structure for table emcor.cold
CREATE TABLE IF NOT EXISTS `cold` (
  `col_id` mediumint(8) unsigned NOT NULL COMMENT 'Lauko identifikatorius',
  `nr` smallint(5) unsigned NOT NULL COMMENT 'Numeris',
  `desc_col_id` mediumint(8) unsigned NOT NULL COMMENT 'Apibūdinančio tekstinio lauko identifikatorius',
  PRIMARY KEY (`col_id`,`nr`),
  KEY `cold_desc_col_i` (`desc_col_id`),
  CONSTRAINT `cold_col_fk` FOREIGN KEY (`col_id`) REFERENCES `col` (`col_id`) ON DELETE CASCADE,
  CONSTRAINT `cold_desc_col_fk` FOREIGN KEY (`desc_col_id`) REFERENCES `col` (`col_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Lentelių laukus-identifikatorius apibūdinantys tekstiniai laukai';

-- Dumping data for table emcor.cold: ~110 rows (approximately)
/*!40000 ALTER TABLE `cold` DISABLE KEYS */;
INSERT INTO `cold` (`col_id`, `nr`, `desc_col_id`) VALUES
	(3, 1, 5),
	(6, 1, 7),
	(9, 1, 10),
	(11, 1, 12),
	(13, 1, 14),
	(21, 1, 20),
	(25, 1, 24),
	(28, 1, 29),
	(36, 1, 35),
	(41, 1, 38),
	(62, 1, 61),
	(99, 1, 100),
	(684, 1, 103),
	(105, 1, 106),
	(111, 1, 112),
	(113, 1, 114),
	(122, 1, 121),
	(123, 1, 124),
	(128, 1, 125),
	(131, 1, 132),
	(133, 1, 134),
	(140, 1, 136),
	(150, 1, 148),
	(160, 1, 159),
	(394, 8, 161),
	(164, 1, 163),
	(172, 1, 170),
	(175, 1, 174),
	(180, 1, 179),
	(185, 1, 184),
	(199, 1, 195),
	(196, 1, 197),
	(202, 1, 203),
	(209, 1, 206),
	(225, 1, 224),
	(229, 1, 228),
	(237, 1, 236),
	(244, 1, 239),
	(394, 6, 246),
	(248, 1, 247),
	(256, 1, 255),
	(266, 1, 263),
	(274, 1, 273),
	(305, 1, 306),
	(319, 1, 320),
	(323, 1, 322),
	(326, 1, 325),
	(346, 1, 345),
	(349, 1, 350),
	(351, 1, 352),
	(355, 1, 354),
	(357, 1, 356),
	(368, 1, 369),
	(383, 1, 382),
	(387, 1, 386),
	(391, 1, 390),
	(392, 1, 393),
	(406, 1, 405),
	(412, 1, 411),
	(410, 2, 413),
	(415, 1, 416),
	(425, 1, 424),
	(442, 1, 428),
	(448, 1, 447),
	(454, 1, 453),
	(462, 1, 461),
	(471, 1, 470),
	(475, 1, 474),
	(480, 1, 482),
	(486, 1, 485),
	(488, 1, 490),
	(492, 1, 491),
	(506, 1, 508),
	(510, 1, 509),
	(512, 1, 513),
	(515, 1, 514),
	(516, 1, 517),
	(520, 1, 519),
	(536, 1, 529),
	(534, 1, 535),
	(541, 1, 542),
	(548, 1, 545),
	(558, 1, 557),
	(561, 1, 562),
	(564, 1, 563),
	(584, 1, 585),
	(582, 1, 587),
	(612, 1, 611),
	(614, 1, 613),
	(636, 1, 635),
	(642, 4, 644),
	(649, 1, 648),
	(651, 1, 650),
	(667, 1, 668),
	(670, 1, 671),
	(674, 1, 673),
	(675, 1, 676),
	(690, 1, 689),
	(696, 1, 695),
	(714, 1, 713),
	(716, 1, 715),
	(719, 1, 718),
	(720, 1, 721),
	(723, 1, 724),
	(726, 1, 725),
	(729, 2, 727),
	(739, 1, 740),
	(745, 1, 747),
	(751, 1, 750),
	(755, 1, 754);
/*!40000 ALTER TABLE `cold` ENABLE KEYS */;

-- Dumping structure for table emcor.cold_data
CREATE TABLE IF NOT EXISTS `cold_data` (
  `col_id` mediumint(8) unsigned NOT NULL COMMENT 'Lauko identifikatorius',
  `col_val` bigint(20) NOT NULL COMMENT 'Lauko reikšmė',
  `nr` smallint(5) unsigned NOT NULL COMMENT 'Numeris',
  `desc_col_id` mediumint(8) unsigned NOT NULL COMMENT 'Apibūdinančio tekstinio lauko identifikatorius',
  `desc_ae_id` int(10) unsigned NOT NULL COMMENT 'Apibūdinančio tekstinio elemento identifikatorius',
  PRIMARY KEY (`col_id`,`col_val`,`nr`),
  KEY `cold_data_desc_i` (`desc_col_id`,`desc_ae_id`),
  KEY `cold_data_desc_ae_fk` (`desc_ae_id`),
  CONSTRAINT `cold_data_desc_ae_fk` FOREIGN KEY (`desc_ae_id`) REFERENCES `ae` (`ae_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Lentelių identifikatorius apibūdinantys tekstiniai elementai';

-- Dumping data for table emcor.cold_data: ~3 461 rows (approximately)
/*!40000 ALTER TABLE `cold_data` DISABLE KEYS */;
INSERT INTO `cold_data` (`col_id`, `col_val`, `nr`, `desc_col_id`, `desc_ae_id`) VALUES
	(6, -7, 1, 7, 297),
	(6, -6, 1, 7, 298),
	(6, -5, 1, 7, 299),
	(6, -4, 1, 7, 300),
	(6, -3, 1, 7, 301),
	(6, -2, 1, 7, 302),
	(6, -1, 1, 7, 303),
	(25, 1, 1, 24, 304),
	(25, 5, 1, 24, 305),
	(25, 26, 1, 24, 306),
	(25, 38, 1, 24, 307),
	(25, 46, 1, 24, 308),
	(25, 56, 1, 24, 309),
	(25, 57, 1, 24, 310),
	(25, 62, 1, 24, 311),
	(25, 67, 1, 24, 312),
	(25, 72, 1, 24, 313),
	(25, 77, 1, 24, 314),
	(25, 78, 1, 24, 315),
	(25, 82, 1, 24, 316),
	(25, 87, 1, 24, 317),
	(25, 92, 1, 24, 318),
	(28, 752, 1, 29, 19),
	(28, 397, 1, 29, 23),
	(28, 398, 1, 29, 33),
	(28, 669, 1, 29, 53),
	(28, 757, 1, 29, 140),
	(28, 680, 1, 29, 147),
	(28, 64, 1, 29, 319),
	(28, 65, 1, 29, 320),
	(28, 66, 1, 29, 321),
	(28, 71, 1, 29, 322),
	(28, 92, 1, 29, 323),
	(28, 183, 1, 29, 324),
	(28, 221, 1, 29, 325),
	(28, 202, 1, 29, 326),
	(28, 203, 1, 29, 327),
	(28, 204, 1, 29, 328),
	(28, 205, 1, 29, 329),
	(28, 216, 1, 29, 330),
	(28, 86, 1, 29, 331),
	(28, 87, 1, 29, 332),
	(28, 96, 1, 29, 333),
	(28, 106, 1, 29, 334),
	(28, 107, 1, 29, 335),
	(28, 121, 1, 29, 336),
	(28, 122, 1, 29, 337),
	(28, 126, 1, 29, 338),
	(28, 127, 1, 29, 339),
	(28, 128, 1, 29, 340),
	(28, 129, 1, 29, 341),
	(28, 130, 1, 29, 342),
	(28, 140, 1, 29, 343),
	(28, 186, 1, 29, 344),
	(28, 187, 1, 29, 345),
	(28, 188, 1, 29, 346),
	(28, 206, 1, 29, 347),
	(28, 207, 1, 29, 348),
	(28, 211, 1, 29, 349),
	(28, 241, 1, 29, 350),
	(28, 242, 1, 29, 351),
	(28, 243, 1, 29, 352),
	(28, 244, 1, 29, 353),
	(28, 245, 1, 29, 354),
	(28, 246, 1, 29, 355),
	(28, 116, 1, 29, 356),
	(28, 117, 1, 29, 357),
	(28, 49, 1, 29, 358),
	(28, 21, 1, 29, 359),
	(28, 22, 1, 29, 360),
	(28, 23, 1, 29, 361),
	(28, 24, 1, 29, 362),
	(28, 25, 1, 29, 363),
	(28, 26, 1, 29, 364),
	(28, 27, 1, 29, 365),
	(28, 28, 1, 29, 366),
	(28, 29, 1, 29, 367),
	(28, 30, 1, 29, 368),
	(28, 32, 1, 29, 369),
	(28, 33, 1, 29, 370),
	(28, 34, 1, 29, 371),
	(28, 35, 1, 29, 372),
	(28, 36, 1, 29, 373),
	(28, 37, 1, 29, 374),
	(28, 38, 1, 29, 375),
	(28, 39, 1, 29, 376),
	(28, 40, 1, 29, 377),
	(28, 41, 1, 29, 378),
	(28, 42, 1, 29, 379),
	(28, 43, 1, 29, 380),
	(28, 44, 1, 29, 381),
	(28, 45, 1, 29, 382),
	(28, 46, 1, 29, 383),
	(28, 47, 1, 29, 384),
	(28, 48, 1, 29, 385),
	(28, 118, 1, 29, 386),
	(28, 277, 1, 29, 387),
	(28, 61, 1, 29, 388),
	(28, 62, 1, 29, 389),
	(28, 63, 1, 29, 390),
	(28, 156, 1, 29, 391),
	(28, 157, 1, 29, 392),
	(28, 181, 1, 29, 393),
	(28, 182, 1, 29, 394),
	(28, 91, 1, 29, 395),
	(28, 278, 1, 29, 396),
	(28, 111, 1, 29, 397),
	(28, 112, 1, 29, 398),
	(28, 110, 1, 29, 399),
	(28, 113, 1, 29, 400),
	(28, 131, 1, 29, 401),
	(28, 132, 1, 29, 402),
	(28, 139, 1, 29, 403),
	(28, 141, 1, 29, 404),
	(28, 142, 1, 29, 405),
	(28, 143, 1, 29, 406),
	(28, 144, 1, 29, 407),
	(28, 145, 1, 29, 408),
	(28, 146, 1, 29, 409),
	(28, 147, 1, 29, 410),
	(28, 148, 1, 29, 411),
	(28, 149, 1, 29, 412),
	(28, 150, 1, 29, 413),
	(28, 151, 1, 29, 414),
	(28, 162, 1, 29, 415),
	(28, 163, 1, 29, 416),
	(28, 164, 1, 29, 417),
	(28, 165, 1, 29, 418),
	(28, 166, 1, 29, 419),
	(28, 167, 1, 29, 420),
	(28, 168, 1, 29, 421),
	(28, 170, 1, 29, 422),
	(28, 171, 1, 29, 423),
	(28, 172, 1, 29, 424),
	(28, 173, 1, 29, 425),
	(28, 174, 1, 29, 426),
	(28, 175, 1, 29, 427),
	(28, 176, 1, 29, 428),
	(28, 279, 1, 29, 429),
	(28, 136, 1, 29, 430),
	(28, 137, 1, 29, 431),
	(28, 138, 1, 29, 432),
	(28, 226, 1, 29, 433),
	(28, 227, 1, 29, 434),
	(28, 228, 1, 29, 435),
	(28, 276, 1, 29, 436),
	(28, 280, 1, 29, 437),
	(28, 281, 1, 29, 438),
	(28, 282, 1, 29, 439),
	(28, 283, 1, 29, 440),
	(28, 284, 1, 29, 441),
	(28, 285, 1, 29, 442),
	(28, 260, 1, 29, 443),
	(28, 261, 1, 29, 444),
	(28, 262, 1, 29, 445),
	(28, 263, 1, 29, 446),
	(28, 264, 1, 29, 447),
	(28, 265, 1, 29, 448),
	(28, 266, 1, 29, 449),
	(28, 267, 1, 29, 450),
	(28, 268, 1, 29, 451),
	(28, 269, 1, 29, 452),
	(28, 270, 1, 29, 453),
	(28, 271, 1, 29, 454),
	(28, 272, 1, 29, 455),
	(28, 273, 1, 29, 456),
	(28, 274, 1, 29, 457),
	(28, 275, 1, 29, 458),
	(28, 256, 1, 29, 459),
	(28, 257, 1, 29, 460),
	(28, 258, 1, 29, 461),
	(28, 259, 1, 29, 462),
	(28, 251, 1, 29, 463),
	(28, 252, 1, 29, 464),
	(28, 253, 1, 29, 465),
	(28, 301, 1, 29, 466),
	(28, 302, 1, 29, 467),
	(28, 303, 1, 29, 468),
	(28, 335, 1, 29, 469),
	(28, 336, 1, 29, 470),
	(28, 337, 1, 29, 471),
	(28, 338, 1, 29, 472),
	(28, 339, 1, 29, 473),
	(28, 340, 1, 29, 474),
	(28, 341, 1, 29, 475),
	(28, 342, 1, 29, 476),
	(28, 343, 1, 29, 477),
	(28, 344, 1, 29, 478),
	(28, 345, 1, 29, 479),
	(28, 346, 1, 29, 480),
	(28, 347, 1, 29, 481),
	(28, 361, 1, 29, 482),
	(28, 362, 1, 29, 483),
	(28, 363, 1, 29, 484),
	(28, 364, 1, 29, 485),
	(28, 365, 1, 29, 486),
	(28, 366, 1, 29, 487),
	(28, 367, 1, 29, 488),
	(28, 368, 1, 29, 489),
	(28, 369, 1, 29, 490),
	(28, 370, 1, 29, 491),
	(28, 371, 1, 29, 492),
	(28, 372, 1, 29, 493),
	(28, 373, 1, 29, 494),
	(28, 374, 1, 29, 495),
	(28, 375, 1, 29, 496),
	(28, 376, 1, 29, 497),
	(28, 377, 1, 29, 498),
	(28, 378, 1, 29, 499),
	(28, 379, 1, 29, 500),
	(28, 380, 1, 29, 501),
	(28, 381, 1, 29, 502),
	(28, 382, 1, 29, 503),
	(28, 383, 1, 29, 504),
	(28, 384, 1, 29, 505),
	(28, 385, 1, 29, 506),
	(28, 386, 1, 29, 507),
	(28, 387, 1, 29, 508),
	(28, 388, 1, 29, 509),
	(28, 389, 1, 29, 510),
	(28, 390, 1, 29, 511),
	(28, 391, 1, 29, 512),
	(28, 392, 1, 29, 513),
	(28, 393, 1, 29, 514),
	(28, 394, 1, 29, 515),
	(28, 395, 1, 29, 516),
	(28, 396, 1, 29, 517),
	(28, 404, 1, 29, 518),
	(28, 405, 1, 29, 519),
	(28, 406, 1, 29, 520),
	(28, 407, 1, 29, 521),
	(28, 503, 1, 29, 522),
	(28, 504, 1, 29, 523),
	(28, 505, 1, 29, 524),
	(28, 506, 1, 29, 525),
	(28, 507, 1, 29, 526),
	(28, 508, 1, 29, 527),
	(28, 509, 1, 29, 528),
	(28, 296, 1, 29, 529),
	(28, 297, 1, 29, 530),
	(28, 298, 1, 29, 531),
	(28, 299, 1, 29, 532),
	(28, 306, 1, 29, 533),
	(28, 511, 1, 29, 534),
	(28, 311, 1, 29, 535),
	(28, 312, 1, 29, 536),
	(28, 316, 1, 29, 537),
	(28, 317, 1, 29, 538),
	(28, 318, 1, 29, 539),
	(28, 319, 1, 29, 540),
	(28, 320, 1, 29, 541),
	(28, 321, 1, 29, 542),
	(28, 322, 1, 29, 543),
	(28, 323, 1, 29, 544),
	(28, 324, 1, 29, 545),
	(28, 325, 1, 29, 546),
	(28, 326, 1, 29, 547),
	(28, 327, 1, 29, 548),
	(28, 328, 1, 29, 549),
	(28, 329, 1, 29, 550),
	(28, 330, 1, 29, 551),
	(28, 331, 1, 29, 552),
	(28, 332, 1, 29, 553),
	(28, 333, 1, 29, 554),
	(28, 334, 1, 29, 555),
	(28, 351, 1, 29, 556),
	(28, 352, 1, 29, 557),
	(28, 353, 1, 29, 558),
	(28, 354, 1, 29, 559),
	(28, 355, 1, 29, 560),
	(28, 356, 1, 29, 561),
	(28, 357, 1, 29, 562),
	(28, 358, 1, 29, 563),
	(28, 401, 1, 29, 564),
	(28, 402, 1, 29, 565),
	(28, 403, 1, 29, 566),
	(28, 408, 1, 29, 567),
	(28, 409, 1, 29, 568),
	(28, 410, 1, 29, 569),
	(28, 411, 1, 29, 570),
	(28, 412, 1, 29, 571),
	(28, 413, 1, 29, 572),
	(28, 414, 1, 29, 573),
	(28, 415, 1, 29, 574),
	(28, 416, 1, 29, 575),
	(28, 417, 1, 29, 576),
	(28, 418, 1, 29, 577),
	(28, 419, 1, 29, 578),
	(28, 420, 1, 29, 579),
	(28, 421, 1, 29, 580),
	(28, 422, 1, 29, 581),
	(28, 423, 1, 29, 582),
	(28, 424, 1, 29, 583),
	(28, 425, 1, 29, 584),
	(28, 426, 1, 29, 585),
	(28, 427, 1, 29, 586),
	(28, 428, 1, 29, 587),
	(28, 510, 1, 29, 588),
	(28, 512, 1, 29, 589),
	(28, 513, 1, 29, 590),
	(28, 514, 1, 29, 591),
	(28, 515, 1, 29, 592),
	(28, 291, 1, 29, 593),
	(28, 433, 1, 29, 594),
	(28, 434, 1, 29, 595),
	(28, 435, 1, 29, 596),
	(28, 436, 1, 29, 597),
	(28, 437, 1, 29, 598),
	(28, 438, 1, 29, 599),
	(28, 439, 1, 29, 600),
	(28, 440, 1, 29, 601),
	(28, 441, 1, 29, 602),
	(28, 442, 1, 29, 603),
	(28, 443, 1, 29, 604),
	(28, 444, 1, 29, 605),
	(28, 445, 1, 29, 606),
	(28, 446, 1, 29, 607),
	(28, 447, 1, 29, 608),
	(28, 448, 1, 29, 609),
	(28, 449, 1, 29, 610),
	(28, 450, 1, 29, 611),
	(28, 451, 1, 29, 612),
	(28, 452, 1, 29, 613),
	(28, 453, 1, 29, 614),
	(28, 454, 1, 29, 615),
	(28, 455, 1, 29, 616),
	(28, 456, 1, 29, 617),
	(28, 457, 1, 29, 618),
	(28, 458, 1, 29, 619),
	(28, 459, 1, 29, 620),
	(28, 460, 1, 29, 621),
	(28, 461, 1, 29, 622),
	(28, 462, 1, 29, 623),
	(28, 463, 1, 29, 624),
	(28, 464, 1, 29, 625),
	(28, 465, 1, 29, 626),
	(28, 466, 1, 29, 627),
	(28, 467, 1, 29, 628),
	(28, 468, 1, 29, 629),
	(28, 469, 1, 29, 630),
	(28, 470, 1, 29, 631),
	(28, 471, 1, 29, 632),
	(28, 472, 1, 29, 633),
	(28, 473, 1, 29, 634),
	(28, 474, 1, 29, 635),
	(28, 475, 1, 29, 636),
	(28, 476, 1, 29, 637),
	(28, 477, 1, 29, 638),
	(28, 478, 1, 29, 639),
	(28, 479, 1, 29, 640),
	(28, 480, 1, 29, 641),
	(28, 481, 1, 29, 642),
	(28, 482, 1, 29, 643),
	(28, 483, 1, 29, 644),
	(28, 484, 1, 29, 645),
	(28, 485, 1, 29, 646),
	(28, 486, 1, 29, 647),
	(28, 487, 1, 29, 648),
	(28, 488, 1, 29, 649),
	(28, 489, 1, 29, 650),
	(28, 490, 1, 29, 651),
	(28, 491, 1, 29, 652),
	(28, 492, 1, 29, 653),
	(28, 493, 1, 29, 654),
	(28, 494, 1, 29, 655),
	(28, 495, 1, 29, 656),
	(28, 496, 1, 29, 657),
	(28, 497, 1, 29, 658),
	(28, 498, 1, 29, 659),
	(28, 499, 1, 29, 660),
	(28, 500, 1, 29, 661),
	(28, 501, 1, 29, 662),
	(28, 502, 1, 29, 663),
	(28, 576, 1, 29, 664),
	(28, 577, 1, 29, 665),
	(28, 578, 1, 29, 666),
	(28, 579, 1, 29, 667),
	(28, 580, 1, 29, 668),
	(28, 581, 1, 29, 669),
	(28, 582, 1, 29, 670),
	(28, 583, 1, 29, 671),
	(28, 584, 1, 29, 672),
	(28, 585, 1, 29, 673),
	(28, 586, 1, 29, 674),
	(28, 587, 1, 29, 675),
	(28, 588, 1, 29, 676),
	(28, 589, 1, 29, 677),
	(28, 590, 1, 29, 678),
	(28, 591, 1, 29, 679),
	(28, 592, 1, 29, 680),
	(28, 593, 1, 29, 681),
	(28, 594, 1, 29, 682),
	(28, 595, 1, 29, 683),
	(28, 596, 1, 29, 684),
	(28, 597, 1, 29, 685),
	(28, 598, 1, 29, 686),
	(28, 599, 1, 29, 687),
	(28, 600, 1, 29, 688),
	(28, 601, 1, 29, 689),
	(28, 602, 1, 29, 690),
	(28, 603, 1, 29, 691),
	(28, 604, 1, 29, 692),
	(28, 605, 1, 29, 693),
	(28, 606, 1, 29, 694),
	(28, 607, 1, 29, 695),
	(28, 608, 1, 29, 696),
	(28, 609, 1, 29, 697),
	(28, 610, 1, 29, 698),
	(28, 611, 1, 29, 699),
	(28, 612, 1, 29, 700),
	(28, 613, 1, 29, 701),
	(28, 614, 1, 29, 702),
	(28, 615, 1, 29, 703),
	(28, 616, 1, 29, 704),
	(28, 617, 1, 29, 705),
	(28, 618, 1, 29, 706),
	(28, 619, 1, 29, 707),
	(28, 620, 1, 29, 708),
	(28, 621, 1, 29, 709),
	(28, 622, 1, 29, 710),
	(28, 623, 1, 29, 711),
	(28, 624, 1, 29, 712),
	(28, 625, 1, 29, 713),
	(28, 626, 1, 29, 714),
	(28, 627, 1, 29, 715),
	(28, 628, 1, 29, 716),
	(28, 629, 1, 29, 717),
	(28, 630, 1, 29, 718),
	(28, 631, 1, 29, 719),
	(28, 632, 1, 29, 720),
	(28, 648, 1, 29, 721),
	(28, 649, 1, 29, 722),
	(28, 650, 1, 29, 723),
	(28, 651, 1, 29, 724),
	(28, 652, 1, 29, 725),
	(28, 653, 1, 29, 726),
	(28, 654, 1, 29, 727),
	(28, 655, 1, 29, 728),
	(28, 656, 1, 29, 729),
	(28, 657, 1, 29, 730),
	(28, 658, 1, 29, 731),
	(28, 659, 1, 29, 732),
	(28, 663, 1, 29, 733),
	(28, 707, 1, 29, 734),
	(28, 708, 1, 29, 735),
	(28, 709, 1, 29, 736),
	(28, 710, 1, 29, 737),
	(28, 711, 1, 29, 738),
	(28, 712, 1, 29, 739),
	(28, 713, 1, 29, 740),
	(28, 714, 1, 29, 741),
	(28, 715, 1, 29, 742),
	(28, 716, 1, 29, 743),
	(28, 717, 1, 29, 744),
	(28, 718, 1, 29, 745),
	(28, 738, 1, 29, 746),
	(28, 739, 1, 29, 747),
	(28, 747, 1, 29, 748),
	(28, 643, 1, 29, 749),
	(28, 644, 1, 29, 750),
	(28, 645, 1, 29, 751),
	(28, 664, 1, 29, 752),
	(28, 665, 1, 29, 753),
	(28, 667, 1, 29, 754),
	(28, 668, 1, 29, 755),
	(28, 670, 1, 29, 756),
	(28, 671, 1, 29, 757),
	(28, 728, 1, 29, 758),
	(28, 729, 1, 29, 759),
	(28, 730, 1, 29, 760),
	(28, 731, 1, 29, 761),
	(28, 732, 1, 29, 762),
	(28, 633, 1, 29, 763),
	(28, 634, 1, 29, 764),
	(28, 635, 1, 29, 765),
	(28, 636, 1, 29, 766),
	(28, 637, 1, 29, 767),
	(28, 638, 1, 29, 768),
	(28, 639, 1, 29, 769),
	(28, 640, 1, 29, 770),
	(28, 641, 1, 29, 771),
	(28, 723, 1, 29, 772),
	(28, 724, 1, 29, 773),
	(28, 725, 1, 29, 774),
	(28, 726, 1, 29, 775),
	(28, 660, 1, 29, 776),
	(28, 661, 1, 29, 777),
	(28, 673, 1, 29, 778),
	(28, 674, 1, 29, 779),
	(28, 675, 1, 29, 780),
	(28, 676, 1, 29, 781),
	(28, 677, 1, 29, 782),
	(28, 678, 1, 29, 783),
	(28, 679, 1, 29, 784),
	(28, 681, 1, 29, 785),
	(28, 702, 1, 29, 786),
	(28, 703, 1, 29, 787),
	(28, 704, 1, 29, 788),
	(28, 705, 1, 29, 789),
	(28, 706, 1, 29, 790),
	(28, 733, 1, 29, 791),
	(28, 743, 1, 29, 792),
	(28, 744, 1, 29, 793),
	(28, 745, 1, 29, 794),
	(28, 746, 1, 29, 795),
	(28, 666, 1, 29, 796),
	(28, 748, 1, 29, 797),
	(28, 749, 1, 29, 798),
	(28, 750, 1, 29, 799),
	(28, 682, 1, 29, 800),
	(28, 683, 1, 29, 801),
	(28, 684, 1, 29, 802),
	(28, 685, 1, 29, 803),
	(28, 686, 1, 29, 804),
	(28, 687, 1, 29, 805),
	(28, 688, 1, 29, 806),
	(28, 689, 1, 29, 807),
	(28, 690, 1, 29, 808),
	(28, 691, 1, 29, 809),
	(28, 692, 1, 29, 810),
	(28, 693, 1, 29, 811),
	(28, 694, 1, 29, 812),
	(28, 695, 1, 29, 813),
	(28, 696, 1, 29, 814),
	(28, 697, 1, 29, 815),
	(28, 698, 1, 29, 816),
	(28, 699, 1, 29, 817),
	(28, 700, 1, 29, 818),
	(28, 701, 1, 29, 819),
	(28, 751, 1, 29, 820),
	(28, 516, 1, 29, 821),
	(28, 517, 1, 29, 822),
	(28, 518, 1, 29, 823),
	(28, 519, 1, 29, 824),
	(28, 520, 1, 29, 825),
	(28, 521, 1, 29, 826),
	(28, 522, 1, 29, 827),
	(28, 523, 1, 29, 828),
	(28, 524, 1, 29, 829),
	(28, 525, 1, 29, 830),
	(28, 526, 1, 29, 831),
	(28, 527, 1, 29, 832),
	(28, 528, 1, 29, 833),
	(28, 529, 1, 29, 834),
	(28, 530, 1, 29, 835),
	(28, 531, 1, 29, 836),
	(28, 532, 1, 29, 837),
	(28, 533, 1, 29, 838),
	(28, 534, 1, 29, 839),
	(28, 535, 1, 29, 840),
	(28, 536, 1, 29, 841),
	(28, 537, 1, 29, 842),
	(28, 538, 1, 29, 843),
	(28, 539, 1, 29, 844),
	(28, 540, 1, 29, 845),
	(28, 541, 1, 29, 846),
	(28, 542, 1, 29, 847),
	(28, 543, 1, 29, 848),
	(28, 544, 1, 29, 849),
	(28, 545, 1, 29, 850),
	(28, 546, 1, 29, 851),
	(28, 547, 1, 29, 852),
	(28, 548, 1, 29, 853),
	(28, 549, 1, 29, 854),
	(28, 550, 1, 29, 855),
	(28, 551, 1, 29, 856),
	(28, 552, 1, 29, 857),
	(28, 553, 1, 29, 858),
	(28, 554, 1, 29, 859),
	(28, 555, 1, 29, 860),
	(28, 556, 1, 29, 861),
	(28, 557, 1, 29, 862),
	(28, 558, 1, 29, 863),
	(28, 559, 1, 29, 864),
	(28, 560, 1, 29, 865),
	(28, 561, 1, 29, 866),
	(28, 562, 1, 29, 867),
	(28, 563, 1, 29, 868),
	(28, 564, 1, 29, 869),
	(28, 565, 1, 29, 870),
	(28, 566, 1, 29, 871),
	(28, 567, 1, 29, 872),
	(28, 568, 1, 29, 873),
	(28, 569, 1, 29, 874),
	(28, 570, 1, 29, 875),
	(28, 571, 1, 29, 876),
	(28, 572, 1, 29, 877),
	(28, 573, 1, 29, 878),
	(28, 574, 1, 29, 879),
	(28, 575, 1, 29, 880),
	(28, 758, 1, 29, 2978),
	(28, 762, 1, 29, 3210),
	(28, 763, 1, 29, 3286),
	(41, 127, 1, 38, 1),
	(41, 215, 1, 38, 4),
	(41, 377, 1, 38, 9),
	(41, 126, 1, 38, 20),
	(41, 336, 1, 38, 28),
	(41, 315, 1, 38, 29),
	(41, 245, 1, 38, 87),
	(41, 111, 1, 38, 91),
	(41, 221, 1, 38, 93),
	(41, 220, 1, 38, 100),
	(41, 312, 1, 38, 106),
	(41, 219, 1, 38, 109),
	(41, 251, 1, 38, 112),
	(41, 244, 1, 38, 115),
	(41, 372, 1, 38, 120),
	(41, 216, 1, 38, 121),
	(41, 360, 1, 38, 134),
	(41, 283, 1, 38, 145),
	(41, 308, 1, 38, 158),
	(41, 316, 1, 38, 169),
	(41, 217, 1, 38, 170),
	(41, 317, 1, 38, 192),
	(41, 297, 1, 38, 193),
	(41, 218, 1, 38, 195),
	(41, 306, 1, 38, 881),
	(41, 121, 1, 38, 882),
	(41, 136, 1, 38, 883),
	(41, 321, 1, 38, 884),
	(41, 86, 1, 38, 885),
	(41, 352, 1, 38, 886),
	(41, 184, 1, 38, 887),
	(41, 210, 1, 38, 888),
	(41, 28, 1, 38, 889),
	(41, 340, 1, 38, 890),
	(41, 172, 1, 38, 891),
	(41, 311, 1, 38, 892),
	(41, 302, 1, 38, 893),
	(41, 25, 1, 38, 894),
	(41, 31, 1, 38, 895),
	(41, 329, 1, 38, 896),
	(41, 234, 1, 38, 897),
	(41, 357, 1, 38, 898),
	(41, 249, 1, 38, 899),
	(41, 358, 1, 38, 900),
	(41, 266, 1, 38, 901),
	(41, 345, 1, 38, 902),
	(41, 337, 1, 38, 903),
	(41, 191, 1, 38, 904),
	(41, 119, 1, 38, 905),
	(41, 277, 1, 38, 906),
	(41, 365, 1, 38, 907),
	(41, 304, 1, 38, 908),
	(41, 231, 1, 38, 909),
	(41, 299, 1, 38, 910),
	(41, 346, 1, 38, 911),
	(41, 270, 1, 38, 912),
	(41, 183, 1, 38, 913),
	(41, 256, 1, 38, 914),
	(41, 211, 1, 38, 915),
	(41, 371, 1, 38, 916),
	(41, 322, 1, 38, 917),
	(41, 137, 1, 38, 918),
	(41, 268, 1, 38, 919),
	(41, 27, 1, 38, 920),
	(41, 367, 1, 38, 921),
	(41, 61, 1, 38, 922),
	(41, 368, 1, 38, 923),
	(41, 101, 1, 38, 924),
	(41, 288, 1, 38, 925),
	(41, 21, 1, 38, 926),
	(41, 228, 1, 38, 927),
	(41, 305, 1, 38, 928),
	(41, 23, 1, 38, 929),
	(41, 303, 1, 38, 930),
	(41, 188, 1, 38, 931),
	(41, 116, 1, 38, 932),
	(41, 115, 1, 38, 933),
	(41, 333, 1, 38, 934),
	(41, 255, 1, 38, 935),
	(41, 222, 1, 38, 936),
	(41, 369, 1, 38, 937),
	(41, 182, 1, 38, 938),
	(41, 156, 1, 38, 939),
	(41, 287, 1, 38, 940),
	(41, 194, 1, 38, 941),
	(41, 120, 1, 38, 942),
	(41, 338, 1, 38, 943),
	(41, 271, 1, 38, 944),
	(41, 298, 1, 38, 945),
	(41, 187, 1, 38, 946),
	(41, 117, 1, 38, 947),
	(41, 224, 1, 38, 948),
	(41, 22, 1, 38, 949),
	(41, 310, 1, 38, 950),
	(41, 267, 1, 38, 951),
	(41, 131, 1, 38, 952),
	(41, 190, 1, 38, 953),
	(41, 230, 1, 38, 954),
	(41, 326, 1, 38, 955),
	(41, 252, 1, 38, 956),
	(41, 166, 1, 38, 957),
	(41, 232, 1, 38, 958),
	(41, 151, 1, 38, 959),
	(41, 339, 1, 38, 960),
	(41, 204, 1, 38, 961),
	(41, 332, 1, 38, 962),
	(41, 313, 1, 38, 963),
	(41, 209, 1, 38, 964),
	(41, 296, 1, 38, 965),
	(41, 328, 1, 38, 966),
	(41, 239, 1, 38, 967),
	(41, 185, 1, 38, 968),
	(41, 370, 1, 38, 969),
	(41, 265, 1, 38, 970),
	(41, 309, 1, 38, 971),
	(41, 359, 1, 38, 972),
	(41, 319, 1, 38, 973),
	(41, 62, 1, 38, 974),
	(41, 327, 1, 38, 975),
	(41, 250, 1, 38, 976),
	(41, 343, 1, 38, 977),
	(41, 364, 1, 38, 978),
	(41, 318, 1, 38, 979),
	(41, 269, 1, 38, 980),
	(41, 253, 1, 38, 981),
	(41, 348, 1, 38, 982),
	(41, 226, 1, 38, 983),
	(41, 323, 1, 38, 984),
	(41, 341, 1, 38, 985),
	(41, 261, 1, 38, 986),
	(41, 331, 1, 38, 987),
	(41, 314, 1, 38, 988),
	(41, 291, 1, 38, 989),
	(41, 214, 1, 38, 990),
	(41, 290, 1, 38, 991),
	(41, 286, 1, 38, 992),
	(41, 351, 1, 38, 993),
	(41, 181, 1, 38, 994),
	(41, 361, 1, 38, 995),
	(41, 263, 1, 38, 996),
	(41, 281, 1, 38, 997),
	(41, 307, 1, 38, 998),
	(41, 325, 1, 38, 999),
	(41, 173, 1, 38, 1000),
	(41, 229, 1, 38, 1001),
	(41, 114, 1, 38, 1002),
	(41, 29, 1, 38, 1003),
	(41, 342, 1, 38, 1004),
	(41, 278, 1, 38, 1005),
	(41, 276, 1, 38, 1006),
	(41, 344, 1, 38, 1007),
	(41, 112, 1, 38, 1008),
	(41, 189, 1, 38, 1009),
	(41, 26, 1, 38, 1010),
	(41, 366, 1, 38, 1011),
	(41, 30, 1, 38, 1012),
	(41, 161, 1, 38, 1013),
	(41, 186, 1, 38, 1014),
	(41, 46, 1, 38, 1015),
	(41, 362, 1, 38, 1016),
	(41, 106, 1, 38, 1017),
	(41, 324, 1, 38, 1018),
	(41, 227, 1, 38, 1019),
	(41, 356, 1, 38, 1020),
	(41, 347, 1, 38, 1021),
	(41, 225, 1, 38, 1022),
	(41, 301, 1, 38, 1023),
	(41, 363, 1, 38, 1024),
	(41, 118, 1, 38, 1025),
	(41, 330, 1, 38, 1026),
	(41, 132, 1, 38, 1027),
	(41, 96, 1, 38, 1028),
	(41, 113, 1, 38, 1029),
	(41, 171, 1, 38, 1030),
	(41, 262, 1, 38, 1031),
	(41, 264, 1, 38, 1032),
	(41, 257, 1, 38, 1033),
	(41, 223, 1, 38, 1034),
	(41, 254, 1, 38, 1035),
	(41, 282, 1, 38, 1036),
	(41, 199, 1, 38, 1037),
	(41, 289, 1, 38, 1038),
	(41, 320, 1, 38, 1039),
	(41, 81, 1, 38, 1040),
	(41, 378, 1, 38, 2977),
	(41, 382, 1, 38, 3209),
	(41, 383, 1, 38, 3228),
	(41, 384, 1, 38, 3259),
	(41, 385, 1, 38, 3285),
	(62, 355, 1, 61, 167),
	(62, 154, 1, 61, 1041),
	(62, 191, 1, 61, 1042),
	(62, 183, 1, 61, 1043),
	(62, 192, 1, 61, 1044),
	(62, 176, 1, 61, 1045),
	(62, 155, 1, 61, 1046),
	(62, 163, 1, 61, 1047),
	(62, 166, 1, 61, 1048),
	(62, 168, 1, 61, 1049),
	(62, 169, 1, 61, 1050),
	(62, 173, 1, 61, 1051),
	(62, 181, 1, 61, 1052),
	(62, 126, 1, 61, 1053),
	(62, 127, 1, 61, 1054),
	(62, 128, 1, 61, 1055),
	(62, 131, 1, 61, 1056),
	(62, 133, 1, 61, 1057),
	(62, 141, 1, 61, 1058),
	(62, 142, 1, 61, 1059),
	(62, 143, 1, 61, 1060),
	(62, 147, 1, 61, 1061),
	(62, 148, 1, 61, 1062),
	(62, 150, 1, 61, 1063),
	(62, 134, 1, 61, 1064),
	(62, 106, 1, 61, 1065),
	(62, 113, 1, 61, 1066),
	(62, 115, 1, 61, 1067),
	(62, 2, 1, 61, 1068),
	(62, 4, 1, 61, 1069),
	(62, 5, 1, 61, 1070),
	(62, 10, 1, 61, 1071),
	(62, 12, 1, 61, 1072),
	(62, 22, 1, 61, 1073),
	(62, 18, 1, 61, 1074),
	(62, 23, 1, 61, 1075),
	(62, 24, 1, 61, 1076),
	(62, 27, 1, 61, 1077),
	(62, 28, 1, 61, 1078),
	(62, 32, 1, 61, 1079),
	(62, 39, 1, 61, 1080),
	(62, 40, 1, 61, 1081),
	(62, 41, 1, 61, 1082),
	(62, 45, 1, 61, 1083),
	(62, 47, 1, 61, 1084),
	(62, 49, 1, 61, 1085),
	(62, 54, 1, 61, 1086),
	(62, 56, 1, 61, 1087),
	(62, 57, 1, 61, 1088),
	(62, 64, 1, 61, 1089),
	(62, 66, 1, 61, 1090),
	(62, 68, 1, 61, 1091),
	(62, 70, 1, 61, 1092),
	(62, 74, 1, 61, 1093),
	(62, 75, 1, 61, 1094),
	(62, 78, 1, 61, 1095),
	(62, 81, 1, 61, 1096),
	(62, 83, 1, 61, 1097),
	(62, 84, 1, 61, 1098),
	(62, 86, 1, 61, 1099),
	(62, 87, 1, 61, 1100),
	(62, 90, 1, 61, 1101),
	(62, 91, 1, 61, 1102),
	(62, 98, 1, 61, 1103),
	(62, 100, 1, 61, 1104),
	(62, 118, 1, 61, 1105),
	(62, 107, 1, 61, 1106),
	(62, 108, 1, 61, 1107),
	(62, 109, 1, 61, 1108),
	(62, 120, 1, 61, 1109),
	(62, 121, 1, 61, 1110),
	(62, 135, 1, 61, 1111),
	(62, 136, 1, 61, 1112),
	(62, 137, 1, 61, 1113),
	(62, 138, 1, 61, 1114),
	(62, 122, 1, 61, 1115),
	(62, 152, 1, 61, 1116),
	(62, 123, 1, 61, 1117),
	(62, 125, 1, 61, 1118),
	(62, 151, 1, 61, 1119),
	(62, 159, 1, 61, 1120),
	(62, 160, 1, 61, 1121),
	(62, 161, 1, 61, 1122),
	(62, 180, 1, 61, 1123),
	(62, 158, 1, 61, 1124),
	(62, 187, 1, 61, 1125),
	(62, 188, 1, 61, 1126),
	(62, 189, 1, 61, 1127),
	(62, 190, 1, 61, 1128),
	(62, 186, 1, 61, 1129),
	(62, 156, 1, 61, 1130),
	(62, 157, 1, 61, 1131),
	(62, 164, 1, 61, 1132),
	(62, 195, 1, 61, 1133),
	(62, 194, 1, 61, 1134),
	(62, 197, 1, 61, 1135),
	(62, 220, 1, 61, 1136),
	(62, 221, 1, 61, 1137),
	(62, 222, 1, 61, 1138),
	(62, 223, 1, 61, 1139),
	(62, 224, 1, 61, 1140),
	(62, 225, 1, 61, 1141),
	(62, 226, 1, 61, 1142),
	(62, 227, 1, 61, 1143),
	(62, 228, 1, 61, 1144),
	(62, 1001, 1, 61, 1145),
	(62, 1002, 1, 61, 1146),
	(62, 1003, 1, 61, 1147),
	(62, 1004, 1, 61, 1148),
	(62, 1005, 1, 61, 1149),
	(62, 1006, 1, 61, 1150),
	(62, 1007, 1, 61, 1151),
	(62, 1008, 1, 61, 1152),
	(62, 1009, 1, 61, 1153),
	(62, 198, 1, 61, 1154),
	(62, 200, 1, 61, 1155),
	(62, 201, 1, 61, 1156),
	(62, 11, 1, 61, 1157),
	(62, 13, 1, 61, 1158),
	(62, 17, 1, 61, 1159),
	(62, 26, 1, 61, 1160),
	(62, 37, 1, 61, 1161),
	(62, 46, 1, 61, 1162),
	(62, 51, 1, 61, 1163),
	(62, 59, 1, 61, 1164),
	(62, 63, 1, 61, 1165),
	(62, 82, 1, 61, 1166),
	(62, 95, 1, 61, 1167),
	(62, 96, 1, 61, 1168),
	(62, 101, 1, 61, 1169),
	(62, 165, 1, 61, 1170),
	(62, 172, 1, 61, 1171),
	(62, 124, 1, 61, 1172),
	(62, 132, 1, 61, 1173),
	(62, 140, 1, 61, 1174),
	(62, 144, 1, 61, 1175),
	(62, 146, 1, 61, 1176),
	(62, 149, 1, 61, 1177),
	(62, 119, 1, 61, 1178),
	(62, 114, 1, 61, 1179),
	(62, 117, 1, 61, 1180),
	(62, 21, 1, 61, 1181),
	(62, 30, 1, 61, 1182),
	(62, 53, 1, 61, 1183),
	(62, 80, 1, 61, 1184),
	(62, 85, 1, 61, 1185),
	(62, 93, 1, 61, 1186),
	(62, 89, 1, 61, 1187),
	(62, 1, 1, 61, 1188),
	(62, 9, 1, 61, 1189),
	(62, 15, 1, 61, 1190),
	(62, 20, 1, 61, 1191),
	(62, 25, 1, 61, 1192),
	(62, 33, 1, 61, 1193),
	(62, 43, 1, 61, 1194),
	(62, 67, 1, 61, 1195),
	(62, 92, 1, 61, 1196),
	(62, 94, 1, 61, 1197),
	(62, 177, 1, 61, 1198),
	(62, 182, 1, 61, 1199),
	(62, 185, 1, 61, 1200),
	(62, 175, 1, 61, 1201),
	(62, 196, 1, 61, 1202),
	(62, 167, 1, 61, 1203),
	(62, 171, 1, 61, 1204),
	(62, 174, 1, 61, 1205),
	(62, 145, 1, 61, 1206),
	(62, 110, 1, 61, 1207),
	(62, 3, 1, 61, 1208),
	(62, 6, 1, 61, 1209),
	(62, 19, 1, 61, 1210),
	(62, 31, 1, 61, 1211),
	(62, 34, 1, 61, 1212),
	(62, 42, 1, 61, 1213),
	(62, 48, 1, 61, 1214),
	(62, 52, 1, 61, 1215),
	(62, 58, 1, 61, 1216),
	(62, 62, 1, 61, 1217),
	(62, 69, 1, 61, 1218),
	(62, 73, 1, 61, 1219),
	(62, 88, 1, 61, 1220),
	(62, 97, 1, 61, 1221),
	(62, 112, 1, 61, 1222),
	(62, 71, 1, 61, 1223),
	(62, 7, 1, 61, 1224),
	(62, 36, 1, 61, 1225),
	(62, 61, 1, 61, 1226),
	(62, 139, 1, 61, 1227),
	(62, 76, 1, 61, 1228),
	(62, 8, 1, 61, 1229),
	(62, 16, 1, 61, 1230),
	(62, 29, 1, 61, 1231),
	(62, 35, 1, 61, 1232),
	(62, 38, 1, 61, 1233),
	(62, 44, 1, 61, 1234),
	(62, 50, 1, 61, 1235),
	(62, 202, 1, 61, 1236),
	(62, 203, 1, 61, 1237),
	(62, 55, 1, 61, 1238),
	(62, 60, 1, 61, 1239),
	(62, 65, 1, 61, 1240),
	(62, 72, 1, 61, 1241),
	(62, 77, 1, 61, 1242),
	(62, 79, 1, 61, 1243),
	(62, 99, 1, 61, 1244),
	(62, 111, 1, 61, 1245),
	(62, 116, 1, 61, 1246),
	(62, 129, 1, 61, 1247),
	(62, 130, 1, 61, 1248),
	(62, 153, 1, 61, 1249),
	(62, 162, 1, 61, 1250),
	(62, 170, 1, 61, 1251),
	(62, 178, 1, 61, 1252),
	(62, 179, 1, 61, 1253),
	(62, 184, 1, 61, 1254),
	(62, 193, 1, 61, 1255),
	(62, 199, 1, 61, 1256),
	(62, 204, 1, 61, 1257),
	(62, 205, 1, 61, 1258),
	(62, 206, 1, 61, 1259),
	(62, 207, 1, 61, 1260),
	(62, 208, 1, 61, 1261),
	(62, 209, 1, 61, 1262),
	(62, 210, 1, 61, 1263),
	(62, 211, 1, 61, 1264),
	(62, 212, 1, 61, 1265),
	(62, 213, 1, 61, 1266),
	(62, 219, 1, 61, 1267),
	(62, 1010, 1, 61, 1268),
	(62, 1011, 1, 61, 1269),
	(62, 1012, 1, 61, 1270),
	(62, 1013, 1, 61, 1271),
	(62, 1014, 1, 61, 1272),
	(62, 1015, 1, 61, 1273),
	(62, 1016, 1, 61, 1274),
	(62, 1017, 1, 61, 1275),
	(62, 1018, 1, 61, 1276),
	(62, 1019, 1, 61, 1277),
	(62, 1020, 1, 61, 1278),
	(62, 1021, 1, 61, 1279),
	(62, 1022, 1, 61, 1280),
	(62, 1023, 1, 61, 1281),
	(62, 1024, 1, 61, 1282),
	(62, 1025, 1, 61, 1283),
	(62, 1026, 1, 61, 1284),
	(62, 1027, 1, 61, 1285),
	(62, 1028, 1, 61, 1286),
	(62, 1029, 1, 61, 1287),
	(62, 1030, 1, 61, 1288),
	(62, 1031, 1, 61, 1289),
	(62, 1032, 1, 61, 1290),
	(62, 1033, 1, 61, 1291),
	(62, 1034, 1, 61, 1292),
	(62, 1035, 1, 61, 1293),
	(62, 1036, 1, 61, 1294),
	(62, 1037, 1, 61, 1295),
	(62, 1038, 1, 61, 1296),
	(62, 1039, 1, 61, 1297),
	(62, 1040, 1, 61, 1298),
	(62, 1041, 1, 61, 1299),
	(62, 1042, 1, 61, 1300),
	(62, 1043, 1, 61, 1301),
	(62, 1044, 1, 61, 1302),
	(62, 1045, 1, 61, 1303),
	(62, 1046, 1, 61, 1304),
	(62, 1047, 1, 61, 1305),
	(62, 1048, 1, 61, 1306),
	(62, 1049, 1, 61, 1307),
	(62, 1050, 1, 61, 1308),
	(62, 1051, 1, 61, 1309),
	(62, 1052, 1, 61, 1310),
	(62, 1053, 1, 61, 1311),
	(62, 1054, 1, 61, 1312),
	(62, 1055, 1, 61, 1313),
	(62, 1254, 1, 61, 1314),
	(62, 1255, 1, 61, 1315),
	(62, 1256, 1, 61, 1316),
	(62, 1257, 1, 61, 1317),
	(62, 1258, 1, 61, 1318),
	(62, 1259, 1, 61, 1319),
	(62, 1260, 1, 61, 1320),
	(62, 1261, 1, 61, 1321),
	(62, 1262, 1, 61, 1322),
	(62, 1263, 1, 61, 1323),
	(62, 1264, 1, 61, 1324),
	(62, 1265, 1, 61, 1325),
	(62, 1266, 1, 61, 1326),
	(62, 1267, 1, 61, 1327),
	(62, 1268, 1, 61, 1328),
	(62, 1269, 1, 61, 1329),
	(62, 1270, 1, 61, 1330),
	(62, 1271, 1, 61, 1331),
	(62, 1272, 1, 61, 1332),
	(62, 1273, 1, 61, 1333),
	(62, 1274, 1, 61, 1334),
	(62, 1275, 1, 61, 1335),
	(62, 1276, 1, 61, 1336),
	(62, 1277, 1, 61, 1337),
	(62, 1278, 1, 61, 1338),
	(62, 1279, 1, 61, 1339),
	(62, 1280, 1, 61, 1340),
	(62, 1281, 1, 61, 1341),
	(62, 1282, 1, 61, 1342),
	(62, 1283, 1, 61, 1343),
	(62, 1284, 1, 61, 1344),
	(62, 1285, 1, 61, 1345),
	(62, 1286, 1, 61, 1346),
	(62, 1287, 1, 61, 1347),
	(62, 1288, 1, 61, 1348),
	(62, 1289, 1, 61, 1349),
	(62, 1290, 1, 61, 1350),
	(62, 1291, 1, 61, 1351),
	(62, 1292, 1, 61, 1352),
	(62, 1293, 1, 61, 1353),
	(62, 1294, 1, 61, 1354),
	(62, 1295, 1, 61, 1355),
	(62, 1296, 1, 61, 1356),
	(62, 1297, 1, 61, 1357),
	(62, 1298, 1, 61, 1358),
	(62, 1299, 1, 61, 1359),
	(62, 1300, 1, 61, 1360),
	(62, 1301, 1, 61, 1361),
	(62, 1302, 1, 61, 1362),
	(62, 1303, 1, 61, 1363),
	(62, 1304, 1, 61, 1364),
	(62, 1305, 1, 61, 1365),
	(62, 1306, 1, 61, 1366),
	(62, 1307, 1, 61, 1367),
	(62, 1308, 1, 61, 1368),
	(62, 1309, 1, 61, 1369),
	(62, 1310, 1, 61, 1370),
	(62, 1311, 1, 61, 1371),
	(62, 1312, 1, 61, 1372),
	(62, 1313, 1, 61, 1373),
	(62, 1314, 1, 61, 1374),
	(62, 1315, 1, 61, 1375),
	(62, 1316, 1, 61, 1376),
	(62, 1317, 1, 61, 1377),
	(62, 1318, 1, 61, 1378),
	(62, 1319, 1, 61, 1379),
	(62, 1320, 1, 61, 1380),
	(62, 1321, 1, 61, 1381),
	(62, 1322, 1, 61, 1382),
	(62, 1323, 1, 61, 1383),
	(62, 1324, 1, 61, 1384),
	(62, 1325, 1, 61, 1385),
	(62, 1326, 1, 61, 1386),
	(62, 1327, 1, 61, 1387),
	(62, 1328, 1, 61, 1388),
	(62, 1329, 1, 61, 1389),
	(62, 1330, 1, 61, 1390),
	(62, 1331, 1, 61, 1391),
	(62, 1332, 1, 61, 1392),
	(62, 1333, 1, 61, 1393),
	(62, 1334, 1, 61, 1394),
	(62, 1335, 1, 61, 1395),
	(62, 1336, 1, 61, 1396),
	(62, 1337, 1, 61, 1397),
	(62, 1338, 1, 61, 1398),
	(62, 1339, 1, 61, 1399),
	(62, 1340, 1, 61, 1400),
	(62, 1341, 1, 61, 1401),
	(62, 1342, 1, 61, 1402),
	(62, 1343, 1, 61, 1403),
	(62, 1344, 1, 61, 1404),
	(62, 1345, 1, 61, 1405),
	(62, 1346, 1, 61, 1406),
	(62, 1347, 1, 61, 1407),
	(62, 1348, 1, 61, 1408),
	(62, 1349, 1, 61, 1409),
	(62, 1350, 1, 61, 1410),
	(62, 1351, 1, 61, 1411),
	(62, 1352, 1, 61, 1412),
	(62, 1353, 1, 61, 1413),
	(62, 1354, 1, 61, 1414),
	(62, 1355, 1, 61, 1415),
	(62, 1356, 1, 61, 1416),
	(62, 1357, 1, 61, 1417),
	(62, 1358, 1, 61, 1418),
	(62, 1359, 1, 61, 1419),
	(62, 1360, 1, 61, 1420),
	(62, 1361, 1, 61, 1421),
	(62, 1362, 1, 61, 1422),
	(62, 1363, 1, 61, 1423),
	(62, 1364, 1, 61, 1424),
	(62, 1365, 1, 61, 1425),
	(62, 1366, 1, 61, 1426),
	(62, 1367, 1, 61, 1427),
	(62, 1368, 1, 61, 1428),
	(62, 1369, 1, 61, 1429),
	(62, 1370, 1, 61, 1430),
	(62, 1371, 1, 61, 1431),
	(62, 1372, 1, 61, 1432),
	(62, 1373, 1, 61, 1433),
	(62, 1374, 1, 61, 1434),
	(62, 1375, 1, 61, 1435),
	(62, 1376, 1, 61, 1436),
	(62, 1377, 1, 61, 1437),
	(62, 1378, 1, 61, 1438),
	(62, 1379, 1, 61, 1439),
	(62, 1380, 1, 61, 1440),
	(62, 1381, 1, 61, 1441),
	(62, 1382, 1, 61, 1442),
	(62, 1383, 1, 61, 1443),
	(62, 1384, 1, 61, 1444),
	(62, 1385, 1, 61, 1445),
	(62, 1386, 1, 61, 1446),
	(62, 1387, 1, 61, 1447),
	(62, 1388, 1, 61, 1448),
	(62, 1389, 1, 61, 1449),
	(62, 1390, 1, 61, 1450),
	(62, 1391, 1, 61, 1451),
	(62, 1392, 1, 61, 1452),
	(62, 1393, 1, 61, 1453),
	(62, 1394, 1, 61, 1454),
	(62, 1395, 1, 61, 1455),
	(62, 1396, 1, 61, 1456),
	(62, 1397, 1, 61, 1457),
	(62, 1398, 1, 61, 1458),
	(62, 1399, 1, 61, 1459),
	(62, 1400, 1, 61, 1460),
	(62, 1401, 1, 61, 1461),
	(62, 1402, 1, 61, 1462),
	(62, 1403, 1, 61, 1463),
	(62, 1404, 1, 61, 1464),
	(62, 1405, 1, 61, 1465),
	(62, 1406, 1, 61, 1466),
	(62, 1407, 1, 61, 1467),
	(62, 1408, 1, 61, 1468),
	(62, 1409, 1, 61, 1469),
	(62, 1056, 1, 61, 1470),
	(62, 1057, 1, 61, 1471),
	(62, 1058, 1, 61, 1472),
	(62, 1059, 1, 61, 1473),
	(62, 1060, 1, 61, 1474),
	(62, 1061, 1, 61, 1475),
	(62, 1062, 1, 61, 1476),
	(62, 1063, 1, 61, 1477),
	(62, 1064, 1, 61, 1478),
	(62, 1065, 1, 61, 1479),
	(62, 1066, 1, 61, 1480),
	(62, 1067, 1, 61, 1481),
	(62, 1068, 1, 61, 1482),
	(62, 1069, 1, 61, 1483),
	(62, 1070, 1, 61, 1484),
	(62, 1071, 1, 61, 1485),
	(62, 1072, 1, 61, 1486),
	(62, 1073, 1, 61, 1487),
	(62, 1074, 1, 61, 1488),
	(62, 1075, 1, 61, 1489),
	(62, 1076, 1, 61, 1490),
	(62, 1077, 1, 61, 1491),
	(62, 1078, 1, 61, 1492),
	(62, 1079, 1, 61, 1493),
	(62, 1080, 1, 61, 1494),
	(62, 1081, 1, 61, 1495),
	(62, 1082, 1, 61, 1496),
	(62, 1083, 1, 61, 1497),
	(62, 1084, 1, 61, 1498),
	(62, 1085, 1, 61, 1499),
	(62, 1086, 1, 61, 1500),
	(62, 1087, 1, 61, 1501),
	(62, 1088, 1, 61, 1502),
	(62, 1089, 1, 61, 1503),
	(62, 1090, 1, 61, 1504),
	(62, 1091, 1, 61, 1505),
	(62, 1092, 1, 61, 1506),
	(62, 1093, 1, 61, 1507),
	(62, 1094, 1, 61, 1508),
	(62, 1095, 1, 61, 1509),
	(62, 1096, 1, 61, 1510),
	(62, 1097, 1, 61, 1511),
	(62, 1098, 1, 61, 1512),
	(62, 1099, 1, 61, 1513),
	(62, 1100, 1, 61, 1514),
	(62, 1101, 1, 61, 1515),
	(62, 1102, 1, 61, 1516),
	(62, 1103, 1, 61, 1517),
	(62, 1104, 1, 61, 1518),
	(62, 1105, 1, 61, 1519),
	(62, 1106, 1, 61, 1520),
	(62, 1107, 1, 61, 1521),
	(62, 1108, 1, 61, 1522),
	(62, 1109, 1, 61, 1523),
	(62, 1110, 1, 61, 1524),
	(62, 1111, 1, 61, 1525),
	(62, 1112, 1, 61, 1526),
	(62, 1113, 1, 61, 1527),
	(62, 1114, 1, 61, 1528),
	(62, 1115, 1, 61, 1529),
	(62, 1116, 1, 61, 1530),
	(62, 1117, 1, 61, 1531),
	(62, 1118, 1, 61, 1532),
	(62, 1119, 1, 61, 1533),
	(62, 1120, 1, 61, 1534),
	(62, 1121, 1, 61, 1535),
	(62, 1122, 1, 61, 1536),
	(62, 1123, 1, 61, 1537),
	(62, 1124, 1, 61, 1538),
	(62, 1125, 1, 61, 1539),
	(62, 1126, 1, 61, 1540),
	(62, 1127, 1, 61, 1541),
	(62, 1128, 1, 61, 1542),
	(62, 1129, 1, 61, 1543),
	(62, 1130, 1, 61, 1544),
	(62, 1131, 1, 61, 1545),
	(62, 1132, 1, 61, 1546),
	(62, 1133, 1, 61, 1547),
	(62, 1134, 1, 61, 1548),
	(62, 1135, 1, 61, 1549),
	(62, 1136, 1, 61, 1550),
	(62, 1137, 1, 61, 1551),
	(62, 1138, 1, 61, 1552),
	(62, 1139, 1, 61, 1553),
	(62, 1140, 1, 61, 1554),
	(62, 1141, 1, 61, 1555),
	(62, 1142, 1, 61, 1556),
	(62, 1143, 1, 61, 1557),
	(62, 1144, 1, 61, 1558),
	(62, 1145, 1, 61, 1559),
	(62, 1146, 1, 61, 1560),
	(62, 1147, 1, 61, 1561),
	(62, 1148, 1, 61, 1562),
	(62, 1149, 1, 61, 1563),
	(62, 1150, 1, 61, 1564),
	(62, 1151, 1, 61, 1565),
	(62, 1152, 1, 61, 1566),
	(62, 1153, 1, 61, 1567),
	(62, 1154, 1, 61, 1568),
	(62, 1155, 1, 61, 1569),
	(62, 1156, 1, 61, 1570),
	(62, 1157, 1, 61, 1571),
	(62, 1158, 1, 61, 1572),
	(62, 1159, 1, 61, 1573),
	(62, 1160, 1, 61, 1574),
	(62, 1161, 1, 61, 1575),
	(62, 1162, 1, 61, 1576),
	(62, 1163, 1, 61, 1577),
	(62, 1164, 1, 61, 1578),
	(62, 1165, 1, 61, 1579),
	(62, 1166, 1, 61, 1580),
	(62, 1167, 1, 61, 1581),
	(62, 1168, 1, 61, 1582),
	(62, 1169, 1, 61, 1583),
	(62, 1170, 1, 61, 1584),
	(62, 1171, 1, 61, 1585),
	(62, 1172, 1, 61, 1586),
	(62, 1173, 1, 61, 1587),
	(62, 1174, 1, 61, 1588),
	(62, 1175, 1, 61, 1589),
	(62, 1176, 1, 61, 1590),
	(62, 1177, 1, 61, 1591),
	(62, 1178, 1, 61, 1592),
	(62, 1179, 1, 61, 1593),
	(62, 1180, 1, 61, 1594),
	(62, 1181, 1, 61, 1595),
	(62, 1182, 1, 61, 1596),
	(62, 1183, 1, 61, 1597),
	(62, 1184, 1, 61, 1598),
	(62, 1185, 1, 61, 1599),
	(62, 1186, 1, 61, 1600),
	(62, 1187, 1, 61, 1601),
	(62, 1188, 1, 61, 1602),
	(62, 1189, 1, 61, 1603),
	(62, 1190, 1, 61, 1604),
	(62, 1191, 1, 61, 1605),
	(62, 1192, 1, 61, 1606),
	(62, 1193, 1, 61, 1607),
	(62, 1194, 1, 61, 1608),
	(62, 1195, 1, 61, 1609),
	(62, 1196, 1, 61, 1610),
	(62, 1197, 1, 61, 1611),
	(62, 1198, 1, 61, 1612),
	(62, 1199, 1, 61, 1613),
	(62, 1200, 1, 61, 1614),
	(62, 1201, 1, 61, 1615),
	(62, 1202, 1, 61, 1616),
	(62, 1203, 1, 61, 1617),
	(62, 1204, 1, 61, 1618),
	(62, 1205, 1, 61, 1619),
	(62, 1206, 1, 61, 1620),
	(62, 1207, 1, 61, 1621),
	(62, 1208, 1, 61, 1622),
	(62, 1209, 1, 61, 1623),
	(62, 1210, 1, 61, 1624),
	(62, 1211, 1, 61, 1625),
	(62, 1212, 1, 61, 1626),
	(62, 1213, 1, 61, 1627),
	(62, 1214, 1, 61, 1628),
	(62, 1215, 1, 61, 1629),
	(62, 1216, 1, 61, 1630),
	(62, 1217, 1, 61, 1631),
	(62, 1218, 1, 61, 1632),
	(62, 1219, 1, 61, 1633),
	(62, 1220, 1, 61, 1634),
	(62, 1221, 1, 61, 1635),
	(62, 1222, 1, 61, 1636),
	(62, 1223, 1, 61, 1637),
	(62, 1224, 1, 61, 1638),
	(62, 1225, 1, 61, 1639),
	(62, 1226, 1, 61, 1640),
	(62, 1227, 1, 61, 1641),
	(62, 1228, 1, 61, 1642),
	(62, 1229, 1, 61, 1643),
	(62, 1230, 1, 61, 1644),
	(62, 1231, 1, 61, 1645),
	(62, 1232, 1, 61, 1646),
	(62, 1233, 1, 61, 1647),
	(62, 1234, 1, 61, 1648),
	(62, 1235, 1, 61, 1649),
	(62, 1236, 1, 61, 1650),
	(62, 1237, 1, 61, 1651),
	(62, 1238, 1, 61, 1652),
	(62, 1239, 1, 61, 1653),
	(62, 1240, 1, 61, 1654),
	(62, 1241, 1, 61, 1655),
	(62, 1242, 1, 61, 1656),
	(62, 1243, 1, 61, 1657),
	(62, 1244, 1, 61, 1658),
	(62, 1245, 1, 61, 1659),
	(62, 1246, 1, 61, 1660),
	(62, 1247, 1, 61, 1661),
	(62, 1248, 1, 61, 1662),
	(62, 1249, 1, 61, 1663),
	(62, 1250, 1, 61, 1664),
	(62, 1251, 1, 61, 1665),
	(62, 1252, 1, 61, 1666),
	(62, 1253, 1, 61, 1667),
	(62, 1594, 1, 61, 1668),
	(62, 1595, 1, 61, 1669),
	(62, 1596, 1, 61, 1670),
	(62, 1597, 1, 61, 1671),
	(62, 1598, 1, 61, 1672),
	(62, 1599, 1, 61, 1673),
	(62, 1600, 1, 61, 1674),
	(62, 1601, 1, 61, 1675),
	(62, 1602, 1, 61, 1676),
	(62, 1603, 1, 61, 1677),
	(62, 1604, 1, 61, 1678),
	(62, 1605, 1, 61, 1679),
	(62, 1606, 1, 61, 1680),
	(62, 1607, 1, 61, 1681),
	(62, 1608, 1, 61, 1682),
	(62, 1609, 1, 61, 1683),
	(62, 1610, 1, 61, 1684),
	(62, 1611, 1, 61, 1685),
	(62, 1612, 1, 61, 1686),
	(62, 1613, 1, 61, 1687),
	(62, 1614, 1, 61, 1688),
	(62, 1615, 1, 61, 1689),
	(62, 1616, 1, 61, 1690),
	(62, 229, 1, 61, 1691),
	(62, 1619, 1, 61, 1692),
	(62, 1620, 1, 61, 1693),
	(62, 1621, 1, 61, 1694),
	(62, 236, 1, 61, 1695),
	(62, 237, 1, 61, 1696),
	(62, 238, 1, 61, 1697),
	(62, 239, 1, 61, 1698),
	(62, 240, 1, 61, 1699),
	(62, 241, 1, 61, 1700),
	(62, 242, 1, 61, 1701),
	(62, 243, 1, 61, 1702),
	(62, 244, 1, 61, 1703),
	(62, 245, 1, 61, 1704),
	(62, 246, 1, 61, 1705),
	(62, 247, 1, 61, 1706),
	(62, 251, 1, 61, 1707),
	(62, 252, 1, 61, 1708),
	(62, 249, 1, 61, 1709),
	(62, 250, 1, 61, 1710),
	(62, 254, 1, 61, 1711),
	(62, 248, 1, 61, 1712),
	(62, 253, 1, 61, 1713),
	(62, 1622, 1, 61, 1714),
	(62, 1623, 1, 61, 1715),
	(62, 1624, 1, 61, 1716),
	(62, 1625, 1, 61, 1717),
	(62, 1626, 1, 61, 1718),
	(62, 1627, 1, 61, 1719),
	(62, 1628, 1, 61, 1720),
	(62, 1629, 1, 61, 1721),
	(62, 1630, 1, 61, 1722),
	(62, 255, 1, 61, 1723),
	(62, 256, 1, 61, 1724),
	(62, 257, 1, 61, 1725),
	(62, 258, 1, 61, 1726),
	(62, 259, 1, 61, 1727),
	(62, 260, 1, 61, 1728),
	(62, 261, 1, 61, 1729),
	(62, 262, 1, 61, 1730),
	(62, 267, 1, 61, 1731),
	(62, 268, 1, 61, 1732),
	(62, 102, 1, 61, 1733),
	(62, 103, 1, 61, 1734),
	(62, 14, 1, 61, 1735),
	(62, 104, 1, 61, 1736),
	(62, 105, 1, 61, 1737),
	(62, 269, 1, 61, 1738),
	(62, 272, 1, 61, 1739),
	(62, 273, 1, 61, 1740),
	(62, 235, 1, 61, 1741),
	(62, 231, 1, 61, 1742),
	(62, 232, 1, 61, 1743),
	(62, 233, 1, 61, 1744),
	(62, 234, 1, 61, 1745),
	(62, 230, 1, 61, 1746),
	(62, 263, 1, 61, 1747),
	(62, 264, 1, 61, 1748),
	(62, 265, 1, 61, 1749),
	(62, 266, 1, 61, 1750),
	(62, 274, 1, 61, 1751),
	(62, 275, 1, 61, 1752),
	(62, 276, 1, 61, 1753),
	(62, 277, 1, 61, 1754),
	(62, 278, 1, 61, 1755),
	(62, 279, 1, 61, 1756),
	(62, 280, 1, 61, 1757),
	(62, 281, 1, 61, 1758),
	(62, 282, 1, 61, 1759),
	(62, 283, 1, 61, 1760),
	(62, 284, 1, 61, 1761),
	(62, 285, 1, 61, 1762),
	(62, 286, 1, 61, 1763),
	(62, 287, 1, 61, 1764),
	(62, 288, 1, 61, 1765),
	(62, 289, 1, 61, 1766),
	(62, 290, 1, 61, 1767),
	(62, 291, 1, 61, 1768),
	(62, 292, 1, 61, 1769),
	(62, 293, 1, 61, 1770),
	(62, 294, 1, 61, 1771),
	(62, 295, 1, 61, 1772),
	(62, 296, 1, 61, 1773),
	(62, 297, 1, 61, 1774),
	(62, 298, 1, 61, 1775),
	(62, -1, 1, 61, 1776),
	(62, 299, 1, 61, 1777),
	(62, 300, 1, 61, 1778),
	(62, 1410, 1, 61, 1779),
	(62, 1411, 1, 61, 1780),
	(62, 1412, 1, 61, 1781),
	(62, 1413, 1, 61, 1782),
	(62, 1414, 1, 61, 1783),
	(62, 1415, 1, 61, 1784),
	(62, 1416, 1, 61, 1785),
	(62, 1417, 1, 61, 1786),
	(62, 1418, 1, 61, 1787),
	(62, 1419, 1, 61, 1788),
	(62, 1420, 1, 61, 1789),
	(62, 1421, 1, 61, 1790),
	(62, 1422, 1, 61, 1791),
	(62, 1423, 1, 61, 1792),
	(62, 1424, 1, 61, 1793),
	(62, 1425, 1, 61, 1794),
	(62, 1426, 1, 61, 1795),
	(62, 1427, 1, 61, 1796),
	(62, 1428, 1, 61, 1797),
	(62, 1429, 1, 61, 1798),
	(62, 1430, 1, 61, 1799),
	(62, 1431, 1, 61, 1800),
	(62, 1432, 1, 61, 1801),
	(62, 1433, 1, 61, 1802),
	(62, 1434, 1, 61, 1803),
	(62, 1435, 1, 61, 1804),
	(62, 1436, 1, 61, 1805),
	(62, 1437, 1, 61, 1806),
	(62, 1438, 1, 61, 1807),
	(62, 1439, 1, 61, 1808),
	(62, 1440, 1, 61, 1809),
	(62, 1441, 1, 61, 1810),
	(62, 1442, 1, 61, 1811),
	(62, 1443, 1, 61, 1812),
	(62, 1444, 1, 61, 1813),
	(62, 1445, 1, 61, 1814),
	(62, 1446, 1, 61, 1815),
	(62, 1447, 1, 61, 1816),
	(62, 1448, 1, 61, 1817),
	(62, 1449, 1, 61, 1818),
	(62, 1450, 1, 61, 1819),
	(62, 1451, 1, 61, 1820),
	(62, 1452, 1, 61, 1821),
	(62, 1453, 1, 61, 1822),
	(62, 1454, 1, 61, 1823),
	(62, 1455, 1, 61, 1824),
	(62, 1456, 1, 61, 1825),
	(62, 1457, 1, 61, 1826),
	(62, 1458, 1, 61, 1827),
	(62, 1459, 1, 61, 1828),
	(62, 1460, 1, 61, 1829),
	(62, 1461, 1, 61, 1830),
	(62, 1462, 1, 61, 1831),
	(62, 1463, 1, 61, 1832),
	(62, 1464, 1, 61, 1833),
	(62, 1465, 1, 61, 1834),
	(62, 1466, 1, 61, 1835),
	(62, 1467, 1, 61, 1836),
	(62, 1468, 1, 61, 1837),
	(62, 1469, 1, 61, 1838),
	(62, 1470, 1, 61, 1839),
	(62, 1471, 1, 61, 1840),
	(62, 1472, 1, 61, 1841),
	(62, 1473, 1, 61, 1842),
	(62, 1474, 1, 61, 1843),
	(62, 1475, 1, 61, 1844),
	(62, 1476, 1, 61, 1845),
	(62, 1477, 1, 61, 1846),
	(62, 1478, 1, 61, 1847),
	(62, 1479, 1, 61, 1848),
	(62, 1480, 1, 61, 1849),
	(62, 1481, 1, 61, 1850),
	(62, 1482, 1, 61, 1851),
	(62, 1483, 1, 61, 1852),
	(62, 1484, 1, 61, 1853),
	(62, 1485, 1, 61, 1854),
	(62, 1486, 1, 61, 1855),
	(62, 1487, 1, 61, 1856),
	(62, 1488, 1, 61, 1857),
	(62, 1489, 1, 61, 1858),
	(62, 1490, 1, 61, 1859),
	(62, 1491, 1, 61, 1860),
	(62, 1492, 1, 61, 1861),
	(62, 1493, 1, 61, 1862),
	(62, 1494, 1, 61, 1863),
	(62, 1495, 1, 61, 1864),
	(62, 1496, 1, 61, 1865),
	(62, 1497, 1, 61, 1866),
	(62, 1498, 1, 61, 1867),
	(62, 1499, 1, 61, 1868),
	(62, 1500, 1, 61, 1869),
	(62, 1501, 1, 61, 1870),
	(62, 1502, 1, 61, 1871),
	(62, 1503, 1, 61, 1872),
	(62, 1504, 1, 61, 1873),
	(62, 1505, 1, 61, 1874),
	(62, 1506, 1, 61, 1875),
	(62, 1507, 1, 61, 1876),
	(62, 1508, 1, 61, 1877),
	(62, 1509, 1, 61, 1878),
	(62, 1510, 1, 61, 1879),
	(62, 1511, 1, 61, 1880),
	(62, 1512, 1, 61, 1881),
	(62, 1513, 1, 61, 1882),
	(62, 1514, 1, 61, 1883),
	(62, 1515, 1, 61, 1884),
	(62, 1516, 1, 61, 1885),
	(62, 1517, 1, 61, 1886),
	(62, 1518, 1, 61, 1887),
	(62, 1519, 1, 61, 1888),
	(62, 1520, 1, 61, 1889),
	(62, 1521, 1, 61, 1890),
	(62, 1522, 1, 61, 1891),
	(62, 1523, 1, 61, 1892),
	(62, 1524, 1, 61, 1893),
	(62, 1525, 1, 61, 1894),
	(62, 1526, 1, 61, 1895),
	(62, 1527, 1, 61, 1896),
	(62, 1528, 1, 61, 1897),
	(62, 1529, 1, 61, 1898),
	(62, 1530, 1, 61, 1899),
	(62, 1531, 1, 61, 1900),
	(62, 1532, 1, 61, 1901),
	(62, 1533, 1, 61, 1902),
	(62, 1534, 1, 61, 1903),
	(62, 1535, 1, 61, 1904),
	(62, 1536, 1, 61, 1905),
	(62, 1537, 1, 61, 1906),
	(62, 1538, 1, 61, 1907),
	(62, 1539, 1, 61, 1908),
	(62, 1540, 1, 61, 1909),
	(62, 1541, 1, 61, 1910),
	(62, 1542, 1, 61, 1911),
	(62, 1543, 1, 61, 1912),
	(62, 1544, 1, 61, 1913),
	(62, 1545, 1, 61, 1914),
	(62, 1546, 1, 61, 1915),
	(62, 1547, 1, 61, 1916),
	(62, 1548, 1, 61, 1917),
	(62, 1549, 1, 61, 1918),
	(62, 1550, 1, 61, 1919),
	(62, 1551, 1, 61, 1920),
	(62, 1552, 1, 61, 1921),
	(62, 1553, 1, 61, 1922),
	(62, 1554, 1, 61, 1923),
	(62, 1555, 1, 61, 1924),
	(62, 1556, 1, 61, 1925),
	(62, 1557, 1, 61, 1926),
	(62, 1558, 1, 61, 1927),
	(62, 1559, 1, 61, 1928),
	(62, 1560, 1, 61, 1929),
	(62, 1561, 1, 61, 1930),
	(62, 1562, 1, 61, 1931),
	(62, 1563, 1, 61, 1932),
	(62, 1564, 1, 61, 1933),
	(62, 1565, 1, 61, 1934),
	(62, 1566, 1, 61, 1935),
	(62, 1567, 1, 61, 1936),
	(62, 1568, 1, 61, 1937),
	(62, 1569, 1, 61, 1938),
	(62, 1570, 1, 61, 1939),
	(62, 1571, 1, 61, 1940),
	(62, 1572, 1, 61, 1941),
	(62, 1573, 1, 61, 1942),
	(62, 1574, 1, 61, 1943),
	(62, 1575, 1, 61, 1944),
	(62, 1576, 1, 61, 1945),
	(62, 1577, 1, 61, 1946),
	(62, 1578, 1, 61, 1947),
	(62, 1579, 1, 61, 1948),
	(62, 1580, 1, 61, 1949),
	(62, 1581, 1, 61, 1950),
	(62, 1582, 1, 61, 1951),
	(62, 1583, 1, 61, 1952),
	(62, 1584, 1, 61, 1953),
	(62, 1585, 1, 61, 1954),
	(62, 1586, 1, 61, 1955),
	(62, 1587, 1, 61, 1956),
	(62, 1588, 1, 61, 1957),
	(62, 1589, 1, 61, 1958),
	(62, 1590, 1, 61, 1959),
	(62, 1591, 1, 61, 1960),
	(62, 1592, 1, 61, 1961),
	(62, 1593, 1, 61, 1962),
	(62, 303, 1, 61, 1963),
	(62, 304, 1, 61, 1964),
	(62, 319, 1, 61, 1965),
	(62, 320, 1, 61, 1966),
	(62, 1631, 1, 61, 1967),
	(62, 1632, 1, 61, 1968),
	(62, 1633, 1, 61, 1969),
	(62, 1634, 1, 61, 1970),
	(62, 1635, 1, 61, 1971),
	(62, 321, 1, 61, 1972),
	(62, 322, 1, 61, 1973),
	(62, 323, 1, 61, 1974),
	(62, 348, 1, 61, 1975),
	(62, 349, 1, 61, 1976),
	(62, 350, 1, 61, 1977),
	(62, 351, 1, 61, 1978),
	(62, 352, 1, 61, 1979),
	(62, 301, 1, 61, 1980),
	(62, 302, 1, 61, 1981),
	(62, 307, 1, 61, 1982),
	(62, 308, 1, 61, 1983),
	(62, 309, 1, 61, 1984),
	(62, 310, 1, 61, 1985),
	(62, 311, 1, 61, 1986),
	(62, 312, 1, 61, 1987),
	(62, 313, 1, 61, 1988),
	(62, 314, 1, 61, 1989),
	(62, 315, 1, 61, 1990),
	(62, 316, 1, 61, 1991),
	(62, 317, 1, 61, 1992),
	(62, 318, 1, 61, 1993),
	(62, 333, 1, 61, 1994),
	(62, 334, 1, 61, 1995),
	(62, 335, 1, 61, 1996),
	(62, 353, 1, 61, 1997),
	(62, 324, 1, 61, 1998),
	(62, 354, 1, 61, 1999),
	(62, 346, 1, 61, 2000),
	(62, 347, 1, 61, 2001),
	(62, 339, 1, 61, 2002),
	(62, 340, 1, 61, 2003),
	(62, 341, 1, 61, 2004),
	(62, 342, 1, 61, 2005),
	(62, 343, 1, 61, 2006),
	(62, 344, 1, 61, 2007),
	(62, 345, 1, 61, 2008),
	(62, 305, 1, 61, 2009),
	(62, 306, 1, 61, 2010),
	(62, 328, 1, 61, 2011),
	(62, 329, 1, 61, 2012),
	(62, 331, 1, 61, 2013),
	(62, 330, 1, 61, 2014),
	(62, 332, 1, 61, 2015),
	(62, 336, 1, 61, 2016),
	(62, 337, 1, 61, 2017),
	(62, 338, 1, 61, 2018),
	(62, 356, 1, 61, 3004),
	(62, 357, 1, 61, 3007),
	(62, 358, 1, 61, 3017),
	(62, 359, 1, 61, 3023),
	(62, 360, 1, 61, 3026),
	(62, 361, 1, 61, 3031),
	(62, 362, 1, 61, 3035),
	(62, 363, 1, 61, 3039),
	(62, 364, 1, 61, 3043),
	(62, 365, 1, 61, 3047),
	(62, 366, 1, 61, 3051),
	(62, 367, 1, 61, 3055),
	(62, 368, 1, 61, 3223),
	(62, 369, 1, 61, 3225),
	(62, 370, 1, 61, 3227),
	(62, 371, 1, 61, 3580),
	(62, 372, 1, 61, 3582),
	(62, 373, 1, 61, 3584),
	(62, 374, 1, 61, 3586),
	(684, 0, 1, 103, 2019),
	(684, 1, 1, 103, 2020),
	(113, 5, 1, 114, 2021),
	(113, 6, 1, 114, 2022),
	(113, 7, 1, 114, 2023),
	(113, 62, 1, 114, 2024),
	(123, 1, 1, 124, 2025),
	(123, 2, 1, 124, 2026),
	(128, 454, 1, 125, 2027),
	(128, 600, 1, 125, 2028),
	(133, 1, 1, 134, 2029),
	(133, 2, 1, 134, 2030),
	(150, 1, 1, 148, 177),
	(160, 1, 1, 159, 2031),
	(160, 2, 1, 159, 2032),
	(160, 21, 1, 159, 2033),
	(160, 22, 1, 159, 2034),
	(172, 977, 1, 170, 40),
	(172, 979, 1, 170, 55),
	(172, 978, 1, 170, 111),
	(172, 982, 1, 170, 165),
	(172, 983, 1, 170, 190),
	(172, 818, 1, 170, 934),
	(172, 96, 1, 170, 2035),
	(172, 107, 1, 170, 2036),
	(172, 116, 1, 170, 2037),
	(172, 117, 1, 170, 2038),
	(172, 421, 1, 170, 2039),
	(172, 422, 1, 170, 2040),
	(172, 423, 1, 170, 2041),
	(172, 424, 1, 170, 2042),
	(172, 425, 1, 170, 2043),
	(172, 426, 1, 170, 2044),
	(172, 88, 1, 170, 2045),
	(172, 121, 1, 170, 2046),
	(172, 92, 1, 170, 2047),
	(172, 122, 1, 170, 2048),
	(172, 123, 1, 170, 2049),
	(172, 124, 1, 170, 2050),
	(172, 136, 1, 170, 2051),
	(172, 141, 1, 170, 2052),
	(172, 361, 1, 170, 2053),
	(172, 362, 1, 170, 2054),
	(172, 366, 1, 170, 2055),
	(172, 416, 1, 170, 2056),
	(172, 456, 1, 170, 2057),
	(172, 83, 1, 170, 2058),
	(172, 41, 1, 170, 2059),
	(172, 61, 1, 170, 2060),
	(172, 1, 1, 170, 2061),
	(172, 2, 1, 170, 2062),
	(172, 3, 1, 170, 2063),
	(172, 4, 1, 170, 2064),
	(172, 5, 1, 170, 2065),
	(172, 6, 1, 170, 2066),
	(172, 7, 1, 170, 2067),
	(172, 8, 1, 170, 2068),
	(172, 9, 1, 170, 2069),
	(172, 381, 1, 170, 2070),
	(172, 82, 1, 170, 2071),
	(172, 84, 1, 170, 2072),
	(172, 382, 1, 170, 2073),
	(172, 383, 1, 170, 2074),
	(172, 384, 1, 170, 2075),
	(172, 441, 1, 170, 2076),
	(172, 442, 1, 170, 2077),
	(172, 251, 1, 170, 2078),
	(172, 252, 1, 170, 2079),
	(172, 253, 1, 170, 2080),
	(172, 254, 1, 170, 2081),
	(172, 255, 1, 170, 2082),
	(172, 256, 1, 170, 2083),
	(172, 257, 1, 170, 2084),
	(172, 258, 1, 170, 2085),
	(172, 259, 1, 170, 2086),
	(172, 260, 1, 170, 2087),
	(172, 261, 1, 170, 2088),
	(172, 262, 1, 170, 2089),
	(172, 263, 1, 170, 2090),
	(172, 264, 1, 170, 2091),
	(172, 265, 1, 170, 2092),
	(172, 266, 1, 170, 2093),
	(172, 267, 1, 170, 2094),
	(172, 268, 1, 170, 2095),
	(172, 269, 1, 170, 2096),
	(172, 270, 1, 170, 2097),
	(172, 271, 1, 170, 2098),
	(172, 272, 1, 170, 2099),
	(172, 273, 1, 170, 2100),
	(172, 274, 1, 170, 2101),
	(172, 275, 1, 170, 2102),
	(172, 276, 1, 170, 2103),
	(172, 277, 1, 170, 2104),
	(172, 278, 1, 170, 2105),
	(172, 279, 1, 170, 2106),
	(172, 280, 1, 170, 2107),
	(172, 281, 1, 170, 2108),
	(172, 282, 1, 170, 2109),
	(172, 283, 1, 170, 2110),
	(172, 284, 1, 170, 2111),
	(172, 285, 1, 170, 2112),
	(172, 286, 1, 170, 2113),
	(172, 287, 1, 170, 2114),
	(172, 288, 1, 170, 2115),
	(172, 289, 1, 170, 2116),
	(172, 290, 1, 170, 2117),
	(172, 291, 1, 170, 2118),
	(172, 292, 1, 170, 2119),
	(172, 293, 1, 170, 2120),
	(172, 294, 1, 170, 2121),
	(172, 295, 1, 170, 2122),
	(172, 296, 1, 170, 2123),
	(172, 297, 1, 170, 2124),
	(172, 298, 1, 170, 2125),
	(172, 299, 1, 170, 2126),
	(172, 300, 1, 170, 2127),
	(172, 301, 1, 170, 2128),
	(172, 302, 1, 170, 2129),
	(172, 303, 1, 170, 2130),
	(172, 304, 1, 170, 2131),
	(172, 305, 1, 170, 2132),
	(172, 306, 1, 170, 2133),
	(172, 307, 1, 170, 2134),
	(172, 308, 1, 170, 2135),
	(172, 309, 1, 170, 2136),
	(172, 310, 1, 170, 2137),
	(172, 311, 1, 170, 2138),
	(172, 312, 1, 170, 2139),
	(172, 313, 1, 170, 2140),
	(172, 314, 1, 170, 2141),
	(172, 315, 1, 170, 2142),
	(172, 316, 1, 170, 2143),
	(172, 317, 1, 170, 2144),
	(172, 318, 1, 170, 2145),
	(172, 319, 1, 170, 2146),
	(172, 320, 1, 170, 2147),
	(172, 321, 1, 170, 2148),
	(172, 322, 1, 170, 2149),
	(172, 323, 1, 170, 2150),
	(172, 324, 1, 170, 2151),
	(172, 325, 1, 170, 2152),
	(172, 326, 1, 170, 2153),
	(172, 327, 1, 170, 2154),
	(172, 328, 1, 170, 2155),
	(172, 329, 1, 170, 2156),
	(172, 330, 1, 170, 2157),
	(172, 331, 1, 170, 2158),
	(172, 332, 1, 170, 2159),
	(172, 333, 1, 170, 2160),
	(172, 334, 1, 170, 2161),
	(172, 335, 1, 170, 2162),
	(172, 336, 1, 170, 2163),
	(172, 337, 1, 170, 2164),
	(172, 338, 1, 170, 2165),
	(172, 339, 1, 170, 2166),
	(172, 340, 1, 170, 2167),
	(172, 341, 1, 170, 2168),
	(172, 342, 1, 170, 2169),
	(172, 343, 1, 170, 2170),
	(172, 344, 1, 170, 2171),
	(172, 345, 1, 170, 2172),
	(172, 346, 1, 170, 2173),
	(172, 347, 1, 170, 2174),
	(172, 348, 1, 170, 2175),
	(172, 349, 1, 170, 2176),
	(172, 350, 1, 170, 2177),
	(172, 351, 1, 170, 2178),
	(172, 352, 1, 170, 2179),
	(172, 353, 1, 170, 2180),
	(172, 354, 1, 170, 2181),
	(172, 355, 1, 170, 2182),
	(172, 356, 1, 170, 2183),
	(172, 357, 1, 170, 2184),
	(172, 371, 1, 170, 2185),
	(172, 377, 1, 170, 2186),
	(172, 411, 1, 170, 2187),
	(172, 126, 1, 170, 2188),
	(172, 146, 1, 170, 2189),
	(172, 147, 1, 170, 2190),
	(172, 148, 1, 170, 2191),
	(172, 149, 1, 170, 2192),
	(172, 150, 1, 170, 2193),
	(172, 151, 1, 170, 2194),
	(172, 152, 1, 170, 2195),
	(172, 153, 1, 170, 2196),
	(172, 154, 1, 170, 2197),
	(172, 155, 1, 170, 2198),
	(172, 156, 1, 170, 2199),
	(172, 157, 1, 170, 2200),
	(172, 158, 1, 170, 2201),
	(172, 159, 1, 170, 2202),
	(172, 160, 1, 170, 2203),
	(172, 161, 1, 170, 2204),
	(172, 162, 1, 170, 2205),
	(172, 163, 1, 170, 2206),
	(172, 164, 1, 170, 2207),
	(172, 165, 1, 170, 2208),
	(172, 166, 1, 170, 2209),
	(172, 167, 1, 170, 2210),
	(172, 168, 1, 170, 2211),
	(172, 169, 1, 170, 2212),
	(172, 170, 1, 170, 2213),
	(172, 171, 1, 170, 2214),
	(172, 172, 1, 170, 2215),
	(172, 173, 1, 170, 2216),
	(172, 174, 1, 170, 2217),
	(172, 175, 1, 170, 2218),
	(172, 176, 1, 170, 2219),
	(172, 177, 1, 170, 2220),
	(172, 178, 1, 170, 2221),
	(172, 179, 1, 170, 2222),
	(172, 180, 1, 170, 2223),
	(172, 181, 1, 170, 2224),
	(172, 182, 1, 170, 2225),
	(172, 183, 1, 170, 2226),
	(172, 184, 1, 170, 2227),
	(172, 185, 1, 170, 2228),
	(172, 186, 1, 170, 2229),
	(172, 187, 1, 170, 2230),
	(172, 188, 1, 170, 2231),
	(172, 189, 1, 170, 2232),
	(172, 190, 1, 170, 2233),
	(172, 191, 1, 170, 2234),
	(172, 192, 1, 170, 2235),
	(172, 193, 1, 170, 2236),
	(172, 194, 1, 170, 2237),
	(172, 195, 1, 170, 2238),
	(172, 196, 1, 170, 2239),
	(172, 197, 1, 170, 2240),
	(172, 198, 1, 170, 2241),
	(172, 199, 1, 170, 2242),
	(172, 200, 1, 170, 2243),
	(172, 201, 1, 170, 2244),
	(172, 202, 1, 170, 2245),
	(172, 203, 1, 170, 2246),
	(172, 204, 1, 170, 2247),
	(172, 205, 1, 170, 2248),
	(172, 206, 1, 170, 2249),
	(172, 207, 1, 170, 2250),
	(172, 208, 1, 170, 2251),
	(172, 209, 1, 170, 2252),
	(172, 210, 1, 170, 2253),
	(172, 211, 1, 170, 2254),
	(172, 212, 1, 170, 2255),
	(172, 213, 1, 170, 2256),
	(172, 214, 1, 170, 2257),
	(172, 215, 1, 170, 2258),
	(172, 216, 1, 170, 2259),
	(172, 217, 1, 170, 2260),
	(172, 218, 1, 170, 2261),
	(172, 219, 1, 170, 2262),
	(172, 220, 1, 170, 2263),
	(172, 221, 1, 170, 2264),
	(172, 222, 1, 170, 2265),
	(172, 223, 1, 170, 2266),
	(172, 224, 1, 170, 2267),
	(172, 225, 1, 170, 2268),
	(172, 226, 1, 170, 2269),
	(172, 227, 1, 170, 2270),
	(172, 228, 1, 170, 2271),
	(172, 229, 1, 170, 2272),
	(172, 230, 1, 170, 2273),
	(172, 231, 1, 170, 2274),
	(172, 232, 1, 170, 2275),
	(172, 233, 1, 170, 2276),
	(172, 234, 1, 170, 2277),
	(172, 235, 1, 170, 2278),
	(172, 236, 1, 170, 2279),
	(172, 237, 1, 170, 2280),
	(172, 238, 1, 170, 2281),
	(172, 239, 1, 170, 2282),
	(172, 240, 1, 170, 2283),
	(172, 241, 1, 170, 2284),
	(172, 242, 1, 170, 2285),
	(172, 243, 1, 170, 2286),
	(172, 244, 1, 170, 2287),
	(172, 245, 1, 170, 2288),
	(172, 246, 1, 170, 2289),
	(172, 247, 1, 170, 2290),
	(172, 248, 1, 170, 2291),
	(172, 249, 1, 170, 2292),
	(172, 250, 1, 170, 2293),
	(172, 391, 1, 170, 2294),
	(172, 392, 1, 170, 2295),
	(172, 393, 1, 170, 2296),
	(172, 394, 1, 170, 2297),
	(172, 395, 1, 170, 2298),
	(172, 396, 1, 170, 2299),
	(172, 397, 1, 170, 2300),
	(172, 398, 1, 170, 2301),
	(172, 399, 1, 170, 2302),
	(172, 400, 1, 170, 2303),
	(172, 401, 1, 170, 2304),
	(172, 402, 1, 170, 2305),
	(172, 403, 1, 170, 2306),
	(172, 404, 1, 170, 2307),
	(172, 405, 1, 170, 2308),
	(172, 406, 1, 170, 2309),
	(172, 431, 1, 170, 2310),
	(172, 461, 1, 170, 2311),
	(172, 471, 1, 170, 2312),
	(172, 472, 1, 170, 2313),
	(172, 481, 1, 170, 2314),
	(172, 526, 1, 170, 2315),
	(172, 527, 1, 170, 2316),
	(172, 528, 1, 170, 2317),
	(172, 529, 1, 170, 2318),
	(172, 530, 1, 170, 2319),
	(172, 531, 1, 170, 2320),
	(172, 532, 1, 170, 2321),
	(172, 533, 1, 170, 2322),
	(172, 534, 1, 170, 2323),
	(172, 535, 1, 170, 2324),
	(172, 536, 1, 170, 2325),
	(172, 537, 1, 170, 2326),
	(172, 538, 1, 170, 2327),
	(172, 539, 1, 170, 2328),
	(172, 540, 1, 170, 2329),
	(172, 541, 1, 170, 2330),
	(172, 542, 1, 170, 2331),
	(172, 543, 1, 170, 2332),
	(172, 544, 1, 170, 2333),
	(172, 545, 1, 170, 2334),
	(172, 546, 1, 170, 2335),
	(172, 547, 1, 170, 2336),
	(172, 548, 1, 170, 2337),
	(172, 549, 1, 170, 2338),
	(172, 550, 1, 170, 2339),
	(172, 553, 1, 170, 2340),
	(172, 554, 1, 170, 2341),
	(172, 555, 1, 170, 2342),
	(172, 556, 1, 170, 2343),
	(172, 557, 1, 170, 2344),
	(172, 558, 1, 170, 2345),
	(172, 559, 1, 170, 2346),
	(172, 560, 1, 170, 2347),
	(172, 561, 1, 170, 2348),
	(172, 562, 1, 170, 2349),
	(172, 563, 1, 170, 2350),
	(172, 564, 1, 170, 2351),
	(172, 565, 1, 170, 2352),
	(172, 566, 1, 170, 2353),
	(172, 567, 1, 170, 2354),
	(172, 568, 1, 170, 2355),
	(172, 569, 1, 170, 2356),
	(172, 570, 1, 170, 2357),
	(172, 637, 1, 170, 2358),
	(172, 638, 1, 170, 2359),
	(172, 639, 1, 170, 2360),
	(172, 640, 1, 170, 2361),
	(172, 641, 1, 170, 2362),
	(172, 642, 1, 170, 2363),
	(172, 643, 1, 170, 2364),
	(172, 644, 1, 170, 2365),
	(172, 645, 1, 170, 2366),
	(172, 646, 1, 170, 2367),
	(172, 647, 1, 170, 2368),
	(172, 648, 1, 170, 2369),
	(172, 718, 1, 170, 2370),
	(172, 719, 1, 170, 2371),
	(172, 720, 1, 170, 2372),
	(172, 774, 1, 170, 2373),
	(172, 775, 1, 170, 2374),
	(172, 784, 1, 170, 2375),
	(172, 785, 1, 170, 2376),
	(172, 786, 1, 170, 2377),
	(172, 787, 1, 170, 2378),
	(172, 788, 1, 170, 2379),
	(172, 789, 1, 170, 2380),
	(172, 790, 1, 170, 2381),
	(172, 791, 1, 170, 2382),
	(172, 792, 1, 170, 2383),
	(172, 793, 1, 170, 2384),
	(172, 794, 1, 170, 2385),
	(172, 795, 1, 170, 2386),
	(172, 796, 1, 170, 2387),
	(172, 797, 1, 170, 2388),
	(172, 800, 1, 170, 2389),
	(172, 801, 1, 170, 2390),
	(172, 802, 1, 170, 2391),
	(172, 803, 1, 170, 2392),
	(172, 804, 1, 170, 2393),
	(172, 805, 1, 170, 2394),
	(172, 806, 1, 170, 2395),
	(172, 807, 1, 170, 2396),
	(172, 808, 1, 170, 2397),
	(172, 809, 1, 170, 2398),
	(172, 810, 1, 170, 2399),
	(172, 811, 1, 170, 2400),
	(172, 812, 1, 170, 2401),
	(172, 813, 1, 170, 2402),
	(172, 814, 1, 170, 2403),
	(172, 815, 1, 170, 2404),
	(172, 816, 1, 170, 2405),
	(172, 817, 1, 170, 2406),
	(172, 899, 1, 170, 2407),
	(172, 900, 1, 170, 2408),
	(172, 901, 1, 170, 2409),
	(172, 902, 1, 170, 2410),
	(172, 903, 1, 170, 2411),
	(172, 904, 1, 170, 2412),
	(172, 905, 1, 170, 2413),
	(172, 906, 1, 170, 2414),
	(172, 907, 1, 170, 2415),
	(172, 908, 1, 170, 2416),
	(172, 909, 1, 170, 2417),
	(172, 910, 1, 170, 2418),
	(172, 911, 1, 170, 2419),
	(172, 912, 1, 170, 2420),
	(172, 913, 1, 170, 2421),
	(172, 914, 1, 170, 2422),
	(172, 915, 1, 170, 2423),
	(172, 916, 1, 170, 2424),
	(172, 917, 1, 170, 2425),
	(172, 918, 1, 170, 2426),
	(172, 919, 1, 170, 2427),
	(172, 924, 1, 170, 2428),
	(172, 925, 1, 170, 2429),
	(172, 926, 1, 170, 2430),
	(172, 927, 1, 170, 2431),
	(172, 928, 1, 170, 2432),
	(172, 929, 1, 170, 2433),
	(172, 930, 1, 170, 2434),
	(172, 931, 1, 170, 2435),
	(172, 932, 1, 170, 2436),
	(172, 933, 1, 170, 2437),
	(172, 934, 1, 170, 2438),
	(172, 935, 1, 170, 2439),
	(172, 936, 1, 170, 2440),
	(172, 937, 1, 170, 2441),
	(172, 938, 1, 170, 2442),
	(172, 939, 1, 170, 2443),
	(172, 940, 1, 170, 2444),
	(172, 941, 1, 170, 2445),
	(172, 942, 1, 170, 2446),
	(172, 943, 1, 170, 2447),
	(172, 944, 1, 170, 2448),
	(172, 945, 1, 170, 2449),
	(172, 946, 1, 170, 2450),
	(172, 947, 1, 170, 2451),
	(172, 466, 1, 170, 2452),
	(172, 467, 1, 170, 2453),
	(172, 491, 1, 170, 2454),
	(172, 492, 1, 170, 2455),
	(172, 493, 1, 170, 2456),
	(172, 494, 1, 170, 2457),
	(172, 495, 1, 170, 2458),
	(172, 496, 1, 170, 2459),
	(172, 497, 1, 170, 2460),
	(172, 498, 1, 170, 2461),
	(172, 499, 1, 170, 2462),
	(172, 500, 1, 170, 2463),
	(172, 501, 1, 170, 2464),
	(172, 502, 1, 170, 2465),
	(172, 503, 1, 170, 2466),
	(172, 504, 1, 170, 2467),
	(172, 505, 1, 170, 2468),
	(172, 506, 1, 170, 2469),
	(172, 507, 1, 170, 2470),
	(172, 508, 1, 170, 2471),
	(172, 509, 1, 170, 2472),
	(172, 510, 1, 170, 2473),
	(172, 511, 1, 170, 2474),
	(172, 512, 1, 170, 2475),
	(172, 513, 1, 170, 2476),
	(172, 514, 1, 170, 2477),
	(172, 515, 1, 170, 2478),
	(172, 516, 1, 170, 2479),
	(172, 700, 1, 170, 2480),
	(172, 522, 1, 170, 2481),
	(172, 523, 1, 170, 2482),
	(172, 524, 1, 170, 2483),
	(172, 525, 1, 170, 2484),
	(172, 551, 1, 170, 2485),
	(172, 573, 1, 170, 2486),
	(172, 580, 1, 170, 2487),
	(172, 581, 1, 170, 2488),
	(172, 582, 1, 170, 2489),
	(172, 583, 1, 170, 2490),
	(172, 584, 1, 170, 2491),
	(172, 586, 1, 170, 2492),
	(172, 588, 1, 170, 2493),
	(172, 589, 1, 170, 2494),
	(172, 590, 1, 170, 2495),
	(172, 591, 1, 170, 2496),
	(172, 592, 1, 170, 2497),
	(172, 593, 1, 170, 2498),
	(172, 594, 1, 170, 2499),
	(172, 595, 1, 170, 2500),
	(172, 596, 1, 170, 2501),
	(172, 597, 1, 170, 2502),
	(172, 598, 1, 170, 2503),
	(172, 599, 1, 170, 2504),
	(172, 600, 1, 170, 2505),
	(172, 601, 1, 170, 2506),
	(172, 602, 1, 170, 2507),
	(172, 603, 1, 170, 2508),
	(172, 604, 1, 170, 2509),
	(172, 605, 1, 170, 2510),
	(172, 606, 1, 170, 2511),
	(172, 607, 1, 170, 2512),
	(172, 608, 1, 170, 2513),
	(172, 609, 1, 170, 2514),
	(172, 610, 1, 170, 2515),
	(172, 611, 1, 170, 2516),
	(172, 612, 1, 170, 2517),
	(172, 613, 1, 170, 2518),
	(172, 614, 1, 170, 2519),
	(172, 615, 1, 170, 2520),
	(172, 616, 1, 170, 2521),
	(172, 617, 1, 170, 2522),
	(172, 618, 1, 170, 2523),
	(172, 619, 1, 170, 2524),
	(172, 620, 1, 170, 2525),
	(172, 621, 1, 170, 2526),
	(172, 622, 1, 170, 2527),
	(172, 623, 1, 170, 2528),
	(172, 624, 1, 170, 2529),
	(172, 625, 1, 170, 2530),
	(172, 626, 1, 170, 2531),
	(172, 627, 1, 170, 2532),
	(172, 628, 1, 170, 2533),
	(172, 629, 1, 170, 2534),
	(172, 630, 1, 170, 2535),
	(172, 631, 1, 170, 2536),
	(172, 632, 1, 170, 2537),
	(172, 633, 1, 170, 2538),
	(172, 634, 1, 170, 2539),
	(172, 635, 1, 170, 2540),
	(172, 636, 1, 170, 2541),
	(172, 649, 1, 170, 2542),
	(172, 650, 1, 170, 2543),
	(172, 651, 1, 170, 2544),
	(172, 652, 1, 170, 2545),
	(172, 653, 1, 170, 2546),
	(172, 654, 1, 170, 2547),
	(172, 655, 1, 170, 2548),
	(172, 656, 1, 170, 2549),
	(172, 657, 1, 170, 2550),
	(172, 658, 1, 170, 2551),
	(172, 659, 1, 170, 2552),
	(172, 660, 1, 170, 2553),
	(172, 661, 1, 170, 2554),
	(172, 662, 1, 170, 2555),
	(172, 663, 1, 170, 2556),
	(172, 664, 1, 170, 2557),
	(172, 665, 1, 170, 2558),
	(172, 666, 1, 170, 2559),
	(172, 667, 1, 170, 2560),
	(172, 668, 1, 170, 2561),
	(172, 669, 1, 170, 2562),
	(172, 670, 1, 170, 2563),
	(172, 671, 1, 170, 2564),
	(172, 672, 1, 170, 2565),
	(172, 673, 1, 170, 2566),
	(172, 674, 1, 170, 2567),
	(172, 675, 1, 170, 2568),
	(172, 676, 1, 170, 2569),
	(172, 677, 1, 170, 2570),
	(172, 678, 1, 170, 2571),
	(172, 679, 1, 170, 2572),
	(172, 680, 1, 170, 2573),
	(172, 681, 1, 170, 2574),
	(172, 682, 1, 170, 2575),
	(172, 683, 1, 170, 2576),
	(172, 684, 1, 170, 2577),
	(172, 685, 1, 170, 2578),
	(172, 686, 1, 170, 2579),
	(172, 699, 1, 170, 2580),
	(172, 724, 1, 170, 2581),
	(172, 725, 1, 170, 2582),
	(172, 726, 1, 170, 2583),
	(172, 727, 1, 170, 2584),
	(172, 728, 1, 170, 2585),
	(172, 729, 1, 170, 2586),
	(172, 730, 1, 170, 2587),
	(172, 731, 1, 170, 2588),
	(172, 732, 1, 170, 2589),
	(172, 733, 1, 170, 2590),
	(172, 734, 1, 170, 2591),
	(172, 735, 1, 170, 2592),
	(172, 736, 1, 170, 2593),
	(172, 737, 1, 170, 2594),
	(172, 738, 1, 170, 2595),
	(172, 739, 1, 170, 2596),
	(172, 740, 1, 170, 2597),
	(172, 741, 1, 170, 2598),
	(172, 742, 1, 170, 2599),
	(172, 779, 1, 170, 2600),
	(172, 476, 1, 170, 2601),
	(172, 477, 1, 170, 2602),
	(172, 486, 1, 170, 2603),
	(172, 578, 1, 170, 2604),
	(172, 579, 1, 170, 2605),
	(172, 689, 1, 170, 2606),
	(172, 690, 1, 170, 2607),
	(172, 691, 1, 170, 2608),
	(172, 692, 1, 170, 2609),
	(172, 693, 1, 170, 2610),
	(172, 694, 1, 170, 2611),
	(172, 695, 1, 170, 2612),
	(172, 696, 1, 170, 2613),
	(172, 697, 1, 170, 2614),
	(172, 698, 1, 170, 2615),
	(172, 701, 1, 170, 2616),
	(172, 704, 1, 170, 2617),
	(172, 705, 1, 170, 2618),
	(172, 706, 1, 170, 2619),
	(172, 707, 1, 170, 2620),
	(172, 708, 1, 170, 2621),
	(172, 709, 1, 170, 2622),
	(172, 710, 1, 170, 2623),
	(172, 711, 1, 170, 2624),
	(172, 712, 1, 170, 2625),
	(172, 713, 1, 170, 2626),
	(172, 714, 1, 170, 2627),
	(172, 715, 1, 170, 2628),
	(172, 716, 1, 170, 2629),
	(172, 717, 1, 170, 2630),
	(172, 744, 1, 170, 2631),
	(172, 745, 1, 170, 2632),
	(172, 746, 1, 170, 2633),
	(172, 747, 1, 170, 2634),
	(172, 748, 1, 170, 2635),
	(172, 749, 1, 170, 2636),
	(172, 750, 1, 170, 2637),
	(172, 751, 1, 170, 2638),
	(172, 752, 1, 170, 2639),
	(172, 753, 1, 170, 2640),
	(172, 754, 1, 170, 2641),
	(172, 755, 1, 170, 2642),
	(172, 756, 1, 170, 2643),
	(172, 757, 1, 170, 2644),
	(172, 758, 1, 170, 2645),
	(172, 759, 1, 170, 2646),
	(172, 760, 1, 170, 2647),
	(172, 761, 1, 170, 2648),
	(172, 762, 1, 170, 2649),
	(172, 763, 1, 170, 2650),
	(172, 764, 1, 170, 2651),
	(172, 765, 1, 170, 2652),
	(172, 766, 1, 170, 2653),
	(172, 767, 1, 170, 2654),
	(172, 768, 1, 170, 2655),
	(172, 769, 1, 170, 2656),
	(172, 770, 1, 170, 2657),
	(172, 780, 1, 170, 2658),
	(172, 781, 1, 170, 2659),
	(172, 798, 1, 170, 2660),
	(172, 799, 1, 170, 2661),
	(172, 819, 1, 170, 2662),
	(172, 820, 1, 170, 2663),
	(172, 821, 1, 170, 2664),
	(172, 822, 1, 170, 2665),
	(172, 823, 1, 170, 2666),
	(172, 824, 1, 170, 2667),
	(172, 825, 1, 170, 2668),
	(172, 826, 1, 170, 2669),
	(172, 827, 1, 170, 2670),
	(172, 828, 1, 170, 2671),
	(172, 829, 1, 170, 2672),
	(172, 830, 1, 170, 2673),
	(172, 831, 1, 170, 2674),
	(172, 832, 1, 170, 2675),
	(172, 833, 1, 170, 2676),
	(172, 834, 1, 170, 2677),
	(172, 835, 1, 170, 2678),
	(172, 836, 1, 170, 2679),
	(172, 837, 1, 170, 2680),
	(172, 838, 1, 170, 2681),
	(172, 839, 1, 170, 2682),
	(172, 840, 1, 170, 2683),
	(172, 841, 1, 170, 2684),
	(172, 842, 1, 170, 2685),
	(172, 843, 1, 170, 2686),
	(172, 844, 1, 170, 2687),
	(172, 845, 1, 170, 2688),
	(172, 846, 1, 170, 2689),
	(172, 847, 1, 170, 2690),
	(172, 848, 1, 170, 2691),
	(172, 849, 1, 170, 2692),
	(172, 850, 1, 170, 2693),
	(172, 851, 1, 170, 2694),
	(172, 852, 1, 170, 2695),
	(172, 853, 1, 170, 2696),
	(172, 854, 1, 170, 2697),
	(172, 855, 1, 170, 2698),
	(172, 856, 1, 170, 2699),
	(172, 857, 1, 170, 2700),
	(172, 858, 1, 170, 2701),
	(172, 859, 1, 170, 2702),
	(172, 860, 1, 170, 2703),
	(172, 861, 1, 170, 2704),
	(172, 862, 1, 170, 2705),
	(172, 863, 1, 170, 2706),
	(172, 864, 1, 170, 2707),
	(172, 865, 1, 170, 2708),
	(172, 866, 1, 170, 2709),
	(172, 867, 1, 170, 2710),
	(172, 868, 1, 170, 2711),
	(172, 869, 1, 170, 2712),
	(172, 870, 1, 170, 2713),
	(172, 871, 1, 170, 2714),
	(172, 872, 1, 170, 2715),
	(172, 873, 1, 170, 2716),
	(172, 874, 1, 170, 2717),
	(172, 875, 1, 170, 2718),
	(172, 876, 1, 170, 2719),
	(172, 877, 1, 170, 2720),
	(172, 879, 1, 170, 2721),
	(172, 880, 1, 170, 2722),
	(172, 881, 1, 170, 2723),
	(172, 882, 1, 170, 2724),
	(172, 883, 1, 170, 2725),
	(172, 884, 1, 170, 2726),
	(172, 885, 1, 170, 2727),
	(172, 886, 1, 170, 2728),
	(172, 887, 1, 170, 2729),
	(172, 888, 1, 170, 2730),
	(172, 889, 1, 170, 2731),
	(172, 890, 1, 170, 2732),
	(172, 891, 1, 170, 2733),
	(172, 892, 1, 170, 2734),
	(172, 894, 1, 170, 2735),
	(172, 895, 1, 170, 2736),
	(172, 948, 1, 170, 2737),
	(172, 949, 1, 170, 2738),
	(172, 950, 1, 170, 2739),
	(172, 951, 1, 170, 2740),
	(172, 952, 1, 170, 2741),
	(172, 953, 1, 170, 2742),
	(172, 954, 1, 170, 2743),
	(172, 955, 1, 170, 2744),
	(172, 956, 1, 170, 2745),
	(172, 957, 1, 170, 2746),
	(172, 958, 1, 170, 2747),
	(172, 959, 1, 170, 2748),
	(172, 960, 1, 170, 2749),
	(172, 961, 1, 170, 2750),
	(172, 962, 1, 170, 2751),
	(172, 963, 1, 170, 2752),
	(172, 964, 1, 170, 2753),
	(172, 965, 1, 170, 2754),
	(172, 966, 1, 170, 2755),
	(172, 967, 1, 170, 2756),
	(172, 968, 1, 170, 2757),
	(172, 969, 1, 170, 2758),
	(172, 970, 1, 170, 2759),
	(172, 971, 1, 170, 2760),
	(172, 972, 1, 170, 2761),
	(172, 973, 1, 170, 2762),
	(172, 974, 1, 170, 2763),
	(172, 975, 1, 170, 2764),
	(172, 976, 1, 170, 2765),
	(172, 987, 1, 170, 2987),
	(172, 988, 1, 170, 3111),
	(172, 989, 1, 170, 3117),
	(172, 990, 1, 170, 3119),
	(172, 991, 1, 170, 3121),
	(172, 992, 1, 170, 3123),
	(172, 993, 1, 170, 3125),
	(172, 994, 1, 170, 3129),
	(172, 995, 1, 170, 3133),
	(172, 996, 1, 170, 3137),
	(172, 997, 1, 170, 3141),
	(172, 998, 1, 170, 3145),
	(172, 999, 1, 170, 3149),
	(172, 1000, 1, 170, 3151),
	(172, 1001, 1, 170, 3153),
	(172, 1002, 1, 170, 3157),
	(172, 1003, 1, 170, 3159),
	(172, 1004, 1, 170, 3161),
	(172, 1005, 1, 170, 3163),
	(172, 1006, 1, 170, 3165),
	(172, 1007, 1, 170, 3167),
	(172, 1008, 1, 170, 3169),
	(172, 1009, 1, 170, 3171),
	(172, 1010, 1, 170, 3173),
	(172, 1011, 1, 170, 3175),
	(172, 1012, 1, 170, 3177),
	(172, 1013, 1, 170, 3179),
	(172, 1014, 1, 170, 3181),
	(172, 1015, 1, 170, 3183),
	(172, 1016, 1, 170, 3185),
	(172, 1017, 1, 170, 3187),
	(172, 1018, 1, 170, 3189),
	(172, 1019, 1, 170, 3191),
	(172, 1020, 1, 170, 3193),
	(172, 1021, 1, 170, 3195),
	(172, 1022, 1, 170, 3197),
	(172, 1023, 1, 170, 3199),
	(172, 1024, 1, 170, 3201),
	(172, 1025, 1, 170, 3203),
	(172, 1026, 1, 170, 3205),
	(172, 1027, 1, 170, 3240),
	(172, 1028, 1, 170, 3247),
	(172, 1029, 1, 170, 3253),
	(172, 1030, 1, 170, 3255),
	(172, 1031, 1, 170, 3257),
	(172, 1032, 1, 170, 3272),
	(172, 1033, 1, 170, 3274),
	(172, 1034, 1, 170, 3276),
	(172, 1035, 1, 170, 3281),
	(172, 1036, 1, 170, 3283),
	(172, 1037, 1, 170, 3312),
	(172, 1038, 1, 170, 3316),
	(172, 1039, 1, 170, 3318),
	(172, 1040, 1, 170, 3320),
	(172, 1041, 1, 170, 3322),
	(172, 1042, 1, 170, 3324),
	(172, 1043, 1, 170, 3328),
	(172, 1044, 1, 170, 3330),
	(172, 1045, 1, 170, 3332),
	(172, 1046, 1, 170, 3334),
	(172, 1047, 1, 170, 3336),
	(172, 1048, 1, 170, 3338),
	(172, 1049, 1, 170, 3340),
	(172, 1050, 1, 170, 3342),
	(172, 1051, 1, 170, 3344),
	(172, 1052, 1, 170, 3347),
	(172, 1053, 1, 170, 3351),
	(172, 1054, 1, 170, 3355),
	(172, 1055, 1, 170, 3357),
	(172, 1056, 1, 170, 3359),
	(172, 1057, 1, 170, 3361),
	(172, 1058, 1, 170, 3363),
	(172, 1059, 1, 170, 3365),
	(172, 1060, 1, 170, 3367),
	(172, 1061, 1, 170, 3369),
	(172, 1062, 1, 170, 3371),
	(172, 1063, 1, 170, 3373),
	(172, 1064, 1, 170, 3375),
	(172, 1065, 1, 170, 3377),
	(172, 1066, 1, 170, 3379),
	(172, 1067, 1, 170, 3381),
	(172, 1068, 1, 170, 3385),
	(172, 1069, 1, 170, 3387),
	(172, 1070, 1, 170, 3389),
	(172, 1071, 1, 170, 3391),
	(172, 1072, 1, 170, 3393),
	(172, 1073, 1, 170, 3395),
	(172, 1074, 1, 170, 3397),
	(172, 1075, 1, 170, 3399),
	(172, 1076, 1, 170, 3401),
	(172, 1077, 1, 170, 3403),
	(172, 1078, 1, 170, 3405),
	(172, 1079, 1, 170, 3407),
	(172, 1080, 1, 170, 3409),
	(172, 1081, 1, 170, 3411),
	(172, 1082, 1, 170, 3413),
	(172, 1083, 1, 170, 3415),
	(172, 1084, 1, 170, 3417),
	(172, 1085, 1, 170, 3419),
	(172, 1086, 1, 170, 3421),
	(172, 1087, 1, 170, 3423),
	(172, 1088, 1, 170, 3425),
	(172, 1089, 1, 170, 3427),
	(172, 1090, 1, 170, 3429),
	(172, 1091, 1, 170, 3431),
	(172, 1092, 1, 170, 3433),
	(172, 1093, 1, 170, 3435),
	(172, 1094, 1, 170, 3437),
	(172, 1095, 1, 170, 3439),
	(172, 1096, 1, 170, 3441),
	(172, 1097, 1, 170, 3443),
	(172, 1098, 1, 170, 3445),
	(172, 1099, 1, 170, 3447),
	(172, 1100, 1, 170, 3449),
	(172, 1101, 1, 170, 3451),
	(172, 1102, 1, 170, 3453),
	(172, 1103, 1, 170, 3455),
	(172, 1104, 1, 170, 3457),
	(172, 1105, 1, 170, 3459),
	(172, 1106, 1, 170, 3461),
	(172, 1107, 1, 170, 3465),
	(172, 1108, 1, 170, 3467),
	(172, 1109, 1, 170, 3469),
	(172, 1110, 1, 170, 3471),
	(172, 1111, 1, 170, 3473),
	(172, 1112, 1, 170, 3475),
	(172, 1113, 1, 170, 3477),
	(172, 1114, 1, 170, 3481),
	(172, 1115, 1, 170, 3483),
	(172, 1116, 1, 170, 3485),
	(172, 1117, 1, 170, 3487),
	(172, 1118, 1, 170, 3489),
	(172, 1119, 1, 170, 3491),
	(172, 1120, 1, 170, 3493),
	(172, 1121, 1, 170, 3495),
	(172, 1122, 1, 170, 3497),
	(172, 1123, 1, 170, 3499),
	(172, 1124, 1, 170, 3501),
	(172, 1125, 1, 170, 3503),
	(172, 1126, 1, 170, 3505),
	(172, 1127, 1, 170, 3507),
	(172, 1128, 1, 170, 3509),
	(172, 1129, 1, 170, 3511),
	(172, 1130, 1, 170, 3513),
	(172, 1131, 1, 170, 3515),
	(172, 1132, 1, 170, 3517),
	(172, 1133, 1, 170, 3519),
	(172, 1134, 1, 170, 3521),
	(172, 1135, 1, 170, 3523),
	(172, 1136, 1, 170, 3525),
	(172, 1137, 1, 170, 3527),
	(172, 1138, 1, 170, 3529),
	(172, 1139, 1, 170, 3531),
	(172, 1140, 1, 170, 3534),
	(172, 1141, 1, 170, 3536),
	(172, 1142, 1, 170, 3538),
	(172, 1143, 1, 170, 3540),
	(172, 1144, 1, 170, 3542),
	(172, 1145, 1, 170, 3544),
	(172, 1146, 1, 170, 3547),
	(172, 1147, 1, 170, 3549),
	(172, 1148, 1, 170, 3551),
	(172, 1149, 1, 170, 3553),
	(172, 1150, 1, 170, 3555),
	(172, 1151, 1, 170, 3557),
	(172, 1152, 1, 170, 3559),
	(172, 1153, 1, 170, 3562),
	(172, 1154, 1, 170, 3564),
	(172, 1155, 1, 170, 3566),
	(172, 1156, 1, 170, 3568),
	(172, 1157, 1, 170, 3570),
	(172, 1158, 1, 170, 3572),
	(175, 0, 1, 174, 2766),
	(175, 1, 1, 174, 2767),
	(175, 2, 1, 174, 2768),
	(175, 3, 1, 174, 2769),
	(175, 4, 1, 174, 2770),
	(175, 5, 1, 174, 2771),
	(175, 6, 1, 174, 2772),
	(175, 7, 1, 174, 2773),
	(175, 8, 1, 174, 2774),
	(180, 10, 1, 179, 2775),
	(180, 26, 1, 179, 2776),
	(180, 27, 1, 179, 2777),
	(180, 28, 1, 179, 2778),
	(180, 29, 1, 179, 2779),
	(180, 30, 1, 179, 2780),
	(180, 31, 1, 179, 2781),
	(180, 32, 1, 179, 2782),
	(180, 33, 1, 179, 2783),
	(180, 34, 1, 179, 2784),
	(180, 35, 1, 179, 2785),
	(180, 36, 1, 179, 2786),
	(180, 37, 1, 179, 2787),
	(180, 38, 1, 179, 2788),
	(180, 39, 1, 179, 2789),
	(180, 40, 1, 179, 2790),
	(180, 41, 1, 179, 2791),
	(180, 42, 1, 179, 2792),
	(180, 43, 1, 179, 2793),
	(180, 44, 1, 179, 2794),
	(180, 45, 1, 179, 2795),
	(180, 46, 1, 179, 2796),
	(180, 47, 1, 179, 2797),
	(180, 48, 1, 179, 2798),
	(185, 1, 1, 184, 2799),
	(185, 26, 1, 184, 2800),
	(185, 27, 1, 184, 2801),
	(199, 1, 1, 195, 2802),
	(199, 2, 1, 195, 2803),
	(199, 3, 1, 195, 2804),
	(199, 6, 1, 195, 2805),
	(202, 1, 1, 203, 2806),
	(202, 11, 1, 203, 2807),
	(209, -1, 1, 206, 2808),
	(209, 1, 1, 206, 2809),
	(209, 2, 1, 206, 2810),
	(248, 1, 1, 247, 2811),
	(256, 1, 1, 255, 2799),
	(266, 890, 1, 263, 28),
	(266, 855, 1, 263, 87),
	(266, 872, 1, 263, 158),
	(266, 865, 1, 263, 754),
	(266, 900, 1, 263, 886),
	(266, 850, 1, 263, 888),
	(266, 870, 1, 263, 893),
	(266, 907, 1, 263, 907),
	(266, 908, 1, 263, 921),
	(266, 871, 1, 263, 930),
	(266, 860, 1, 263, 951),
	(266, 882, 1, 263, 955),
	(266, 888, 1, 263, 962),
	(266, 875, 1, 263, 963),
	(266, 884, 1, 263, 966),
	(266, 873, 1, 263, 971),
	(266, 877, 1, 263, 973),
	(266, 883, 1, 263, 975),
	(266, 879, 1, 263, 984),
	(266, 895, 1, 263, 985),
	(266, 887, 1, 263, 987),
	(266, 876, 1, 263, 988),
	(266, 905, 1, 263, 995),
	(266, 881, 1, 263, 999),
	(266, 549, 1, 263, 1015),
	(266, 880, 1, 263, 1018),
	(266, 878, 1, 263, 1039),
	(266, 2, 1, 263, 2812),
	(266, 833, 1, 263, 2813),
	(266, 834, 1, 263, 2814),
	(266, 835, 1, 263, 2815),
	(266, 838, 1, 263, 2816),
	(266, 839, 1, 263, 2817),
	(266, 847, 1, 263, 2818),
	(266, 866, 1, 263, 2819),
	(266, 867, 1, 263, 2820),
	(266, 868, 1, 263, 2821),
	(266, 874, 1, 263, 2822),
	(266, 885, 1, 263, 2823),
	(266, 886, 1, 263, 2824),
	(266, 906, 1, 263, 2825),
	(274, 1, 1, 273, 2826),
	(274, 2, 1, 273, 2827),
	(274, 21, 1, 273, 2828),
	(274, 101, 1, 273, 2829),
	(274, 126, 1, 273, 2830),
	(274, 127, 1, 273, 2831),
	(274, 128, 1, 273, 2832),
	(319, 1, 1, 320, 2833),
	(323, 355, 1, 322, 2659),
	(351, 2, 1, 352, 2814),
	(351, 1, 1, 352, 2815),
	(351, 4, 1, 352, 2816),
	(351, 3, 1, 352, 2817),
	(355, 8871, 1, 354, 3288),
	(357, 1, 1, 356, 2834),
	(357, 2, 1, 356, 2835),
	(357, 3, 1, 356, 2836),
	(357, 4, 1, 356, 2837),
	(368, 1, 1, 369, 2838),
	(383, 65, 1, 382, 2839),
	(383, 66, 1, 382, 2840),
	(383, 67, 1, 382, 2841),
	(383, 68, 1, 382, 2842),
	(383, 69, 1, 382, 2843),
	(383, 70, 1, 382, 2844),
	(383, 71, 1, 382, 2845),
	(383, 72, 1, 382, 2846),
	(383, 73, 1, 382, 2847),
	(387, 1, 1, 386, 2799),
	(387, 7, 1, 386, 2848),
	(392, 0, 1, 393, 2849),
	(392, 1, 1, 393, 2850),
	(392, 2, 1, 393, 2851),
	(392, 5, 1, 393, 2852),
	(392, 6, 1, 393, 2853),
	(392, 7, 1, 393, 2854),
	(392, 8, 1, 393, 2855),
	(392, 11, 1, 393, 2856),
	(406, 2, 1, 405, 3289),
	(410, 457, 2, 413, 2857),
	(410, 593, 2, 413, 2857),
	(415, 1, 1, 416, 2858),
	(415, 2, 1, 416, 2859),
	(415, 3, 1, 416, 2860),
	(415, 4, 1, 416, 2861),
	(415, 5, 1, 416, 2862),
	(415, 6, 1, 416, 2863),
	(415, 7, 1, 416, 2864),
	(415, 11, 1, 416, 2865),
	(442, 1, 1, 428, 2866),
	(448, 1, 1, 447, 2825),
	(448, 41, 1, 447, 2867),
	(448, 61, 1, 447, 2868),
	(448, 91, 1, 447, 2869),
	(448, 92, 1, 447, 2870),
	(448, 93, 1, 447, 2871),
	(448, 94, 1, 447, 2872),
	(448, 127, 1, 447, 2873),
	(454, 86, 1, 453, 934),
	(454, 47, 1, 453, 2874),
	(454, 72, 1, 453, 2875),
	(454, 73, 1, 453, 2876),
	(454, 74, 1, 453, 2877),
	(454, 85, 1, 453, 2878),
	(462, 1, 1, 461, 2799),
	(475, 49, 1, 474, 1009),
	(475, 46, 1, 474, 2879),
	(475, 47, 1, 474, 2880),
	(475, 48, 1, 474, 2881),
	(475, 50, 1, 474, 2882),
	(475, 51, 1, 474, 2883),
	(475, 52, 1, 474, 2884),
	(480, 1, 1, 482, 124),
	(480, 6, 1, 482, 2885),
	(480, 21, 1, 482, 2886),
	(480, 22, 1, 482, 2887),
	(480, 16, 1, 482, 2888),
	(480, 11, 1, 482, 2889),
	(486, 1, 1, 485, 3291),
	(488, 1, 1, 490, 124),
	(488, 24, 1, 490, 157),
	(488, 6, 1, 490, 2885),
	(488, 41, 1, 490, 2886),
	(488, 42, 1, 490, 2887),
	(488, 16, 1, 490, 2888),
	(488, 14, 1, 490, 2889),
	(488, 11, 1, 490, 2890),
	(488, 12, 1, 490, 2891),
	(488, 13, 1, 490, 2892),
	(488, 17, 1, 490, 2893),
	(488, 18, 1, 490, 2894),
	(488, 19, 1, 490, 2895),
	(488, 20, 1, 490, 2896),
	(488, 21, 1, 490, 2897),
	(488, 22, 1, 490, 2898),
	(488, 23, 1, 490, 2899),
	(488, 25, 1, 490, 2900),
	(488, 26, 1, 490, 2901),
	(488, 27, 1, 490, 2902),
	(488, 28, 1, 490, 2903),
	(488, 29, 1, 490, 2904),
	(488, 30, 1, 490, 2905),
	(488, 31, 1, 490, 2906),
	(488, 32, 1, 490, 2907),
	(488, 33, 1, 490, 2908),
	(488, 34, 1, 490, 2909),
	(488, 35, 1, 490, 2910),
	(488, 36, 1, 490, 2911),
	(488, 46, 1, 490, 2912),
	(488, 51, 1, 490, 2913),
	(488, 52, 1, 490, 2914),
	(488, 53, 1, 490, 2915),
	(488, 54, 1, 490, 2916),
	(488, 55, 1, 490, 2917),
	(488, 56, 1, 490, 2918),
	(488, 57, 1, 490, 2919),
	(488, 58, 1, 490, 2920),
	(488, 59, 1, 490, 2921),
	(488, 60, 1, 490, 2922),
	(488, 61, 1, 490, 2923),
	(488, 62, 1, 490, 2924),
	(488, 63, 1, 490, 3290),
	(492, 1, 1, 491, 198),
	(506, 24, 1, 508, 157),
	(506, 41, 1, 508, 2886),
	(506, 42, 1, 508, 2887),
	(506, 16, 1, 508, 2888),
	(506, 17, 1, 508, 2893),
	(506, 18, 1, 508, 2894),
	(506, 19, 1, 508, 2895),
	(506, 20, 1, 508, 2896),
	(506, 21, 1, 508, 2897),
	(506, 22, 1, 508, 2898),
	(506, 23, 1, 508, 2899),
	(506, 25, 1, 508, 2900),
	(506, 26, 1, 508, 2901),
	(506, 29, 1, 508, 2904),
	(506, 30, 1, 508, 2905),
	(506, 31, 1, 508, 2906),
	(506, 32, 1, 508, 2907),
	(506, 33, 1, 508, 2908),
	(506, 34, 1, 508, 2909),
	(506, 46, 1, 508, 2909),
	(506, 51, 1, 508, 2909),
	(506, 52, 1, 508, 2909),
	(506, 53, 1, 508, 2909),
	(506, 54, 1, 508, 2909),
	(506, 55, 1, 508, 2909),
	(506, 56, 1, 508, 2909),
	(506, 57, 1, 508, 2909),
	(506, 58, 1, 508, 2909),
	(506, 59, 1, 508, 2909),
	(506, 60, 1, 508, 2909),
	(506, 61, 1, 508, 2909),
	(506, 62, 1, 508, 2909),
	(506, 63, 1, 508, 2909),
	(506, 35, 1, 508, 2910),
	(506, 36, 1, 508, 2911),
	(506, 1, 1, 508, 2925),
	(506, 6, 1, 508, 2926),
	(506, 11, 1, 508, 2927),
	(506, 12, 1, 508, 2928),
	(506, 13, 1, 508, 2929),
	(506, 14, 1, 508, 2930),
	(506, 27, 1, 508, 2931),
	(506, 28, 1, 508, 2932),
	(516, 6, 1, 517, 2885),
	(516, 11, 1, 517, 2888),
	(516, 1, 1, 517, 2933),
	(516, 12, 1, 517, 2934),
	(516, 13, 1, 517, 2935),
	(516, 16, 1, 517, 2936),
	(520, 1, 1, 519, 2937),
	(582, 22, 1, 587, 2938),
	(582, 42, 1, 587, 2939),
	(582, 43, 1, 587, 2940),
	(582, 44, 1, 587, 2941),
	(582, 62, 1, 587, 2942),
	(582, 103, 1, 587, 2943),
	(582, 167, 1, 587, 2944),
	(582, 238, 1, 587, 2945),
	(582, 303, 1, 587, 2946),
	(582, 310, 1, 587, 2947),
	(636, 2, 1, 635, 199),
	(636, 1, 1, 635, 200),
	(636, 9, 1, 635, 296),
	(636, 10, 1, 635, 2998),
	(636, 4, 1, 635, 3246),
	(636, 11, 1, 635, 3300),
	(642, 525, 4, 644, 319),
	(642, 526, 4, 644, 320),
	(642, 527, 4, 644, 321),
	(642, 565, 4, 644, 323),
	(642, 779, 4, 644, 324),
	(642, 942, 4, 644, 325),
	(642, 833, 4, 644, 326),
	(642, 834, 4, 644, 327),
	(642, 835, 4, 644, 328),
	(642, 937, 4, 644, 330),
	(642, 544, 4, 644, 331),
	(642, 545, 4, 644, 332),
	(642, 1056, 4, 644, 333),
	(642, 622, 4, 644, 334),
	(642, 623, 4, 644, 335),
	(642, 667, 4, 644, 336),
	(642, 668, 4, 644, 337),
	(642, 702, 4, 644, 338),
	(642, 703, 4, 644, 339),
	(642, 704, 4, 644, 340),
	(642, 705, 4, 644, 341),
	(642, 706, 4, 644, 342),
	(642, 736, 4, 644, 343),
	(642, 782, 4, 644, 344),
	(642, 783, 4, 644, 345),
	(642, 784, 4, 644, 346),
	(642, 842, 4, 644, 348),
	(642, 912, 4, 644, 349),
	(642, 1002, 4, 644, 350),
	(642, 1003, 4, 644, 351),
	(642, 1004, 4, 644, 352),
	(642, 1005, 4, 644, 353),
	(642, 1006, 4, 644, 354),
	(642, 1007, 4, 644, 355),
	(642, 652, 4, 644, 356),
	(642, 653, 4, 644, 357),
	(642, 493, 4, 644, 358),
	(642, 467, 4, 644, 359),
	(642, 468, 4, 644, 360),
	(642, 1008, 4, 644, 361),
	(642, 470, 4, 644, 362),
	(642, 471, 4, 644, 363),
	(642, 489, 4, 644, 365),
	(642, 490, 4, 644, 366),
	(642, 473, 4, 644, 369),
	(642, 472, 4, 644, 370),
	(642, 482, 4, 644, 371),
	(642, 483, 4, 644, 372),
	(642, 484, 4, 644, 373),
	(642, 485, 4, 644, 374),
	(642, 481, 4, 644, 375),
	(642, 486, 4, 644, 376),
	(642, 487, 4, 644, 377),
	(642, 488, 4, 644, 378),
	(642, 474, 4, 644, 379),
	(642, 479, 4, 644, 380),
	(642, 480, 4, 644, 381),
	(642, 478, 4, 644, 382),
	(642, 475, 4, 644, 383),
	(642, 476, 4, 644, 384),
	(642, 477, 4, 644, 385),
	(642, 654, 4, 644, 386),
	(642, 1037, 4, 644, 387),
	(642, 522, 4, 644, 388),
	(642, 523, 4, 644, 389),
	(642, 524, 4, 644, 390),
	(642, 777, 4, 644, 393),
	(642, 778, 4, 644, 394),
	(642, 1038, 4, 644, 396),
	(642, 627, 4, 644, 397),
	(642, 628, 4, 644, 398),
	(642, 626, 4, 644, 399),
	(642, 629, 4, 644, 400),
	(642, 712, 4, 644, 401),
	(642, 713, 4, 644, 402),
	(642, 735, 4, 644, 403),
	(642, 758, 4, 644, 415),
	(642, 759, 4, 644, 416),
	(642, 760, 4, 644, 417),
	(642, 761, 4, 644, 418),
	(642, 762, 4, 644, 419),
	(642, 763, 4, 644, 420),
	(642, 764, 4, 644, 421),
	(642, 766, 4, 644, 422),
	(642, 767, 4, 644, 423),
	(642, 768, 4, 644, 424),
	(642, 769, 4, 644, 425),
	(642, 770, 4, 644, 426),
	(642, 771, 4, 644, 427),
	(642, 772, 4, 644, 428),
	(642, 1039, 4, 644, 429),
	(642, 732, 4, 644, 430),
	(642, 733, 4, 644, 431),
	(642, 734, 4, 644, 432),
	(642, 962, 4, 644, 433),
	(642, 963, 4, 644, 434),
	(642, 964, 4, 644, 435),
	(642, 1036, 4, 644, 436),
	(642, 1040, 4, 644, 437),
	(642, 1041, 4, 644, 438),
	(642, 1042, 4, 644, 439),
	(642, 1043, 4, 644, 440),
	(642, 1044, 4, 644, 441),
	(642, 1045, 4, 644, 442),
	(642, 1021, 4, 644, 444),
	(642, 1022, 4, 644, 445),
	(642, 1023, 4, 644, 446),
	(642, 1024, 4, 644, 447),
	(642, 1025, 4, 644, 448),
	(642, 1026, 4, 644, 449),
	(642, 1027, 4, 644, 450),
	(642, 1028, 4, 644, 451),
	(642, 1029, 4, 644, 452),
	(642, 1030, 4, 644, 453),
	(642, 1031, 4, 644, 454),
	(642, 1032, 4, 644, 455),
	(642, 1033, 4, 644, 456),
	(642, 1034, 4, 644, 457),
	(642, 1035, 4, 644, 458),
	(642, 1017, 4, 644, 459),
	(642, 1018, 4, 644, 460),
	(642, 1019, 4, 644, 461),
	(642, 1020, 4, 644, 462),
	(642, 1012, 4, 644, 463),
	(642, 1013, 4, 644, 464),
	(642, 1014, 4, 644, 465),
	(642, 1051, 4, 644, 466),
	(642, 1052, 4, 644, 467),
	(642, 1053, 4, 644, 468),
	(642, 1074, 4, 644, 475),
	(642, 1075, 4, 644, 476),
	(642, 1076, 4, 644, 477),
	(642, 1077, 4, 644, 478),
	(642, 1078, 4, 644, 479),
	(642, 1079, 4, 644, 480),
	(642, 1080, 4, 644, 481),
	(642, 1091, 4, 644, 482),
	(642, 1092, 4, 644, 483),
	(642, 1093, 4, 644, 484),
	(642, 1094, 4, 644, 485),
	(642, 1095, 4, 644, 486),
	(642, 1096, 4, 644, 487),
	(642, 1097, 4, 644, 488),
	(642, 1098, 4, 644, 489),
	(642, 1099, 4, 644, 490),
	(642, 1100, 4, 644, 491),
	(642, 1101, 4, 644, 492),
	(642, 1102, 4, 644, 493),
	(642, 1103, 4, 644, 494),
	(642, 1104, 4, 644, 495),
	(642, 1105, 4, 644, 496),
	(642, 1106, 4, 644, 497),
	(642, 1107, 4, 644, 498),
	(642, 1108, 4, 644, 499),
	(642, 1109, 4, 644, 500),
	(642, 1110, 4, 644, 501),
	(642, 1111, 4, 644, 502),
	(642, 1112, 4, 644, 503),
	(642, 1113, 4, 644, 504),
	(642, 1114, 4, 644, 505),
	(642, 1115, 4, 644, 506),
	(642, 1116, 4, 644, 507),
	(642, 1117, 4, 644, 508),
	(642, 1118, 4, 644, 509),
	(642, 1119, 4, 644, 510),
	(642, 1120, 4, 644, 511),
	(642, 1121, 4, 644, 512),
	(642, 1122, 4, 644, 513),
	(642, 1123, 4, 644, 514),
	(642, 1124, 4, 644, 515),
	(642, 1125, 4, 644, 516),
	(642, 1126, 4, 644, 517),
	(642, 1134, 4, 644, 518),
	(642, 1135, 4, 644, 519),
	(642, 1136, 4, 644, 520),
	(642, 1137, 4, 644, 521),
	(642, 1228, 4, 644, 522),
	(642, 1229, 4, 644, 523),
	(642, 1230, 4, 644, 524),
	(642, 1231, 4, 644, 525),
	(642, 1232, 4, 644, 526),
	(642, 1233, 4, 644, 527),
	(642, 1234, 4, 644, 528),
	(642, 1046, 4, 644, 529),
	(642, 1047, 4, 644, 530),
	(642, 1048, 4, 644, 531),
	(642, 1049, 4, 644, 532),
	(642, 1236, 4, 644, 534),
	(642, 1061, 4, 644, 537),
	(642, 1062, 4, 644, 538),
	(642, 1063, 4, 644, 539),
	(642, 1064, 4, 644, 540),
	(642, 1065, 4, 644, 541),
	(642, 1066, 4, 644, 542),
	(642, 1067, 4, 644, 543),
	(642, 1068, 4, 644, 544),
	(642, 1069, 4, 644, 545),
	(642, 1070, 4, 644, 546),
	(642, 1071, 4, 644, 547),
	(642, 1072, 4, 644, 548),
	(642, 1073, 4, 644, 549),
	(642, 1081, 4, 644, 556),
	(642, 1082, 4, 644, 557),
	(642, 1083, 4, 644, 558),
	(642, 1084, 4, 644, 559),
	(642, 1085, 4, 644, 560),
	(642, 1086, 4, 644, 561),
	(642, 1087, 4, 644, 562),
	(642, 1088, 4, 644, 563),
	(642, 1131, 4, 644, 564),
	(642, 1132, 4, 644, 565),
	(642, 1133, 4, 644, 566),
	(642, 1138, 4, 644, 568),
	(642, 1139, 4, 644, 569),
	(642, 1140, 4, 644, 570),
	(642, 1141, 4, 644, 571),
	(642, 1142, 4, 644, 572),
	(642, 1143, 4, 644, 573),
	(642, 1144, 4, 644, 574),
	(642, 1145, 4, 644, 575),
	(642, 1146, 4, 644, 576),
	(642, 1147, 4, 644, 577),
	(642, 1148, 4, 644, 578),
	(642, 1149, 4, 644, 579),
	(642, 1150, 4, 644, 580),
	(642, 1151, 4, 644, 581),
	(642, 1152, 4, 644, 582),
	(642, 1153, 4, 644, 583),
	(642, 1154, 4, 644, 584),
	(642, 1155, 4, 644, 585),
	(642, 1156, 4, 644, 586),
	(642, 1157, 4, 644, 587),
	(642, 1235, 4, 644, 588),
	(642, 1237, 4, 644, 589),
	(642, 1238, 4, 644, 590),
	(642, 1239, 4, 644, 591),
	(642, 1240, 4, 644, 592),
	(642, 1158, 4, 644, 594),
	(642, 1159, 4, 644, 595),
	(642, 1160, 4, 644, 596),
	(642, 1161, 4, 644, 597),
	(642, 1162, 4, 644, 598),
	(642, 1163, 4, 644, 599),
	(642, 1164, 4, 644, 600),
	(642, 1165, 4, 644, 601),
	(642, 1166, 4, 644, 602),
	(642, 1167, 4, 644, 603),
	(642, 1168, 4, 644, 604),
	(642, 1169, 4, 644, 605),
	(642, 1170, 4, 644, 606),
	(642, 1171, 4, 644, 607),
	(642, 1172, 4, 644, 608),
	(642, 1173, 4, 644, 609),
	(642, 1174, 4, 644, 610),
	(642, 1175, 4, 644, 611),
	(642, 1176, 4, 644, 612),
	(642, 1177, 4, 644, 613),
	(642, 1178, 4, 644, 614),
	(642, 1179, 4, 644, 615),
	(642, 1180, 4, 644, 616),
	(642, 1181, 4, 644, 617),
	(642, 1183, 4, 644, 619),
	(642, 1184, 4, 644, 620),
	(642, 1185, 4, 644, 621),
	(642, 1186, 4, 644, 622),
	(642, 1187, 4, 644, 623),
	(642, 1188, 4, 644, 624),
	(642, 1189, 4, 644, 625),
	(642, 1190, 4, 644, 626),
	(642, 1191, 4, 644, 627),
	(642, 1192, 4, 644, 628),
	(642, 1193, 4, 644, 629),
	(642, 1194, 4, 644, 630),
	(642, 1195, 4, 644, 631),
	(642, 1196, 4, 644, 632),
	(642, 1197, 4, 644, 633),
	(642, 1198, 4, 644, 634),
	(642, 1199, 4, 644, 635),
	(642, 1200, 4, 644, 636),
	(642, 1201, 4, 644, 637),
	(642, 1202, 4, 644, 638),
	(642, 1203, 4, 644, 639),
	(642, 1204, 4, 644, 640),
	(642, 1205, 4, 644, 641),
	(642, 1206, 4, 644, 642),
	(642, 1207, 4, 644, 643),
	(642, 1208, 4, 644, 644),
	(642, 1209, 4, 644, 645),
	(642, 1210, 4, 644, 646),
	(642, 1211, 4, 644, 647),
	(642, 1212, 4, 644, 648),
	(642, 1213, 4, 644, 649),
	(642, 1214, 4, 644, 650),
	(642, 1215, 4, 644, 651),
	(642, 1216, 4, 644, 652),
	(642, 1217, 4, 644, 653),
	(642, 1218, 4, 644, 654),
	(642, 1219, 4, 644, 655),
	(642, 1220, 4, 644, 656),
	(642, 1221, 4, 644, 657),
	(642, 1222, 4, 644, 658),
	(642, 1223, 4, 644, 659),
	(642, 1224, 4, 644, 660),
	(642, 1225, 4, 644, 661),
	(642, 1226, 4, 644, 662),
	(642, 1227, 4, 644, 663),
	(642, 1301, 4, 644, 664),
	(642, 1302, 4, 644, 665),
	(642, 1303, 4, 644, 666),
	(642, 1304, 4, 644, 667),
	(642, 1305, 4, 644, 668),
	(642, 1306, 4, 644, 669),
	(642, 1307, 4, 644, 670),
	(642, 1308, 4, 644, 671),
	(642, 1309, 4, 644, 672),
	(642, 1310, 4, 644, 673),
	(642, 1311, 4, 644, 674),
	(642, 1312, 4, 644, 675),
	(642, 1313, 4, 644, 676),
	(642, 1314, 4, 644, 677),
	(642, 1315, 4, 644, 678),
	(642, 1316, 4, 644, 679),
	(642, 1317, 4, 644, 680),
	(642, 1318, 4, 644, 681),
	(642, 1319, 4, 644, 682),
	(642, 1320, 4, 644, 683),
	(642, 1321, 4, 644, 684),
	(642, 1322, 4, 644, 685),
	(642, 1323, 4, 644, 686),
	(642, 1324, 4, 644, 687),
	(642, 1325, 4, 644, 688),
	(642, 1326, 4, 644, 689),
	(642, 1327, 4, 644, 690),
	(642, 1328, 4, 644, 691),
	(642, 1329, 4, 644, 692),
	(642, 1330, 4, 644, 693),
	(642, 1331, 4, 644, 694),
	(642, 1332, 4, 644, 695),
	(642, 1333, 4, 644, 696),
	(642, 1334, 4, 644, 697),
	(642, 1335, 4, 644, 698),
	(642, 1336, 4, 644, 699),
	(642, 1337, 4, 644, 700),
	(642, 1338, 4, 644, 701),
	(642, 1339, 4, 644, 702),
	(642, 1340, 4, 644, 703),
	(642, 1341, 4, 644, 704),
	(642, 1342, 4, 644, 705),
	(642, 1343, 4, 644, 706),
	(642, 1344, 4, 644, 707),
	(642, 1345, 4, 644, 708),
	(642, 1346, 4, 644, 709),
	(642, 1347, 4, 644, 710),
	(642, 1348, 4, 644, 711),
	(642, 1349, 4, 644, 712),
	(642, 1350, 4, 644, 713),
	(642, 1351, 4, 644, 714),
	(642, 1352, 4, 644, 715),
	(642, 1353, 4, 644, 716),
	(642, 1354, 4, 644, 717),
	(642, 1355, 4, 644, 718),
	(642, 1356, 4, 644, 719),
	(642, 1357, 4, 644, 720),
	(642, 1373, 4, 644, 722),
	(642, 1374, 4, 644, 723),
	(642, 1375, 4, 644, 724),
	(642, 1376, 4, 644, 725),
	(642, 1377, 4, 644, 726),
	(642, 1378, 4, 644, 727),
	(642, 1379, 4, 644, 728),
	(642, 1380, 4, 644, 729),
	(642, 1381, 4, 644, 730),
	(642, 1382, 4, 644, 731),
	(642, 1383, 4, 644, 732),
	(642, 1368, 4, 644, 749),
	(642, 1388, 4, 644, 752),
	(642, 1389, 4, 644, 753),
	(642, 1358, 4, 644, 763),
	(642, 1359, 4, 644, 764),
	(642, 1360, 4, 644, 765),
	(642, 1361, 4, 644, 766),
	(642, 1362, 4, 644, 767),
	(642, 1363, 4, 644, 768),
	(642, 1364, 4, 644, 769),
	(642, 1365, 4, 644, 770),
	(642, 1366, 4, 644, 771),
	(642, 1384, 4, 644, 777),
	(642, 1393, 4, 644, 778),
	(642, 1394, 4, 644, 781),
	(642, 1413, 4, 644, 792),
	(642, 1414, 4, 644, 793),
	(642, 1395, 4, 644, 802),
	(642, 1396, 4, 644, 803),
	(642, 1397, 4, 644, 804),
	(642, 1398, 4, 644, 805),
	(642, 1399, 4, 644, 806),
	(642, 1400, 4, 644, 807),
	(642, 1401, 4, 644, 808),
	(642, 1402, 4, 644, 809),
	(642, 1403, 4, 644, 810),
	(642, 1404, 4, 644, 811),
	(642, 1405, 4, 644, 812),
	(642, 1406, 4, 644, 813),
	(642, 1407, 4, 644, 814),
	(642, 1408, 4, 644, 815),
	(642, 1409, 4, 644, 816),
	(642, 1410, 4, 644, 817),
	(642, 1241, 4, 644, 821),
	(642, 1242, 4, 644, 822),
	(642, 1243, 4, 644, 823),
	(642, 1244, 4, 644, 824),
	(642, 1245, 4, 644, 825),
	(642, 1246, 4, 644, 826),
	(642, 1247, 4, 644, 827),
	(642, 1248, 4, 644, 828),
	(642, 1249, 4, 644, 829),
	(642, 1250, 4, 644, 830),
	(642, 1251, 4, 644, 831),
	(642, 1252, 4, 644, 832),
	(642, 1253, 4, 644, 833),
	(642, 1254, 4, 644, 834),
	(642, 1255, 4, 644, 835),
	(642, 1256, 4, 644, 836),
	(642, 1257, 4, 644, 837),
	(642, 1258, 4, 644, 838),
	(642, 1259, 4, 644, 839),
	(642, 1260, 4, 644, 840),
	(642, 1261, 4, 644, 841),
	(642, 1262, 4, 644, 842),
	(642, 1263, 4, 644, 843),
	(642, 1264, 4, 644, 844),
	(642, 1265, 4, 644, 845),
	(642, 1266, 4, 644, 846),
	(642, 1267, 4, 644, 847),
	(642, 1268, 4, 644, 848),
	(642, 1269, 4, 644, 849),
	(642, 1270, 4, 644, 850),
	(642, 1271, 4, 644, 851),
	(642, 1272, 4, 644, 852),
	(642, 1273, 4, 644, 853),
	(642, 1274, 4, 644, 854),
	(642, 1275, 4, 644, 855),
	(642, 1276, 4, 644, 856),
	(642, 1277, 4, 644, 857),
	(642, 1278, 4, 644, 858),
	(642, 1279, 4, 644, 859),
	(642, 1280, 4, 644, 860),
	(642, 1281, 4, 644, 861),
	(642, 1282, 4, 644, 862),
	(642, 1283, 4, 644, 863),
	(642, 1284, 4, 644, 864),
	(642, 1285, 4, 644, 865),
	(642, 1286, 4, 644, 866),
	(642, 1287, 4, 644, 867),
	(642, 1288, 4, 644, 868),
	(642, 1289, 4, 644, 869),
	(642, 1290, 4, 644, 870),
	(642, 1291, 4, 644, 871),
	(642, 1292, 4, 644, 872),
	(642, 1293, 4, 644, 873),
	(642, 1294, 4, 644, 874),
	(642, 1295, 4, 644, 875),
	(642, 1296, 4, 644, 876),
	(642, 1297, 4, 644, 877),
	(642, 1298, 4, 644, 878),
	(642, 1299, 4, 644, 879),
	(642, 1300, 4, 644, 880),
	(642, 994, 4, 644, 2948),
	(642, 491, 4, 644, 2949),
	(642, 492, 4, 644, 2950),
	(651, 161, 1, 650, 2814),
	(651, 141, 1, 650, 2817),
	(675, 8, 1, 676, 2951),
	(675, 61, 1, 676, 2952),
	(690, 6, 1, 689, 2953),
	(690, 7, 1, 689, 2954),
	(690, 8, 1, 689, 2955),
	(690, 9, 1, 689, 2956);
/*!40000 ALTER TABLE `cold_data` ENABLE KEYS */;

-- Dumping structure for table emcor.col_alias
CREATE TABLE IF NOT EXISTS `col_alias` (
  `col_alias_id` mediumint(8) unsigned NOT NULL COMMENT 'Lauko-pseudonimo identifikatorius',
  `col_id` mediumint(8) unsigned NOT NULL COMMENT 'Lauko identifikatorius',
  PRIMARY KEY (`col_alias_id`),
  KEY `col_alias_col_i` (`col_id`),
  CONSTRAINT `col_alias_alias_fk` FOREIGN KEY (`col_alias_id`) REFERENCES `col` (`col_id`),
  CONSTRAINT `col_alias_col_fk` FOREIGN KEY (`col_id`) REFERENCES `col` (`col_id`),
  CONSTRAINT `COL_ALIAS_NOT_SAME_CHK` CHECK (`col_alias_id` <> `col_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Laukų pseudonimai';

-- Dumping data for table emcor.col_alias: ~45 rows (approximately)
/*!40000 ALTER TABLE `col_alias` DISABLE KEYS */;
INSERT INTO `col_alias` (`col_alias_id`, `col_id`) VALUES
	(80, 122),
	(86, 122),
	(264, 122),
	(440, 122),
	(81, 160),
	(87, 160),
	(265, 160),
	(620, 160),
	(658, 160),
	(655, 196),
	(623, 244),
	(660, 244),
	(82, 266),
	(88, 266),
	(84, 274),
	(90, 274),
	(347, 346),
	(625, 355),
	(662, 355),
	(83, 391),
	(89, 391),
	(267, 391),
	(445, 391),
	(626, 394),
	(643, 394),
	(16, 406),
	(18, 406),
	(60, 406),
	(338, 406),
	(540, 406),
	(547, 406),
	(551, 406),
	(553, 406),
	(556, 406),
	(575, 406),
	(578, 406),
	(598, 406),
	(600, 406),
	(576, 419),
	(56, 442),
	(627, 548),
	(544, 582),
	(580, 651),
	(168, 665),
	(220, 665);
/*!40000 ALTER TABLE `col_alias` ENABLE KEYS */;

-- Dumping structure for table emcor.costa
CREATE TABLE IF NOT EXISTS `costa` (
  `costa_id` tinyint(3) unsigned NOT NULL COMMENT 'Ryšio būsenos ID',
  `costa_code` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Ryšio būsenos kodas',
  `costa_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ryšio būsenos pavadinimas',
  PRIMARY KEY (`costa_id`),
  UNIQUE KEY `costa_code_u` (`costa_code`),
  UNIQUE KEY `costa_name_u` (`costa_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ryšio būsenos';

-- Dumping data for table emcor.costa: ~2 rows (approximately)
/*!40000 ALTER TABLE `costa` DISABLE KEYS */;
INSERT INTO `costa` (`costa_id`, `costa_code`, `costa_name`) VALUES
	(1, 'CONNECTION_OK', 'Ryšys yra'),
	(2, 'CONNECTION_FAILED', 'Ryšio nėra');
/*!40000 ALTER TABLE `costa` ENABLE KEYS */;

-- Dumping structure for table emcor.cp
CREATE TABLE IF NOT EXISTS `cp` (
  `per_id` tinyint(3) unsigned NOT NULL COMMENT 'Periodo identifikatorius',
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `cp_t` date NOT NULL COMMENT 'Uždaromo periodo pradžios data',
  `cp_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Periodo uždarymo požymis',
  `cp_note_code` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'Rodmenų uždarymo verifikavimo rezultato kodas. Nuoroda į CP_NOTE.CODE.',
  PRIMARY KEY (`per_id`,`point_id`,`cp_t`),
  KEY `cp_cp_t_i` (`cp_t`),
  KEY `cp_point_i` (`point_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Uždaromi periodai'
 PARTITION BY RANGE (
    to_days(cp_t))
(PARTITION par_201701 VALUES LESS THAN (736726) ENGINE = InnoDB,
 PARTITION par_201702 VALUES LESS THAN (736754) ENGINE = InnoDB,
 PARTITION par_201703 VALUES LESS THAN (736785) ENGINE = InnoDB,
 PARTITION par_201704 VALUES LESS THAN (736815) ENGINE = InnoDB,
 PARTITION par_201705 VALUES LESS THAN (736846) ENGINE = InnoDB);

-- Dumping data for table emcor.cp: ~5 rows (approximately)
/*!40000 ALTER TABLE `cp` DISABLE KEYS */;
/*!40000 ALTER TABLE `cp` ENABLE KEYS */;

-- Dumping structure for table emcor.cp_data
CREATE TABLE IF NOT EXISTS `cp_data` (
  `cpd_id` int(10) unsigned NOT NULL COMMENT 'Matavimo rezultatų verifikavimo identifikatorius',
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `ms_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimo identifikatorius',
  `dir_id` tinyint(4) NOT NULL COMMENT 'Krypties identifikatorius',
  `md_id` tinyint(3) unsigned NOT NULL COMMENT 'Matavimo diskretiškumo identifikatorius',
  `per_id` tinyint(3) unsigned NOT NULL COMMENT 'Periodo identifikatorius',
  `cp_t` date NOT NULL COMMENT 'Uždaromo periodo pradžios data',
  `pl_t` datetime NOT NULL COMMENT 'Matavimo linijos matavimo taške duomenų laikas',
  `vp_id` int(10) unsigned DEFAULT NULL COMMENT 'Verifikacijos profilio identifikatorius',
  `vp_tff_flag` varchar(8) COLLATE utf8_bin DEFAULT NULL COMMENT 'Palyginimo pagal tarifus taisyklė: S- lyginama tarifų suma 0- betarifė suma 1234- pagal konkretų tarifą.',
  `aggs_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  `target_val` double DEFAULT NULL COMMENT 'Paskirties rodiklio reikšmė sulyginimo metu',
  `source_val` double DEFAULT NULL COMMENT 'Palyginamojo agregavimo segmento rodiklio reikšmė',
  `db_time` datetime DEFAULT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `cp_note_code` varchar(10) COLLATE utf8_bin DEFAULT NULL COMMENT 'Rodmenų uždarymo verifikavimo rezultato kodas. Nuoroda į CP_NOTE.CODE.',
  `ml_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Matavimo linijos identifikatorius',
  `verge_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Kraštinės ID',
  `sf_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Statuso požymio ID',
  `fp_flag` tinyint(1) DEFAULT NULL,
  KEY `cp_data_cpd_i` (`cpd_id`),
  KEY `cp_data_indx$tmp` (`point_id`),
  KEY `cp_data_ui` (`per_id`,`point_id`,`cp_t`),
  KEY `cp_data_verge_i` (`verge_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Rodmenų uždarymo verifikavimo rezultatų lentelė.'
 PARTITION BY RANGE (
    to_days(cp_t))
(PARTITION par_201701 VALUES LESS THAN (736726) ENGINE = InnoDB,
 PARTITION par_201702 VALUES LESS THAN (736754) ENGINE = InnoDB,
 PARTITION par_201703 VALUES LESS THAN (736785) ENGINE = InnoDB,
 PARTITION par_201704 VALUES LESS THAN (736815) ENGINE = InnoDB,
 PARTITION par_201705 VALUES LESS THAN (736846) ENGINE = InnoDB);

-- Dumping data for table emcor.cp_data: ~5 rows (approximately)
/*!40000 ALTER TABLE `cp_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `cp_data` ENABLE KEYS */;

-- Dumping structure for table emcor.cp_note
CREATE TABLE IF NOT EXISTS `cp_note` (
  `code` varchar(2) COLLATE utf8_bin DEFAULT NULL COMMENT 'Kodas',
  `note` varchar(2000) COLLATE utf8_bin DEFAULT NULL COMMENT 'Rodmenų uždarymo verifikavimo rezultato aprašymas'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Rodmenų uždarymo verifikavimo rezultatas.';

-- Dumping data for table emcor.cp_note: ~21 rows (approximately)
/*!40000 ALTER TABLE `cp_note` DISABLE KEYS */;
INSERT INTO `cp_note` (`code`, `note`) VALUES
	('A', 'Neužpildytos visos palyginamų platesnių rodmenų reikšmės'),
	('B', 'Neužpildyta dalis palyginamų platesnių rodmenų reikšmių'),
	('C', 'Neuždarytas detalesnis palyginamas periodas'),
	('D', 'Neužpildytos visos palyginamų detalesnių rodmenų reikšmės'),
	('E', 'Neužpildyta dalis palyginamų detalesnių rodmenų reikšmių'),
	('F', 'Nesutampa palyginamų platesnių ir detalesnių rodmenų reikšmės'),
	('G', 'Pagal nurodytą užpildymo profilį nėra rodmenų reikšmių'),
	('N', 'Neatlikti visi numatyti monitoringo testai'),
	('P', 'Nesėkmingas monitoringo testas'),
	('Q', 'Aptiktas išimtinis duomenų statusas'),
	('R', 'Neuždarytos mėnesio paros'),
	('S', 'Suminė energijos prieaugis nesutampa su energija už periodą'),
	('T', 'Neužpildyti suminiai rodmenys'),
	('K', 'Suminės energijos rodmuo mažesnis, nei prieš tai buvęs'),
	('J', 'Betarifė suma nesutampa su bendra tarifų suma'),
	('I', 'Momentinis matavimas nepatenka į nuskaitomų duomenų elementų nuskaitytus periodus'),
	('O', 'Priverstinis periodo uždarymas'),
	('L0', 'Dalis palyginamų detalesnių duomenų turi negalutinį pagerinamų rodmenų statusą'),
	('L1', 'Dalis palyginamų platesnių duomenų turi negalutinį pagerinamų rodmenų statusą'),
	('M1', 'Daliai palyginamų platesnių duomenų yra nustatytas, bet neatliktas pakartotinis perrinkimas'),
	('M0', 'Daliai palyginamų detalesnių duomenų yra nustatytas, bet neatliktas pakartotinis perrinkimas');
/*!40000 ALTER TABLE `cp_note` ENABLE KEYS */;

-- Dumping structure for table emcor.cp_pl
CREATE TABLE IF NOT EXISTS `cp_pl` (
  `cpd_id` int(10) unsigned NOT NULL COMMENT 'Matavimo rezultatų verifikavimo identifikatorius',
  `pl_id` int(10) unsigned NOT NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
  `ts_id` tinyint(1) DEFAULT NULL COMMENT 'Paskirties požymis',
  KEY `cp_pl_cpd_id_i` (`cpd_id`),
  KEY `cp_pl_pl_id_i` (`pl_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Uždaromų periodų taškų matavimo linijų rinkiniai';

-- Dumping data for table emcor.cp_pl: ~0 rows (approximately)
/*!40000 ALTER TABLE `cp_pl` DISABLE KEYS */;
/*!40000 ALTER TABLE `cp_pl` ENABLE KEYS */;

-- Dumping structure for table emcor.das
CREATE TABLE IF NOT EXISTS `das` (
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  `das_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų surinkimo serverio pavadinimas',
  `das_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Duomenų surinkimo serverio naudojimo požymis',
  PRIMARY KEY (`das_id`),
  UNIQUE KEY `das_name_u` (`das_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų surinkimo serveriai';

-- Dumping data for table emcor.das: ~0 rows (approximately)
/*!40000 ALTER TABLE `das` DISABLE KEYS */;
/*!40000 ALTER TABLE `das` ENABLE KEYS */;

-- Dumping structure for table emcor.das_state
CREATE TABLE IF NOT EXISTS `das_state` (
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  `db_time` datetime NOT NULL DEFAULT '1899-12-30 00:00:00' COMMENT 'Registravimo duomenų bazėje laikas',
  PRIMARY KEY (`das_id`),
  CONSTRAINT `das_state_das_fk` FOREIGN KEY (`das_id`) REFERENCES `das` (`das_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų surinkimo serverių būsenos';

-- Dumping data for table emcor.das_state: ~0 rows (approximately)
/*!40000 ALTER TABLE `das_state` DISABLE KEYS */;
/*!40000 ALTER TABLE `das_state` ENABLE KEYS */;

-- Dumping structure for table emcor.days
CREATE TABLE IF NOT EXISTS `days` (
  `da` date NOT NULL COMMENT 'Diena',
  `mo` date NOT NULL COMMENT 'Mėnuo',
  PRIMARY KEY (`da`),
  KEY `days_mo_u` (`mo`,`da`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Dienos';

-- Dumping data for table emcor.days: ~21 760 rows (approximately)
/*!40000 ALTER TABLE `days` DISABLE KEYS */;
INSERT INTO `days` (`da`, `mo`) VALUES
	('2000-01-01', '2000-01-01'),
	('2000-01-02', '2000-01-01'),
	('2000-01-03', '2000-01-01'),
	('2000-01-04', '2000-01-01'),
	('2000-01-05', '2000-01-01'),
	('2000-01-06', '2000-01-01'),
	('2000-01-07', '2000-01-01'),
	('2000-01-08', '2000-01-01'),
	('2000-01-09', '2000-01-01'),
	('2000-01-10', '2000-01-01'),
	('2000-01-11', '2000-01-01'),
	('2000-01-12', '2000-01-01'),
	('2000-01-13', '2000-01-01'),
	('2000-01-14', '2000-01-01'),
	('2000-01-15', '2000-01-01'),
	('2000-01-16', '2000-01-01'),
	('2000-01-17', '2000-01-01'),
	('2000-01-18', '2000-01-01'),
	('2000-01-19', '2000-01-01'),
	('2000-01-20', '2000-01-01'),
	('2000-01-21', '2000-01-01'),
	('2000-01-22', '2000-01-01'),
	('2000-01-23', '2000-01-01'),
	('2000-01-24', '2000-01-01'),
	('2000-01-25', '2000-01-01'),
	('2000-01-26', '2000-01-01'),
	('2000-01-27', '2000-01-01'),
	('2000-01-28', '2000-01-01'),
	('2000-01-29', '2000-01-01'),
	('2000-01-30', '2000-01-01'),
	('2000-01-31', '2000-01-01'),
	('2000-02-01', '2000-02-01'),
	('2000-02-02', '2000-02-01'),
	('2000-02-03', '2000-02-01'),
	('2000-02-04', '2000-02-01'),
	('2000-02-05', '2000-02-01'),
	('2000-02-06', '2000-02-01'),
	('2000-02-07', '2000-02-01'),
	('2000-02-08', '2000-02-01'),
	('2000-02-09', '2000-02-01'),
	('2000-02-10', '2000-02-01'),
	('2000-02-11', '2000-02-01'),
	('2000-02-12', '2000-02-01'),
	('2000-02-13', '2000-02-01'),
	('2000-02-14', '2000-02-01'),
	('2000-02-15', '2000-02-01'),
	('2000-02-16', '2000-02-01'),
	('2000-02-17', '2000-02-01'),
	('2000-02-18', '2000-02-01'),
	('2000-02-19', '2000-02-01'),
	('2000-02-20', '2000-02-01'),
	('2000-02-21', '2000-02-01'),
	('2000-02-22', '2000-02-01'),
	('2000-02-23', '2000-02-01'),
	('2000-02-24', '2000-02-01'),
	('2000-02-25', '2000-02-01'),
	('2000-02-26', '2000-02-01'),
	('2000-02-27', '2000-02-01'),
	('2000-02-28', '2000-02-01'),
	('2000-02-29', '2000-02-01'),
	('2000-03-01', '2000-03-01'),
	('2000-03-02', '2000-03-01'),
	('2000-03-03', '2000-03-01'),
	('2000-03-04', '2000-03-01'),
	('2000-03-05', '2000-03-01'),
	('2000-03-06', '2000-03-01'),
	('2000-03-07', '2000-03-01'),
	('2000-03-08', '2000-03-01'),
	('2000-03-09', '2000-03-01'),
	('2000-03-10', '2000-03-01'),
	('2000-03-11', '2000-03-01'),
	('2000-03-12', '2000-03-01'),
	('2000-03-13', '2000-03-01'),
	('2000-03-14', '2000-03-01'),
	('2000-03-15', '2000-03-01'),
	('2000-03-16', '2000-03-01'),
	('2000-03-17', '2000-03-01'),
	('2000-03-18', '2000-03-01'),
	('2000-03-19', '2000-03-01'),
	('2000-03-20', '2000-03-01'),
	('2000-03-21', '2000-03-01'),
	('2000-03-22', '2000-03-01'),
	('2000-03-23', '2000-03-01'),
	('2000-03-24', '2000-03-01'),
	('2000-03-25', '2000-03-01'),
	('2000-03-26', '2000-03-01'),
	('2000-03-27', '2000-03-01'),
	('2000-03-28', '2000-03-01'),
	('2000-03-29', '2000-03-01'),
	('2000-03-30', '2000-03-01'),
	('2000-03-31', '2000-03-01'),
	('2000-04-01', '2000-04-01'),
	('2000-04-02', '2000-04-01'),
	('2000-04-03', '2000-04-01'),
	('2000-04-04', '2000-04-01'),
	('2000-04-05', '2000-04-01'),
	('2000-04-06', '2000-04-01'),
	('2000-04-07', '2000-04-01'),
	('2000-04-08', '2000-04-01'),
	('2000-04-09', '2000-04-01'),
	('2000-04-10', '2000-04-01'),
	('2000-04-11', '2000-04-01'),
	('2000-04-12', '2000-04-01'),
	('2000-04-13', '2000-04-01'),
	('2000-04-14', '2000-04-01'),
	('2000-04-15', '2000-04-01'),
	('2000-04-16', '2000-04-01'),
	('2000-04-17', '2000-04-01'),
	('2000-04-18', '2000-04-01'),
	('2000-04-19', '2000-04-01'),
	('2000-04-20', '2000-04-01'),
	('2000-04-21', '2000-04-01'),
	('2000-04-22', '2000-04-01'),
	('2000-04-23', '2000-04-01'),
	('2000-04-24', '2000-04-01'),
	('2000-04-25', '2000-04-01'),
	('2000-04-26', '2000-04-01'),
	('2000-04-27', '2000-04-01'),
	('2000-04-28', '2000-04-01'),
	('2000-04-29', '2000-04-01'),
	('2000-04-30', '2000-04-01'),
	('2000-05-01', '2000-05-01'),
	('2000-05-02', '2000-05-01'),
	('2000-05-03', '2000-05-01'),
	('2000-05-04', '2000-05-01'),
	('2000-05-05', '2000-05-01'),
	('2000-05-06', '2000-05-01'),
	('2000-05-07', '2000-05-01'),
	('2000-05-08', '2000-05-01'),
	('2000-05-09', '2000-05-01'),
	('2000-05-10', '2000-05-01'),
	('2000-05-11', '2000-05-01'),
	('2000-05-12', '2000-05-01'),
	('2000-05-13', '2000-05-01'),
	('2000-05-14', '2000-05-01'),
	('2000-05-15', '2000-05-01'),
	('2000-05-16', '2000-05-01'),
	('2000-05-17', '2000-05-01'),
	('2000-05-18', '2000-05-01'),
	('2000-05-19', '2000-05-01'),
	('2000-05-20', '2000-05-01'),
	('2000-05-21', '2000-05-01'),
	('2000-05-22', '2000-05-01'),
	('2000-05-23', '2000-05-01'),
	('2000-05-24', '2000-05-01'),
	('2000-05-25', '2000-05-01'),
	('2000-05-26', '2000-05-01'),
	('2000-05-27', '2000-05-01'),
	('2000-05-28', '2000-05-01'),
	('2000-05-29', '2000-05-01'),
	('2000-05-30', '2000-05-01'),
	('2000-05-31', '2000-05-01'),
	('2000-06-01', '2000-06-01'),
	('2000-06-02', '2000-06-01'),
	('2000-06-03', '2000-06-01'),
	('2000-06-04', '2000-06-01'),
	('2000-06-05', '2000-06-01'),
	('2000-06-06', '2000-06-01'),
	('2000-06-07', '2000-06-01'),
	('2000-06-08', '2000-06-01'),
	('2000-06-09', '2000-06-01'),
	('2000-06-10', '2000-06-01'),
	('2000-06-11', '2000-06-01'),
	('2000-06-12', '2000-06-01'),
	('2000-06-13', '2000-06-01'),
	('2000-06-14', '2000-06-01'),
	('2000-06-15', '2000-06-01'),
	('2000-06-16', '2000-06-01'),
	('2000-06-17', '2000-06-01'),
	('2000-06-18', '2000-06-01'),
	('2000-06-19', '2000-06-01'),
	('2000-06-20', '2000-06-01'),
	('2000-06-21', '2000-06-01'),
	('2000-06-22', '2000-06-01'),
	('2000-06-23', '2000-06-01'),
	('2000-06-24', '2000-06-01'),
	('2000-06-25', '2000-06-01'),
	('2000-06-26', '2000-06-01'),
	('2000-06-27', '2000-06-01'),
	('2000-06-28', '2000-06-01'),
	('2000-06-29', '2000-06-01'),
	('2000-06-30', '2000-06-01'),
	('2000-07-01', '2000-07-01'),
	('2000-07-02', '2000-07-01'),
	('2000-07-03', '2000-07-01'),
	('2000-07-04', '2000-07-01'),
	('2000-07-05', '2000-07-01'),
	('2000-07-06', '2000-07-01'),
	('2000-07-07', '2000-07-01'),
	('2000-07-08', '2000-07-01'),
	('2000-07-09', '2000-07-01'),
	('2000-07-10', '2000-07-01'),
	('2000-07-11', '2000-07-01'),
	('2000-07-12', '2000-07-01'),
	('2000-07-13', '2000-07-01'),
	('2000-07-14', '2000-07-01'),
	('2000-07-15', '2000-07-01'),
	('2000-07-16', '2000-07-01'),
	('2000-07-17', '2000-07-01'),
	('2000-07-18', '2000-07-01'),
	('2000-07-19', '2000-07-01'),
	('2000-07-20', '2000-07-01'),
	('2000-07-21', '2000-07-01'),
	('2000-07-22', '2000-07-01'),
	('2000-07-23', '2000-07-01'),
	('2000-07-24', '2000-07-01'),
	('2000-07-25', '2000-07-01'),
	('2000-07-26', '2000-07-01'),
	('2000-07-27', '2000-07-01'),
	('2000-07-28', '2000-07-01'),
	('2000-07-29', '2000-07-01'),
	('2000-07-30', '2000-07-01'),
	('2000-07-31', '2000-07-01'),
	('2000-08-01', '2000-08-01'),
	('2000-08-02', '2000-08-01'),
	('2000-08-03', '2000-08-01'),
	('2000-08-04', '2000-08-01'),
	('2000-08-05', '2000-08-01'),
	('2000-08-06', '2000-08-01'),
	('2000-08-07', '2000-08-01'),
	('2000-08-08', '2000-08-01'),
	('2000-08-09', '2000-08-01'),
	('2000-08-10', '2000-08-01'),
	('2000-08-11', '2000-08-01'),
	('2000-08-12', '2000-08-01'),
	('2000-08-13', '2000-08-01'),
	('2000-08-14', '2000-08-01'),
	('2000-08-15', '2000-08-01'),
	('2000-08-16', '2000-08-01'),
	('2000-08-17', '2000-08-01'),
	('2000-08-18', '2000-08-01'),
	('2000-08-19', '2000-08-01'),
	('2000-08-20', '2000-08-01'),
	('2000-08-21', '2000-08-01'),
	('2000-08-22', '2000-08-01'),
	('2000-08-23', '2000-08-01'),
	('2000-08-24', '2000-08-01'),
	('2000-08-25', '2000-08-01'),
	('2000-08-26', '2000-08-01'),
	('2000-08-27', '2000-08-01'),
	('2000-08-28', '2000-08-01'),
	('2000-08-29', '2000-08-01'),
	('2000-08-30', '2000-08-01'),
	('2000-08-31', '2000-08-01'),
	('2000-09-01', '2000-09-01'),
	('2000-09-02', '2000-09-01'),
	('2000-09-03', '2000-09-01'),
	('2000-09-04', '2000-09-01'),
	('2000-09-05', '2000-09-01'),
	('2000-09-06', '2000-09-01'),
	('2000-09-07', '2000-09-01'),
	('2000-09-08', '2000-09-01'),
	('2000-09-09', '2000-09-01'),
	('2000-09-10', '2000-09-01'),
	('2000-09-11', '2000-09-01'),
	('2000-09-12', '2000-09-01'),
	('2000-09-13', '2000-09-01'),
	('2000-09-14', '2000-09-01'),
	('2000-09-15', '2000-09-01'),
	('2000-09-16', '2000-09-01'),
	('2000-09-17', '2000-09-01'),
	('2000-09-18', '2000-09-01'),
	('2000-09-19', '2000-09-01'),
	('2000-09-20', '2000-09-01'),
	('2000-09-21', '2000-09-01'),
	('2000-09-22', '2000-09-01'),
	('2000-09-23', '2000-09-01'),
	('2000-09-24', '2000-09-01'),
	('2000-09-25', '2000-09-01'),
	('2000-09-26', '2000-09-01'),
	('2000-09-27', '2000-09-01'),
	('2000-09-28', '2000-09-01'),
	('2000-09-29', '2000-09-01'),
	('2000-09-30', '2000-09-01'),
	('2000-10-01', '2000-10-01'),
	('2000-10-02', '2000-10-01'),
	('2000-10-03', '2000-10-01'),
	('2000-10-04', '2000-10-01'),
	('2000-10-05', '2000-10-01'),
	('2000-10-06', '2000-10-01'),
	('2000-10-07', '2000-10-01'),
	('2000-10-08', '2000-10-01'),
	('2000-10-09', '2000-10-01'),
	('2000-10-10', '2000-10-01'),
	('2000-10-11', '2000-10-01'),
	('2000-10-12', '2000-10-01'),
	('2000-10-13', '2000-10-01'),
	('2000-10-14', '2000-10-01'),
	('2000-10-15', '2000-10-01'),
	('2000-10-16', '2000-10-01'),
	('2000-10-17', '2000-10-01'),
	('2000-10-18', '2000-10-01'),
	('2000-10-19', '2000-10-01'),
	('2000-10-20', '2000-10-01'),
	('2000-10-21', '2000-10-01'),
	('2000-10-22', '2000-10-01'),
	('2000-10-23', '2000-10-01'),
	('2000-10-24', '2000-10-01'),
	('2000-10-25', '2000-10-01'),
	('2000-10-26', '2000-10-01'),
	('2000-10-27', '2000-10-01'),
	('2000-10-28', '2000-10-01'),
	('2000-10-29', '2000-10-01'),
	('2000-10-30', '2000-10-01'),
	('2000-10-31', '2000-10-01'),
	('2000-11-01', '2000-11-01'),
	('2000-11-02', '2000-11-01'),
	('2000-11-03', '2000-11-01'),
	('2000-11-04', '2000-11-01'),
	('2000-11-05', '2000-11-01'),
	('2000-11-06', '2000-11-01'),
	('2000-11-07', '2000-11-01'),
	('2000-11-08', '2000-11-01'),
	('2000-11-09', '2000-11-01'),
	('2000-11-10', '2000-11-01'),
	('2000-11-11', '2000-11-01'),
	('2000-11-12', '2000-11-01'),
	('2000-11-13', '2000-11-01'),
	('2000-11-14', '2000-11-01'),
	('2000-11-15', '2000-11-01'),
	('2000-11-16', '2000-11-01'),
	('2000-11-17', '2000-11-01'),
	('2000-11-18', '2000-11-01'),
	('2000-11-19', '2000-11-01'),
	('2000-11-20', '2000-11-01'),
	('2000-11-21', '2000-11-01'),
	('2000-11-22', '2000-11-01'),
	('2000-11-23', '2000-11-01'),
	('2000-11-24', '2000-11-01'),
	('2000-11-25', '2000-11-01'),
	('2000-11-26', '2000-11-01'),
	('2000-11-27', '2000-11-01'),
	('2000-11-28', '2000-11-01'),
	('2000-11-29', '2000-11-01'),
	('2000-11-30', '2000-11-01'),
	('2000-12-01', '2000-12-01'),
	('2000-12-02', '2000-12-01'),
	('2000-12-03', '2000-12-01'),
	('2000-12-04', '2000-12-01'),
	('2000-12-05', '2000-12-01'),
	('2000-12-06', '2000-12-01'),
	('2000-12-07', '2000-12-01'),
	('2000-12-08', '2000-12-01'),
	('2000-12-09', '2000-12-01'),
	('2000-12-10', '2000-12-01'),
	('2000-12-11', '2000-12-01'),
	('2000-12-12', '2000-12-01'),
	('2000-12-13', '2000-12-01'),
	('2000-12-14', '2000-12-01'),
	('2000-12-15', '2000-12-01'),
	('2000-12-16', '2000-12-01'),
	('2000-12-17', '2000-12-01'),
	('2000-12-18', '2000-12-01'),
	('2000-12-19', '2000-12-01'),
	('2000-12-20', '2000-12-01'),
	('2000-12-21', '2000-12-01'),
	('2000-12-22', '2000-12-01'),
	('2000-12-23', '2000-12-01'),
	('2000-12-24', '2000-12-01'),
	('2000-12-25', '2000-12-01'),
	('2000-12-26', '2000-12-01'),
	('2000-12-27', '2000-12-01'),
	('2000-12-28', '2000-12-01'),
	('2000-12-29', '2000-12-01'),
	('2000-12-30', '2000-12-01'),
	('2000-12-31', '2000-12-01'),
	('2001-01-01', '2001-01-01'),
	('2001-01-02', '2001-01-01'),
	('2001-01-03', '2001-01-01'),
	('2001-01-04', '2001-01-01'),
	('2001-01-05', '2001-01-01'),
	('2001-01-06', '2001-01-01'),
	('2001-01-07', '2001-01-01'),
	('2001-01-08', '2001-01-01'),
	('2001-01-09', '2001-01-01'),
	('2001-01-10', '2001-01-01'),
	('2001-01-11', '2001-01-01'),
	('2001-01-12', '2001-01-01'),
	('2001-01-13', '2001-01-01'),
	('2001-01-14', '2001-01-01'),
	('2001-01-15', '2001-01-01'),
	('2001-01-16', '2001-01-01'),
	('2001-01-17', '2001-01-01'),
	('2001-01-18', '2001-01-01'),
	('2001-01-19', '2001-01-01'),
	('2001-01-20', '2001-01-01'),
	('2001-01-21', '2001-01-01'),
	('2001-01-22', '2001-01-01'),
	('2001-01-23', '2001-01-01'),
	('2001-01-24', '2001-01-01'),
	('2001-01-25', '2001-01-01'),
	('2001-01-26', '2001-01-01'),
	('2001-01-27', '2001-01-01'),
	('2001-01-28', '2001-01-01'),
	('2001-01-29', '2001-01-01'),
	('2001-01-30', '2001-01-01'),
	('2001-01-31', '2001-01-01'),
	('2001-02-01', '2001-02-01'),
	('2001-02-02', '2001-02-01'),
	('2001-02-03', '2001-02-01'),
	('2001-02-04', '2001-02-01'),
	('2001-02-05', '2001-02-01'),
	('2001-02-06', '2001-02-01'),
	('2001-02-07', '2001-02-01'),
	('2001-02-08', '2001-02-01'),
	('2001-02-09', '2001-02-01'),
	('2001-02-10', '2001-02-01'),
	('2001-02-11', '2001-02-01'),
	('2001-02-12', '2001-02-01'),
	('2001-02-13', '2001-02-01'),
	('2001-02-14', '2001-02-01'),
	('2001-02-15', '2001-02-01'),
	('2001-02-16', '2001-02-01'),
	('2001-02-17', '2001-02-01'),
	('2001-02-18', '2001-02-01'),
	('2001-02-19', '2001-02-01'),
	('2001-02-20', '2001-02-01'),
	('2001-02-21', '2001-02-01'),
	('2001-02-22', '2001-02-01'),
	('2001-02-23', '2001-02-01'),
	('2001-02-24', '2001-02-01'),
	('2001-02-25', '2001-02-01'),
	('2001-02-26', '2001-02-01'),
	('2001-02-27', '2001-02-01'),
	('2001-02-28', '2001-02-01'),
	('2001-03-01', '2001-03-01'),
	('2001-03-02', '2001-03-01'),
	('2001-03-03', '2001-03-01'),
	('2001-03-04', '2001-03-01'),
	('2001-03-05', '2001-03-01'),
	('2001-03-06', '2001-03-01'),
	('2001-03-07', '2001-03-01'),
	('2001-03-08', '2001-03-01'),
	('2001-03-09', '2001-03-01'),
	('2001-03-10', '2001-03-01'),
	('2001-03-11', '2001-03-01'),
	('2001-03-12', '2001-03-01'),
	('2001-03-13', '2001-03-01'),
	('2001-03-14', '2001-03-01'),
	('2001-03-15', '2001-03-01'),
	('2001-03-16', '2001-03-01'),
	('2001-03-17', '2001-03-01'),
	('2001-03-18', '2001-03-01'),
	('2001-03-19', '2001-03-01'),
	('2001-03-20', '2001-03-01'),
	('2001-03-21', '2001-03-01'),
	('2001-03-22', '2001-03-01'),
	('2001-03-23', '2001-03-01'),
	('2001-03-24', '2001-03-01'),
	('2001-03-25', '2001-03-01'),
	('2001-03-26', '2001-03-01'),
	('2001-03-27', '2001-03-01'),
	('2001-03-28', '2001-03-01'),
	('2001-03-29', '2001-03-01'),
	('2001-03-30', '2001-03-01'),
	('2001-03-31', '2001-03-01'),
	('2001-04-01', '2001-04-01'),
	('2001-04-02', '2001-04-01'),
	('2001-04-03', '2001-04-01'),
	('2001-04-04', '2001-04-01'),
	('2001-04-05', '2001-04-01'),
	('2001-04-06', '2001-04-01'),
	('2001-04-07', '2001-04-01'),
	('2001-04-08', '2001-04-01'),
	('2001-04-09', '2001-04-01'),
	('2001-04-10', '2001-04-01'),
	('2001-04-11', '2001-04-01'),
	('2001-04-12', '2001-04-01'),
	('2001-04-13', '2001-04-01'),
	('2001-04-14', '2001-04-01'),
	('2001-04-15', '2001-04-01'),
	('2001-04-16', '2001-04-01'),
	('2001-04-17', '2001-04-01'),
	('2001-04-18', '2001-04-01'),
	('2001-04-19', '2001-04-01'),
	('2001-04-20', '2001-04-01'),
	('2001-04-21', '2001-04-01'),
	('2001-04-22', '2001-04-01'),
	('2001-04-23', '2001-04-01'),
	('2001-04-24', '2001-04-01'),
	('2001-04-25', '2001-04-01'),
	('2001-04-26', '2001-04-01'),
	('2001-04-27', '2001-04-01'),
	('2001-04-28', '2001-04-01'),
	('2001-04-29', '2001-04-01'),
	('2001-04-30', '2001-04-01'),
	('2001-05-01', '2001-05-01'),
	('2001-05-02', '2001-05-01'),
	('2001-05-03', '2001-05-01'),
	('2001-05-04', '2001-05-01'),
	('2001-05-05', '2001-05-01'),
	('2001-05-06', '2001-05-01'),
	('2001-05-07', '2001-05-01'),
	('2001-05-08', '2001-05-01'),
	('2001-05-09', '2001-05-01'),
	('2001-05-10', '2001-05-01'),
	('2001-05-11', '2001-05-01'),
	('2001-05-12', '2001-05-01'),
	('2001-05-13', '2001-05-01'),
	('2001-05-14', '2001-05-01'),
	('2001-05-15', '2001-05-01'),
	('2001-05-16', '2001-05-01'),
	('2001-05-17', '2001-05-01'),
	('2001-05-18', '2001-05-01'),
	('2001-05-19', '2001-05-01'),
	('2001-05-20', '2001-05-01'),
	('2001-05-21', '2001-05-01'),
	('2001-05-22', '2001-05-01'),
	('2001-05-23', '2001-05-01'),
	('2001-05-24', '2001-05-01'),
	('2001-05-25', '2001-05-01'),
	('2001-05-26', '2001-05-01'),
	('2001-05-27', '2001-05-01'),
	('2001-05-28', '2001-05-01'),
	('2001-05-29', '2001-05-01'),
	('2001-05-30', '2001-05-01'),
	('2001-05-31', '2001-05-01'),
	('2001-06-01', '2001-06-01'),
	('2001-06-02', '2001-06-01'),
	('2001-06-03', '2001-06-01'),
	('2001-06-04', '2001-06-01'),
	('2001-06-05', '2001-06-01'),
	('2001-06-06', '2001-06-01'),
	('2001-06-07', '2001-06-01'),
	('2001-06-08', '2001-06-01'),
	('2001-06-09', '2001-06-01'),
	('2001-06-10', '2001-06-01'),
	('2001-06-11', '2001-06-01'),
	('2001-06-12', '2001-06-01'),
	('2001-06-13', '2001-06-01'),
	('2001-06-14', '2001-06-01'),
	('2001-06-15', '2001-06-01'),
	('2001-06-16', '2001-06-01'),
	('2001-06-17', '2001-06-01'),
	('2001-06-18', '2001-06-01'),
	('2001-06-19', '2001-06-01'),
	('2001-06-20', '2001-06-01'),
	('2001-06-21', '2001-06-01'),
	('2001-06-22', '2001-06-01'),
	('2001-06-23', '2001-06-01'),
	('2001-06-24', '2001-06-01'),
	('2001-06-25', '2001-06-01'),
	('2001-06-26', '2001-06-01'),
	('2001-06-27', '2001-06-01'),
	('2001-06-28', '2001-06-01'),
	('2001-06-29', '2001-06-01'),
	('2001-06-30', '2001-06-01'),
	('2001-07-01', '2001-07-01'),
	('2001-07-02', '2001-07-01'),
	('2001-07-03', '2001-07-01'),
	('2001-07-04', '2001-07-01'),
	('2001-07-05', '2001-07-01'),
	('2001-07-06', '2001-07-01'),
	('2001-07-07', '2001-07-01'),
	('2001-07-08', '2001-07-01'),
	('2001-07-09', '2001-07-01'),
	('2001-07-10', '2001-07-01'),
	('2001-07-11', '2001-07-01'),
	('2001-07-12', '2001-07-01'),
	('2001-07-13', '2001-07-01'),
	('2001-07-14', '2001-07-01'),
	('2001-07-15', '2001-07-01'),
	('2001-07-16', '2001-07-01'),
	('2001-07-17', '2001-07-01'),
	('2001-07-18', '2001-07-01'),
	('2001-07-19', '2001-07-01'),
	('2001-07-20', '2001-07-01'),
	('2001-07-21', '2001-07-01'),
	('2001-07-22', '2001-07-01'),
	('2001-07-23', '2001-07-01'),
	('2001-07-24', '2001-07-01'),
	('2001-07-25', '2001-07-01'),
	('2001-07-26', '2001-07-01'),
	('2001-07-27', '2001-07-01'),
	('2001-07-28', '2001-07-01'),
	('2001-07-29', '2001-07-01'),
	('2001-07-30', '2001-07-01'),
	('2001-07-31', '2001-07-01'),
	('2001-08-01', '2001-08-01'),
	('2001-08-02', '2001-08-01'),
	('2001-08-03', '2001-08-01'),
	('2001-08-04', '2001-08-01'),
	('2001-08-05', '2001-08-01'),
	('2001-08-06', '2001-08-01'),
	('2001-08-07', '2001-08-01'),
	('2001-08-08', '2001-08-01'),
	('2001-08-09', '2001-08-01'),
	('2001-08-10', '2001-08-01'),
	('2001-08-11', '2001-08-01'),
	('2001-08-12', '2001-08-01'),
	('2001-08-13', '2001-08-01'),
	('2001-08-14', '2001-08-01'),
	('2001-08-15', '2001-08-01'),
	('2001-08-16', '2001-08-01'),
	('2001-08-17', '2001-08-01'),
	('2001-08-18', '2001-08-01'),
	('2001-08-19', '2001-08-01'),
	('2001-08-20', '2001-08-01'),
	('2001-08-21', '2001-08-01'),
	('2001-08-22', '2001-08-01'),
	('2001-08-23', '2001-08-01'),
	('2001-08-24', '2001-08-01'),
	('2001-08-25', '2001-08-01'),
	('2001-08-26', '2001-08-01'),
	('2001-08-27', '2001-08-01'),
	('2001-08-28', '2001-08-01'),
	('2001-08-29', '2001-08-01'),
	('2001-08-30', '2001-08-01'),
	('2001-08-31', '2001-08-01'),
	('2001-09-01', '2001-09-01'),
	('2001-09-02', '2001-09-01'),
	('2001-09-03', '2001-09-01'),
	('2001-09-04', '2001-09-01'),
	('2001-09-05', '2001-09-01'),
	('2001-09-06', '2001-09-01'),
	('2001-09-07', '2001-09-01'),
	('2001-09-08', '2001-09-01'),
	('2001-09-09', '2001-09-01'),
	('2001-09-10', '2001-09-01'),
	('2001-09-11', '2001-09-01'),
	('2001-09-12', '2001-09-01'),
	('2001-09-13', '2001-09-01'),
	('2001-09-14', '2001-09-01'),
	('2001-09-15', '2001-09-01'),
	('2001-09-16', '2001-09-01'),
	('2001-09-17', '2001-09-01'),
	('2001-09-18', '2001-09-01'),
	('2001-09-19', '2001-09-01'),
	('2001-09-20', '2001-09-01'),
	('2001-09-21', '2001-09-01'),
	('2001-09-22', '2001-09-01'),
	('2001-09-23', '2001-09-01'),
	('2001-09-24', '2001-09-01'),
	('2001-09-25', '2001-09-01'),
	('2001-09-26', '2001-09-01'),
	('2001-09-27', '2001-09-01'),
	('2001-09-28', '2001-09-01'),
	('2001-09-29', '2001-09-01'),
	('2001-09-30', '2001-09-01'),
	('2001-10-01', '2001-10-01'),
	('2001-10-02', '2001-10-01'),
	('2001-10-03', '2001-10-01'),
	('2001-10-04', '2001-10-01'),
	('2001-10-05', '2001-10-01'),
	('2001-10-06', '2001-10-01'),
	('2001-10-07', '2001-10-01'),
	('2001-10-08', '2001-10-01'),
	('2001-10-09', '2001-10-01'),
	('2001-10-10', '2001-10-01'),
	('2001-10-11', '2001-10-01'),
	('2001-10-12', '2001-10-01'),
	('2001-10-13', '2001-10-01'),
	('2001-10-14', '2001-10-01'),
	('2001-10-15', '2001-10-01'),
	('2001-10-16', '2001-10-01'),
	('2001-10-17', '2001-10-01'),
	('2001-10-18', '2001-10-01'),
	('2001-10-19', '2001-10-01'),
	('2001-10-20', '2001-10-01'),
	('2001-10-21', '2001-10-01'),
	('2001-10-22', '2001-10-01'),
	('2001-10-23', '2001-10-01'),
	('2001-10-24', '2001-10-01'),
	('2001-10-25', '2001-10-01'),
	('2001-10-26', '2001-10-01'),
	('2001-10-27', '2001-10-01'),
	('2001-10-28', '2001-10-01'),
	('2001-10-29', '2001-10-01'),
	('2001-10-30', '2001-10-01'),
	('2001-10-31', '2001-10-01'),
	('2001-11-01', '2001-11-01'),
	('2001-11-02', '2001-11-01'),
	('2001-11-03', '2001-11-01'),
	('2001-11-04', '2001-11-01'),
	('2001-11-05', '2001-11-01'),
	('2001-11-06', '2001-11-01'),
	('2001-11-07', '2001-11-01'),
	('2001-11-08', '2001-11-01'),
	('2001-11-09', '2001-11-01'),
	('2001-11-10', '2001-11-01'),
	('2001-11-11', '2001-11-01'),
	('2001-11-12', '2001-11-01'),
	('2001-11-13', '2001-11-01'),
	('2001-11-14', '2001-11-01'),
	('2001-11-15', '2001-11-01'),
	('2001-11-16', '2001-11-01'),
	('2001-11-17', '2001-11-01'),
	('2001-11-18', '2001-11-01'),
	('2001-11-19', '2001-11-01'),
	('2001-11-20', '2001-11-01'),
	('2001-11-21', '2001-11-01'),
	('2001-11-22', '2001-11-01'),
	('2001-11-23', '2001-11-01'),
	('2001-11-24', '2001-11-01'),
	('2001-11-25', '2001-11-01'),
	('2001-11-26', '2001-11-01'),
	('2001-11-27', '2001-11-01'),
	('2001-11-28', '2001-11-01'),
	('2001-11-29', '2001-11-01'),
	('2001-11-30', '2001-11-01'),
	('2001-12-01', '2001-12-01'),
	('2001-12-02', '2001-12-01'),
	('2001-12-03', '2001-12-01'),
	('2001-12-04', '2001-12-01'),
	('2001-12-05', '2001-12-01'),
	('2001-12-06', '2001-12-01'),
	('2001-12-07', '2001-12-01'),
	('2001-12-08', '2001-12-01'),
	('2001-12-09', '2001-12-01'),
	('2001-12-10', '2001-12-01'),
	('2001-12-11', '2001-12-01'),
	('2001-12-12', '2001-12-01'),
	('2001-12-13', '2001-12-01'),
	('2001-12-14', '2001-12-01'),
	('2001-12-15', '2001-12-01'),
	('2001-12-16', '2001-12-01'),
	('2001-12-17', '2001-12-01'),
	('2001-12-18', '2001-12-01'),
	('2001-12-19', '2001-12-01'),
	('2001-12-20', '2001-12-01'),
	('2001-12-21', '2001-12-01'),
	('2001-12-22', '2001-12-01'),
	('2001-12-23', '2001-12-01'),
	('2001-12-24', '2001-12-01'),
	('2001-12-25', '2001-12-01'),
	('2001-12-26', '2001-12-01'),
	('2001-12-27', '2001-12-01'),
	('2001-12-28', '2001-12-01'),
	('2001-12-29', '2001-12-01'),
	('2001-12-30', '2001-12-01'),
	('2001-12-31', '2001-12-01'),
	('2002-01-01', '2002-01-01'),
	('2002-01-02', '2002-01-01'),
	('2002-01-03', '2002-01-01'),
	('2002-01-04', '2002-01-01'),
	('2002-01-05', '2002-01-01'),
	('2002-01-06', '2002-01-01'),
	('2002-01-07', '2002-01-01'),
	('2002-01-08', '2002-01-01'),
	('2002-01-09', '2002-01-01'),
	('2002-01-10', '2002-01-01'),
	('2002-01-11', '2002-01-01'),
	('2002-01-12', '2002-01-01'),
	('2002-01-13', '2002-01-01'),
	('2002-01-14', '2002-01-01'),
	('2002-01-15', '2002-01-01'),
	('2002-01-16', '2002-01-01'),
	('2002-01-17', '2002-01-01'),
	('2002-01-18', '2002-01-01'),
	('2002-01-19', '2002-01-01'),
	('2002-01-20', '2002-01-01'),
	('2002-01-21', '2002-01-01'),
	('2002-01-22', '2002-01-01'),
	('2002-01-23', '2002-01-01'),
	('2002-01-24', '2002-01-01'),
	('2002-01-25', '2002-01-01'),
	('2002-01-26', '2002-01-01'),
	('2002-01-27', '2002-01-01'),
	('2002-01-28', '2002-01-01'),
	('2002-01-29', '2002-01-01'),
	('2002-01-30', '2002-01-01'),
	('2002-01-31', '2002-01-01'),
	('2002-02-01', '2002-02-01'),
	('2002-02-02', '2002-02-01'),
	('2002-02-03', '2002-02-01'),
	('2002-02-04', '2002-02-01'),
	('2002-02-05', '2002-02-01'),
	('2002-02-06', '2002-02-01'),
	('2002-02-07', '2002-02-01'),
	('2002-02-08', '2002-02-01'),
	('2002-02-09', '2002-02-01'),
	('2002-02-10', '2002-02-01'),
	('2002-02-11', '2002-02-01'),
	('2002-02-12', '2002-02-01'),
	('2002-02-13', '2002-02-01'),
	('2002-02-14', '2002-02-01'),
	('2002-02-15', '2002-02-01'),
	('2002-02-16', '2002-02-01'),
	('2002-02-17', '2002-02-01'),
	('2002-02-18', '2002-02-01'),
	('2002-02-19', '2002-02-01'),
	('2002-02-20', '2002-02-01'),
	('2002-02-21', '2002-02-01'),
	('2002-02-22', '2002-02-01'),
	('2002-02-23', '2002-02-01'),
	('2002-02-24', '2002-02-01'),
	('2002-02-25', '2002-02-01'),
	('2002-02-26', '2002-02-01'),
	('2002-02-27', '2002-02-01'),
	('2002-02-28', '2002-02-01'),
	('2002-03-01', '2002-03-01'),
	('2002-03-02', '2002-03-01'),
	('2002-03-03', '2002-03-01'),
	('2002-03-04', '2002-03-01'),
	('2002-03-05', '2002-03-01'),
	('2002-03-06', '2002-03-01'),
	('2002-03-07', '2002-03-01'),
	('2002-03-08', '2002-03-01'),
	('2002-03-09', '2002-03-01'),
	('2002-03-10', '2002-03-01'),
	('2002-03-11', '2002-03-01'),
	('2002-03-12', '2002-03-01'),
	('2002-03-13', '2002-03-01'),
	('2002-03-14', '2002-03-01'),
	('2002-03-15', '2002-03-01'),
	('2002-03-16', '2002-03-01'),
	('2002-03-17', '2002-03-01'),
	('2002-03-18', '2002-03-01'),
	('2002-03-19', '2002-03-01'),
	('2002-03-20', '2002-03-01'),
	('2002-03-21', '2002-03-01'),
	('2002-03-22', '2002-03-01'),
	('2002-03-23', '2002-03-01'),
	('2002-03-24', '2002-03-01'),
	('2002-03-25', '2002-03-01'),
	('2002-03-26', '2002-03-01'),
	('2002-03-27', '2002-03-01'),
	('2002-03-28', '2002-03-01'),
	('2002-03-29', '2002-03-01'),
	('2002-03-30', '2002-03-01'),
	('2002-03-31', '2002-03-01'),
	('2002-04-01', '2002-04-01'),
	('2002-04-02', '2002-04-01'),
	('2002-04-03', '2002-04-01'),
	('2002-04-04', '2002-04-01'),
	('2002-04-05', '2002-04-01'),
	('2002-04-06', '2002-04-01'),
	('2002-04-07', '2002-04-01'),
	('2002-04-08', '2002-04-01'),
	('2002-04-09', '2002-04-01'),
	('2002-04-10', '2002-04-01'),
	('2002-04-11', '2002-04-01'),
	('2002-04-12', '2002-04-01'),
	('2002-04-13', '2002-04-01'),
	('2002-04-14', '2002-04-01'),
	('2002-04-15', '2002-04-01'),
	('2002-04-16', '2002-04-01'),
	('2002-04-17', '2002-04-01'),
	('2002-04-18', '2002-04-01'),
	('2002-04-19', '2002-04-01'),
	('2002-04-20', '2002-04-01'),
	('2002-04-21', '2002-04-01'),
	('2002-04-22', '2002-04-01'),
	('2002-04-23', '2002-04-01'),
	('2002-04-24', '2002-04-01'),
	('2002-04-25', '2002-04-01'),
	('2002-04-26', '2002-04-01'),
	('2002-04-27', '2002-04-01'),
	('2002-04-28', '2002-04-01'),
	('2002-04-29', '2002-04-01'),
	('2002-04-30', '2002-04-01'),
	('2002-05-01', '2002-05-01'),
	('2002-05-02', '2002-05-01'),
	('2002-05-03', '2002-05-01'),
	('2002-05-04', '2002-05-01'),
	('2002-05-05', '2002-05-01'),
	('2002-05-06', '2002-05-01'),
	('2002-05-07', '2002-05-01'),
	('2002-05-08', '2002-05-01'),
	('2002-05-09', '2002-05-01'),
	('2002-05-10', '2002-05-01'),
	('2002-05-11', '2002-05-01'),
	('2002-05-12', '2002-05-01'),
	('2002-05-13', '2002-05-01'),
	('2002-05-14', '2002-05-01'),
	('2002-05-15', '2002-05-01'),
	('2002-05-16', '2002-05-01'),
	('2002-05-17', '2002-05-01'),
	('2002-05-18', '2002-05-01'),
	('2002-05-19', '2002-05-01'),
	('2002-05-20', '2002-05-01'),
	('2002-05-21', '2002-05-01'),
	('2002-05-22', '2002-05-01'),
	('2002-05-23', '2002-05-01'),
	('2002-05-24', '2002-05-01'),
	('2002-05-25', '2002-05-01'),
	('2002-05-26', '2002-05-01'),
	('2002-05-27', '2002-05-01'),
	('2002-05-28', '2002-05-01'),
	('2002-05-29', '2002-05-01'),
	('2002-05-30', '2002-05-01'),
	('2002-05-31', '2002-05-01'),
	('2002-06-01', '2002-06-01'),
	('2002-06-02', '2002-06-01'),
	('2002-06-03', '2002-06-01'),
	('2002-06-04', '2002-06-01'),
	('2002-06-05', '2002-06-01'),
	('2002-06-06', '2002-06-01'),
	('2002-06-07', '2002-06-01'),
	('2002-06-08', '2002-06-01'),
	('2002-06-09', '2002-06-01'),
	('2002-06-10', '2002-06-01'),
	('2002-06-11', '2002-06-01'),
	('2002-06-12', '2002-06-01'),
	('2002-06-13', '2002-06-01'),
	('2002-06-14', '2002-06-01'),
	('2002-06-15', '2002-06-01'),
	('2002-06-16', '2002-06-01'),
	('2002-06-17', '2002-06-01'),
	('2002-06-18', '2002-06-01'),
	('2002-06-19', '2002-06-01'),
	('2002-06-20', '2002-06-01'),
	('2002-06-21', '2002-06-01'),
	('2002-06-22', '2002-06-01'),
	('2002-06-23', '2002-06-01'),
	('2002-06-24', '2002-06-01'),
	('2002-06-25', '2002-06-01'),
	('2002-06-26', '2002-06-01'),
	('2002-06-27', '2002-06-01'),
	('2002-06-28', '2002-06-01'),
	('2002-06-29', '2002-06-01'),
	('2002-06-30', '2002-06-01'),
	('2002-07-01', '2002-07-01'),
	('2002-07-02', '2002-07-01'),
	('2002-07-03', '2002-07-01'),
	('2002-07-04', '2002-07-01'),
	('2002-07-05', '2002-07-01'),
	('2002-07-06', '2002-07-01'),
	('2002-07-07', '2002-07-01'),
	('2002-07-08', '2002-07-01'),
	('2002-07-09', '2002-07-01'),
	('2002-07-10', '2002-07-01'),
	('2002-07-11', '2002-07-01'),
	('2002-07-12', '2002-07-01'),
	('2002-07-13', '2002-07-01'),
	('2002-07-14', '2002-07-01'),
	('2002-07-15', '2002-07-01'),
	('2002-07-16', '2002-07-01'),
	('2002-07-17', '2002-07-01'),
	('2002-07-18', '2002-07-01'),
	('2002-07-19', '2002-07-01'),
	('2002-07-20', '2002-07-01'),
	('2002-07-21', '2002-07-01'),
	('2002-07-22', '2002-07-01'),
	('2002-07-23', '2002-07-01'),
	('2002-07-24', '2002-07-01'),
	('2002-07-25', '2002-07-01'),
	('2002-07-26', '2002-07-01'),
	('2002-07-27', '2002-07-01'),
	('2002-07-28', '2002-07-01'),
	('2002-07-29', '2002-07-01'),
	('2002-07-30', '2002-07-01'),
	('2002-07-31', '2002-07-01'),
	('2002-08-01', '2002-08-01'),
	('2002-08-02', '2002-08-01'),
	('2002-08-03', '2002-08-01'),
	('2002-08-04', '2002-08-01'),
	('2002-08-05', '2002-08-01'),
	('2002-08-06', '2002-08-01'),
	('2002-08-07', '2002-08-01'),
	('2002-08-08', '2002-08-01'),
	('2002-08-09', '2002-08-01'),
	('2002-08-10', '2002-08-01'),
	('2002-08-11', '2002-08-01'),
	('2002-08-12', '2002-08-01'),
	('2002-08-13', '2002-08-01'),
	('2002-08-14', '2002-08-01'),
	('2002-08-15', '2002-08-01'),
	('2002-08-16', '2002-08-01'),
	('2002-08-17', '2002-08-01'),
	('2002-08-18', '2002-08-01'),
	('2002-08-19', '2002-08-01'),
	('2002-08-20', '2002-08-01'),
	('2002-08-21', '2002-08-01'),
	('2002-08-22', '2002-08-01'),
	('2002-08-23', '2002-08-01'),
	('2002-08-24', '2002-08-01'),
	('2002-08-25', '2002-08-01'),
	('2002-08-26', '2002-08-01'),
	('2002-08-27', '2002-08-01'),
	('2002-08-28', '2002-08-01'),
	('2002-08-29', '2002-08-01'),
	('2002-08-30', '2002-08-01'),
	('2002-08-31', '2002-08-01'),
	('2002-09-01', '2002-09-01'),
	('2002-09-02', '2002-09-01'),
	('2002-09-03', '2002-09-01'),
	('2002-09-04', '2002-09-01'),
	('2002-09-05', '2002-09-01'),
	('2002-09-06', '2002-09-01'),
	('2002-09-07', '2002-09-01'),
	('2002-09-08', '2002-09-01'),
	('2002-09-09', '2002-09-01'),
	('2002-09-10', '2002-09-01'),
	('2002-09-11', '2002-09-01'),
	('2002-09-12', '2002-09-01'),
	('2002-09-13', '2002-09-01'),
	('2002-09-14', '2002-09-01'),
	('2002-09-15', '2002-09-01'),
	('2002-09-16', '2002-09-01'),
	('2002-09-17', '2002-09-01'),
	('2002-09-18', '2002-09-01'),
	('2002-09-19', '2002-09-01'),
	('2002-09-20', '2002-09-01'),
	('2002-09-21', '2002-09-01'),
	('2002-09-22', '2002-09-01'),
	('2002-09-23', '2002-09-01'),
	('2002-09-24', '2002-09-01'),
	('2002-09-25', '2002-09-01'),
	('2002-09-26', '2002-09-01'),
	('2002-09-27', '2002-09-01'),
	('2002-09-28', '2002-09-01'),
	('2002-09-29', '2002-09-01'),
	('2002-09-30', '2002-09-01'),
	('2002-10-01', '2002-10-01'),
	('2002-10-02', '2002-10-01'),
	('2002-10-03', '2002-10-01'),
	('2002-10-04', '2002-10-01'),
	('2002-10-05', '2002-10-01'),
	('2002-10-06', '2002-10-01'),
	('2002-10-07', '2002-10-01'),
	('2002-10-08', '2002-10-01'),
	('2002-10-09', '2002-10-01'),
	('2002-10-10', '2002-10-01'),
	('2002-10-11', '2002-10-01'),
	('2002-10-12', '2002-10-01'),
	('2002-10-13', '2002-10-01'),
	('2002-10-14', '2002-10-01'),
	('2002-10-15', '2002-10-01'),
	('2002-10-16', '2002-10-01'),
	('2002-10-17', '2002-10-01'),
	('2002-10-18', '2002-10-01'),
	('2002-10-19', '2002-10-01'),
	('2002-10-20', '2002-10-01'),
	('2002-10-21', '2002-10-01'),
	('2002-10-22', '2002-10-01'),
	('2002-10-23', '2002-10-01'),
	('2002-10-24', '2002-10-01'),
	('2002-10-25', '2002-10-01'),
	('2002-10-26', '2002-10-01'),
	('2002-10-27', '2002-10-01'),
	('2002-10-28', '2002-10-01'),
	('2002-10-29', '2002-10-01'),
	('2002-10-30', '2002-10-01'),
	('2002-10-31', '2002-10-01'),
	('2002-11-01', '2002-11-01'),
	('2002-11-02', '2002-11-01'),
	('2002-11-03', '2002-11-01'),
	('2002-11-04', '2002-11-01'),
	('2002-11-05', '2002-11-01'),
	('2002-11-06', '2002-11-01'),
	('2002-11-07', '2002-11-01'),
	('2002-11-08', '2002-11-01'),
	('2002-11-09', '2002-11-01'),
	('2002-11-10', '2002-11-01'),
	('2002-11-11', '2002-11-01'),
	('2002-11-12', '2002-11-01'),
	('2002-11-13', '2002-11-01'),
	('2002-11-14', '2002-11-01'),
	('2002-11-15', '2002-11-01'),
	('2002-11-16', '2002-11-01'),
	('2002-11-17', '2002-11-01'),
	('2002-11-18', '2002-11-01'),
	('2002-11-19', '2002-11-01'),
	('2002-11-20', '2002-11-01'),
	('2002-11-21', '2002-11-01'),
	('2002-11-22', '2002-11-01'),
	('2002-11-23', '2002-11-01'),
	('2002-11-24', '2002-11-01'),
	('2002-11-25', '2002-11-01'),
	('2002-11-26', '2002-11-01'),
	('2002-11-27', '2002-11-01'),
	('2002-11-28', '2002-11-01'),
	('2002-11-29', '2002-11-01'),
	('2002-11-30', '2002-11-01'),
	('2002-12-01', '2002-12-01'),
	('2002-12-02', '2002-12-01'),
	('2002-12-03', '2002-12-01'),
	('2002-12-04', '2002-12-01'),
	('2002-12-05', '2002-12-01'),
	('2002-12-06', '2002-12-01'),
	('2002-12-07', '2002-12-01'),
	('2002-12-08', '2002-12-01'),
	('2002-12-09', '2002-12-01'),
	('2002-12-10', '2002-12-01'),
	('2002-12-11', '2002-12-01'),
	('2002-12-12', '2002-12-01'),
	('2002-12-13', '2002-12-01'),
	('2002-12-14', '2002-12-01'),
	('2002-12-15', '2002-12-01'),
	('2002-12-16', '2002-12-01'),
	('2002-12-17', '2002-12-01'),
	('2002-12-18', '2002-12-01'),
	('2002-12-19', '2002-12-01'),
	('2002-12-20', '2002-12-01'),
	('2002-12-21', '2002-12-01'),
	('2002-12-22', '2002-12-01'),
	('2002-12-23', '2002-12-01'),
	('2002-12-24', '2002-12-01'),
	('2002-12-25', '2002-12-01'),
	('2002-12-26', '2002-12-01'),
	('2002-12-27', '2002-12-01'),
	('2002-12-28', '2002-12-01'),
	('2002-12-29', '2002-12-01'),
	('2002-12-30', '2002-12-01'),
	('2002-12-31', '2002-12-01'),
	('2003-01-01', '2003-01-01'),
	('2003-01-02', '2003-01-01'),
	('2003-01-03', '2003-01-01'),
	('2003-01-04', '2003-01-01'),
	('2003-01-05', '2003-01-01'),
	('2003-01-06', '2003-01-01'),
	('2003-01-07', '2003-01-01'),
	('2003-01-08', '2003-01-01'),
	('2003-01-09', '2003-01-01'),
	('2003-01-10', '2003-01-01'),
	('2003-01-11', '2003-01-01'),
	('2003-01-12', '2003-01-01'),
	('2003-01-13', '2003-01-01'),
	('2003-01-14', '2003-01-01'),
	('2003-01-15', '2003-01-01'),
	('2003-01-16', '2003-01-01'),
	('2003-01-17', '2003-01-01'),
	('2003-01-18', '2003-01-01'),
	('2003-01-19', '2003-01-01'),
	('2003-01-20', '2003-01-01'),
	('2003-01-21', '2003-01-01'),
	('2003-01-22', '2003-01-01'),
	('2003-01-23', '2003-01-01'),
	('2003-01-24', '2003-01-01'),
	('2003-01-25', '2003-01-01'),
	('2003-01-26', '2003-01-01'),
	('2003-01-27', '2003-01-01'),
	('2003-01-28', '2003-01-01'),
	('2003-01-29', '2003-01-01'),
	('2003-01-30', '2003-01-01'),
	('2003-01-31', '2003-01-01'),
	('2003-02-01', '2003-02-01'),
	('2003-02-02', '2003-02-01'),
	('2003-02-03', '2003-02-01'),
	('2003-02-04', '2003-02-01'),
	('2003-02-05', '2003-02-01'),
	('2003-02-06', '2003-02-01'),
	('2003-02-07', '2003-02-01'),
	('2003-02-08', '2003-02-01'),
	('2003-02-09', '2003-02-01'),
	('2003-02-10', '2003-02-01'),
	('2003-02-11', '2003-02-01'),
	('2003-02-12', '2003-02-01'),
	('2003-02-13', '2003-02-01'),
	('2003-02-14', '2003-02-01'),
	('2003-02-15', '2003-02-01'),
	('2003-02-16', '2003-02-01'),
	('2003-02-17', '2003-02-01'),
	('2003-02-18', '2003-02-01'),
	('2003-02-19', '2003-02-01'),
	('2003-02-20', '2003-02-01'),
	('2003-02-21', '2003-02-01'),
	('2003-02-22', '2003-02-01'),
	('2003-02-23', '2003-02-01'),
	('2003-02-24', '2003-02-01'),
	('2003-02-25', '2003-02-01'),
	('2003-02-26', '2003-02-01'),
	('2003-02-27', '2003-02-01'),
	('2003-02-28', '2003-02-01'),
	('2003-03-01', '2003-03-01'),
	('2003-03-02', '2003-03-01'),
	('2003-03-03', '2003-03-01'),
	('2003-03-04', '2003-03-01'),
	('2003-03-05', '2003-03-01'),
	('2003-03-06', '2003-03-01'),
	('2003-03-07', '2003-03-01'),
	('2003-03-08', '2003-03-01'),
	('2003-03-09', '2003-03-01'),
	('2003-03-10', '2003-03-01'),
	('2003-03-11', '2003-03-01'),
	('2003-03-12', '2003-03-01'),
	('2003-03-13', '2003-03-01'),
	('2003-03-14', '2003-03-01'),
	('2003-03-15', '2003-03-01'),
	('2003-03-16', '2003-03-01'),
	('2003-03-17', '2003-03-01'),
	('2003-03-18', '2003-03-01'),
	('2003-03-19', '2003-03-01'),
	('2003-03-20', '2003-03-01'),
	('2003-03-21', '2003-03-01'),
	('2003-03-22', '2003-03-01'),
	('2003-03-23', '2003-03-01'),
	('2003-03-24', '2003-03-01'),
	('2003-03-25', '2003-03-01'),
	('2003-03-26', '2003-03-01'),
	('2003-03-27', '2003-03-01'),
	('2003-03-28', '2003-03-01'),
	('2003-03-29', '2003-03-01'),
	('2003-03-30', '2003-03-01'),
	('2003-03-31', '2003-03-01'),
	('2003-04-01', '2003-04-01'),
	('2003-04-02', '2003-04-01'),
	('2003-04-03', '2003-04-01'),
	('2003-04-04', '2003-04-01'),
	('2003-04-05', '2003-04-01'),
	('2003-04-06', '2003-04-01'),
	('2003-04-07', '2003-04-01'),
	('2003-04-08', '2003-04-01'),
	('2003-04-09', '2003-04-01'),
	('2003-04-10', '2003-04-01'),
	('2003-04-11', '2003-04-01'),
	('2003-04-12', '2003-04-01'),
	('2003-04-13', '2003-04-01'),
	('2003-04-14', '2003-04-01'),
	('2003-04-15', '2003-04-01'),
	('2003-04-16', '2003-04-01'),
	('2003-04-17', '2003-04-01'),
	('2003-04-18', '2003-04-01'),
	('2003-04-19', '2003-04-01'),
	('2003-04-20', '2003-04-01'),
	('2003-04-21', '2003-04-01'),
	('2003-04-22', '2003-04-01'),
	('2003-04-23', '2003-04-01'),
	('2003-04-24', '2003-04-01'),
	('2003-04-25', '2003-04-01'),
	('2003-04-26', '2003-04-01'),
	('2003-04-27', '2003-04-01'),
	('2003-04-28', '2003-04-01'),
	('2003-04-29', '2003-04-01'),
	('2003-04-30', '2003-04-01'),
	('2003-05-01', '2003-05-01'),
	('2003-05-02', '2003-05-01'),
	('2003-05-03', '2003-05-01'),
	('2003-05-04', '2003-05-01'),
	('2003-05-05', '2003-05-01'),
	('2003-05-06', '2003-05-01'),
	('2003-05-07', '2003-05-01'),
	('2003-05-08', '2003-05-01'),
	('2003-05-09', '2003-05-01'),
	('2003-05-10', '2003-05-01'),
	('2003-05-11', '2003-05-01'),
	('2003-05-12', '2003-05-01'),
	('2003-05-13', '2003-05-01'),
	('2003-05-14', '2003-05-01'),
	('2003-05-15', '2003-05-01'),
	('2003-05-16', '2003-05-01'),
	('2003-05-17', '2003-05-01'),
	('2003-05-18', '2003-05-01'),
	('2003-05-19', '2003-05-01'),
	('2003-05-20', '2003-05-01'),
	('2003-05-21', '2003-05-01'),
	('2003-05-22', '2003-05-01'),
	('2003-05-23', '2003-05-01'),
	('2003-05-24', '2003-05-01'),
	('2003-05-25', '2003-05-01'),
	('2003-05-26', '2003-05-01'),
	('2003-05-27', '2003-05-01'),
	('2003-05-28', '2003-05-01'),
	('2003-05-29', '2003-05-01'),
	('2003-05-30', '2003-05-01'),
	('2003-05-31', '2003-05-01'),
	('2003-06-01', '2003-06-01'),
	('2003-06-02', '2003-06-01'),
	('2003-06-03', '2003-06-01'),
	('2003-06-04', '2003-06-01'),
	('2003-06-05', '2003-06-01'),
	('2003-06-06', '2003-06-01'),
	('2003-06-07', '2003-06-01'),
	('2003-06-08', '2003-06-01'),
	('2003-06-09', '2003-06-01'),
	('2003-06-10', '2003-06-01'),
	('2003-06-11', '2003-06-01'),
	('2003-06-12', '2003-06-01'),
	('2003-06-13', '2003-06-01'),
	('2003-06-14', '2003-06-01'),
	('2003-06-15', '2003-06-01'),
	('2003-06-16', '2003-06-01'),
	('2003-06-17', '2003-06-01'),
	('2003-06-18', '2003-06-01'),
	('2003-06-19', '2003-06-01'),
	('2003-06-20', '2003-06-01'),
	('2003-06-21', '2003-06-01'),
	('2003-06-22', '2003-06-01'),
	('2003-06-23', '2003-06-01'),
	('2003-06-24', '2003-06-01'),
	('2003-06-25', '2003-06-01'),
	('2003-06-26', '2003-06-01'),
	('2003-06-27', '2003-06-01'),
	('2003-06-28', '2003-06-01'),
	('2003-06-29', '2003-06-01'),
	('2003-06-30', '2003-06-01'),
	('2003-07-01', '2003-07-01'),
	('2003-07-02', '2003-07-01'),
	('2003-07-03', '2003-07-01'),
	('2003-07-04', '2003-07-01'),
	('2003-07-05', '2003-07-01'),
	('2003-07-06', '2003-07-01'),
	('2003-07-07', '2003-07-01'),
	('2003-07-08', '2003-07-01'),
	('2003-07-09', '2003-07-01'),
	('2003-07-10', '2003-07-01'),
	('2003-07-11', '2003-07-01'),
	('2003-07-12', '2003-07-01'),
	('2003-07-13', '2003-07-01'),
	('2003-07-14', '2003-07-01'),
	('2003-07-15', '2003-07-01'),
	('2003-07-16', '2003-07-01'),
	('2003-07-17', '2003-07-01'),
	('2003-07-18', '2003-07-01'),
	('2003-07-19', '2003-07-01'),
	('2003-07-20', '2003-07-01'),
	('2003-07-21', '2003-07-01'),
	('2003-07-22', '2003-07-01'),
	('2003-07-23', '2003-07-01'),
	('2003-07-24', '2003-07-01'),
	('2003-07-25', '2003-07-01'),
	('2003-07-26', '2003-07-01'),
	('2003-07-27', '2003-07-01'),
	('2003-07-28', '2003-07-01'),
	('2003-07-29', '2003-07-01'),
	('2003-07-30', '2003-07-01'),
	('2003-07-31', '2003-07-01'),
	('2003-08-01', '2003-08-01'),
	('2003-08-02', '2003-08-01'),
	('2003-08-03', '2003-08-01'),
	('2003-08-04', '2003-08-01'),
	('2003-08-05', '2003-08-01'),
	('2003-08-06', '2003-08-01'),
	('2003-08-07', '2003-08-01'),
	('2003-08-08', '2003-08-01'),
	('2003-08-09', '2003-08-01'),
	('2003-08-10', '2003-08-01'),
	('2003-08-11', '2003-08-01'),
	('2003-08-12', '2003-08-01'),
	('2003-08-13', '2003-08-01'),
	('2003-08-14', '2003-08-01'),
	('2003-08-15', '2003-08-01'),
	('2003-08-16', '2003-08-01'),
	('2003-08-17', '2003-08-01'),
	('2003-08-18', '2003-08-01'),
	('2003-08-19', '2003-08-01'),
	('2003-08-20', '2003-08-01'),
	('2003-08-21', '2003-08-01'),
	('2003-08-22', '2003-08-01'),
	('2003-08-23', '2003-08-01'),
	('2003-08-24', '2003-08-01'),
	('2003-08-25', '2003-08-01'),
	('2003-08-26', '2003-08-01'),
	('2003-08-27', '2003-08-01'),
	('2003-08-28', '2003-08-01'),
	('2003-08-29', '2003-08-01'),
	('2003-08-30', '2003-08-01'),
	('2003-08-31', '2003-08-01'),
	('2003-09-01', '2003-09-01'),
	('2003-09-02', '2003-09-01'),
	('2003-09-03', '2003-09-01'),
	('2003-09-04', '2003-09-01'),
	('2003-09-05', '2003-09-01'),
	('2003-09-06', '2003-09-01'),
	('2003-09-07', '2003-09-01'),
	('2003-09-08', '2003-09-01'),
	('2003-09-09', '2003-09-01'),
	('2003-09-10', '2003-09-01'),
	('2003-09-11', '2003-09-01'),
	('2003-09-12', '2003-09-01'),
	('2003-09-13', '2003-09-01'),
	('2003-09-14', '2003-09-01'),
	('2003-09-15', '2003-09-01'),
	('2003-09-16', '2003-09-01'),
	('2003-09-17', '2003-09-01'),
	('2003-09-18', '2003-09-01'),
	('2003-09-19', '2003-09-01'),
	('2003-09-20', '2003-09-01'),
	('2003-09-21', '2003-09-01'),
	('2003-09-22', '2003-09-01'),
	('2003-09-23', '2003-09-01'),
	('2003-09-24', '2003-09-01'),
	('2003-09-25', '2003-09-01'),
	('2003-09-26', '2003-09-01'),
	('2003-09-27', '2003-09-01'),
	('2003-09-28', '2003-09-01'),
	('2003-09-29', '2003-09-01'),
	('2003-09-30', '2003-09-01'),
	('2003-10-01', '2003-10-01'),
	('2003-10-02', '2003-10-01'),
	('2003-10-03', '2003-10-01'),
	('2003-10-04', '2003-10-01'),
	('2003-10-05', '2003-10-01'),
	('2003-10-06', '2003-10-01'),
	('2003-10-07', '2003-10-01'),
	('2003-10-08', '2003-10-01'),
	('2003-10-09', '2003-10-01'),
	('2003-10-10', '2003-10-01'),
	('2003-10-11', '2003-10-01'),
	('2003-10-12', '2003-10-01'),
	('2003-10-13', '2003-10-01'),
	('2003-10-14', '2003-10-01'),
	('2003-10-15', '2003-10-01'),
	('2003-10-16', '2003-10-01'),
	('2003-10-17', '2003-10-01'),
	('2003-10-18', '2003-10-01'),
	('2003-10-19', '2003-10-01'),
	('2003-10-20', '2003-10-01'),
	('2003-10-21', '2003-10-01'),
	('2003-10-22', '2003-10-01'),
	('2003-10-23', '2003-10-01'),
	('2003-10-24', '2003-10-01'),
	('2003-10-25', '2003-10-01'),
	('2003-10-26', '2003-10-01'),
	('2003-10-27', '2003-10-01'),
	('2003-10-28', '2003-10-01'),
	('2003-10-29', '2003-10-01'),
	('2003-10-30', '2003-10-01'),
	('2003-10-31', '2003-10-01'),
	('2003-11-01', '2003-11-01'),
	('2003-11-02', '2003-11-01'),
	('2003-11-03', '2003-11-01'),
	('2003-11-04', '2003-11-01'),
	('2003-11-05', '2003-11-01'),
	('2003-11-06', '2003-11-01'),
	('2003-11-07', '2003-11-01'),
	('2003-11-08', '2003-11-01'),
	('2003-11-09', '2003-11-01'),
	('2003-11-10', '2003-11-01'),
	('2003-11-11', '2003-11-01'),
	('2003-11-12', '2003-11-01'),
	('2003-11-13', '2003-11-01'),
	('2003-11-14', '2003-11-01'),
	('2003-11-15', '2003-11-01'),
	('2003-11-16', '2003-11-01'),
	('2003-11-17', '2003-11-01'),
	('2003-11-18', '2003-11-01'),
	('2003-11-19', '2003-11-01'),
	('2003-11-20', '2003-11-01'),
	('2003-11-21', '2003-11-01'),
	('2003-11-22', '2003-11-01'),
	('2003-11-23', '2003-11-01'),
	('2003-11-24', '2003-11-01'),
	('2003-11-25', '2003-11-01'),
	('2003-11-26', '2003-11-01'),
	('2003-11-27', '2003-11-01'),
	('2003-11-28', '2003-11-01'),
	('2003-11-29', '2003-11-01'),
	('2003-11-30', '2003-11-01'),
	('2003-12-01', '2003-12-01'),
	('2003-12-02', '2003-12-01'),
	('2003-12-03', '2003-12-01'),
	('2003-12-04', '2003-12-01'),
	('2003-12-05', '2003-12-01'),
	('2003-12-06', '2003-12-01'),
	('2003-12-07', '2003-12-01'),
	('2003-12-08', '2003-12-01'),
	('2003-12-09', '2003-12-01'),
	('2003-12-10', '2003-12-01'),
	('2003-12-11', '2003-12-01'),
	('2003-12-12', '2003-12-01'),
	('2003-12-13', '2003-12-01'),
	('2003-12-14', '2003-12-01'),
	('2003-12-15', '2003-12-01'),
	('2003-12-16', '2003-12-01'),
	('2003-12-17', '2003-12-01'),
	('2003-12-18', '2003-12-01'),
	('2003-12-19', '2003-12-01'),
	('2003-12-20', '2003-12-01'),
	('2003-12-21', '2003-12-01'),
	('2003-12-22', '2003-12-01'),
	('2003-12-23', '2003-12-01'),
	('2003-12-24', '2003-12-01'),
	('2003-12-25', '2003-12-01'),
	('2003-12-26', '2003-12-01'),
	('2003-12-27', '2003-12-01'),
	('2003-12-28', '2003-12-01'),
	('2003-12-29', '2003-12-01'),
	('2003-12-30', '2003-12-01'),
	('2003-12-31', '2003-12-01'),
	('2004-01-01', '2004-01-01'),
	('2004-01-02', '2004-01-01'),
	('2004-01-03', '2004-01-01'),
	('2004-01-04', '2004-01-01'),
	('2004-01-05', '2004-01-01'),
	('2004-01-06', '2004-01-01'),
	('2004-01-07', '2004-01-01'),
	('2004-01-08', '2004-01-01'),
	('2004-01-09', '2004-01-01'),
	('2004-01-10', '2004-01-01'),
	('2004-01-11', '2004-01-01'),
	('2004-01-12', '2004-01-01'),
	('2004-01-13', '2004-01-01'),
	('2004-01-14', '2004-01-01'),
	('2004-01-15', '2004-01-01'),
	('2004-01-16', '2004-01-01'),
	('2004-01-17', '2004-01-01'),
	('2004-01-18', '2004-01-01'),
	('2004-01-19', '2004-01-01'),
	('2004-01-20', '2004-01-01'),
	('2004-01-21', '2004-01-01'),
	('2004-01-22', '2004-01-01'),
	('2004-01-23', '2004-01-01'),
	('2004-01-24', '2004-01-01'),
	('2004-01-25', '2004-01-01'),
	('2004-01-26', '2004-01-01'),
	('2004-01-27', '2004-01-01'),
	('2004-01-28', '2004-01-01'),
	('2004-01-29', '2004-01-01'),
	('2004-01-30', '2004-01-01'),
	('2004-01-31', '2004-01-01'),
	('2004-02-01', '2004-02-01'),
	('2004-02-02', '2004-02-01'),
	('2004-02-03', '2004-02-01'),
	('2004-02-04', '2004-02-01'),
	('2004-02-05', '2004-02-01'),
	('2004-02-06', '2004-02-01'),
	('2004-02-07', '2004-02-01'),
	('2004-02-08', '2004-02-01'),
	('2004-02-09', '2004-02-01'),
	('2004-02-10', '2004-02-01'),
	('2004-02-11', '2004-02-01'),
	('2004-02-12', '2004-02-01'),
	('2004-02-13', '2004-02-01'),
	('2004-02-14', '2004-02-01'),
	('2004-02-15', '2004-02-01'),
	('2004-02-16', '2004-02-01'),
	('2004-02-17', '2004-02-01'),
	('2004-02-18', '2004-02-01'),
	('2004-02-19', '2004-02-01'),
	('2004-02-20', '2004-02-01'),
	('2004-02-21', '2004-02-01'),
	('2004-02-22', '2004-02-01'),
	('2004-02-23', '2004-02-01'),
	('2004-02-24', '2004-02-01'),
	('2004-02-25', '2004-02-01'),
	('2004-02-26', '2004-02-01'),
	('2004-02-27', '2004-02-01'),
	('2004-02-28', '2004-02-01'),
	('2004-02-29', '2004-02-01'),
	('2004-03-01', '2004-03-01'),
	('2004-03-02', '2004-03-01'),
	('2004-03-03', '2004-03-01'),
	('2004-03-04', '2004-03-01'),
	('2004-03-05', '2004-03-01'),
	('2004-03-06', '2004-03-01'),
	('2004-03-07', '2004-03-01'),
	('2004-03-08', '2004-03-01'),
	('2004-03-09', '2004-03-01'),
	('2004-03-10', '2004-03-01'),
	('2004-03-11', '2004-03-01'),
	('2004-03-12', '2004-03-01'),
	('2004-03-13', '2004-03-01'),
	('2004-03-14', '2004-03-01'),
	('2004-03-15', '2004-03-01'),
	('2004-03-16', '2004-03-01'),
	('2004-03-17', '2004-03-01'),
	('2004-03-18', '2004-03-01'),
	('2004-03-19', '2004-03-01'),
	('2004-03-20', '2004-03-01'),
	('2004-03-21', '2004-03-01'),
	('2004-03-22', '2004-03-01'),
	('2004-03-23', '2004-03-01'),
	('2004-03-24', '2004-03-01'),
	('2004-03-25', '2004-03-01'),
	('2004-03-26', '2004-03-01'),
	('2004-03-27', '2004-03-01'),
	('2004-03-28', '2004-03-01'),
	('2004-03-29', '2004-03-01'),
	('2004-03-30', '2004-03-01'),
	('2004-03-31', '2004-03-01'),
	('2004-04-01', '2004-04-01'),
	('2004-04-02', '2004-04-01'),
	('2004-04-03', '2004-04-01'),
	('2004-04-04', '2004-04-01'),
	('2004-04-05', '2004-04-01'),
	('2004-04-06', '2004-04-01'),
	('2004-04-07', '2004-04-01'),
	('2004-04-08', '2004-04-01'),
	('2004-04-09', '2004-04-01'),
	('2004-04-10', '2004-04-01'),
	('2004-04-11', '2004-04-01'),
	('2004-04-12', '2004-04-01'),
	('2004-04-13', '2004-04-01'),
	('2004-04-14', '2004-04-01'),
	('2004-04-15', '2004-04-01'),
	('2004-04-16', '2004-04-01'),
	('2004-04-17', '2004-04-01'),
	('2004-04-18', '2004-04-01'),
	('2004-04-19', '2004-04-01'),
	('2004-04-20', '2004-04-01'),
	('2004-04-21', '2004-04-01'),
	('2004-04-22', '2004-04-01'),
	('2004-04-23', '2004-04-01'),
	('2004-04-24', '2004-04-01'),
	('2004-04-25', '2004-04-01'),
	('2004-04-26', '2004-04-01'),
	('2004-04-27', '2004-04-01'),
	('2004-04-28', '2004-04-01'),
	('2004-04-29', '2004-04-01'),
	('2004-04-30', '2004-04-01'),
	('2004-05-01', '2004-05-01'),
	('2004-05-02', '2004-05-01'),
	('2004-05-03', '2004-05-01'),
	('2004-05-04', '2004-05-01'),
	('2004-05-05', '2004-05-01'),
	('2004-05-06', '2004-05-01'),
	('2004-05-07', '2004-05-01'),
	('2004-05-08', '2004-05-01'),
	('2004-05-09', '2004-05-01'),
	('2004-05-10', '2004-05-01'),
	('2004-05-11', '2004-05-01'),
	('2004-05-12', '2004-05-01'),
	('2004-05-13', '2004-05-01'),
	('2004-05-14', '2004-05-01'),
	('2004-05-15', '2004-05-01'),
	('2004-05-16', '2004-05-01'),
	('2004-05-17', '2004-05-01'),
	('2004-05-18', '2004-05-01'),
	('2004-05-19', '2004-05-01'),
	('2004-05-20', '2004-05-01'),
	('2004-05-21', '2004-05-01'),
	('2004-05-22', '2004-05-01'),
	('2004-05-23', '2004-05-01'),
	('2004-05-24', '2004-05-01'),
	('2004-05-25', '2004-05-01'),
	('2004-05-26', '2004-05-01'),
	('2004-05-27', '2004-05-01'),
	('2004-05-28', '2004-05-01'),
	('2004-05-29', '2004-05-01'),
	('2004-05-30', '2004-05-01'),
	('2004-05-31', '2004-05-01'),
	('2004-06-01', '2004-06-01'),
	('2004-06-02', '2004-06-01'),
	('2004-06-03', '2004-06-01'),
	('2004-06-04', '2004-06-01'),
	('2004-06-05', '2004-06-01'),
	('2004-06-06', '2004-06-01'),
	('2004-06-07', '2004-06-01'),
	('2004-06-08', '2004-06-01'),
	('2004-06-09', '2004-06-01'),
	('2004-06-10', '2004-06-01'),
	('2004-06-11', '2004-06-01'),
	('2004-06-12', '2004-06-01'),
	('2004-06-13', '2004-06-01'),
	('2004-06-14', '2004-06-01'),
	('2004-06-15', '2004-06-01'),
	('2004-06-16', '2004-06-01'),
	('2004-06-17', '2004-06-01'),
	('2004-06-18', '2004-06-01'),
	('2004-06-19', '2004-06-01'),
	('2004-06-20', '2004-06-01'),
	('2004-06-21', '2004-06-01'),
	('2004-06-22', '2004-06-01'),
	('2004-06-23', '2004-06-01'),
	('2004-06-24', '2004-06-01'),
	('2004-06-25', '2004-06-01'),
	('2004-06-26', '2004-06-01'),
	('2004-06-27', '2004-06-01'),
	('2004-06-28', '2004-06-01'),
	('2004-06-29', '2004-06-01'),
	('2004-06-30', '2004-06-01'),
	('2004-07-01', '2004-07-01'),
	('2004-07-02', '2004-07-01'),
	('2004-07-03', '2004-07-01'),
	('2004-07-04', '2004-07-01'),
	('2004-07-05', '2004-07-01'),
	('2004-07-06', '2004-07-01'),
	('2004-07-07', '2004-07-01'),
	('2004-07-08', '2004-07-01'),
	('2004-07-09', '2004-07-01'),
	('2004-07-10', '2004-07-01'),
	('2004-07-11', '2004-07-01'),
	('2004-07-12', '2004-07-01'),
	('2004-07-13', '2004-07-01'),
	('2004-07-14', '2004-07-01'),
	('2004-07-15', '2004-07-01'),
	('2004-07-16', '2004-07-01'),
	('2004-07-17', '2004-07-01'),
	('2004-07-18', '2004-07-01'),
	('2004-07-19', '2004-07-01'),
	('2004-07-20', '2004-07-01'),
	('2004-07-21', '2004-07-01'),
	('2004-07-22', '2004-07-01'),
	('2004-07-23', '2004-07-01'),
	('2004-07-24', '2004-07-01'),
	('2004-07-25', '2004-07-01'),
	('2004-07-26', '2004-07-01'),
	('2004-07-27', '2004-07-01'),
	('2004-07-28', '2004-07-01'),
	('2004-07-29', '2004-07-01'),
	('2004-07-30', '2004-07-01'),
	('2004-07-31', '2004-07-01'),
	('2004-08-01', '2004-08-01'),
	('2004-08-02', '2004-08-01'),
	('2004-08-03', '2004-08-01'),
	('2004-08-04', '2004-08-01'),
	('2004-08-05', '2004-08-01'),
	('2004-08-06', '2004-08-01'),
	('2004-08-07', '2004-08-01'),
	('2004-08-08', '2004-08-01'),
	('2004-08-09', '2004-08-01'),
	('2004-08-10', '2004-08-01'),
	('2004-08-11', '2004-08-01'),
	('2004-08-12', '2004-08-01'),
	('2004-08-13', '2004-08-01'),
	('2004-08-14', '2004-08-01'),
	('2004-08-15', '2004-08-01'),
	('2004-08-16', '2004-08-01'),
	('2004-08-17', '2004-08-01'),
	('2004-08-18', '2004-08-01'),
	('2004-08-19', '2004-08-01'),
	('2004-08-20', '2004-08-01'),
	('2004-08-21', '2004-08-01'),
	('2004-08-22', '2004-08-01'),
	('2004-08-23', '2004-08-01'),
	('2004-08-24', '2004-08-01'),
	('2004-08-25', '2004-08-01'),
	('2004-08-26', '2004-08-01'),
	('2004-08-27', '2004-08-01'),
	('2004-08-28', '2004-08-01'),
	('2004-08-29', '2004-08-01'),
	('2004-08-30', '2004-08-01'),
	('2004-08-31', '2004-08-01'),
	('2004-09-01', '2004-09-01'),
	('2004-09-02', '2004-09-01'),
	('2004-09-03', '2004-09-01'),
	('2004-09-04', '2004-09-01'),
	('2004-09-05', '2004-09-01'),
	('2004-09-06', '2004-09-01'),
	('2004-09-07', '2004-09-01'),
	('2004-09-08', '2004-09-01'),
	('2004-09-09', '2004-09-01'),
	('2004-09-10', '2004-09-01'),
	('2004-09-11', '2004-09-01'),
	('2004-09-12', '2004-09-01'),
	('2004-09-13', '2004-09-01'),
	('2004-09-14', '2004-09-01'),
	('2004-09-15', '2004-09-01'),
	('2004-09-16', '2004-09-01'),
	('2004-09-17', '2004-09-01'),
	('2004-09-18', '2004-09-01'),
	('2004-09-19', '2004-09-01'),
	('2004-09-20', '2004-09-01'),
	('2004-09-21', '2004-09-01'),
	('2004-09-22', '2004-09-01'),
	('2004-09-23', '2004-09-01'),
	('2004-09-24', '2004-09-01'),
	('2004-09-25', '2004-09-01'),
	('2004-09-26', '2004-09-01'),
	('2004-09-27', '2004-09-01'),
	('2004-09-28', '2004-09-01'),
	('2004-09-29', '2004-09-01'),
	('2004-09-30', '2004-09-01'),
	('2004-10-01', '2004-10-01'),
	('2004-10-02', '2004-10-01'),
	('2004-10-03', '2004-10-01'),
	('2004-10-04', '2004-10-01'),
	('2004-10-05', '2004-10-01'),
	('2004-10-06', '2004-10-01'),
	('2004-10-07', '2004-10-01'),
	('2004-10-08', '2004-10-01'),
	('2004-10-09', '2004-10-01'),
	('2004-10-10', '2004-10-01'),
	('2004-10-11', '2004-10-01'),
	('2004-10-12', '2004-10-01'),
	('2004-10-13', '2004-10-01'),
	('2004-10-14', '2004-10-01'),
	('2004-10-15', '2004-10-01'),
	('2004-10-16', '2004-10-01'),
	('2004-10-17', '2004-10-01'),
	('2004-10-18', '2004-10-01'),
	('2004-10-19', '2004-10-01'),
	('2004-10-20', '2004-10-01'),
	('2004-10-21', '2004-10-01'),
	('2004-10-22', '2004-10-01'),
	('2004-10-23', '2004-10-01'),
	('2004-10-24', '2004-10-01'),
	('2004-10-25', '2004-10-01'),
	('2004-10-26', '2004-10-01'),
	('2004-10-27', '2004-10-01'),
	('2004-10-28', '2004-10-01'),
	('2004-10-29', '2004-10-01'),
	('2004-10-30', '2004-10-01'),
	('2004-10-31', '2004-10-01'),
	('2004-11-01', '2004-11-01'),
	('2004-11-02', '2004-11-01'),
	('2004-11-03', '2004-11-01'),
	('2004-11-04', '2004-11-01'),
	('2004-11-05', '2004-11-01'),
	('2004-11-06', '2004-11-01'),
	('2004-11-07', '2004-11-01'),
	('2004-11-08', '2004-11-01'),
	('2004-11-09', '2004-11-01'),
	('2004-11-10', '2004-11-01'),
	('2004-11-11', '2004-11-01'),
	('2004-11-12', '2004-11-01'),
	('2004-11-13', '2004-11-01'),
	('2004-11-14', '2004-11-01'),
	('2004-11-15', '2004-11-01'),
	('2004-11-16', '2004-11-01'),
	('2004-11-17', '2004-11-01'),
	('2004-11-18', '2004-11-01'),
	('2004-11-19', '2004-11-01'),
	('2004-11-20', '2004-11-01'),
	('2004-11-21', '2004-11-01'),
	('2004-11-22', '2004-11-01'),
	('2004-11-23', '2004-11-01'),
	('2004-11-24', '2004-11-01'),
	('2004-11-25', '2004-11-01'),
	('2004-11-26', '2004-11-01'),
	('2004-11-27', '2004-11-01'),
	('2004-11-28', '2004-11-01'),
	('2004-11-29', '2004-11-01'),
	('2004-11-30', '2004-11-01'),
	('2004-12-01', '2004-12-01'),
	('2004-12-02', '2004-12-01'),
	('2004-12-03', '2004-12-01'),
	('2004-12-04', '2004-12-01'),
	('2004-12-05', '2004-12-01'),
	('2004-12-06', '2004-12-01'),
	('2004-12-07', '2004-12-01'),
	('2004-12-08', '2004-12-01'),
	('2004-12-09', '2004-12-01'),
	('2004-12-10', '2004-12-01'),
	('2004-12-11', '2004-12-01'),
	('2004-12-12', '2004-12-01'),
	('2004-12-13', '2004-12-01'),
	('2004-12-14', '2004-12-01'),
	('2004-12-15', '2004-12-01'),
	('2004-12-16', '2004-12-01'),
	('2004-12-17', '2004-12-01'),
	('2004-12-18', '2004-12-01'),
	('2004-12-19', '2004-12-01'),
	('2004-12-20', '2004-12-01'),
	('2004-12-21', '2004-12-01'),
	('2004-12-22', '2004-12-01'),
	('2004-12-23', '2004-12-01'),
	('2004-12-24', '2004-12-01'),
	('2004-12-25', '2004-12-01'),
	('2004-12-26', '2004-12-01'),
	('2004-12-27', '2004-12-01'),
	('2004-12-28', '2004-12-01'),
	('2004-12-29', '2004-12-01'),
	('2004-12-30', '2004-12-01'),
	('2004-12-31', '2004-12-01'),
	('2005-01-01', '2005-01-01'),
	('2005-01-02', '2005-01-01'),
	('2005-01-03', '2005-01-01'),
	('2005-01-04', '2005-01-01'),
	('2005-01-05', '2005-01-01'),
	('2005-01-06', '2005-01-01'),
	('2005-01-07', '2005-01-01'),
	('2005-01-08', '2005-01-01'),
	('2005-01-09', '2005-01-01'),
	('2005-01-10', '2005-01-01'),
	('2005-01-11', '2005-01-01'),
	('2005-01-12', '2005-01-01'),
	('2005-01-13', '2005-01-01'),
	('2005-01-14', '2005-01-01'),
	('2005-01-15', '2005-01-01'),
	('2005-01-16', '2005-01-01'),
	('2005-01-17', '2005-01-01'),
	('2005-01-18', '2005-01-01'),
	('2005-01-19', '2005-01-01'),
	('2005-01-20', '2005-01-01'),
	('2005-01-21', '2005-01-01'),
	('2005-01-22', '2005-01-01'),
	('2005-01-23', '2005-01-01'),
	('2005-01-24', '2005-01-01'),
	('2005-01-25', '2005-01-01'),
	('2005-01-26', '2005-01-01'),
	('2005-01-27', '2005-01-01'),
	('2005-01-28', '2005-01-01'),
	('2005-01-29', '2005-01-01'),
	('2005-01-30', '2005-01-01'),
	('2005-01-31', '2005-01-01'),
	('2005-02-01', '2005-02-01'),
	('2005-02-02', '2005-02-01'),
	('2005-02-03', '2005-02-01'),
	('2005-02-04', '2005-02-01'),
	('2005-02-05', '2005-02-01'),
	('2005-02-06', '2005-02-01'),
	('2005-02-07', '2005-02-01'),
	('2005-02-08', '2005-02-01'),
	('2005-02-09', '2005-02-01'),
	('2005-02-10', '2005-02-01'),
	('2005-02-11', '2005-02-01'),
	('2005-02-12', '2005-02-01'),
	('2005-02-13', '2005-02-01'),
	('2005-02-14', '2005-02-01'),
	('2005-02-15', '2005-02-01'),
	('2005-02-16', '2005-02-01'),
	('2005-02-17', '2005-02-01'),
	('2005-02-18', '2005-02-01'),
	('2005-02-19', '2005-02-01'),
	('2005-02-20', '2005-02-01'),
	('2005-02-21', '2005-02-01'),
	('2005-02-22', '2005-02-01'),
	('2005-02-23', '2005-02-01'),
	('2005-02-24', '2005-02-01'),
	('2005-02-25', '2005-02-01'),
	('2005-02-26', '2005-02-01'),
	('2005-02-27', '2005-02-01'),
	('2005-02-28', '2005-02-01'),
	('2005-03-01', '2005-03-01'),
	('2005-03-02', '2005-03-01'),
	('2005-03-03', '2005-03-01'),
	('2005-03-04', '2005-03-01'),
	('2005-03-05', '2005-03-01'),
	('2005-03-06', '2005-03-01'),
	('2005-03-07', '2005-03-01'),
	('2005-03-08', '2005-03-01'),
	('2005-03-09', '2005-03-01'),
	('2005-03-10', '2005-03-01'),
	('2005-03-11', '2005-03-01'),
	('2005-03-12', '2005-03-01'),
	('2005-03-13', '2005-03-01'),
	('2005-03-14', '2005-03-01'),
	('2005-03-15', '2005-03-01'),
	('2005-03-16', '2005-03-01'),
	('2005-03-17', '2005-03-01'),
	('2005-03-18', '2005-03-01'),
	('2005-03-19', '2005-03-01'),
	('2005-03-20', '2005-03-01'),
	('2005-03-21', '2005-03-01'),
	('2005-03-22', '2005-03-01'),
	('2005-03-23', '2005-03-01'),
	('2005-03-24', '2005-03-01'),
	('2005-03-25', '2005-03-01'),
	('2005-03-26', '2005-03-01'),
	('2005-03-27', '2005-03-01'),
	('2005-03-28', '2005-03-01'),
	('2005-03-29', '2005-03-01'),
	('2005-03-30', '2005-03-01'),
	('2005-03-31', '2005-03-01'),
	('2005-04-01', '2005-04-01'),
	('2005-04-02', '2005-04-01'),
	('2005-04-03', '2005-04-01'),
	('2005-04-04', '2005-04-01'),
	('2005-04-05', '2005-04-01'),
	('2005-04-06', '2005-04-01'),
	('2005-04-07', '2005-04-01'),
	('2005-04-08', '2005-04-01'),
	('2005-04-09', '2005-04-01'),
	('2005-04-10', '2005-04-01'),
	('2005-04-11', '2005-04-01'),
	('2005-04-12', '2005-04-01'),
	('2005-04-13', '2005-04-01'),
	('2005-04-14', '2005-04-01'),
	('2005-04-15', '2005-04-01'),
	('2005-04-16', '2005-04-01'),
	('2005-04-17', '2005-04-01'),
	('2005-04-18', '2005-04-01'),
	('2005-04-19', '2005-04-01'),
	('2005-04-20', '2005-04-01'),
	('2005-04-21', '2005-04-01'),
	('2005-04-22', '2005-04-01'),
	('2005-04-23', '2005-04-01'),
	('2005-04-24', '2005-04-01'),
	('2005-04-25', '2005-04-01'),
	('2005-04-26', '2005-04-01'),
	('2005-04-27', '2005-04-01'),
	('2005-04-28', '2005-04-01'),
	('2005-04-29', '2005-04-01'),
	('2005-04-30', '2005-04-01'),
	('2005-05-01', '2005-05-01'),
	('2005-05-02', '2005-05-01'),
	('2005-05-03', '2005-05-01'),
	('2005-05-04', '2005-05-01'),
	('2005-05-05', '2005-05-01'),
	('2005-05-06', '2005-05-01'),
	('2005-05-07', '2005-05-01'),
	('2005-05-08', '2005-05-01'),
	('2005-05-09', '2005-05-01'),
	('2005-05-10', '2005-05-01'),
	('2005-05-11', '2005-05-01'),
	('2005-05-12', '2005-05-01'),
	('2005-05-13', '2005-05-01'),
	('2005-05-14', '2005-05-01'),
	('2005-05-15', '2005-05-01'),
	('2005-05-16', '2005-05-01'),
	('2005-05-17', '2005-05-01'),
	('2005-05-18', '2005-05-01'),
	('2005-05-19', '2005-05-01'),
	('2005-05-20', '2005-05-01'),
	('2005-05-21', '2005-05-01'),
	('2005-05-22', '2005-05-01'),
	('2005-05-23', '2005-05-01'),
	('2005-05-24', '2005-05-01'),
	('2005-05-25', '2005-05-01'),
	('2005-05-26', '2005-05-01'),
	('2005-05-27', '2005-05-01'),
	('2005-05-28', '2005-05-01'),
	('2005-05-29', '2005-05-01'),
	('2005-05-30', '2005-05-01'),
	('2005-05-31', '2005-05-01'),
	('2005-06-01', '2005-06-01'),
	('2005-06-02', '2005-06-01'),
	('2005-06-03', '2005-06-01'),
	('2005-06-04', '2005-06-01'),
	('2005-06-05', '2005-06-01'),
	('2005-06-06', '2005-06-01'),
	('2005-06-07', '2005-06-01'),
	('2005-06-08', '2005-06-01'),
	('2005-06-09', '2005-06-01'),
	('2005-06-10', '2005-06-01'),
	('2005-06-11', '2005-06-01'),
	('2005-06-12', '2005-06-01'),
	('2005-06-13', '2005-06-01'),
	('2005-06-14', '2005-06-01'),
	('2005-06-15', '2005-06-01'),
	('2005-06-16', '2005-06-01'),
	('2005-06-17', '2005-06-01'),
	('2005-06-18', '2005-06-01'),
	('2005-06-19', '2005-06-01'),
	('2005-06-20', '2005-06-01'),
	('2005-06-21', '2005-06-01'),
	('2005-06-22', '2005-06-01'),
	('2005-06-23', '2005-06-01'),
	('2005-06-24', '2005-06-01'),
	('2005-06-25', '2005-06-01'),
	('2005-06-26', '2005-06-01'),
	('2005-06-27', '2005-06-01'),
	('2005-06-28', '2005-06-01'),
	('2005-06-29', '2005-06-01'),
	('2005-06-30', '2005-06-01'),
	('2005-07-01', '2005-07-01'),
	('2005-07-02', '2005-07-01'),
	('2005-07-03', '2005-07-01'),
	('2005-07-04', '2005-07-01'),
	('2005-07-05', '2005-07-01'),
	('2005-07-06', '2005-07-01'),
	('2005-07-07', '2005-07-01'),
	('2005-07-08', '2005-07-01'),
	('2005-07-09', '2005-07-01'),
	('2005-07-10', '2005-07-01'),
	('2005-07-11', '2005-07-01'),
	('2005-07-12', '2005-07-01'),
	('2005-07-13', '2005-07-01'),
	('2005-07-14', '2005-07-01'),
	('2005-07-15', '2005-07-01'),
	('2005-07-16', '2005-07-01'),
	('2005-07-17', '2005-07-01'),
	('2005-07-18', '2005-07-01'),
	('2005-07-19', '2005-07-01'),
	('2005-07-20', '2005-07-01'),
	('2005-07-21', '2005-07-01'),
	('2005-07-22', '2005-07-01'),
	('2005-07-23', '2005-07-01'),
	('2005-07-24', '2005-07-01'),
	('2005-07-25', '2005-07-01'),
	('2005-07-26', '2005-07-01'),
	('2005-07-27', '2005-07-01'),
	('2005-07-28', '2005-07-01'),
	('2005-07-29', '2005-07-01'),
	('2005-07-30', '2005-07-01'),
	('2005-07-31', '2005-07-01'),
	('2005-08-01', '2005-08-01'),
	('2005-08-02', '2005-08-01'),
	('2005-08-03', '2005-08-01'),
	('2005-08-04', '2005-08-01'),
	('2005-08-05', '2005-08-01'),
	('2005-08-06', '2005-08-01'),
	('2005-08-07', '2005-08-01'),
	('2005-08-08', '2005-08-01'),
	('2005-08-09', '2005-08-01'),
	('2005-08-10', '2005-08-01'),
	('2005-08-11', '2005-08-01'),
	('2005-08-12', '2005-08-01'),
	('2005-08-13', '2005-08-01'),
	('2005-08-14', '2005-08-01'),
	('2005-08-15', '2005-08-01'),
	('2005-08-16', '2005-08-01'),
	('2005-08-17', '2005-08-01'),
	('2005-08-18', '2005-08-01'),
	('2005-08-19', '2005-08-01'),
	('2005-08-20', '2005-08-01'),
	('2005-08-21', '2005-08-01'),
	('2005-08-22', '2005-08-01'),
	('2005-08-23', '2005-08-01'),
	('2005-08-24', '2005-08-01'),
	('2005-08-25', '2005-08-01'),
	('2005-08-26', '2005-08-01'),
	('2005-08-27', '2005-08-01'),
	('2005-08-28', '2005-08-01'),
	('2005-08-29', '2005-08-01'),
	('2005-08-30', '2005-08-01'),
	('2005-08-31', '2005-08-01'),
	('2005-09-01', '2005-09-01'),
	('2005-09-02', '2005-09-01'),
	('2005-09-03', '2005-09-01'),
	('2005-09-04', '2005-09-01'),
	('2005-09-05', '2005-09-01'),
	('2005-09-06', '2005-09-01'),
	('2005-09-07', '2005-09-01'),
	('2005-09-08', '2005-09-01'),
	('2005-09-09', '2005-09-01'),
	('2005-09-10', '2005-09-01'),
	('2005-09-11', '2005-09-01'),
	('2005-09-12', '2005-09-01'),
	('2005-09-13', '2005-09-01'),
	('2005-09-14', '2005-09-01'),
	('2005-09-15', '2005-09-01'),
	('2005-09-16', '2005-09-01'),
	('2005-09-17', '2005-09-01'),
	('2005-09-18', '2005-09-01'),
	('2005-09-19', '2005-09-01'),
	('2005-09-20', '2005-09-01'),
	('2005-09-21', '2005-09-01'),
	('2005-09-22', '2005-09-01'),
	('2005-09-23', '2005-09-01'),
	('2005-09-24', '2005-09-01'),
	('2005-09-25', '2005-09-01'),
	('2005-09-26', '2005-09-01'),
	('2005-09-27', '2005-09-01'),
	('2005-09-28', '2005-09-01'),
	('2005-09-29', '2005-09-01'),
	('2005-09-30', '2005-09-01'),
	('2005-10-01', '2005-10-01'),
	('2005-10-02', '2005-10-01'),
	('2005-10-03', '2005-10-01'),
	('2005-10-04', '2005-10-01'),
	('2005-10-05', '2005-10-01'),
	('2005-10-06', '2005-10-01'),
	('2005-10-07', '2005-10-01'),
	('2005-10-08', '2005-10-01'),
	('2005-10-09', '2005-10-01'),
	('2005-10-10', '2005-10-01'),
	('2005-10-11', '2005-10-01'),
	('2005-10-12', '2005-10-01'),
	('2005-10-13', '2005-10-01'),
	('2005-10-14', '2005-10-01'),
	('2005-10-15', '2005-10-01'),
	('2005-10-16', '2005-10-01'),
	('2005-10-17', '2005-10-01'),
	('2005-10-18', '2005-10-01'),
	('2005-10-19', '2005-10-01'),
	('2005-10-20', '2005-10-01'),
	('2005-10-21', '2005-10-01'),
	('2005-10-22', '2005-10-01'),
	('2005-10-23', '2005-10-01'),
	('2005-10-24', '2005-10-01'),
	('2005-10-25', '2005-10-01'),
	('2005-10-26', '2005-10-01'),
	('2005-10-27', '2005-10-01'),
	('2005-10-28', '2005-10-01'),
	('2005-10-29', '2005-10-01'),
	('2005-10-30', '2005-10-01'),
	('2005-10-31', '2005-10-01'),
	('2005-11-01', '2005-11-01'),
	('2005-11-02', '2005-11-01'),
	('2005-11-03', '2005-11-01'),
	('2005-11-04', '2005-11-01'),
	('2005-11-05', '2005-11-01'),
	('2005-11-06', '2005-11-01'),
	('2005-11-07', '2005-11-01'),
	('2005-11-08', '2005-11-01'),
	('2005-11-09', '2005-11-01'),
	('2005-11-10', '2005-11-01'),
	('2005-11-11', '2005-11-01'),
	('2005-11-12', '2005-11-01'),
	('2005-11-13', '2005-11-01'),
	('2005-11-14', '2005-11-01'),
	('2005-11-15', '2005-11-01'),
	('2005-11-16', '2005-11-01'),
	('2005-11-17', '2005-11-01'),
	('2005-11-18', '2005-11-01'),
	('2005-11-19', '2005-11-01'),
	('2005-11-20', '2005-11-01'),
	('2005-11-21', '2005-11-01'),
	('2005-11-22', '2005-11-01'),
	('2005-11-23', '2005-11-01'),
	('2005-11-24', '2005-11-01'),
	('2005-11-25', '2005-11-01'),
	('2005-11-26', '2005-11-01'),
	('2005-11-27', '2005-11-01'),
	('2005-11-28', '2005-11-01'),
	('2005-11-29', '2005-11-01'),
	('2005-11-30', '2005-11-01'),
	('2005-12-01', '2005-12-01'),
	('2005-12-02', '2005-12-01'),
	('2005-12-03', '2005-12-01'),
	('2005-12-04', '2005-12-01'),
	('2005-12-05', '2005-12-01'),
	('2005-12-06', '2005-12-01'),
	('2005-12-07', '2005-12-01'),
	('2005-12-08', '2005-12-01'),
	('2005-12-09', '2005-12-01'),
	('2005-12-10', '2005-12-01'),
	('2005-12-11', '2005-12-01'),
	('2005-12-12', '2005-12-01'),
	('2005-12-13', '2005-12-01'),
	('2005-12-14', '2005-12-01'),
	('2005-12-15', '2005-12-01'),
	('2005-12-16', '2005-12-01'),
	('2005-12-17', '2005-12-01'),
	('2005-12-18', '2005-12-01'),
	('2005-12-19', '2005-12-01'),
	('2005-12-20', '2005-12-01'),
	('2005-12-21', '2005-12-01'),
	('2005-12-22', '2005-12-01'),
	('2005-12-23', '2005-12-01'),
	('2005-12-24', '2005-12-01'),
	('2005-12-25', '2005-12-01'),
	('2005-12-26', '2005-12-01'),
	('2005-12-27', '2005-12-01'),
	('2005-12-28', '2005-12-01'),
	('2005-12-29', '2005-12-01'),
	('2005-12-30', '2005-12-01'),
	('2005-12-31', '2005-12-01'),
	('2006-01-01', '2006-01-01'),
	('2006-01-02', '2006-01-01'),
	('2006-01-03', '2006-01-01'),
	('2006-01-04', '2006-01-01'),
	('2006-01-05', '2006-01-01'),
	('2006-01-06', '2006-01-01'),
	('2006-01-07', '2006-01-01'),
	('2006-01-08', '2006-01-01'),
	('2006-01-09', '2006-01-01'),
	('2006-01-10', '2006-01-01'),
	('2006-01-11', '2006-01-01'),
	('2006-01-12', '2006-01-01'),
	('2006-01-13', '2006-01-01'),
	('2006-01-14', '2006-01-01'),
	('2006-01-15', '2006-01-01'),
	('2006-01-16', '2006-01-01'),
	('2006-01-17', '2006-01-01'),
	('2006-01-18', '2006-01-01'),
	('2006-01-19', '2006-01-01'),
	('2006-01-20', '2006-01-01'),
	('2006-01-21', '2006-01-01'),
	('2006-01-22', '2006-01-01'),
	('2006-01-23', '2006-01-01'),
	('2006-01-24', '2006-01-01'),
	('2006-01-25', '2006-01-01'),
	('2006-01-26', '2006-01-01'),
	('2006-01-27', '2006-01-01'),
	('2006-01-28', '2006-01-01'),
	('2006-01-29', '2006-01-01'),
	('2006-01-30', '2006-01-01'),
	('2006-01-31', '2006-01-01'),
	('2006-02-01', '2006-02-01'),
	('2006-02-02', '2006-02-01'),
	('2006-02-03', '2006-02-01'),
	('2006-02-04', '2006-02-01'),
	('2006-02-05', '2006-02-01'),
	('2006-02-06', '2006-02-01'),
	('2006-02-07', '2006-02-01'),
	('2006-02-08', '2006-02-01'),
	('2006-02-09', '2006-02-01'),
	('2006-02-10', '2006-02-01'),
	('2006-02-11', '2006-02-01'),
	('2006-02-12', '2006-02-01'),
	('2006-02-13', '2006-02-01'),
	('2006-02-14', '2006-02-01'),
	('2006-02-15', '2006-02-01'),
	('2006-02-16', '2006-02-01'),
	('2006-02-17', '2006-02-01'),
	('2006-02-18', '2006-02-01'),
	('2006-02-19', '2006-02-01'),
	('2006-02-20', '2006-02-01'),
	('2006-02-21', '2006-02-01'),
	('2006-02-22', '2006-02-01'),
	('2006-02-23', '2006-02-01'),
	('2006-02-24', '2006-02-01'),
	('2006-02-25', '2006-02-01'),
	('2006-02-26', '2006-02-01'),
	('2006-02-27', '2006-02-01'),
	('2006-02-28', '2006-02-01'),
	('2006-03-01', '2006-03-01'),
	('2006-03-02', '2006-03-01'),
	('2006-03-03', '2006-03-01'),
	('2006-03-04', '2006-03-01'),
	('2006-03-05', '2006-03-01'),
	('2006-03-06', '2006-03-01'),
	('2006-03-07', '2006-03-01'),
	('2006-03-08', '2006-03-01'),
	('2006-03-09', '2006-03-01'),
	('2006-03-10', '2006-03-01'),
	('2006-03-11', '2006-03-01'),
	('2006-03-12', '2006-03-01'),
	('2006-03-13', '2006-03-01'),
	('2006-03-14', '2006-03-01'),
	('2006-03-15', '2006-03-01'),
	('2006-03-16', '2006-03-01'),
	('2006-03-17', '2006-03-01'),
	('2006-03-18', '2006-03-01'),
	('2006-03-19', '2006-03-01'),
	('2006-03-20', '2006-03-01'),
	('2006-03-21', '2006-03-01'),
	('2006-03-22', '2006-03-01'),
	('2006-03-23', '2006-03-01'),
	('2006-03-24', '2006-03-01'),
	('2006-03-25', '2006-03-01'),
	('2006-03-26', '2006-03-01'),
	('2006-03-27', '2006-03-01'),
	('2006-03-28', '2006-03-01'),
	('2006-03-29', '2006-03-01'),
	('2006-03-30', '2006-03-01'),
	('2006-03-31', '2006-03-01'),
	('2006-04-01', '2006-04-01'),
	('2006-04-02', '2006-04-01'),
	('2006-04-03', '2006-04-01'),
	('2006-04-04', '2006-04-01'),
	('2006-04-05', '2006-04-01'),
	('2006-04-06', '2006-04-01'),
	('2006-04-07', '2006-04-01'),
	('2006-04-08', '2006-04-01'),
	('2006-04-09', '2006-04-01'),
	('2006-04-10', '2006-04-01'),
	('2006-04-11', '2006-04-01'),
	('2006-04-12', '2006-04-01'),
	('2006-04-13', '2006-04-01'),
	('2006-04-14', '2006-04-01'),
	('2006-04-15', '2006-04-01'),
	('2006-04-16', '2006-04-01'),
	('2006-04-17', '2006-04-01'),
	('2006-04-18', '2006-04-01'),
	('2006-04-19', '2006-04-01'),
	('2006-04-20', '2006-04-01'),
	('2006-04-21', '2006-04-01'),
	('2006-04-22', '2006-04-01'),
	('2006-04-23', '2006-04-01'),
	('2006-04-24', '2006-04-01'),
	('2006-04-25', '2006-04-01'),
	('2006-04-26', '2006-04-01'),
	('2006-04-27', '2006-04-01'),
	('2006-04-28', '2006-04-01'),
	('2006-04-29', '2006-04-01'),
	('2006-04-30', '2006-04-01'),
	('2006-05-01', '2006-05-01'),
	('2006-05-02', '2006-05-01'),
	('2006-05-03', '2006-05-01'),
	('2006-05-04', '2006-05-01'),
	('2006-05-05', '2006-05-01'),
	('2006-05-06', '2006-05-01'),
	('2006-05-07', '2006-05-01'),
	('2006-05-08', '2006-05-01'),
	('2006-05-09', '2006-05-01'),
	('2006-05-10', '2006-05-01'),
	('2006-05-11', '2006-05-01'),
	('2006-05-12', '2006-05-01'),
	('2006-05-13', '2006-05-01'),
	('2006-05-14', '2006-05-01'),
	('2006-05-15', '2006-05-01'),
	('2006-05-16', '2006-05-01'),
	('2006-05-17', '2006-05-01'),
	('2006-05-18', '2006-05-01'),
	('2006-05-19', '2006-05-01'),
	('2006-05-20', '2006-05-01'),
	('2006-05-21', '2006-05-01'),
	('2006-05-22', '2006-05-01'),
	('2006-05-23', '2006-05-01'),
	('2006-05-24', '2006-05-01'),
	('2006-05-25', '2006-05-01'),
	('2006-05-26', '2006-05-01'),
	('2006-05-27', '2006-05-01'),
	('2006-05-28', '2006-05-01'),
	('2006-05-29', '2006-05-01'),
	('2006-05-30', '2006-05-01'),
	('2006-05-31', '2006-05-01'),
	('2006-06-01', '2006-06-01'),
	('2006-06-02', '2006-06-01'),
	('2006-06-03', '2006-06-01'),
	('2006-06-04', '2006-06-01'),
	('2006-06-05', '2006-06-01'),
	('2006-06-06', '2006-06-01'),
	('2006-06-07', '2006-06-01'),
	('2006-06-08', '2006-06-01'),
	('2006-06-09', '2006-06-01'),
	('2006-06-10', '2006-06-01'),
	('2006-06-11', '2006-06-01'),
	('2006-06-12', '2006-06-01'),
	('2006-06-13', '2006-06-01'),
	('2006-06-14', '2006-06-01'),
	('2006-06-15', '2006-06-01'),
	('2006-06-16', '2006-06-01'),
	('2006-06-17', '2006-06-01'),
	('2006-06-18', '2006-06-01'),
	('2006-06-19', '2006-06-01'),
	('2006-06-20', '2006-06-01'),
	('2006-06-21', '2006-06-01'),
	('2006-06-22', '2006-06-01'),
	('2006-06-23', '2006-06-01'),
	('2006-06-24', '2006-06-01'),
	('2006-06-25', '2006-06-01'),
	('2006-06-26', '2006-06-01'),
	('2006-06-27', '2006-06-01'),
	('2006-06-28', '2006-06-01'),
	('2006-06-29', '2006-06-01'),
	('2006-06-30', '2006-06-01'),
	('2006-07-01', '2006-07-01'),
	('2006-07-02', '2006-07-01'),
	('2006-07-03', '2006-07-01'),
	('2006-07-04', '2006-07-01'),
	('2006-07-05', '2006-07-01'),
	('2006-07-06', '2006-07-01'),
	('2006-07-07', '2006-07-01'),
	('2006-07-08', '2006-07-01'),
	('2006-07-09', '2006-07-01'),
	('2006-07-10', '2006-07-01'),
	('2006-07-11', '2006-07-01'),
	('2006-07-12', '2006-07-01'),
	('2006-07-13', '2006-07-01'),
	('2006-07-14', '2006-07-01'),
	('2006-07-15', '2006-07-01'),
	('2006-07-16', '2006-07-01'),
	('2006-07-17', '2006-07-01'),
	('2006-07-18', '2006-07-01'),
	('2006-07-19', '2006-07-01'),
	('2006-07-20', '2006-07-01'),
	('2006-07-21', '2006-07-01'),
	('2006-07-22', '2006-07-01'),
	('2006-07-23', '2006-07-01'),
	('2006-07-24', '2006-07-01'),
	('2006-07-25', '2006-07-01'),
	('2006-07-26', '2006-07-01'),
	('2006-07-27', '2006-07-01'),
	('2006-07-28', '2006-07-01'),
	('2006-07-29', '2006-07-01'),
	('2006-07-30', '2006-07-01'),
	('2006-07-31', '2006-07-01'),
	('2006-08-01', '2006-08-01'),
	('2006-08-02', '2006-08-01'),
	('2006-08-03', '2006-08-01'),
	('2006-08-04', '2006-08-01'),
	('2006-08-05', '2006-08-01'),
	('2006-08-06', '2006-08-01'),
	('2006-08-07', '2006-08-01'),
	('2006-08-08', '2006-08-01'),
	('2006-08-09', '2006-08-01'),
	('2006-08-10', '2006-08-01'),
	('2006-08-11', '2006-08-01'),
	('2006-08-12', '2006-08-01'),
	('2006-08-13', '2006-08-01'),
	('2006-08-14', '2006-08-01'),
	('2006-08-15', '2006-08-01'),
	('2006-08-16', '2006-08-01'),
	('2006-08-17', '2006-08-01'),
	('2006-08-18', '2006-08-01'),
	('2006-08-19', '2006-08-01'),
	('2006-08-20', '2006-08-01'),
	('2006-08-21', '2006-08-01'),
	('2006-08-22', '2006-08-01'),
	('2006-08-23', '2006-08-01'),
	('2006-08-24', '2006-08-01'),
	('2006-08-25', '2006-08-01'),
	('2006-08-26', '2006-08-01'),
	('2006-08-27', '2006-08-01'),
	('2006-08-28', '2006-08-01'),
	('2006-08-29', '2006-08-01'),
	('2006-08-30', '2006-08-01'),
	('2006-08-31', '2006-08-01'),
	('2006-09-01', '2006-09-01'),
	('2006-09-02', '2006-09-01'),
	('2006-09-03', '2006-09-01'),
	('2006-09-04', '2006-09-01'),
	('2006-09-05', '2006-09-01'),
	('2006-09-06', '2006-09-01'),
	('2006-09-07', '2006-09-01'),
	('2006-09-08', '2006-09-01'),
	('2006-09-09', '2006-09-01'),
	('2006-09-10', '2006-09-01'),
	('2006-09-11', '2006-09-01'),
	('2006-09-12', '2006-09-01'),
	('2006-09-13', '2006-09-01'),
	('2006-09-14', '2006-09-01'),
	('2006-09-15', '2006-09-01'),
	('2006-09-16', '2006-09-01'),
	('2006-09-17', '2006-09-01'),
	('2006-09-18', '2006-09-01'),
	('2006-09-19', '2006-09-01'),
	('2006-09-20', '2006-09-01'),
	('2006-09-21', '2006-09-01'),
	('2006-09-22', '2006-09-01'),
	('2006-09-23', '2006-09-01'),
	('2006-09-24', '2006-09-01'),
	('2006-09-25', '2006-09-01'),
	('2006-09-26', '2006-09-01'),
	('2006-09-27', '2006-09-01'),
	('2006-09-28', '2006-09-01'),
	('2006-09-29', '2006-09-01'),
	('2006-09-30', '2006-09-01'),
	('2006-10-01', '2006-10-01'),
	('2006-10-02', '2006-10-01'),
	('2006-10-03', '2006-10-01'),
	('2006-10-04', '2006-10-01'),
	('2006-10-05', '2006-10-01'),
	('2006-10-06', '2006-10-01'),
	('2006-10-07', '2006-10-01'),
	('2006-10-08', '2006-10-01'),
	('2006-10-09', '2006-10-01'),
	('2006-10-10', '2006-10-01'),
	('2006-10-11', '2006-10-01'),
	('2006-10-12', '2006-10-01'),
	('2006-10-13', '2006-10-01'),
	('2006-10-14', '2006-10-01'),
	('2006-10-15', '2006-10-01'),
	('2006-10-16', '2006-10-01'),
	('2006-10-17', '2006-10-01'),
	('2006-10-18', '2006-10-01'),
	('2006-10-19', '2006-10-01'),
	('2006-10-20', '2006-10-01'),
	('2006-10-21', '2006-10-01'),
	('2006-10-22', '2006-10-01'),
	('2006-10-23', '2006-10-01'),
	('2006-10-24', '2006-10-01'),
	('2006-10-25', '2006-10-01'),
	('2006-10-26', '2006-10-01'),
	('2006-10-27', '2006-10-01'),
	('2006-10-28', '2006-10-01'),
	('2006-10-29', '2006-10-01'),
	('2006-10-30', '2006-10-01'),
	('2006-10-31', '2006-10-01'),
	('2006-11-01', '2006-11-01'),
	('2006-11-02', '2006-11-01'),
	('2006-11-03', '2006-11-01'),
	('2006-11-04', '2006-11-01'),
	('2006-11-05', '2006-11-01'),
	('2006-11-06', '2006-11-01'),
	('2006-11-07', '2006-11-01'),
	('2006-11-08', '2006-11-01'),
	('2006-11-09', '2006-11-01'),
	('2006-11-10', '2006-11-01'),
	('2006-11-11', '2006-11-01'),
	('2006-11-12', '2006-11-01'),
	('2006-11-13', '2006-11-01'),
	('2006-11-14', '2006-11-01'),
	('2006-11-15', '2006-11-01'),
	('2006-11-16', '2006-11-01'),
	('2006-11-17', '2006-11-01'),
	('2006-11-18', '2006-11-01'),
	('2006-11-19', '2006-11-01'),
	('2006-11-20', '2006-11-01'),
	('2006-11-21', '2006-11-01'),
	('2006-11-22', '2006-11-01'),
	('2006-11-23', '2006-11-01'),
	('2006-11-24', '2006-11-01'),
	('2006-11-25', '2006-11-01'),
	('2006-11-26', '2006-11-01'),
	('2006-11-27', '2006-11-01'),
	('2006-11-28', '2006-11-01'),
	('2006-11-29', '2006-11-01'),
	('2006-11-30', '2006-11-01'),
	('2006-12-01', '2006-12-01'),
	('2006-12-02', '2006-12-01'),
	('2006-12-03', '2006-12-01'),
	('2006-12-04', '2006-12-01'),
	('2006-12-05', '2006-12-01'),
	('2006-12-06', '2006-12-01'),
	('2006-12-07', '2006-12-01'),
	('2006-12-08', '2006-12-01'),
	('2006-12-09', '2006-12-01'),
	('2006-12-10', '2006-12-01'),
	('2006-12-11', '2006-12-01'),
	('2006-12-12', '2006-12-01'),
	('2006-12-13', '2006-12-01'),
	('2006-12-14', '2006-12-01'),
	('2006-12-15', '2006-12-01'),
	('2006-12-16', '2006-12-01'),
	('2006-12-17', '2006-12-01'),
	('2006-12-18', '2006-12-01'),
	('2006-12-19', '2006-12-01'),
	('2006-12-20', '2006-12-01'),
	('2006-12-21', '2006-12-01'),
	('2006-12-22', '2006-12-01'),
	('2006-12-23', '2006-12-01'),
	('2006-12-24', '2006-12-01'),
	('2006-12-25', '2006-12-01'),
	('2006-12-26', '2006-12-01'),
	('2006-12-27', '2006-12-01'),
	('2006-12-28', '2006-12-01'),
	('2006-12-29', '2006-12-01'),
	('2006-12-30', '2006-12-01'),
	('2006-12-31', '2006-12-01'),
	('2007-01-01', '2007-01-01'),
	('2007-01-02', '2007-01-01'),
	('2007-01-03', '2007-01-01'),
	('2007-01-04', '2007-01-01'),
	('2007-01-05', '2007-01-01'),
	('2007-01-06', '2007-01-01'),
	('2007-01-07', '2007-01-01'),
	('2007-01-08', '2007-01-01'),
	('2007-01-09', '2007-01-01'),
	('2007-01-10', '2007-01-01'),
	('2007-01-11', '2007-01-01'),
	('2007-01-12', '2007-01-01'),
	('2007-01-13', '2007-01-01'),
	('2007-01-14', '2007-01-01'),
	('2007-01-15', '2007-01-01'),
	('2007-01-16', '2007-01-01'),
	('2007-01-17', '2007-01-01'),
	('2007-01-18', '2007-01-01'),
	('2007-01-19', '2007-01-01'),
	('2007-01-20', '2007-01-01'),
	('2007-01-21', '2007-01-01'),
	('2007-01-22', '2007-01-01'),
	('2007-01-23', '2007-01-01'),
	('2007-01-24', '2007-01-01'),
	('2007-01-25', '2007-01-01'),
	('2007-01-26', '2007-01-01'),
	('2007-01-27', '2007-01-01'),
	('2007-01-28', '2007-01-01'),
	('2007-01-29', '2007-01-01'),
	('2007-01-30', '2007-01-01'),
	('2007-01-31', '2007-01-01'),
	('2007-02-01', '2007-02-01'),
	('2007-02-02', '2007-02-01'),
	('2007-02-03', '2007-02-01'),
	('2007-02-04', '2007-02-01'),
	('2007-02-05', '2007-02-01'),
	('2007-02-06', '2007-02-01'),
	('2007-02-07', '2007-02-01'),
	('2007-02-08', '2007-02-01'),
	('2007-02-09', '2007-02-01'),
	('2007-02-10', '2007-02-01'),
	('2007-02-11', '2007-02-01'),
	('2007-02-12', '2007-02-01'),
	('2007-02-13', '2007-02-01'),
	('2007-02-14', '2007-02-01'),
	('2007-02-15', '2007-02-01'),
	('2007-02-16', '2007-02-01'),
	('2007-02-17', '2007-02-01'),
	('2007-02-18', '2007-02-01'),
	('2007-02-19', '2007-02-01'),
	('2007-02-20', '2007-02-01'),
	('2007-02-21', '2007-02-01'),
	('2007-02-22', '2007-02-01'),
	('2007-02-23', '2007-02-01'),
	('2007-02-24', '2007-02-01'),
	('2007-02-25', '2007-02-01'),
	('2007-02-26', '2007-02-01'),
	('2007-02-27', '2007-02-01'),
	('2007-02-28', '2007-02-01'),
	('2007-03-01', '2007-03-01'),
	('2007-03-02', '2007-03-01'),
	('2007-03-03', '2007-03-01'),
	('2007-03-04', '2007-03-01'),
	('2007-03-05', '2007-03-01'),
	('2007-03-06', '2007-03-01'),
	('2007-03-07', '2007-03-01'),
	('2007-03-08', '2007-03-01'),
	('2007-03-09', '2007-03-01'),
	('2007-03-10', '2007-03-01'),
	('2007-03-11', '2007-03-01'),
	('2007-03-12', '2007-03-01'),
	('2007-03-13', '2007-03-01'),
	('2007-03-14', '2007-03-01'),
	('2007-03-15', '2007-03-01'),
	('2007-03-16', '2007-03-01'),
	('2007-03-17', '2007-03-01'),
	('2007-03-18', '2007-03-01'),
	('2007-03-19', '2007-03-01'),
	('2007-03-20', '2007-03-01'),
	('2007-03-21', '2007-03-01'),
	('2007-03-22', '2007-03-01'),
	('2007-03-23', '2007-03-01'),
	('2007-03-24', '2007-03-01'),
	('2007-03-25', '2007-03-01'),
	('2007-03-26', '2007-03-01'),
	('2007-03-27', '2007-03-01'),
	('2007-03-28', '2007-03-01'),
	('2007-03-29', '2007-03-01'),
	('2007-03-30', '2007-03-01'),
	('2007-03-31', '2007-03-01'),
	('2007-04-01', '2007-04-01'),
	('2007-04-02', '2007-04-01'),
	('2007-04-03', '2007-04-01'),
	('2007-04-04', '2007-04-01'),
	('2007-04-05', '2007-04-01'),
	('2007-04-06', '2007-04-01'),
	('2007-04-07', '2007-04-01'),
	('2007-04-08', '2007-04-01'),
	('2007-04-09', '2007-04-01'),
	('2007-04-10', '2007-04-01'),
	('2007-04-11', '2007-04-01'),
	('2007-04-12', '2007-04-01'),
	('2007-04-13', '2007-04-01'),
	('2007-04-14', '2007-04-01'),
	('2007-04-15', '2007-04-01'),
	('2007-04-16', '2007-04-01'),
	('2007-04-17', '2007-04-01'),
	('2007-04-18', '2007-04-01'),
	('2007-04-19', '2007-04-01'),
	('2007-04-20', '2007-04-01'),
	('2007-04-21', '2007-04-01'),
	('2007-04-22', '2007-04-01'),
	('2007-04-23', '2007-04-01'),
	('2007-04-24', '2007-04-01'),
	('2007-04-25', '2007-04-01'),
	('2007-04-26', '2007-04-01'),
	('2007-04-27', '2007-04-01'),
	('2007-04-28', '2007-04-01'),
	('2007-04-29', '2007-04-01'),
	('2007-04-30', '2007-04-01'),
	('2007-05-01', '2007-05-01'),
	('2007-05-02', '2007-05-01'),
	('2007-05-03', '2007-05-01'),
	('2007-05-04', '2007-05-01'),
	('2007-05-05', '2007-05-01'),
	('2007-05-06', '2007-05-01'),
	('2007-05-07', '2007-05-01'),
	('2007-05-08', '2007-05-01'),
	('2007-05-09', '2007-05-01'),
	('2007-05-10', '2007-05-01'),
	('2007-05-11', '2007-05-01'),
	('2007-05-12', '2007-05-01'),
	('2007-05-13', '2007-05-01'),
	('2007-05-14', '2007-05-01'),
	('2007-05-15', '2007-05-01'),
	('2007-05-16', '2007-05-01'),
	('2007-05-17', '2007-05-01'),
	('2007-05-18', '2007-05-01'),
	('2007-05-19', '2007-05-01'),
	('2007-05-20', '2007-05-01'),
	('2007-05-21', '2007-05-01'),
	('2007-05-22', '2007-05-01'),
	('2007-05-23', '2007-05-01'),
	('2007-05-24', '2007-05-01'),
	('2007-05-25', '2007-05-01'),
	('2007-05-26', '2007-05-01'),
	('2007-05-27', '2007-05-01'),
	('2007-05-28', '2007-05-01'),
	('2007-05-29', '2007-05-01'),
	('2007-05-30', '2007-05-01'),
	('2007-05-31', '2007-05-01'),
	('2007-06-01', '2007-06-01'),
	('2007-06-02', '2007-06-01'),
	('2007-06-03', '2007-06-01'),
	('2007-06-04', '2007-06-01'),
	('2007-06-05', '2007-06-01'),
	('2007-06-06', '2007-06-01'),
	('2007-06-07', '2007-06-01'),
	('2007-06-08', '2007-06-01'),
	('2007-06-09', '2007-06-01'),
	('2007-06-10', '2007-06-01'),
	('2007-06-11', '2007-06-01'),
	('2007-06-12', '2007-06-01'),
	('2007-06-13', '2007-06-01'),
	('2007-06-14', '2007-06-01'),
	('2007-06-15', '2007-06-01'),
	('2007-06-16', '2007-06-01'),
	('2007-06-17', '2007-06-01'),
	('2007-06-18', '2007-06-01'),
	('2007-06-19', '2007-06-01'),
	('2007-06-20', '2007-06-01'),
	('2007-06-21', '2007-06-01'),
	('2007-06-22', '2007-06-01'),
	('2007-06-23', '2007-06-01'),
	('2007-06-24', '2007-06-01'),
	('2007-06-25', '2007-06-01'),
	('2007-06-26', '2007-06-01'),
	('2007-06-27', '2007-06-01'),
	('2007-06-28', '2007-06-01'),
	('2007-06-29', '2007-06-01'),
	('2007-06-30', '2007-06-01'),
	('2007-07-01', '2007-07-01'),
	('2007-07-02', '2007-07-01'),
	('2007-07-03', '2007-07-01'),
	('2007-07-04', '2007-07-01'),
	('2007-07-05', '2007-07-01'),
	('2007-07-06', '2007-07-01'),
	('2007-07-07', '2007-07-01'),
	('2007-07-08', '2007-07-01'),
	('2007-07-09', '2007-07-01'),
	('2007-07-10', '2007-07-01'),
	('2007-07-11', '2007-07-01'),
	('2007-07-12', '2007-07-01'),
	('2007-07-13', '2007-07-01'),
	('2007-07-14', '2007-07-01'),
	('2007-07-15', '2007-07-01'),
	('2007-07-16', '2007-07-01'),
	('2007-07-17', '2007-07-01'),
	('2007-07-18', '2007-07-01'),
	('2007-07-19', '2007-07-01'),
	('2007-07-20', '2007-07-01'),
	('2007-07-21', '2007-07-01'),
	('2007-07-22', '2007-07-01'),
	('2007-07-23', '2007-07-01'),
	('2007-07-24', '2007-07-01'),
	('2007-07-25', '2007-07-01'),
	('2007-07-26', '2007-07-01'),
	('2007-07-27', '2007-07-01'),
	('2007-07-28', '2007-07-01'),
	('2007-07-29', '2007-07-01'),
	('2007-07-30', '2007-07-01'),
	('2007-07-31', '2007-07-01'),
	('2007-08-01', '2007-08-01'),
	('2007-08-02', '2007-08-01'),
	('2007-08-03', '2007-08-01'),
	('2007-08-04', '2007-08-01'),
	('2007-08-05', '2007-08-01'),
	('2007-08-06', '2007-08-01'),
	('2007-08-07', '2007-08-01'),
	('2007-08-08', '2007-08-01'),
	('2007-08-09', '2007-08-01'),
	('2007-08-10', '2007-08-01'),
	('2007-08-11', '2007-08-01'),
	('2007-08-12', '2007-08-01'),
	('2007-08-13', '2007-08-01'),
	('2007-08-14', '2007-08-01'),
	('2007-08-15', '2007-08-01'),
	('2007-08-16', '2007-08-01'),
	('2007-08-17', '2007-08-01'),
	('2007-08-18', '2007-08-01'),
	('2007-08-19', '2007-08-01'),
	('2007-08-20', '2007-08-01'),
	('2007-08-21', '2007-08-01'),
	('2007-08-22', '2007-08-01'),
	('2007-08-23', '2007-08-01'),
	('2007-08-24', '2007-08-01'),
	('2007-08-25', '2007-08-01'),
	('2007-08-26', '2007-08-01'),
	('2007-08-27', '2007-08-01'),
	('2007-08-28', '2007-08-01'),
	('2007-08-29', '2007-08-01'),
	('2007-08-30', '2007-08-01'),
	('2007-08-31', '2007-08-01'),
	('2007-09-01', '2007-09-01'),
	('2007-09-02', '2007-09-01'),
	('2007-09-03', '2007-09-01'),
	('2007-09-04', '2007-09-01'),
	('2007-09-05', '2007-09-01'),
	('2007-09-06', '2007-09-01'),
	('2007-09-07', '2007-09-01'),
	('2007-09-08', '2007-09-01'),
	('2007-09-09', '2007-09-01'),
	('2007-09-10', '2007-09-01'),
	('2007-09-11', '2007-09-01'),
	('2007-09-12', '2007-09-01'),
	('2007-09-13', '2007-09-01'),
	('2007-09-14', '2007-09-01'),
	('2007-09-15', '2007-09-01'),
	('2007-09-16', '2007-09-01'),
	('2007-09-17', '2007-09-01'),
	('2007-09-18', '2007-09-01'),
	('2007-09-19', '2007-09-01'),
	('2007-09-20', '2007-09-01'),
	('2007-09-21', '2007-09-01'),
	('2007-09-22', '2007-09-01'),
	('2007-09-23', '2007-09-01'),
	('2007-09-24', '2007-09-01'),
	('2007-09-25', '2007-09-01'),
	('2007-09-26', '2007-09-01'),
	('2007-09-27', '2007-09-01'),
	('2007-09-28', '2007-09-01'),
	('2007-09-29', '2007-09-01'),
	('2007-09-30', '2007-09-01'),
	('2007-10-01', '2007-10-01'),
	('2007-10-02', '2007-10-01'),
	('2007-10-03', '2007-10-01'),
	('2007-10-04', '2007-10-01'),
	('2007-10-05', '2007-10-01'),
	('2007-10-06', '2007-10-01'),
	('2007-10-07', '2007-10-01'),
	('2007-10-08', '2007-10-01'),
	('2007-10-09', '2007-10-01'),
	('2007-10-10', '2007-10-01'),
	('2007-10-11', '2007-10-01'),
	('2007-10-12', '2007-10-01'),
	('2007-10-13', '2007-10-01'),
	('2007-10-14', '2007-10-01'),
	('2007-10-15', '2007-10-01'),
	('2007-10-16', '2007-10-01'),
	('2007-10-17', '2007-10-01'),
	('2007-10-18', '2007-10-01'),
	('2007-10-19', '2007-10-01'),
	('2007-10-20', '2007-10-01'),
	('2007-10-21', '2007-10-01'),
	('2007-10-22', '2007-10-01'),
	('2007-10-23', '2007-10-01'),
	('2007-10-24', '2007-10-01'),
	('2007-10-25', '2007-10-01'),
	('2007-10-26', '2007-10-01'),
	('2007-10-27', '2007-10-01'),
	('2007-10-28', '2007-10-01'),
	('2007-10-29', '2007-10-01'),
	('2007-10-30', '2007-10-01'),
	('2007-10-31', '2007-10-01'),
	('2007-11-01', '2007-11-01'),
	('2007-11-02', '2007-11-01'),
	('2007-11-03', '2007-11-01'),
	('2007-11-04', '2007-11-01'),
	('2007-11-05', '2007-11-01'),
	('2007-11-06', '2007-11-01'),
	('2007-11-07', '2007-11-01'),
	('2007-11-08', '2007-11-01'),
	('2007-11-09', '2007-11-01'),
	('2007-11-10', '2007-11-01'),
	('2007-11-11', '2007-11-01'),
	('2007-11-12', '2007-11-01'),
	('2007-11-13', '2007-11-01'),
	('2007-11-14', '2007-11-01'),
	('2007-11-15', '2007-11-01'),
	('2007-11-16', '2007-11-01'),
	('2007-11-17', '2007-11-01'),
	('2007-11-18', '2007-11-01'),
	('2007-11-19', '2007-11-01'),
	('2007-11-20', '2007-11-01'),
	('2007-11-21', '2007-11-01'),
	('2007-11-22', '2007-11-01'),
	('2007-11-23', '2007-11-01'),
	('2007-11-24', '2007-11-01'),
	('2007-11-25', '2007-11-01'),
	('2007-11-26', '2007-11-01'),
	('2007-11-27', '2007-11-01'),
	('2007-11-28', '2007-11-01'),
	('2007-11-29', '2007-11-01'),
	('2007-11-30', '2007-11-01'),
	('2007-12-01', '2007-12-01'),
	('2007-12-02', '2007-12-01'),
	('2007-12-03', '2007-12-01'),
	('2007-12-04', '2007-12-01'),
	('2007-12-05', '2007-12-01'),
	('2007-12-06', '2007-12-01'),
	('2007-12-07', '2007-12-01'),
	('2007-12-08', '2007-12-01'),
	('2007-12-09', '2007-12-01'),
	('2007-12-10', '2007-12-01'),
	('2007-12-11', '2007-12-01'),
	('2007-12-12', '2007-12-01'),
	('2007-12-13', '2007-12-01'),
	('2007-12-14', '2007-12-01'),
	('2007-12-15', '2007-12-01'),
	('2007-12-16', '2007-12-01'),
	('2007-12-17', '2007-12-01'),
	('2007-12-18', '2007-12-01'),
	('2007-12-19', '2007-12-01'),
	('2007-12-20', '2007-12-01'),
	('2007-12-21', '2007-12-01'),
	('2007-12-22', '2007-12-01'),
	('2007-12-23', '2007-12-01'),
	('2007-12-24', '2007-12-01'),
	('2007-12-25', '2007-12-01'),
	('2007-12-26', '2007-12-01'),
	('2007-12-27', '2007-12-01'),
	('2007-12-28', '2007-12-01'),
	('2007-12-29', '2007-12-01'),
	('2007-12-30', '2007-12-01'),
	('2007-12-31', '2007-12-01'),
	('2008-01-01', '2008-01-01'),
	('2008-01-02', '2008-01-01'),
	('2008-01-03', '2008-01-01'),
	('2008-01-04', '2008-01-01'),
	('2008-01-05', '2008-01-01'),
	('2008-01-06', '2008-01-01'),
	('2008-01-07', '2008-01-01'),
	('2008-01-08', '2008-01-01'),
	('2008-01-09', '2008-01-01'),
	('2008-01-10', '2008-01-01'),
	('2008-01-11', '2008-01-01'),
	('2008-01-12', '2008-01-01'),
	('2008-01-13', '2008-01-01'),
	('2008-01-14', '2008-01-01'),
	('2008-01-15', '2008-01-01'),
	('2008-01-16', '2008-01-01'),
	('2008-01-17', '2008-01-01'),
	('2008-01-18', '2008-01-01'),
	('2008-01-19', '2008-01-01'),
	('2008-01-20', '2008-01-01'),
	('2008-01-21', '2008-01-01'),
	('2008-01-22', '2008-01-01'),
	('2008-01-23', '2008-01-01'),
	('2008-01-24', '2008-01-01'),
	('2008-01-25', '2008-01-01'),
	('2008-01-26', '2008-01-01'),
	('2008-01-27', '2008-01-01'),
	('2008-01-28', '2008-01-01'),
	('2008-01-29', '2008-01-01'),
	('2008-01-30', '2008-01-01'),
	('2008-01-31', '2008-01-01'),
	('2008-02-01', '2008-02-01'),
	('2008-02-02', '2008-02-01'),
	('2008-02-03', '2008-02-01'),
	('2008-02-04', '2008-02-01'),
	('2008-02-05', '2008-02-01'),
	('2008-02-06', '2008-02-01'),
	('2008-02-07', '2008-02-01'),
	('2008-02-08', '2008-02-01'),
	('2008-02-09', '2008-02-01'),
	('2008-02-10', '2008-02-01'),
	('2008-02-11', '2008-02-01'),
	('2008-02-12', '2008-02-01'),
	('2008-02-13', '2008-02-01'),
	('2008-02-14', '2008-02-01'),
	('2008-02-15', '2008-02-01'),
	('2008-02-16', '2008-02-01'),
	('2008-02-17', '2008-02-01'),
	('2008-02-18', '2008-02-01'),
	('2008-02-19', '2008-02-01'),
	('2008-02-20', '2008-02-01'),
	('2008-02-21', '2008-02-01'),
	('2008-02-22', '2008-02-01'),
	('2008-02-23', '2008-02-01'),
	('2008-02-24', '2008-02-01'),
	('2008-02-25', '2008-02-01'),
	('2008-02-26', '2008-02-01'),
	('2008-02-27', '2008-02-01'),
	('2008-02-28', '2008-02-01'),
	('2008-02-29', '2008-02-01'),
	('2008-03-01', '2008-03-01'),
	('2008-03-02', '2008-03-01'),
	('2008-03-03', '2008-03-01'),
	('2008-03-04', '2008-03-01'),
	('2008-03-05', '2008-03-01'),
	('2008-03-06', '2008-03-01'),
	('2008-03-07', '2008-03-01'),
	('2008-03-08', '2008-03-01'),
	('2008-03-09', '2008-03-01'),
	('2008-03-10', '2008-03-01'),
	('2008-03-11', '2008-03-01'),
	('2008-03-12', '2008-03-01'),
	('2008-03-13', '2008-03-01'),
	('2008-03-14', '2008-03-01'),
	('2008-03-15', '2008-03-01'),
	('2008-03-16', '2008-03-01'),
	('2008-03-17', '2008-03-01'),
	('2008-03-18', '2008-03-01'),
	('2008-03-19', '2008-03-01'),
	('2008-03-20', '2008-03-01'),
	('2008-03-21', '2008-03-01'),
	('2008-03-22', '2008-03-01'),
	('2008-03-23', '2008-03-01'),
	('2008-03-24', '2008-03-01'),
	('2008-03-25', '2008-03-01'),
	('2008-03-26', '2008-03-01'),
	('2008-03-27', '2008-03-01'),
	('2008-03-28', '2008-03-01'),
	('2008-03-29', '2008-03-01'),
	('2008-03-30', '2008-03-01'),
	('2008-03-31', '2008-03-01'),
	('2008-04-01', '2008-04-01'),
	('2008-04-02', '2008-04-01'),
	('2008-04-03', '2008-04-01'),
	('2008-04-04', '2008-04-01'),
	('2008-04-05', '2008-04-01'),
	('2008-04-06', '2008-04-01'),
	('2008-04-07', '2008-04-01'),
	('2008-04-08', '2008-04-01'),
	('2008-04-09', '2008-04-01'),
	('2008-04-10', '2008-04-01'),
	('2008-04-11', '2008-04-01'),
	('2008-04-12', '2008-04-01'),
	('2008-04-13', '2008-04-01'),
	('2008-04-14', '2008-04-01'),
	('2008-04-15', '2008-04-01'),
	('2008-04-16', '2008-04-01'),
	('2008-04-17', '2008-04-01'),
	('2008-04-18', '2008-04-01'),
	('2008-04-19', '2008-04-01'),
	('2008-04-20', '2008-04-01'),
	('2008-04-21', '2008-04-01'),
	('2008-04-22', '2008-04-01'),
	('2008-04-23', '2008-04-01'),
	('2008-04-24', '2008-04-01'),
	('2008-04-25', '2008-04-01'),
	('2008-04-26', '2008-04-01'),
	('2008-04-27', '2008-04-01'),
	('2008-04-28', '2008-04-01'),
	('2008-04-29', '2008-04-01'),
	('2008-04-30', '2008-04-01'),
	('2008-05-01', '2008-05-01'),
	('2008-05-02', '2008-05-01'),
	('2008-05-03', '2008-05-01'),
	('2008-05-04', '2008-05-01'),
	('2008-05-05', '2008-05-01'),
	('2008-05-06', '2008-05-01'),
	('2008-05-07', '2008-05-01'),
	('2008-05-08', '2008-05-01'),
	('2008-05-09', '2008-05-01'),
	('2008-05-10', '2008-05-01'),
	('2008-05-11', '2008-05-01'),
	('2008-05-12', '2008-05-01'),
	('2008-05-13', '2008-05-01'),
	('2008-05-14', '2008-05-01'),
	('2008-05-15', '2008-05-01'),
	('2008-05-16', '2008-05-01'),
	('2008-05-17', '2008-05-01'),
	('2008-05-18', '2008-05-01'),
	('2008-05-19', '2008-05-01'),
	('2008-05-20', '2008-05-01'),
	('2008-05-21', '2008-05-01'),
	('2008-05-22', '2008-05-01'),
	('2008-05-23', '2008-05-01'),
	('2008-05-24', '2008-05-01'),
	('2008-05-25', '2008-05-01'),
	('2008-05-26', '2008-05-01'),
	('2008-05-27', '2008-05-01'),
	('2008-05-28', '2008-05-01'),
	('2008-05-29', '2008-05-01'),
	('2008-05-30', '2008-05-01'),
	('2008-05-31', '2008-05-01'),
	('2008-06-01', '2008-06-01'),
	('2008-06-02', '2008-06-01'),
	('2008-06-03', '2008-06-01'),
	('2008-06-04', '2008-06-01'),
	('2008-06-05', '2008-06-01'),
	('2008-06-06', '2008-06-01'),
	('2008-06-07', '2008-06-01'),
	('2008-06-08', '2008-06-01'),
	('2008-06-09', '2008-06-01'),
	('2008-06-10', '2008-06-01'),
	('2008-06-11', '2008-06-01'),
	('2008-06-12', '2008-06-01'),
	('2008-06-13', '2008-06-01'),
	('2008-06-14', '2008-06-01'),
	('2008-06-15', '2008-06-01'),
	('2008-06-16', '2008-06-01'),
	('2008-06-17', '2008-06-01'),
	('2008-06-18', '2008-06-01'),
	('2008-06-19', '2008-06-01'),
	('2008-06-20', '2008-06-01'),
	('2008-06-21', '2008-06-01'),
	('2008-06-22', '2008-06-01'),
	('2008-06-23', '2008-06-01'),
	('2008-06-24', '2008-06-01'),
	('2008-06-25', '2008-06-01'),
	('2008-06-26', '2008-06-01'),
	('2008-06-27', '2008-06-01'),
	('2008-06-28', '2008-06-01'),
	('2008-06-29', '2008-06-01'),
	('2008-06-30', '2008-06-01'),
	('2008-07-01', '2008-07-01'),
	('2008-07-02', '2008-07-01'),
	('2008-07-03', '2008-07-01'),
	('2008-07-04', '2008-07-01'),
	('2008-07-05', '2008-07-01'),
	('2008-07-06', '2008-07-01'),
	('2008-07-07', '2008-07-01'),
	('2008-07-08', '2008-07-01'),
	('2008-07-09', '2008-07-01'),
	('2008-07-10', '2008-07-01'),
	('2008-07-11', '2008-07-01'),
	('2008-07-12', '2008-07-01'),
	('2008-07-13', '2008-07-01'),
	('2008-07-14', '2008-07-01'),
	('2008-07-15', '2008-07-01'),
	('2008-07-16', '2008-07-01'),
	('2008-07-17', '2008-07-01'),
	('2008-07-18', '2008-07-01'),
	('2008-07-19', '2008-07-01'),
	('2008-07-20', '2008-07-01'),
	('2008-07-21', '2008-07-01'),
	('2008-07-22', '2008-07-01'),
	('2008-07-23', '2008-07-01'),
	('2008-07-24', '2008-07-01'),
	('2008-07-25', '2008-07-01'),
	('2008-07-26', '2008-07-01'),
	('2008-07-27', '2008-07-01'),
	('2008-07-28', '2008-07-01'),
	('2008-07-29', '2008-07-01'),
	('2008-07-30', '2008-07-01'),
	('2008-07-31', '2008-07-01'),
	('2008-08-01', '2008-08-01'),
	('2008-08-02', '2008-08-01'),
	('2008-08-03', '2008-08-01'),
	('2008-08-04', '2008-08-01'),
	('2008-08-05', '2008-08-01'),
	('2008-08-06', '2008-08-01'),
	('2008-08-07', '2008-08-01'),
	('2008-08-08', '2008-08-01'),
	('2008-08-09', '2008-08-01'),
	('2008-08-10', '2008-08-01'),
	('2008-08-11', '2008-08-01'),
	('2008-08-12', '2008-08-01'),
	('2008-08-13', '2008-08-01'),
	('2008-08-14', '2008-08-01'),
	('2008-08-15', '2008-08-01'),
	('2008-08-16', '2008-08-01'),
	('2008-08-17', '2008-08-01'),
	('2008-08-18', '2008-08-01'),
	('2008-08-19', '2008-08-01'),
	('2008-08-20', '2008-08-01'),
	('2008-08-21', '2008-08-01'),
	('2008-08-22', '2008-08-01'),
	('2008-08-23', '2008-08-01'),
	('2008-08-24', '2008-08-01'),
	('2008-08-25', '2008-08-01'),
	('2008-08-26', '2008-08-01'),
	('2008-08-27', '2008-08-01'),
	('2008-08-28', '2008-08-01'),
	('2008-08-29', '2008-08-01'),
	('2008-08-30', '2008-08-01'),
	('2008-08-31', '2008-08-01'),
	('2008-09-01', '2008-09-01'),
	('2008-09-02', '2008-09-01'),
	('2008-09-03', '2008-09-01'),
	('2008-09-04', '2008-09-01'),
	('2008-09-05', '2008-09-01'),
	('2008-09-06', '2008-09-01'),
	('2008-09-07', '2008-09-01'),
	('2008-09-08', '2008-09-01'),
	('2008-09-09', '2008-09-01'),
	('2008-09-10', '2008-09-01'),
	('2008-09-11', '2008-09-01'),
	('2008-09-12', '2008-09-01'),
	('2008-09-13', '2008-09-01'),
	('2008-09-14', '2008-09-01'),
	('2008-09-15', '2008-09-01'),
	('2008-09-16', '2008-09-01'),
	('2008-09-17', '2008-09-01'),
	('2008-09-18', '2008-09-01'),
	('2008-09-19', '2008-09-01'),
	('2008-09-20', '2008-09-01'),
	('2008-09-21', '2008-09-01'),
	('2008-09-22', '2008-09-01'),
	('2008-09-23', '2008-09-01'),
	('2008-09-24', '2008-09-01'),
	('2008-09-25', '2008-09-01'),
	('2008-09-26', '2008-09-01'),
	('2008-09-27', '2008-09-01'),
	('2008-09-28', '2008-09-01'),
	('2008-09-29', '2008-09-01'),
	('2008-09-30', '2008-09-01'),
	('2008-10-01', '2008-10-01'),
	('2008-10-02', '2008-10-01'),
	('2008-10-03', '2008-10-01'),
	('2008-10-04', '2008-10-01'),
	('2008-10-05', '2008-10-01'),
	('2008-10-06', '2008-10-01'),
	('2008-10-07', '2008-10-01'),
	('2008-10-08', '2008-10-01'),
	('2008-10-09', '2008-10-01'),
	('2008-10-10', '2008-10-01'),
	('2008-10-11', '2008-10-01'),
	('2008-10-12', '2008-10-01'),
	('2008-10-13', '2008-10-01'),
	('2008-10-14', '2008-10-01'),
	('2008-10-15', '2008-10-01'),
	('2008-10-16', '2008-10-01'),
	('2008-10-17', '2008-10-01'),
	('2008-10-18', '2008-10-01'),
	('2008-10-19', '2008-10-01'),
	('2008-10-20', '2008-10-01'),
	('2008-10-21', '2008-10-01'),
	('2008-10-22', '2008-10-01'),
	('2008-10-23', '2008-10-01'),
	('2008-10-24', '2008-10-01'),
	('2008-10-25', '2008-10-01'),
	('2008-10-26', '2008-10-01'),
	('2008-10-27', '2008-10-01'),
	('2008-10-28', '2008-10-01'),
	('2008-10-29', '2008-10-01'),
	('2008-10-30', '2008-10-01'),
	('2008-10-31', '2008-10-01'),
	('2008-11-01', '2008-11-01'),
	('2008-11-02', '2008-11-01'),
	('2008-11-03', '2008-11-01'),
	('2008-11-04', '2008-11-01'),
	('2008-11-05', '2008-11-01'),
	('2008-11-06', '2008-11-01'),
	('2008-11-07', '2008-11-01'),
	('2008-11-08', '2008-11-01'),
	('2008-11-09', '2008-11-01'),
	('2008-11-10', '2008-11-01'),
	('2008-11-11', '2008-11-01'),
	('2008-11-12', '2008-11-01'),
	('2008-11-13', '2008-11-01'),
	('2008-11-14', '2008-11-01'),
	('2008-11-15', '2008-11-01'),
	('2008-11-16', '2008-11-01'),
	('2008-11-17', '2008-11-01'),
	('2008-11-18', '2008-11-01'),
	('2008-11-19', '2008-11-01'),
	('2008-11-20', '2008-11-01'),
	('2008-11-21', '2008-11-01'),
	('2008-11-22', '2008-11-01'),
	('2008-11-23', '2008-11-01'),
	('2008-11-24', '2008-11-01'),
	('2008-11-25', '2008-11-01'),
	('2008-11-26', '2008-11-01'),
	('2008-11-27', '2008-11-01'),
	('2008-11-28', '2008-11-01'),
	('2008-11-29', '2008-11-01'),
	('2008-11-30', '2008-11-01'),
	('2008-12-01', '2008-12-01'),
	('2008-12-02', '2008-12-01'),
	('2008-12-03', '2008-12-01'),
	('2008-12-04', '2008-12-01'),
	('2008-12-05', '2008-12-01'),
	('2008-12-06', '2008-12-01'),
	('2008-12-07', '2008-12-01'),
	('2008-12-08', '2008-12-01'),
	('2008-12-09', '2008-12-01'),
	('2008-12-10', '2008-12-01'),
	('2008-12-11', '2008-12-01'),
	('2008-12-12', '2008-12-01'),
	('2008-12-13', '2008-12-01'),
	('2008-12-14', '2008-12-01'),
	('2008-12-15', '2008-12-01'),
	('2008-12-16', '2008-12-01'),
	('2008-12-17', '2008-12-01'),
	('2008-12-18', '2008-12-01'),
	('2008-12-19', '2008-12-01'),
	('2008-12-20', '2008-12-01'),
	('2008-12-21', '2008-12-01'),
	('2008-12-22', '2008-12-01'),
	('2008-12-23', '2008-12-01'),
	('2008-12-24', '2008-12-01'),
	('2008-12-25', '2008-12-01'),
	('2008-12-26', '2008-12-01'),
	('2008-12-27', '2008-12-01'),
	('2008-12-28', '2008-12-01'),
	('2008-12-29', '2008-12-01'),
	('2008-12-30', '2008-12-01'),
	('2008-12-31', '2008-12-01'),
	('2009-01-01', '2009-01-01'),
	('2009-01-02', '2009-01-01'),
	('2009-01-03', '2009-01-01'),
	('2009-01-04', '2009-01-01'),
	('2009-01-05', '2009-01-01'),
	('2009-01-06', '2009-01-01'),
	('2009-01-07', '2009-01-01'),
	('2009-01-08', '2009-01-01'),
	('2009-01-09', '2009-01-01'),
	('2009-01-10', '2009-01-01'),
	('2009-01-11', '2009-01-01'),
	('2009-01-12', '2009-01-01'),
	('2009-01-13', '2009-01-01'),
	('2009-01-14', '2009-01-01'),
	('2009-01-15', '2009-01-01'),
	('2009-01-16', '2009-01-01'),
	('2009-01-17', '2009-01-01'),
	('2009-01-18', '2009-01-01'),
	('2009-01-19', '2009-01-01'),
	('2009-01-20', '2009-01-01'),
	('2009-01-21', '2009-01-01'),
	('2009-01-22', '2009-01-01'),
	('2009-01-23', '2009-01-01'),
	('2009-01-24', '2009-01-01'),
	('2009-01-25', '2009-01-01'),
	('2009-01-26', '2009-01-01'),
	('2009-01-27', '2009-01-01'),
	('2009-01-28', '2009-01-01'),
	('2009-01-29', '2009-01-01'),
	('2009-01-30', '2009-01-01'),
	('2009-01-31', '2009-01-01'),
	('2009-02-01', '2009-02-01'),
	('2009-02-02', '2009-02-01'),
	('2009-02-03', '2009-02-01'),
	('2009-02-04', '2009-02-01'),
	('2009-02-05', '2009-02-01'),
	('2009-02-06', '2009-02-01'),
	('2009-02-07', '2009-02-01'),
	('2009-02-08', '2009-02-01'),
	('2009-02-09', '2009-02-01'),
	('2009-02-10', '2009-02-01'),
	('2009-02-11', '2009-02-01'),
	('2009-02-12', '2009-02-01'),
	('2009-02-13', '2009-02-01'),
	('2009-02-14', '2009-02-01'),
	('2009-02-15', '2009-02-01'),
	('2009-02-16', '2009-02-01'),
	('2009-02-17', '2009-02-01'),
	('2009-02-18', '2009-02-01'),
	('2009-02-19', '2009-02-01'),
	('2009-02-20', '2009-02-01'),
	('2009-02-21', '2009-02-01'),
	('2009-02-22', '2009-02-01'),
	('2009-02-23', '2009-02-01'),
	('2009-02-24', '2009-02-01'),
	('2009-02-25', '2009-02-01'),
	('2009-02-26', '2009-02-01'),
	('2009-02-27', '2009-02-01'),
	('2009-02-28', '2009-02-01'),
	('2009-03-01', '2009-03-01'),
	('2009-03-02', '2009-03-01'),
	('2009-03-03', '2009-03-01'),
	('2009-03-04', '2009-03-01'),
	('2009-03-05', '2009-03-01'),
	('2009-03-06', '2009-03-01'),
	('2009-03-07', '2009-03-01'),
	('2009-03-08', '2009-03-01'),
	('2009-03-09', '2009-03-01'),
	('2009-03-10', '2009-03-01'),
	('2009-03-11', '2009-03-01'),
	('2009-03-12', '2009-03-01'),
	('2009-03-13', '2009-03-01'),
	('2009-03-14', '2009-03-01'),
	('2009-03-15', '2009-03-01'),
	('2009-03-16', '2009-03-01'),
	('2009-03-17', '2009-03-01'),
	('2009-03-18', '2009-03-01'),
	('2009-03-19', '2009-03-01'),
	('2009-03-20', '2009-03-01'),
	('2009-03-21', '2009-03-01'),
	('2009-03-22', '2009-03-01'),
	('2009-03-23', '2009-03-01'),
	('2009-03-24', '2009-03-01'),
	('2009-03-25', '2009-03-01'),
	('2009-03-26', '2009-03-01'),
	('2009-03-27', '2009-03-01'),
	('2009-03-28', '2009-03-01'),
	('2009-03-29', '2009-03-01'),
	('2009-03-30', '2009-03-01'),
	('2009-03-31', '2009-03-01'),
	('2009-04-01', '2009-04-01'),
	('2009-04-02', '2009-04-01'),
	('2009-04-03', '2009-04-01'),
	('2009-04-04', '2009-04-01'),
	('2009-04-05', '2009-04-01'),
	('2009-04-06', '2009-04-01'),
	('2009-04-07', '2009-04-01'),
	('2009-04-08', '2009-04-01'),
	('2009-04-09', '2009-04-01'),
	('2009-04-10', '2009-04-01'),
	('2009-04-11', '2009-04-01'),
	('2009-04-12', '2009-04-01'),
	('2009-04-13', '2009-04-01'),
	('2009-04-14', '2009-04-01'),
	('2009-04-15', '2009-04-01'),
	('2009-04-16', '2009-04-01'),
	('2009-04-17', '2009-04-01'),
	('2009-04-18', '2009-04-01'),
	('2009-04-19', '2009-04-01'),
	('2009-04-20', '2009-04-01'),
	('2009-04-21', '2009-04-01'),
	('2009-04-22', '2009-04-01'),
	('2009-04-23', '2009-04-01'),
	('2009-04-24', '2009-04-01'),
	('2009-04-25', '2009-04-01'),
	('2009-04-26', '2009-04-01'),
	('2009-04-27', '2009-04-01'),
	('2009-04-28', '2009-04-01'),
	('2009-04-29', '2009-04-01'),
	('2009-04-30', '2009-04-01'),
	('2009-05-01', '2009-05-01'),
	('2009-05-02', '2009-05-01'),
	('2009-05-03', '2009-05-01'),
	('2009-05-04', '2009-05-01'),
	('2009-05-05', '2009-05-01'),
	('2009-05-06', '2009-05-01'),
	('2009-05-07', '2009-05-01'),
	('2009-05-08', '2009-05-01'),
	('2009-05-09', '2009-05-01'),
	('2009-05-10', '2009-05-01'),
	('2009-05-11', '2009-05-01'),
	('2009-05-12', '2009-05-01'),
	('2009-05-13', '2009-05-01'),
	('2009-05-14', '2009-05-01'),
	('2009-05-15', '2009-05-01'),
	('2009-05-16', '2009-05-01'),
	('2009-05-17', '2009-05-01'),
	('2009-05-18', '2009-05-01'),
	('2009-05-19', '2009-05-01'),
	('2009-05-20', '2009-05-01'),
	('2009-05-21', '2009-05-01'),
	('2009-05-22', '2009-05-01'),
	('2009-05-23', '2009-05-01'),
	('2009-05-24', '2009-05-01'),
	('2009-05-25', '2009-05-01'),
	('2009-05-26', '2009-05-01'),
	('2009-05-27', '2009-05-01'),
	('2009-05-28', '2009-05-01'),
	('2009-05-29', '2009-05-01'),
	('2009-05-30', '2009-05-01'),
	('2009-05-31', '2009-05-01'),
	('2009-06-01', '2009-06-01'),
	('2009-06-02', '2009-06-01'),
	('2009-06-03', '2009-06-01'),
	('2009-06-04', '2009-06-01'),
	('2009-06-05', '2009-06-01'),
	('2009-06-06', '2009-06-01'),
	('2009-06-07', '2009-06-01'),
	('2009-06-08', '2009-06-01'),
	('2009-06-09', '2009-06-01'),
	('2009-06-10', '2009-06-01'),
	('2009-06-11', '2009-06-01'),
	('2009-06-12', '2009-06-01'),
	('2009-06-13', '2009-06-01'),
	('2009-06-14', '2009-06-01'),
	('2009-06-15', '2009-06-01'),
	('2009-06-16', '2009-06-01'),
	('2009-06-17', '2009-06-01'),
	('2009-06-18', '2009-06-01'),
	('2009-06-19', '2009-06-01'),
	('2009-06-20', '2009-06-01'),
	('2009-06-21', '2009-06-01'),
	('2009-06-22', '2009-06-01'),
	('2009-06-23', '2009-06-01'),
	('2009-06-24', '2009-06-01'),
	('2009-06-25', '2009-06-01'),
	('2009-06-26', '2009-06-01'),
	('2009-06-27', '2009-06-01'),
	('2009-06-28', '2009-06-01'),
	('2009-06-29', '2009-06-01'),
	('2009-06-30', '2009-06-01'),
	('2009-07-01', '2009-07-01'),
	('2009-07-02', '2009-07-01'),
	('2009-07-03', '2009-07-01'),
	('2009-07-04', '2009-07-01'),
	('2009-07-05', '2009-07-01'),
	('2009-07-06', '2009-07-01'),
	('2009-07-07', '2009-07-01'),
	('2009-07-08', '2009-07-01'),
	('2009-07-09', '2009-07-01'),
	('2009-07-10', '2009-07-01'),
	('2009-07-11', '2009-07-01'),
	('2009-07-12', '2009-07-01'),
	('2009-07-13', '2009-07-01'),
	('2009-07-14', '2009-07-01'),
	('2009-07-15', '2009-07-01'),
	('2009-07-16', '2009-07-01'),
	('2009-07-17', '2009-07-01'),
	('2009-07-18', '2009-07-01'),
	('2009-07-19', '2009-07-01'),
	('2009-07-20', '2009-07-01'),
	('2009-07-21', '2009-07-01'),
	('2009-07-22', '2009-07-01'),
	('2009-07-23', '2009-07-01'),
	('2009-07-24', '2009-07-01'),
	('2009-07-25', '2009-07-01'),
	('2009-07-26', '2009-07-01'),
	('2009-07-27', '2009-07-01'),
	('2009-07-28', '2009-07-01'),
	('2009-07-29', '2009-07-01'),
	('2009-07-30', '2009-07-01'),
	('2009-07-31', '2009-07-01'),
	('2009-08-01', '2009-08-01'),
	('2009-08-02', '2009-08-01'),
	('2009-08-03', '2009-08-01'),
	('2009-08-04', '2009-08-01'),
	('2009-08-05', '2009-08-01'),
	('2009-08-06', '2009-08-01'),
	('2009-08-07', '2009-08-01'),
	('2009-08-08', '2009-08-01'),
	('2009-08-09', '2009-08-01'),
	('2009-08-10', '2009-08-01'),
	('2009-08-11', '2009-08-01'),
	('2009-08-12', '2009-08-01'),
	('2009-08-13', '2009-08-01'),
	('2009-08-14', '2009-08-01'),
	('2009-08-15', '2009-08-01'),
	('2009-08-16', '2009-08-01'),
	('2009-08-17', '2009-08-01'),
	('2009-08-18', '2009-08-01'),
	('2009-08-19', '2009-08-01'),
	('2009-08-20', '2009-08-01'),
	('2009-08-21', '2009-08-01'),
	('2009-08-22', '2009-08-01'),
	('2009-08-23', '2009-08-01'),
	('2009-08-24', '2009-08-01'),
	('2009-08-25', '2009-08-01'),
	('2009-08-26', '2009-08-01'),
	('2009-08-27', '2009-08-01'),
	('2009-08-28', '2009-08-01'),
	('2009-08-29', '2009-08-01'),
	('2009-08-30', '2009-08-01'),
	('2009-08-31', '2009-08-01'),
	('2009-09-01', '2009-09-01'),
	('2009-09-02', '2009-09-01'),
	('2009-09-03', '2009-09-01'),
	('2009-09-04', '2009-09-01'),
	('2009-09-05', '2009-09-01'),
	('2009-09-06', '2009-09-01'),
	('2009-09-07', '2009-09-01'),
	('2009-09-08', '2009-09-01'),
	('2009-09-09', '2009-09-01'),
	('2009-09-10', '2009-09-01'),
	('2009-09-11', '2009-09-01'),
	('2009-09-12', '2009-09-01'),
	('2009-09-13', '2009-09-01'),
	('2009-09-14', '2009-09-01'),
	('2009-09-15', '2009-09-01'),
	('2009-09-16', '2009-09-01'),
	('2009-09-17', '2009-09-01'),
	('2009-09-18', '2009-09-01'),
	('2009-09-19', '2009-09-01'),
	('2009-09-20', '2009-09-01'),
	('2009-09-21', '2009-09-01'),
	('2009-09-22', '2009-09-01'),
	('2009-09-23', '2009-09-01'),
	('2009-09-24', '2009-09-01'),
	('2009-09-25', '2009-09-01'),
	('2009-09-26', '2009-09-01'),
	('2009-09-27', '2009-09-01'),
	('2009-09-28', '2009-09-01'),
	('2009-09-29', '2009-09-01'),
	('2009-09-30', '2009-09-01'),
	('2009-10-01', '2009-10-01'),
	('2009-10-02', '2009-10-01'),
	('2009-10-03', '2009-10-01'),
	('2009-10-04', '2009-10-01'),
	('2009-10-05', '2009-10-01'),
	('2009-10-06', '2009-10-01'),
	('2009-10-07', '2009-10-01'),
	('2009-10-08', '2009-10-01'),
	('2009-10-09', '2009-10-01'),
	('2009-10-10', '2009-10-01'),
	('2009-10-11', '2009-10-01'),
	('2009-10-12', '2009-10-01'),
	('2009-10-13', '2009-10-01'),
	('2009-10-14', '2009-10-01'),
	('2009-10-15', '2009-10-01'),
	('2009-10-16', '2009-10-01'),
	('2009-10-17', '2009-10-01'),
	('2009-10-18', '2009-10-01'),
	('2009-10-19', '2009-10-01'),
	('2009-10-20', '2009-10-01'),
	('2009-10-21', '2009-10-01'),
	('2009-10-22', '2009-10-01'),
	('2009-10-23', '2009-10-01'),
	('2009-10-24', '2009-10-01'),
	('2009-10-25', '2009-10-01'),
	('2009-10-26', '2009-10-01'),
	('2009-10-27', '2009-10-01'),
	('2009-10-28', '2009-10-01'),
	('2009-10-29', '2009-10-01'),
	('2009-10-30', '2009-10-01'),
	('2009-10-31', '2009-10-01'),
	('2009-11-01', '2009-11-01'),
	('2009-11-02', '2009-11-01'),
	('2009-11-03', '2009-11-01'),
	('2009-11-04', '2009-11-01'),
	('2009-11-05', '2009-11-01'),
	('2009-11-06', '2009-11-01'),
	('2009-11-07', '2009-11-01'),
	('2009-11-08', '2009-11-01'),
	('2009-11-09', '2009-11-01'),
	('2009-11-10', '2009-11-01'),
	('2009-11-11', '2009-11-01'),
	('2009-11-12', '2009-11-01'),
	('2009-11-13', '2009-11-01'),
	('2009-11-14', '2009-11-01'),
	('2009-11-15', '2009-11-01'),
	('2009-11-16', '2009-11-01'),
	('2009-11-17', '2009-11-01'),
	('2009-11-18', '2009-11-01'),
	('2009-11-19', '2009-11-01'),
	('2009-11-20', '2009-11-01'),
	('2009-11-21', '2009-11-01'),
	('2009-11-22', '2009-11-01'),
	('2009-11-23', '2009-11-01'),
	('2009-11-24', '2009-11-01'),
	('2009-11-25', '2009-11-01'),
	('2009-11-26', '2009-11-01'),
	('2009-11-27', '2009-11-01'),
	('2009-11-28', '2009-11-01'),
	('2009-11-29', '2009-11-01'),
	('2009-11-30', '2009-11-01'),
	('2009-12-01', '2009-12-01'),
	('2009-12-02', '2009-12-01'),
	('2009-12-03', '2009-12-01'),
	('2009-12-04', '2009-12-01'),
	('2009-12-05', '2009-12-01'),
	('2009-12-06', '2009-12-01'),
	('2009-12-07', '2009-12-01'),
	('2009-12-08', '2009-12-01'),
	('2009-12-09', '2009-12-01'),
	('2009-12-10', '2009-12-01'),
	('2009-12-11', '2009-12-01'),
	('2009-12-12', '2009-12-01'),
	('2009-12-13', '2009-12-01'),
	('2009-12-14', '2009-12-01'),
	('2009-12-15', '2009-12-01'),
	('2009-12-16', '2009-12-01'),
	('2009-12-17', '2009-12-01'),
	('2009-12-18', '2009-12-01'),
	('2009-12-19', '2009-12-01'),
	('2009-12-20', '2009-12-01'),
	('2009-12-21', '2009-12-01'),
	('2009-12-22', '2009-12-01'),
	('2009-12-23', '2009-12-01'),
	('2009-12-24', '2009-12-01'),
	('2009-12-25', '2009-12-01'),
	('2009-12-26', '2009-12-01'),
	('2009-12-27', '2009-12-01'),
	('2009-12-28', '2009-12-01'),
	('2009-12-29', '2009-12-01'),
	('2009-12-30', '2009-12-01'),
	('2009-12-31', '2009-12-01'),
	('2010-01-01', '2010-01-01'),
	('2010-01-02', '2010-01-01'),
	('2010-01-03', '2010-01-01'),
	('2010-01-04', '2010-01-01'),
	('2010-01-05', '2010-01-01'),
	('2010-01-06', '2010-01-01'),
	('2010-01-07', '2010-01-01'),
	('2010-01-08', '2010-01-01'),
	('2010-01-09', '2010-01-01'),
	('2010-01-10', '2010-01-01'),
	('2010-01-11', '2010-01-01'),
	('2010-01-12', '2010-01-01'),
	('2010-01-13', '2010-01-01'),
	('2010-01-14', '2010-01-01'),
	('2010-01-15', '2010-01-01'),
	('2010-01-16', '2010-01-01'),
	('2010-01-17', '2010-01-01'),
	('2010-01-18', '2010-01-01'),
	('2010-01-19', '2010-01-01'),
	('2010-01-20', '2010-01-01'),
	('2010-01-21', '2010-01-01'),
	('2010-01-22', '2010-01-01'),
	('2010-01-23', '2010-01-01'),
	('2010-01-24', '2010-01-01'),
	('2010-01-25', '2010-01-01'),
	('2010-01-26', '2010-01-01'),
	('2010-01-27', '2010-01-01'),
	('2010-01-28', '2010-01-01'),
	('2010-01-29', '2010-01-01'),
	('2010-01-30', '2010-01-01'),
	('2010-01-31', '2010-01-01'),
	('2010-02-01', '2010-02-01'),
	('2010-02-02', '2010-02-01'),
	('2010-02-03', '2010-02-01'),
	('2010-02-04', '2010-02-01'),
	('2010-02-05', '2010-02-01'),
	('2010-02-06', '2010-02-01'),
	('2010-02-07', '2010-02-01'),
	('2010-02-08', '2010-02-01'),
	('2010-02-09', '2010-02-01'),
	('2010-02-10', '2010-02-01'),
	('2010-02-11', '2010-02-01'),
	('2010-02-12', '2010-02-01'),
	('2010-02-13', '2010-02-01'),
	('2010-02-14', '2010-02-01'),
	('2010-02-15', '2010-02-01'),
	('2010-02-16', '2010-02-01'),
	('2010-02-17', '2010-02-01'),
	('2010-02-18', '2010-02-01'),
	('2010-02-19', '2010-02-01'),
	('2010-02-20', '2010-02-01'),
	('2010-02-21', '2010-02-01'),
	('2010-02-22', '2010-02-01'),
	('2010-02-23', '2010-02-01'),
	('2010-02-24', '2010-02-01'),
	('2010-02-25', '2010-02-01'),
	('2010-02-26', '2010-02-01'),
	('2010-02-27', '2010-02-01'),
	('2010-02-28', '2010-02-01'),
	('2010-03-01', '2010-03-01'),
	('2010-03-02', '2010-03-01'),
	('2010-03-03', '2010-03-01'),
	('2010-03-04', '2010-03-01'),
	('2010-03-05', '2010-03-01'),
	('2010-03-06', '2010-03-01'),
	('2010-03-07', '2010-03-01'),
	('2010-03-08', '2010-03-01'),
	('2010-03-09', '2010-03-01'),
	('2010-03-10', '2010-03-01'),
	('2010-03-11', '2010-03-01'),
	('2010-03-12', '2010-03-01'),
	('2010-03-13', '2010-03-01'),
	('2010-03-14', '2010-03-01'),
	('2010-03-15', '2010-03-01'),
	('2010-03-16', '2010-03-01'),
	('2010-03-17', '2010-03-01'),
	('2010-03-18', '2010-03-01'),
	('2010-03-19', '2010-03-01'),
	('2010-03-20', '2010-03-01'),
	('2010-03-21', '2010-03-01'),
	('2010-03-22', '2010-03-01'),
	('2010-03-23', '2010-03-01'),
	('2010-03-24', '2010-03-01'),
	('2010-03-25', '2010-03-01'),
	('2010-03-26', '2010-03-01'),
	('2010-03-27', '2010-03-01'),
	('2010-03-28', '2010-03-01'),
	('2010-03-29', '2010-03-01'),
	('2010-03-30', '2010-03-01'),
	('2010-03-31', '2010-03-01'),
	('2010-04-01', '2010-04-01'),
	('2010-04-02', '2010-04-01'),
	('2010-04-03', '2010-04-01'),
	('2010-04-04', '2010-04-01'),
	('2010-04-05', '2010-04-01'),
	('2010-04-06', '2010-04-01'),
	('2010-04-07', '2010-04-01'),
	('2010-04-08', '2010-04-01'),
	('2010-04-09', '2010-04-01'),
	('2010-04-10', '2010-04-01'),
	('2010-04-11', '2010-04-01'),
	('2010-04-12', '2010-04-01'),
	('2010-04-13', '2010-04-01'),
	('2010-04-14', '2010-04-01'),
	('2010-04-15', '2010-04-01'),
	('2010-04-16', '2010-04-01'),
	('2010-04-17', '2010-04-01'),
	('2010-04-18', '2010-04-01'),
	('2010-04-19', '2010-04-01'),
	('2010-04-20', '2010-04-01'),
	('2010-04-21', '2010-04-01'),
	('2010-04-22', '2010-04-01'),
	('2010-04-23', '2010-04-01'),
	('2010-04-24', '2010-04-01'),
	('2010-04-25', '2010-04-01'),
	('2010-04-26', '2010-04-01'),
	('2010-04-27', '2010-04-01'),
	('2010-04-28', '2010-04-01'),
	('2010-04-29', '2010-04-01'),
	('2010-04-30', '2010-04-01'),
	('2010-05-01', '2010-05-01'),
	('2010-05-02', '2010-05-01'),
	('2010-05-03', '2010-05-01'),
	('2010-05-04', '2010-05-01'),
	('2010-05-05', '2010-05-01'),
	('2010-05-06', '2010-05-01'),
	('2010-05-07', '2010-05-01'),
	('2010-05-08', '2010-05-01'),
	('2010-05-09', '2010-05-01'),
	('2010-05-10', '2010-05-01'),
	('2010-05-11', '2010-05-01'),
	('2010-05-12', '2010-05-01'),
	('2010-05-13', '2010-05-01'),
	('2010-05-14', '2010-05-01'),
	('2010-05-15', '2010-05-01'),
	('2010-05-16', '2010-05-01'),
	('2010-05-17', '2010-05-01'),
	('2010-05-18', '2010-05-01'),
	('2010-05-19', '2010-05-01'),
	('2010-05-20', '2010-05-01'),
	('2010-05-21', '2010-05-01'),
	('2010-05-22', '2010-05-01'),
	('2010-05-23', '2010-05-01'),
	('2010-05-24', '2010-05-01'),
	('2010-05-25', '2010-05-01'),
	('2010-05-26', '2010-05-01'),
	('2010-05-27', '2010-05-01'),
	('2010-05-28', '2010-05-01'),
	('2010-05-29', '2010-05-01'),
	('2010-05-30', '2010-05-01'),
	('2010-05-31', '2010-05-01'),
	('2010-06-01', '2010-06-01'),
	('2010-06-02', '2010-06-01'),
	('2010-06-03', '2010-06-01'),
	('2010-06-04', '2010-06-01'),
	('2010-06-05', '2010-06-01'),
	('2010-06-06', '2010-06-01'),
	('2010-06-07', '2010-06-01'),
	('2010-06-08', '2010-06-01'),
	('2010-06-09', '2010-06-01'),
	('2010-06-10', '2010-06-01'),
	('2010-06-11', '2010-06-01'),
	('2010-06-12', '2010-06-01'),
	('2010-06-13', '2010-06-01'),
	('2010-06-14', '2010-06-01'),
	('2010-06-15', '2010-06-01'),
	('2010-06-16', '2010-06-01'),
	('2010-06-17', '2010-06-01'),
	('2010-06-18', '2010-06-01'),
	('2010-06-19', '2010-06-01'),
	('2010-06-20', '2010-06-01'),
	('2010-06-21', '2010-06-01'),
	('2010-06-22', '2010-06-01'),
	('2010-06-23', '2010-06-01'),
	('2010-06-24', '2010-06-01'),
	('2010-06-25', '2010-06-01'),
	('2010-06-26', '2010-06-01'),
	('2010-06-27', '2010-06-01'),
	('2010-06-28', '2010-06-01'),
	('2010-06-29', '2010-06-01'),
	('2010-06-30', '2010-06-01'),
	('2010-07-01', '2010-07-01'),
	('2010-07-02', '2010-07-01'),
	('2010-07-03', '2010-07-01'),
	('2010-07-04', '2010-07-01'),
	('2010-07-05', '2010-07-01'),
	('2010-07-06', '2010-07-01'),
	('2010-07-07', '2010-07-01'),
	('2010-07-08', '2010-07-01'),
	('2010-07-09', '2010-07-01'),
	('2010-07-10', '2010-07-01'),
	('2010-07-11', '2010-07-01'),
	('2010-07-12', '2010-07-01'),
	('2010-07-13', '2010-07-01'),
	('2010-07-14', '2010-07-01'),
	('2010-07-15', '2010-07-01'),
	('2010-07-16', '2010-07-01'),
	('2010-07-17', '2010-07-01'),
	('2010-07-18', '2010-07-01'),
	('2010-07-19', '2010-07-01'),
	('2010-07-20', '2010-07-01'),
	('2010-07-21', '2010-07-01'),
	('2010-07-22', '2010-07-01'),
	('2010-07-23', '2010-07-01'),
	('2010-07-24', '2010-07-01'),
	('2010-07-25', '2010-07-01'),
	('2010-07-26', '2010-07-01'),
	('2010-07-27', '2010-07-01'),
	('2010-07-28', '2010-07-01'),
	('2010-07-29', '2010-07-01'),
	('2010-07-30', '2010-07-01'),
	('2010-07-31', '2010-07-01'),
	('2010-08-01', '2010-08-01'),
	('2010-08-02', '2010-08-01'),
	('2010-08-03', '2010-08-01'),
	('2010-08-04', '2010-08-01'),
	('2010-08-05', '2010-08-01'),
	('2010-08-06', '2010-08-01'),
	('2010-08-07', '2010-08-01'),
	('2010-08-08', '2010-08-01'),
	('2010-08-09', '2010-08-01'),
	('2010-08-10', '2010-08-01'),
	('2010-08-11', '2010-08-01'),
	('2010-08-12', '2010-08-01'),
	('2010-08-13', '2010-08-01'),
	('2010-08-14', '2010-08-01'),
	('2010-08-15', '2010-08-01'),
	('2010-08-16', '2010-08-01'),
	('2010-08-17', '2010-08-01'),
	('2010-08-18', '2010-08-01'),
	('2010-08-19', '2010-08-01'),
	('2010-08-20', '2010-08-01'),
	('2010-08-21', '2010-08-01'),
	('2010-08-22', '2010-08-01'),
	('2010-08-23', '2010-08-01'),
	('2010-08-24', '2010-08-01'),
	('2010-08-25', '2010-08-01'),
	('2010-08-26', '2010-08-01'),
	('2010-08-27', '2010-08-01'),
	('2010-08-28', '2010-08-01'),
	('2010-08-29', '2010-08-01'),
	('2010-08-30', '2010-08-01'),
	('2010-08-31', '2010-08-01'),
	('2010-09-01', '2010-09-01'),
	('2010-09-02', '2010-09-01'),
	('2010-09-03', '2010-09-01'),
	('2010-09-04', '2010-09-01'),
	('2010-09-05', '2010-09-01'),
	('2010-09-06', '2010-09-01'),
	('2010-09-07', '2010-09-01'),
	('2010-09-08', '2010-09-01'),
	('2010-09-09', '2010-09-01'),
	('2010-09-10', '2010-09-01'),
	('2010-09-11', '2010-09-01'),
	('2010-09-12', '2010-09-01'),
	('2010-09-13', '2010-09-01'),
	('2010-09-14', '2010-09-01'),
	('2010-09-15', '2010-09-01'),
	('2010-09-16', '2010-09-01'),
	('2010-09-17', '2010-09-01'),
	('2010-09-18', '2010-09-01'),
	('2010-09-19', '2010-09-01'),
	('2010-09-20', '2010-09-01'),
	('2010-09-21', '2010-09-01'),
	('2010-09-22', '2010-09-01'),
	('2010-09-23', '2010-09-01'),
	('2010-09-24', '2010-09-01'),
	('2010-09-25', '2010-09-01'),
	('2010-09-26', '2010-09-01'),
	('2010-09-27', '2010-09-01'),
	('2010-09-28', '2010-09-01'),
	('2010-09-29', '2010-09-01'),
	('2010-09-30', '2010-09-01'),
	('2010-10-01', '2010-10-01'),
	('2010-10-02', '2010-10-01'),
	('2010-10-03', '2010-10-01'),
	('2010-10-04', '2010-10-01'),
	('2010-10-05', '2010-10-01'),
	('2010-10-06', '2010-10-01'),
	('2010-10-07', '2010-10-01'),
	('2010-10-08', '2010-10-01'),
	('2010-10-09', '2010-10-01'),
	('2010-10-10', '2010-10-01'),
	('2010-10-11', '2010-10-01'),
	('2010-10-12', '2010-10-01'),
	('2010-10-13', '2010-10-01'),
	('2010-10-14', '2010-10-01'),
	('2010-10-15', '2010-10-01'),
	('2010-10-16', '2010-10-01'),
	('2010-10-17', '2010-10-01'),
	('2010-10-18', '2010-10-01'),
	('2010-10-19', '2010-10-01'),
	('2010-10-20', '2010-10-01'),
	('2010-10-21', '2010-10-01'),
	('2010-10-22', '2010-10-01'),
	('2010-10-23', '2010-10-01'),
	('2010-10-24', '2010-10-01'),
	('2010-10-25', '2010-10-01'),
	('2010-10-26', '2010-10-01'),
	('2010-10-27', '2010-10-01'),
	('2010-10-28', '2010-10-01'),
	('2010-10-29', '2010-10-01'),
	('2010-10-30', '2010-10-01'),
	('2010-10-31', '2010-10-01'),
	('2010-11-01', '2010-11-01'),
	('2010-11-02', '2010-11-01'),
	('2010-11-03', '2010-11-01'),
	('2010-11-04', '2010-11-01'),
	('2010-11-05', '2010-11-01'),
	('2010-11-06', '2010-11-01'),
	('2010-11-07', '2010-11-01'),
	('2010-11-08', '2010-11-01'),
	('2010-11-09', '2010-11-01'),
	('2010-11-10', '2010-11-01'),
	('2010-11-11', '2010-11-01'),
	('2010-11-12', '2010-11-01'),
	('2010-11-13', '2010-11-01'),
	('2010-11-14', '2010-11-01'),
	('2010-11-15', '2010-11-01'),
	('2010-11-16', '2010-11-01'),
	('2010-11-17', '2010-11-01'),
	('2010-11-18', '2010-11-01'),
	('2010-11-19', '2010-11-01'),
	('2010-11-20', '2010-11-01'),
	('2010-11-21', '2010-11-01'),
	('2010-11-22', '2010-11-01'),
	('2010-11-23', '2010-11-01'),
	('2010-11-24', '2010-11-01'),
	('2010-11-25', '2010-11-01'),
	('2010-11-26', '2010-11-01'),
	('2010-11-27', '2010-11-01'),
	('2010-11-28', '2010-11-01'),
	('2010-11-29', '2010-11-01'),
	('2010-11-30', '2010-11-01'),
	('2010-12-01', '2010-12-01'),
	('2010-12-02', '2010-12-01'),
	('2010-12-03', '2010-12-01'),
	('2010-12-04', '2010-12-01'),
	('2010-12-05', '2010-12-01'),
	('2010-12-06', '2010-12-01'),
	('2010-12-07', '2010-12-01'),
	('2010-12-08', '2010-12-01'),
	('2010-12-09', '2010-12-01'),
	('2010-12-10', '2010-12-01'),
	('2010-12-11', '2010-12-01'),
	('2010-12-12', '2010-12-01'),
	('2010-12-13', '2010-12-01'),
	('2010-12-14', '2010-12-01'),
	('2010-12-15', '2010-12-01'),
	('2010-12-16', '2010-12-01'),
	('2010-12-17', '2010-12-01'),
	('2010-12-18', '2010-12-01'),
	('2010-12-19', '2010-12-01'),
	('2010-12-20', '2010-12-01'),
	('2010-12-21', '2010-12-01'),
	('2010-12-22', '2010-12-01'),
	('2010-12-23', '2010-12-01'),
	('2010-12-24', '2010-12-01'),
	('2010-12-25', '2010-12-01'),
	('2010-12-26', '2010-12-01'),
	('2010-12-27', '2010-12-01'),
	('2010-12-28', '2010-12-01'),
	('2010-12-29', '2010-12-01'),
	('2010-12-30', '2010-12-01'),
	('2010-12-31', '2010-12-01'),
	('2011-01-01', '2011-01-01'),
	('2011-01-02', '2011-01-01'),
	('2011-01-03', '2011-01-01'),
	('2011-01-04', '2011-01-01'),
	('2011-01-05', '2011-01-01'),
	('2011-01-06', '2011-01-01'),
	('2011-01-07', '2011-01-01'),
	('2011-01-08', '2011-01-01'),
	('2011-01-09', '2011-01-01'),
	('2011-01-10', '2011-01-01'),
	('2011-01-11', '2011-01-01'),
	('2011-01-12', '2011-01-01'),
	('2011-01-13', '2011-01-01'),
	('2011-01-14', '2011-01-01'),
	('2011-01-15', '2011-01-01'),
	('2011-01-16', '2011-01-01'),
	('2011-01-17', '2011-01-01'),
	('2011-01-18', '2011-01-01'),
	('2011-01-19', '2011-01-01'),
	('2011-01-20', '2011-01-01'),
	('2011-01-21', '2011-01-01'),
	('2011-01-22', '2011-01-01'),
	('2011-01-23', '2011-01-01'),
	('2011-01-24', '2011-01-01'),
	('2011-01-25', '2011-01-01'),
	('2011-01-26', '2011-01-01'),
	('2011-01-27', '2011-01-01'),
	('2011-01-28', '2011-01-01'),
	('2011-01-29', '2011-01-01'),
	('2011-01-30', '2011-01-01'),
	('2011-01-31', '2011-01-01'),
	('2011-02-01', '2011-02-01'),
	('2011-02-02', '2011-02-01'),
	('2011-02-03', '2011-02-01'),
	('2011-02-04', '2011-02-01'),
	('2011-02-05', '2011-02-01'),
	('2011-02-06', '2011-02-01'),
	('2011-02-07', '2011-02-01'),
	('2011-02-08', '2011-02-01'),
	('2011-02-09', '2011-02-01'),
	('2011-02-10', '2011-02-01'),
	('2011-02-11', '2011-02-01'),
	('2011-02-12', '2011-02-01'),
	('2011-02-13', '2011-02-01'),
	('2011-02-14', '2011-02-01'),
	('2011-02-15', '2011-02-01'),
	('2011-02-16', '2011-02-01'),
	('2011-02-17', '2011-02-01'),
	('2011-02-18', '2011-02-01'),
	('2011-02-19', '2011-02-01'),
	('2011-02-20', '2011-02-01'),
	('2011-02-21', '2011-02-01'),
	('2011-02-22', '2011-02-01'),
	('2011-02-23', '2011-02-01'),
	('2011-02-24', '2011-02-01'),
	('2011-02-25', '2011-02-01'),
	('2011-02-26', '2011-02-01'),
	('2011-02-27', '2011-02-01'),
	('2011-02-28', '2011-02-01'),
	('2011-03-01', '2011-03-01'),
	('2011-03-02', '2011-03-01'),
	('2011-03-03', '2011-03-01'),
	('2011-03-04', '2011-03-01'),
	('2011-03-05', '2011-03-01'),
	('2011-03-06', '2011-03-01'),
	('2011-03-07', '2011-03-01'),
	('2011-03-08', '2011-03-01'),
	('2011-03-09', '2011-03-01'),
	('2011-03-10', '2011-03-01'),
	('2011-03-11', '2011-03-01'),
	('2011-03-12', '2011-03-01'),
	('2011-03-13', '2011-03-01'),
	('2011-03-14', '2011-03-01'),
	('2011-03-15', '2011-03-01'),
	('2011-03-16', '2011-03-01'),
	('2011-03-17', '2011-03-01'),
	('2011-03-18', '2011-03-01'),
	('2011-03-19', '2011-03-01'),
	('2011-03-20', '2011-03-01'),
	('2011-03-21', '2011-03-01'),
	('2011-03-22', '2011-03-01'),
	('2011-03-23', '2011-03-01'),
	('2011-03-24', '2011-03-01'),
	('2011-03-25', '2011-03-01'),
	('2011-03-26', '2011-03-01'),
	('2011-03-27', '2011-03-01'),
	('2011-03-28', '2011-03-01'),
	('2011-03-29', '2011-03-01'),
	('2011-03-30', '2011-03-01'),
	('2011-03-31', '2011-03-01'),
	('2011-04-01', '2011-04-01'),
	('2011-04-02', '2011-04-01'),
	('2011-04-03', '2011-04-01'),
	('2011-04-04', '2011-04-01'),
	('2011-04-05', '2011-04-01'),
	('2011-04-06', '2011-04-01'),
	('2011-04-07', '2011-04-01'),
	('2011-04-08', '2011-04-01'),
	('2011-04-09', '2011-04-01'),
	('2011-04-10', '2011-04-01'),
	('2011-04-11', '2011-04-01'),
	('2011-04-12', '2011-04-01'),
	('2011-04-13', '2011-04-01'),
	('2011-04-14', '2011-04-01'),
	('2011-04-15', '2011-04-01'),
	('2011-04-16', '2011-04-01'),
	('2011-04-17', '2011-04-01'),
	('2011-04-18', '2011-04-01'),
	('2011-04-19', '2011-04-01'),
	('2011-04-20', '2011-04-01'),
	('2011-04-21', '2011-04-01'),
	('2011-04-22', '2011-04-01'),
	('2011-04-23', '2011-04-01'),
	('2011-04-24', '2011-04-01'),
	('2011-04-25', '2011-04-01'),
	('2011-04-26', '2011-04-01'),
	('2011-04-27', '2011-04-01'),
	('2011-04-28', '2011-04-01'),
	('2011-04-29', '2011-04-01'),
	('2011-04-30', '2011-04-01'),
	('2011-05-01', '2011-05-01'),
	('2011-05-02', '2011-05-01'),
	('2011-05-03', '2011-05-01'),
	('2011-05-04', '2011-05-01'),
	('2011-05-05', '2011-05-01'),
	('2011-05-06', '2011-05-01'),
	('2011-05-07', '2011-05-01'),
	('2011-05-08', '2011-05-01'),
	('2011-05-09', '2011-05-01'),
	('2011-05-10', '2011-05-01'),
	('2011-05-11', '2011-05-01'),
	('2011-05-12', '2011-05-01'),
	('2011-05-13', '2011-05-01'),
	('2011-05-14', '2011-05-01'),
	('2011-05-15', '2011-05-01'),
	('2011-05-16', '2011-05-01'),
	('2011-05-17', '2011-05-01'),
	('2011-05-18', '2011-05-01'),
	('2011-05-19', '2011-05-01'),
	('2011-05-20', '2011-05-01'),
	('2011-05-21', '2011-05-01'),
	('2011-05-22', '2011-05-01'),
	('2011-05-23', '2011-05-01'),
	('2011-05-24', '2011-05-01'),
	('2011-05-25', '2011-05-01'),
	('2011-05-26', '2011-05-01'),
	('2011-05-27', '2011-05-01'),
	('2011-05-28', '2011-05-01'),
	('2011-05-29', '2011-05-01'),
	('2011-05-30', '2011-05-01'),
	('2011-05-31', '2011-05-01'),
	('2011-06-01', '2011-06-01'),
	('2011-06-02', '2011-06-01'),
	('2011-06-03', '2011-06-01'),
	('2011-06-04', '2011-06-01'),
	('2011-06-05', '2011-06-01'),
	('2011-06-06', '2011-06-01'),
	('2011-06-07', '2011-06-01'),
	('2011-06-08', '2011-06-01'),
	('2011-06-09', '2011-06-01'),
	('2011-06-10', '2011-06-01'),
	('2011-06-11', '2011-06-01'),
	('2011-06-12', '2011-06-01'),
	('2011-06-13', '2011-06-01'),
	('2011-06-14', '2011-06-01'),
	('2011-06-15', '2011-06-01'),
	('2011-06-16', '2011-06-01'),
	('2011-06-17', '2011-06-01'),
	('2011-06-18', '2011-06-01'),
	('2011-06-19', '2011-06-01'),
	('2011-06-20', '2011-06-01'),
	('2011-06-21', '2011-06-01'),
	('2011-06-22', '2011-06-01'),
	('2011-06-23', '2011-06-01'),
	('2011-06-24', '2011-06-01'),
	('2011-06-25', '2011-06-01'),
	('2011-06-26', '2011-06-01'),
	('2011-06-27', '2011-06-01'),
	('2011-06-28', '2011-06-01'),
	('2011-06-29', '2011-06-01'),
	('2011-06-30', '2011-06-01'),
	('2011-07-01', '2011-07-01'),
	('2011-07-02', '2011-07-01'),
	('2011-07-03', '2011-07-01'),
	('2011-07-04', '2011-07-01'),
	('2011-07-05', '2011-07-01'),
	('2011-07-06', '2011-07-01'),
	('2011-07-07', '2011-07-01'),
	('2011-07-08', '2011-07-01'),
	('2011-07-09', '2011-07-01'),
	('2011-07-10', '2011-07-01'),
	('2011-07-11', '2011-07-01'),
	('2011-07-12', '2011-07-01'),
	('2011-07-13', '2011-07-01'),
	('2011-07-14', '2011-07-01'),
	('2011-07-15', '2011-07-01'),
	('2011-07-16', '2011-07-01'),
	('2011-07-17', '2011-07-01'),
	('2011-07-18', '2011-07-01'),
	('2011-07-19', '2011-07-01'),
	('2011-07-20', '2011-07-01'),
	('2011-07-21', '2011-07-01'),
	('2011-07-22', '2011-07-01'),
	('2011-07-23', '2011-07-01'),
	('2011-07-24', '2011-07-01'),
	('2011-07-25', '2011-07-01'),
	('2011-07-26', '2011-07-01'),
	('2011-07-27', '2011-07-01'),
	('2011-07-28', '2011-07-01'),
	('2011-07-29', '2011-07-01'),
	('2011-07-30', '2011-07-01'),
	('2011-07-31', '2011-07-01'),
	('2011-08-01', '2011-08-01'),
	('2011-08-02', '2011-08-01'),
	('2011-08-03', '2011-08-01'),
	('2011-08-04', '2011-08-01'),
	('2011-08-05', '2011-08-01'),
	('2011-08-06', '2011-08-01'),
	('2011-08-07', '2011-08-01'),
	('2011-08-08', '2011-08-01'),
	('2011-08-09', '2011-08-01'),
	('2011-08-10', '2011-08-01'),
	('2011-08-11', '2011-08-01'),
	('2011-08-12', '2011-08-01'),
	('2011-08-13', '2011-08-01'),
	('2011-08-14', '2011-08-01'),
	('2011-08-15', '2011-08-01'),
	('2011-08-16', '2011-08-01'),
	('2011-08-17', '2011-08-01'),
	('2011-08-18', '2011-08-01'),
	('2011-08-19', '2011-08-01'),
	('2011-08-20', '2011-08-01'),
	('2011-08-21', '2011-08-01'),
	('2011-08-22', '2011-08-01'),
	('2011-08-23', '2011-08-01'),
	('2011-08-24', '2011-08-01'),
	('2011-08-25', '2011-08-01'),
	('2011-08-26', '2011-08-01'),
	('2011-08-27', '2011-08-01'),
	('2011-08-28', '2011-08-01'),
	('2011-08-29', '2011-08-01'),
	('2011-08-30', '2011-08-01'),
	('2011-08-31', '2011-08-01'),
	('2011-09-01', '2011-09-01'),
	('2011-09-02', '2011-09-01'),
	('2011-09-03', '2011-09-01'),
	('2011-09-04', '2011-09-01'),
	('2011-09-05', '2011-09-01'),
	('2011-09-06', '2011-09-01'),
	('2011-09-07', '2011-09-01'),
	('2011-09-08', '2011-09-01'),
	('2011-09-09', '2011-09-01'),
	('2011-09-10', '2011-09-01'),
	('2011-09-11', '2011-09-01'),
	('2011-09-12', '2011-09-01'),
	('2011-09-13', '2011-09-01'),
	('2011-09-14', '2011-09-01'),
	('2011-09-15', '2011-09-01'),
	('2011-09-16', '2011-09-01'),
	('2011-09-17', '2011-09-01'),
	('2011-09-18', '2011-09-01'),
	('2011-09-19', '2011-09-01'),
	('2011-09-20', '2011-09-01'),
	('2011-09-21', '2011-09-01'),
	('2011-09-22', '2011-09-01'),
	('2011-09-23', '2011-09-01'),
	('2011-09-24', '2011-09-01'),
	('2011-09-25', '2011-09-01'),
	('2011-09-26', '2011-09-01'),
	('2011-09-27', '2011-09-01'),
	('2011-09-28', '2011-09-01'),
	('2011-09-29', '2011-09-01'),
	('2011-09-30', '2011-09-01'),
	('2011-10-01', '2011-10-01'),
	('2011-10-02', '2011-10-01'),
	('2011-10-03', '2011-10-01'),
	('2011-10-04', '2011-10-01'),
	('2011-10-05', '2011-10-01'),
	('2011-10-06', '2011-10-01'),
	('2011-10-07', '2011-10-01'),
	('2011-10-08', '2011-10-01'),
	('2011-10-09', '2011-10-01'),
	('2011-10-10', '2011-10-01'),
	('2011-10-11', '2011-10-01'),
	('2011-10-12', '2011-10-01'),
	('2011-10-13', '2011-10-01'),
	('2011-10-14', '2011-10-01'),
	('2011-10-15', '2011-10-01'),
	('2011-10-16', '2011-10-01'),
	('2011-10-17', '2011-10-01'),
	('2011-10-18', '2011-10-01'),
	('2011-10-19', '2011-10-01'),
	('2011-10-20', '2011-10-01'),
	('2011-10-21', '2011-10-01'),
	('2011-10-22', '2011-10-01'),
	('2011-10-23', '2011-10-01'),
	('2011-10-24', '2011-10-01'),
	('2011-10-25', '2011-10-01'),
	('2011-10-26', '2011-10-01'),
	('2011-10-27', '2011-10-01'),
	('2011-10-28', '2011-10-01'),
	('2011-10-29', '2011-10-01'),
	('2011-10-30', '2011-10-01'),
	('2011-10-31', '2011-10-01'),
	('2011-11-01', '2011-11-01'),
	('2011-11-02', '2011-11-01'),
	('2011-11-03', '2011-11-01'),
	('2011-11-04', '2011-11-01'),
	('2011-11-05', '2011-11-01'),
	('2011-11-06', '2011-11-01'),
	('2011-11-07', '2011-11-01'),
	('2011-11-08', '2011-11-01'),
	('2011-11-09', '2011-11-01'),
	('2011-11-10', '2011-11-01'),
	('2011-11-11', '2011-11-01'),
	('2011-11-12', '2011-11-01'),
	('2011-11-13', '2011-11-01'),
	('2011-11-14', '2011-11-01'),
	('2011-11-15', '2011-11-01'),
	('2011-11-16', '2011-11-01'),
	('2011-11-17', '2011-11-01'),
	('2011-11-18', '2011-11-01'),
	('2011-11-19', '2011-11-01'),
	('2011-11-20', '2011-11-01'),
	('2011-11-21', '2011-11-01'),
	('2011-11-22', '2011-11-01'),
	('2011-11-23', '2011-11-01'),
	('2011-11-24', '2011-11-01'),
	('2011-11-25', '2011-11-01'),
	('2011-11-26', '2011-11-01'),
	('2011-11-27', '2011-11-01'),
	('2011-11-28', '2011-11-01'),
	('2011-11-29', '2011-11-01'),
	('2011-11-30', '2011-11-01'),
	('2011-12-01', '2011-12-01'),
	('2011-12-02', '2011-12-01'),
	('2011-12-03', '2011-12-01'),
	('2011-12-04', '2011-12-01'),
	('2011-12-05', '2011-12-01'),
	('2011-12-06', '2011-12-01'),
	('2011-12-07', '2011-12-01'),
	('2011-12-08', '2011-12-01'),
	('2011-12-09', '2011-12-01'),
	('2011-12-10', '2011-12-01'),
	('2011-12-11', '2011-12-01'),
	('2011-12-12', '2011-12-01'),
	('2011-12-13', '2011-12-01'),
	('2011-12-14', '2011-12-01'),
	('2011-12-15', '2011-12-01'),
	('2011-12-16', '2011-12-01'),
	('2011-12-17', '2011-12-01'),
	('2011-12-18', '2011-12-01'),
	('2011-12-19', '2011-12-01'),
	('2011-12-20', '2011-12-01'),
	('2011-12-21', '2011-12-01'),
	('2011-12-22', '2011-12-01'),
	('2011-12-23', '2011-12-01'),
	('2011-12-24', '2011-12-01'),
	('2011-12-25', '2011-12-01'),
	('2011-12-26', '2011-12-01'),
	('2011-12-27', '2011-12-01'),
	('2011-12-28', '2011-12-01'),
	('2011-12-29', '2011-12-01'),
	('2011-12-30', '2011-12-01'),
	('2011-12-31', '2011-12-01'),
	('2012-01-01', '2012-01-01'),
	('2012-01-02', '2012-01-01'),
	('2012-01-03', '2012-01-01'),
	('2012-01-04', '2012-01-01'),
	('2012-01-05', '2012-01-01'),
	('2012-01-06', '2012-01-01'),
	('2012-01-07', '2012-01-01'),
	('2012-01-08', '2012-01-01'),
	('2012-01-09', '2012-01-01'),
	('2012-01-10', '2012-01-01'),
	('2012-01-11', '2012-01-01'),
	('2012-01-12', '2012-01-01'),
	('2012-01-13', '2012-01-01'),
	('2012-01-14', '2012-01-01'),
	('2012-01-15', '2012-01-01'),
	('2012-01-16', '2012-01-01'),
	('2012-01-17', '2012-01-01'),
	('2012-01-18', '2012-01-01'),
	('2012-01-19', '2012-01-01'),
	('2012-01-20', '2012-01-01'),
	('2012-01-21', '2012-01-01'),
	('2012-01-22', '2012-01-01'),
	('2012-01-23', '2012-01-01'),
	('2012-01-24', '2012-01-01'),
	('2012-01-25', '2012-01-01'),
	('2012-01-26', '2012-01-01'),
	('2012-01-27', '2012-01-01'),
	('2012-01-28', '2012-01-01'),
	('2012-01-29', '2012-01-01'),
	('2012-01-30', '2012-01-01'),
	('2012-01-31', '2012-01-01'),
	('2012-02-01', '2012-02-01'),
	('2012-02-02', '2012-02-01'),
	('2012-02-03', '2012-02-01'),
	('2012-02-04', '2012-02-01'),
	('2012-02-05', '2012-02-01'),
	('2012-02-06', '2012-02-01'),
	('2012-02-07', '2012-02-01'),
	('2012-02-08', '2012-02-01'),
	('2012-02-09', '2012-02-01'),
	('2012-02-10', '2012-02-01'),
	('2012-02-11', '2012-02-01'),
	('2012-02-12', '2012-02-01'),
	('2012-02-13', '2012-02-01'),
	('2012-02-14', '2012-02-01'),
	('2012-02-15', '2012-02-01'),
	('2012-02-16', '2012-02-01'),
	('2012-02-17', '2012-02-01'),
	('2012-02-18', '2012-02-01'),
	('2012-02-19', '2012-02-01'),
	('2012-02-20', '2012-02-01'),
	('2012-02-21', '2012-02-01'),
	('2012-02-22', '2012-02-01'),
	('2012-02-23', '2012-02-01'),
	('2012-02-24', '2012-02-01'),
	('2012-02-25', '2012-02-01'),
	('2012-02-26', '2012-02-01'),
	('2012-02-27', '2012-02-01'),
	('2012-02-28', '2012-02-01'),
	('2012-02-29', '2012-02-01'),
	('2012-03-01', '2012-03-01'),
	('2012-03-02', '2012-03-01'),
	('2012-03-03', '2012-03-01'),
	('2012-03-04', '2012-03-01'),
	('2012-03-05', '2012-03-01'),
	('2012-03-06', '2012-03-01'),
	('2012-03-07', '2012-03-01'),
	('2012-03-08', '2012-03-01'),
	('2012-03-09', '2012-03-01'),
	('2012-03-10', '2012-03-01'),
	('2012-03-11', '2012-03-01'),
	('2012-03-12', '2012-03-01'),
	('2012-03-13', '2012-03-01'),
	('2012-03-14', '2012-03-01'),
	('2012-03-15', '2012-03-01'),
	('2012-03-16', '2012-03-01'),
	('2012-03-17', '2012-03-01'),
	('2012-03-18', '2012-03-01'),
	('2012-03-19', '2012-03-01'),
	('2012-03-20', '2012-03-01'),
	('2012-03-21', '2012-03-01'),
	('2012-03-22', '2012-03-01'),
	('2012-03-23', '2012-03-01'),
	('2012-03-24', '2012-03-01'),
	('2012-03-25', '2012-03-01'),
	('2012-03-26', '2012-03-01'),
	('2012-03-27', '2012-03-01'),
	('2012-03-28', '2012-03-01'),
	('2012-03-29', '2012-03-01'),
	('2012-03-30', '2012-03-01'),
	('2012-03-31', '2012-03-01'),
	('2012-04-01', '2012-04-01'),
	('2012-04-02', '2012-04-01'),
	('2012-04-03', '2012-04-01'),
	('2012-04-04', '2012-04-01'),
	('2012-04-05', '2012-04-01'),
	('2012-04-06', '2012-04-01'),
	('2012-04-07', '2012-04-01'),
	('2012-04-08', '2012-04-01'),
	('2012-04-09', '2012-04-01'),
	('2012-04-10', '2012-04-01'),
	('2012-04-11', '2012-04-01'),
	('2012-04-12', '2012-04-01'),
	('2012-04-13', '2012-04-01'),
	('2012-04-14', '2012-04-01'),
	('2012-04-15', '2012-04-01'),
	('2012-04-16', '2012-04-01'),
	('2012-04-17', '2012-04-01'),
	('2012-04-18', '2012-04-01'),
	('2012-04-19', '2012-04-01'),
	('2012-04-20', '2012-04-01'),
	('2012-04-21', '2012-04-01'),
	('2012-04-22', '2012-04-01'),
	('2012-04-23', '2012-04-01'),
	('2012-04-24', '2012-04-01'),
	('2012-04-25', '2012-04-01'),
	('2012-04-26', '2012-04-01'),
	('2012-04-27', '2012-04-01'),
	('2012-04-28', '2012-04-01'),
	('2012-04-29', '2012-04-01'),
	('2012-04-30', '2012-04-01'),
	('2012-05-01', '2012-05-01'),
	('2012-05-02', '2012-05-01'),
	('2012-05-03', '2012-05-01'),
	('2012-05-04', '2012-05-01'),
	('2012-05-05', '2012-05-01'),
	('2012-05-06', '2012-05-01'),
	('2012-05-07', '2012-05-01'),
	('2012-05-08', '2012-05-01'),
	('2012-05-09', '2012-05-01'),
	('2012-05-10', '2012-05-01'),
	('2012-05-11', '2012-05-01'),
	('2012-05-12', '2012-05-01'),
	('2012-05-13', '2012-05-01'),
	('2012-05-14', '2012-05-01'),
	('2012-05-15', '2012-05-01'),
	('2012-05-16', '2012-05-01'),
	('2012-05-17', '2012-05-01'),
	('2012-05-18', '2012-05-01'),
	('2012-05-19', '2012-05-01'),
	('2012-05-20', '2012-05-01'),
	('2012-05-21', '2012-05-01'),
	('2012-05-22', '2012-05-01'),
	('2012-05-23', '2012-05-01'),
	('2012-05-24', '2012-05-01'),
	('2012-05-25', '2012-05-01'),
	('2012-05-26', '2012-05-01'),
	('2012-05-27', '2012-05-01'),
	('2012-05-28', '2012-05-01'),
	('2012-05-29', '2012-05-01'),
	('2012-05-30', '2012-05-01'),
	('2012-05-31', '2012-05-01'),
	('2012-06-01', '2012-06-01'),
	('2012-06-02', '2012-06-01'),
	('2012-06-03', '2012-06-01'),
	('2012-06-04', '2012-06-01'),
	('2012-06-05', '2012-06-01'),
	('2012-06-06', '2012-06-01'),
	('2012-06-07', '2012-06-01'),
	('2012-06-08', '2012-06-01'),
	('2012-06-09', '2012-06-01'),
	('2012-06-10', '2012-06-01'),
	('2012-06-11', '2012-06-01'),
	('2012-06-12', '2012-06-01'),
	('2012-06-13', '2012-06-01'),
	('2012-06-14', '2012-06-01'),
	('2012-06-15', '2012-06-01'),
	('2012-06-16', '2012-06-01'),
	('2012-06-17', '2012-06-01'),
	('2012-06-18', '2012-06-01'),
	('2012-06-19', '2012-06-01'),
	('2012-06-20', '2012-06-01'),
	('2012-06-21', '2012-06-01'),
	('2012-06-22', '2012-06-01'),
	('2012-06-23', '2012-06-01'),
	('2012-06-24', '2012-06-01'),
	('2012-06-25', '2012-06-01'),
	('2012-06-26', '2012-06-01'),
	('2012-06-27', '2012-06-01'),
	('2012-06-28', '2012-06-01'),
	('2012-06-29', '2012-06-01'),
	('2012-06-30', '2012-06-01'),
	('2012-07-01', '2012-07-01'),
	('2012-07-02', '2012-07-01'),
	('2012-07-03', '2012-07-01'),
	('2012-07-04', '2012-07-01'),
	('2012-07-05', '2012-07-01'),
	('2012-07-06', '2012-07-01'),
	('2012-07-07', '2012-07-01'),
	('2012-07-08', '2012-07-01'),
	('2012-07-09', '2012-07-01'),
	('2012-07-10', '2012-07-01'),
	('2012-07-11', '2012-07-01'),
	('2012-07-12', '2012-07-01'),
	('2012-07-13', '2012-07-01'),
	('2012-07-14', '2012-07-01'),
	('2012-07-15', '2012-07-01'),
	('2012-07-16', '2012-07-01'),
	('2012-07-17', '2012-07-01'),
	('2012-07-18', '2012-07-01'),
	('2012-07-19', '2012-07-01'),
	('2012-07-20', '2012-07-01'),
	('2012-07-21', '2012-07-01'),
	('2012-07-22', '2012-07-01'),
	('2012-07-23', '2012-07-01'),
	('2012-07-24', '2012-07-01'),
	('2012-07-25', '2012-07-01'),
	('2012-07-26', '2012-07-01'),
	('2012-07-27', '2012-07-01'),
	('2012-07-28', '2012-07-01'),
	('2012-07-29', '2012-07-01'),
	('2012-07-30', '2012-07-01'),
	('2012-07-31', '2012-07-01'),
	('2012-08-01', '2012-08-01'),
	('2012-08-02', '2012-08-01'),
	('2012-08-03', '2012-08-01'),
	('2012-08-04', '2012-08-01'),
	('2012-08-05', '2012-08-01'),
	('2012-08-06', '2012-08-01'),
	('2012-08-07', '2012-08-01'),
	('2012-08-08', '2012-08-01'),
	('2012-08-09', '2012-08-01'),
	('2012-08-10', '2012-08-01'),
	('2012-08-11', '2012-08-01'),
	('2012-08-12', '2012-08-01'),
	('2012-08-13', '2012-08-01'),
	('2012-08-14', '2012-08-01'),
	('2012-08-15', '2012-08-01'),
	('2012-08-16', '2012-08-01'),
	('2012-08-17', '2012-08-01'),
	('2012-08-18', '2012-08-01'),
	('2012-08-19', '2012-08-01'),
	('2012-08-20', '2012-08-01'),
	('2012-08-21', '2012-08-01'),
	('2012-08-22', '2012-08-01'),
	('2012-08-23', '2012-08-01'),
	('2012-08-24', '2012-08-01'),
	('2012-08-25', '2012-08-01'),
	('2012-08-26', '2012-08-01'),
	('2012-08-27', '2012-08-01'),
	('2012-08-28', '2012-08-01'),
	('2012-08-29', '2012-08-01'),
	('2012-08-30', '2012-08-01'),
	('2012-08-31', '2012-08-01'),
	('2012-09-01', '2012-09-01'),
	('2012-09-02', '2012-09-01'),
	('2012-09-03', '2012-09-01'),
	('2012-09-04', '2012-09-01'),
	('2012-09-05', '2012-09-01'),
	('2012-09-06', '2012-09-01'),
	('2012-09-07', '2012-09-01'),
	('2012-09-08', '2012-09-01'),
	('2012-09-09', '2012-09-01'),
	('2012-09-10', '2012-09-01'),
	('2012-09-11', '2012-09-01'),
	('2012-09-12', '2012-09-01'),
	('2012-09-13', '2012-09-01'),
	('2012-09-14', '2012-09-01'),
	('2012-09-15', '2012-09-01'),
	('2012-09-16', '2012-09-01'),
	('2012-09-17', '2012-09-01'),
	('2012-09-18', '2012-09-01'),
	('2012-09-19', '2012-09-01'),
	('2012-09-20', '2012-09-01'),
	('2012-09-21', '2012-09-01'),
	('2012-09-22', '2012-09-01'),
	('2012-09-23', '2012-09-01'),
	('2012-09-24', '2012-09-01'),
	('2012-09-25', '2012-09-01'),
	('2012-09-26', '2012-09-01'),
	('2012-09-27', '2012-09-01'),
	('2012-09-28', '2012-09-01'),
	('2012-09-29', '2012-09-01'),
	('2012-09-30', '2012-09-01'),
	('2012-10-01', '2012-10-01'),
	('2012-10-02', '2012-10-01'),
	('2012-10-03', '2012-10-01'),
	('2012-10-04', '2012-10-01'),
	('2012-10-05', '2012-10-01'),
	('2012-10-06', '2012-10-01'),
	('2012-10-07', '2012-10-01'),
	('2012-10-08', '2012-10-01'),
	('2012-10-09', '2012-10-01'),
	('2012-10-10', '2012-10-01'),
	('2012-10-11', '2012-10-01'),
	('2012-10-12', '2012-10-01'),
	('2012-10-13', '2012-10-01'),
	('2012-10-14', '2012-10-01'),
	('2012-10-15', '2012-10-01'),
	('2012-10-16', '2012-10-01'),
	('2012-10-17', '2012-10-01'),
	('2012-10-18', '2012-10-01'),
	('2012-10-19', '2012-10-01'),
	('2012-10-20', '2012-10-01'),
	('2012-10-21', '2012-10-01'),
	('2012-10-22', '2012-10-01'),
	('2012-10-23', '2012-10-01'),
	('2012-10-24', '2012-10-01'),
	('2012-10-25', '2012-10-01'),
	('2012-10-26', '2012-10-01'),
	('2012-10-27', '2012-10-01'),
	('2012-10-28', '2012-10-01'),
	('2012-10-29', '2012-10-01'),
	('2012-10-30', '2012-10-01'),
	('2012-10-31', '2012-10-01'),
	('2012-11-01', '2012-11-01'),
	('2012-11-02', '2012-11-01'),
	('2012-11-03', '2012-11-01'),
	('2012-11-04', '2012-11-01'),
	('2012-11-05', '2012-11-01'),
	('2012-11-06', '2012-11-01'),
	('2012-11-07', '2012-11-01'),
	('2012-11-08', '2012-11-01'),
	('2012-11-09', '2012-11-01'),
	('2012-11-10', '2012-11-01'),
	('2012-11-11', '2012-11-01'),
	('2012-11-12', '2012-11-01'),
	('2012-11-13', '2012-11-01'),
	('2012-11-14', '2012-11-01'),
	('2012-11-15', '2012-11-01'),
	('2012-11-16', '2012-11-01'),
	('2012-11-17', '2012-11-01'),
	('2012-11-18', '2012-11-01'),
	('2012-11-19', '2012-11-01'),
	('2012-11-20', '2012-11-01'),
	('2012-11-21', '2012-11-01'),
	('2012-11-22', '2012-11-01'),
	('2012-11-23', '2012-11-01'),
	('2012-11-24', '2012-11-01'),
	('2012-11-25', '2012-11-01'),
	('2012-11-26', '2012-11-01'),
	('2012-11-27', '2012-11-01'),
	('2012-11-28', '2012-11-01'),
	('2012-11-29', '2012-11-01'),
	('2012-11-30', '2012-11-01'),
	('2012-12-01', '2012-12-01'),
	('2012-12-02', '2012-12-01'),
	('2012-12-03', '2012-12-01'),
	('2012-12-04', '2012-12-01'),
	('2012-12-05', '2012-12-01'),
	('2012-12-06', '2012-12-01'),
	('2012-12-07', '2012-12-01'),
	('2012-12-08', '2012-12-01'),
	('2012-12-09', '2012-12-01'),
	('2012-12-10', '2012-12-01'),
	('2012-12-11', '2012-12-01'),
	('2012-12-12', '2012-12-01'),
	('2012-12-13', '2012-12-01'),
	('2012-12-14', '2012-12-01'),
	('2012-12-15', '2012-12-01'),
	('2012-12-16', '2012-12-01'),
	('2012-12-17', '2012-12-01'),
	('2012-12-18', '2012-12-01'),
	('2012-12-19', '2012-12-01'),
	('2012-12-20', '2012-12-01'),
	('2012-12-21', '2012-12-01'),
	('2012-12-22', '2012-12-01'),
	('2012-12-23', '2012-12-01'),
	('2012-12-24', '2012-12-01'),
	('2012-12-25', '2012-12-01'),
	('2012-12-26', '2012-12-01'),
	('2012-12-27', '2012-12-01'),
	('2012-12-28', '2012-12-01'),
	('2012-12-29', '2012-12-01'),
	('2012-12-30', '2012-12-01'),
	('2012-12-31', '2012-12-01'),
	('2013-01-01', '2013-01-01'),
	('2013-01-02', '2013-01-01'),
	('2013-01-03', '2013-01-01'),
	('2013-01-04', '2013-01-01'),
	('2013-01-05', '2013-01-01'),
	('2013-01-06', '2013-01-01'),
	('2013-01-07', '2013-01-01'),
	('2013-01-08', '2013-01-01'),
	('2013-01-09', '2013-01-01'),
	('2013-01-10', '2013-01-01'),
	('2013-01-11', '2013-01-01'),
	('2013-01-12', '2013-01-01'),
	('2013-01-13', '2013-01-01'),
	('2013-01-14', '2013-01-01'),
	('2013-01-15', '2013-01-01'),
	('2013-01-16', '2013-01-01'),
	('2013-01-17', '2013-01-01'),
	('2013-01-18', '2013-01-01'),
	('2013-01-19', '2013-01-01'),
	('2013-01-20', '2013-01-01'),
	('2013-01-21', '2013-01-01'),
	('2013-01-22', '2013-01-01'),
	('2013-01-23', '2013-01-01'),
	('2013-01-24', '2013-01-01'),
	('2013-01-25', '2013-01-01'),
	('2013-01-26', '2013-01-01'),
	('2013-01-27', '2013-01-01'),
	('2013-01-28', '2013-01-01'),
	('2013-01-29', '2013-01-01'),
	('2013-01-30', '2013-01-01'),
	('2013-01-31', '2013-01-01'),
	('2013-02-01', '2013-02-01'),
	('2013-02-02', '2013-02-01'),
	('2013-02-03', '2013-02-01'),
	('2013-02-04', '2013-02-01'),
	('2013-02-05', '2013-02-01'),
	('2013-02-06', '2013-02-01'),
	('2013-02-07', '2013-02-01'),
	('2013-02-08', '2013-02-01'),
	('2013-02-09', '2013-02-01'),
	('2013-02-10', '2013-02-01'),
	('2013-02-11', '2013-02-01'),
	('2013-02-12', '2013-02-01'),
	('2013-02-13', '2013-02-01'),
	('2013-02-14', '2013-02-01'),
	('2013-02-15', '2013-02-01'),
	('2013-02-16', '2013-02-01'),
	('2013-02-17', '2013-02-01'),
	('2013-02-18', '2013-02-01'),
	('2013-02-19', '2013-02-01'),
	('2013-02-20', '2013-02-01'),
	('2013-02-21', '2013-02-01'),
	('2013-02-22', '2013-02-01'),
	('2013-02-23', '2013-02-01'),
	('2013-02-24', '2013-02-01'),
	('2013-02-25', '2013-02-01'),
	('2013-02-26', '2013-02-01'),
	('2013-02-27', '2013-02-01'),
	('2013-02-28', '2013-02-01'),
	('2013-03-01', '2013-03-01'),
	('2013-03-02', '2013-03-01'),
	('2013-03-03', '2013-03-01'),
	('2013-03-04', '2013-03-01'),
	('2013-03-05', '2013-03-01'),
	('2013-03-06', '2013-03-01'),
	('2013-03-07', '2013-03-01'),
	('2013-03-08', '2013-03-01'),
	('2013-03-09', '2013-03-01'),
	('2013-03-10', '2013-03-01'),
	('2013-03-11', '2013-03-01'),
	('2013-03-12', '2013-03-01'),
	('2013-03-13', '2013-03-01'),
	('2013-03-14', '2013-03-01'),
	('2013-03-15', '2013-03-01'),
	('2013-03-16', '2013-03-01'),
	('2013-03-17', '2013-03-01'),
	('2013-03-18', '2013-03-01'),
	('2013-03-19', '2013-03-01'),
	('2013-03-20', '2013-03-01'),
	('2013-03-21', '2013-03-01'),
	('2013-03-22', '2013-03-01'),
	('2013-03-23', '2013-03-01'),
	('2013-03-24', '2013-03-01'),
	('2013-03-25', '2013-03-01'),
	('2013-03-26', '2013-03-01'),
	('2013-03-27', '2013-03-01'),
	('2013-03-28', '2013-03-01'),
	('2013-03-29', '2013-03-01'),
	('2013-03-30', '2013-03-01'),
	('2013-03-31', '2013-03-01'),
	('2013-04-01', '2013-04-01'),
	('2013-04-02', '2013-04-01'),
	('2013-04-03', '2013-04-01'),
	('2013-04-04', '2013-04-01'),
	('2013-04-05', '2013-04-01'),
	('2013-04-06', '2013-04-01'),
	('2013-04-07', '2013-04-01'),
	('2013-04-08', '2013-04-01'),
	('2013-04-09', '2013-04-01'),
	('2013-04-10', '2013-04-01'),
	('2013-04-11', '2013-04-01'),
	('2013-04-12', '2013-04-01'),
	('2013-04-13', '2013-04-01'),
	('2013-04-14', '2013-04-01'),
	('2013-04-15', '2013-04-01'),
	('2013-04-16', '2013-04-01'),
	('2013-04-17', '2013-04-01'),
	('2013-04-18', '2013-04-01'),
	('2013-04-19', '2013-04-01'),
	('2013-04-20', '2013-04-01'),
	('2013-04-21', '2013-04-01'),
	('2013-04-22', '2013-04-01'),
	('2013-04-23', '2013-04-01'),
	('2013-04-24', '2013-04-01'),
	('2013-04-25', '2013-04-01'),
	('2013-04-26', '2013-04-01'),
	('2013-04-27', '2013-04-01'),
	('2013-04-28', '2013-04-01'),
	('2013-04-29', '2013-04-01'),
	('2013-04-30', '2013-04-01'),
	('2013-05-01', '2013-05-01'),
	('2013-05-02', '2013-05-01'),
	('2013-05-03', '2013-05-01'),
	('2013-05-04', '2013-05-01'),
	('2013-05-05', '2013-05-01'),
	('2013-05-06', '2013-05-01'),
	('2013-05-07', '2013-05-01'),
	('2013-05-08', '2013-05-01'),
	('2013-05-09', '2013-05-01'),
	('2013-05-10', '2013-05-01'),
	('2013-05-11', '2013-05-01'),
	('2013-05-12', '2013-05-01'),
	('2013-05-13', '2013-05-01'),
	('2013-05-14', '2013-05-01'),
	('2013-05-15', '2013-05-01'),
	('2013-05-16', '2013-05-01'),
	('2013-05-17', '2013-05-01'),
	('2013-05-18', '2013-05-01'),
	('2013-05-19', '2013-05-01'),
	('2013-05-20', '2013-05-01'),
	('2013-05-21', '2013-05-01'),
	('2013-05-22', '2013-05-01'),
	('2013-05-23', '2013-05-01'),
	('2013-05-24', '2013-05-01'),
	('2013-05-25', '2013-05-01'),
	('2013-05-26', '2013-05-01'),
	('2013-05-27', '2013-05-01'),
	('2013-05-28', '2013-05-01'),
	('2013-05-29', '2013-05-01'),
	('2013-05-30', '2013-05-01'),
	('2013-05-31', '2013-05-01'),
	('2013-06-01', '2013-06-01'),
	('2013-06-02', '2013-06-01'),
	('2013-06-03', '2013-06-01'),
	('2013-06-04', '2013-06-01'),
	('2013-06-05', '2013-06-01'),
	('2013-06-06', '2013-06-01'),
	('2013-06-07', '2013-06-01'),
	('2013-06-08', '2013-06-01'),
	('2013-06-09', '2013-06-01'),
	('2013-06-10', '2013-06-01'),
	('2013-06-11', '2013-06-01'),
	('2013-06-12', '2013-06-01'),
	('2013-06-13', '2013-06-01'),
	('2013-06-14', '2013-06-01'),
	('2013-06-15', '2013-06-01'),
	('2013-06-16', '2013-06-01'),
	('2013-06-17', '2013-06-01'),
	('2013-06-18', '2013-06-01'),
	('2013-06-19', '2013-06-01'),
	('2013-06-20', '2013-06-01'),
	('2013-06-21', '2013-06-01'),
	('2013-06-22', '2013-06-01'),
	('2013-06-23', '2013-06-01'),
	('2013-06-24', '2013-06-01'),
	('2013-06-25', '2013-06-01'),
	('2013-06-26', '2013-06-01'),
	('2013-06-27', '2013-06-01'),
	('2013-06-28', '2013-06-01'),
	('2013-06-29', '2013-06-01'),
	('2013-06-30', '2013-06-01'),
	('2013-07-01', '2013-07-01'),
	('2013-07-02', '2013-07-01'),
	('2013-07-03', '2013-07-01'),
	('2013-07-04', '2013-07-01'),
	('2013-07-05', '2013-07-01'),
	('2013-07-06', '2013-07-01'),
	('2013-07-07', '2013-07-01'),
	('2013-07-08', '2013-07-01'),
	('2013-07-09', '2013-07-01'),
	('2013-07-10', '2013-07-01'),
	('2013-07-11', '2013-07-01'),
	('2013-07-12', '2013-07-01'),
	('2013-07-13', '2013-07-01'),
	('2013-07-14', '2013-07-01'),
	('2013-07-15', '2013-07-01'),
	('2013-07-16', '2013-07-01'),
	('2013-07-17', '2013-07-01'),
	('2013-07-18', '2013-07-01'),
	('2013-07-19', '2013-07-01'),
	('2013-07-20', '2013-07-01'),
	('2013-07-21', '2013-07-01'),
	('2013-07-22', '2013-07-01'),
	('2013-07-23', '2013-07-01'),
	('2013-07-24', '2013-07-01'),
	('2013-07-25', '2013-07-01'),
	('2013-07-26', '2013-07-01'),
	('2013-07-27', '2013-07-01'),
	('2013-07-28', '2013-07-01'),
	('2013-07-29', '2013-07-01'),
	('2013-07-30', '2013-07-01'),
	('2013-07-31', '2013-07-01'),
	('2013-08-01', '2013-08-01'),
	('2013-08-02', '2013-08-01'),
	('2013-08-03', '2013-08-01'),
	('2013-08-04', '2013-08-01'),
	('2013-08-05', '2013-08-01'),
	('2013-08-06', '2013-08-01'),
	('2013-08-07', '2013-08-01'),
	('2013-08-08', '2013-08-01'),
	('2013-08-09', '2013-08-01'),
	('2013-08-10', '2013-08-01'),
	('2013-08-11', '2013-08-01'),
	('2013-08-12', '2013-08-01'),
	('2013-08-13', '2013-08-01'),
	('2013-08-14', '2013-08-01'),
	('2013-08-15', '2013-08-01'),
	('2013-08-16', '2013-08-01'),
	('2013-08-17', '2013-08-01'),
	('2013-08-18', '2013-08-01'),
	('2013-08-19', '2013-08-01'),
	('2013-08-20', '2013-08-01'),
	('2013-08-21', '2013-08-01'),
	('2013-08-22', '2013-08-01'),
	('2013-08-23', '2013-08-01'),
	('2013-08-24', '2013-08-01'),
	('2013-08-25', '2013-08-01'),
	('2013-08-26', '2013-08-01'),
	('2013-08-27', '2013-08-01'),
	('2013-08-28', '2013-08-01'),
	('2013-08-29', '2013-08-01'),
	('2013-08-30', '2013-08-01'),
	('2013-08-31', '2013-08-01'),
	('2013-09-01', '2013-09-01'),
	('2013-09-02', '2013-09-01'),
	('2013-09-03', '2013-09-01'),
	('2013-09-04', '2013-09-01'),
	('2013-09-05', '2013-09-01'),
	('2013-09-06', '2013-09-01'),
	('2013-09-07', '2013-09-01'),
	('2013-09-08', '2013-09-01'),
	('2013-09-09', '2013-09-01'),
	('2013-09-10', '2013-09-01'),
	('2013-09-11', '2013-09-01'),
	('2013-09-12', '2013-09-01'),
	('2013-09-13', '2013-09-01'),
	('2013-09-14', '2013-09-01'),
	('2013-09-15', '2013-09-01'),
	('2013-09-16', '2013-09-01'),
	('2013-09-17', '2013-09-01'),
	('2013-09-18', '2013-09-01'),
	('2013-09-19', '2013-09-01'),
	('2013-09-20', '2013-09-01'),
	('2013-09-21', '2013-09-01'),
	('2013-09-22', '2013-09-01'),
	('2013-09-23', '2013-09-01'),
	('2013-09-24', '2013-09-01'),
	('2013-09-25', '2013-09-01'),
	('2013-09-26', '2013-09-01'),
	('2013-09-27', '2013-09-01'),
	('2013-09-28', '2013-09-01'),
	('2013-09-29', '2013-09-01'),
	('2013-09-30', '2013-09-01'),
	('2013-10-01', '2013-10-01'),
	('2013-10-02', '2013-10-01'),
	('2013-10-03', '2013-10-01'),
	('2013-10-04', '2013-10-01'),
	('2013-10-05', '2013-10-01'),
	('2013-10-06', '2013-10-01'),
	('2013-10-07', '2013-10-01'),
	('2013-10-08', '2013-10-01'),
	('2013-10-09', '2013-10-01'),
	('2013-10-10', '2013-10-01'),
	('2013-10-11', '2013-10-01'),
	('2013-10-12', '2013-10-01'),
	('2013-10-13', '2013-10-01'),
	('2013-10-14', '2013-10-01'),
	('2013-10-15', '2013-10-01'),
	('2013-10-16', '2013-10-01'),
	('2013-10-17', '2013-10-01'),
	('2013-10-18', '2013-10-01'),
	('2013-10-19', '2013-10-01'),
	('2013-10-20', '2013-10-01'),
	('2013-10-21', '2013-10-01'),
	('2013-10-22', '2013-10-01'),
	('2013-10-23', '2013-10-01'),
	('2013-10-24', '2013-10-01'),
	('2013-10-25', '2013-10-01'),
	('2013-10-26', '2013-10-01'),
	('2013-10-27', '2013-10-01'),
	('2013-10-28', '2013-10-01'),
	('2013-10-29', '2013-10-01'),
	('2013-10-30', '2013-10-01'),
	('2013-10-31', '2013-10-01'),
	('2013-11-01', '2013-11-01'),
	('2013-11-02', '2013-11-01'),
	('2013-11-03', '2013-11-01'),
	('2013-11-04', '2013-11-01'),
	('2013-11-05', '2013-11-01'),
	('2013-11-06', '2013-11-01'),
	('2013-11-07', '2013-11-01'),
	('2013-11-08', '2013-11-01'),
	('2013-11-09', '2013-11-01'),
	('2013-11-10', '2013-11-01'),
	('2013-11-11', '2013-11-01'),
	('2013-11-12', '2013-11-01'),
	('2013-11-13', '2013-11-01'),
	('2013-11-14', '2013-11-01'),
	('2013-11-15', '2013-11-01'),
	('2013-11-16', '2013-11-01'),
	('2013-11-17', '2013-11-01'),
	('2013-11-18', '2013-11-01'),
	('2013-11-19', '2013-11-01'),
	('2013-11-20', '2013-11-01'),
	('2013-11-21', '2013-11-01'),
	('2013-11-22', '2013-11-01'),
	('2013-11-23', '2013-11-01'),
	('2013-11-24', '2013-11-01'),
	('2013-11-25', '2013-11-01'),
	('2013-11-26', '2013-11-01'),
	('2013-11-27', '2013-11-01'),
	('2013-11-28', '2013-11-01'),
	('2013-11-29', '2013-11-01'),
	('2013-11-30', '2013-11-01'),
	('2013-12-01', '2013-12-01'),
	('2013-12-02', '2013-12-01'),
	('2013-12-03', '2013-12-01'),
	('2013-12-04', '2013-12-01'),
	('2013-12-05', '2013-12-01'),
	('2013-12-06', '2013-12-01'),
	('2013-12-07', '2013-12-01'),
	('2013-12-08', '2013-12-01'),
	('2013-12-09', '2013-12-01'),
	('2013-12-10', '2013-12-01'),
	('2013-12-11', '2013-12-01'),
	('2013-12-12', '2013-12-01'),
	('2013-12-13', '2013-12-01'),
	('2013-12-14', '2013-12-01'),
	('2013-12-15', '2013-12-01'),
	('2013-12-16', '2013-12-01'),
	('2013-12-17', '2013-12-01'),
	('2013-12-18', '2013-12-01'),
	('2013-12-19', '2013-12-01'),
	('2013-12-20', '2013-12-01'),
	('2013-12-21', '2013-12-01'),
	('2013-12-22', '2013-12-01'),
	('2013-12-23', '2013-12-01'),
	('2013-12-24', '2013-12-01'),
	('2013-12-25', '2013-12-01'),
	('2013-12-26', '2013-12-01'),
	('2013-12-27', '2013-12-01'),
	('2013-12-28', '2013-12-01'),
	('2013-12-29', '2013-12-01'),
	('2013-12-30', '2013-12-01'),
	('2013-12-31', '2013-12-01'),
	('2014-01-01', '2014-01-01'),
	('2014-01-02', '2014-01-01'),
	('2014-01-03', '2014-01-01'),
	('2014-01-04', '2014-01-01'),
	('2014-01-05', '2014-01-01'),
	('2014-01-06', '2014-01-01'),
	('2014-01-07', '2014-01-01'),
	('2014-01-08', '2014-01-01'),
	('2014-01-09', '2014-01-01'),
	('2014-01-10', '2014-01-01'),
	('2014-01-11', '2014-01-01'),
	('2014-01-12', '2014-01-01'),
	('2014-01-13', '2014-01-01'),
	('2014-01-14', '2014-01-01'),
	('2014-01-15', '2014-01-01'),
	('2014-01-16', '2014-01-01'),
	('2014-01-17', '2014-01-01'),
	('2014-01-18', '2014-01-01'),
	('2014-01-19', '2014-01-01'),
	('2014-01-20', '2014-01-01'),
	('2014-01-21', '2014-01-01'),
	('2014-01-22', '2014-01-01'),
	('2014-01-23', '2014-01-01'),
	('2014-01-24', '2014-01-01'),
	('2014-01-25', '2014-01-01'),
	('2014-01-26', '2014-01-01'),
	('2014-01-27', '2014-01-01'),
	('2014-01-28', '2014-01-01'),
	('2014-01-29', '2014-01-01'),
	('2014-01-30', '2014-01-01'),
	('2014-01-31', '2014-01-01'),
	('2014-02-01', '2014-02-01'),
	('2014-02-02', '2014-02-01'),
	('2014-02-03', '2014-02-01'),
	('2014-02-04', '2014-02-01'),
	('2014-02-05', '2014-02-01'),
	('2014-02-06', '2014-02-01'),
	('2014-02-07', '2014-02-01'),
	('2014-02-08', '2014-02-01'),
	('2014-02-09', '2014-02-01'),
	('2014-02-10', '2014-02-01'),
	('2014-02-11', '2014-02-01'),
	('2014-02-12', '2014-02-01'),
	('2014-02-13', '2014-02-01'),
	('2014-02-14', '2014-02-01'),
	('2014-02-15', '2014-02-01'),
	('2014-02-16', '2014-02-01'),
	('2014-02-17', '2014-02-01'),
	('2014-02-18', '2014-02-01'),
	('2014-02-19', '2014-02-01'),
	('2014-02-20', '2014-02-01'),
	('2014-02-21', '2014-02-01'),
	('2014-02-22', '2014-02-01'),
	('2014-02-23', '2014-02-01'),
	('2014-02-24', '2014-02-01'),
	('2014-02-25', '2014-02-01'),
	('2014-02-26', '2014-02-01'),
	('2014-02-27', '2014-02-01'),
	('2014-02-28', '2014-02-01'),
	('2014-03-01', '2014-03-01'),
	('2014-03-02', '2014-03-01'),
	('2014-03-03', '2014-03-01'),
	('2014-03-04', '2014-03-01'),
	('2014-03-05', '2014-03-01'),
	('2014-03-06', '2014-03-01'),
	('2014-03-07', '2014-03-01'),
	('2014-03-08', '2014-03-01'),
	('2014-03-09', '2014-03-01'),
	('2014-03-10', '2014-03-01'),
	('2014-03-11', '2014-03-01'),
	('2014-03-12', '2014-03-01'),
	('2014-03-13', '2014-03-01'),
	('2014-03-14', '2014-03-01'),
	('2014-03-15', '2014-03-01'),
	('2014-03-16', '2014-03-01'),
	('2014-03-17', '2014-03-01'),
	('2014-03-18', '2014-03-01'),
	('2014-03-19', '2014-03-01'),
	('2014-03-20', '2014-03-01'),
	('2014-03-21', '2014-03-01'),
	('2014-03-22', '2014-03-01'),
	('2014-03-23', '2014-03-01'),
	('2014-03-24', '2014-03-01'),
	('2014-03-25', '2014-03-01'),
	('2014-03-26', '2014-03-01'),
	('2014-03-27', '2014-03-01'),
	('2014-03-28', '2014-03-01'),
	('2014-03-29', '2014-03-01'),
	('2014-03-30', '2014-03-01'),
	('2014-03-31', '2014-03-01'),
	('2014-04-01', '2014-04-01'),
	('2014-04-02', '2014-04-01'),
	('2014-04-03', '2014-04-01'),
	('2014-04-04', '2014-04-01'),
	('2014-04-05', '2014-04-01'),
	('2014-04-06', '2014-04-01'),
	('2014-04-07', '2014-04-01'),
	('2014-04-08', '2014-04-01'),
	('2014-04-09', '2014-04-01'),
	('2014-04-10', '2014-04-01'),
	('2014-04-11', '2014-04-01'),
	('2014-04-12', '2014-04-01'),
	('2014-04-13', '2014-04-01'),
	('2014-04-14', '2014-04-01'),
	('2014-04-15', '2014-04-01'),
	('2014-04-16', '2014-04-01'),
	('2014-04-17', '2014-04-01'),
	('2014-04-18', '2014-04-01'),
	('2014-04-19', '2014-04-01'),
	('2014-04-20', '2014-04-01'),
	('2014-04-21', '2014-04-01'),
	('2014-04-22', '2014-04-01'),
	('2014-04-23', '2014-04-01'),
	('2014-04-24', '2014-04-01'),
	('2014-04-25', '2014-04-01'),
	('2014-04-26', '2014-04-01'),
	('2014-04-27', '2014-04-01'),
	('2014-04-28', '2014-04-01'),
	('2014-04-29', '2014-04-01'),
	('2014-04-30', '2014-04-01'),
	('2014-05-01', '2014-05-01'),
	('2014-05-02', '2014-05-01'),
	('2014-05-03', '2014-05-01'),
	('2014-05-04', '2014-05-01'),
	('2014-05-05', '2014-05-01'),
	('2014-05-06', '2014-05-01'),
	('2014-05-07', '2014-05-01'),
	('2014-05-08', '2014-05-01'),
	('2014-05-09', '2014-05-01'),
	('2014-05-10', '2014-05-01'),
	('2014-05-11', '2014-05-01'),
	('2014-05-12', '2014-05-01'),
	('2014-05-13', '2014-05-01'),
	('2014-05-14', '2014-05-01'),
	('2014-05-15', '2014-05-01'),
	('2014-05-16', '2014-05-01'),
	('2014-05-17', '2014-05-01'),
	('2014-05-18', '2014-05-01'),
	('2014-05-19', '2014-05-01'),
	('2014-05-20', '2014-05-01'),
	('2014-05-21', '2014-05-01'),
	('2014-05-22', '2014-05-01'),
	('2014-05-23', '2014-05-01'),
	('2014-05-24', '2014-05-01'),
	('2014-05-25', '2014-05-01'),
	('2014-05-26', '2014-05-01'),
	('2014-05-27', '2014-05-01'),
	('2014-05-28', '2014-05-01'),
	('2014-05-29', '2014-05-01'),
	('2014-05-30', '2014-05-01'),
	('2014-05-31', '2014-05-01'),
	('2014-06-01', '2014-06-01'),
	('2014-06-02', '2014-06-01'),
	('2014-06-03', '2014-06-01'),
	('2014-06-04', '2014-06-01'),
	('2014-06-05', '2014-06-01'),
	('2014-06-06', '2014-06-01'),
	('2014-06-07', '2014-06-01'),
	('2014-06-08', '2014-06-01'),
	('2014-06-09', '2014-06-01'),
	('2014-06-10', '2014-06-01'),
	('2014-06-11', '2014-06-01'),
	('2014-06-12', '2014-06-01'),
	('2014-06-13', '2014-06-01'),
	('2014-06-14', '2014-06-01'),
	('2014-06-15', '2014-06-01'),
	('2014-06-16', '2014-06-01'),
	('2014-06-17', '2014-06-01'),
	('2014-06-18', '2014-06-01'),
	('2014-06-19', '2014-06-01'),
	('2014-06-20', '2014-06-01'),
	('2014-06-21', '2014-06-01'),
	('2014-06-22', '2014-06-01'),
	('2014-06-23', '2014-06-01'),
	('2014-06-24', '2014-06-01'),
	('2014-06-25', '2014-06-01'),
	('2014-06-26', '2014-06-01'),
	('2014-06-27', '2014-06-01'),
	('2014-06-28', '2014-06-01'),
	('2014-06-29', '2014-06-01'),
	('2014-06-30', '2014-06-01'),
	('2014-07-01', '2014-07-01'),
	('2014-07-02', '2014-07-01'),
	('2014-07-03', '2014-07-01'),
	('2014-07-04', '2014-07-01'),
	('2014-07-05', '2014-07-01'),
	('2014-07-06', '2014-07-01'),
	('2014-07-07', '2014-07-01'),
	('2014-07-08', '2014-07-01'),
	('2014-07-09', '2014-07-01'),
	('2014-07-10', '2014-07-01'),
	('2014-07-11', '2014-07-01'),
	('2014-07-12', '2014-07-01'),
	('2014-07-13', '2014-07-01'),
	('2014-07-14', '2014-07-01'),
	('2014-07-15', '2014-07-01'),
	('2014-07-16', '2014-07-01'),
	('2014-07-17', '2014-07-01'),
	('2014-07-18', '2014-07-01'),
	('2014-07-19', '2014-07-01'),
	('2014-07-20', '2014-07-01'),
	('2014-07-21', '2014-07-01'),
	('2014-07-22', '2014-07-01'),
	('2014-07-23', '2014-07-01'),
	('2014-07-24', '2014-07-01'),
	('2014-07-25', '2014-07-01'),
	('2014-07-26', '2014-07-01'),
	('2014-07-27', '2014-07-01'),
	('2014-07-28', '2014-07-01'),
	('2014-07-29', '2014-07-01'),
	('2014-07-30', '2014-07-01'),
	('2014-07-31', '2014-07-01'),
	('2014-08-01', '2014-08-01'),
	('2014-08-02', '2014-08-01'),
	('2014-08-03', '2014-08-01'),
	('2014-08-04', '2014-08-01'),
	('2014-08-05', '2014-08-01'),
	('2014-08-06', '2014-08-01'),
	('2014-08-07', '2014-08-01'),
	('2014-08-08', '2014-08-01'),
	('2014-08-09', '2014-08-01'),
	('2014-08-10', '2014-08-01'),
	('2014-08-11', '2014-08-01'),
	('2014-08-12', '2014-08-01'),
	('2014-08-13', '2014-08-01'),
	('2014-08-14', '2014-08-01'),
	('2014-08-15', '2014-08-01'),
	('2014-08-16', '2014-08-01'),
	('2014-08-17', '2014-08-01'),
	('2014-08-18', '2014-08-01'),
	('2014-08-19', '2014-08-01'),
	('2014-08-20', '2014-08-01'),
	('2014-08-21', '2014-08-01'),
	('2014-08-22', '2014-08-01'),
	('2014-08-23', '2014-08-01'),
	('2014-08-24', '2014-08-01'),
	('2014-08-25', '2014-08-01'),
	('2014-08-26', '2014-08-01'),
	('2014-08-27', '2014-08-01'),
	('2014-08-28', '2014-08-01'),
	('2014-08-29', '2014-08-01'),
	('2014-08-30', '2014-08-01'),
	('2014-08-31', '2014-08-01'),
	('2014-09-01', '2014-09-01'),
	('2014-09-02', '2014-09-01'),
	('2014-09-03', '2014-09-01'),
	('2014-09-04', '2014-09-01'),
	('2014-09-05', '2014-09-01'),
	('2014-09-06', '2014-09-01'),
	('2014-09-07', '2014-09-01'),
	('2014-09-08', '2014-09-01'),
	('2014-09-09', '2014-09-01'),
	('2014-09-10', '2014-09-01'),
	('2014-09-11', '2014-09-01'),
	('2014-09-12', '2014-09-01'),
	('2014-09-13', '2014-09-01'),
	('2014-09-14', '2014-09-01'),
	('2014-09-15', '2014-09-01'),
	('2014-09-16', '2014-09-01'),
	('2014-09-17', '2014-09-01'),
	('2014-09-18', '2014-09-01'),
	('2014-09-19', '2014-09-01'),
	('2014-09-20', '2014-09-01'),
	('2014-09-21', '2014-09-01'),
	('2014-09-22', '2014-09-01'),
	('2014-09-23', '2014-09-01'),
	('2014-09-24', '2014-09-01'),
	('2014-09-25', '2014-09-01'),
	('2014-09-26', '2014-09-01'),
	('2014-09-27', '2014-09-01'),
	('2014-09-28', '2014-09-01'),
	('2014-09-29', '2014-09-01'),
	('2014-09-30', '2014-09-01'),
	('2014-10-01', '2014-10-01'),
	('2014-10-02', '2014-10-01'),
	('2014-10-03', '2014-10-01'),
	('2014-10-04', '2014-10-01'),
	('2014-10-05', '2014-10-01'),
	('2014-10-06', '2014-10-01'),
	('2014-10-07', '2014-10-01'),
	('2014-10-08', '2014-10-01'),
	('2014-10-09', '2014-10-01'),
	('2014-10-10', '2014-10-01'),
	('2014-10-11', '2014-10-01'),
	('2014-10-12', '2014-10-01'),
	('2014-10-13', '2014-10-01'),
	('2014-10-14', '2014-10-01'),
	('2014-10-15', '2014-10-01'),
	('2014-10-16', '2014-10-01'),
	('2014-10-17', '2014-10-01'),
	('2014-10-18', '2014-10-01'),
	('2014-10-19', '2014-10-01'),
	('2014-10-20', '2014-10-01'),
	('2014-10-21', '2014-10-01'),
	('2014-10-22', '2014-10-01'),
	('2014-10-23', '2014-10-01'),
	('2014-10-24', '2014-10-01'),
	('2014-10-25', '2014-10-01'),
	('2014-10-26', '2014-10-01'),
	('2014-10-27', '2014-10-01'),
	('2014-10-28', '2014-10-01'),
	('2014-10-29', '2014-10-01'),
	('2014-10-30', '2014-10-01'),
	('2014-10-31', '2014-10-01'),
	('2014-11-01', '2014-11-01'),
	('2014-11-02', '2014-11-01'),
	('2014-11-03', '2014-11-01'),
	('2014-11-04', '2014-11-01'),
	('2014-11-05', '2014-11-01'),
	('2014-11-06', '2014-11-01'),
	('2014-11-07', '2014-11-01'),
	('2014-11-08', '2014-11-01'),
	('2014-11-09', '2014-11-01'),
	('2014-11-10', '2014-11-01'),
	('2014-11-11', '2014-11-01'),
	('2014-11-12', '2014-11-01'),
	('2014-11-13', '2014-11-01'),
	('2014-11-14', '2014-11-01'),
	('2014-11-15', '2014-11-01'),
	('2014-11-16', '2014-11-01'),
	('2014-11-17', '2014-11-01'),
	('2014-11-18', '2014-11-01'),
	('2014-11-19', '2014-11-01'),
	('2014-11-20', '2014-11-01'),
	('2014-11-21', '2014-11-01'),
	('2014-11-22', '2014-11-01'),
	('2014-11-23', '2014-11-01'),
	('2014-11-24', '2014-11-01'),
	('2014-11-25', '2014-11-01'),
	('2014-11-26', '2014-11-01'),
	('2014-11-27', '2014-11-01'),
	('2014-11-28', '2014-11-01'),
	('2014-11-29', '2014-11-01'),
	('2014-11-30', '2014-11-01'),
	('2014-12-01', '2014-12-01'),
	('2014-12-02', '2014-12-01'),
	('2014-12-03', '2014-12-01'),
	('2014-12-04', '2014-12-01'),
	('2014-12-05', '2014-12-01'),
	('2014-12-06', '2014-12-01'),
	('2014-12-07', '2014-12-01'),
	('2014-12-08', '2014-12-01'),
	('2014-12-09', '2014-12-01'),
	('2014-12-10', '2014-12-01'),
	('2014-12-11', '2014-12-01'),
	('2014-12-12', '2014-12-01'),
	('2014-12-13', '2014-12-01'),
	('2014-12-14', '2014-12-01'),
	('2014-12-15', '2014-12-01'),
	('2014-12-16', '2014-12-01'),
	('2014-12-17', '2014-12-01'),
	('2014-12-18', '2014-12-01'),
	('2014-12-19', '2014-12-01'),
	('2014-12-20', '2014-12-01'),
	('2014-12-21', '2014-12-01'),
	('2014-12-22', '2014-12-01'),
	('2014-12-23', '2014-12-01'),
	('2014-12-24', '2014-12-01'),
	('2014-12-25', '2014-12-01'),
	('2014-12-26', '2014-12-01'),
	('2014-12-27', '2014-12-01'),
	('2014-12-28', '2014-12-01'),
	('2014-12-29', '2014-12-01'),
	('2014-12-30', '2014-12-01'),
	('2014-12-31', '2014-12-01'),
	('2015-01-01', '2015-01-01'),
	('2015-01-02', '2015-01-01'),
	('2015-01-03', '2015-01-01'),
	('2015-01-04', '2015-01-01'),
	('2015-01-05', '2015-01-01'),
	('2015-01-06', '2015-01-01'),
	('2015-01-07', '2015-01-01'),
	('2015-01-08', '2015-01-01'),
	('2015-01-09', '2015-01-01'),
	('2015-01-10', '2015-01-01'),
	('2015-01-11', '2015-01-01'),
	('2015-01-12', '2015-01-01'),
	('2015-01-13', '2015-01-01'),
	('2015-01-14', '2015-01-01'),
	('2015-01-15', '2015-01-01'),
	('2015-01-16', '2015-01-01'),
	('2015-01-17', '2015-01-01'),
	('2015-01-18', '2015-01-01'),
	('2015-01-19', '2015-01-01'),
	('2015-01-20', '2015-01-01'),
	('2015-01-21', '2015-01-01'),
	('2015-01-22', '2015-01-01'),
	('2015-01-23', '2015-01-01'),
	('2015-01-24', '2015-01-01'),
	('2015-01-25', '2015-01-01'),
	('2015-01-26', '2015-01-01'),
	('2015-01-27', '2015-01-01'),
	('2015-01-28', '2015-01-01'),
	('2015-01-29', '2015-01-01'),
	('2015-01-30', '2015-01-01'),
	('2015-01-31', '2015-01-01'),
	('2015-02-01', '2015-02-01'),
	('2015-02-02', '2015-02-01'),
	('2015-02-03', '2015-02-01'),
	('2015-02-04', '2015-02-01'),
	('2015-02-05', '2015-02-01'),
	('2015-02-06', '2015-02-01'),
	('2015-02-07', '2015-02-01'),
	('2015-02-08', '2015-02-01'),
	('2015-02-09', '2015-02-01'),
	('2015-02-10', '2015-02-01'),
	('2015-02-11', '2015-02-01'),
	('2015-02-12', '2015-02-01'),
	('2015-02-13', '2015-02-01'),
	('2015-02-14', '2015-02-01'),
	('2015-02-15', '2015-02-01'),
	('2015-02-16', '2015-02-01'),
	('2015-02-17', '2015-02-01'),
	('2015-02-18', '2015-02-01'),
	('2015-02-19', '2015-02-01'),
	('2015-02-20', '2015-02-01'),
	('2015-02-21', '2015-02-01'),
	('2015-02-22', '2015-02-01'),
	('2015-02-23', '2015-02-01'),
	('2015-02-24', '2015-02-01'),
	('2015-02-25', '2015-02-01'),
	('2015-02-26', '2015-02-01'),
	('2015-02-27', '2015-02-01'),
	('2015-02-28', '2015-02-01'),
	('2015-03-01', '2015-03-01'),
	('2015-03-02', '2015-03-01'),
	('2015-03-03', '2015-03-01'),
	('2015-03-04', '2015-03-01'),
	('2015-03-05', '2015-03-01'),
	('2015-03-06', '2015-03-01'),
	('2015-03-07', '2015-03-01'),
	('2015-03-08', '2015-03-01'),
	('2015-03-09', '2015-03-01'),
	('2015-03-10', '2015-03-01'),
	('2015-03-11', '2015-03-01'),
	('2015-03-12', '2015-03-01'),
	('2015-03-13', '2015-03-01'),
	('2015-03-14', '2015-03-01'),
	('2015-03-15', '2015-03-01'),
	('2015-03-16', '2015-03-01'),
	('2015-03-17', '2015-03-01'),
	('2015-03-18', '2015-03-01'),
	('2015-03-19', '2015-03-01'),
	('2015-03-20', '2015-03-01'),
	('2015-03-21', '2015-03-01'),
	('2015-03-22', '2015-03-01'),
	('2015-03-23', '2015-03-01'),
	('2015-03-24', '2015-03-01'),
	('2015-03-25', '2015-03-01'),
	('2015-03-26', '2015-03-01'),
	('2015-03-27', '2015-03-01'),
	('2015-03-28', '2015-03-01'),
	('2015-03-29', '2015-03-01'),
	('2015-03-30', '2015-03-01'),
	('2015-03-31', '2015-03-01'),
	('2015-04-01', '2015-04-01'),
	('2015-04-02', '2015-04-01'),
	('2015-04-03', '2015-04-01'),
	('2015-04-04', '2015-04-01'),
	('2015-04-05', '2015-04-01'),
	('2015-04-06', '2015-04-01'),
	('2015-04-07', '2015-04-01'),
	('2015-04-08', '2015-04-01'),
	('2015-04-09', '2015-04-01'),
	('2015-04-10', '2015-04-01'),
	('2015-04-11', '2015-04-01'),
	('2015-04-12', '2015-04-01'),
	('2015-04-13', '2015-04-01'),
	('2015-04-14', '2015-04-01'),
	('2015-04-15', '2015-04-01'),
	('2015-04-16', '2015-04-01'),
	('2015-04-17', '2015-04-01'),
	('2015-04-18', '2015-04-01'),
	('2015-04-19', '2015-04-01'),
	('2015-04-20', '2015-04-01'),
	('2015-04-21', '2015-04-01'),
	('2015-04-22', '2015-04-01'),
	('2015-04-23', '2015-04-01'),
	('2015-04-24', '2015-04-01'),
	('2015-04-25', '2015-04-01'),
	('2015-04-26', '2015-04-01'),
	('2015-04-27', '2015-04-01'),
	('2015-04-28', '2015-04-01'),
	('2015-04-29', '2015-04-01'),
	('2015-04-30', '2015-04-01'),
	('2015-05-01', '2015-05-01'),
	('2015-05-02', '2015-05-01'),
	('2015-05-03', '2015-05-01'),
	('2015-05-04', '2015-05-01'),
	('2015-05-05', '2015-05-01'),
	('2015-05-06', '2015-05-01'),
	('2015-05-07', '2015-05-01'),
	('2015-05-08', '2015-05-01'),
	('2015-05-09', '2015-05-01'),
	('2015-05-10', '2015-05-01'),
	('2015-05-11', '2015-05-01'),
	('2015-05-12', '2015-05-01'),
	('2015-05-13', '2015-05-01'),
	('2015-05-14', '2015-05-01'),
	('2015-05-15', '2015-05-01'),
	('2015-05-16', '2015-05-01'),
	('2015-05-17', '2015-05-01'),
	('2015-05-18', '2015-05-01'),
	('2015-05-19', '2015-05-01'),
	('2015-05-20', '2015-05-01'),
	('2015-05-21', '2015-05-01'),
	('2015-05-22', '2015-05-01'),
	('2015-05-23', '2015-05-01'),
	('2015-05-24', '2015-05-01'),
	('2015-05-25', '2015-05-01'),
	('2015-05-26', '2015-05-01'),
	('2015-05-27', '2015-05-01'),
	('2015-05-28', '2015-05-01'),
	('2015-05-29', '2015-05-01'),
	('2015-05-30', '2015-05-01'),
	('2015-05-31', '2015-05-01'),
	('2015-06-01', '2015-06-01'),
	('2015-06-02', '2015-06-01'),
	('2015-06-03', '2015-06-01'),
	('2015-06-04', '2015-06-01'),
	('2015-06-05', '2015-06-01'),
	('2015-06-06', '2015-06-01'),
	('2015-06-07', '2015-06-01'),
	('2015-06-08', '2015-06-01'),
	('2015-06-09', '2015-06-01'),
	('2015-06-10', '2015-06-01'),
	('2015-06-11', '2015-06-01'),
	('2015-06-12', '2015-06-01'),
	('2015-06-13', '2015-06-01'),
	('2015-06-14', '2015-06-01'),
	('2015-06-15', '2015-06-01'),
	('2015-06-16', '2015-06-01'),
	('2015-06-17', '2015-06-01'),
	('2015-06-18', '2015-06-01'),
	('2015-06-19', '2015-06-01'),
	('2015-06-20', '2015-06-01'),
	('2015-06-21', '2015-06-01'),
	('2015-06-22', '2015-06-01'),
	('2015-06-23', '2015-06-01'),
	('2015-06-24', '2015-06-01'),
	('2015-06-25', '2015-06-01'),
	('2015-06-26', '2015-06-01'),
	('2015-06-27', '2015-06-01'),
	('2015-06-28', '2015-06-01'),
	('2015-06-29', '2015-06-01'),
	('2015-06-30', '2015-06-01'),
	('2015-07-01', '2015-07-01'),
	('2015-07-02', '2015-07-01'),
	('2015-07-03', '2015-07-01'),
	('2015-07-04', '2015-07-01'),
	('2015-07-05', '2015-07-01'),
	('2015-07-06', '2015-07-01'),
	('2015-07-07', '2015-07-01'),
	('2015-07-08', '2015-07-01'),
	('2015-07-09', '2015-07-01'),
	('2015-07-10', '2015-07-01'),
	('2015-07-11', '2015-07-01'),
	('2015-07-12', '2015-07-01'),
	('2015-07-13', '2015-07-01'),
	('2015-07-14', '2015-07-01'),
	('2015-07-15', '2015-07-01'),
	('2015-07-16', '2015-07-01'),
	('2015-07-17', '2015-07-01'),
	('2015-07-18', '2015-07-01'),
	('2015-07-19', '2015-07-01'),
	('2015-07-20', '2015-07-01'),
	('2015-07-21', '2015-07-01'),
	('2015-07-22', '2015-07-01'),
	('2015-07-23', '2015-07-01'),
	('2015-07-24', '2015-07-01'),
	('2015-07-25', '2015-07-01'),
	('2015-07-26', '2015-07-01'),
	('2015-07-27', '2015-07-01'),
	('2015-07-28', '2015-07-01'),
	('2015-07-29', '2015-07-01'),
	('2015-07-30', '2015-07-01'),
	('2015-07-31', '2015-07-01'),
	('2015-08-01', '2015-08-01'),
	('2015-08-02', '2015-08-01'),
	('2015-08-03', '2015-08-01'),
	('2015-08-04', '2015-08-01'),
	('2015-08-05', '2015-08-01'),
	('2015-08-06', '2015-08-01'),
	('2015-08-07', '2015-08-01'),
	('2015-08-08', '2015-08-01'),
	('2015-08-09', '2015-08-01'),
	('2015-08-10', '2015-08-01'),
	('2015-08-11', '2015-08-01'),
	('2015-08-12', '2015-08-01'),
	('2015-08-13', '2015-08-01'),
	('2015-08-14', '2015-08-01'),
	('2015-08-15', '2015-08-01'),
	('2015-08-16', '2015-08-01'),
	('2015-08-17', '2015-08-01'),
	('2015-08-18', '2015-08-01'),
	('2015-08-19', '2015-08-01'),
	('2015-08-20', '2015-08-01'),
	('2015-08-21', '2015-08-01'),
	('2015-08-22', '2015-08-01'),
	('2015-08-23', '2015-08-01'),
	('2015-08-24', '2015-08-01'),
	('2015-08-25', '2015-08-01'),
	('2015-08-26', '2015-08-01'),
	('2015-08-27', '2015-08-01'),
	('2015-08-28', '2015-08-01'),
	('2015-08-29', '2015-08-01'),
	('2015-08-30', '2015-08-01'),
	('2015-08-31', '2015-08-01'),
	('2015-09-01', '2015-09-01'),
	('2015-09-02', '2015-09-01'),
	('2015-09-03', '2015-09-01'),
	('2015-09-04', '2015-09-01'),
	('2015-09-05', '2015-09-01'),
	('2015-09-06', '2015-09-01'),
	('2015-09-07', '2015-09-01'),
	('2015-09-08', '2015-09-01'),
	('2015-09-09', '2015-09-01'),
	('2015-09-10', '2015-09-01'),
	('2015-09-11', '2015-09-01'),
	('2015-09-12', '2015-09-01'),
	('2015-09-13', '2015-09-01'),
	('2015-09-14', '2015-09-01'),
	('2015-09-15', '2015-09-01'),
	('2015-09-16', '2015-09-01'),
	('2015-09-17', '2015-09-01'),
	('2015-09-18', '2015-09-01'),
	('2015-09-19', '2015-09-01'),
	('2015-09-20', '2015-09-01'),
	('2015-09-21', '2015-09-01'),
	('2015-09-22', '2015-09-01'),
	('2015-09-23', '2015-09-01'),
	('2015-09-24', '2015-09-01'),
	('2015-09-25', '2015-09-01'),
	('2015-09-26', '2015-09-01'),
	('2015-09-27', '2015-09-01'),
	('2015-09-28', '2015-09-01'),
	('2015-09-29', '2015-09-01'),
	('2015-09-30', '2015-09-01'),
	('2015-10-01', '2015-10-01'),
	('2015-10-02', '2015-10-01'),
	('2015-10-03', '2015-10-01'),
	('2015-10-04', '2015-10-01'),
	('2015-10-05', '2015-10-01'),
	('2015-10-06', '2015-10-01'),
	('2015-10-07', '2015-10-01'),
	('2015-10-08', '2015-10-01'),
	('2015-10-09', '2015-10-01'),
	('2015-10-10', '2015-10-01'),
	('2015-10-11', '2015-10-01'),
	('2015-10-12', '2015-10-01'),
	('2015-10-13', '2015-10-01'),
	('2015-10-14', '2015-10-01'),
	('2015-10-15', '2015-10-01'),
	('2015-10-16', '2015-10-01'),
	('2015-10-17', '2015-10-01'),
	('2015-10-18', '2015-10-01'),
	('2015-10-19', '2015-10-01'),
	('2015-10-20', '2015-10-01'),
	('2015-10-21', '2015-10-01'),
	('2015-10-22', '2015-10-01'),
	('2015-10-23', '2015-10-01'),
	('2015-10-24', '2015-10-01'),
	('2015-10-25', '2015-10-01'),
	('2015-10-26', '2015-10-01'),
	('2015-10-27', '2015-10-01'),
	('2015-10-28', '2015-10-01'),
	('2015-10-29', '2015-10-01'),
	('2015-10-30', '2015-10-01'),
	('2015-10-31', '2015-10-01'),
	('2015-11-01', '2015-11-01'),
	('2015-11-02', '2015-11-01'),
	('2015-11-03', '2015-11-01'),
	('2015-11-04', '2015-11-01'),
	('2015-11-05', '2015-11-01'),
	('2015-11-06', '2015-11-01'),
	('2015-11-07', '2015-11-01'),
	('2015-11-08', '2015-11-01'),
	('2015-11-09', '2015-11-01'),
	('2015-11-10', '2015-11-01'),
	('2015-11-11', '2015-11-01'),
	('2015-11-12', '2015-11-01'),
	('2015-11-13', '2015-11-01'),
	('2015-11-14', '2015-11-01'),
	('2015-11-15', '2015-11-01'),
	('2015-11-16', '2015-11-01'),
	('2015-11-17', '2015-11-01'),
	('2015-11-18', '2015-11-01'),
	('2015-11-19', '2015-11-01'),
	('2015-11-20', '2015-11-01'),
	('2015-11-21', '2015-11-01'),
	('2015-11-22', '2015-11-01'),
	('2015-11-23', '2015-11-01'),
	('2015-11-24', '2015-11-01'),
	('2015-11-25', '2015-11-01'),
	('2015-11-26', '2015-11-01'),
	('2015-11-27', '2015-11-01'),
	('2015-11-28', '2015-11-01'),
	('2015-11-29', '2015-11-01'),
	('2015-11-30', '2015-11-01'),
	('2015-12-01', '2015-12-01'),
	('2015-12-02', '2015-12-01'),
	('2015-12-03', '2015-12-01'),
	('2015-12-04', '2015-12-01'),
	('2015-12-05', '2015-12-01'),
	('2015-12-06', '2015-12-01'),
	('2015-12-07', '2015-12-01'),
	('2015-12-08', '2015-12-01'),
	('2015-12-09', '2015-12-01'),
	('2015-12-10', '2015-12-01'),
	('2015-12-11', '2015-12-01'),
	('2015-12-12', '2015-12-01'),
	('2015-12-13', '2015-12-01'),
	('2015-12-14', '2015-12-01'),
	('2015-12-15', '2015-12-01'),
	('2015-12-16', '2015-12-01'),
	('2015-12-17', '2015-12-01'),
	('2015-12-18', '2015-12-01'),
	('2015-12-19', '2015-12-01'),
	('2015-12-20', '2015-12-01'),
	('2015-12-21', '2015-12-01'),
	('2015-12-22', '2015-12-01'),
	('2015-12-23', '2015-12-01'),
	('2015-12-24', '2015-12-01'),
	('2015-12-25', '2015-12-01'),
	('2015-12-26', '2015-12-01'),
	('2015-12-27', '2015-12-01'),
	('2015-12-28', '2015-12-01'),
	('2015-12-29', '2015-12-01'),
	('2015-12-30', '2015-12-01'),
	('2015-12-31', '2015-12-01'),
	('2016-01-01', '2016-01-01'),
	('2016-01-02', '2016-01-01'),
	('2016-01-03', '2016-01-01'),
	('2016-01-04', '2016-01-01'),
	('2016-01-05', '2016-01-01'),
	('2016-01-06', '2016-01-01'),
	('2016-01-07', '2016-01-01'),
	('2016-01-08', '2016-01-01'),
	('2016-01-09', '2016-01-01'),
	('2016-01-10', '2016-01-01'),
	('2016-01-11', '2016-01-01'),
	('2016-01-12', '2016-01-01'),
	('2016-01-13', '2016-01-01'),
	('2016-01-14', '2016-01-01'),
	('2016-01-15', '2016-01-01'),
	('2016-01-16', '2016-01-01'),
	('2016-01-17', '2016-01-01'),
	('2016-01-18', '2016-01-01'),
	('2016-01-19', '2016-01-01'),
	('2016-01-20', '2016-01-01'),
	('2016-01-21', '2016-01-01'),
	('2016-01-22', '2016-01-01'),
	('2016-01-23', '2016-01-01'),
	('2016-01-24', '2016-01-01'),
	('2016-01-25', '2016-01-01'),
	('2016-01-26', '2016-01-01'),
	('2016-01-27', '2016-01-01'),
	('2016-01-28', '2016-01-01'),
	('2016-01-29', '2016-01-01'),
	('2016-01-30', '2016-01-01'),
	('2016-01-31', '2016-01-01'),
	('2016-02-01', '2016-02-01'),
	('2016-02-02', '2016-02-01'),
	('2016-02-03', '2016-02-01'),
	('2016-02-04', '2016-02-01'),
	('2016-02-05', '2016-02-01'),
	('2016-02-06', '2016-02-01'),
	('2016-02-07', '2016-02-01'),
	('2016-02-08', '2016-02-01'),
	('2016-02-09', '2016-02-01'),
	('2016-02-10', '2016-02-01'),
	('2016-02-11', '2016-02-01'),
	('2016-02-12', '2016-02-01'),
	('2016-02-13', '2016-02-01'),
	('2016-02-14', '2016-02-01'),
	('2016-02-15', '2016-02-01'),
	('2016-02-16', '2016-02-01'),
	('2016-02-17', '2016-02-01'),
	('2016-02-18', '2016-02-01'),
	('2016-02-19', '2016-02-01'),
	('2016-02-20', '2016-02-01'),
	('2016-02-21', '2016-02-01'),
	('2016-02-22', '2016-02-01'),
	('2016-02-23', '2016-02-01'),
	('2016-02-24', '2016-02-01'),
	('2016-02-25', '2016-02-01'),
	('2016-02-26', '2016-02-01'),
	('2016-02-27', '2016-02-01'),
	('2016-02-28', '2016-02-01'),
	('2016-02-29', '2016-02-01'),
	('2016-03-01', '2016-03-01'),
	('2016-03-02', '2016-03-01'),
	('2016-03-03', '2016-03-01'),
	('2016-03-04', '2016-03-01'),
	('2016-03-05', '2016-03-01'),
	('2016-03-06', '2016-03-01'),
	('2016-03-07', '2016-03-01'),
	('2016-03-08', '2016-03-01'),
	('2016-03-09', '2016-03-01'),
	('2016-03-10', '2016-03-01'),
	('2016-03-11', '2016-03-01'),
	('2016-03-12', '2016-03-01'),
	('2016-03-13', '2016-03-01'),
	('2016-03-14', '2016-03-01'),
	('2016-03-15', '2016-03-01'),
	('2016-03-16', '2016-03-01'),
	('2016-03-17', '2016-03-01'),
	('2016-03-18', '2016-03-01'),
	('2016-03-19', '2016-03-01'),
	('2016-03-20', '2016-03-01'),
	('2016-03-21', '2016-03-01'),
	('2016-03-22', '2016-03-01'),
	('2016-03-23', '2016-03-01'),
	('2016-03-24', '2016-03-01'),
	('2016-03-25', '2016-03-01'),
	('2016-03-26', '2016-03-01'),
	('2016-03-27', '2016-03-01'),
	('2016-03-28', '2016-03-01'),
	('2016-03-29', '2016-03-01'),
	('2016-03-30', '2016-03-01'),
	('2016-03-31', '2016-03-01'),
	('2016-04-01', '2016-04-01'),
	('2016-04-02', '2016-04-01'),
	('2016-04-03', '2016-04-01'),
	('2016-04-04', '2016-04-01'),
	('2016-04-05', '2016-04-01'),
	('2016-04-06', '2016-04-01'),
	('2016-04-07', '2016-04-01'),
	('2016-04-08', '2016-04-01'),
	('2016-04-09', '2016-04-01'),
	('2016-04-10', '2016-04-01'),
	('2016-04-11', '2016-04-01'),
	('2016-04-12', '2016-04-01'),
	('2016-04-13', '2016-04-01'),
	('2016-04-14', '2016-04-01'),
	('2016-04-15', '2016-04-01'),
	('2016-04-16', '2016-04-01'),
	('2016-04-17', '2016-04-01'),
	('2016-04-18', '2016-04-01'),
	('2016-04-19', '2016-04-01'),
	('2016-04-20', '2016-04-01'),
	('2016-04-21', '2016-04-01'),
	('2016-04-22', '2016-04-01'),
	('2016-04-23', '2016-04-01'),
	('2016-04-24', '2016-04-01'),
	('2016-04-25', '2016-04-01'),
	('2016-04-26', '2016-04-01'),
	('2016-04-27', '2016-04-01'),
	('2016-04-28', '2016-04-01'),
	('2016-04-29', '2016-04-01'),
	('2016-04-30', '2016-04-01'),
	('2016-05-01', '2016-05-01'),
	('2016-05-02', '2016-05-01'),
	('2016-05-03', '2016-05-01'),
	('2016-05-04', '2016-05-01'),
	('2016-05-05', '2016-05-01'),
	('2016-05-06', '2016-05-01'),
	('2016-05-07', '2016-05-01'),
	('2016-05-08', '2016-05-01'),
	('2016-05-09', '2016-05-01'),
	('2016-05-10', '2016-05-01'),
	('2016-05-11', '2016-05-01'),
	('2016-05-12', '2016-05-01'),
	('2016-05-13', '2016-05-01'),
	('2016-05-14', '2016-05-01'),
	('2016-05-15', '2016-05-01'),
	('2016-05-16', '2016-05-01'),
	('2016-05-17', '2016-05-01'),
	('2016-05-18', '2016-05-01'),
	('2016-05-19', '2016-05-01'),
	('2016-05-20', '2016-05-01'),
	('2016-05-21', '2016-05-01'),
	('2016-05-22', '2016-05-01'),
	('2016-05-23', '2016-05-01'),
	('2016-05-24', '2016-05-01'),
	('2016-05-25', '2016-05-01'),
	('2016-05-26', '2016-05-01'),
	('2016-05-27', '2016-05-01'),
	('2016-05-28', '2016-05-01'),
	('2016-05-29', '2016-05-01'),
	('2016-05-30', '2016-05-01'),
	('2016-05-31', '2016-05-01'),
	('2016-06-01', '2016-06-01'),
	('2016-06-02', '2016-06-01'),
	('2016-06-03', '2016-06-01'),
	('2016-06-04', '2016-06-01'),
	('2016-06-05', '2016-06-01'),
	('2016-06-06', '2016-06-01'),
	('2016-06-07', '2016-06-01'),
	('2016-06-08', '2016-06-01'),
	('2016-06-09', '2016-06-01'),
	('2016-06-10', '2016-06-01'),
	('2016-06-11', '2016-06-01'),
	('2016-06-12', '2016-06-01'),
	('2016-06-13', '2016-06-01'),
	('2016-06-14', '2016-06-01'),
	('2016-06-15', '2016-06-01'),
	('2016-06-16', '2016-06-01'),
	('2016-06-17', '2016-06-01'),
	('2016-06-18', '2016-06-01'),
	('2016-06-19', '2016-06-01'),
	('2016-06-20', '2016-06-01'),
	('2016-06-21', '2016-06-01'),
	('2016-06-22', '2016-06-01'),
	('2016-06-23', '2016-06-01'),
	('2016-06-24', '2016-06-01'),
	('2016-06-25', '2016-06-01'),
	('2016-06-26', '2016-06-01'),
	('2016-06-27', '2016-06-01'),
	('2016-06-28', '2016-06-01'),
	('2016-06-29', '2016-06-01'),
	('2016-06-30', '2016-06-01'),
	('2016-07-01', '2016-07-01'),
	('2016-07-02', '2016-07-01'),
	('2016-07-03', '2016-07-01'),
	('2016-07-04', '2016-07-01'),
	('2016-07-05', '2016-07-01'),
	('2016-07-06', '2016-07-01'),
	('2016-07-07', '2016-07-01'),
	('2016-07-08', '2016-07-01'),
	('2016-07-09', '2016-07-01'),
	('2016-07-10', '2016-07-01'),
	('2016-07-11', '2016-07-01'),
	('2016-07-12', '2016-07-01'),
	('2016-07-13', '2016-07-01'),
	('2016-07-14', '2016-07-01'),
	('2016-07-15', '2016-07-01'),
	('2016-07-16', '2016-07-01'),
	('2016-07-17', '2016-07-01'),
	('2016-07-18', '2016-07-01'),
	('2016-07-19', '2016-07-01'),
	('2016-07-20', '2016-07-01'),
	('2016-07-21', '2016-07-01'),
	('2016-07-22', '2016-07-01'),
	('2016-07-23', '2016-07-01'),
	('2016-07-24', '2016-07-01'),
	('2016-07-25', '2016-07-01'),
	('2016-07-26', '2016-07-01'),
	('2016-07-27', '2016-07-01'),
	('2016-07-28', '2016-07-01'),
	('2016-07-29', '2016-07-01'),
	('2016-07-30', '2016-07-01'),
	('2016-07-31', '2016-07-01'),
	('2016-08-01', '2016-08-01'),
	('2016-08-02', '2016-08-01'),
	('2016-08-03', '2016-08-01'),
	('2016-08-04', '2016-08-01'),
	('2016-08-05', '2016-08-01'),
	('2016-08-06', '2016-08-01'),
	('2016-08-07', '2016-08-01'),
	('2016-08-08', '2016-08-01'),
	('2016-08-09', '2016-08-01'),
	('2016-08-10', '2016-08-01'),
	('2016-08-11', '2016-08-01'),
	('2016-08-12', '2016-08-01'),
	('2016-08-13', '2016-08-01'),
	('2016-08-14', '2016-08-01'),
	('2016-08-15', '2016-08-01'),
	('2016-08-16', '2016-08-01'),
	('2016-08-17', '2016-08-01'),
	('2016-08-18', '2016-08-01'),
	('2016-08-19', '2016-08-01'),
	('2016-08-20', '2016-08-01'),
	('2016-08-21', '2016-08-01'),
	('2016-08-22', '2016-08-01'),
	('2016-08-23', '2016-08-01'),
	('2016-08-24', '2016-08-01'),
	('2016-08-25', '2016-08-01'),
	('2016-08-26', '2016-08-01'),
	('2016-08-27', '2016-08-01'),
	('2016-08-28', '2016-08-01'),
	('2016-08-29', '2016-08-01'),
	('2016-08-30', '2016-08-01'),
	('2016-08-31', '2016-08-01'),
	('2016-09-01', '2016-09-01'),
	('2016-09-02', '2016-09-01'),
	('2016-09-03', '2016-09-01'),
	('2016-09-04', '2016-09-01'),
	('2016-09-05', '2016-09-01'),
	('2016-09-06', '2016-09-01'),
	('2016-09-07', '2016-09-01'),
	('2016-09-08', '2016-09-01'),
	('2016-09-09', '2016-09-01'),
	('2016-09-10', '2016-09-01'),
	('2016-09-11', '2016-09-01'),
	('2016-09-12', '2016-09-01'),
	('2016-09-13', '2016-09-01'),
	('2016-09-14', '2016-09-01'),
	('2016-09-15', '2016-09-01'),
	('2016-09-16', '2016-09-01'),
	('2016-09-17', '2016-09-01'),
	('2016-09-18', '2016-09-01'),
	('2016-09-19', '2016-09-01'),
	('2016-09-20', '2016-09-01'),
	('2016-09-21', '2016-09-01'),
	('2016-09-22', '2016-09-01'),
	('2016-09-23', '2016-09-01'),
	('2016-09-24', '2016-09-01'),
	('2016-09-25', '2016-09-01'),
	('2016-09-26', '2016-09-01'),
	('2016-09-27', '2016-09-01'),
	('2016-09-28', '2016-09-01'),
	('2016-09-29', '2016-09-01'),
	('2016-09-30', '2016-09-01'),
	('2016-10-01', '2016-10-01'),
	('2016-10-02', '2016-10-01'),
	('2016-10-03', '2016-10-01'),
	('2016-10-04', '2016-10-01'),
	('2016-10-05', '2016-10-01'),
	('2016-10-06', '2016-10-01'),
	('2016-10-07', '2016-10-01'),
	('2016-10-08', '2016-10-01'),
	('2016-10-09', '2016-10-01'),
	('2016-10-10', '2016-10-01'),
	('2016-10-11', '2016-10-01'),
	('2016-10-12', '2016-10-01'),
	('2016-10-13', '2016-10-01'),
	('2016-10-14', '2016-10-01'),
	('2016-10-15', '2016-10-01'),
	('2016-10-16', '2016-10-01'),
	('2016-10-17', '2016-10-01'),
	('2016-10-18', '2016-10-01'),
	('2016-10-19', '2016-10-01'),
	('2016-10-20', '2016-10-01'),
	('2016-10-21', '2016-10-01'),
	('2016-10-22', '2016-10-01'),
	('2016-10-23', '2016-10-01'),
	('2016-10-24', '2016-10-01'),
	('2016-10-25', '2016-10-01'),
	('2016-10-26', '2016-10-01'),
	('2016-10-27', '2016-10-01'),
	('2016-10-28', '2016-10-01'),
	('2016-10-29', '2016-10-01'),
	('2016-10-30', '2016-10-01'),
	('2016-10-31', '2016-10-01'),
	('2016-11-01', '2016-11-01'),
	('2016-11-02', '2016-11-01'),
	('2016-11-03', '2016-11-01'),
	('2016-11-04', '2016-11-01'),
	('2016-11-05', '2016-11-01'),
	('2016-11-06', '2016-11-01'),
	('2016-11-07', '2016-11-01'),
	('2016-11-08', '2016-11-01'),
	('2016-11-09', '2016-11-01'),
	('2016-11-10', '2016-11-01'),
	('2016-11-11', '2016-11-01'),
	('2016-11-12', '2016-11-01'),
	('2016-11-13', '2016-11-01'),
	('2016-11-14', '2016-11-01'),
	('2016-11-15', '2016-11-01'),
	('2016-11-16', '2016-11-01'),
	('2016-11-17', '2016-11-01'),
	('2016-11-18', '2016-11-01'),
	('2016-11-19', '2016-11-01'),
	('2016-11-20', '2016-11-01'),
	('2016-11-21', '2016-11-01'),
	('2016-11-22', '2016-11-01'),
	('2016-11-23', '2016-11-01'),
	('2016-11-24', '2016-11-01'),
	('2016-11-25', '2016-11-01'),
	('2016-11-26', '2016-11-01'),
	('2016-11-27', '2016-11-01'),
	('2016-11-28', '2016-11-01'),
	('2016-11-29', '2016-11-01'),
	('2016-11-30', '2016-11-01'),
	('2016-12-01', '2016-12-01'),
	('2016-12-02', '2016-12-01'),
	('2016-12-03', '2016-12-01'),
	('2016-12-04', '2016-12-01'),
	('2016-12-05', '2016-12-01'),
	('2016-12-06', '2016-12-01'),
	('2016-12-07', '2016-12-01'),
	('2016-12-08', '2016-12-01'),
	('2016-12-09', '2016-12-01'),
	('2016-12-10', '2016-12-01'),
	('2016-12-11', '2016-12-01'),
	('2016-12-12', '2016-12-01'),
	('2016-12-13', '2016-12-01'),
	('2016-12-14', '2016-12-01'),
	('2016-12-15', '2016-12-01'),
	('2016-12-16', '2016-12-01'),
	('2016-12-17', '2016-12-01'),
	('2016-12-18', '2016-12-01'),
	('2016-12-19', '2016-12-01'),
	('2016-12-20', '2016-12-01'),
	('2016-12-21', '2016-12-01'),
	('2016-12-22', '2016-12-01'),
	('2016-12-23', '2016-12-01'),
	('2016-12-24', '2016-12-01'),
	('2016-12-25', '2016-12-01'),
	('2016-12-26', '2016-12-01'),
	('2016-12-27', '2016-12-01'),
	('2016-12-28', '2016-12-01'),
	('2016-12-29', '2016-12-01'),
	('2016-12-30', '2016-12-01'),
	('2016-12-31', '2016-12-01'),
	('2017-01-01', '2017-01-01'),
	('2017-01-02', '2017-01-01'),
	('2017-01-03', '2017-01-01'),
	('2017-01-04', '2017-01-01'),
	('2017-01-05', '2017-01-01'),
	('2017-01-06', '2017-01-01'),
	('2017-01-07', '2017-01-01'),
	('2017-01-08', '2017-01-01'),
	('2017-01-09', '2017-01-01'),
	('2017-01-10', '2017-01-01'),
	('2017-01-11', '2017-01-01'),
	('2017-01-12', '2017-01-01'),
	('2017-01-13', '2017-01-01'),
	('2017-01-14', '2017-01-01'),
	('2017-01-15', '2017-01-01'),
	('2017-01-16', '2017-01-01'),
	('2017-01-17', '2017-01-01'),
	('2017-01-18', '2017-01-01'),
	('2017-01-19', '2017-01-01'),
	('2017-01-20', '2017-01-01'),
	('2017-01-21', '2017-01-01'),
	('2017-01-22', '2017-01-01'),
	('2017-01-23', '2017-01-01'),
	('2017-01-24', '2017-01-01'),
	('2017-01-25', '2017-01-01'),
	('2017-01-26', '2017-01-01'),
	('2017-01-27', '2017-01-01'),
	('2017-01-28', '2017-01-01'),
	('2017-01-29', '2017-01-01'),
	('2017-01-30', '2017-01-01'),
	('2017-01-31', '2017-01-01'),
	('2017-02-01', '2017-02-01'),
	('2017-02-02', '2017-02-01'),
	('2017-02-03', '2017-02-01'),
	('2017-02-04', '2017-02-01'),
	('2017-02-05', '2017-02-01'),
	('2017-02-06', '2017-02-01'),
	('2017-02-07', '2017-02-01'),
	('2017-02-08', '2017-02-01'),
	('2017-02-09', '2017-02-01'),
	('2017-02-10', '2017-02-01'),
	('2017-02-11', '2017-02-01'),
	('2017-02-12', '2017-02-01'),
	('2017-02-13', '2017-02-01'),
	('2017-02-14', '2017-02-01'),
	('2017-02-15', '2017-02-01'),
	('2017-02-16', '2017-02-01'),
	('2017-02-17', '2017-02-01'),
	('2017-02-18', '2017-02-01'),
	('2017-02-19', '2017-02-01'),
	('2017-02-20', '2017-02-01'),
	('2017-02-21', '2017-02-01'),
	('2017-02-22', '2017-02-01'),
	('2017-02-23', '2017-02-01'),
	('2017-02-24', '2017-02-01'),
	('2017-02-25', '2017-02-01'),
	('2017-02-26', '2017-02-01'),
	('2017-02-27', '2017-02-01'),
	('2017-02-28', '2017-02-01'),
	('2017-03-01', '2017-03-01'),
	('2017-03-02', '2017-03-01'),
	('2017-03-03', '2017-03-01'),
	('2017-03-04', '2017-03-01'),
	('2017-03-05', '2017-03-01'),
	('2017-03-06', '2017-03-01'),
	('2017-03-07', '2017-03-01'),
	('2017-03-08', '2017-03-01'),
	('2017-03-09', '2017-03-01'),
	('2017-03-10', '2017-03-01'),
	('2017-03-11', '2017-03-01'),
	('2017-03-12', '2017-03-01'),
	('2017-03-13', '2017-03-01'),
	('2017-03-14', '2017-03-01'),
	('2017-03-15', '2017-03-01'),
	('2017-03-16', '2017-03-01'),
	('2017-03-17', '2017-03-01'),
	('2017-03-18', '2017-03-01'),
	('2017-03-19', '2017-03-01'),
	('2017-03-20', '2017-03-01'),
	('2017-03-21', '2017-03-01'),
	('2017-03-22', '2017-03-01'),
	('2017-03-23', '2017-03-01'),
	('2017-03-24', '2017-03-01'),
	('2017-03-25', '2017-03-01'),
	('2017-03-26', '2017-03-01'),
	('2017-03-27', '2017-03-01'),
	('2017-03-28', '2017-03-01'),
	('2017-03-29', '2017-03-01'),
	('2017-03-30', '2017-03-01'),
	('2017-03-31', '2017-03-01'),
	('2017-04-01', '2017-04-01'),
	('2017-04-02', '2017-04-01'),
	('2017-04-03', '2017-04-01'),
	('2017-04-04', '2017-04-01'),
	('2017-04-05', '2017-04-01'),
	('2017-04-06', '2017-04-01'),
	('2017-04-07', '2017-04-01'),
	('2017-04-08', '2017-04-01'),
	('2017-04-09', '2017-04-01'),
	('2017-04-10', '2017-04-01'),
	('2017-04-11', '2017-04-01'),
	('2017-04-12', '2017-04-01'),
	('2017-04-13', '2017-04-01'),
	('2017-04-14', '2017-04-01'),
	('2017-04-15', '2017-04-01'),
	('2017-04-16', '2017-04-01'),
	('2017-04-17', '2017-04-01'),
	('2017-04-18', '2017-04-01'),
	('2017-04-19', '2017-04-01'),
	('2017-04-20', '2017-04-01'),
	('2017-04-21', '2017-04-01'),
	('2017-04-22', '2017-04-01'),
	('2017-04-23', '2017-04-01'),
	('2017-04-24', '2017-04-01'),
	('2017-04-25', '2017-04-01'),
	('2017-04-26', '2017-04-01'),
	('2017-04-27', '2017-04-01'),
	('2017-04-28', '2017-04-01'),
	('2017-04-29', '2017-04-01'),
	('2017-04-30', '2017-04-01'),
	('2017-05-01', '2017-05-01'),
	('2017-05-02', '2017-05-01'),
	('2017-05-03', '2017-05-01'),
	('2017-05-04', '2017-05-01'),
	('2017-05-05', '2017-05-01'),
	('2017-05-06', '2017-05-01'),
	('2017-05-07', '2017-05-01'),
	('2017-05-08', '2017-05-01'),
	('2017-05-09', '2017-05-01'),
	('2017-05-10', '2017-05-01'),
	('2017-05-11', '2017-05-01'),
	('2017-05-12', '2017-05-01'),
	('2017-05-13', '2017-05-01'),
	('2017-05-14', '2017-05-01'),
	('2017-05-15', '2017-05-01'),
	('2017-05-16', '2017-05-01'),
	('2017-05-17', '2017-05-01'),
	('2017-05-18', '2017-05-01'),
	('2017-05-19', '2017-05-01'),
	('2017-05-20', '2017-05-01'),
	('2017-05-21', '2017-05-01'),
	('2017-05-22', '2017-05-01'),
	('2017-05-23', '2017-05-01'),
	('2017-05-24', '2017-05-01'),
	('2017-05-25', '2017-05-01'),
	('2017-05-26', '2017-05-01'),
	('2017-05-27', '2017-05-01'),
	('2017-05-28', '2017-05-01'),
	('2017-05-29', '2017-05-01'),
	('2017-05-30', '2017-05-01'),
	('2017-05-31', '2017-05-01'),
	('2017-06-01', '2017-06-01'),
	('2017-06-02', '2017-06-01'),
	('2017-06-03', '2017-06-01'),
	('2017-06-04', '2017-06-01'),
	('2017-06-05', '2017-06-01'),
	('2017-06-06', '2017-06-01'),
	('2017-06-07', '2017-06-01'),
	('2017-06-08', '2017-06-01'),
	('2017-06-09', '2017-06-01'),
	('2017-06-10', '2017-06-01'),
	('2017-06-11', '2017-06-01'),
	('2017-06-12', '2017-06-01'),
	('2017-06-13', '2017-06-01'),
	('2017-06-14', '2017-06-01'),
	('2017-06-15', '2017-06-01'),
	('2017-06-16', '2017-06-01'),
	('2017-06-17', '2017-06-01'),
	('2017-06-18', '2017-06-01'),
	('2017-06-19', '2017-06-01'),
	('2017-06-20', '2017-06-01'),
	('2017-06-21', '2017-06-01'),
	('2017-06-22', '2017-06-01'),
	('2017-06-23', '2017-06-01'),
	('2017-06-24', '2017-06-01'),
	('2017-06-25', '2017-06-01'),
	('2017-06-26', '2017-06-01'),
	('2017-06-27', '2017-06-01'),
	('2017-06-28', '2017-06-01'),
	('2017-06-29', '2017-06-01'),
	('2017-06-30', '2017-06-01'),
	('2017-07-01', '2017-07-01'),
	('2017-07-02', '2017-07-01'),
	('2017-07-03', '2017-07-01'),
	('2017-07-04', '2017-07-01'),
	('2017-07-05', '2017-07-01'),
	('2017-07-06', '2017-07-01'),
	('2017-07-07', '2017-07-01'),
	('2017-07-08', '2017-07-01'),
	('2017-07-09', '2017-07-01'),
	('2017-07-10', '2017-07-01'),
	('2017-07-11', '2017-07-01'),
	('2017-07-12', '2017-07-01'),
	('2017-07-13', '2017-07-01'),
	('2017-07-14', '2017-07-01'),
	('2017-07-15', '2017-07-01'),
	('2017-07-16', '2017-07-01'),
	('2017-07-17', '2017-07-01'),
	('2017-07-18', '2017-07-01'),
	('2017-07-19', '2017-07-01'),
	('2017-07-20', '2017-07-01'),
	('2017-07-21', '2017-07-01'),
	('2017-07-22', '2017-07-01'),
	('2017-07-23', '2017-07-01'),
	('2017-07-24', '2017-07-01'),
	('2017-07-25', '2017-07-01'),
	('2017-07-26', '2017-07-01'),
	('2017-07-27', '2017-07-01'),
	('2017-07-28', '2017-07-01'),
	('2017-07-29', '2017-07-01'),
	('2017-07-30', '2017-07-01'),
	('2017-07-31', '2017-07-01'),
	('2017-08-01', '2017-08-01'),
	('2017-08-02', '2017-08-01'),
	('2017-08-03', '2017-08-01'),
	('2017-08-04', '2017-08-01'),
	('2017-08-05', '2017-08-01'),
	('2017-08-06', '2017-08-01'),
	('2017-08-07', '2017-08-01'),
	('2017-08-08', '2017-08-01'),
	('2017-08-09', '2017-08-01'),
	('2017-08-10', '2017-08-01'),
	('2017-08-11', '2017-08-01'),
	('2017-08-12', '2017-08-01'),
	('2017-08-13', '2017-08-01'),
	('2017-08-14', '2017-08-01'),
	('2017-08-15', '2017-08-01'),
	('2017-08-16', '2017-08-01'),
	('2017-08-17', '2017-08-01'),
	('2017-08-18', '2017-08-01'),
	('2017-08-19', '2017-08-01'),
	('2017-08-20', '2017-08-01'),
	('2017-08-21', '2017-08-01'),
	('2017-08-22', '2017-08-01'),
	('2017-08-23', '2017-08-01'),
	('2017-08-24', '2017-08-01'),
	('2017-08-25', '2017-08-01'),
	('2017-08-26', '2017-08-01'),
	('2017-08-27', '2017-08-01'),
	('2017-08-28', '2017-08-01'),
	('2017-08-29', '2017-08-01'),
	('2017-08-30', '2017-08-01'),
	('2017-08-31', '2017-08-01'),
	('2017-09-01', '2017-09-01'),
	('2017-09-02', '2017-09-01'),
	('2017-09-03', '2017-09-01'),
	('2017-09-04', '2017-09-01'),
	('2017-09-05', '2017-09-01'),
	('2017-09-06', '2017-09-01'),
	('2017-09-07', '2017-09-01'),
	('2017-09-08', '2017-09-01'),
	('2017-09-09', '2017-09-01'),
	('2017-09-10', '2017-09-01'),
	('2017-09-11', '2017-09-01'),
	('2017-09-12', '2017-09-01'),
	('2017-09-13', '2017-09-01'),
	('2017-09-14', '2017-09-01'),
	('2017-09-15', '2017-09-01'),
	('2017-09-16', '2017-09-01'),
	('2017-09-17', '2017-09-01'),
	('2017-09-18', '2017-09-01'),
	('2017-09-19', '2017-09-01'),
	('2017-09-20', '2017-09-01'),
	('2017-09-21', '2017-09-01'),
	('2017-09-22', '2017-09-01'),
	('2017-09-23', '2017-09-01'),
	('2017-09-24', '2017-09-01'),
	('2017-09-25', '2017-09-01'),
	('2017-09-26', '2017-09-01'),
	('2017-09-27', '2017-09-01'),
	('2017-09-28', '2017-09-01'),
	('2017-09-29', '2017-09-01'),
	('2017-09-30', '2017-09-01'),
	('2017-10-01', '2017-10-01'),
	('2017-10-02', '2017-10-01'),
	('2017-10-03', '2017-10-01'),
	('2017-10-04', '2017-10-01'),
	('2017-10-05', '2017-10-01'),
	('2017-10-06', '2017-10-01'),
	('2017-10-07', '2017-10-01'),
	('2017-10-08', '2017-10-01'),
	('2017-10-09', '2017-10-01'),
	('2017-10-10', '2017-10-01'),
	('2017-10-11', '2017-10-01'),
	('2017-10-12', '2017-10-01'),
	('2017-10-13', '2017-10-01'),
	('2017-10-14', '2017-10-01'),
	('2017-10-15', '2017-10-01'),
	('2017-10-16', '2017-10-01'),
	('2017-10-17', '2017-10-01'),
	('2017-10-18', '2017-10-01'),
	('2017-10-19', '2017-10-01'),
	('2017-10-20', '2017-10-01'),
	('2017-10-21', '2017-10-01'),
	('2017-10-22', '2017-10-01'),
	('2017-10-23', '2017-10-01'),
	('2017-10-24', '2017-10-01'),
	('2017-10-25', '2017-10-01'),
	('2017-10-26', '2017-10-01'),
	('2017-10-27', '2017-10-01'),
	('2017-10-28', '2017-10-01'),
	('2017-10-29', '2017-10-01'),
	('2017-10-30', '2017-10-01'),
	('2017-10-31', '2017-10-01'),
	('2017-11-01', '2017-11-01'),
	('2017-11-02', '2017-11-01'),
	('2017-11-03', '2017-11-01'),
	('2017-11-04', '2017-11-01'),
	('2017-11-05', '2017-11-01'),
	('2017-11-06', '2017-11-01'),
	('2017-11-07', '2017-11-01'),
	('2017-11-08', '2017-11-01'),
	('2017-11-09', '2017-11-01'),
	('2017-11-10', '2017-11-01'),
	('2017-11-11', '2017-11-01'),
	('2017-11-12', '2017-11-01'),
	('2017-11-13', '2017-11-01'),
	('2017-11-14', '2017-11-01'),
	('2017-11-15', '2017-11-01'),
	('2017-11-16', '2017-11-01'),
	('2017-11-17', '2017-11-01'),
	('2017-11-18', '2017-11-01'),
	('2017-11-19', '2017-11-01'),
	('2017-11-20', '2017-11-01'),
	('2017-11-21', '2017-11-01'),
	('2017-11-22', '2017-11-01'),
	('2017-11-23', '2017-11-01'),
	('2017-11-24', '2017-11-01'),
	('2017-11-25', '2017-11-01'),
	('2017-11-26', '2017-11-01'),
	('2017-11-27', '2017-11-01'),
	('2017-11-28', '2017-11-01'),
	('2017-11-29', '2017-11-01'),
	('2017-11-30', '2017-11-01'),
	('2017-12-01', '2017-12-01'),
	('2017-12-02', '2017-12-01'),
	('2017-12-03', '2017-12-01'),
	('2017-12-04', '2017-12-01'),
	('2017-12-05', '2017-12-01'),
	('2017-12-06', '2017-12-01'),
	('2017-12-07', '2017-12-01'),
	('2017-12-08', '2017-12-01'),
	('2017-12-09', '2017-12-01'),
	('2017-12-10', '2017-12-01'),
	('2017-12-11', '2017-12-01'),
	('2017-12-12', '2017-12-01'),
	('2017-12-13', '2017-12-01'),
	('2017-12-14', '2017-12-01'),
	('2017-12-15', '2017-12-01'),
	('2017-12-16', '2017-12-01'),
	('2017-12-17', '2017-12-01'),
	('2017-12-18', '2017-12-01'),
	('2017-12-19', '2017-12-01'),
	('2017-12-20', '2017-12-01'),
	('2017-12-21', '2017-12-01'),
	('2017-12-22', '2017-12-01'),
	('2017-12-23', '2017-12-01'),
	('2017-12-24', '2017-12-01'),
	('2017-12-25', '2017-12-01'),
	('2017-12-26', '2017-12-01'),
	('2017-12-27', '2017-12-01'),
	('2017-12-28', '2017-12-01'),
	('2017-12-29', '2017-12-01'),
	('2017-12-30', '2017-12-01'),
	('2017-12-31', '2017-12-01'),
	('2018-01-01', '2018-01-01'),
	('2018-01-02', '2018-01-01'),
	('2018-01-03', '2018-01-01'),
	('2018-01-04', '2018-01-01'),
	('2018-01-05', '2018-01-01'),
	('2018-01-06', '2018-01-01'),
	('2018-01-07', '2018-01-01'),
	('2018-01-08', '2018-01-01'),
	('2018-01-09', '2018-01-01'),
	('2018-01-10', '2018-01-01'),
	('2018-01-11', '2018-01-01'),
	('2018-01-12', '2018-01-01'),
	('2018-01-13', '2018-01-01'),
	('2018-01-14', '2018-01-01'),
	('2018-01-15', '2018-01-01'),
	('2018-01-16', '2018-01-01'),
	('2018-01-17', '2018-01-01'),
	('2018-01-18', '2018-01-01'),
	('2018-01-19', '2018-01-01'),
	('2018-01-20', '2018-01-01'),
	('2018-01-21', '2018-01-01'),
	('2018-01-22', '2018-01-01'),
	('2018-01-23', '2018-01-01'),
	('2018-01-24', '2018-01-01'),
	('2018-01-25', '2018-01-01'),
	('2018-01-26', '2018-01-01'),
	('2018-01-27', '2018-01-01'),
	('2018-01-28', '2018-01-01'),
	('2018-01-29', '2018-01-01'),
	('2018-01-30', '2018-01-01'),
	('2018-01-31', '2018-01-01'),
	('2018-02-01', '2018-02-01'),
	('2018-02-02', '2018-02-01'),
	('2018-02-03', '2018-02-01'),
	('2018-02-04', '2018-02-01'),
	('2018-02-05', '2018-02-01'),
	('2018-02-06', '2018-02-01'),
	('2018-02-07', '2018-02-01'),
	('2018-02-08', '2018-02-01'),
	('2018-02-09', '2018-02-01'),
	('2018-02-10', '2018-02-01'),
	('2018-02-11', '2018-02-01'),
	('2018-02-12', '2018-02-01'),
	('2018-02-13', '2018-02-01'),
	('2018-02-14', '2018-02-01'),
	('2018-02-15', '2018-02-01'),
	('2018-02-16', '2018-02-01'),
	('2018-02-17', '2018-02-01'),
	('2018-02-18', '2018-02-01'),
	('2018-02-19', '2018-02-01'),
	('2018-02-20', '2018-02-01'),
	('2018-02-21', '2018-02-01'),
	('2018-02-22', '2018-02-01'),
	('2018-02-23', '2018-02-01'),
	('2018-02-24', '2018-02-01'),
	('2018-02-25', '2018-02-01'),
	('2018-02-26', '2018-02-01'),
	('2018-02-27', '2018-02-01'),
	('2018-02-28', '2018-02-01'),
	('2018-03-01', '2018-03-01'),
	('2018-03-02', '2018-03-01'),
	('2018-03-03', '2018-03-01'),
	('2018-03-04', '2018-03-01'),
	('2018-03-05', '2018-03-01'),
	('2018-03-06', '2018-03-01'),
	('2018-03-07', '2018-03-01'),
	('2018-03-08', '2018-03-01'),
	('2018-03-09', '2018-03-01'),
	('2018-03-10', '2018-03-01'),
	('2018-03-11', '2018-03-01'),
	('2018-03-12', '2018-03-01'),
	('2018-03-13', '2018-03-01'),
	('2018-03-14', '2018-03-01'),
	('2018-03-15', '2018-03-01'),
	('2018-03-16', '2018-03-01'),
	('2018-03-17', '2018-03-01'),
	('2018-03-18', '2018-03-01'),
	('2018-03-19', '2018-03-01'),
	('2018-03-20', '2018-03-01'),
	('2018-03-21', '2018-03-01'),
	('2018-03-22', '2018-03-01'),
	('2018-03-23', '2018-03-01'),
	('2018-03-24', '2018-03-01'),
	('2018-03-25', '2018-03-01'),
	('2018-03-26', '2018-03-01'),
	('2018-03-27', '2018-03-01'),
	('2018-03-28', '2018-03-01'),
	('2018-03-29', '2018-03-01'),
	('2018-03-30', '2018-03-01'),
	('2018-03-31', '2018-03-01'),
	('2018-04-01', '2018-04-01'),
	('2018-04-02', '2018-04-01'),
	('2018-04-03', '2018-04-01'),
	('2018-04-04', '2018-04-01'),
	('2018-04-05', '2018-04-01'),
	('2018-04-06', '2018-04-01'),
	('2018-04-07', '2018-04-01'),
	('2018-04-08', '2018-04-01'),
	('2018-04-09', '2018-04-01'),
	('2018-04-10', '2018-04-01'),
	('2018-04-11', '2018-04-01'),
	('2018-04-12', '2018-04-01'),
	('2018-04-13', '2018-04-01'),
	('2018-04-14', '2018-04-01'),
	('2018-04-15', '2018-04-01'),
	('2018-04-16', '2018-04-01'),
	('2018-04-17', '2018-04-01'),
	('2018-04-18', '2018-04-01'),
	('2018-04-19', '2018-04-01'),
	('2018-04-20', '2018-04-01'),
	('2018-04-21', '2018-04-01'),
	('2018-04-22', '2018-04-01'),
	('2018-04-23', '2018-04-01'),
	('2018-04-24', '2018-04-01'),
	('2018-04-25', '2018-04-01'),
	('2018-04-26', '2018-04-01'),
	('2018-04-27', '2018-04-01'),
	('2018-04-28', '2018-04-01'),
	('2018-04-29', '2018-04-01'),
	('2018-04-30', '2018-04-01'),
	('2018-05-01', '2018-05-01'),
	('2018-05-02', '2018-05-01'),
	('2018-05-03', '2018-05-01'),
	('2018-05-04', '2018-05-01'),
	('2018-05-05', '2018-05-01'),
	('2018-05-06', '2018-05-01'),
	('2018-05-07', '2018-05-01'),
	('2018-05-08', '2018-05-01'),
	('2018-05-09', '2018-05-01'),
	('2018-05-10', '2018-05-01'),
	('2018-05-11', '2018-05-01'),
	('2018-05-12', '2018-05-01'),
	('2018-05-13', '2018-05-01'),
	('2018-05-14', '2018-05-01'),
	('2018-05-15', '2018-05-01'),
	('2018-05-16', '2018-05-01'),
	('2018-05-17', '2018-05-01'),
	('2018-05-18', '2018-05-01'),
	('2018-05-19', '2018-05-01'),
	('2018-05-20', '2018-05-01'),
	('2018-05-21', '2018-05-01'),
	('2018-05-22', '2018-05-01'),
	('2018-05-23', '2018-05-01'),
	('2018-05-24', '2018-05-01'),
	('2018-05-25', '2018-05-01'),
	('2018-05-26', '2018-05-01'),
	('2018-05-27', '2018-05-01'),
	('2018-05-28', '2018-05-01'),
	('2018-05-29', '2018-05-01'),
	('2018-05-30', '2018-05-01'),
	('2018-05-31', '2018-05-01'),
	('2018-06-01', '2018-06-01'),
	('2018-06-02', '2018-06-01'),
	('2018-06-03', '2018-06-01'),
	('2018-06-04', '2018-06-01'),
	('2018-06-05', '2018-06-01'),
	('2018-06-06', '2018-06-01'),
	('2018-06-07', '2018-06-01'),
	('2018-06-08', '2018-06-01'),
	('2018-06-09', '2018-06-01'),
	('2018-06-10', '2018-06-01'),
	('2018-06-11', '2018-06-01'),
	('2018-06-12', '2018-06-01'),
	('2018-06-13', '2018-06-01'),
	('2018-06-14', '2018-06-01'),
	('2018-06-15', '2018-06-01'),
	('2018-06-16', '2018-06-01'),
	('2018-06-17', '2018-06-01'),
	('2018-06-18', '2018-06-01'),
	('2018-06-19', '2018-06-01'),
	('2018-06-20', '2018-06-01'),
	('2018-06-21', '2018-06-01'),
	('2018-06-22', '2018-06-01'),
	('2018-06-23', '2018-06-01'),
	('2018-06-24', '2018-06-01'),
	('2018-06-25', '2018-06-01'),
	('2018-06-26', '2018-06-01'),
	('2018-06-27', '2018-06-01'),
	('2018-06-28', '2018-06-01'),
	('2018-06-29', '2018-06-01'),
	('2018-06-30', '2018-06-01'),
	('2018-07-01', '2018-07-01'),
	('2018-07-02', '2018-07-01'),
	('2018-07-03', '2018-07-01'),
	('2018-07-04', '2018-07-01'),
	('2018-07-05', '2018-07-01'),
	('2018-07-06', '2018-07-01'),
	('2018-07-07', '2018-07-01'),
	('2018-07-08', '2018-07-01'),
	('2018-07-09', '2018-07-01'),
	('2018-07-10', '2018-07-01'),
	('2018-07-11', '2018-07-01'),
	('2018-07-12', '2018-07-01'),
	('2018-07-13', '2018-07-01'),
	('2018-07-14', '2018-07-01'),
	('2018-07-15', '2018-07-01'),
	('2018-07-16', '2018-07-01'),
	('2018-07-17', '2018-07-01'),
	('2018-07-18', '2018-07-01'),
	('2018-07-19', '2018-07-01'),
	('2018-07-20', '2018-07-01'),
	('2018-07-21', '2018-07-01'),
	('2018-07-22', '2018-07-01'),
	('2018-07-23', '2018-07-01'),
	('2018-07-24', '2018-07-01'),
	('2018-07-25', '2018-07-01'),
	('2018-07-26', '2018-07-01'),
	('2018-07-27', '2018-07-01'),
	('2018-07-28', '2018-07-01'),
	('2018-07-29', '2018-07-01'),
	('2018-07-30', '2018-07-01'),
	('2018-07-31', '2018-07-01'),
	('2018-08-01', '2018-08-01'),
	('2018-08-02', '2018-08-01'),
	('2018-08-03', '2018-08-01'),
	('2018-08-04', '2018-08-01'),
	('2018-08-05', '2018-08-01'),
	('2018-08-06', '2018-08-01'),
	('2018-08-07', '2018-08-01'),
	('2018-08-08', '2018-08-01'),
	('2018-08-09', '2018-08-01'),
	('2018-08-10', '2018-08-01'),
	('2018-08-11', '2018-08-01'),
	('2018-08-12', '2018-08-01'),
	('2018-08-13', '2018-08-01'),
	('2018-08-14', '2018-08-01'),
	('2018-08-15', '2018-08-01'),
	('2018-08-16', '2018-08-01'),
	('2018-08-17', '2018-08-01'),
	('2018-08-18', '2018-08-01'),
	('2018-08-19', '2018-08-01'),
	('2018-08-20', '2018-08-01'),
	('2018-08-21', '2018-08-01'),
	('2018-08-22', '2018-08-01'),
	('2018-08-23', '2018-08-01'),
	('2018-08-24', '2018-08-01'),
	('2018-08-25', '2018-08-01'),
	('2018-08-26', '2018-08-01'),
	('2018-08-27', '2018-08-01'),
	('2018-08-28', '2018-08-01'),
	('2018-08-29', '2018-08-01'),
	('2018-08-30', '2018-08-01'),
	('2018-08-31', '2018-08-01'),
	('2018-09-01', '2018-09-01'),
	('2018-09-02', '2018-09-01'),
	('2018-09-03', '2018-09-01'),
	('2018-09-04', '2018-09-01'),
	('2018-09-05', '2018-09-01'),
	('2018-09-06', '2018-09-01'),
	('2018-09-07', '2018-09-01'),
	('2018-09-08', '2018-09-01'),
	('2018-09-09', '2018-09-01'),
	('2018-09-10', '2018-09-01'),
	('2018-09-11', '2018-09-01'),
	('2018-09-12', '2018-09-01'),
	('2018-09-13', '2018-09-01'),
	('2018-09-14', '2018-09-01'),
	('2018-09-15', '2018-09-01'),
	('2018-09-16', '2018-09-01'),
	('2018-09-17', '2018-09-01'),
	('2018-09-18', '2018-09-01'),
	('2018-09-19', '2018-09-01'),
	('2018-09-20', '2018-09-01'),
	('2018-09-21', '2018-09-01'),
	('2018-09-22', '2018-09-01'),
	('2018-09-23', '2018-09-01'),
	('2018-09-24', '2018-09-01'),
	('2018-09-25', '2018-09-01'),
	('2018-09-26', '2018-09-01'),
	('2018-09-27', '2018-09-01'),
	('2018-09-28', '2018-09-01'),
	('2018-09-29', '2018-09-01'),
	('2018-09-30', '2018-09-01'),
	('2018-10-01', '2018-10-01'),
	('2018-10-02', '2018-10-01'),
	('2018-10-03', '2018-10-01'),
	('2018-10-04', '2018-10-01'),
	('2018-10-05', '2018-10-01'),
	('2018-10-06', '2018-10-01'),
	('2018-10-07', '2018-10-01'),
	('2018-10-08', '2018-10-01'),
	('2018-10-09', '2018-10-01'),
	('2018-10-10', '2018-10-01'),
	('2018-10-11', '2018-10-01'),
	('2018-10-12', '2018-10-01'),
	('2018-10-13', '2018-10-01'),
	('2018-10-14', '2018-10-01'),
	('2018-10-15', '2018-10-01'),
	('2018-10-16', '2018-10-01'),
	('2018-10-17', '2018-10-01'),
	('2018-10-18', '2018-10-01'),
	('2018-10-19', '2018-10-01'),
	('2018-10-20', '2018-10-01'),
	('2018-10-21', '2018-10-01'),
	('2018-10-22', '2018-10-01'),
	('2018-10-23', '2018-10-01'),
	('2018-10-24', '2018-10-01'),
	('2018-10-25', '2018-10-01'),
	('2018-10-26', '2018-10-01'),
	('2018-10-27', '2018-10-01'),
	('2018-10-28', '2018-10-01'),
	('2018-10-29', '2018-10-01'),
	('2018-10-30', '2018-10-01'),
	('2018-10-31', '2018-10-01'),
	('2018-11-01', '2018-11-01'),
	('2018-11-02', '2018-11-01'),
	('2018-11-03', '2018-11-01'),
	('2018-11-04', '2018-11-01'),
	('2018-11-05', '2018-11-01'),
	('2018-11-06', '2018-11-01'),
	('2018-11-07', '2018-11-01'),
	('2018-11-08', '2018-11-01'),
	('2018-11-09', '2018-11-01'),
	('2018-11-10', '2018-11-01'),
	('2018-11-11', '2018-11-01'),
	('2018-11-12', '2018-11-01'),
	('2018-11-13', '2018-11-01'),
	('2018-11-14', '2018-11-01'),
	('2018-11-15', '2018-11-01'),
	('2018-11-16', '2018-11-01'),
	('2018-11-17', '2018-11-01'),
	('2018-11-18', '2018-11-01'),
	('2018-11-19', '2018-11-01'),
	('2018-11-20', '2018-11-01'),
	('2018-11-21', '2018-11-01'),
	('2018-11-22', '2018-11-01'),
	('2018-11-23', '2018-11-01'),
	('2018-11-24', '2018-11-01'),
	('2018-11-25', '2018-11-01'),
	('2018-11-26', '2018-11-01'),
	('2018-11-27', '2018-11-01'),
	('2018-11-28', '2018-11-01'),
	('2018-11-29', '2018-11-01'),
	('2018-11-30', '2018-11-01'),
	('2018-12-01', '2018-12-01'),
	('2018-12-02', '2018-12-01'),
	('2018-12-03', '2018-12-01'),
	('2018-12-04', '2018-12-01'),
	('2018-12-05', '2018-12-01'),
	('2018-12-06', '2018-12-01'),
	('2018-12-07', '2018-12-01'),
	('2018-12-08', '2018-12-01'),
	('2018-12-09', '2018-12-01'),
	('2018-12-10', '2018-12-01'),
	('2018-12-11', '2018-12-01'),
	('2018-12-12', '2018-12-01'),
	('2018-12-13', '2018-12-01'),
	('2018-12-14', '2018-12-01'),
	('2018-12-15', '2018-12-01'),
	('2018-12-16', '2018-12-01'),
	('2018-12-17', '2018-12-01'),
	('2018-12-18', '2018-12-01'),
	('2018-12-19', '2018-12-01'),
	('2018-12-20', '2018-12-01'),
	('2018-12-21', '2018-12-01'),
	('2018-12-22', '2018-12-01'),
	('2018-12-23', '2018-12-01'),
	('2018-12-24', '2018-12-01'),
	('2018-12-25', '2018-12-01'),
	('2018-12-26', '2018-12-01'),
	('2018-12-27', '2018-12-01'),
	('2018-12-28', '2018-12-01'),
	('2018-12-29', '2018-12-01'),
	('2018-12-30', '2018-12-01'),
	('2018-12-31', '2018-12-01'),
	('2019-01-01', '2019-01-01'),
	('2019-01-02', '2019-01-01'),
	('2019-01-03', '2019-01-01'),
	('2019-01-04', '2019-01-01'),
	('2019-01-05', '2019-01-01'),
	('2019-01-06', '2019-01-01'),
	('2019-01-07', '2019-01-01'),
	('2019-01-08', '2019-01-01'),
	('2019-01-09', '2019-01-01'),
	('2019-01-10', '2019-01-01'),
	('2019-01-11', '2019-01-01'),
	('2019-01-12', '2019-01-01'),
	('2019-01-13', '2019-01-01'),
	('2019-01-14', '2019-01-01'),
	('2019-01-15', '2019-01-01'),
	('2019-01-16', '2019-01-01'),
	('2019-01-17', '2019-01-01'),
	('2019-01-18', '2019-01-01'),
	('2019-01-19', '2019-01-01'),
	('2019-01-20', '2019-01-01'),
	('2019-01-21', '2019-01-01'),
	('2019-01-22', '2019-01-01'),
	('2019-01-23', '2019-01-01'),
	('2019-01-24', '2019-01-01'),
	('2019-01-25', '2019-01-01'),
	('2019-01-26', '2019-01-01'),
	('2019-01-27', '2019-01-01'),
	('2019-01-28', '2019-01-01'),
	('2019-01-29', '2019-01-01'),
	('2019-01-30', '2019-01-01'),
	('2019-01-31', '2019-01-01'),
	('2019-02-01', '2019-02-01'),
	('2019-02-02', '2019-02-01'),
	('2019-02-03', '2019-02-01'),
	('2019-02-04', '2019-02-01'),
	('2019-02-05', '2019-02-01'),
	('2019-02-06', '2019-02-01'),
	('2019-02-07', '2019-02-01'),
	('2019-02-08', '2019-02-01'),
	('2019-02-09', '2019-02-01'),
	('2019-02-10', '2019-02-01'),
	('2019-02-11', '2019-02-01'),
	('2019-02-12', '2019-02-01'),
	('2019-02-13', '2019-02-01'),
	('2019-02-14', '2019-02-01'),
	('2019-02-15', '2019-02-01'),
	('2019-02-16', '2019-02-01'),
	('2019-02-17', '2019-02-01'),
	('2019-02-18', '2019-02-01'),
	('2019-02-19', '2019-02-01'),
	('2019-02-20', '2019-02-01'),
	('2019-02-21', '2019-02-01'),
	('2019-02-22', '2019-02-01'),
	('2019-02-23', '2019-02-01'),
	('2019-02-24', '2019-02-01'),
	('2019-02-25', '2019-02-01'),
	('2019-02-26', '2019-02-01'),
	('2019-02-27', '2019-02-01'),
	('2019-02-28', '2019-02-01'),
	('2019-03-01', '2019-03-01'),
	('2019-03-02', '2019-03-01'),
	('2019-03-03', '2019-03-01'),
	('2019-03-04', '2019-03-01'),
	('2019-03-05', '2019-03-01'),
	('2019-03-06', '2019-03-01'),
	('2019-03-07', '2019-03-01'),
	('2019-03-08', '2019-03-01'),
	('2019-03-09', '2019-03-01'),
	('2019-03-10', '2019-03-01'),
	('2019-03-11', '2019-03-01'),
	('2019-03-12', '2019-03-01'),
	('2019-03-13', '2019-03-01'),
	('2019-03-14', '2019-03-01'),
	('2019-03-15', '2019-03-01'),
	('2019-03-16', '2019-03-01'),
	('2019-03-17', '2019-03-01'),
	('2019-03-18', '2019-03-01'),
	('2019-03-19', '2019-03-01'),
	('2019-03-20', '2019-03-01'),
	('2019-03-21', '2019-03-01'),
	('2019-03-22', '2019-03-01'),
	('2019-03-23', '2019-03-01'),
	('2019-03-24', '2019-03-01'),
	('2019-03-25', '2019-03-01'),
	('2019-03-26', '2019-03-01'),
	('2019-03-27', '2019-03-01'),
	('2019-03-28', '2019-03-01'),
	('2019-03-29', '2019-03-01'),
	('2019-03-30', '2019-03-01'),
	('2019-03-31', '2019-03-01'),
	('2019-04-01', '2019-04-01'),
	('2019-04-02', '2019-04-01'),
	('2019-04-03', '2019-04-01'),
	('2019-04-04', '2019-04-01'),
	('2019-04-05', '2019-04-01'),
	('2019-04-06', '2019-04-01'),
	('2019-04-07', '2019-04-01'),
	('2019-04-08', '2019-04-01'),
	('2019-04-09', '2019-04-01'),
	('2019-04-10', '2019-04-01'),
	('2019-04-11', '2019-04-01'),
	('2019-04-12', '2019-04-01'),
	('2019-04-13', '2019-04-01'),
	('2019-04-14', '2019-04-01'),
	('2019-04-15', '2019-04-01'),
	('2019-04-16', '2019-04-01'),
	('2019-04-17', '2019-04-01'),
	('2019-04-18', '2019-04-01'),
	('2019-04-19', '2019-04-01'),
	('2019-04-20', '2019-04-01'),
	('2019-04-21', '2019-04-01'),
	('2019-04-22', '2019-04-01'),
	('2019-04-23', '2019-04-01'),
	('2019-04-24', '2019-04-01'),
	('2019-04-25', '2019-04-01'),
	('2019-04-26', '2019-04-01'),
	('2019-04-27', '2019-04-01'),
	('2019-04-28', '2019-04-01'),
	('2019-04-29', '2019-04-01'),
	('2019-04-30', '2019-04-01'),
	('2019-05-01', '2019-05-01'),
	('2019-05-02', '2019-05-01'),
	('2019-05-03', '2019-05-01'),
	('2019-05-04', '2019-05-01'),
	('2019-05-05', '2019-05-01'),
	('2019-05-06', '2019-05-01'),
	('2019-05-07', '2019-05-01'),
	('2019-05-08', '2019-05-01'),
	('2019-05-09', '2019-05-01'),
	('2019-05-10', '2019-05-01'),
	('2019-05-11', '2019-05-01'),
	('2019-05-12', '2019-05-01'),
	('2019-05-13', '2019-05-01'),
	('2019-05-14', '2019-05-01'),
	('2019-05-15', '2019-05-01'),
	('2019-05-16', '2019-05-01'),
	('2019-05-17', '2019-05-01'),
	('2019-05-18', '2019-05-01'),
	('2019-05-19', '2019-05-01'),
	('2019-05-20', '2019-05-01'),
	('2019-05-21', '2019-05-01'),
	('2019-05-22', '2019-05-01'),
	('2019-05-23', '2019-05-01'),
	('2019-05-24', '2019-05-01'),
	('2019-05-25', '2019-05-01'),
	('2019-05-26', '2019-05-01'),
	('2019-05-27', '2019-05-01'),
	('2019-05-28', '2019-05-01'),
	('2019-05-29', '2019-05-01'),
	('2019-05-30', '2019-05-01'),
	('2019-05-31', '2019-05-01'),
	('2019-06-01', '2019-06-01'),
	('2019-06-02', '2019-06-01'),
	('2019-06-03', '2019-06-01'),
	('2019-06-04', '2019-06-01'),
	('2019-06-05', '2019-06-01'),
	('2019-06-06', '2019-06-01'),
	('2019-06-07', '2019-06-01'),
	('2019-06-08', '2019-06-01'),
	('2019-06-09', '2019-06-01'),
	('2019-06-10', '2019-06-01'),
	('2019-06-11', '2019-06-01'),
	('2019-06-12', '2019-06-01'),
	('2019-06-13', '2019-06-01'),
	('2019-06-14', '2019-06-01'),
	('2019-06-15', '2019-06-01'),
	('2019-06-16', '2019-06-01'),
	('2019-06-17', '2019-06-01'),
	('2019-06-18', '2019-06-01'),
	('2019-06-19', '2019-06-01'),
	('2019-06-20', '2019-06-01'),
	('2019-06-21', '2019-06-01'),
	('2019-06-22', '2019-06-01'),
	('2019-06-23', '2019-06-01'),
	('2019-06-24', '2019-06-01'),
	('2019-06-25', '2019-06-01'),
	('2019-06-26', '2019-06-01'),
	('2019-06-27', '2019-06-01'),
	('2019-06-28', '2019-06-01'),
	('2019-06-29', '2019-06-01'),
	('2019-06-30', '2019-06-01'),
	('2019-07-01', '2019-07-01'),
	('2019-07-02', '2019-07-01'),
	('2019-07-03', '2019-07-01'),
	('2019-07-04', '2019-07-01'),
	('2019-07-05', '2019-07-01'),
	('2019-07-06', '2019-07-01'),
	('2019-07-07', '2019-07-01'),
	('2019-07-08', '2019-07-01'),
	('2019-07-09', '2019-07-01'),
	('2019-07-10', '2019-07-01'),
	('2019-07-11', '2019-07-01'),
	('2019-07-12', '2019-07-01'),
	('2019-07-13', '2019-07-01'),
	('2019-07-14', '2019-07-01'),
	('2019-07-15', '2019-07-01'),
	('2019-07-16', '2019-07-01'),
	('2019-07-17', '2019-07-01'),
	('2019-07-18', '2019-07-01'),
	('2019-07-19', '2019-07-01'),
	('2019-07-20', '2019-07-01'),
	('2019-07-21', '2019-07-01'),
	('2019-07-22', '2019-07-01'),
	('2019-07-23', '2019-07-01'),
	('2019-07-24', '2019-07-01'),
	('2019-07-25', '2019-07-01'),
	('2019-07-26', '2019-07-01'),
	('2019-07-27', '2019-07-01'),
	('2019-07-28', '2019-07-01'),
	('2019-07-29', '2019-07-01'),
	('2019-07-30', '2019-07-01'),
	('2019-07-31', '2019-07-01'),
	('2019-08-01', '2019-08-01'),
	('2019-08-02', '2019-08-01'),
	('2019-08-03', '2019-08-01'),
	('2019-08-04', '2019-08-01'),
	('2019-08-05', '2019-08-01'),
	('2019-08-06', '2019-08-01'),
	('2019-08-07', '2019-08-01'),
	('2019-08-08', '2019-08-01'),
	('2019-08-09', '2019-08-01'),
	('2019-08-10', '2019-08-01'),
	('2019-08-11', '2019-08-01'),
	('2019-08-12', '2019-08-01'),
	('2019-08-13', '2019-08-01'),
	('2019-08-14', '2019-08-01'),
	('2019-08-15', '2019-08-01'),
	('2019-08-16', '2019-08-01'),
	('2019-08-17', '2019-08-01'),
	('2019-08-18', '2019-08-01'),
	('2019-08-19', '2019-08-01'),
	('2019-08-20', '2019-08-01'),
	('2019-08-21', '2019-08-01'),
	('2019-08-22', '2019-08-01'),
	('2019-08-23', '2019-08-01'),
	('2019-08-24', '2019-08-01'),
	('2019-08-25', '2019-08-01'),
	('2019-08-26', '2019-08-01'),
	('2019-08-27', '2019-08-01'),
	('2019-08-28', '2019-08-01'),
	('2019-08-29', '2019-08-01'),
	('2019-08-30', '2019-08-01'),
	('2019-08-31', '2019-08-01'),
	('2019-09-01', '2019-09-01'),
	('2019-09-02', '2019-09-01'),
	('2019-09-03', '2019-09-01'),
	('2019-09-04', '2019-09-01'),
	('2019-09-05', '2019-09-01'),
	('2019-09-06', '2019-09-01'),
	('2019-09-07', '2019-09-01'),
	('2019-09-08', '2019-09-01'),
	('2019-09-09', '2019-09-01'),
	('2019-09-10', '2019-09-01'),
	('2019-09-11', '2019-09-01'),
	('2019-09-12', '2019-09-01'),
	('2019-09-13', '2019-09-01'),
	('2019-09-14', '2019-09-01'),
	('2019-09-15', '2019-09-01'),
	('2019-09-16', '2019-09-01'),
	('2019-09-17', '2019-09-01'),
	('2019-09-18', '2019-09-01'),
	('2019-09-19', '2019-09-01'),
	('2019-09-20', '2019-09-01'),
	('2019-09-21', '2019-09-01'),
	('2019-09-22', '2019-09-01'),
	('2019-09-23', '2019-09-01'),
	('2019-09-24', '2019-09-01'),
	('2019-09-25', '2019-09-01'),
	('2019-09-26', '2019-09-01'),
	('2019-09-27', '2019-09-01'),
	('2019-09-28', '2019-09-01'),
	('2019-09-29', '2019-09-01'),
	('2019-09-30', '2019-09-01'),
	('2019-10-01', '2019-10-01'),
	('2019-10-02', '2019-10-01'),
	('2019-10-03', '2019-10-01'),
	('2019-10-04', '2019-10-01'),
	('2019-10-05', '2019-10-01'),
	('2019-10-06', '2019-10-01'),
	('2019-10-07', '2019-10-01'),
	('2019-10-08', '2019-10-01'),
	('2019-10-09', '2019-10-01'),
	('2019-10-10', '2019-10-01'),
	('2019-10-11', '2019-10-01'),
	('2019-10-12', '2019-10-01'),
	('2019-10-13', '2019-10-01'),
	('2019-10-14', '2019-10-01'),
	('2019-10-15', '2019-10-01'),
	('2019-10-16', '2019-10-01'),
	('2019-10-17', '2019-10-01'),
	('2019-10-18', '2019-10-01'),
	('2019-10-19', '2019-10-01'),
	('2019-10-20', '2019-10-01'),
	('2019-10-21', '2019-10-01'),
	('2019-10-22', '2019-10-01'),
	('2019-10-23', '2019-10-01'),
	('2019-10-24', '2019-10-01'),
	('2019-10-25', '2019-10-01'),
	('2019-10-26', '2019-10-01'),
	('2019-10-27', '2019-10-01'),
	('2019-10-28', '2019-10-01'),
	('2019-10-29', '2019-10-01'),
	('2019-10-30', '2019-10-01'),
	('2019-10-31', '2019-10-01'),
	('2019-11-01', '2019-11-01'),
	('2019-11-02', '2019-11-01'),
	('2019-11-03', '2019-11-01'),
	('2019-11-04', '2019-11-01'),
	('2019-11-05', '2019-11-01'),
	('2019-11-06', '2019-11-01'),
	('2019-11-07', '2019-11-01'),
	('2019-11-08', '2019-11-01'),
	('2019-11-09', '2019-11-01'),
	('2019-11-10', '2019-11-01'),
	('2019-11-11', '2019-11-01'),
	('2019-11-12', '2019-11-01'),
	('2019-11-13', '2019-11-01'),
	('2019-11-14', '2019-11-01'),
	('2019-11-15', '2019-11-01'),
	('2019-11-16', '2019-11-01'),
	('2019-11-17', '2019-11-01'),
	('2019-11-18', '2019-11-01'),
	('2019-11-19', '2019-11-01'),
	('2019-11-20', '2019-11-01'),
	('2019-11-21', '2019-11-01'),
	('2019-11-22', '2019-11-01'),
	('2019-11-23', '2019-11-01'),
	('2019-11-24', '2019-11-01'),
	('2019-11-25', '2019-11-01'),
	('2019-11-26', '2019-11-01'),
	('2019-11-27', '2019-11-01'),
	('2019-11-28', '2019-11-01'),
	('2019-11-29', '2019-11-01'),
	('2019-11-30', '2019-11-01'),
	('2019-12-01', '2019-12-01'),
	('2019-12-02', '2019-12-01'),
	('2019-12-03', '2019-12-01'),
	('2019-12-04', '2019-12-01'),
	('2019-12-05', '2019-12-01'),
	('2019-12-06', '2019-12-01'),
	('2019-12-07', '2019-12-01'),
	('2019-12-08', '2019-12-01'),
	('2019-12-09', '2019-12-01'),
	('2019-12-10', '2019-12-01'),
	('2019-12-11', '2019-12-01'),
	('2019-12-12', '2019-12-01'),
	('2019-12-13', '2019-12-01'),
	('2019-12-14', '2019-12-01'),
	('2019-12-15', '2019-12-01'),
	('2019-12-16', '2019-12-01'),
	('2019-12-17', '2019-12-01'),
	('2019-12-18', '2019-12-01'),
	('2019-12-19', '2019-12-01'),
	('2019-12-20', '2019-12-01'),
	('2019-12-21', '2019-12-01'),
	('2019-12-22', '2019-12-01'),
	('2019-12-23', '2019-12-01'),
	('2019-12-24', '2019-12-01'),
	('2019-12-25', '2019-12-01'),
	('2019-12-26', '2019-12-01'),
	('2019-12-27', '2019-12-01'),
	('2019-12-28', '2019-12-01'),
	('2019-12-29', '2019-12-01'),
	('2019-12-30', '2019-12-01'),
	('2019-12-31', '2019-12-01'),
	('2020-01-01', '2020-01-01'),
	('2020-01-02', '2020-01-01'),
	('2020-01-03', '2020-01-01'),
	('2020-01-04', '2020-01-01'),
	('2020-01-05', '2020-01-01'),
	('2020-01-06', '2020-01-01'),
	('2020-01-07', '2020-01-01'),
	('2020-01-08', '2020-01-01'),
	('2020-01-09', '2020-01-01'),
	('2020-01-10', '2020-01-01'),
	('2020-01-11', '2020-01-01'),
	('2020-01-12', '2020-01-01'),
	('2020-01-13', '2020-01-01'),
	('2020-01-14', '2020-01-01'),
	('2020-01-15', '2020-01-01'),
	('2020-01-16', '2020-01-01'),
	('2020-01-17', '2020-01-01'),
	('2020-01-18', '2020-01-01'),
	('2020-01-19', '2020-01-01'),
	('2020-01-20', '2020-01-01'),
	('2020-01-21', '2020-01-01'),
	('2020-01-22', '2020-01-01'),
	('2020-01-23', '2020-01-01'),
	('2020-01-24', '2020-01-01'),
	('2020-01-25', '2020-01-01'),
	('2020-01-26', '2020-01-01'),
	('2020-01-27', '2020-01-01'),
	('2020-01-28', '2020-01-01'),
	('2020-01-29', '2020-01-01'),
	('2020-01-30', '2020-01-01'),
	('2020-01-31', '2020-01-01'),
	('2020-02-01', '2020-02-01'),
	('2020-02-02', '2020-02-01'),
	('2020-02-03', '2020-02-01'),
	('2020-02-04', '2020-02-01'),
	('2020-02-05', '2020-02-01'),
	('2020-02-06', '2020-02-01'),
	('2020-02-07', '2020-02-01'),
	('2020-02-08', '2020-02-01'),
	('2020-02-09', '2020-02-01'),
	('2020-02-10', '2020-02-01'),
	('2020-02-11', '2020-02-01'),
	('2020-02-12', '2020-02-01'),
	('2020-02-13', '2020-02-01'),
	('2020-02-14', '2020-02-01'),
	('2020-02-15', '2020-02-01'),
	('2020-02-16', '2020-02-01'),
	('2020-02-17', '2020-02-01'),
	('2020-02-18', '2020-02-01'),
	('2020-02-19', '2020-02-01'),
	('2020-02-20', '2020-02-01'),
	('2020-02-21', '2020-02-01'),
	('2020-02-22', '2020-02-01'),
	('2020-02-23', '2020-02-01'),
	('2020-02-24', '2020-02-01'),
	('2020-02-25', '2020-02-01'),
	('2020-02-26', '2020-02-01'),
	('2020-02-27', '2020-02-01'),
	('2020-02-28', '2020-02-01'),
	('2020-02-29', '2020-02-01'),
	('2020-03-01', '2020-03-01'),
	('2020-03-02', '2020-03-01'),
	('2020-03-03', '2020-03-01'),
	('2020-03-04', '2020-03-01'),
	('2020-03-05', '2020-03-01'),
	('2020-03-06', '2020-03-01'),
	('2020-03-07', '2020-03-01'),
	('2020-03-08', '2020-03-01'),
	('2020-03-09', '2020-03-01'),
	('2020-03-10', '2020-03-01'),
	('2020-03-11', '2020-03-01'),
	('2020-03-12', '2020-03-01'),
	('2020-03-13', '2020-03-01'),
	('2020-03-14', '2020-03-01'),
	('2020-03-15', '2020-03-01'),
	('2020-03-16', '2020-03-01'),
	('2020-03-17', '2020-03-01'),
	('2020-03-18', '2020-03-01'),
	('2020-03-19', '2020-03-01'),
	('2020-03-20', '2020-03-01'),
	('2020-03-21', '2020-03-01'),
	('2020-03-22', '2020-03-01'),
	('2020-03-23', '2020-03-01'),
	('2020-03-24', '2020-03-01'),
	('2020-03-25', '2020-03-01'),
	('2020-03-26', '2020-03-01'),
	('2020-03-27', '2020-03-01'),
	('2020-03-28', '2020-03-01'),
	('2020-03-29', '2020-03-01'),
	('2020-03-30', '2020-03-01'),
	('2020-03-31', '2020-03-01'),
	('2020-04-01', '2020-04-01'),
	('2020-04-02', '2020-04-01'),
	('2020-04-03', '2020-04-01'),
	('2020-04-04', '2020-04-01'),
	('2020-04-05', '2020-04-01'),
	('2020-04-06', '2020-04-01'),
	('2020-04-07', '2020-04-01'),
	('2020-04-08', '2020-04-01'),
	('2020-04-09', '2020-04-01'),
	('2020-04-10', '2020-04-01'),
	('2020-04-11', '2020-04-01'),
	('2020-04-12', '2020-04-01'),
	('2020-04-13', '2020-04-01'),
	('2020-04-14', '2020-04-01'),
	('2020-04-15', '2020-04-01'),
	('2020-04-16', '2020-04-01'),
	('2020-04-17', '2020-04-01'),
	('2020-04-18', '2020-04-01'),
	('2020-04-19', '2020-04-01'),
	('2020-04-20', '2020-04-01'),
	('2020-04-21', '2020-04-01'),
	('2020-04-22', '2020-04-01'),
	('2020-04-23', '2020-04-01'),
	('2020-04-24', '2020-04-01'),
	('2020-04-25', '2020-04-01'),
	('2020-04-26', '2020-04-01'),
	('2020-04-27', '2020-04-01'),
	('2020-04-28', '2020-04-01'),
	('2020-04-29', '2020-04-01'),
	('2020-04-30', '2020-04-01'),
	('2020-05-01', '2020-05-01'),
	('2020-05-02', '2020-05-01'),
	('2020-05-03', '2020-05-01'),
	('2020-05-04', '2020-05-01'),
	('2020-05-05', '2020-05-01'),
	('2020-05-06', '2020-05-01'),
	('2020-05-07', '2020-05-01'),
	('2020-05-08', '2020-05-01'),
	('2020-05-09', '2020-05-01'),
	('2020-05-10', '2020-05-01'),
	('2020-05-11', '2020-05-01'),
	('2020-05-12', '2020-05-01'),
	('2020-05-13', '2020-05-01'),
	('2020-05-14', '2020-05-01'),
	('2020-05-15', '2020-05-01'),
	('2020-05-16', '2020-05-01'),
	('2020-05-17', '2020-05-01'),
	('2020-05-18', '2020-05-01'),
	('2020-05-19', '2020-05-01'),
	('2020-05-20', '2020-05-01'),
	('2020-05-21', '2020-05-01'),
	('2020-05-22', '2020-05-01'),
	('2020-05-23', '2020-05-01'),
	('2020-05-24', '2020-05-01'),
	('2020-05-25', '2020-05-01'),
	('2020-05-26', '2020-05-01'),
	('2020-05-27', '2020-05-01'),
	('2020-05-28', '2020-05-01'),
	('2020-05-29', '2020-05-01'),
	('2020-05-30', '2020-05-01'),
	('2020-05-31', '2020-05-01'),
	('2020-06-01', '2020-06-01'),
	('2020-06-02', '2020-06-01'),
	('2020-06-03', '2020-06-01'),
	('2020-06-04', '2020-06-01'),
	('2020-06-05', '2020-06-01'),
	('2020-06-06', '2020-06-01'),
	('2020-06-07', '2020-06-01'),
	('2020-06-08', '2020-06-01'),
	('2020-06-09', '2020-06-01'),
	('2020-06-10', '2020-06-01'),
	('2020-06-11', '2020-06-01'),
	('2020-06-12', '2020-06-01'),
	('2020-06-13', '2020-06-01'),
	('2020-06-14', '2020-06-01'),
	('2020-06-15', '2020-06-01'),
	('2020-06-16', '2020-06-01'),
	('2020-06-17', '2020-06-01'),
	('2020-06-18', '2020-06-01'),
	('2020-06-19', '2020-06-01'),
	('2020-06-20', '2020-06-01'),
	('2020-06-21', '2020-06-01'),
	('2020-06-22', '2020-06-01'),
	('2020-06-23', '2020-06-01'),
	('2020-06-24', '2020-06-01'),
	('2020-06-25', '2020-06-01'),
	('2020-06-26', '2020-06-01'),
	('2020-06-27', '2020-06-01'),
	('2020-06-28', '2020-06-01'),
	('2020-06-29', '2020-06-01'),
	('2020-06-30', '2020-06-01'),
	('2020-07-01', '2020-07-01'),
	('2020-07-02', '2020-07-01'),
	('2020-07-03', '2020-07-01'),
	('2020-07-04', '2020-07-01'),
	('2020-07-05', '2020-07-01'),
	('2020-07-06', '2020-07-01'),
	('2020-07-07', '2020-07-01'),
	('2020-07-08', '2020-07-01'),
	('2020-07-09', '2020-07-01'),
	('2020-07-10', '2020-07-01'),
	('2020-07-11', '2020-07-01'),
	('2020-07-12', '2020-07-01'),
	('2020-07-13', '2020-07-01'),
	('2020-07-14', '2020-07-01'),
	('2020-07-15', '2020-07-01'),
	('2020-07-16', '2020-07-01'),
	('2020-07-17', '2020-07-01'),
	('2020-07-18', '2020-07-01'),
	('2020-07-19', '2020-07-01'),
	('2020-07-20', '2020-07-01'),
	('2020-07-21', '2020-07-01'),
	('2020-07-22', '2020-07-01'),
	('2020-07-23', '2020-07-01'),
	('2020-07-24', '2020-07-01'),
	('2020-07-25', '2020-07-01'),
	('2020-07-26', '2020-07-01'),
	('2020-07-27', '2020-07-01'),
	('2020-07-28', '2020-07-01'),
	('2020-07-29', '2020-07-01'),
	('2020-07-30', '2020-07-01'),
	('2020-07-31', '2020-07-01'),
	('2020-08-01', '2020-08-01'),
	('2020-08-02', '2020-08-01'),
	('2020-08-03', '2020-08-01'),
	('2020-08-04', '2020-08-01'),
	('2020-08-05', '2020-08-01'),
	('2020-08-06', '2020-08-01'),
	('2020-08-07', '2020-08-01'),
	('2020-08-08', '2020-08-01'),
	('2020-08-09', '2020-08-01'),
	('2020-08-10', '2020-08-01'),
	('2020-08-11', '2020-08-01'),
	('2020-08-12', '2020-08-01'),
	('2020-08-13', '2020-08-01'),
	('2020-08-14', '2020-08-01'),
	('2020-08-15', '2020-08-01'),
	('2020-08-16', '2020-08-01'),
	('2020-08-17', '2020-08-01'),
	('2020-08-18', '2020-08-01'),
	('2020-08-19', '2020-08-01'),
	('2020-08-20', '2020-08-01'),
	('2020-08-21', '2020-08-01'),
	('2020-08-22', '2020-08-01'),
	('2020-08-23', '2020-08-01'),
	('2020-08-24', '2020-08-01'),
	('2020-08-25', '2020-08-01'),
	('2020-08-26', '2020-08-01'),
	('2020-08-27', '2020-08-01'),
	('2020-08-28', '2020-08-01'),
	('2020-08-29', '2020-08-01'),
	('2020-08-30', '2020-08-01'),
	('2020-08-31', '2020-08-01'),
	('2020-09-01', '2020-09-01'),
	('2020-09-02', '2020-09-01'),
	('2020-09-03', '2020-09-01'),
	('2020-09-04', '2020-09-01'),
	('2020-09-05', '2020-09-01'),
	('2020-09-06', '2020-09-01'),
	('2020-09-07', '2020-09-01'),
	('2020-09-08', '2020-09-01'),
	('2020-09-09', '2020-09-01'),
	('2020-09-10', '2020-09-01'),
	('2020-09-11', '2020-09-01'),
	('2020-09-12', '2020-09-01'),
	('2020-09-13', '2020-09-01'),
	('2020-09-14', '2020-09-01'),
	('2020-09-15', '2020-09-01'),
	('2020-09-16', '2020-09-01'),
	('2020-09-17', '2020-09-01'),
	('2020-09-18', '2020-09-01'),
	('2020-09-19', '2020-09-01'),
	('2020-09-20', '2020-09-01'),
	('2020-09-21', '2020-09-01'),
	('2020-09-22', '2020-09-01'),
	('2020-09-23', '2020-09-01'),
	('2020-09-24', '2020-09-01'),
	('2020-09-25', '2020-09-01'),
	('2020-09-26', '2020-09-01'),
	('2020-09-27', '2020-09-01'),
	('2020-09-28', '2020-09-01'),
	('2020-09-29', '2020-09-01'),
	('2020-09-30', '2020-09-01'),
	('2020-10-01', '2020-10-01'),
	('2020-10-02', '2020-10-01'),
	('2020-10-03', '2020-10-01'),
	('2020-10-04', '2020-10-01'),
	('2020-10-05', '2020-10-01'),
	('2020-10-06', '2020-10-01'),
	('2020-10-07', '2020-10-01'),
	('2020-10-08', '2020-10-01'),
	('2020-10-09', '2020-10-01'),
	('2020-10-10', '2020-10-01'),
	('2020-10-11', '2020-10-01'),
	('2020-10-12', '2020-10-01'),
	('2020-10-13', '2020-10-01'),
	('2020-10-14', '2020-10-01'),
	('2020-10-15', '2020-10-01'),
	('2020-10-16', '2020-10-01'),
	('2020-10-17', '2020-10-01'),
	('2020-10-18', '2020-10-01'),
	('2020-10-19', '2020-10-01'),
	('2020-10-20', '2020-10-01'),
	('2020-10-21', '2020-10-01'),
	('2020-10-22', '2020-10-01'),
	('2020-10-23', '2020-10-01'),
	('2020-10-24', '2020-10-01'),
	('2020-10-25', '2020-10-01'),
	('2020-10-26', '2020-10-01'),
	('2020-10-27', '2020-10-01'),
	('2020-10-28', '2020-10-01'),
	('2020-10-29', '2020-10-01'),
	('2020-10-30', '2020-10-01'),
	('2020-10-31', '2020-10-01'),
	('2020-11-01', '2020-11-01'),
	('2020-11-02', '2020-11-01'),
	('2020-11-03', '2020-11-01'),
	('2020-11-04', '2020-11-01'),
	('2020-11-05', '2020-11-01'),
	('2020-11-06', '2020-11-01'),
	('2020-11-07', '2020-11-01'),
	('2020-11-08', '2020-11-01'),
	('2020-11-09', '2020-11-01'),
	('2020-11-10', '2020-11-01'),
	('2020-11-11', '2020-11-01'),
	('2020-11-12', '2020-11-01'),
	('2020-11-13', '2020-11-01'),
	('2020-11-14', '2020-11-01'),
	('2020-11-15', '2020-11-01'),
	('2020-11-16', '2020-11-01'),
	('2020-11-17', '2020-11-01'),
	('2020-11-18', '2020-11-01'),
	('2020-11-19', '2020-11-01'),
	('2020-11-20', '2020-11-01'),
	('2020-11-21', '2020-11-01'),
	('2020-11-22', '2020-11-01'),
	('2020-11-23', '2020-11-01'),
	('2020-11-24', '2020-11-01'),
	('2020-11-25', '2020-11-01'),
	('2020-11-26', '2020-11-01'),
	('2020-11-27', '2020-11-01'),
	('2020-11-28', '2020-11-01'),
	('2020-11-29', '2020-11-01'),
	('2020-11-30', '2020-11-01'),
	('2020-12-01', '2020-12-01'),
	('2020-12-02', '2020-12-01'),
	('2020-12-03', '2020-12-01'),
	('2020-12-04', '2020-12-01'),
	('2020-12-05', '2020-12-01'),
	('2020-12-06', '2020-12-01'),
	('2020-12-07', '2020-12-01'),
	('2020-12-08', '2020-12-01'),
	('2020-12-09', '2020-12-01'),
	('2020-12-10', '2020-12-01'),
	('2020-12-11', '2020-12-01'),
	('2020-12-12', '2020-12-01'),
	('2020-12-13', '2020-12-01'),
	('2020-12-14', '2020-12-01'),
	('2020-12-15', '2020-12-01'),
	('2020-12-16', '2020-12-01'),
	('2020-12-17', '2020-12-01'),
	('2020-12-18', '2020-12-01'),
	('2020-12-19', '2020-12-01'),
	('2020-12-20', '2020-12-01'),
	('2020-12-21', '2020-12-01'),
	('2020-12-22', '2020-12-01'),
	('2020-12-23', '2020-12-01'),
	('2020-12-24', '2020-12-01'),
	('2020-12-25', '2020-12-01'),
	('2020-12-26', '2020-12-01'),
	('2020-12-27', '2020-12-01'),
	('2020-12-28', '2020-12-01'),
	('2020-12-29', '2020-12-01'),
	('2020-12-30', '2020-12-01'),
	('2020-12-31', '2020-12-01'),
	('2021-01-01', '2021-01-01'),
	('2021-01-02', '2021-01-01'),
	('2021-01-03', '2021-01-01'),
	('2021-01-04', '2021-01-01'),
	('2021-01-05', '2021-01-01'),
	('2021-01-06', '2021-01-01'),
	('2021-01-07', '2021-01-01'),
	('2021-01-08', '2021-01-01'),
	('2021-01-09', '2021-01-01'),
	('2021-01-10', '2021-01-01'),
	('2021-01-11', '2021-01-01'),
	('2021-01-12', '2021-01-01'),
	('2021-01-13', '2021-01-01'),
	('2021-01-14', '2021-01-01'),
	('2021-01-15', '2021-01-01'),
	('2021-01-16', '2021-01-01'),
	('2021-01-17', '2021-01-01'),
	('2021-01-18', '2021-01-01'),
	('2021-01-19', '2021-01-01'),
	('2021-01-20', '2021-01-01'),
	('2021-01-21', '2021-01-01'),
	('2021-01-22', '2021-01-01'),
	('2021-01-23', '2021-01-01'),
	('2021-01-24', '2021-01-01'),
	('2021-01-25', '2021-01-01'),
	('2021-01-26', '2021-01-01'),
	('2021-01-27', '2021-01-01'),
	('2021-01-28', '2021-01-01'),
	('2021-01-29', '2021-01-01'),
	('2021-01-30', '2021-01-01'),
	('2021-01-31', '2021-01-01'),
	('2021-02-01', '2021-02-01'),
	('2021-02-02', '2021-02-01'),
	('2021-02-03', '2021-02-01'),
	('2021-02-04', '2021-02-01'),
	('2021-02-05', '2021-02-01'),
	('2021-02-06', '2021-02-01'),
	('2021-02-07', '2021-02-01'),
	('2021-02-08', '2021-02-01'),
	('2021-02-09', '2021-02-01'),
	('2021-02-10', '2021-02-01'),
	('2021-02-11', '2021-02-01'),
	('2021-02-12', '2021-02-01'),
	('2021-02-13', '2021-02-01'),
	('2021-02-14', '2021-02-01'),
	('2021-02-15', '2021-02-01'),
	('2021-02-16', '2021-02-01'),
	('2021-02-17', '2021-02-01'),
	('2021-02-18', '2021-02-01'),
	('2021-02-19', '2021-02-01'),
	('2021-02-20', '2021-02-01'),
	('2021-02-21', '2021-02-01'),
	('2021-02-22', '2021-02-01'),
	('2021-02-23', '2021-02-01'),
	('2021-02-24', '2021-02-01'),
	('2021-02-25', '2021-02-01'),
	('2021-02-26', '2021-02-01'),
	('2021-02-27', '2021-02-01'),
	('2021-02-28', '2021-02-01'),
	('2021-03-01', '2021-03-01'),
	('2021-03-02', '2021-03-01'),
	('2021-03-03', '2021-03-01'),
	('2021-03-04', '2021-03-01'),
	('2021-03-05', '2021-03-01'),
	('2021-03-06', '2021-03-01'),
	('2021-03-07', '2021-03-01'),
	('2021-03-08', '2021-03-01'),
	('2021-03-09', '2021-03-01'),
	('2021-03-10', '2021-03-01'),
	('2021-03-11', '2021-03-01'),
	('2021-03-12', '2021-03-01'),
	('2021-03-13', '2021-03-01'),
	('2021-03-14', '2021-03-01'),
	('2021-03-15', '2021-03-01'),
	('2021-03-16', '2021-03-01'),
	('2021-03-17', '2021-03-01'),
	('2021-03-18', '2021-03-01'),
	('2021-03-19', '2021-03-01'),
	('2021-03-20', '2021-03-01'),
	('2021-03-21', '2021-03-01'),
	('2021-03-22', '2021-03-01'),
	('2021-03-23', '2021-03-01'),
	('2021-03-24', '2021-03-01'),
	('2021-03-25', '2021-03-01'),
	('2021-03-26', '2021-03-01'),
	('2021-03-27', '2021-03-01'),
	('2021-03-28', '2021-03-01'),
	('2021-03-29', '2021-03-01'),
	('2021-03-30', '2021-03-01'),
	('2021-03-31', '2021-03-01'),
	('2021-04-01', '2021-04-01'),
	('2021-04-02', '2021-04-01'),
	('2021-04-03', '2021-04-01'),
	('2021-04-04', '2021-04-01'),
	('2021-04-05', '2021-04-01'),
	('2021-04-06', '2021-04-01'),
	('2021-04-07', '2021-04-01'),
	('2021-04-08', '2021-04-01'),
	('2021-04-09', '2021-04-01'),
	('2021-04-10', '2021-04-01'),
	('2021-04-11', '2021-04-01'),
	('2021-04-12', '2021-04-01'),
	('2021-04-13', '2021-04-01'),
	('2021-04-14', '2021-04-01'),
	('2021-04-15', '2021-04-01'),
	('2021-04-16', '2021-04-01'),
	('2021-04-17', '2021-04-01'),
	('2021-04-18', '2021-04-01'),
	('2021-04-19', '2021-04-01'),
	('2021-04-20', '2021-04-01'),
	('2021-04-21', '2021-04-01'),
	('2021-04-22', '2021-04-01'),
	('2021-04-23', '2021-04-01'),
	('2021-04-24', '2021-04-01'),
	('2021-04-25', '2021-04-01'),
	('2021-04-26', '2021-04-01'),
	('2021-04-27', '2021-04-01'),
	('2021-04-28', '2021-04-01'),
	('2021-04-29', '2021-04-01'),
	('2021-04-30', '2021-04-01'),
	('2021-05-01', '2021-05-01'),
	('2021-05-02', '2021-05-01'),
	('2021-05-03', '2021-05-01'),
	('2021-05-04', '2021-05-01'),
	('2021-05-05', '2021-05-01'),
	('2021-05-06', '2021-05-01'),
	('2021-05-07', '2021-05-01'),
	('2021-05-08', '2021-05-01'),
	('2021-05-09', '2021-05-01'),
	('2021-05-10', '2021-05-01'),
	('2021-05-11', '2021-05-01'),
	('2021-05-12', '2021-05-01'),
	('2021-05-13', '2021-05-01'),
	('2021-05-14', '2021-05-01'),
	('2021-05-15', '2021-05-01'),
	('2021-05-16', '2021-05-01'),
	('2021-05-17', '2021-05-01'),
	('2021-05-18', '2021-05-01'),
	('2021-05-19', '2021-05-01'),
	('2021-05-20', '2021-05-01'),
	('2021-05-21', '2021-05-01'),
	('2021-05-22', '2021-05-01'),
	('2021-05-23', '2021-05-01'),
	('2021-05-24', '2021-05-01'),
	('2021-05-25', '2021-05-01'),
	('2021-05-26', '2021-05-01'),
	('2021-05-27', '2021-05-01'),
	('2021-05-28', '2021-05-01'),
	('2021-05-29', '2021-05-01'),
	('2021-05-30', '2021-05-01'),
	('2021-05-31', '2021-05-01'),
	('2021-06-01', '2021-06-01'),
	('2021-06-02', '2021-06-01'),
	('2021-06-03', '2021-06-01'),
	('2021-06-04', '2021-06-01'),
	('2021-06-05', '2021-06-01'),
	('2021-06-06', '2021-06-01'),
	('2021-06-07', '2021-06-01'),
	('2021-06-08', '2021-06-01'),
	('2021-06-09', '2021-06-01'),
	('2021-06-10', '2021-06-01'),
	('2021-06-11', '2021-06-01'),
	('2021-06-12', '2021-06-01'),
	('2021-06-13', '2021-06-01'),
	('2021-06-14', '2021-06-01'),
	('2021-06-15', '2021-06-01'),
	('2021-06-16', '2021-06-01'),
	('2021-06-17', '2021-06-01'),
	('2021-06-18', '2021-06-01'),
	('2021-06-19', '2021-06-01'),
	('2021-06-20', '2021-06-01'),
	('2021-06-21', '2021-06-01'),
	('2021-06-22', '2021-06-01'),
	('2021-06-23', '2021-06-01'),
	('2021-06-24', '2021-06-01'),
	('2021-06-25', '2021-06-01'),
	('2021-06-26', '2021-06-01'),
	('2021-06-27', '2021-06-01'),
	('2021-06-28', '2021-06-01'),
	('2021-06-29', '2021-06-01'),
	('2021-06-30', '2021-06-01'),
	('2021-07-01', '2021-07-01'),
	('2021-07-02', '2021-07-01'),
	('2021-07-03', '2021-07-01'),
	('2021-07-04', '2021-07-01'),
	('2021-07-05', '2021-07-01'),
	('2021-07-06', '2021-07-01'),
	('2021-07-07', '2021-07-01'),
	('2021-07-08', '2021-07-01'),
	('2021-07-09', '2021-07-01'),
	('2021-07-10', '2021-07-01'),
	('2021-07-11', '2021-07-01'),
	('2021-07-12', '2021-07-01'),
	('2021-07-13', '2021-07-01'),
	('2021-07-14', '2021-07-01'),
	('2021-07-15', '2021-07-01'),
	('2021-07-16', '2021-07-01'),
	('2021-07-17', '2021-07-01'),
	('2021-07-18', '2021-07-01'),
	('2021-07-19', '2021-07-01'),
	('2021-07-20', '2021-07-01'),
	('2021-07-21', '2021-07-01'),
	('2021-07-22', '2021-07-01'),
	('2021-07-23', '2021-07-01'),
	('2021-07-24', '2021-07-01'),
	('2021-07-25', '2021-07-01'),
	('2021-07-26', '2021-07-01'),
	('2021-07-27', '2021-07-01'),
	('2021-07-28', '2021-07-01'),
	('2021-07-29', '2021-07-01'),
	('2021-07-30', '2021-07-01'),
	('2021-07-31', '2021-07-01'),
	('2021-08-01', '2021-08-01'),
	('2021-08-02', '2021-08-01'),
	('2021-08-03', '2021-08-01'),
	('2021-08-04', '2021-08-01'),
	('2021-08-05', '2021-08-01'),
	('2021-08-06', '2021-08-01'),
	('2021-08-07', '2021-08-01'),
	('2021-08-08', '2021-08-01'),
	('2021-08-09', '2021-08-01'),
	('2021-08-10', '2021-08-01'),
	('2021-08-11', '2021-08-01'),
	('2021-08-12', '2021-08-01'),
	('2021-08-13', '2021-08-01'),
	('2021-08-14', '2021-08-01'),
	('2021-08-15', '2021-08-01'),
	('2021-08-16', '2021-08-01'),
	('2021-08-17', '2021-08-01'),
	('2021-08-18', '2021-08-01'),
	('2021-08-19', '2021-08-01'),
	('2021-08-20', '2021-08-01'),
	('2021-08-21', '2021-08-01'),
	('2021-08-22', '2021-08-01'),
	('2021-08-23', '2021-08-01'),
	('2021-08-24', '2021-08-01'),
	('2021-08-25', '2021-08-01'),
	('2021-08-26', '2021-08-01'),
	('2021-08-27', '2021-08-01'),
	('2021-08-28', '2021-08-01'),
	('2021-08-29', '2021-08-01'),
	('2021-08-30', '2021-08-01'),
	('2021-08-31', '2021-08-01'),
	('2021-09-01', '2021-09-01'),
	('2021-09-02', '2021-09-01'),
	('2021-09-03', '2021-09-01'),
	('2021-09-04', '2021-09-01'),
	('2021-09-05', '2021-09-01'),
	('2021-09-06', '2021-09-01'),
	('2021-09-07', '2021-09-01'),
	('2021-09-08', '2021-09-01'),
	('2021-09-09', '2021-09-01'),
	('2021-09-10', '2021-09-01'),
	('2021-09-11', '2021-09-01'),
	('2021-09-12', '2021-09-01'),
	('2021-09-13', '2021-09-01'),
	('2021-09-14', '2021-09-01'),
	('2021-09-15', '2021-09-01'),
	('2021-09-16', '2021-09-01'),
	('2021-09-17', '2021-09-01'),
	('2021-09-18', '2021-09-01'),
	('2021-09-19', '2021-09-01'),
	('2021-09-20', '2021-09-01'),
	('2021-09-21', '2021-09-01'),
	('2021-09-22', '2021-09-01'),
	('2021-09-23', '2021-09-01'),
	('2021-09-24', '2021-09-01'),
	('2021-09-25', '2021-09-01'),
	('2021-09-26', '2021-09-01'),
	('2021-09-27', '2021-09-01'),
	('2021-09-28', '2021-09-01'),
	('2021-09-29', '2021-09-01'),
	('2021-09-30', '2021-09-01'),
	('2021-10-01', '2021-10-01'),
	('2021-10-02', '2021-10-01'),
	('2021-10-03', '2021-10-01'),
	('2021-10-04', '2021-10-01'),
	('2021-10-05', '2021-10-01'),
	('2021-10-06', '2021-10-01'),
	('2021-10-07', '2021-10-01'),
	('2021-10-08', '2021-10-01'),
	('2021-10-09', '2021-10-01'),
	('2021-10-10', '2021-10-01'),
	('2021-10-11', '2021-10-01'),
	('2021-10-12', '2021-10-01'),
	('2021-10-13', '2021-10-01'),
	('2021-10-14', '2021-10-01'),
	('2021-10-15', '2021-10-01'),
	('2021-10-16', '2021-10-01'),
	('2021-10-17', '2021-10-01'),
	('2021-10-18', '2021-10-01'),
	('2021-10-19', '2021-10-01'),
	('2021-10-20', '2021-10-01'),
	('2021-10-21', '2021-10-01'),
	('2021-10-22', '2021-10-01'),
	('2021-10-23', '2021-10-01'),
	('2021-10-24', '2021-10-01'),
	('2021-10-25', '2021-10-01'),
	('2021-10-26', '2021-10-01'),
	('2021-10-27', '2021-10-01'),
	('2021-10-28', '2021-10-01'),
	('2021-10-29', '2021-10-01'),
	('2021-10-30', '2021-10-01'),
	('2021-10-31', '2021-10-01'),
	('2021-11-01', '2021-11-01'),
	('2021-11-02', '2021-11-01'),
	('2021-11-03', '2021-11-01'),
	('2021-11-04', '2021-11-01'),
	('2021-11-05', '2021-11-01'),
	('2021-11-06', '2021-11-01'),
	('2021-11-07', '2021-11-01'),
	('2021-11-08', '2021-11-01'),
	('2021-11-09', '2021-11-01'),
	('2021-11-10', '2021-11-01'),
	('2021-11-11', '2021-11-01'),
	('2021-11-12', '2021-11-01'),
	('2021-11-13', '2021-11-01'),
	('2021-11-14', '2021-11-01'),
	('2021-11-15', '2021-11-01'),
	('2021-11-16', '2021-11-01'),
	('2021-11-17', '2021-11-01'),
	('2021-11-18', '2021-11-01'),
	('2021-11-19', '2021-11-01'),
	('2021-11-20', '2021-11-01'),
	('2021-11-21', '2021-11-01'),
	('2021-11-22', '2021-11-01'),
	('2021-11-23', '2021-11-01'),
	('2021-11-24', '2021-11-01'),
	('2021-11-25', '2021-11-01'),
	('2021-11-26', '2021-11-01'),
	('2021-11-27', '2021-11-01'),
	('2021-11-28', '2021-11-01'),
	('2021-11-29', '2021-11-01'),
	('2021-11-30', '2021-11-01'),
	('2021-12-01', '2021-12-01'),
	('2021-12-02', '2021-12-01'),
	('2021-12-03', '2021-12-01'),
	('2021-12-04', '2021-12-01'),
	('2021-12-05', '2021-12-01'),
	('2021-12-06', '2021-12-01'),
	('2021-12-07', '2021-12-01'),
	('2021-12-08', '2021-12-01'),
	('2021-12-09', '2021-12-01'),
	('2021-12-10', '2021-12-01'),
	('2021-12-11', '2021-12-01'),
	('2021-12-12', '2021-12-01'),
	('2021-12-13', '2021-12-01'),
	('2021-12-14', '2021-12-01'),
	('2021-12-15', '2021-12-01'),
	('2021-12-16', '2021-12-01'),
	('2021-12-17', '2021-12-01'),
	('2021-12-18', '2021-12-01'),
	('2021-12-19', '2021-12-01'),
	('2021-12-20', '2021-12-01'),
	('2021-12-21', '2021-12-01'),
	('2021-12-22', '2021-12-01'),
	('2021-12-23', '2021-12-01'),
	('2021-12-24', '2021-12-01'),
	('2021-12-25', '2021-12-01'),
	('2021-12-26', '2021-12-01'),
	('2021-12-27', '2021-12-01'),
	('2021-12-28', '2021-12-01'),
	('2021-12-29', '2021-12-01'),
	('2021-12-30', '2021-12-01'),
	('2021-12-31', '2021-12-01'),
	('2022-01-01', '2022-01-01'),
	('2022-01-02', '2022-01-01'),
	('2022-01-03', '2022-01-01'),
	('2022-01-04', '2022-01-01'),
	('2022-01-05', '2022-01-01'),
	('2022-01-06', '2022-01-01'),
	('2022-01-07', '2022-01-01'),
	('2022-01-08', '2022-01-01'),
	('2022-01-09', '2022-01-01'),
	('2022-01-10', '2022-01-01'),
	('2022-01-11', '2022-01-01'),
	('2022-01-12', '2022-01-01'),
	('2022-01-13', '2022-01-01'),
	('2022-01-14', '2022-01-01'),
	('2022-01-15', '2022-01-01'),
	('2022-01-16', '2022-01-01'),
	('2022-01-17', '2022-01-01'),
	('2022-01-18', '2022-01-01'),
	('2022-01-19', '2022-01-01'),
	('2022-01-20', '2022-01-01'),
	('2022-01-21', '2022-01-01'),
	('2022-01-22', '2022-01-01'),
	('2022-01-23', '2022-01-01'),
	('2022-01-24', '2022-01-01'),
	('2022-01-25', '2022-01-01'),
	('2022-01-26', '2022-01-01'),
	('2022-01-27', '2022-01-01'),
	('2022-01-28', '2022-01-01'),
	('2022-01-29', '2022-01-01'),
	('2022-01-30', '2022-01-01'),
	('2022-01-31', '2022-01-01'),
	('2022-02-01', '2022-02-01'),
	('2022-02-02', '2022-02-01'),
	('2022-02-03', '2022-02-01'),
	('2022-02-04', '2022-02-01'),
	('2022-02-05', '2022-02-01'),
	('2022-02-06', '2022-02-01'),
	('2022-02-07', '2022-02-01'),
	('2022-02-08', '2022-02-01'),
	('2022-02-09', '2022-02-01'),
	('2022-02-10', '2022-02-01'),
	('2022-02-11', '2022-02-01'),
	('2022-02-12', '2022-02-01'),
	('2022-02-13', '2022-02-01'),
	('2022-02-14', '2022-02-01'),
	('2022-02-15', '2022-02-01'),
	('2022-02-16', '2022-02-01'),
	('2022-02-17', '2022-02-01'),
	('2022-02-18', '2022-02-01'),
	('2022-02-19', '2022-02-01'),
	('2022-02-20', '2022-02-01'),
	('2022-02-21', '2022-02-01'),
	('2022-02-22', '2022-02-01'),
	('2022-02-23', '2022-02-01'),
	('2022-02-24', '2022-02-01'),
	('2022-02-25', '2022-02-01'),
	('2022-02-26', '2022-02-01'),
	('2022-02-27', '2022-02-01'),
	('2022-02-28', '2022-02-01'),
	('2022-03-01', '2022-03-01'),
	('2022-03-02', '2022-03-01'),
	('2022-03-03', '2022-03-01'),
	('2022-03-04', '2022-03-01'),
	('2022-03-05', '2022-03-01'),
	('2022-03-06', '2022-03-01'),
	('2022-03-07', '2022-03-01'),
	('2022-03-08', '2022-03-01'),
	('2022-03-09', '2022-03-01'),
	('2022-03-10', '2022-03-01'),
	('2022-03-11', '2022-03-01'),
	('2022-03-12', '2022-03-01'),
	('2022-03-13', '2022-03-01'),
	('2022-03-14', '2022-03-01'),
	('2022-03-15', '2022-03-01'),
	('2022-03-16', '2022-03-01'),
	('2022-03-17', '2022-03-01'),
	('2022-03-18', '2022-03-01'),
	('2022-03-19', '2022-03-01'),
	('2022-03-20', '2022-03-01'),
	('2022-03-21', '2022-03-01'),
	('2022-03-22', '2022-03-01'),
	('2022-03-23', '2022-03-01'),
	('2022-03-24', '2022-03-01'),
	('2022-03-25', '2022-03-01'),
	('2022-03-26', '2022-03-01'),
	('2022-03-27', '2022-03-01'),
	('2022-03-28', '2022-03-01'),
	('2022-03-29', '2022-03-01'),
	('2022-03-30', '2022-03-01'),
	('2022-03-31', '2022-03-01'),
	('2022-04-01', '2022-04-01'),
	('2022-04-02', '2022-04-01'),
	('2022-04-03', '2022-04-01'),
	('2022-04-04', '2022-04-01'),
	('2022-04-05', '2022-04-01'),
	('2022-04-06', '2022-04-01'),
	('2022-04-07', '2022-04-01'),
	('2022-04-08', '2022-04-01'),
	('2022-04-09', '2022-04-01'),
	('2022-04-10', '2022-04-01'),
	('2022-04-11', '2022-04-01'),
	('2022-04-12', '2022-04-01'),
	('2022-04-13', '2022-04-01'),
	('2022-04-14', '2022-04-01'),
	('2022-04-15', '2022-04-01'),
	('2022-04-16', '2022-04-01'),
	('2022-04-17', '2022-04-01'),
	('2022-04-18', '2022-04-01'),
	('2022-04-19', '2022-04-01'),
	('2022-04-20', '2022-04-01'),
	('2022-04-21', '2022-04-01'),
	('2022-04-22', '2022-04-01'),
	('2022-04-23', '2022-04-01'),
	('2022-04-24', '2022-04-01'),
	('2022-04-25', '2022-04-01'),
	('2022-04-26', '2022-04-01'),
	('2022-04-27', '2022-04-01'),
	('2022-04-28', '2022-04-01'),
	('2022-04-29', '2022-04-01'),
	('2022-04-30', '2022-04-01'),
	('2022-05-01', '2022-05-01'),
	('2022-05-02', '2022-05-01'),
	('2022-05-03', '2022-05-01'),
	('2022-05-04', '2022-05-01'),
	('2022-05-05', '2022-05-01'),
	('2022-05-06', '2022-05-01'),
	('2022-05-07', '2022-05-01'),
	('2022-05-08', '2022-05-01'),
	('2022-05-09', '2022-05-01'),
	('2022-05-10', '2022-05-01'),
	('2022-05-11', '2022-05-01'),
	('2022-05-12', '2022-05-01'),
	('2022-05-13', '2022-05-01'),
	('2022-05-14', '2022-05-01'),
	('2022-05-15', '2022-05-01'),
	('2022-05-16', '2022-05-01'),
	('2022-05-17', '2022-05-01'),
	('2022-05-18', '2022-05-01'),
	('2022-05-19', '2022-05-01'),
	('2022-05-20', '2022-05-01'),
	('2022-05-21', '2022-05-01'),
	('2022-05-22', '2022-05-01'),
	('2022-05-23', '2022-05-01'),
	('2022-05-24', '2022-05-01'),
	('2022-05-25', '2022-05-01'),
	('2022-05-26', '2022-05-01'),
	('2022-05-27', '2022-05-01'),
	('2022-05-28', '2022-05-01'),
	('2022-05-29', '2022-05-01'),
	('2022-05-30', '2022-05-01'),
	('2022-05-31', '2022-05-01'),
	('2022-06-01', '2022-06-01'),
	('2022-06-02', '2022-06-01'),
	('2022-06-03', '2022-06-01'),
	('2022-06-04', '2022-06-01'),
	('2022-06-05', '2022-06-01'),
	('2022-06-06', '2022-06-01'),
	('2022-06-07', '2022-06-01'),
	('2022-06-08', '2022-06-01'),
	('2022-06-09', '2022-06-01'),
	('2022-06-10', '2022-06-01'),
	('2022-06-11', '2022-06-01'),
	('2022-06-12', '2022-06-01'),
	('2022-06-13', '2022-06-01'),
	('2022-06-14', '2022-06-01'),
	('2022-06-15', '2022-06-01'),
	('2022-06-16', '2022-06-01'),
	('2022-06-17', '2022-06-01'),
	('2022-06-18', '2022-06-01'),
	('2022-06-19', '2022-06-01'),
	('2022-06-20', '2022-06-01'),
	('2022-06-21', '2022-06-01'),
	('2022-06-22', '2022-06-01'),
	('2022-06-23', '2022-06-01'),
	('2022-06-24', '2022-06-01'),
	('2022-06-25', '2022-06-01'),
	('2022-06-26', '2022-06-01'),
	('2022-06-27', '2022-06-01'),
	('2022-06-28', '2022-06-01'),
	('2022-06-29', '2022-06-01'),
	('2022-06-30', '2022-06-01'),
	('2022-07-01', '2022-07-01'),
	('2022-07-02', '2022-07-01'),
	('2022-07-03', '2022-07-01'),
	('2022-07-04', '2022-07-01'),
	('2022-07-05', '2022-07-01'),
	('2022-07-06', '2022-07-01'),
	('2022-07-07', '2022-07-01'),
	('2022-07-08', '2022-07-01'),
	('2022-07-09', '2022-07-01'),
	('2022-07-10', '2022-07-01'),
	('2022-07-11', '2022-07-01'),
	('2022-07-12', '2022-07-01'),
	('2022-07-13', '2022-07-01'),
	('2022-07-14', '2022-07-01'),
	('2022-07-15', '2022-07-01'),
	('2022-07-16', '2022-07-01'),
	('2022-07-17', '2022-07-01'),
	('2022-07-18', '2022-07-01'),
	('2022-07-19', '2022-07-01'),
	('2022-07-20', '2022-07-01'),
	('2022-07-21', '2022-07-01'),
	('2022-07-22', '2022-07-01'),
	('2022-07-23', '2022-07-01'),
	('2022-07-24', '2022-07-01'),
	('2022-07-25', '2022-07-01'),
	('2022-07-26', '2022-07-01'),
	('2022-07-27', '2022-07-01'),
	('2022-07-28', '2022-07-01'),
	('2022-07-29', '2022-07-01'),
	('2022-07-30', '2022-07-01'),
	('2022-07-31', '2022-07-01'),
	('2022-08-01', '2022-08-01'),
	('2022-08-02', '2022-08-01'),
	('2022-08-03', '2022-08-01'),
	('2022-08-04', '2022-08-01'),
	('2022-08-05', '2022-08-01'),
	('2022-08-06', '2022-08-01'),
	('2022-08-07', '2022-08-01'),
	('2022-08-08', '2022-08-01'),
	('2022-08-09', '2022-08-01'),
	('2022-08-10', '2022-08-01'),
	('2022-08-11', '2022-08-01'),
	('2022-08-12', '2022-08-01'),
	('2022-08-13', '2022-08-01'),
	('2022-08-14', '2022-08-01'),
	('2022-08-15', '2022-08-01'),
	('2022-08-16', '2022-08-01'),
	('2022-08-17', '2022-08-01'),
	('2022-08-18', '2022-08-01'),
	('2022-08-19', '2022-08-01'),
	('2022-08-20', '2022-08-01'),
	('2022-08-21', '2022-08-01'),
	('2022-08-22', '2022-08-01'),
	('2022-08-23', '2022-08-01'),
	('2022-08-24', '2022-08-01'),
	('2022-08-25', '2022-08-01'),
	('2022-08-26', '2022-08-01'),
	('2022-08-27', '2022-08-01'),
	('2022-08-28', '2022-08-01'),
	('2022-08-29', '2022-08-01'),
	('2022-08-30', '2022-08-01'),
	('2022-08-31', '2022-08-01'),
	('2022-09-01', '2022-09-01'),
	('2022-09-02', '2022-09-01'),
	('2022-09-03', '2022-09-01'),
	('2022-09-04', '2022-09-01'),
	('2022-09-05', '2022-09-01'),
	('2022-09-06', '2022-09-01'),
	('2022-09-07', '2022-09-01'),
	('2022-09-08', '2022-09-01'),
	('2022-09-09', '2022-09-01'),
	('2022-09-10', '2022-09-01'),
	('2022-09-11', '2022-09-01'),
	('2022-09-12', '2022-09-01'),
	('2022-09-13', '2022-09-01'),
	('2022-09-14', '2022-09-01'),
	('2022-09-15', '2022-09-01'),
	('2022-09-16', '2022-09-01'),
	('2022-09-17', '2022-09-01'),
	('2022-09-18', '2022-09-01'),
	('2022-09-19', '2022-09-01'),
	('2022-09-20', '2022-09-01'),
	('2022-09-21', '2022-09-01'),
	('2022-09-22', '2022-09-01'),
	('2022-09-23', '2022-09-01'),
	('2022-09-24', '2022-09-01'),
	('2022-09-25', '2022-09-01'),
	('2022-09-26', '2022-09-01'),
	('2022-09-27', '2022-09-01'),
	('2022-09-28', '2022-09-01'),
	('2022-09-29', '2022-09-01'),
	('2022-09-30', '2022-09-01'),
	('2022-10-01', '2022-10-01'),
	('2022-10-02', '2022-10-01'),
	('2022-10-03', '2022-10-01'),
	('2022-10-04', '2022-10-01'),
	('2022-10-05', '2022-10-01'),
	('2022-10-06', '2022-10-01'),
	('2022-10-07', '2022-10-01'),
	('2022-10-08', '2022-10-01'),
	('2022-10-09', '2022-10-01'),
	('2022-10-10', '2022-10-01'),
	('2022-10-11', '2022-10-01'),
	('2022-10-12', '2022-10-01'),
	('2022-10-13', '2022-10-01'),
	('2022-10-14', '2022-10-01'),
	('2022-10-15', '2022-10-01'),
	('2022-10-16', '2022-10-01'),
	('2022-10-17', '2022-10-01'),
	('2022-10-18', '2022-10-01'),
	('2022-10-19', '2022-10-01'),
	('2022-10-20', '2022-10-01'),
	('2022-10-21', '2022-10-01'),
	('2022-10-22', '2022-10-01'),
	('2022-10-23', '2022-10-01'),
	('2022-10-24', '2022-10-01'),
	('2022-10-25', '2022-10-01'),
	('2022-10-26', '2022-10-01'),
	('2022-10-27', '2022-10-01'),
	('2022-10-28', '2022-10-01'),
	('2022-10-29', '2022-10-01'),
	('2022-10-30', '2022-10-01'),
	('2022-10-31', '2022-10-01'),
	('2022-11-01', '2022-11-01'),
	('2022-11-02', '2022-11-01'),
	('2022-11-03', '2022-11-01'),
	('2022-11-04', '2022-11-01'),
	('2022-11-05', '2022-11-01'),
	('2022-11-06', '2022-11-01'),
	('2022-11-07', '2022-11-01'),
	('2022-11-08', '2022-11-01'),
	('2022-11-09', '2022-11-01'),
	('2022-11-10', '2022-11-01'),
	('2022-11-11', '2022-11-01'),
	('2022-11-12', '2022-11-01'),
	('2022-11-13', '2022-11-01'),
	('2022-11-14', '2022-11-01'),
	('2022-11-15', '2022-11-01'),
	('2022-11-16', '2022-11-01'),
	('2022-11-17', '2022-11-01'),
	('2022-11-18', '2022-11-01'),
	('2022-11-19', '2022-11-01'),
	('2022-11-20', '2022-11-01'),
	('2022-11-21', '2022-11-01'),
	('2022-11-22', '2022-11-01'),
	('2022-11-23', '2022-11-01'),
	('2022-11-24', '2022-11-01'),
	('2022-11-25', '2022-11-01'),
	('2022-11-26', '2022-11-01'),
	('2022-11-27', '2022-11-01'),
	('2022-11-28', '2022-11-01'),
	('2022-11-29', '2022-11-01'),
	('2022-11-30', '2022-11-01'),
	('2022-12-01', '2022-12-01'),
	('2022-12-02', '2022-12-01'),
	('2022-12-03', '2022-12-01'),
	('2022-12-04', '2022-12-01'),
	('2022-12-05', '2022-12-01'),
	('2022-12-06', '2022-12-01'),
	('2022-12-07', '2022-12-01'),
	('2022-12-08', '2022-12-01'),
	('2022-12-09', '2022-12-01'),
	('2022-12-10', '2022-12-01'),
	('2022-12-11', '2022-12-01'),
	('2022-12-12', '2022-12-01'),
	('2022-12-13', '2022-12-01'),
	('2022-12-14', '2022-12-01'),
	('2022-12-15', '2022-12-01'),
	('2022-12-16', '2022-12-01'),
	('2022-12-17', '2022-12-01'),
	('2022-12-18', '2022-12-01'),
	('2022-12-19', '2022-12-01'),
	('2022-12-20', '2022-12-01'),
	('2022-12-21', '2022-12-01'),
	('2022-12-22', '2022-12-01'),
	('2022-12-23', '2022-12-01'),
	('2022-12-24', '2022-12-01'),
	('2022-12-25', '2022-12-01'),
	('2022-12-26', '2022-12-01'),
	('2022-12-27', '2022-12-01'),
	('2022-12-28', '2022-12-01'),
	('2022-12-29', '2022-12-01'),
	('2022-12-30', '2022-12-01'),
	('2022-12-31', '2022-12-01'),
	('2023-01-01', '2023-01-01'),
	('2023-01-02', '2023-01-01'),
	('2023-01-03', '2023-01-01'),
	('2023-01-04', '2023-01-01'),
	('2023-01-05', '2023-01-01'),
	('2023-01-06', '2023-01-01'),
	('2023-01-07', '2023-01-01'),
	('2023-01-08', '2023-01-01'),
	('2023-01-09', '2023-01-01'),
	('2023-01-10', '2023-01-01'),
	('2023-01-11', '2023-01-01'),
	('2023-01-12', '2023-01-01'),
	('2023-01-13', '2023-01-01'),
	('2023-01-14', '2023-01-01'),
	('2023-01-15', '2023-01-01'),
	('2023-01-16', '2023-01-01'),
	('2023-01-17', '2023-01-01'),
	('2023-01-18', '2023-01-01'),
	('2023-01-19', '2023-01-01'),
	('2023-01-20', '2023-01-01'),
	('2023-01-21', '2023-01-01'),
	('2023-01-22', '2023-01-01'),
	('2023-01-23', '2023-01-01'),
	('2023-01-24', '2023-01-01'),
	('2023-01-25', '2023-01-01'),
	('2023-01-26', '2023-01-01'),
	('2023-01-27', '2023-01-01'),
	('2023-01-28', '2023-01-01'),
	('2023-01-29', '2023-01-01'),
	('2023-01-30', '2023-01-01'),
	('2023-01-31', '2023-01-01'),
	('2023-02-01', '2023-02-01'),
	('2023-02-02', '2023-02-01'),
	('2023-02-03', '2023-02-01'),
	('2023-02-04', '2023-02-01'),
	('2023-02-05', '2023-02-01'),
	('2023-02-06', '2023-02-01'),
	('2023-02-07', '2023-02-01'),
	('2023-02-08', '2023-02-01'),
	('2023-02-09', '2023-02-01'),
	('2023-02-10', '2023-02-01'),
	('2023-02-11', '2023-02-01'),
	('2023-02-12', '2023-02-01'),
	('2023-02-13', '2023-02-01'),
	('2023-02-14', '2023-02-01'),
	('2023-02-15', '2023-02-01'),
	('2023-02-16', '2023-02-01'),
	('2023-02-17', '2023-02-01'),
	('2023-02-18', '2023-02-01'),
	('2023-02-19', '2023-02-01'),
	('2023-02-20', '2023-02-01'),
	('2023-02-21', '2023-02-01'),
	('2023-02-22', '2023-02-01'),
	('2023-02-23', '2023-02-01'),
	('2023-02-24', '2023-02-01'),
	('2023-02-25', '2023-02-01'),
	('2023-02-26', '2023-02-01'),
	('2023-02-27', '2023-02-01'),
	('2023-02-28', '2023-02-01'),
	('2023-03-01', '2023-03-01'),
	('2023-03-02', '2023-03-01'),
	('2023-03-03', '2023-03-01'),
	('2023-03-04', '2023-03-01'),
	('2023-03-05', '2023-03-01'),
	('2023-03-06', '2023-03-01'),
	('2023-03-07', '2023-03-01'),
	('2023-03-08', '2023-03-01'),
	('2023-03-09', '2023-03-01'),
	('2023-03-10', '2023-03-01'),
	('2023-03-11', '2023-03-01'),
	('2023-03-12', '2023-03-01'),
	('2023-03-13', '2023-03-01'),
	('2023-03-14', '2023-03-01'),
	('2023-03-15', '2023-03-01'),
	('2023-03-16', '2023-03-01'),
	('2023-03-17', '2023-03-01'),
	('2023-03-18', '2023-03-01'),
	('2023-03-19', '2023-03-01'),
	('2023-03-20', '2023-03-01'),
	('2023-03-21', '2023-03-01'),
	('2023-03-22', '2023-03-01'),
	('2023-03-23', '2023-03-01'),
	('2023-03-24', '2023-03-01'),
	('2023-03-25', '2023-03-01'),
	('2023-03-26', '2023-03-01'),
	('2023-03-27', '2023-03-01'),
	('2023-03-28', '2023-03-01'),
	('2023-03-29', '2023-03-01'),
	('2023-03-30', '2023-03-01'),
	('2023-03-31', '2023-03-01'),
	('2023-04-01', '2023-04-01'),
	('2023-04-02', '2023-04-01'),
	('2023-04-03', '2023-04-01'),
	('2023-04-04', '2023-04-01'),
	('2023-04-05', '2023-04-01'),
	('2023-04-06', '2023-04-01'),
	('2023-04-07', '2023-04-01'),
	('2023-04-08', '2023-04-01'),
	('2023-04-09', '2023-04-01'),
	('2023-04-10', '2023-04-01'),
	('2023-04-11', '2023-04-01'),
	('2023-04-12', '2023-04-01'),
	('2023-04-13', '2023-04-01'),
	('2023-04-14', '2023-04-01'),
	('2023-04-15', '2023-04-01'),
	('2023-04-16', '2023-04-01'),
	('2023-04-17', '2023-04-01'),
	('2023-04-18', '2023-04-01'),
	('2023-04-19', '2023-04-01'),
	('2023-04-20', '2023-04-01'),
	('2023-04-21', '2023-04-01'),
	('2023-04-22', '2023-04-01'),
	('2023-04-23', '2023-04-01'),
	('2023-04-24', '2023-04-01'),
	('2023-04-25', '2023-04-01'),
	('2023-04-26', '2023-04-01'),
	('2023-04-27', '2023-04-01'),
	('2023-04-28', '2023-04-01'),
	('2023-04-29', '2023-04-01'),
	('2023-04-30', '2023-04-01'),
	('2023-05-01', '2023-05-01'),
	('2023-05-02', '2023-05-01'),
	('2023-05-03', '2023-05-01'),
	('2023-05-04', '2023-05-01'),
	('2023-05-05', '2023-05-01'),
	('2023-05-06', '2023-05-01'),
	('2023-05-07', '2023-05-01'),
	('2023-05-08', '2023-05-01'),
	('2023-05-09', '2023-05-01'),
	('2023-05-10', '2023-05-01'),
	('2023-05-11', '2023-05-01'),
	('2023-05-12', '2023-05-01'),
	('2023-05-13', '2023-05-01'),
	('2023-05-14', '2023-05-01'),
	('2023-05-15', '2023-05-01'),
	('2023-05-16', '2023-05-01'),
	('2023-05-17', '2023-05-01'),
	('2023-05-18', '2023-05-01'),
	('2023-05-19', '2023-05-01'),
	('2023-05-20', '2023-05-01'),
	('2023-05-21', '2023-05-01'),
	('2023-05-22', '2023-05-01'),
	('2023-05-23', '2023-05-01'),
	('2023-05-24', '2023-05-01'),
	('2023-05-25', '2023-05-01'),
	('2023-05-26', '2023-05-01'),
	('2023-05-27', '2023-05-01'),
	('2023-05-28', '2023-05-01'),
	('2023-05-29', '2023-05-01'),
	('2023-05-30', '2023-05-01'),
	('2023-05-31', '2023-05-01'),
	('2023-06-01', '2023-06-01'),
	('2023-06-02', '2023-06-01'),
	('2023-06-03', '2023-06-01'),
	('2023-06-04', '2023-06-01'),
	('2023-06-05', '2023-06-01'),
	('2023-06-06', '2023-06-01'),
	('2023-06-07', '2023-06-01'),
	('2023-06-08', '2023-06-01'),
	('2023-06-09', '2023-06-01'),
	('2023-06-10', '2023-06-01'),
	('2023-06-11', '2023-06-01'),
	('2023-06-12', '2023-06-01'),
	('2023-06-13', '2023-06-01'),
	('2023-06-14', '2023-06-01'),
	('2023-06-15', '2023-06-01'),
	('2023-06-16', '2023-06-01'),
	('2023-06-17', '2023-06-01'),
	('2023-06-18', '2023-06-01'),
	('2023-06-19', '2023-06-01'),
	('2023-06-20', '2023-06-01'),
	('2023-06-21', '2023-06-01'),
	('2023-06-22', '2023-06-01'),
	('2023-06-23', '2023-06-01'),
	('2023-06-24', '2023-06-01'),
	('2023-06-25', '2023-06-01'),
	('2023-06-26', '2023-06-01'),
	('2023-06-27', '2023-06-01'),
	('2023-06-28', '2023-06-01'),
	('2023-06-29', '2023-06-01'),
	('2023-06-30', '2023-06-01'),
	('2023-07-01', '2023-07-01'),
	('2023-07-02', '2023-07-01'),
	('2023-07-03', '2023-07-01'),
	('2023-07-04', '2023-07-01'),
	('2023-07-05', '2023-07-01'),
	('2023-07-06', '2023-07-01'),
	('2023-07-07', '2023-07-01'),
	('2023-07-08', '2023-07-01'),
	('2023-07-09', '2023-07-01'),
	('2023-07-10', '2023-07-01'),
	('2023-07-11', '2023-07-01'),
	('2023-07-12', '2023-07-01'),
	('2023-07-13', '2023-07-01'),
	('2023-07-14', '2023-07-01'),
	('2023-07-15', '2023-07-01'),
	('2023-07-16', '2023-07-01'),
	('2023-07-17', '2023-07-01'),
	('2023-07-18', '2023-07-01'),
	('2023-07-19', '2023-07-01'),
	('2023-07-20', '2023-07-01'),
	('2023-07-21', '2023-07-01'),
	('2023-07-22', '2023-07-01'),
	('2023-07-23', '2023-07-01'),
	('2023-07-24', '2023-07-01'),
	('2023-07-25', '2023-07-01'),
	('2023-07-26', '2023-07-01'),
	('2023-07-27', '2023-07-01'),
	('2023-07-28', '2023-07-01'),
	('2023-07-29', '2023-07-01'),
	('2023-07-30', '2023-07-01'),
	('2023-07-31', '2023-07-01'),
	('2023-08-01', '2023-08-01'),
	('2023-08-02', '2023-08-01'),
	('2023-08-03', '2023-08-01'),
	('2023-08-04', '2023-08-01'),
	('2023-08-05', '2023-08-01'),
	('2023-08-06', '2023-08-01'),
	('2023-08-07', '2023-08-01'),
	('2023-08-08', '2023-08-01'),
	('2023-08-09', '2023-08-01'),
	('2023-08-10', '2023-08-01'),
	('2023-08-11', '2023-08-01'),
	('2023-08-12', '2023-08-01'),
	('2023-08-13', '2023-08-01'),
	('2023-08-14', '2023-08-01'),
	('2023-08-15', '2023-08-01'),
	('2023-08-16', '2023-08-01'),
	('2023-08-17', '2023-08-01'),
	('2023-08-18', '2023-08-01'),
	('2023-08-19', '2023-08-01'),
	('2023-08-20', '2023-08-01'),
	('2023-08-21', '2023-08-01'),
	('2023-08-22', '2023-08-01'),
	('2023-08-23', '2023-08-01'),
	('2023-08-24', '2023-08-01'),
	('2023-08-25', '2023-08-01'),
	('2023-08-26', '2023-08-01'),
	('2023-08-27', '2023-08-01'),
	('2023-08-28', '2023-08-01'),
	('2023-08-29', '2023-08-01'),
	('2023-08-30', '2023-08-01'),
	('2023-08-31', '2023-08-01'),
	('2023-09-01', '2023-09-01'),
	('2023-09-02', '2023-09-01'),
	('2023-09-03', '2023-09-01'),
	('2023-09-04', '2023-09-01'),
	('2023-09-05', '2023-09-01'),
	('2023-09-06', '2023-09-01'),
	('2023-09-07', '2023-09-01'),
	('2023-09-08', '2023-09-01'),
	('2023-09-09', '2023-09-01'),
	('2023-09-10', '2023-09-01'),
	('2023-09-11', '2023-09-01'),
	('2023-09-12', '2023-09-01'),
	('2023-09-13', '2023-09-01'),
	('2023-09-14', '2023-09-01'),
	('2023-09-15', '2023-09-01'),
	('2023-09-16', '2023-09-01'),
	('2023-09-17', '2023-09-01'),
	('2023-09-18', '2023-09-01'),
	('2023-09-19', '2023-09-01'),
	('2023-09-20', '2023-09-01'),
	('2023-09-21', '2023-09-01'),
	('2023-09-22', '2023-09-01'),
	('2023-09-23', '2023-09-01'),
	('2023-09-24', '2023-09-01'),
	('2023-09-25', '2023-09-01'),
	('2023-09-26', '2023-09-01'),
	('2023-09-27', '2023-09-01'),
	('2023-09-28', '2023-09-01'),
	('2023-09-29', '2023-09-01'),
	('2023-09-30', '2023-09-01'),
	('2023-10-01', '2023-10-01'),
	('2023-10-02', '2023-10-01'),
	('2023-10-03', '2023-10-01'),
	('2023-10-04', '2023-10-01'),
	('2023-10-05', '2023-10-01'),
	('2023-10-06', '2023-10-01'),
	('2023-10-07', '2023-10-01'),
	('2023-10-08', '2023-10-01'),
	('2023-10-09', '2023-10-01'),
	('2023-10-10', '2023-10-01'),
	('2023-10-11', '2023-10-01'),
	('2023-10-12', '2023-10-01'),
	('2023-10-13', '2023-10-01'),
	('2023-10-14', '2023-10-01'),
	('2023-10-15', '2023-10-01'),
	('2023-10-16', '2023-10-01'),
	('2023-10-17', '2023-10-01'),
	('2023-10-18', '2023-10-01'),
	('2023-10-19', '2023-10-01'),
	('2023-10-20', '2023-10-01'),
	('2023-10-21', '2023-10-01'),
	('2023-10-22', '2023-10-01'),
	('2023-10-23', '2023-10-01'),
	('2023-10-24', '2023-10-01'),
	('2023-10-25', '2023-10-01'),
	('2023-10-26', '2023-10-01'),
	('2023-10-27', '2023-10-01'),
	('2023-10-28', '2023-10-01'),
	('2023-10-29', '2023-10-01'),
	('2023-10-30', '2023-10-01'),
	('2023-10-31', '2023-10-01'),
	('2023-11-01', '2023-11-01'),
	('2023-11-02', '2023-11-01'),
	('2023-11-03', '2023-11-01'),
	('2023-11-04', '2023-11-01'),
	('2023-11-05', '2023-11-01'),
	('2023-11-06', '2023-11-01'),
	('2023-11-07', '2023-11-01'),
	('2023-11-08', '2023-11-01'),
	('2023-11-09', '2023-11-01'),
	('2023-11-10', '2023-11-01'),
	('2023-11-11', '2023-11-01'),
	('2023-11-12', '2023-11-01'),
	('2023-11-13', '2023-11-01'),
	('2023-11-14', '2023-11-01'),
	('2023-11-15', '2023-11-01'),
	('2023-11-16', '2023-11-01'),
	('2023-11-17', '2023-11-01'),
	('2023-11-18', '2023-11-01'),
	('2023-11-19', '2023-11-01'),
	('2023-11-20', '2023-11-01'),
	('2023-11-21', '2023-11-01'),
	('2023-11-22', '2023-11-01'),
	('2023-11-23', '2023-11-01'),
	('2023-11-24', '2023-11-01'),
	('2023-11-25', '2023-11-01'),
	('2023-11-26', '2023-11-01'),
	('2023-11-27', '2023-11-01'),
	('2023-11-28', '2023-11-01'),
	('2023-11-29', '2023-11-01'),
	('2023-11-30', '2023-11-01'),
	('2023-12-01', '2023-12-01'),
	('2023-12-02', '2023-12-01'),
	('2023-12-03', '2023-12-01'),
	('2023-12-04', '2023-12-01'),
	('2023-12-05', '2023-12-01'),
	('2023-12-06', '2023-12-01'),
	('2023-12-07', '2023-12-01'),
	('2023-12-08', '2023-12-01'),
	('2023-12-09', '2023-12-01'),
	('2023-12-10', '2023-12-01'),
	('2023-12-11', '2023-12-01'),
	('2023-12-12', '2023-12-01'),
	('2023-12-13', '2023-12-01'),
	('2023-12-14', '2023-12-01'),
	('2023-12-15', '2023-12-01'),
	('2023-12-16', '2023-12-01'),
	('2023-12-17', '2023-12-01'),
	('2023-12-18', '2023-12-01'),
	('2023-12-19', '2023-12-01'),
	('2023-12-20', '2023-12-01'),
	('2023-12-21', '2023-12-01'),
	('2023-12-22', '2023-12-01'),
	('2023-12-23', '2023-12-01'),
	('2023-12-24', '2023-12-01'),
	('2023-12-25', '2023-12-01'),
	('2023-12-26', '2023-12-01'),
	('2023-12-27', '2023-12-01'),
	('2023-12-28', '2023-12-01'),
	('2023-12-29', '2023-12-01'),
	('2023-12-30', '2023-12-01'),
	('2023-12-31', '2023-12-01'),
	('2024-01-01', '2024-01-01'),
	('2024-01-02', '2024-01-01'),
	('2024-01-03', '2024-01-01'),
	('2024-01-04', '2024-01-01'),
	('2024-01-05', '2024-01-01'),
	('2024-01-06', '2024-01-01'),
	('2024-01-07', '2024-01-01'),
	('2024-01-08', '2024-01-01'),
	('2024-01-09', '2024-01-01'),
	('2024-01-10', '2024-01-01'),
	('2024-01-11', '2024-01-01'),
	('2024-01-12', '2024-01-01'),
	('2024-01-13', '2024-01-01'),
	('2024-01-14', '2024-01-01'),
	('2024-01-15', '2024-01-01'),
	('2024-01-16', '2024-01-01'),
	('2024-01-17', '2024-01-01'),
	('2024-01-18', '2024-01-01'),
	('2024-01-19', '2024-01-01'),
	('2024-01-20', '2024-01-01'),
	('2024-01-21', '2024-01-01'),
	('2024-01-22', '2024-01-01'),
	('2024-01-23', '2024-01-01'),
	('2024-01-24', '2024-01-01'),
	('2024-01-25', '2024-01-01'),
	('2024-01-26', '2024-01-01'),
	('2024-01-27', '2024-01-01'),
	('2024-01-28', '2024-01-01'),
	('2024-01-29', '2024-01-01'),
	('2024-01-30', '2024-01-01'),
	('2024-01-31', '2024-01-01'),
	('2024-02-01', '2024-02-01'),
	('2024-02-02', '2024-02-01'),
	('2024-02-03', '2024-02-01'),
	('2024-02-04', '2024-02-01'),
	('2024-02-05', '2024-02-01'),
	('2024-02-06', '2024-02-01'),
	('2024-02-07', '2024-02-01'),
	('2024-02-08', '2024-02-01'),
	('2024-02-09', '2024-02-01'),
	('2024-02-10', '2024-02-01'),
	('2024-02-11', '2024-02-01'),
	('2024-02-12', '2024-02-01'),
	('2024-02-13', '2024-02-01'),
	('2024-02-14', '2024-02-01'),
	('2024-02-15', '2024-02-01'),
	('2024-02-16', '2024-02-01'),
	('2024-02-17', '2024-02-01'),
	('2024-02-18', '2024-02-01'),
	('2024-02-19', '2024-02-01'),
	('2024-02-20', '2024-02-01'),
	('2024-02-21', '2024-02-01'),
	('2024-02-22', '2024-02-01'),
	('2024-02-23', '2024-02-01'),
	('2024-02-24', '2024-02-01'),
	('2024-02-25', '2024-02-01'),
	('2024-02-26', '2024-02-01'),
	('2024-02-27', '2024-02-01'),
	('2024-02-28', '2024-02-01'),
	('2024-02-29', '2024-02-01'),
	('2024-03-01', '2024-03-01'),
	('2024-03-02', '2024-03-01'),
	('2024-03-03', '2024-03-01'),
	('2024-03-04', '2024-03-01'),
	('2024-03-05', '2024-03-01'),
	('2024-03-06', '2024-03-01'),
	('2024-03-07', '2024-03-01'),
	('2024-03-08', '2024-03-01'),
	('2024-03-09', '2024-03-01'),
	('2024-03-10', '2024-03-01'),
	('2024-03-11', '2024-03-01'),
	('2024-03-12', '2024-03-01'),
	('2024-03-13', '2024-03-01'),
	('2024-03-14', '2024-03-01'),
	('2024-03-15', '2024-03-01'),
	('2024-03-16', '2024-03-01'),
	('2024-03-17', '2024-03-01'),
	('2024-03-18', '2024-03-01'),
	('2024-03-19', '2024-03-01'),
	('2024-03-20', '2024-03-01'),
	('2024-03-21', '2024-03-01'),
	('2024-03-22', '2024-03-01'),
	('2024-03-23', '2024-03-01'),
	('2024-03-24', '2024-03-01'),
	('2024-03-25', '2024-03-01'),
	('2024-03-26', '2024-03-01'),
	('2024-03-27', '2024-03-01'),
	('2024-03-28', '2024-03-01'),
	('2024-03-29', '2024-03-01'),
	('2024-03-30', '2024-03-01'),
	('2024-03-31', '2024-03-01'),
	('2024-04-01', '2024-04-01'),
	('2024-04-02', '2024-04-01'),
	('2024-04-03', '2024-04-01'),
	('2024-04-04', '2024-04-01'),
	('2024-04-05', '2024-04-01'),
	('2024-04-06', '2024-04-01'),
	('2024-04-07', '2024-04-01'),
	('2024-04-08', '2024-04-01'),
	('2024-04-09', '2024-04-01'),
	('2024-04-10', '2024-04-01'),
	('2024-04-11', '2024-04-01'),
	('2024-04-12', '2024-04-01'),
	('2024-04-13', '2024-04-01'),
	('2024-04-14', '2024-04-01'),
	('2024-04-15', '2024-04-01'),
	('2024-04-16', '2024-04-01'),
	('2024-04-17', '2024-04-01'),
	('2024-04-18', '2024-04-01'),
	('2024-04-19', '2024-04-01'),
	('2024-04-20', '2024-04-01'),
	('2024-04-21', '2024-04-01'),
	('2024-04-22', '2024-04-01'),
	('2024-04-23', '2024-04-01'),
	('2024-04-24', '2024-04-01'),
	('2024-04-25', '2024-04-01'),
	('2024-04-26', '2024-04-01'),
	('2024-04-27', '2024-04-01'),
	('2024-04-28', '2024-04-01'),
	('2024-04-29', '2024-04-01'),
	('2024-04-30', '2024-04-01'),
	('2024-05-01', '2024-05-01'),
	('2024-05-02', '2024-05-01'),
	('2024-05-03', '2024-05-01'),
	('2024-05-04', '2024-05-01'),
	('2024-05-05', '2024-05-01'),
	('2024-05-06', '2024-05-01'),
	('2024-05-07', '2024-05-01'),
	('2024-05-08', '2024-05-01'),
	('2024-05-09', '2024-05-01'),
	('2024-05-10', '2024-05-01'),
	('2024-05-11', '2024-05-01'),
	('2024-05-12', '2024-05-01'),
	('2024-05-13', '2024-05-01'),
	('2024-05-14', '2024-05-01'),
	('2024-05-15', '2024-05-01'),
	('2024-05-16', '2024-05-01'),
	('2024-05-17', '2024-05-01'),
	('2024-05-18', '2024-05-01'),
	('2024-05-19', '2024-05-01'),
	('2024-05-20', '2024-05-01'),
	('2024-05-21', '2024-05-01'),
	('2024-05-22', '2024-05-01'),
	('2024-05-23', '2024-05-01'),
	('2024-05-24', '2024-05-01'),
	('2024-05-25', '2024-05-01'),
	('2024-05-26', '2024-05-01'),
	('2024-05-27', '2024-05-01'),
	('2024-05-28', '2024-05-01'),
	('2024-05-29', '2024-05-01'),
	('2024-05-30', '2024-05-01'),
	('2024-05-31', '2024-05-01'),
	('2024-06-01', '2024-06-01'),
	('2024-06-02', '2024-06-01'),
	('2024-06-03', '2024-06-01'),
	('2024-06-04', '2024-06-01'),
	('2024-06-05', '2024-06-01'),
	('2024-06-06', '2024-06-01'),
	('2024-06-07', '2024-06-01'),
	('2024-06-08', '2024-06-01'),
	('2024-06-09', '2024-06-01'),
	('2024-06-10', '2024-06-01'),
	('2024-06-11', '2024-06-01'),
	('2024-06-12', '2024-06-01'),
	('2024-06-13', '2024-06-01'),
	('2024-06-14', '2024-06-01'),
	('2024-06-15', '2024-06-01'),
	('2024-06-16', '2024-06-01'),
	('2024-06-17', '2024-06-01'),
	('2024-06-18', '2024-06-01'),
	('2024-06-19', '2024-06-01'),
	('2024-06-20', '2024-06-01'),
	('2024-06-21', '2024-06-01'),
	('2024-06-22', '2024-06-01'),
	('2024-06-23', '2024-06-01'),
	('2024-06-24', '2024-06-01'),
	('2024-06-25', '2024-06-01'),
	('2024-06-26', '2024-06-01'),
	('2024-06-27', '2024-06-01'),
	('2024-06-28', '2024-06-01'),
	('2024-06-29', '2024-06-01'),
	('2024-06-30', '2024-06-01'),
	('2024-07-01', '2024-07-01'),
	('2024-07-02', '2024-07-01'),
	('2024-07-03', '2024-07-01'),
	('2024-07-04', '2024-07-01'),
	('2024-07-05', '2024-07-01'),
	('2024-07-06', '2024-07-01'),
	('2024-07-07', '2024-07-01'),
	('2024-07-08', '2024-07-01'),
	('2024-07-09', '2024-07-01'),
	('2024-07-10', '2024-07-01'),
	('2024-07-11', '2024-07-01'),
	('2024-07-12', '2024-07-01'),
	('2024-07-13', '2024-07-01'),
	('2024-07-14', '2024-07-01'),
	('2024-07-15', '2024-07-01'),
	('2024-07-16', '2024-07-01'),
	('2024-07-17', '2024-07-01'),
	('2024-07-18', '2024-07-01'),
	('2024-07-19', '2024-07-01'),
	('2024-07-20', '2024-07-01'),
	('2024-07-21', '2024-07-01'),
	('2024-07-22', '2024-07-01'),
	('2024-07-23', '2024-07-01'),
	('2024-07-24', '2024-07-01'),
	('2024-07-25', '2024-07-01'),
	('2024-07-26', '2024-07-01'),
	('2024-07-27', '2024-07-01'),
	('2024-07-28', '2024-07-01'),
	('2024-07-29', '2024-07-01'),
	('2024-07-30', '2024-07-01'),
	('2024-07-31', '2024-07-01'),
	('2024-08-01', '2024-08-01'),
	('2024-08-02', '2024-08-01'),
	('2024-08-03', '2024-08-01'),
	('2024-08-04', '2024-08-01'),
	('2024-08-05', '2024-08-01'),
	('2024-08-06', '2024-08-01'),
	('2024-08-07', '2024-08-01'),
	('2024-08-08', '2024-08-01'),
	('2024-08-09', '2024-08-01'),
	('2024-08-10', '2024-08-01'),
	('2024-08-11', '2024-08-01'),
	('2024-08-12', '2024-08-01'),
	('2024-08-13', '2024-08-01'),
	('2024-08-14', '2024-08-01'),
	('2024-08-15', '2024-08-01'),
	('2024-08-16', '2024-08-01'),
	('2024-08-17', '2024-08-01'),
	('2024-08-18', '2024-08-01'),
	('2024-08-19', '2024-08-01'),
	('2024-08-20', '2024-08-01'),
	('2024-08-21', '2024-08-01'),
	('2024-08-22', '2024-08-01'),
	('2024-08-23', '2024-08-01'),
	('2024-08-24', '2024-08-01'),
	('2024-08-25', '2024-08-01'),
	('2024-08-26', '2024-08-01'),
	('2024-08-27', '2024-08-01'),
	('2024-08-28', '2024-08-01'),
	('2024-08-29', '2024-08-01'),
	('2024-08-30', '2024-08-01'),
	('2024-08-31', '2024-08-01'),
	('2024-09-01', '2024-09-01'),
	('2024-09-02', '2024-09-01'),
	('2024-09-03', '2024-09-01'),
	('2024-09-04', '2024-09-01'),
	('2024-09-05', '2024-09-01'),
	('2024-09-06', '2024-09-01'),
	('2024-09-07', '2024-09-01'),
	('2024-09-08', '2024-09-01'),
	('2024-09-09', '2024-09-01'),
	('2024-09-10', '2024-09-01'),
	('2024-09-11', '2024-09-01'),
	('2024-09-12', '2024-09-01'),
	('2024-09-13', '2024-09-01'),
	('2024-09-14', '2024-09-01'),
	('2024-09-15', '2024-09-01'),
	('2024-09-16', '2024-09-01'),
	('2024-09-17', '2024-09-01'),
	('2024-09-18', '2024-09-01'),
	('2024-09-19', '2024-09-01'),
	('2024-09-20', '2024-09-01'),
	('2024-09-21', '2024-09-01'),
	('2024-09-22', '2024-09-01'),
	('2024-09-23', '2024-09-01'),
	('2024-09-24', '2024-09-01'),
	('2024-09-25', '2024-09-01'),
	('2024-09-26', '2024-09-01'),
	('2024-09-27', '2024-09-01'),
	('2024-09-28', '2024-09-01'),
	('2024-09-29', '2024-09-01'),
	('2024-09-30', '2024-09-01'),
	('2024-10-01', '2024-10-01'),
	('2024-10-02', '2024-10-01'),
	('2024-10-03', '2024-10-01'),
	('2024-10-04', '2024-10-01'),
	('2024-10-05', '2024-10-01'),
	('2024-10-06', '2024-10-01'),
	('2024-10-07', '2024-10-01'),
	('2024-10-08', '2024-10-01'),
	('2024-10-09', '2024-10-01'),
	('2024-10-10', '2024-10-01'),
	('2024-10-11', '2024-10-01'),
	('2024-10-12', '2024-10-01'),
	('2024-10-13', '2024-10-01'),
	('2024-10-14', '2024-10-01'),
	('2024-10-15', '2024-10-01'),
	('2024-10-16', '2024-10-01'),
	('2024-10-17', '2024-10-01'),
	('2024-10-18', '2024-10-01'),
	('2024-10-19', '2024-10-01'),
	('2024-10-20', '2024-10-01'),
	('2024-10-21', '2024-10-01'),
	('2024-10-22', '2024-10-01'),
	('2024-10-23', '2024-10-01'),
	('2024-10-24', '2024-10-01'),
	('2024-10-25', '2024-10-01'),
	('2024-10-26', '2024-10-01'),
	('2024-10-27', '2024-10-01'),
	('2024-10-28', '2024-10-01'),
	('2024-10-29', '2024-10-01'),
	('2024-10-30', '2024-10-01'),
	('2024-10-31', '2024-10-01'),
	('2024-11-01', '2024-11-01'),
	('2024-11-02', '2024-11-01'),
	('2024-11-03', '2024-11-01'),
	('2024-11-04', '2024-11-01'),
	('2024-11-05', '2024-11-01'),
	('2024-11-06', '2024-11-01'),
	('2024-11-07', '2024-11-01'),
	('2024-11-08', '2024-11-01'),
	('2024-11-09', '2024-11-01'),
	('2024-11-10', '2024-11-01'),
	('2024-11-11', '2024-11-01'),
	('2024-11-12', '2024-11-01'),
	('2024-11-13', '2024-11-01'),
	('2024-11-14', '2024-11-01'),
	('2024-11-15', '2024-11-01'),
	('2024-11-16', '2024-11-01'),
	('2024-11-17', '2024-11-01'),
	('2024-11-18', '2024-11-01'),
	('2024-11-19', '2024-11-01'),
	('2024-11-20', '2024-11-01'),
	('2024-11-21', '2024-11-01'),
	('2024-11-22', '2024-11-01'),
	('2024-11-23', '2024-11-01'),
	('2024-11-24', '2024-11-01'),
	('2024-11-25', '2024-11-01'),
	('2024-11-26', '2024-11-01'),
	('2024-11-27', '2024-11-01'),
	('2024-11-28', '2024-11-01'),
	('2024-11-29', '2024-11-01'),
	('2024-11-30', '2024-11-01'),
	('2024-12-01', '2024-12-01'),
	('2024-12-02', '2024-12-01'),
	('2024-12-03', '2024-12-01'),
	('2024-12-04', '2024-12-01'),
	('2024-12-05', '2024-12-01'),
	('2024-12-06', '2024-12-01'),
	('2024-12-07', '2024-12-01'),
	('2024-12-08', '2024-12-01'),
	('2024-12-09', '2024-12-01'),
	('2024-12-10', '2024-12-01'),
	('2024-12-11', '2024-12-01'),
	('2024-12-12', '2024-12-01'),
	('2024-12-13', '2024-12-01'),
	('2024-12-14', '2024-12-01'),
	('2024-12-15', '2024-12-01'),
	('2024-12-16', '2024-12-01'),
	('2024-12-17', '2024-12-01'),
	('2024-12-18', '2024-12-01'),
	('2024-12-19', '2024-12-01'),
	('2024-12-20', '2024-12-01'),
	('2024-12-21', '2024-12-01'),
	('2024-12-22', '2024-12-01'),
	('2024-12-23', '2024-12-01'),
	('2024-12-24', '2024-12-01'),
	('2024-12-25', '2024-12-01'),
	('2024-12-26', '2024-12-01'),
	('2024-12-27', '2024-12-01'),
	('2024-12-28', '2024-12-01'),
	('2024-12-29', '2024-12-01'),
	('2024-12-30', '2024-12-01'),
	('2024-12-31', '2024-12-01'),
	('2025-01-01', '2025-01-01'),
	('2025-01-02', '2025-01-01'),
	('2025-01-03', '2025-01-01'),
	('2025-01-04', '2025-01-01'),
	('2025-01-05', '2025-01-01'),
	('2025-01-06', '2025-01-01'),
	('2025-01-07', '2025-01-01'),
	('2025-01-08', '2025-01-01'),
	('2025-01-09', '2025-01-01'),
	('2025-01-10', '2025-01-01'),
	('2025-01-11', '2025-01-01'),
	('2025-01-12', '2025-01-01'),
	('2025-01-13', '2025-01-01'),
	('2025-01-14', '2025-01-01'),
	('2025-01-15', '2025-01-01'),
	('2025-01-16', '2025-01-01'),
	('2025-01-17', '2025-01-01'),
	('2025-01-18', '2025-01-01'),
	('2025-01-19', '2025-01-01'),
	('2025-01-20', '2025-01-01'),
	('2025-01-21', '2025-01-01'),
	('2025-01-22', '2025-01-01'),
	('2025-01-23', '2025-01-01'),
	('2025-01-24', '2025-01-01'),
	('2025-01-25', '2025-01-01'),
	('2025-01-26', '2025-01-01'),
	('2025-01-27', '2025-01-01'),
	('2025-01-28', '2025-01-01'),
	('2025-01-29', '2025-01-01'),
	('2025-01-30', '2025-01-01'),
	('2025-01-31', '2025-01-01'),
	('2025-02-01', '2025-02-01'),
	('2025-02-02', '2025-02-01'),
	('2025-02-03', '2025-02-01'),
	('2025-02-04', '2025-02-01'),
	('2025-02-05', '2025-02-01'),
	('2025-02-06', '2025-02-01'),
	('2025-02-07', '2025-02-01'),
	('2025-02-08', '2025-02-01'),
	('2025-02-09', '2025-02-01'),
	('2025-02-10', '2025-02-01'),
	('2025-02-11', '2025-02-01'),
	('2025-02-12', '2025-02-01'),
	('2025-02-13', '2025-02-01'),
	('2025-02-14', '2025-02-01'),
	('2025-02-15', '2025-02-01'),
	('2025-02-16', '2025-02-01'),
	('2025-02-17', '2025-02-01'),
	('2025-02-18', '2025-02-01'),
	('2025-02-19', '2025-02-01'),
	('2025-02-20', '2025-02-01'),
	('2025-02-21', '2025-02-01'),
	('2025-02-22', '2025-02-01'),
	('2025-02-23', '2025-02-01'),
	('2025-02-24', '2025-02-01'),
	('2025-02-25', '2025-02-01'),
	('2025-02-26', '2025-02-01'),
	('2025-02-27', '2025-02-01'),
	('2025-02-28', '2025-02-01'),
	('2025-03-01', '2025-03-01'),
	('2025-03-02', '2025-03-01'),
	('2025-03-03', '2025-03-01'),
	('2025-03-04', '2025-03-01'),
	('2025-03-05', '2025-03-01'),
	('2025-03-06', '2025-03-01'),
	('2025-03-07', '2025-03-01'),
	('2025-03-08', '2025-03-01'),
	('2025-03-09', '2025-03-01'),
	('2025-03-10', '2025-03-01'),
	('2025-03-11', '2025-03-01'),
	('2025-03-12', '2025-03-01'),
	('2025-03-13', '2025-03-01'),
	('2025-03-14', '2025-03-01'),
	('2025-03-15', '2025-03-01'),
	('2025-03-16', '2025-03-01'),
	('2025-03-17', '2025-03-01'),
	('2025-03-18', '2025-03-01'),
	('2025-03-19', '2025-03-01'),
	('2025-03-20', '2025-03-01'),
	('2025-03-21', '2025-03-01'),
	('2025-03-22', '2025-03-01'),
	('2025-03-23', '2025-03-01'),
	('2025-03-24', '2025-03-01'),
	('2025-03-25', '2025-03-01'),
	('2025-03-26', '2025-03-01'),
	('2025-03-27', '2025-03-01'),
	('2025-03-28', '2025-03-01'),
	('2025-03-29', '2025-03-01'),
	('2025-03-30', '2025-03-01'),
	('2025-03-31', '2025-03-01'),
	('2025-04-01', '2025-04-01'),
	('2025-04-02', '2025-04-01'),
	('2025-04-03', '2025-04-01'),
	('2025-04-04', '2025-04-01'),
	('2025-04-05', '2025-04-01'),
	('2025-04-06', '2025-04-01'),
	('2025-04-07', '2025-04-01'),
	('2025-04-08', '2025-04-01'),
	('2025-04-09', '2025-04-01'),
	('2025-04-10', '2025-04-01'),
	('2025-04-11', '2025-04-01'),
	('2025-04-12', '2025-04-01'),
	('2025-04-13', '2025-04-01'),
	('2025-04-14', '2025-04-01'),
	('2025-04-15', '2025-04-01'),
	('2025-04-16', '2025-04-01'),
	('2025-04-17', '2025-04-01'),
	('2025-04-18', '2025-04-01'),
	('2025-04-19', '2025-04-01'),
	('2025-04-20', '2025-04-01'),
	('2025-04-21', '2025-04-01'),
	('2025-04-22', '2025-04-01'),
	('2025-04-23', '2025-04-01'),
	('2025-04-24', '2025-04-01'),
	('2025-04-25', '2025-04-01'),
	('2025-04-26', '2025-04-01'),
	('2025-04-27', '2025-04-01'),
	('2025-04-28', '2025-04-01'),
	('2025-04-29', '2025-04-01'),
	('2025-04-30', '2025-04-01'),
	('2025-05-01', '2025-05-01'),
	('2025-05-02', '2025-05-01'),
	('2025-05-03', '2025-05-01'),
	('2025-05-04', '2025-05-01'),
	('2025-05-05', '2025-05-01'),
	('2025-05-06', '2025-05-01'),
	('2025-05-07', '2025-05-01'),
	('2025-05-08', '2025-05-01'),
	('2025-05-09', '2025-05-01'),
	('2025-05-10', '2025-05-01'),
	('2025-05-11', '2025-05-01'),
	('2025-05-12', '2025-05-01'),
	('2025-05-13', '2025-05-01'),
	('2025-05-14', '2025-05-01'),
	('2025-05-15', '2025-05-01'),
	('2025-05-16', '2025-05-01'),
	('2025-05-17', '2025-05-01'),
	('2025-05-18', '2025-05-01'),
	('2025-05-19', '2025-05-01'),
	('2025-05-20', '2025-05-01'),
	('2025-05-21', '2025-05-01'),
	('2025-05-22', '2025-05-01'),
	('2025-05-23', '2025-05-01'),
	('2025-05-24', '2025-05-01'),
	('2025-05-25', '2025-05-01'),
	('2025-05-26', '2025-05-01'),
	('2025-05-27', '2025-05-01'),
	('2025-05-28', '2025-05-01'),
	('2025-05-29', '2025-05-01'),
	('2025-05-30', '2025-05-01'),
	('2025-05-31', '2025-05-01'),
	('2025-06-01', '2025-06-01'),
	('2025-06-02', '2025-06-01'),
	('2025-06-03', '2025-06-01'),
	('2025-06-04', '2025-06-01'),
	('2025-06-05', '2025-06-01'),
	('2025-06-06', '2025-06-01'),
	('2025-06-07', '2025-06-01'),
	('2025-06-08', '2025-06-01'),
	('2025-06-09', '2025-06-01'),
	('2025-06-10', '2025-06-01'),
	('2025-06-11', '2025-06-01'),
	('2025-06-12', '2025-06-01'),
	('2025-06-13', '2025-06-01'),
	('2025-06-14', '2025-06-01'),
	('2025-06-15', '2025-06-01'),
	('2025-06-16', '2025-06-01'),
	('2025-06-17', '2025-06-01'),
	('2025-06-18', '2025-06-01'),
	('2025-06-19', '2025-06-01'),
	('2025-06-20', '2025-06-01'),
	('2025-06-21', '2025-06-01'),
	('2025-06-22', '2025-06-01'),
	('2025-06-23', '2025-06-01'),
	('2025-06-24', '2025-06-01'),
	('2025-06-25', '2025-06-01'),
	('2025-06-26', '2025-06-01'),
	('2025-06-27', '2025-06-01'),
	('2025-06-28', '2025-06-01'),
	('2025-06-29', '2025-06-01'),
	('2025-06-30', '2025-06-01'),
	('2025-07-01', '2025-07-01'),
	('2025-07-02', '2025-07-01'),
	('2025-07-03', '2025-07-01'),
	('2025-07-04', '2025-07-01'),
	('2025-07-05', '2025-07-01'),
	('2025-07-06', '2025-07-01'),
	('2025-07-07', '2025-07-01'),
	('2025-07-08', '2025-07-01'),
	('2025-07-09', '2025-07-01'),
	('2025-07-10', '2025-07-01'),
	('2025-07-11', '2025-07-01'),
	('2025-07-12', '2025-07-01'),
	('2025-07-13', '2025-07-01'),
	('2025-07-14', '2025-07-01'),
	('2025-07-15', '2025-07-01'),
	('2025-07-16', '2025-07-01'),
	('2025-07-17', '2025-07-01'),
	('2025-07-18', '2025-07-01'),
	('2025-07-19', '2025-07-01'),
	('2025-07-20', '2025-07-01'),
	('2025-07-21', '2025-07-01'),
	('2025-07-22', '2025-07-01'),
	('2025-07-23', '2025-07-01'),
	('2025-07-24', '2025-07-01'),
	('2025-07-25', '2025-07-01'),
	('2025-07-26', '2025-07-01'),
	('2025-07-27', '2025-07-01'),
	('2025-07-28', '2025-07-01'),
	('2025-07-29', '2025-07-01'),
	('2025-07-30', '2025-07-01'),
	('2025-07-31', '2025-07-01'),
	('2025-08-01', '2025-08-01'),
	('2025-08-02', '2025-08-01'),
	('2025-08-03', '2025-08-01'),
	('2025-08-04', '2025-08-01'),
	('2025-08-05', '2025-08-01'),
	('2025-08-06', '2025-08-01'),
	('2025-08-07', '2025-08-01'),
	('2025-08-08', '2025-08-01'),
	('2025-08-09', '2025-08-01'),
	('2025-08-10', '2025-08-01'),
	('2025-08-11', '2025-08-01'),
	('2025-08-12', '2025-08-01'),
	('2025-08-13', '2025-08-01'),
	('2025-08-14', '2025-08-01'),
	('2025-08-15', '2025-08-01'),
	('2025-08-16', '2025-08-01'),
	('2025-08-17', '2025-08-01'),
	('2025-08-18', '2025-08-01'),
	('2025-08-19', '2025-08-01'),
	('2025-08-20', '2025-08-01'),
	('2025-08-21', '2025-08-01'),
	('2025-08-22', '2025-08-01'),
	('2025-08-23', '2025-08-01'),
	('2025-08-24', '2025-08-01'),
	('2025-08-25', '2025-08-01'),
	('2025-08-26', '2025-08-01'),
	('2025-08-27', '2025-08-01'),
	('2025-08-28', '2025-08-01'),
	('2025-08-29', '2025-08-01'),
	('2025-08-30', '2025-08-01'),
	('2025-08-31', '2025-08-01'),
	('2025-09-01', '2025-09-01'),
	('2025-09-02', '2025-09-01'),
	('2025-09-03', '2025-09-01'),
	('2025-09-04', '2025-09-01'),
	('2025-09-05', '2025-09-01'),
	('2025-09-06', '2025-09-01'),
	('2025-09-07', '2025-09-01'),
	('2025-09-08', '2025-09-01'),
	('2025-09-09', '2025-09-01'),
	('2025-09-10', '2025-09-01'),
	('2025-09-11', '2025-09-01'),
	('2025-09-12', '2025-09-01'),
	('2025-09-13', '2025-09-01'),
	('2025-09-14', '2025-09-01'),
	('2025-09-15', '2025-09-01'),
	('2025-09-16', '2025-09-01'),
	('2025-09-17', '2025-09-01'),
	('2025-09-18', '2025-09-01'),
	('2025-09-19', '2025-09-01'),
	('2025-09-20', '2025-09-01'),
	('2025-09-21', '2025-09-01'),
	('2025-09-22', '2025-09-01'),
	('2025-09-23', '2025-09-01'),
	('2025-09-24', '2025-09-01'),
	('2025-09-25', '2025-09-01'),
	('2025-09-26', '2025-09-01'),
	('2025-09-27', '2025-09-01'),
	('2025-09-28', '2025-09-01'),
	('2025-09-29', '2025-09-01'),
	('2025-09-30', '2025-09-01'),
	('2025-10-01', '2025-10-01'),
	('2025-10-02', '2025-10-01'),
	('2025-10-03', '2025-10-01'),
	('2025-10-04', '2025-10-01'),
	('2025-10-05', '2025-10-01'),
	('2025-10-06', '2025-10-01'),
	('2025-10-07', '2025-10-01'),
	('2025-10-08', '2025-10-01'),
	('2025-10-09', '2025-10-01'),
	('2025-10-10', '2025-10-01'),
	('2025-10-11', '2025-10-01'),
	('2025-10-12', '2025-10-01'),
	('2025-10-13', '2025-10-01'),
	('2025-10-14', '2025-10-01'),
	('2025-10-15', '2025-10-01'),
	('2025-10-16', '2025-10-01'),
	('2025-10-17', '2025-10-01'),
	('2025-10-18', '2025-10-01'),
	('2025-10-19', '2025-10-01'),
	('2025-10-20', '2025-10-01'),
	('2025-10-21', '2025-10-01'),
	('2025-10-22', '2025-10-01'),
	('2025-10-23', '2025-10-01'),
	('2025-10-24', '2025-10-01'),
	('2025-10-25', '2025-10-01'),
	('2025-10-26', '2025-10-01'),
	('2025-10-27', '2025-10-01'),
	('2025-10-28', '2025-10-01'),
	('2025-10-29', '2025-10-01'),
	('2025-10-30', '2025-10-01'),
	('2025-10-31', '2025-10-01'),
	('2025-11-01', '2025-11-01'),
	('2025-11-02', '2025-11-01'),
	('2025-11-03', '2025-11-01'),
	('2025-11-04', '2025-11-01'),
	('2025-11-05', '2025-11-01'),
	('2025-11-06', '2025-11-01'),
	('2025-11-07', '2025-11-01'),
	('2025-11-08', '2025-11-01'),
	('2025-11-09', '2025-11-01'),
	('2025-11-10', '2025-11-01'),
	('2025-11-11', '2025-11-01'),
	('2025-11-12', '2025-11-01'),
	('2025-11-13', '2025-11-01'),
	('2025-11-14', '2025-11-01'),
	('2025-11-15', '2025-11-01'),
	('2025-11-16', '2025-11-01'),
	('2025-11-17', '2025-11-01'),
	('2025-11-18', '2025-11-01'),
	('2025-11-19', '2025-11-01'),
	('2025-11-20', '2025-11-01'),
	('2025-11-21', '2025-11-01'),
	('2025-11-22', '2025-11-01'),
	('2025-11-23', '2025-11-01'),
	('2025-11-24', '2025-11-01'),
	('2025-11-25', '2025-11-01'),
	('2025-11-26', '2025-11-01'),
	('2025-11-27', '2025-11-01'),
	('2025-11-28', '2025-11-01'),
	('2025-11-29', '2025-11-01'),
	('2025-11-30', '2025-11-01'),
	('2025-12-01', '2025-12-01'),
	('2025-12-02', '2025-12-01'),
	('2025-12-03', '2025-12-01'),
	('2025-12-04', '2025-12-01'),
	('2025-12-05', '2025-12-01'),
	('2025-12-06', '2025-12-01'),
	('2025-12-07', '2025-12-01'),
	('2025-12-08', '2025-12-01'),
	('2025-12-09', '2025-12-01'),
	('2025-12-10', '2025-12-01'),
	('2025-12-11', '2025-12-01'),
	('2025-12-12', '2025-12-01'),
	('2025-12-13', '2025-12-01'),
	('2025-12-14', '2025-12-01'),
	('2025-12-15', '2025-12-01'),
	('2025-12-16', '2025-12-01'),
	('2025-12-17', '2025-12-01'),
	('2025-12-18', '2025-12-01'),
	('2025-12-19', '2025-12-01'),
	('2025-12-20', '2025-12-01'),
	('2025-12-21', '2025-12-01'),
	('2025-12-22', '2025-12-01'),
	('2025-12-23', '2025-12-01'),
	('2025-12-24', '2025-12-01'),
	('2025-12-25', '2025-12-01'),
	('2025-12-26', '2025-12-01'),
	('2025-12-27', '2025-12-01'),
	('2025-12-28', '2025-12-01'),
	('2025-12-29', '2025-12-01'),
	('2025-12-30', '2025-12-01'),
	('2025-12-31', '2025-12-01'),
	('2026-01-01', '2026-01-01'),
	('2026-01-02', '2026-01-01'),
	('2026-01-03', '2026-01-01'),
	('2026-01-04', '2026-01-01'),
	('2026-01-05', '2026-01-01'),
	('2026-01-06', '2026-01-01'),
	('2026-01-07', '2026-01-01'),
	('2026-01-08', '2026-01-01'),
	('2026-01-09', '2026-01-01'),
	('2026-01-10', '2026-01-01'),
	('2026-01-11', '2026-01-01'),
	('2026-01-12', '2026-01-01'),
	('2026-01-13', '2026-01-01'),
	('2026-01-14', '2026-01-01'),
	('2026-01-15', '2026-01-01'),
	('2026-01-16', '2026-01-01'),
	('2026-01-17', '2026-01-01'),
	('2026-01-18', '2026-01-01'),
	('2026-01-19', '2026-01-01'),
	('2026-01-20', '2026-01-01'),
	('2026-01-21', '2026-01-01'),
	('2026-01-22', '2026-01-01'),
	('2026-01-23', '2026-01-01'),
	('2026-01-24', '2026-01-01'),
	('2026-01-25', '2026-01-01'),
	('2026-01-26', '2026-01-01'),
	('2026-01-27', '2026-01-01'),
	('2026-01-28', '2026-01-01'),
	('2026-01-29', '2026-01-01'),
	('2026-01-30', '2026-01-01'),
	('2026-01-31', '2026-01-01'),
	('2026-02-01', '2026-02-01'),
	('2026-02-02', '2026-02-01'),
	('2026-02-03', '2026-02-01'),
	('2026-02-04', '2026-02-01'),
	('2026-02-05', '2026-02-01'),
	('2026-02-06', '2026-02-01'),
	('2026-02-07', '2026-02-01'),
	('2026-02-08', '2026-02-01'),
	('2026-02-09', '2026-02-01'),
	('2026-02-10', '2026-02-01'),
	('2026-02-11', '2026-02-01'),
	('2026-02-12', '2026-02-01'),
	('2026-02-13', '2026-02-01'),
	('2026-02-14', '2026-02-01'),
	('2026-02-15', '2026-02-01'),
	('2026-02-16', '2026-02-01'),
	('2026-02-17', '2026-02-01'),
	('2026-02-18', '2026-02-01'),
	('2026-02-19', '2026-02-01'),
	('2026-02-20', '2026-02-01'),
	('2026-02-21', '2026-02-01'),
	('2026-02-22', '2026-02-01'),
	('2026-02-23', '2026-02-01'),
	('2026-02-24', '2026-02-01'),
	('2026-02-25', '2026-02-01'),
	('2026-02-26', '2026-02-01'),
	('2026-02-27', '2026-02-01'),
	('2026-02-28', '2026-02-01'),
	('2026-03-01', '2026-03-01'),
	('2026-03-02', '2026-03-01'),
	('2026-03-03', '2026-03-01'),
	('2026-03-04', '2026-03-01'),
	('2026-03-05', '2026-03-01'),
	('2026-03-06', '2026-03-01'),
	('2026-03-07', '2026-03-01'),
	('2026-03-08', '2026-03-01'),
	('2026-03-09', '2026-03-01'),
	('2026-03-10', '2026-03-01'),
	('2026-03-11', '2026-03-01'),
	('2026-03-12', '2026-03-01'),
	('2026-03-13', '2026-03-01'),
	('2026-03-14', '2026-03-01'),
	('2026-03-15', '2026-03-01'),
	('2026-03-16', '2026-03-01'),
	('2026-03-17', '2026-03-01'),
	('2026-03-18', '2026-03-01'),
	('2026-03-19', '2026-03-01'),
	('2026-03-20', '2026-03-01'),
	('2026-03-21', '2026-03-01'),
	('2026-03-22', '2026-03-01'),
	('2026-03-23', '2026-03-01'),
	('2026-03-24', '2026-03-01'),
	('2026-03-25', '2026-03-01'),
	('2026-03-26', '2026-03-01'),
	('2026-03-27', '2026-03-01'),
	('2026-03-28', '2026-03-01'),
	('2026-03-29', '2026-03-01'),
	('2026-03-30', '2026-03-01'),
	('2026-03-31', '2026-03-01'),
	('2026-04-01', '2026-04-01'),
	('2026-04-02', '2026-04-01'),
	('2026-04-03', '2026-04-01'),
	('2026-04-04', '2026-04-01'),
	('2026-04-05', '2026-04-01'),
	('2026-04-06', '2026-04-01'),
	('2026-04-07', '2026-04-01'),
	('2026-04-08', '2026-04-01'),
	('2026-04-09', '2026-04-01'),
	('2026-04-10', '2026-04-01'),
	('2026-04-11', '2026-04-01'),
	('2026-04-12', '2026-04-01'),
	('2026-04-13', '2026-04-01'),
	('2026-04-14', '2026-04-01'),
	('2026-04-15', '2026-04-01'),
	('2026-04-16', '2026-04-01'),
	('2026-04-17', '2026-04-01'),
	('2026-04-18', '2026-04-01'),
	('2026-04-19', '2026-04-01'),
	('2026-04-20', '2026-04-01'),
	('2026-04-21', '2026-04-01'),
	('2026-04-22', '2026-04-01'),
	('2026-04-23', '2026-04-01'),
	('2026-04-24', '2026-04-01'),
	('2026-04-25', '2026-04-01'),
	('2026-04-26', '2026-04-01'),
	('2026-04-27', '2026-04-01'),
	('2026-04-28', '2026-04-01'),
	('2026-04-29', '2026-04-01'),
	('2026-04-30', '2026-04-01'),
	('2026-05-01', '2026-05-01'),
	('2026-05-02', '2026-05-01'),
	('2026-05-03', '2026-05-01'),
	('2026-05-04', '2026-05-01'),
	('2026-05-05', '2026-05-01'),
	('2026-05-06', '2026-05-01'),
	('2026-05-07', '2026-05-01'),
	('2026-05-08', '2026-05-01'),
	('2026-05-09', '2026-05-01'),
	('2026-05-10', '2026-05-01'),
	('2026-05-11', '2026-05-01'),
	('2026-05-12', '2026-05-01'),
	('2026-05-13', '2026-05-01'),
	('2026-05-14', '2026-05-01'),
	('2026-05-15', '2026-05-01'),
	('2026-05-16', '2026-05-01'),
	('2026-05-17', '2026-05-01'),
	('2026-05-18', '2026-05-01'),
	('2026-05-19', '2026-05-01'),
	('2026-05-20', '2026-05-01'),
	('2026-05-21', '2026-05-01'),
	('2026-05-22', '2026-05-01'),
	('2026-05-23', '2026-05-01'),
	('2026-05-24', '2026-05-01'),
	('2026-05-25', '2026-05-01'),
	('2026-05-26', '2026-05-01'),
	('2026-05-27', '2026-05-01'),
	('2026-05-28', '2026-05-01'),
	('2026-05-29', '2026-05-01'),
	('2026-05-30', '2026-05-01'),
	('2026-05-31', '2026-05-01'),
	('2026-06-01', '2026-06-01'),
	('2026-06-02', '2026-06-01'),
	('2026-06-03', '2026-06-01'),
	('2026-06-04', '2026-06-01'),
	('2026-06-05', '2026-06-01'),
	('2026-06-06', '2026-06-01'),
	('2026-06-07', '2026-06-01'),
	('2026-06-08', '2026-06-01'),
	('2026-06-09', '2026-06-01'),
	('2026-06-10', '2026-06-01'),
	('2026-06-11', '2026-06-01'),
	('2026-06-12', '2026-06-01'),
	('2026-06-13', '2026-06-01'),
	('2026-06-14', '2026-06-01'),
	('2026-06-15', '2026-06-01'),
	('2026-06-16', '2026-06-01'),
	('2026-06-17', '2026-06-01'),
	('2026-06-18', '2026-06-01'),
	('2026-06-19', '2026-06-01'),
	('2026-06-20', '2026-06-01'),
	('2026-06-21', '2026-06-01'),
	('2026-06-22', '2026-06-01'),
	('2026-06-23', '2026-06-01'),
	('2026-06-24', '2026-06-01'),
	('2026-06-25', '2026-06-01'),
	('2026-06-26', '2026-06-01'),
	('2026-06-27', '2026-06-01'),
	('2026-06-28', '2026-06-01'),
	('2026-06-29', '2026-06-01'),
	('2026-06-30', '2026-06-01'),
	('2026-07-01', '2026-07-01'),
	('2026-07-02', '2026-07-01'),
	('2026-07-03', '2026-07-01'),
	('2026-07-04', '2026-07-01'),
	('2026-07-05', '2026-07-01'),
	('2026-07-06', '2026-07-01'),
	('2026-07-07', '2026-07-01'),
	('2026-07-08', '2026-07-01'),
	('2026-07-09', '2026-07-01'),
	('2026-07-10', '2026-07-01'),
	('2026-07-11', '2026-07-01'),
	('2026-07-12', '2026-07-01'),
	('2026-07-13', '2026-07-01'),
	('2026-07-14', '2026-07-01'),
	('2026-07-15', '2026-07-01'),
	('2026-07-16', '2026-07-01'),
	('2026-07-17', '2026-07-01'),
	('2026-07-18', '2026-07-01'),
	('2026-07-19', '2026-07-01'),
	('2026-07-20', '2026-07-01'),
	('2026-07-21', '2026-07-01'),
	('2026-07-22', '2026-07-01'),
	('2026-07-23', '2026-07-01'),
	('2026-07-24', '2026-07-01'),
	('2026-07-25', '2026-07-01'),
	('2026-07-26', '2026-07-01'),
	('2026-07-27', '2026-07-01'),
	('2026-07-28', '2026-07-01'),
	('2026-07-29', '2026-07-01'),
	('2026-07-30', '2026-07-01'),
	('2026-07-31', '2026-07-01'),
	('2026-08-01', '2026-08-01'),
	('2026-08-02', '2026-08-01'),
	('2026-08-03', '2026-08-01'),
	('2026-08-04', '2026-08-01'),
	('2026-08-05', '2026-08-01'),
	('2026-08-06', '2026-08-01'),
	('2026-08-07', '2026-08-01'),
	('2026-08-08', '2026-08-01'),
	('2026-08-09', '2026-08-01'),
	('2026-08-10', '2026-08-01'),
	('2026-08-11', '2026-08-01'),
	('2026-08-12', '2026-08-01'),
	('2026-08-13', '2026-08-01'),
	('2026-08-14', '2026-08-01'),
	('2026-08-15', '2026-08-01'),
	('2026-08-16', '2026-08-01'),
	('2026-08-17', '2026-08-01'),
	('2026-08-18', '2026-08-01'),
	('2026-08-19', '2026-08-01'),
	('2026-08-20', '2026-08-01'),
	('2026-08-21', '2026-08-01'),
	('2026-08-22', '2026-08-01'),
	('2026-08-23', '2026-08-01'),
	('2026-08-24', '2026-08-01'),
	('2026-08-25', '2026-08-01'),
	('2026-08-26', '2026-08-01'),
	('2026-08-27', '2026-08-01'),
	('2026-08-28', '2026-08-01'),
	('2026-08-29', '2026-08-01'),
	('2026-08-30', '2026-08-01'),
	('2026-08-31', '2026-08-01'),
	('2026-09-01', '2026-09-01'),
	('2026-09-02', '2026-09-01'),
	('2026-09-03', '2026-09-01'),
	('2026-09-04', '2026-09-01'),
	('2026-09-05', '2026-09-01'),
	('2026-09-06', '2026-09-01'),
	('2026-09-07', '2026-09-01'),
	('2026-09-08', '2026-09-01'),
	('2026-09-09', '2026-09-01'),
	('2026-09-10', '2026-09-01'),
	('2026-09-11', '2026-09-01'),
	('2026-09-12', '2026-09-01'),
	('2026-09-13', '2026-09-01'),
	('2026-09-14', '2026-09-01'),
	('2026-09-15', '2026-09-01'),
	('2026-09-16', '2026-09-01'),
	('2026-09-17', '2026-09-01'),
	('2026-09-18', '2026-09-01'),
	('2026-09-19', '2026-09-01'),
	('2026-09-20', '2026-09-01'),
	('2026-09-21', '2026-09-01'),
	('2026-09-22', '2026-09-01'),
	('2026-09-23', '2026-09-01'),
	('2026-09-24', '2026-09-01'),
	('2026-09-25', '2026-09-01'),
	('2026-09-26', '2026-09-01'),
	('2026-09-27', '2026-09-01'),
	('2026-09-28', '2026-09-01'),
	('2026-09-29', '2026-09-01'),
	('2026-09-30', '2026-09-01'),
	('2026-10-01', '2026-10-01'),
	('2026-10-02', '2026-10-01'),
	('2026-10-03', '2026-10-01'),
	('2026-10-04', '2026-10-01'),
	('2026-10-05', '2026-10-01'),
	('2026-10-06', '2026-10-01'),
	('2026-10-07', '2026-10-01'),
	('2026-10-08', '2026-10-01'),
	('2026-10-09', '2026-10-01'),
	('2026-10-10', '2026-10-01'),
	('2026-10-11', '2026-10-01'),
	('2026-10-12', '2026-10-01'),
	('2026-10-13', '2026-10-01'),
	('2026-10-14', '2026-10-01'),
	('2026-10-15', '2026-10-01'),
	('2026-10-16', '2026-10-01'),
	('2026-10-17', '2026-10-01'),
	('2026-10-18', '2026-10-01'),
	('2026-10-19', '2026-10-01'),
	('2026-10-20', '2026-10-01'),
	('2026-10-21', '2026-10-01'),
	('2026-10-22', '2026-10-01'),
	('2026-10-23', '2026-10-01'),
	('2026-10-24', '2026-10-01'),
	('2026-10-25', '2026-10-01'),
	('2026-10-26', '2026-10-01'),
	('2026-10-27', '2026-10-01'),
	('2026-10-28', '2026-10-01'),
	('2026-10-29', '2026-10-01'),
	('2026-10-30', '2026-10-01'),
	('2026-10-31', '2026-10-01'),
	('2026-11-01', '2026-11-01'),
	('2026-11-02', '2026-11-01'),
	('2026-11-03', '2026-11-01'),
	('2026-11-04', '2026-11-01'),
	('2026-11-05', '2026-11-01'),
	('2026-11-06', '2026-11-01'),
	('2026-11-07', '2026-11-01'),
	('2026-11-08', '2026-11-01'),
	('2026-11-09', '2026-11-01'),
	('2026-11-10', '2026-11-01'),
	('2026-11-11', '2026-11-01'),
	('2026-11-12', '2026-11-01'),
	('2026-11-13', '2026-11-01'),
	('2026-11-14', '2026-11-01'),
	('2026-11-15', '2026-11-01'),
	('2026-11-16', '2026-11-01'),
	('2026-11-17', '2026-11-01'),
	('2026-11-18', '2026-11-01'),
	('2026-11-19', '2026-11-01'),
	('2026-11-20', '2026-11-01'),
	('2026-11-21', '2026-11-01'),
	('2026-11-22', '2026-11-01'),
	('2026-11-23', '2026-11-01'),
	('2026-11-24', '2026-11-01'),
	('2026-11-25', '2026-11-01'),
	('2026-11-26', '2026-11-01'),
	('2026-11-27', '2026-11-01'),
	('2026-11-28', '2026-11-01'),
	('2026-11-29', '2026-11-01'),
	('2026-11-30', '2026-11-01'),
	('2026-12-01', '2026-12-01'),
	('2026-12-02', '2026-12-01'),
	('2026-12-03', '2026-12-01'),
	('2026-12-04', '2026-12-01'),
	('2026-12-05', '2026-12-01'),
	('2026-12-06', '2026-12-01'),
	('2026-12-07', '2026-12-01'),
	('2026-12-08', '2026-12-01'),
	('2026-12-09', '2026-12-01'),
	('2026-12-10', '2026-12-01'),
	('2026-12-11', '2026-12-01'),
	('2026-12-12', '2026-12-01'),
	('2026-12-13', '2026-12-01'),
	('2026-12-14', '2026-12-01'),
	('2026-12-15', '2026-12-01'),
	('2026-12-16', '2026-12-01'),
	('2026-12-17', '2026-12-01'),
	('2026-12-18', '2026-12-01'),
	('2026-12-19', '2026-12-01'),
	('2026-12-20', '2026-12-01'),
	('2026-12-21', '2026-12-01'),
	('2026-12-22', '2026-12-01'),
	('2026-12-23', '2026-12-01'),
	('2026-12-24', '2026-12-01'),
	('2026-12-25', '2026-12-01'),
	('2026-12-26', '2026-12-01'),
	('2026-12-27', '2026-12-01'),
	('2026-12-28', '2026-12-01'),
	('2026-12-29', '2026-12-01'),
	('2026-12-30', '2026-12-01'),
	('2026-12-31', '2026-12-01'),
	('2027-01-01', '2027-01-01'),
	('2027-01-02', '2027-01-01'),
	('2027-01-03', '2027-01-01'),
	('2027-01-04', '2027-01-01'),
	('2027-01-05', '2027-01-01'),
	('2027-01-06', '2027-01-01'),
	('2027-01-07', '2027-01-01'),
	('2027-01-08', '2027-01-01'),
	('2027-01-09', '2027-01-01'),
	('2027-01-10', '2027-01-01'),
	('2027-01-11', '2027-01-01'),
	('2027-01-12', '2027-01-01'),
	('2027-01-13', '2027-01-01'),
	('2027-01-14', '2027-01-01'),
	('2027-01-15', '2027-01-01'),
	('2027-01-16', '2027-01-01'),
	('2027-01-17', '2027-01-01'),
	('2027-01-18', '2027-01-01'),
	('2027-01-19', '2027-01-01'),
	('2027-01-20', '2027-01-01'),
	('2027-01-21', '2027-01-01'),
	('2027-01-22', '2027-01-01'),
	('2027-01-23', '2027-01-01'),
	('2027-01-24', '2027-01-01'),
	('2027-01-25', '2027-01-01'),
	('2027-01-26', '2027-01-01'),
	('2027-01-27', '2027-01-01'),
	('2027-01-28', '2027-01-01'),
	('2027-01-29', '2027-01-01'),
	('2027-01-30', '2027-01-01'),
	('2027-01-31', '2027-01-01'),
	('2027-02-01', '2027-02-01'),
	('2027-02-02', '2027-02-01'),
	('2027-02-03', '2027-02-01'),
	('2027-02-04', '2027-02-01'),
	('2027-02-05', '2027-02-01'),
	('2027-02-06', '2027-02-01'),
	('2027-02-07', '2027-02-01'),
	('2027-02-08', '2027-02-01'),
	('2027-02-09', '2027-02-01'),
	('2027-02-10', '2027-02-01'),
	('2027-02-11', '2027-02-01'),
	('2027-02-12', '2027-02-01'),
	('2027-02-13', '2027-02-01'),
	('2027-02-14', '2027-02-01'),
	('2027-02-15', '2027-02-01'),
	('2027-02-16', '2027-02-01'),
	('2027-02-17', '2027-02-01'),
	('2027-02-18', '2027-02-01'),
	('2027-02-19', '2027-02-01'),
	('2027-02-20', '2027-02-01'),
	('2027-02-21', '2027-02-01'),
	('2027-02-22', '2027-02-01'),
	('2027-02-23', '2027-02-01'),
	('2027-02-24', '2027-02-01'),
	('2027-02-25', '2027-02-01'),
	('2027-02-26', '2027-02-01'),
	('2027-02-27', '2027-02-01'),
	('2027-02-28', '2027-02-01'),
	('2027-03-01', '2027-03-01'),
	('2027-03-02', '2027-03-01'),
	('2027-03-03', '2027-03-01'),
	('2027-03-04', '2027-03-01'),
	('2027-03-05', '2027-03-01'),
	('2027-03-06', '2027-03-01'),
	('2027-03-07', '2027-03-01'),
	('2027-03-08', '2027-03-01'),
	('2027-03-09', '2027-03-01'),
	('2027-03-10', '2027-03-01'),
	('2027-03-11', '2027-03-01'),
	('2027-03-12', '2027-03-01'),
	('2027-03-13', '2027-03-01'),
	('2027-03-14', '2027-03-01'),
	('2027-03-15', '2027-03-01'),
	('2027-03-16', '2027-03-01'),
	('2027-03-17', '2027-03-01'),
	('2027-03-18', '2027-03-01'),
	('2027-03-19', '2027-03-01'),
	('2027-03-20', '2027-03-01'),
	('2027-03-21', '2027-03-01'),
	('2027-03-22', '2027-03-01'),
	('2027-03-23', '2027-03-01'),
	('2027-03-24', '2027-03-01'),
	('2027-03-25', '2027-03-01'),
	('2027-03-26', '2027-03-01'),
	('2027-03-27', '2027-03-01'),
	('2027-03-28', '2027-03-01'),
	('2027-03-29', '2027-03-01'),
	('2027-03-30', '2027-03-01'),
	('2027-03-31', '2027-03-01'),
	('2027-04-01', '2027-04-01'),
	('2027-04-02', '2027-04-01'),
	('2027-04-03', '2027-04-01'),
	('2027-04-04', '2027-04-01'),
	('2027-04-05', '2027-04-01'),
	('2027-04-06', '2027-04-01'),
	('2027-04-07', '2027-04-01'),
	('2027-04-08', '2027-04-01'),
	('2027-04-09', '2027-04-01'),
	('2027-04-10', '2027-04-01'),
	('2027-04-11', '2027-04-01'),
	('2027-04-12', '2027-04-01'),
	('2027-04-13', '2027-04-01'),
	('2027-04-14', '2027-04-01'),
	('2027-04-15', '2027-04-01'),
	('2027-04-16', '2027-04-01'),
	('2027-04-17', '2027-04-01'),
	('2027-04-18', '2027-04-01'),
	('2027-04-19', '2027-04-01'),
	('2027-04-20', '2027-04-01'),
	('2027-04-21', '2027-04-01'),
	('2027-04-22', '2027-04-01'),
	('2027-04-23', '2027-04-01'),
	('2027-04-24', '2027-04-01'),
	('2027-04-25', '2027-04-01'),
	('2027-04-26', '2027-04-01'),
	('2027-04-27', '2027-04-01'),
	('2027-04-28', '2027-04-01'),
	('2027-04-29', '2027-04-01'),
	('2027-04-30', '2027-04-01'),
	('2027-05-01', '2027-05-01'),
	('2027-05-02', '2027-05-01'),
	('2027-05-03', '2027-05-01'),
	('2027-05-04', '2027-05-01'),
	('2027-05-05', '2027-05-01'),
	('2027-05-06', '2027-05-01'),
	('2027-05-07', '2027-05-01'),
	('2027-05-08', '2027-05-01'),
	('2027-05-09', '2027-05-01'),
	('2027-05-10', '2027-05-01'),
	('2027-05-11', '2027-05-01'),
	('2027-05-12', '2027-05-01'),
	('2027-05-13', '2027-05-01'),
	('2027-05-14', '2027-05-01'),
	('2027-05-15', '2027-05-01'),
	('2027-05-16', '2027-05-01'),
	('2027-05-17', '2027-05-01'),
	('2027-05-18', '2027-05-01'),
	('2027-05-19', '2027-05-01'),
	('2027-05-20', '2027-05-01'),
	('2027-05-21', '2027-05-01'),
	('2027-05-22', '2027-05-01'),
	('2027-05-23', '2027-05-01'),
	('2027-05-24', '2027-05-01'),
	('2027-05-25', '2027-05-01'),
	('2027-05-26', '2027-05-01'),
	('2027-05-27', '2027-05-01'),
	('2027-05-28', '2027-05-01'),
	('2027-05-29', '2027-05-01'),
	('2027-05-30', '2027-05-01'),
	('2027-05-31', '2027-05-01'),
	('2027-06-01', '2027-06-01'),
	('2027-06-02', '2027-06-01'),
	('2027-06-03', '2027-06-01'),
	('2027-06-04', '2027-06-01'),
	('2027-06-05', '2027-06-01'),
	('2027-06-06', '2027-06-01'),
	('2027-06-07', '2027-06-01'),
	('2027-06-08', '2027-06-01'),
	('2027-06-09', '2027-06-01'),
	('2027-06-10', '2027-06-01'),
	('2027-06-11', '2027-06-01'),
	('2027-06-12', '2027-06-01'),
	('2027-06-13', '2027-06-01'),
	('2027-06-14', '2027-06-01'),
	('2027-06-15', '2027-06-01'),
	('2027-06-16', '2027-06-01'),
	('2027-06-17', '2027-06-01'),
	('2027-06-18', '2027-06-01'),
	('2027-06-19', '2027-06-01'),
	('2027-06-20', '2027-06-01'),
	('2027-06-21', '2027-06-01'),
	('2027-06-22', '2027-06-01'),
	('2027-06-23', '2027-06-01'),
	('2027-06-24', '2027-06-01'),
	('2027-06-25', '2027-06-01'),
	('2027-06-26', '2027-06-01'),
	('2027-06-27', '2027-06-01'),
	('2027-06-28', '2027-06-01'),
	('2027-06-29', '2027-06-01'),
	('2027-06-30', '2027-06-01'),
	('2027-07-01', '2027-07-01'),
	('2027-07-02', '2027-07-01'),
	('2027-07-03', '2027-07-01'),
	('2027-07-04', '2027-07-01'),
	('2027-07-05', '2027-07-01'),
	('2027-07-06', '2027-07-01'),
	('2027-07-07', '2027-07-01'),
	('2027-07-08', '2027-07-01'),
	('2027-07-09', '2027-07-01'),
	('2027-07-10', '2027-07-01'),
	('2027-07-11', '2027-07-01'),
	('2027-07-12', '2027-07-01'),
	('2027-07-13', '2027-07-01'),
	('2027-07-14', '2027-07-01'),
	('2027-07-15', '2027-07-01'),
	('2027-07-16', '2027-07-01'),
	('2027-07-17', '2027-07-01'),
	('2027-07-18', '2027-07-01'),
	('2027-07-19', '2027-07-01'),
	('2027-07-20', '2027-07-01'),
	('2027-07-21', '2027-07-01'),
	('2027-07-22', '2027-07-01'),
	('2027-07-23', '2027-07-01'),
	('2027-07-24', '2027-07-01'),
	('2027-07-25', '2027-07-01'),
	('2027-07-26', '2027-07-01'),
	('2027-07-27', '2027-07-01'),
	('2027-07-28', '2027-07-01'),
	('2027-07-29', '2027-07-01'),
	('2027-07-30', '2027-07-01'),
	('2027-07-31', '2027-07-01'),
	('2027-08-01', '2027-08-01'),
	('2027-08-02', '2027-08-01'),
	('2027-08-03', '2027-08-01'),
	('2027-08-04', '2027-08-01'),
	('2027-08-05', '2027-08-01'),
	('2027-08-06', '2027-08-01'),
	('2027-08-07', '2027-08-01'),
	('2027-08-08', '2027-08-01'),
	('2027-08-09', '2027-08-01'),
	('2027-08-10', '2027-08-01'),
	('2027-08-11', '2027-08-01'),
	('2027-08-12', '2027-08-01'),
	('2027-08-13', '2027-08-01'),
	('2027-08-14', '2027-08-01'),
	('2027-08-15', '2027-08-01'),
	('2027-08-16', '2027-08-01'),
	('2027-08-17', '2027-08-01'),
	('2027-08-18', '2027-08-01'),
	('2027-08-19', '2027-08-01'),
	('2027-08-20', '2027-08-01'),
	('2027-08-21', '2027-08-01'),
	('2027-08-22', '2027-08-01'),
	('2027-08-23', '2027-08-01'),
	('2027-08-24', '2027-08-01'),
	('2027-08-25', '2027-08-01'),
	('2027-08-26', '2027-08-01'),
	('2027-08-27', '2027-08-01'),
	('2027-08-28', '2027-08-01'),
	('2027-08-29', '2027-08-01'),
	('2027-08-30', '2027-08-01'),
	('2027-08-31', '2027-08-01'),
	('2027-09-01', '2027-09-01'),
	('2027-09-02', '2027-09-01'),
	('2027-09-03', '2027-09-01'),
	('2027-09-04', '2027-09-01'),
	('2027-09-05', '2027-09-01'),
	('2027-09-06', '2027-09-01'),
	('2027-09-07', '2027-09-01'),
	('2027-09-08', '2027-09-01'),
	('2027-09-09', '2027-09-01'),
	('2027-09-10', '2027-09-01'),
	('2027-09-11', '2027-09-01'),
	('2027-09-12', '2027-09-01'),
	('2027-09-13', '2027-09-01'),
	('2027-09-14', '2027-09-01'),
	('2027-09-15', '2027-09-01'),
	('2027-09-16', '2027-09-01'),
	('2027-09-17', '2027-09-01'),
	('2027-09-18', '2027-09-01'),
	('2027-09-19', '2027-09-01'),
	('2027-09-20', '2027-09-01'),
	('2027-09-21', '2027-09-01'),
	('2027-09-22', '2027-09-01'),
	('2027-09-23', '2027-09-01'),
	('2027-09-24', '2027-09-01'),
	('2027-09-25', '2027-09-01'),
	('2027-09-26', '2027-09-01'),
	('2027-09-27', '2027-09-01'),
	('2027-09-28', '2027-09-01'),
	('2027-09-29', '2027-09-01'),
	('2027-09-30', '2027-09-01'),
	('2027-10-01', '2027-10-01'),
	('2027-10-02', '2027-10-01'),
	('2027-10-03', '2027-10-01'),
	('2027-10-04', '2027-10-01'),
	('2027-10-05', '2027-10-01'),
	('2027-10-06', '2027-10-01'),
	('2027-10-07', '2027-10-01'),
	('2027-10-08', '2027-10-01'),
	('2027-10-09', '2027-10-01'),
	('2027-10-10', '2027-10-01'),
	('2027-10-11', '2027-10-01'),
	('2027-10-12', '2027-10-01'),
	('2027-10-13', '2027-10-01'),
	('2027-10-14', '2027-10-01'),
	('2027-10-15', '2027-10-01'),
	('2027-10-16', '2027-10-01'),
	('2027-10-17', '2027-10-01'),
	('2027-10-18', '2027-10-01'),
	('2027-10-19', '2027-10-01'),
	('2027-10-20', '2027-10-01'),
	('2027-10-21', '2027-10-01'),
	('2027-10-22', '2027-10-01'),
	('2027-10-23', '2027-10-01'),
	('2027-10-24', '2027-10-01'),
	('2027-10-25', '2027-10-01'),
	('2027-10-26', '2027-10-01'),
	('2027-10-27', '2027-10-01'),
	('2027-10-28', '2027-10-01'),
	('2027-10-29', '2027-10-01'),
	('2027-10-30', '2027-10-01'),
	('2027-10-31', '2027-10-01'),
	('2027-11-01', '2027-11-01'),
	('2027-11-02', '2027-11-01'),
	('2027-11-03', '2027-11-01'),
	('2027-11-04', '2027-11-01'),
	('2027-11-05', '2027-11-01'),
	('2027-11-06', '2027-11-01'),
	('2027-11-07', '2027-11-01'),
	('2027-11-08', '2027-11-01'),
	('2027-11-09', '2027-11-01'),
	('2027-11-10', '2027-11-01'),
	('2027-11-11', '2027-11-01'),
	('2027-11-12', '2027-11-01'),
	('2027-11-13', '2027-11-01'),
	('2027-11-14', '2027-11-01'),
	('2027-11-15', '2027-11-01'),
	('2027-11-16', '2027-11-01'),
	('2027-11-17', '2027-11-01'),
	('2027-11-18', '2027-11-01'),
	('2027-11-19', '2027-11-01'),
	('2027-11-20', '2027-11-01'),
	('2027-11-21', '2027-11-01'),
	('2027-11-22', '2027-11-01'),
	('2027-11-23', '2027-11-01'),
	('2027-11-24', '2027-11-01'),
	('2027-11-25', '2027-11-01'),
	('2027-11-26', '2027-11-01'),
	('2027-11-27', '2027-11-01'),
	('2027-11-28', '2027-11-01'),
	('2027-11-29', '2027-11-01'),
	('2027-11-30', '2027-11-01'),
	('2027-12-01', '2027-12-01'),
	('2027-12-02', '2027-12-01'),
	('2027-12-03', '2027-12-01'),
	('2027-12-04', '2027-12-01'),
	('2027-12-05', '2027-12-01'),
	('2027-12-06', '2027-12-01'),
	('2027-12-07', '2027-12-01'),
	('2027-12-08', '2027-12-01'),
	('2027-12-09', '2027-12-01'),
	('2027-12-10', '2027-12-01'),
	('2027-12-11', '2027-12-01'),
	('2027-12-12', '2027-12-01'),
	('2027-12-13', '2027-12-01'),
	('2027-12-14', '2027-12-01'),
	('2027-12-15', '2027-12-01'),
	('2027-12-16', '2027-12-01'),
	('2027-12-17', '2027-12-01'),
	('2027-12-18', '2027-12-01'),
	('2027-12-19', '2027-12-01'),
	('2027-12-20', '2027-12-01'),
	('2027-12-21', '2027-12-01'),
	('2027-12-22', '2027-12-01'),
	('2027-12-23', '2027-12-01'),
	('2027-12-24', '2027-12-01'),
	('2027-12-25', '2027-12-01'),
	('2027-12-26', '2027-12-01'),
	('2027-12-27', '2027-12-01'),
	('2027-12-28', '2027-12-01'),
	('2027-12-29', '2027-12-01'),
	('2027-12-30', '2027-12-01'),
	('2027-12-31', '2027-12-01'),
	('2028-01-01', '2028-01-01'),
	('2028-01-02', '2028-01-01'),
	('2028-01-03', '2028-01-01'),
	('2028-01-04', '2028-01-01'),
	('2028-01-05', '2028-01-01'),
	('2028-01-06', '2028-01-01'),
	('2028-01-07', '2028-01-01'),
	('2028-01-08', '2028-01-01'),
	('2028-01-09', '2028-01-01'),
	('2028-01-10', '2028-01-01'),
	('2028-01-11', '2028-01-01'),
	('2028-01-12', '2028-01-01'),
	('2028-01-13', '2028-01-01'),
	('2028-01-14', '2028-01-01'),
	('2028-01-15', '2028-01-01'),
	('2028-01-16', '2028-01-01'),
	('2028-01-17', '2028-01-01'),
	('2028-01-18', '2028-01-01'),
	('2028-01-19', '2028-01-01'),
	('2028-01-20', '2028-01-01'),
	('2028-01-21', '2028-01-01'),
	('2028-01-22', '2028-01-01'),
	('2028-01-23', '2028-01-01'),
	('2028-01-24', '2028-01-01'),
	('2028-01-25', '2028-01-01'),
	('2028-01-26', '2028-01-01'),
	('2028-01-27', '2028-01-01'),
	('2028-01-28', '2028-01-01'),
	('2028-01-29', '2028-01-01'),
	('2028-01-30', '2028-01-01'),
	('2028-01-31', '2028-01-01'),
	('2028-02-01', '2028-02-01'),
	('2028-02-02', '2028-02-01'),
	('2028-02-03', '2028-02-01'),
	('2028-02-04', '2028-02-01'),
	('2028-02-05', '2028-02-01'),
	('2028-02-06', '2028-02-01'),
	('2028-02-07', '2028-02-01'),
	('2028-02-08', '2028-02-01'),
	('2028-02-09', '2028-02-01'),
	('2028-02-10', '2028-02-01'),
	('2028-02-11', '2028-02-01'),
	('2028-02-12', '2028-02-01'),
	('2028-02-13', '2028-02-01'),
	('2028-02-14', '2028-02-01'),
	('2028-02-15', '2028-02-01'),
	('2028-02-16', '2028-02-01'),
	('2028-02-17', '2028-02-01'),
	('2028-02-18', '2028-02-01'),
	('2028-02-19', '2028-02-01'),
	('2028-02-20', '2028-02-01'),
	('2028-02-21', '2028-02-01'),
	('2028-02-22', '2028-02-01'),
	('2028-02-23', '2028-02-01'),
	('2028-02-24', '2028-02-01'),
	('2028-02-25', '2028-02-01'),
	('2028-02-26', '2028-02-01'),
	('2028-02-27', '2028-02-01'),
	('2028-02-28', '2028-02-01'),
	('2028-02-29', '2028-02-01'),
	('2028-03-01', '2028-03-01'),
	('2028-03-02', '2028-03-01'),
	('2028-03-03', '2028-03-01'),
	('2028-03-04', '2028-03-01'),
	('2028-03-05', '2028-03-01'),
	('2028-03-06', '2028-03-01'),
	('2028-03-07', '2028-03-01'),
	('2028-03-08', '2028-03-01'),
	('2028-03-09', '2028-03-01'),
	('2028-03-10', '2028-03-01'),
	('2028-03-11', '2028-03-01'),
	('2028-03-12', '2028-03-01'),
	('2028-03-13', '2028-03-01'),
	('2028-03-14', '2028-03-01'),
	('2028-03-15', '2028-03-01'),
	('2028-03-16', '2028-03-01'),
	('2028-03-17', '2028-03-01'),
	('2028-03-18', '2028-03-01'),
	('2028-03-19', '2028-03-01'),
	('2028-03-20', '2028-03-01'),
	('2028-03-21', '2028-03-01'),
	('2028-03-22', '2028-03-01'),
	('2028-03-23', '2028-03-01'),
	('2028-03-24', '2028-03-01'),
	('2028-03-25', '2028-03-01'),
	('2028-03-26', '2028-03-01'),
	('2028-03-27', '2028-03-01'),
	('2028-03-28', '2028-03-01'),
	('2028-03-29', '2028-03-01'),
	('2028-03-30', '2028-03-01'),
	('2028-03-31', '2028-03-01'),
	('2028-04-01', '2028-04-01'),
	('2028-04-02', '2028-04-01'),
	('2028-04-03', '2028-04-01'),
	('2028-04-04', '2028-04-01'),
	('2028-04-05', '2028-04-01'),
	('2028-04-06', '2028-04-01'),
	('2028-04-07', '2028-04-01'),
	('2028-04-08', '2028-04-01'),
	('2028-04-09', '2028-04-01'),
	('2028-04-10', '2028-04-01'),
	('2028-04-11', '2028-04-01'),
	('2028-04-12', '2028-04-01'),
	('2028-04-13', '2028-04-01'),
	('2028-04-14', '2028-04-01'),
	('2028-04-15', '2028-04-01'),
	('2028-04-16', '2028-04-01'),
	('2028-04-17', '2028-04-01'),
	('2028-04-18', '2028-04-01'),
	('2028-04-19', '2028-04-01'),
	('2028-04-20', '2028-04-01'),
	('2028-04-21', '2028-04-01'),
	('2028-04-22', '2028-04-01'),
	('2028-04-23', '2028-04-01'),
	('2028-04-24', '2028-04-01'),
	('2028-04-25', '2028-04-01'),
	('2028-04-26', '2028-04-01'),
	('2028-04-27', '2028-04-01'),
	('2028-04-28', '2028-04-01'),
	('2028-04-29', '2028-04-01'),
	('2028-04-30', '2028-04-01'),
	('2028-05-01', '2028-05-01'),
	('2028-05-02', '2028-05-01'),
	('2028-05-03', '2028-05-01'),
	('2028-05-04', '2028-05-01'),
	('2028-05-05', '2028-05-01'),
	('2028-05-06', '2028-05-01'),
	('2028-05-07', '2028-05-01'),
	('2028-05-08', '2028-05-01'),
	('2028-05-09', '2028-05-01'),
	('2028-05-10', '2028-05-01'),
	('2028-05-11', '2028-05-01'),
	('2028-05-12', '2028-05-01'),
	('2028-05-13', '2028-05-01'),
	('2028-05-14', '2028-05-01'),
	('2028-05-15', '2028-05-01'),
	('2028-05-16', '2028-05-01'),
	('2028-05-17', '2028-05-01'),
	('2028-05-18', '2028-05-01'),
	('2028-05-19', '2028-05-01'),
	('2028-05-20', '2028-05-01'),
	('2028-05-21', '2028-05-01'),
	('2028-05-22', '2028-05-01'),
	('2028-05-23', '2028-05-01'),
	('2028-05-24', '2028-05-01'),
	('2028-05-25', '2028-05-01'),
	('2028-05-26', '2028-05-01'),
	('2028-05-27', '2028-05-01'),
	('2028-05-28', '2028-05-01'),
	('2028-05-29', '2028-05-01'),
	('2028-05-30', '2028-05-01'),
	('2028-05-31', '2028-05-01'),
	('2028-06-01', '2028-06-01'),
	('2028-06-02', '2028-06-01'),
	('2028-06-03', '2028-06-01'),
	('2028-06-04', '2028-06-01'),
	('2028-06-05', '2028-06-01'),
	('2028-06-06', '2028-06-01'),
	('2028-06-07', '2028-06-01'),
	('2028-06-08', '2028-06-01'),
	('2028-06-09', '2028-06-01'),
	('2028-06-10', '2028-06-01'),
	('2028-06-11', '2028-06-01'),
	('2028-06-12', '2028-06-01'),
	('2028-06-13', '2028-06-01'),
	('2028-06-14', '2028-06-01'),
	('2028-06-15', '2028-06-01'),
	('2028-06-16', '2028-06-01'),
	('2028-06-17', '2028-06-01'),
	('2028-06-18', '2028-06-01'),
	('2028-06-19', '2028-06-01'),
	('2028-06-20', '2028-06-01'),
	('2028-06-21', '2028-06-01'),
	('2028-06-22', '2028-06-01'),
	('2028-06-23', '2028-06-01'),
	('2028-06-24', '2028-06-01'),
	('2028-06-25', '2028-06-01'),
	('2028-06-26', '2028-06-01'),
	('2028-06-27', '2028-06-01'),
	('2028-06-28', '2028-06-01'),
	('2028-06-29', '2028-06-01'),
	('2028-06-30', '2028-06-01'),
	('2028-07-01', '2028-07-01'),
	('2028-07-02', '2028-07-01'),
	('2028-07-03', '2028-07-01'),
	('2028-07-04', '2028-07-01'),
	('2028-07-05', '2028-07-01'),
	('2028-07-06', '2028-07-01'),
	('2028-07-07', '2028-07-01'),
	('2028-07-08', '2028-07-01'),
	('2028-07-09', '2028-07-01'),
	('2028-07-10', '2028-07-01'),
	('2028-07-11', '2028-07-01'),
	('2028-07-12', '2028-07-01'),
	('2028-07-13', '2028-07-01'),
	('2028-07-14', '2028-07-01'),
	('2028-07-15', '2028-07-01'),
	('2028-07-16', '2028-07-01'),
	('2028-07-17', '2028-07-01'),
	('2028-07-18', '2028-07-01'),
	('2028-07-19', '2028-07-01'),
	('2028-07-20', '2028-07-01'),
	('2028-07-21', '2028-07-01'),
	('2028-07-22', '2028-07-01'),
	('2028-07-23', '2028-07-01'),
	('2028-07-24', '2028-07-01'),
	('2028-07-25', '2028-07-01'),
	('2028-07-26', '2028-07-01'),
	('2028-07-27', '2028-07-01'),
	('2028-07-28', '2028-07-01'),
	('2028-07-29', '2028-07-01'),
	('2028-07-30', '2028-07-01'),
	('2028-07-31', '2028-07-01'),
	('2028-08-01', '2028-08-01'),
	('2028-08-02', '2028-08-01'),
	('2028-08-03', '2028-08-01'),
	('2028-08-04', '2028-08-01'),
	('2028-08-05', '2028-08-01'),
	('2028-08-06', '2028-08-01'),
	('2028-08-07', '2028-08-01'),
	('2028-08-08', '2028-08-01'),
	('2028-08-09', '2028-08-01'),
	('2028-08-10', '2028-08-01'),
	('2028-08-11', '2028-08-01'),
	('2028-08-12', '2028-08-01'),
	('2028-08-13', '2028-08-01'),
	('2028-08-14', '2028-08-01'),
	('2028-08-15', '2028-08-01'),
	('2028-08-16', '2028-08-01'),
	('2028-08-17', '2028-08-01'),
	('2028-08-18', '2028-08-01'),
	('2028-08-19', '2028-08-01'),
	('2028-08-20', '2028-08-01'),
	('2028-08-21', '2028-08-01'),
	('2028-08-22', '2028-08-01'),
	('2028-08-23', '2028-08-01'),
	('2028-08-24', '2028-08-01'),
	('2028-08-25', '2028-08-01'),
	('2028-08-26', '2028-08-01'),
	('2028-08-27', '2028-08-01'),
	('2028-08-28', '2028-08-01'),
	('2028-08-29', '2028-08-01'),
	('2028-08-30', '2028-08-01'),
	('2028-08-31', '2028-08-01'),
	('2028-09-01', '2028-09-01'),
	('2028-09-02', '2028-09-01'),
	('2028-09-03', '2028-09-01'),
	('2028-09-04', '2028-09-01'),
	('2028-09-05', '2028-09-01'),
	('2028-09-06', '2028-09-01'),
	('2028-09-07', '2028-09-01'),
	('2028-09-08', '2028-09-01'),
	('2028-09-09', '2028-09-01'),
	('2028-09-10', '2028-09-01'),
	('2028-09-11', '2028-09-01'),
	('2028-09-12', '2028-09-01'),
	('2028-09-13', '2028-09-01'),
	('2028-09-14', '2028-09-01'),
	('2028-09-15', '2028-09-01'),
	('2028-09-16', '2028-09-01'),
	('2028-09-17', '2028-09-01'),
	('2028-09-18', '2028-09-01'),
	('2028-09-19', '2028-09-01'),
	('2028-09-20', '2028-09-01'),
	('2028-09-21', '2028-09-01'),
	('2028-09-22', '2028-09-01'),
	('2028-09-23', '2028-09-01'),
	('2028-09-24', '2028-09-01'),
	('2028-09-25', '2028-09-01'),
	('2028-09-26', '2028-09-01'),
	('2028-09-27', '2028-09-01'),
	('2028-09-28', '2028-09-01'),
	('2028-09-29', '2028-09-01'),
	('2028-09-30', '2028-09-01'),
	('2028-10-01', '2028-10-01'),
	('2028-10-02', '2028-10-01'),
	('2028-10-03', '2028-10-01'),
	('2028-10-04', '2028-10-01'),
	('2028-10-05', '2028-10-01'),
	('2028-10-06', '2028-10-01'),
	('2028-10-07', '2028-10-01'),
	('2028-10-08', '2028-10-01'),
	('2028-10-09', '2028-10-01'),
	('2028-10-10', '2028-10-01'),
	('2028-10-11', '2028-10-01'),
	('2028-10-12', '2028-10-01'),
	('2028-10-13', '2028-10-01'),
	('2028-10-14', '2028-10-01'),
	('2028-10-15', '2028-10-01'),
	('2028-10-16', '2028-10-01'),
	('2028-10-17', '2028-10-01'),
	('2028-10-18', '2028-10-01'),
	('2028-10-19', '2028-10-01'),
	('2028-10-20', '2028-10-01'),
	('2028-10-21', '2028-10-01'),
	('2028-10-22', '2028-10-01'),
	('2028-10-23', '2028-10-01'),
	('2028-10-24', '2028-10-01'),
	('2028-10-25', '2028-10-01'),
	('2028-10-26', '2028-10-01'),
	('2028-10-27', '2028-10-01'),
	('2028-10-28', '2028-10-01'),
	('2028-10-29', '2028-10-01'),
	('2028-10-30', '2028-10-01'),
	('2028-10-31', '2028-10-01'),
	('2028-11-01', '2028-11-01'),
	('2028-11-02', '2028-11-01'),
	('2028-11-03', '2028-11-01'),
	('2028-11-04', '2028-11-01'),
	('2028-11-05', '2028-11-01'),
	('2028-11-06', '2028-11-01'),
	('2028-11-07', '2028-11-01'),
	('2028-11-08', '2028-11-01'),
	('2028-11-09', '2028-11-01'),
	('2028-11-10', '2028-11-01'),
	('2028-11-11', '2028-11-01'),
	('2028-11-12', '2028-11-01'),
	('2028-11-13', '2028-11-01'),
	('2028-11-14', '2028-11-01'),
	('2028-11-15', '2028-11-01'),
	('2028-11-16', '2028-11-01'),
	('2028-11-17', '2028-11-01'),
	('2028-11-18', '2028-11-01'),
	('2028-11-19', '2028-11-01'),
	('2028-11-20', '2028-11-01'),
	('2028-11-21', '2028-11-01'),
	('2028-11-22', '2028-11-01'),
	('2028-11-23', '2028-11-01'),
	('2028-11-24', '2028-11-01'),
	('2028-11-25', '2028-11-01'),
	('2028-11-26', '2028-11-01'),
	('2028-11-27', '2028-11-01'),
	('2028-11-28', '2028-11-01'),
	('2028-11-29', '2028-11-01'),
	('2028-11-30', '2028-11-01'),
	('2028-12-01', '2028-12-01'),
	('2028-12-02', '2028-12-01'),
	('2028-12-03', '2028-12-01'),
	('2028-12-04', '2028-12-01'),
	('2028-12-05', '2028-12-01'),
	('2028-12-06', '2028-12-01'),
	('2028-12-07', '2028-12-01'),
	('2028-12-08', '2028-12-01'),
	('2028-12-09', '2028-12-01'),
	('2028-12-10', '2028-12-01'),
	('2028-12-11', '2028-12-01'),
	('2028-12-12', '2028-12-01'),
	('2028-12-13', '2028-12-01'),
	('2028-12-14', '2028-12-01'),
	('2028-12-15', '2028-12-01'),
	('2028-12-16', '2028-12-01'),
	('2028-12-17', '2028-12-01'),
	('2028-12-18', '2028-12-01'),
	('2028-12-19', '2028-12-01'),
	('2028-12-20', '2028-12-01'),
	('2028-12-21', '2028-12-01'),
	('2028-12-22', '2028-12-01'),
	('2028-12-23', '2028-12-01'),
	('2028-12-24', '2028-12-01'),
	('2028-12-25', '2028-12-01'),
	('2028-12-26', '2028-12-01'),
	('2028-12-27', '2028-12-01'),
	('2028-12-28', '2028-12-01'),
	('2028-12-29', '2028-12-01'),
	('2028-12-30', '2028-12-01'),
	('2028-12-31', '2028-12-01'),
	('2029-01-01', '2029-01-01'),
	('2029-01-02', '2029-01-01'),
	('2029-01-03', '2029-01-01'),
	('2029-01-04', '2029-01-01'),
	('2029-01-05', '2029-01-01'),
	('2029-01-06', '2029-01-01'),
	('2029-01-07', '2029-01-01'),
	('2029-01-08', '2029-01-01'),
	('2029-01-09', '2029-01-01'),
	('2029-01-10', '2029-01-01'),
	('2029-01-11', '2029-01-01'),
	('2029-01-12', '2029-01-01'),
	('2029-01-13', '2029-01-01'),
	('2029-01-14', '2029-01-01'),
	('2029-01-15', '2029-01-01'),
	('2029-01-16', '2029-01-01'),
	('2029-01-17', '2029-01-01'),
	('2029-01-18', '2029-01-01'),
	('2029-01-19', '2029-01-01'),
	('2029-01-20', '2029-01-01'),
	('2029-01-21', '2029-01-01'),
	('2029-01-22', '2029-01-01'),
	('2029-01-23', '2029-01-01'),
	('2029-01-24', '2029-01-01'),
	('2029-01-25', '2029-01-01'),
	('2029-01-26', '2029-01-01'),
	('2029-01-27', '2029-01-01'),
	('2029-01-28', '2029-01-01'),
	('2029-01-29', '2029-01-01'),
	('2029-01-30', '2029-01-01'),
	('2029-01-31', '2029-01-01'),
	('2029-02-01', '2029-02-01'),
	('2029-02-02', '2029-02-01'),
	('2029-02-03', '2029-02-01'),
	('2029-02-04', '2029-02-01'),
	('2029-02-05', '2029-02-01'),
	('2029-02-06', '2029-02-01'),
	('2029-02-07', '2029-02-01'),
	('2029-02-08', '2029-02-01'),
	('2029-02-09', '2029-02-01'),
	('2029-02-10', '2029-02-01'),
	('2029-02-11', '2029-02-01'),
	('2029-02-12', '2029-02-01'),
	('2029-02-13', '2029-02-01'),
	('2029-02-14', '2029-02-01'),
	('2029-02-15', '2029-02-01'),
	('2029-02-16', '2029-02-01'),
	('2029-02-17', '2029-02-01'),
	('2029-02-18', '2029-02-01'),
	('2029-02-19', '2029-02-01'),
	('2029-02-20', '2029-02-01'),
	('2029-02-21', '2029-02-01'),
	('2029-02-22', '2029-02-01'),
	('2029-02-23', '2029-02-01'),
	('2029-02-24', '2029-02-01'),
	('2029-02-25', '2029-02-01'),
	('2029-02-26', '2029-02-01'),
	('2029-02-27', '2029-02-01'),
	('2029-02-28', '2029-02-01'),
	('2029-03-01', '2029-03-01'),
	('2029-03-02', '2029-03-01'),
	('2029-03-03', '2029-03-01'),
	('2029-03-04', '2029-03-01'),
	('2029-03-05', '2029-03-01'),
	('2029-03-06', '2029-03-01'),
	('2029-03-07', '2029-03-01'),
	('2029-03-08', '2029-03-01'),
	('2029-03-09', '2029-03-01'),
	('2029-03-10', '2029-03-01'),
	('2029-03-11', '2029-03-01'),
	('2029-03-12', '2029-03-01'),
	('2029-03-13', '2029-03-01'),
	('2029-03-14', '2029-03-01'),
	('2029-03-15', '2029-03-01'),
	('2029-03-16', '2029-03-01'),
	('2029-03-17', '2029-03-01'),
	('2029-03-18', '2029-03-01'),
	('2029-03-19', '2029-03-01'),
	('2029-03-20', '2029-03-01'),
	('2029-03-21', '2029-03-01'),
	('2029-03-22', '2029-03-01'),
	('2029-03-23', '2029-03-01'),
	('2029-03-24', '2029-03-01'),
	('2029-03-25', '2029-03-01'),
	('2029-03-26', '2029-03-01'),
	('2029-03-27', '2029-03-01'),
	('2029-03-28', '2029-03-01'),
	('2029-03-29', '2029-03-01'),
	('2029-03-30', '2029-03-01'),
	('2029-03-31', '2029-03-01'),
	('2029-04-01', '2029-04-01'),
	('2029-04-02', '2029-04-01'),
	('2029-04-03', '2029-04-01'),
	('2029-04-04', '2029-04-01'),
	('2029-04-05', '2029-04-01'),
	('2029-04-06', '2029-04-01'),
	('2029-04-07', '2029-04-01'),
	('2029-04-08', '2029-04-01'),
	('2029-04-09', '2029-04-01'),
	('2029-04-10', '2029-04-01'),
	('2029-04-11', '2029-04-01'),
	('2029-04-12', '2029-04-01'),
	('2029-04-13', '2029-04-01'),
	('2029-04-14', '2029-04-01'),
	('2029-04-15', '2029-04-01'),
	('2029-04-16', '2029-04-01'),
	('2029-04-17', '2029-04-01'),
	('2029-04-18', '2029-04-01'),
	('2029-04-19', '2029-04-01'),
	('2029-04-20', '2029-04-01'),
	('2029-04-21', '2029-04-01'),
	('2029-04-22', '2029-04-01'),
	('2029-04-23', '2029-04-01'),
	('2029-04-24', '2029-04-01'),
	('2029-04-25', '2029-04-01'),
	('2029-04-26', '2029-04-01'),
	('2029-04-27', '2029-04-01'),
	('2029-04-28', '2029-04-01'),
	('2029-04-29', '2029-04-01'),
	('2029-04-30', '2029-04-01'),
	('2029-05-01', '2029-05-01'),
	('2029-05-02', '2029-05-01'),
	('2029-05-03', '2029-05-01'),
	('2029-05-04', '2029-05-01'),
	('2029-05-05', '2029-05-01'),
	('2029-05-06', '2029-05-01'),
	('2029-05-07', '2029-05-01'),
	('2029-05-08', '2029-05-01'),
	('2029-05-09', '2029-05-01'),
	('2029-05-10', '2029-05-01'),
	('2029-05-11', '2029-05-01'),
	('2029-05-12', '2029-05-01'),
	('2029-05-13', '2029-05-01'),
	('2029-05-14', '2029-05-01'),
	('2029-05-15', '2029-05-01'),
	('2029-05-16', '2029-05-01'),
	('2029-05-17', '2029-05-01'),
	('2029-05-18', '2029-05-01'),
	('2029-05-19', '2029-05-01'),
	('2029-05-20', '2029-05-01'),
	('2029-05-21', '2029-05-01'),
	('2029-05-22', '2029-05-01'),
	('2029-05-23', '2029-05-01'),
	('2029-05-24', '2029-05-01'),
	('2029-05-25', '2029-05-01'),
	('2029-05-26', '2029-05-01'),
	('2029-05-27', '2029-05-01'),
	('2029-05-28', '2029-05-01'),
	('2029-05-29', '2029-05-01'),
	('2029-05-30', '2029-05-01'),
	('2029-05-31', '2029-05-01'),
	('2029-06-01', '2029-06-01'),
	('2029-06-02', '2029-06-01'),
	('2029-06-03', '2029-06-01'),
	('2029-06-04', '2029-06-01'),
	('2029-06-05', '2029-06-01'),
	('2029-06-06', '2029-06-01'),
	('2029-06-07', '2029-06-01'),
	('2029-06-08', '2029-06-01'),
	('2029-06-09', '2029-06-01'),
	('2029-06-10', '2029-06-01'),
	('2029-06-11', '2029-06-01'),
	('2029-06-12', '2029-06-01'),
	('2029-06-13', '2029-06-01'),
	('2029-06-14', '2029-06-01'),
	('2029-06-15', '2029-06-01'),
	('2029-06-16', '2029-06-01'),
	('2029-06-17', '2029-06-01'),
	('2029-06-18', '2029-06-01'),
	('2029-06-19', '2029-06-01'),
	('2029-06-20', '2029-06-01'),
	('2029-06-21', '2029-06-01'),
	('2029-06-22', '2029-06-01'),
	('2029-06-23', '2029-06-01'),
	('2029-06-24', '2029-06-01'),
	('2029-06-25', '2029-06-01'),
	('2029-06-26', '2029-06-01'),
	('2029-06-27', '2029-06-01'),
	('2029-06-28', '2029-06-01'),
	('2029-06-29', '2029-06-01'),
	('2029-06-30', '2029-06-01'),
	('2029-07-01', '2029-07-01'),
	('2029-07-02', '2029-07-01'),
	('2029-07-03', '2029-07-01'),
	('2029-07-04', '2029-07-01'),
	('2029-07-05', '2029-07-01'),
	('2029-07-06', '2029-07-01'),
	('2029-07-07', '2029-07-01'),
	('2029-07-08', '2029-07-01'),
	('2029-07-09', '2029-07-01'),
	('2029-07-10', '2029-07-01'),
	('2029-07-11', '2029-07-01'),
	('2029-07-12', '2029-07-01'),
	('2029-07-13', '2029-07-01'),
	('2029-07-14', '2029-07-01'),
	('2029-07-15', '2029-07-01'),
	('2029-07-16', '2029-07-01'),
	('2029-07-17', '2029-07-01'),
	('2029-07-18', '2029-07-01'),
	('2029-07-19', '2029-07-01'),
	('2029-07-20', '2029-07-01'),
	('2029-07-21', '2029-07-01'),
	('2029-07-22', '2029-07-01'),
	('2029-07-23', '2029-07-01'),
	('2029-07-24', '2029-07-01'),
	('2029-07-25', '2029-07-01'),
	('2029-07-26', '2029-07-01'),
	('2029-07-27', '2029-07-01'),
	('2029-07-28', '2029-07-01'),
	('2029-07-29', '2029-07-01'),
	('2029-07-30', '2029-07-01'),
	('2029-07-31', '2029-07-01'),
	('2029-08-01', '2029-08-01'),
	('2029-08-02', '2029-08-01'),
	('2029-08-03', '2029-08-01'),
	('2029-08-04', '2029-08-01'),
	('2029-08-05', '2029-08-01'),
	('2029-08-06', '2029-08-01'),
	('2029-08-07', '2029-08-01'),
	('2029-08-08', '2029-08-01'),
	('2029-08-09', '2029-08-01'),
	('2029-08-10', '2029-08-01'),
	('2029-08-11', '2029-08-01'),
	('2029-08-12', '2029-08-01'),
	('2029-08-13', '2029-08-01'),
	('2029-08-14', '2029-08-01'),
	('2029-08-15', '2029-08-01'),
	('2029-08-16', '2029-08-01'),
	('2029-08-17', '2029-08-01'),
	('2029-08-18', '2029-08-01'),
	('2029-08-19', '2029-08-01'),
	('2029-08-20', '2029-08-01'),
	('2029-08-21', '2029-08-01'),
	('2029-08-22', '2029-08-01'),
	('2029-08-23', '2029-08-01'),
	('2029-08-24', '2029-08-01'),
	('2029-08-25', '2029-08-01'),
	('2029-08-26', '2029-08-01'),
	('2029-08-27', '2029-08-01'),
	('2029-08-28', '2029-08-01'),
	('2029-08-29', '2029-08-01'),
	('2029-08-30', '2029-08-01'),
	('2029-08-31', '2029-08-01'),
	('2029-09-01', '2029-09-01'),
	('2029-09-02', '2029-09-01'),
	('2029-09-03', '2029-09-01'),
	('2029-09-04', '2029-09-01'),
	('2029-09-05', '2029-09-01'),
	('2029-09-06', '2029-09-01'),
	('2029-09-07', '2029-09-01'),
	('2029-09-08', '2029-09-01'),
	('2029-09-09', '2029-09-01'),
	('2029-09-10', '2029-09-01'),
	('2029-09-11', '2029-09-01'),
	('2029-09-12', '2029-09-01'),
	('2029-09-13', '2029-09-01'),
	('2029-09-14', '2029-09-01'),
	('2029-09-15', '2029-09-01'),
	('2029-09-16', '2029-09-01'),
	('2029-09-17', '2029-09-01'),
	('2029-09-18', '2029-09-01'),
	('2029-09-19', '2029-09-01'),
	('2029-09-20', '2029-09-01'),
	('2029-09-21', '2029-09-01'),
	('2029-09-22', '2029-09-01'),
	('2029-09-23', '2029-09-01'),
	('2029-09-24', '2029-09-01'),
	('2029-09-25', '2029-09-01'),
	('2029-09-26', '2029-09-01'),
	('2029-09-27', '2029-09-01'),
	('2029-09-28', '2029-09-01'),
	('2029-09-29', '2029-09-01'),
	('2029-09-30', '2029-09-01'),
	('2029-10-01', '2029-10-01'),
	('2029-10-02', '2029-10-01'),
	('2029-10-03', '2029-10-01'),
	('2029-10-04', '2029-10-01'),
	('2029-10-05', '2029-10-01'),
	('2029-10-06', '2029-10-01'),
	('2029-10-07', '2029-10-01'),
	('2029-10-08', '2029-10-01'),
	('2029-10-09', '2029-10-01'),
	('2029-10-10', '2029-10-01'),
	('2029-10-11', '2029-10-01'),
	('2029-10-12', '2029-10-01'),
	('2029-10-13', '2029-10-01'),
	('2029-10-14', '2029-10-01'),
	('2029-10-15', '2029-10-01'),
	('2029-10-16', '2029-10-01'),
	('2029-10-17', '2029-10-01'),
	('2029-10-18', '2029-10-01'),
	('2029-10-19', '2029-10-01'),
	('2029-10-20', '2029-10-01'),
	('2029-10-21', '2029-10-01'),
	('2029-10-22', '2029-10-01'),
	('2029-10-23', '2029-10-01'),
	('2029-10-24', '2029-10-01'),
	('2029-10-25', '2029-10-01'),
	('2029-10-26', '2029-10-01'),
	('2029-10-27', '2029-10-01'),
	('2029-10-28', '2029-10-01'),
	('2029-10-29', '2029-10-01'),
	('2029-10-30', '2029-10-01'),
	('2029-10-31', '2029-10-01'),
	('2029-11-01', '2029-11-01'),
	('2029-11-02', '2029-11-01'),
	('2029-11-03', '2029-11-01'),
	('2029-11-04', '2029-11-01'),
	('2029-11-05', '2029-11-01'),
	('2029-11-06', '2029-11-01'),
	('2029-11-07', '2029-11-01'),
	('2029-11-08', '2029-11-01'),
	('2029-11-09', '2029-11-01'),
	('2029-11-10', '2029-11-01'),
	('2029-11-11', '2029-11-01'),
	('2029-11-12', '2029-11-01'),
	('2029-11-13', '2029-11-01'),
	('2029-11-14', '2029-11-01'),
	('2029-11-15', '2029-11-01'),
	('2029-11-16', '2029-11-01'),
	('2029-11-17', '2029-11-01'),
	('2029-11-18', '2029-11-01'),
	('2029-11-19', '2029-11-01'),
	('2029-11-20', '2029-11-01'),
	('2029-11-21', '2029-11-01'),
	('2029-11-22', '2029-11-01'),
	('2029-11-23', '2029-11-01'),
	('2029-11-24', '2029-11-01'),
	('2029-11-25', '2029-11-01'),
	('2029-11-26', '2029-11-01'),
	('2029-11-27', '2029-11-01'),
	('2029-11-28', '2029-11-01'),
	('2029-11-29', '2029-11-01'),
	('2029-11-30', '2029-11-01'),
	('2029-12-01', '2029-12-01'),
	('2029-12-02', '2029-12-01'),
	('2029-12-03', '2029-12-01'),
	('2029-12-04', '2029-12-01'),
	('2029-12-05', '2029-12-01'),
	('2029-12-06', '2029-12-01'),
	('2029-12-07', '2029-12-01'),
	('2029-12-08', '2029-12-01'),
	('2029-12-09', '2029-12-01'),
	('2029-12-10', '2029-12-01'),
	('2029-12-11', '2029-12-01'),
	('2029-12-12', '2029-12-01'),
	('2029-12-13', '2029-12-01'),
	('2029-12-14', '2029-12-01'),
	('2029-12-15', '2029-12-01'),
	('2029-12-16', '2029-12-01'),
	('2029-12-17', '2029-12-01'),
	('2029-12-18', '2029-12-01'),
	('2029-12-19', '2029-12-01'),
	('2029-12-20', '2029-12-01'),
	('2029-12-21', '2029-12-01'),
	('2029-12-22', '2029-12-01'),
	('2029-12-23', '2029-12-01'),
	('2029-12-24', '2029-12-01'),
	('2029-12-25', '2029-12-01'),
	('2029-12-26', '2029-12-01'),
	('2029-12-27', '2029-12-01'),
	('2029-12-28', '2029-12-01'),
	('2029-12-29', '2029-12-01'),
	('2029-12-30', '2029-12-01'),
	('2029-12-31', '2029-12-01'),
	('2030-01-01', '2030-01-01'),
	('2030-01-02', '2030-01-01'),
	('2030-01-03', '2030-01-01'),
	('2030-01-04', '2030-01-01'),
	('2030-01-05', '2030-01-01'),
	('2030-01-06', '2030-01-01'),
	('2030-01-07', '2030-01-01'),
	('2030-01-08', '2030-01-01'),
	('2030-01-09', '2030-01-01'),
	('2030-01-10', '2030-01-01'),
	('2030-01-11', '2030-01-01'),
	('2030-01-12', '2030-01-01'),
	('2030-01-13', '2030-01-01'),
	('2030-01-14', '2030-01-01'),
	('2030-01-15', '2030-01-01'),
	('2030-01-16', '2030-01-01'),
	('2030-01-17', '2030-01-01'),
	('2030-01-18', '2030-01-01'),
	('2030-01-19', '2030-01-01'),
	('2030-01-20', '2030-01-01'),
	('2030-01-21', '2030-01-01'),
	('2030-01-22', '2030-01-01'),
	('2030-01-23', '2030-01-01'),
	('2030-01-24', '2030-01-01'),
	('2030-01-25', '2030-01-01'),
	('2030-01-26', '2030-01-01'),
	('2030-01-27', '2030-01-01'),
	('2030-01-28', '2030-01-01'),
	('2030-01-29', '2030-01-01'),
	('2030-01-30', '2030-01-01'),
	('2030-01-31', '2030-01-01'),
	('2030-02-01', '2030-02-01'),
	('2030-02-02', '2030-02-01'),
	('2030-02-03', '2030-02-01'),
	('2030-02-04', '2030-02-01'),
	('2030-02-05', '2030-02-01'),
	('2030-02-06', '2030-02-01'),
	('2030-02-07', '2030-02-01'),
	('2030-02-08', '2030-02-01'),
	('2030-02-09', '2030-02-01'),
	('2030-02-10', '2030-02-01'),
	('2030-02-11', '2030-02-01'),
	('2030-02-12', '2030-02-01'),
	('2030-02-13', '2030-02-01'),
	('2030-02-14', '2030-02-01'),
	('2030-02-15', '2030-02-01'),
	('2030-02-16', '2030-02-01'),
	('2030-02-17', '2030-02-01'),
	('2030-02-18', '2030-02-01'),
	('2030-02-19', '2030-02-01'),
	('2030-02-20', '2030-02-01'),
	('2030-02-21', '2030-02-01'),
	('2030-02-22', '2030-02-01'),
	('2030-02-23', '2030-02-01'),
	('2030-02-24', '2030-02-01'),
	('2030-02-25', '2030-02-01'),
	('2030-02-26', '2030-02-01'),
	('2030-02-27', '2030-02-01'),
	('2030-02-28', '2030-02-01'),
	('2030-03-01', '2030-03-01'),
	('2030-03-02', '2030-03-01'),
	('2030-03-03', '2030-03-01'),
	('2030-03-04', '2030-03-01'),
	('2030-03-05', '2030-03-01'),
	('2030-03-06', '2030-03-01'),
	('2030-03-07', '2030-03-01'),
	('2030-03-08', '2030-03-01'),
	('2030-03-09', '2030-03-01'),
	('2030-03-10', '2030-03-01'),
	('2030-03-11', '2030-03-01'),
	('2030-03-12', '2030-03-01'),
	('2030-03-13', '2030-03-01'),
	('2030-03-14', '2030-03-01'),
	('2030-03-15', '2030-03-01'),
	('2030-03-16', '2030-03-01'),
	('2030-03-17', '2030-03-01'),
	('2030-03-18', '2030-03-01'),
	('2030-03-19', '2030-03-01'),
	('2030-03-20', '2030-03-01'),
	('2030-03-21', '2030-03-01'),
	('2030-03-22', '2030-03-01'),
	('2030-03-23', '2030-03-01'),
	('2030-03-24', '2030-03-01'),
	('2030-03-25', '2030-03-01'),
	('2030-03-26', '2030-03-01'),
	('2030-03-27', '2030-03-01'),
	('2030-03-28', '2030-03-01'),
	('2030-03-29', '2030-03-01'),
	('2030-03-30', '2030-03-01'),
	('2030-03-31', '2030-03-01'),
	('2030-04-01', '2030-04-01'),
	('2030-04-02', '2030-04-01'),
	('2030-04-03', '2030-04-01'),
	('2030-04-04', '2030-04-01'),
	('2030-04-05', '2030-04-01'),
	('2030-04-06', '2030-04-01'),
	('2030-04-07', '2030-04-01'),
	('2030-04-08', '2030-04-01'),
	('2030-04-09', '2030-04-01'),
	('2030-04-10', '2030-04-01'),
	('2030-04-11', '2030-04-01'),
	('2030-04-12', '2030-04-01'),
	('2030-04-13', '2030-04-01'),
	('2030-04-14', '2030-04-01'),
	('2030-04-15', '2030-04-01'),
	('2030-04-16', '2030-04-01'),
	('2030-04-17', '2030-04-01'),
	('2030-04-18', '2030-04-01'),
	('2030-04-19', '2030-04-01'),
	('2030-04-20', '2030-04-01'),
	('2030-04-21', '2030-04-01'),
	('2030-04-22', '2030-04-01'),
	('2030-04-23', '2030-04-01'),
	('2030-04-24', '2030-04-01'),
	('2030-04-25', '2030-04-01'),
	('2030-04-26', '2030-04-01'),
	('2030-04-27', '2030-04-01'),
	('2030-04-28', '2030-04-01'),
	('2030-04-29', '2030-04-01'),
	('2030-04-30', '2030-04-01'),
	('2030-05-01', '2030-05-01'),
	('2030-05-02', '2030-05-01'),
	('2030-05-03', '2030-05-01'),
	('2030-05-04', '2030-05-01'),
	('2030-05-05', '2030-05-01'),
	('2030-05-06', '2030-05-01'),
	('2030-05-07', '2030-05-01'),
	('2030-05-08', '2030-05-01'),
	('2030-05-09', '2030-05-01'),
	('2030-05-10', '2030-05-01'),
	('2030-05-11', '2030-05-01'),
	('2030-05-12', '2030-05-01'),
	('2030-05-13', '2030-05-01'),
	('2030-05-14', '2030-05-01'),
	('2030-05-15', '2030-05-01'),
	('2030-05-16', '2030-05-01'),
	('2030-05-17', '2030-05-01'),
	('2030-05-18', '2030-05-01'),
	('2030-05-19', '2030-05-01'),
	('2030-05-20', '2030-05-01'),
	('2030-05-21', '2030-05-01'),
	('2030-05-22', '2030-05-01'),
	('2030-05-23', '2030-05-01'),
	('2030-05-24', '2030-05-01'),
	('2030-05-25', '2030-05-01'),
	('2030-05-26', '2030-05-01'),
	('2030-05-27', '2030-05-01'),
	('2030-05-28', '2030-05-01'),
	('2030-05-29', '2030-05-01'),
	('2030-05-30', '2030-05-01'),
	('2030-05-31', '2030-05-01'),
	('2030-06-01', '2030-06-01'),
	('2030-06-02', '2030-06-01'),
	('2030-06-03', '2030-06-01'),
	('2030-06-04', '2030-06-01'),
	('2030-06-05', '2030-06-01'),
	('2030-06-06', '2030-06-01'),
	('2030-06-07', '2030-06-01'),
	('2030-06-08', '2030-06-01'),
	('2030-06-09', '2030-06-01'),
	('2030-06-10', '2030-06-01'),
	('2030-06-11', '2030-06-01'),
	('2030-06-12', '2030-06-01'),
	('2030-06-13', '2030-06-01'),
	('2030-06-14', '2030-06-01'),
	('2030-06-15', '2030-06-01'),
	('2030-06-16', '2030-06-01'),
	('2030-06-17', '2030-06-01'),
	('2030-06-18', '2030-06-01'),
	('2030-06-19', '2030-06-01'),
	('2030-06-20', '2030-06-01'),
	('2030-06-21', '2030-06-01'),
	('2030-06-22', '2030-06-01'),
	('2030-06-23', '2030-06-01'),
	('2030-06-24', '2030-06-01'),
	('2030-06-25', '2030-06-01'),
	('2030-06-26', '2030-06-01'),
	('2030-06-27', '2030-06-01'),
	('2030-06-28', '2030-06-01'),
	('2030-06-29', '2030-06-01'),
	('2030-06-30', '2030-06-01'),
	('2030-07-01', '2030-07-01'),
	('2030-07-02', '2030-07-01'),
	('2030-07-03', '2030-07-01'),
	('2030-07-04', '2030-07-01'),
	('2030-07-05', '2030-07-01'),
	('2030-07-06', '2030-07-01'),
	('2030-07-07', '2030-07-01'),
	('2030-07-08', '2030-07-01'),
	('2030-07-09', '2030-07-01'),
	('2030-07-10', '2030-07-01'),
	('2030-07-11', '2030-07-01'),
	('2030-07-12', '2030-07-01'),
	('2030-07-13', '2030-07-01'),
	('2030-07-14', '2030-07-01'),
	('2030-07-15', '2030-07-01'),
	('2030-07-16', '2030-07-01'),
	('2030-07-17', '2030-07-01'),
	('2030-07-18', '2030-07-01'),
	('2030-07-19', '2030-07-01'),
	('2030-07-20', '2030-07-01'),
	('2030-07-21', '2030-07-01'),
	('2030-07-22', '2030-07-01'),
	('2030-07-23', '2030-07-01'),
	('2030-07-24', '2030-07-01'),
	('2030-07-25', '2030-07-01'),
	('2030-07-26', '2030-07-01'),
	('2030-07-27', '2030-07-01'),
	('2030-07-28', '2030-07-01'),
	('2030-07-29', '2030-07-01'),
	('2030-07-30', '2030-07-01'),
	('2030-07-31', '2030-07-01'),
	('2030-08-01', '2030-08-01'),
	('2030-08-02', '2030-08-01'),
	('2030-08-03', '2030-08-01'),
	('2030-08-04', '2030-08-01'),
	('2030-08-05', '2030-08-01'),
	('2030-08-06', '2030-08-01'),
	('2030-08-07', '2030-08-01'),
	('2030-08-08', '2030-08-01'),
	('2030-08-09', '2030-08-01'),
	('2030-08-10', '2030-08-01'),
	('2030-08-11', '2030-08-01'),
	('2030-08-12', '2030-08-01'),
	('2030-08-13', '2030-08-01'),
	('2030-08-14', '2030-08-01'),
	('2030-08-15', '2030-08-01'),
	('2030-08-16', '2030-08-01'),
	('2030-08-17', '2030-08-01'),
	('2030-08-18', '2030-08-01'),
	('2030-08-19', '2030-08-01'),
	('2030-08-20', '2030-08-01'),
	('2030-08-21', '2030-08-01'),
	('2030-08-22', '2030-08-01'),
	('2030-08-23', '2030-08-01'),
	('2030-08-24', '2030-08-01'),
	('2030-08-25', '2030-08-01'),
	('2030-08-26', '2030-08-01'),
	('2030-08-27', '2030-08-01'),
	('2030-08-28', '2030-08-01'),
	('2030-08-29', '2030-08-01'),
	('2030-08-30', '2030-08-01'),
	('2030-08-31', '2030-08-01'),
	('2030-09-01', '2030-09-01'),
	('2030-09-02', '2030-09-01'),
	('2030-09-03', '2030-09-01'),
	('2030-09-04', '2030-09-01'),
	('2030-09-05', '2030-09-01'),
	('2030-09-06', '2030-09-01'),
	('2030-09-07', '2030-09-01'),
	('2030-09-08', '2030-09-01'),
	('2030-09-09', '2030-09-01'),
	('2030-09-10', '2030-09-01'),
	('2030-09-11', '2030-09-01'),
	('2030-09-12', '2030-09-01'),
	('2030-09-13', '2030-09-01'),
	('2030-09-14', '2030-09-01'),
	('2030-09-15', '2030-09-01'),
	('2030-09-16', '2030-09-01'),
	('2030-09-17', '2030-09-01'),
	('2030-09-18', '2030-09-01'),
	('2030-09-19', '2030-09-01'),
	('2030-09-20', '2030-09-01'),
	('2030-09-21', '2030-09-01'),
	('2030-09-22', '2030-09-01'),
	('2030-09-23', '2030-09-01'),
	('2030-09-24', '2030-09-01'),
	('2030-09-25', '2030-09-01'),
	('2030-09-26', '2030-09-01'),
	('2030-09-27', '2030-09-01'),
	('2030-09-28', '2030-09-01'),
	('2030-09-29', '2030-09-01'),
	('2030-09-30', '2030-09-01'),
	('2030-10-01', '2030-10-01'),
	('2030-10-02', '2030-10-01'),
	('2030-10-03', '2030-10-01'),
	('2030-10-04', '2030-10-01'),
	('2030-10-05', '2030-10-01'),
	('2030-10-06', '2030-10-01'),
	('2030-10-07', '2030-10-01'),
	('2030-10-08', '2030-10-01'),
	('2030-10-09', '2030-10-01'),
	('2030-10-10', '2030-10-01'),
	('2030-10-11', '2030-10-01'),
	('2030-10-12', '2030-10-01'),
	('2030-10-13', '2030-10-01'),
	('2030-10-14', '2030-10-01'),
	('2030-10-15', '2030-10-01'),
	('2030-10-16', '2030-10-01'),
	('2030-10-17', '2030-10-01'),
	('2030-10-18', '2030-10-01'),
	('2030-10-19', '2030-10-01'),
	('2030-10-20', '2030-10-01'),
	('2030-10-21', '2030-10-01'),
	('2030-10-22', '2030-10-01'),
	('2030-10-23', '2030-10-01'),
	('2030-10-24', '2030-10-01'),
	('2030-10-25', '2030-10-01'),
	('2030-10-26', '2030-10-01'),
	('2030-10-27', '2030-10-01'),
	('2030-10-28', '2030-10-01'),
	('2030-10-29', '2030-10-01'),
	('2030-10-30', '2030-10-01'),
	('2030-10-31', '2030-10-01'),
	('2030-11-01', '2030-11-01'),
	('2030-11-02', '2030-11-01'),
	('2030-11-03', '2030-11-01'),
	('2030-11-04', '2030-11-01'),
	('2030-11-05', '2030-11-01'),
	('2030-11-06', '2030-11-01'),
	('2030-11-07', '2030-11-01'),
	('2030-11-08', '2030-11-01'),
	('2030-11-09', '2030-11-01'),
	('2030-11-10', '2030-11-01'),
	('2030-11-11', '2030-11-01'),
	('2030-11-12', '2030-11-01'),
	('2030-11-13', '2030-11-01'),
	('2030-11-14', '2030-11-01'),
	('2030-11-15', '2030-11-01'),
	('2030-11-16', '2030-11-01'),
	('2030-11-17', '2030-11-01'),
	('2030-11-18', '2030-11-01'),
	('2030-11-19', '2030-11-01'),
	('2030-11-20', '2030-11-01'),
	('2030-11-21', '2030-11-01'),
	('2030-11-22', '2030-11-01'),
	('2030-11-23', '2030-11-01'),
	('2030-11-24', '2030-11-01'),
	('2030-11-25', '2030-11-01'),
	('2030-11-26', '2030-11-01'),
	('2030-11-27', '2030-11-01'),
	('2030-11-28', '2030-11-01'),
	('2030-11-29', '2030-11-01'),
	('2030-11-30', '2030-11-01'),
	('2030-12-01', '2030-12-01'),
	('2030-12-02', '2030-12-01'),
	('2030-12-03', '2030-12-01'),
	('2030-12-04', '2030-12-01'),
	('2030-12-05', '2030-12-01'),
	('2030-12-06', '2030-12-01'),
	('2030-12-07', '2030-12-01'),
	('2030-12-08', '2030-12-01'),
	('2030-12-09', '2030-12-01'),
	('2030-12-10', '2030-12-01'),
	('2030-12-11', '2030-12-01'),
	('2030-12-12', '2030-12-01'),
	('2030-12-13', '2030-12-01'),
	('2030-12-14', '2030-12-01'),
	('2030-12-15', '2030-12-01'),
	('2030-12-16', '2030-12-01'),
	('2030-12-17', '2030-12-01'),
	('2030-12-18', '2030-12-01'),
	('2030-12-19', '2030-12-01'),
	('2030-12-20', '2030-12-01'),
	('2030-12-21', '2030-12-01'),
	('2030-12-22', '2030-12-01'),
	('2030-12-23', '2030-12-01'),
	('2030-12-24', '2030-12-01'),
	('2030-12-25', '2030-12-01'),
	('2030-12-26', '2030-12-01'),
	('2030-12-27', '2030-12-01'),
	('2030-12-28', '2030-12-01'),
	('2030-12-29', '2030-12-01'),
	('2030-12-30', '2030-12-01'),
	('2030-12-31', '2030-12-01'),
	('2031-01-01', '2031-01-01'),
	('2031-01-02', '2031-01-01'),
	('2031-01-03', '2031-01-01'),
	('2031-01-04', '2031-01-01'),
	('2031-01-05', '2031-01-01'),
	('2031-01-06', '2031-01-01'),
	('2031-01-07', '2031-01-01'),
	('2031-01-08', '2031-01-01'),
	('2031-01-09', '2031-01-01'),
	('2031-01-10', '2031-01-01'),
	('2031-01-11', '2031-01-01'),
	('2031-01-12', '2031-01-01'),
	('2031-01-13', '2031-01-01'),
	('2031-01-14', '2031-01-01'),
	('2031-01-15', '2031-01-01'),
	('2031-01-16', '2031-01-01'),
	('2031-01-17', '2031-01-01'),
	('2031-01-18', '2031-01-01'),
	('2031-01-19', '2031-01-01'),
	('2031-01-20', '2031-01-01'),
	('2031-01-21', '2031-01-01'),
	('2031-01-22', '2031-01-01'),
	('2031-01-23', '2031-01-01'),
	('2031-01-24', '2031-01-01'),
	('2031-01-25', '2031-01-01'),
	('2031-01-26', '2031-01-01'),
	('2031-01-27', '2031-01-01'),
	('2031-01-28', '2031-01-01'),
	('2031-01-29', '2031-01-01'),
	('2031-01-30', '2031-01-01'),
	('2031-01-31', '2031-01-01'),
	('2031-02-01', '2031-02-01'),
	('2031-02-02', '2031-02-01'),
	('2031-02-03', '2031-02-01'),
	('2031-02-04', '2031-02-01'),
	('2031-02-05', '2031-02-01'),
	('2031-02-06', '2031-02-01'),
	('2031-02-07', '2031-02-01'),
	('2031-02-08', '2031-02-01'),
	('2031-02-09', '2031-02-01'),
	('2031-02-10', '2031-02-01'),
	('2031-02-11', '2031-02-01'),
	('2031-02-12', '2031-02-01'),
	('2031-02-13', '2031-02-01'),
	('2031-02-14', '2031-02-01'),
	('2031-02-15', '2031-02-01'),
	('2031-02-16', '2031-02-01'),
	('2031-02-17', '2031-02-01'),
	('2031-02-18', '2031-02-01'),
	('2031-02-19', '2031-02-01'),
	('2031-02-20', '2031-02-01'),
	('2031-02-21', '2031-02-01'),
	('2031-02-22', '2031-02-01'),
	('2031-02-23', '2031-02-01'),
	('2031-02-24', '2031-02-01'),
	('2031-02-25', '2031-02-01'),
	('2031-02-26', '2031-02-01'),
	('2031-02-27', '2031-02-01'),
	('2031-02-28', '2031-02-01'),
	('2031-03-01', '2031-03-01'),
	('2031-03-02', '2031-03-01'),
	('2031-03-03', '2031-03-01'),
	('2031-03-04', '2031-03-01'),
	('2031-03-05', '2031-03-01'),
	('2031-03-06', '2031-03-01'),
	('2031-03-07', '2031-03-01'),
	('2031-03-08', '2031-03-01'),
	('2031-03-09', '2031-03-01'),
	('2031-03-10', '2031-03-01'),
	('2031-03-11', '2031-03-01'),
	('2031-03-12', '2031-03-01'),
	('2031-03-13', '2031-03-01'),
	('2031-03-14', '2031-03-01'),
	('2031-03-15', '2031-03-01'),
	('2031-03-16', '2031-03-01'),
	('2031-03-17', '2031-03-01'),
	('2031-03-18', '2031-03-01'),
	('2031-03-19', '2031-03-01'),
	('2031-03-20', '2031-03-01'),
	('2031-03-21', '2031-03-01'),
	('2031-03-22', '2031-03-01'),
	('2031-03-23', '2031-03-01'),
	('2031-03-24', '2031-03-01'),
	('2031-03-25', '2031-03-01'),
	('2031-03-26', '2031-03-01'),
	('2031-03-27', '2031-03-01'),
	('2031-03-28', '2031-03-01'),
	('2031-03-29', '2031-03-01'),
	('2031-03-30', '2031-03-01'),
	('2031-03-31', '2031-03-01'),
	('2031-04-01', '2031-04-01'),
	('2031-04-02', '2031-04-01'),
	('2031-04-03', '2031-04-01'),
	('2031-04-04', '2031-04-01'),
	('2031-04-05', '2031-04-01'),
	('2031-04-06', '2031-04-01'),
	('2031-04-07', '2031-04-01'),
	('2031-04-08', '2031-04-01'),
	('2031-04-09', '2031-04-01'),
	('2031-04-10', '2031-04-01'),
	('2031-04-11', '2031-04-01'),
	('2031-04-12', '2031-04-01'),
	('2031-04-13', '2031-04-01'),
	('2031-04-14', '2031-04-01'),
	('2031-04-15', '2031-04-01'),
	('2031-04-16', '2031-04-01'),
	('2031-04-17', '2031-04-01'),
	('2031-04-18', '2031-04-01'),
	('2031-04-19', '2031-04-01'),
	('2031-04-20', '2031-04-01'),
	('2031-04-21', '2031-04-01'),
	('2031-04-22', '2031-04-01'),
	('2031-04-23', '2031-04-01'),
	('2031-04-24', '2031-04-01'),
	('2031-04-25', '2031-04-01'),
	('2031-04-26', '2031-04-01'),
	('2031-04-27', '2031-04-01'),
	('2031-04-28', '2031-04-01'),
	('2031-04-29', '2031-04-01'),
	('2031-04-30', '2031-04-01'),
	('2031-05-01', '2031-05-01'),
	('2031-05-02', '2031-05-01'),
	('2031-05-03', '2031-05-01'),
	('2031-05-04', '2031-05-01'),
	('2031-05-05', '2031-05-01'),
	('2031-05-06', '2031-05-01'),
	('2031-05-07', '2031-05-01'),
	('2031-05-08', '2031-05-01'),
	('2031-05-09', '2031-05-01'),
	('2031-05-10', '2031-05-01'),
	('2031-05-11', '2031-05-01'),
	('2031-05-12', '2031-05-01'),
	('2031-05-13', '2031-05-01'),
	('2031-05-14', '2031-05-01'),
	('2031-05-15', '2031-05-01'),
	('2031-05-16', '2031-05-01'),
	('2031-05-17', '2031-05-01'),
	('2031-05-18', '2031-05-01'),
	('2031-05-19', '2031-05-01'),
	('2031-05-20', '2031-05-01'),
	('2031-05-21', '2031-05-01'),
	('2031-05-22', '2031-05-01'),
	('2031-05-23', '2031-05-01'),
	('2031-05-24', '2031-05-01'),
	('2031-05-25', '2031-05-01'),
	('2031-05-26', '2031-05-01'),
	('2031-05-27', '2031-05-01'),
	('2031-05-28', '2031-05-01'),
	('2031-05-29', '2031-05-01'),
	('2031-05-30', '2031-05-01'),
	('2031-05-31', '2031-05-01'),
	('2031-06-01', '2031-06-01'),
	('2031-06-02', '2031-06-01'),
	('2031-06-03', '2031-06-01'),
	('2031-06-04', '2031-06-01'),
	('2031-06-05', '2031-06-01'),
	('2031-06-06', '2031-06-01'),
	('2031-06-07', '2031-06-01'),
	('2031-06-08', '2031-06-01'),
	('2031-06-09', '2031-06-01'),
	('2031-06-10', '2031-06-01'),
	('2031-06-11', '2031-06-01'),
	('2031-06-12', '2031-06-01'),
	('2031-06-13', '2031-06-01'),
	('2031-06-14', '2031-06-01'),
	('2031-06-15', '2031-06-01'),
	('2031-06-16', '2031-06-01'),
	('2031-06-17', '2031-06-01'),
	('2031-06-18', '2031-06-01'),
	('2031-06-19', '2031-06-01'),
	('2031-06-20', '2031-06-01'),
	('2031-06-21', '2031-06-01'),
	('2031-06-22', '2031-06-01'),
	('2031-06-23', '2031-06-01'),
	('2031-06-24', '2031-06-01'),
	('2031-06-25', '2031-06-01'),
	('2031-06-26', '2031-06-01'),
	('2031-06-27', '2031-06-01'),
	('2031-06-28', '2031-06-01'),
	('2031-06-29', '2031-06-01'),
	('2031-06-30', '2031-06-01'),
	('2031-07-01', '2031-07-01'),
	('2031-07-02', '2031-07-01'),
	('2031-07-03', '2031-07-01'),
	('2031-07-04', '2031-07-01'),
	('2031-07-05', '2031-07-01'),
	('2031-07-06', '2031-07-01'),
	('2031-07-07', '2031-07-01'),
	('2031-07-08', '2031-07-01'),
	('2031-07-09', '2031-07-01'),
	('2031-07-10', '2031-07-01'),
	('2031-07-11', '2031-07-01'),
	('2031-07-12', '2031-07-01'),
	('2031-07-13', '2031-07-01'),
	('2031-07-14', '2031-07-01'),
	('2031-07-15', '2031-07-01'),
	('2031-07-16', '2031-07-01'),
	('2031-07-17', '2031-07-01'),
	('2031-07-18', '2031-07-01'),
	('2031-07-19', '2031-07-01'),
	('2031-07-20', '2031-07-01'),
	('2031-07-21', '2031-07-01'),
	('2031-07-22', '2031-07-01'),
	('2031-07-23', '2031-07-01'),
	('2031-07-24', '2031-07-01'),
	('2031-07-25', '2031-07-01'),
	('2031-07-26', '2031-07-01'),
	('2031-07-27', '2031-07-01'),
	('2031-07-28', '2031-07-01'),
	('2031-07-29', '2031-07-01'),
	('2031-07-30', '2031-07-01'),
	('2031-07-31', '2031-07-01'),
	('2031-08-01', '2031-08-01'),
	('2031-08-02', '2031-08-01'),
	('2031-08-03', '2031-08-01'),
	('2031-08-04', '2031-08-01'),
	('2031-08-05', '2031-08-01'),
	('2031-08-06', '2031-08-01'),
	('2031-08-07', '2031-08-01'),
	('2031-08-08', '2031-08-01'),
	('2031-08-09', '2031-08-01'),
	('2031-08-10', '2031-08-01'),
	('2031-08-11', '2031-08-01'),
	('2031-08-12', '2031-08-01'),
	('2031-08-13', '2031-08-01'),
	('2031-08-14', '2031-08-01'),
	('2031-08-15', '2031-08-01'),
	('2031-08-16', '2031-08-01'),
	('2031-08-17', '2031-08-01'),
	('2031-08-18', '2031-08-01'),
	('2031-08-19', '2031-08-01'),
	('2031-08-20', '2031-08-01'),
	('2031-08-21', '2031-08-01'),
	('2031-08-22', '2031-08-01'),
	('2031-08-23', '2031-08-01'),
	('2031-08-24', '2031-08-01'),
	('2031-08-25', '2031-08-01'),
	('2031-08-26', '2031-08-01'),
	('2031-08-27', '2031-08-01'),
	('2031-08-28', '2031-08-01'),
	('2031-08-29', '2031-08-01'),
	('2031-08-30', '2031-08-01'),
	('2031-08-31', '2031-08-01'),
	('2031-09-01', '2031-09-01'),
	('2031-09-02', '2031-09-01'),
	('2031-09-03', '2031-09-01'),
	('2031-09-04', '2031-09-01'),
	('2031-09-05', '2031-09-01'),
	('2031-09-06', '2031-09-01'),
	('2031-09-07', '2031-09-01'),
	('2031-09-08', '2031-09-01'),
	('2031-09-09', '2031-09-01'),
	('2031-09-10', '2031-09-01'),
	('2031-09-11', '2031-09-01'),
	('2031-09-12', '2031-09-01'),
	('2031-09-13', '2031-09-01'),
	('2031-09-14', '2031-09-01'),
	('2031-09-15', '2031-09-01'),
	('2031-09-16', '2031-09-01'),
	('2031-09-17', '2031-09-01'),
	('2031-09-18', '2031-09-01'),
	('2031-09-19', '2031-09-01'),
	('2031-09-20', '2031-09-01'),
	('2031-09-21', '2031-09-01'),
	('2031-09-22', '2031-09-01'),
	('2031-09-23', '2031-09-01'),
	('2031-09-24', '2031-09-01'),
	('2031-09-25', '2031-09-01'),
	('2031-09-26', '2031-09-01'),
	('2031-09-27', '2031-09-01'),
	('2031-09-28', '2031-09-01'),
	('2031-09-29', '2031-09-01'),
	('2031-09-30', '2031-09-01'),
	('2031-10-01', '2031-10-01'),
	('2031-10-02', '2031-10-01'),
	('2031-10-03', '2031-10-01'),
	('2031-10-04', '2031-10-01'),
	('2031-10-05', '2031-10-01'),
	('2031-10-06', '2031-10-01'),
	('2031-10-07', '2031-10-01'),
	('2031-10-08', '2031-10-01'),
	('2031-10-09', '2031-10-01'),
	('2031-10-10', '2031-10-01'),
	('2031-10-11', '2031-10-01'),
	('2031-10-12', '2031-10-01'),
	('2031-10-13', '2031-10-01'),
	('2031-10-14', '2031-10-01'),
	('2031-10-15', '2031-10-01'),
	('2031-10-16', '2031-10-01'),
	('2031-10-17', '2031-10-01'),
	('2031-10-18', '2031-10-01'),
	('2031-10-19', '2031-10-01'),
	('2031-10-20', '2031-10-01'),
	('2031-10-21', '2031-10-01'),
	('2031-10-22', '2031-10-01'),
	('2031-10-23', '2031-10-01'),
	('2031-10-24', '2031-10-01'),
	('2031-10-25', '2031-10-01'),
	('2031-10-26', '2031-10-01'),
	('2031-10-27', '2031-10-01'),
	('2031-10-28', '2031-10-01'),
	('2031-10-29', '2031-10-01'),
	('2031-10-30', '2031-10-01'),
	('2031-10-31', '2031-10-01'),
	('2031-11-01', '2031-11-01'),
	('2031-11-02', '2031-11-01'),
	('2031-11-03', '2031-11-01'),
	('2031-11-04', '2031-11-01'),
	('2031-11-05', '2031-11-01'),
	('2031-11-06', '2031-11-01'),
	('2031-11-07', '2031-11-01'),
	('2031-11-08', '2031-11-01'),
	('2031-11-09', '2031-11-01'),
	('2031-11-10', '2031-11-01'),
	('2031-11-11', '2031-11-01'),
	('2031-11-12', '2031-11-01'),
	('2031-11-13', '2031-11-01'),
	('2031-11-14', '2031-11-01'),
	('2031-11-15', '2031-11-01'),
	('2031-11-16', '2031-11-01'),
	('2031-11-17', '2031-11-01'),
	('2031-11-18', '2031-11-01'),
	('2031-11-19', '2031-11-01'),
	('2031-11-20', '2031-11-01'),
	('2031-11-21', '2031-11-01'),
	('2031-11-22', '2031-11-01'),
	('2031-11-23', '2031-11-01'),
	('2031-11-24', '2031-11-01'),
	('2031-11-25', '2031-11-01'),
	('2031-11-26', '2031-11-01'),
	('2031-11-27', '2031-11-01'),
	('2031-11-28', '2031-11-01'),
	('2031-11-29', '2031-11-01'),
	('2031-11-30', '2031-11-01'),
	('2031-12-01', '2031-12-01'),
	('2031-12-02', '2031-12-01'),
	('2031-12-03', '2031-12-01'),
	('2031-12-04', '2031-12-01'),
	('2031-12-05', '2031-12-01'),
	('2031-12-06', '2031-12-01'),
	('2031-12-07', '2031-12-01'),
	('2031-12-08', '2031-12-01'),
	('2031-12-09', '2031-12-01'),
	('2031-12-10', '2031-12-01'),
	('2031-12-11', '2031-12-01'),
	('2031-12-12', '2031-12-01'),
	('2031-12-13', '2031-12-01'),
	('2031-12-14', '2031-12-01'),
	('2031-12-15', '2031-12-01'),
	('2031-12-16', '2031-12-01'),
	('2031-12-17', '2031-12-01'),
	('2031-12-18', '2031-12-01'),
	('2031-12-19', '2031-12-01'),
	('2031-12-20', '2031-12-01'),
	('2031-12-21', '2031-12-01'),
	('2031-12-22', '2031-12-01'),
	('2031-12-23', '2031-12-01'),
	('2031-12-24', '2031-12-01'),
	('2031-12-25', '2031-12-01'),
	('2031-12-26', '2031-12-01'),
	('2031-12-27', '2031-12-01'),
	('2031-12-28', '2031-12-01'),
	('2031-12-29', '2031-12-01'),
	('2031-12-30', '2031-12-01'),
	('2031-12-31', '2031-12-01'),
	('2032-01-01', '2032-01-01'),
	('2032-01-02', '2032-01-01'),
	('2032-01-03', '2032-01-01'),
	('2032-01-04', '2032-01-01'),
	('2032-01-05', '2032-01-01'),
	('2032-01-06', '2032-01-01'),
	('2032-01-07', '2032-01-01'),
	('2032-01-08', '2032-01-01'),
	('2032-01-09', '2032-01-01'),
	('2032-01-10', '2032-01-01'),
	('2032-01-11', '2032-01-01'),
	('2032-01-12', '2032-01-01'),
	('2032-01-13', '2032-01-01'),
	('2032-01-14', '2032-01-01'),
	('2032-01-15', '2032-01-01'),
	('2032-01-16', '2032-01-01'),
	('2032-01-17', '2032-01-01'),
	('2032-01-18', '2032-01-01'),
	('2032-01-19', '2032-01-01'),
	('2032-01-20', '2032-01-01'),
	('2032-01-21', '2032-01-01'),
	('2032-01-22', '2032-01-01'),
	('2032-01-23', '2032-01-01'),
	('2032-01-24', '2032-01-01'),
	('2032-01-25', '2032-01-01'),
	('2032-01-26', '2032-01-01'),
	('2032-01-27', '2032-01-01'),
	('2032-01-28', '2032-01-01'),
	('2032-01-29', '2032-01-01'),
	('2032-01-30', '2032-01-01'),
	('2032-01-31', '2032-01-01'),
	('2032-02-01', '2032-02-01'),
	('2032-02-02', '2032-02-01'),
	('2032-02-03', '2032-02-01'),
	('2032-02-04', '2032-02-01'),
	('2032-02-05', '2032-02-01'),
	('2032-02-06', '2032-02-01'),
	('2032-02-07', '2032-02-01'),
	('2032-02-08', '2032-02-01'),
	('2032-02-09', '2032-02-01'),
	('2032-02-10', '2032-02-01'),
	('2032-02-11', '2032-02-01'),
	('2032-02-12', '2032-02-01'),
	('2032-02-13', '2032-02-01'),
	('2032-02-14', '2032-02-01'),
	('2032-02-15', '2032-02-01'),
	('2032-02-16', '2032-02-01'),
	('2032-02-17', '2032-02-01'),
	('2032-02-18', '2032-02-01'),
	('2032-02-19', '2032-02-01'),
	('2032-02-20', '2032-02-01'),
	('2032-02-21', '2032-02-01'),
	('2032-02-22', '2032-02-01'),
	('2032-02-23', '2032-02-01'),
	('2032-02-24', '2032-02-01'),
	('2032-02-25', '2032-02-01'),
	('2032-02-26', '2032-02-01'),
	('2032-02-27', '2032-02-01'),
	('2032-02-28', '2032-02-01'),
	('2032-02-29', '2032-02-01'),
	('2032-03-01', '2032-03-01'),
	('2032-03-02', '2032-03-01'),
	('2032-03-03', '2032-03-01'),
	('2032-03-04', '2032-03-01'),
	('2032-03-05', '2032-03-01'),
	('2032-03-06', '2032-03-01'),
	('2032-03-07', '2032-03-01'),
	('2032-03-08', '2032-03-01'),
	('2032-03-09', '2032-03-01'),
	('2032-03-10', '2032-03-01'),
	('2032-03-11', '2032-03-01'),
	('2032-03-12', '2032-03-01'),
	('2032-03-13', '2032-03-01'),
	('2032-03-14', '2032-03-01'),
	('2032-03-15', '2032-03-01'),
	('2032-03-16', '2032-03-01'),
	('2032-03-17', '2032-03-01'),
	('2032-03-18', '2032-03-01'),
	('2032-03-19', '2032-03-01'),
	('2032-03-20', '2032-03-01'),
	('2032-03-21', '2032-03-01'),
	('2032-03-22', '2032-03-01'),
	('2032-03-23', '2032-03-01'),
	('2032-03-24', '2032-03-01'),
	('2032-03-25', '2032-03-01'),
	('2032-03-26', '2032-03-01'),
	('2032-03-27', '2032-03-01'),
	('2032-03-28', '2032-03-01'),
	('2032-03-29', '2032-03-01'),
	('2032-03-30', '2032-03-01'),
	('2032-03-31', '2032-03-01'),
	('2032-04-01', '2032-04-01'),
	('2032-04-02', '2032-04-01'),
	('2032-04-03', '2032-04-01'),
	('2032-04-04', '2032-04-01'),
	('2032-04-05', '2032-04-01'),
	('2032-04-06', '2032-04-01'),
	('2032-04-07', '2032-04-01'),
	('2032-04-08', '2032-04-01'),
	('2032-04-09', '2032-04-01'),
	('2032-04-10', '2032-04-01'),
	('2032-04-11', '2032-04-01'),
	('2032-04-12', '2032-04-01'),
	('2032-04-13', '2032-04-01'),
	('2032-04-14', '2032-04-01'),
	('2032-04-15', '2032-04-01'),
	('2032-04-16', '2032-04-01'),
	('2032-04-17', '2032-04-01'),
	('2032-04-18', '2032-04-01'),
	('2032-04-19', '2032-04-01'),
	('2032-04-20', '2032-04-01'),
	('2032-04-21', '2032-04-01'),
	('2032-04-22', '2032-04-01'),
	('2032-04-23', '2032-04-01'),
	('2032-04-24', '2032-04-01'),
	('2032-04-25', '2032-04-01'),
	('2032-04-26', '2032-04-01'),
	('2032-04-27', '2032-04-01'),
	('2032-04-28', '2032-04-01'),
	('2032-04-29', '2032-04-01'),
	('2032-04-30', '2032-04-01'),
	('2032-05-01', '2032-05-01'),
	('2032-05-02', '2032-05-01'),
	('2032-05-03', '2032-05-01'),
	('2032-05-04', '2032-05-01'),
	('2032-05-05', '2032-05-01'),
	('2032-05-06', '2032-05-01'),
	('2032-05-07', '2032-05-01'),
	('2032-05-08', '2032-05-01'),
	('2032-05-09', '2032-05-01'),
	('2032-05-10', '2032-05-01'),
	('2032-05-11', '2032-05-01'),
	('2032-05-12', '2032-05-01'),
	('2032-05-13', '2032-05-01'),
	('2032-05-14', '2032-05-01'),
	('2032-05-15', '2032-05-01'),
	('2032-05-16', '2032-05-01'),
	('2032-05-17', '2032-05-01'),
	('2032-05-18', '2032-05-01'),
	('2032-05-19', '2032-05-01'),
	('2032-05-20', '2032-05-01'),
	('2032-05-21', '2032-05-01'),
	('2032-05-22', '2032-05-01'),
	('2032-05-23', '2032-05-01'),
	('2032-05-24', '2032-05-01'),
	('2032-05-25', '2032-05-01'),
	('2032-05-26', '2032-05-01'),
	('2032-05-27', '2032-05-01'),
	('2032-05-28', '2032-05-01'),
	('2032-05-29', '2032-05-01'),
	('2032-05-30', '2032-05-01'),
	('2032-05-31', '2032-05-01'),
	('2032-06-01', '2032-06-01'),
	('2032-06-02', '2032-06-01'),
	('2032-06-03', '2032-06-01'),
	('2032-06-04', '2032-06-01'),
	('2032-06-05', '2032-06-01'),
	('2032-06-06', '2032-06-01'),
	('2032-06-07', '2032-06-01'),
	('2032-06-08', '2032-06-01'),
	('2032-06-09', '2032-06-01'),
	('2032-06-10', '2032-06-01'),
	('2032-06-11', '2032-06-01'),
	('2032-06-12', '2032-06-01'),
	('2032-06-13', '2032-06-01'),
	('2032-06-14', '2032-06-01'),
	('2032-06-15', '2032-06-01'),
	('2032-06-16', '2032-06-01'),
	('2032-06-17', '2032-06-01'),
	('2032-06-18', '2032-06-01'),
	('2032-06-19', '2032-06-01'),
	('2032-06-20', '2032-06-01'),
	('2032-06-21', '2032-06-01'),
	('2032-06-22', '2032-06-01'),
	('2032-06-23', '2032-06-01'),
	('2032-06-24', '2032-06-01'),
	('2032-06-25', '2032-06-01'),
	('2032-06-26', '2032-06-01'),
	('2032-06-27', '2032-06-01'),
	('2032-06-28', '2032-06-01'),
	('2032-06-29', '2032-06-01'),
	('2032-06-30', '2032-06-01'),
	('2032-07-01', '2032-07-01'),
	('2032-07-02', '2032-07-01'),
	('2032-07-03', '2032-07-01'),
	('2032-07-04', '2032-07-01'),
	('2032-07-05', '2032-07-01'),
	('2032-07-06', '2032-07-01'),
	('2032-07-07', '2032-07-01'),
	('2032-07-08', '2032-07-01'),
	('2032-07-09', '2032-07-01'),
	('2032-07-10', '2032-07-01'),
	('2032-07-11', '2032-07-01'),
	('2032-07-12', '2032-07-01'),
	('2032-07-13', '2032-07-01'),
	('2032-07-14', '2032-07-01'),
	('2032-07-15', '2032-07-01'),
	('2032-07-16', '2032-07-01'),
	('2032-07-17', '2032-07-01'),
	('2032-07-18', '2032-07-01'),
	('2032-07-19', '2032-07-01'),
	('2032-07-20', '2032-07-01'),
	('2032-07-21', '2032-07-01'),
	('2032-07-22', '2032-07-01'),
	('2032-07-23', '2032-07-01'),
	('2032-07-24', '2032-07-01'),
	('2032-07-25', '2032-07-01'),
	('2032-07-26', '2032-07-01'),
	('2032-07-27', '2032-07-01'),
	('2032-07-28', '2032-07-01'),
	('2032-07-29', '2032-07-01'),
	('2032-07-30', '2032-07-01'),
	('2032-07-31', '2032-07-01'),
	('2032-08-01', '2032-08-01'),
	('2032-08-02', '2032-08-01'),
	('2032-08-03', '2032-08-01'),
	('2032-08-04', '2032-08-01'),
	('2032-08-05', '2032-08-01'),
	('2032-08-06', '2032-08-01'),
	('2032-08-07', '2032-08-01'),
	('2032-08-08', '2032-08-01'),
	('2032-08-09', '2032-08-01'),
	('2032-08-10', '2032-08-01'),
	('2032-08-11', '2032-08-01'),
	('2032-08-12', '2032-08-01'),
	('2032-08-13', '2032-08-01'),
	('2032-08-14', '2032-08-01'),
	('2032-08-15', '2032-08-01'),
	('2032-08-16', '2032-08-01'),
	('2032-08-17', '2032-08-01'),
	('2032-08-18', '2032-08-01'),
	('2032-08-19', '2032-08-01'),
	('2032-08-20', '2032-08-01'),
	('2032-08-21', '2032-08-01'),
	('2032-08-22', '2032-08-01'),
	('2032-08-23', '2032-08-01'),
	('2032-08-24', '2032-08-01'),
	('2032-08-25', '2032-08-01'),
	('2032-08-26', '2032-08-01'),
	('2032-08-27', '2032-08-01'),
	('2032-08-28', '2032-08-01'),
	('2032-08-29', '2032-08-01'),
	('2032-08-30', '2032-08-01'),
	('2032-08-31', '2032-08-01'),
	('2032-09-01', '2032-09-01'),
	('2032-09-02', '2032-09-01'),
	('2032-09-03', '2032-09-01'),
	('2032-09-04', '2032-09-01'),
	('2032-09-05', '2032-09-01'),
	('2032-09-06', '2032-09-01'),
	('2032-09-07', '2032-09-01'),
	('2032-09-08', '2032-09-01'),
	('2032-09-09', '2032-09-01'),
	('2032-09-10', '2032-09-01'),
	('2032-09-11', '2032-09-01'),
	('2032-09-12', '2032-09-01'),
	('2032-09-13', '2032-09-01'),
	('2032-09-14', '2032-09-01'),
	('2032-09-15', '2032-09-01'),
	('2032-09-16', '2032-09-01'),
	('2032-09-17', '2032-09-01'),
	('2032-09-18', '2032-09-01'),
	('2032-09-19', '2032-09-01'),
	('2032-09-20', '2032-09-01'),
	('2032-09-21', '2032-09-01'),
	('2032-09-22', '2032-09-01'),
	('2032-09-23', '2032-09-01'),
	('2032-09-24', '2032-09-01'),
	('2032-09-25', '2032-09-01'),
	('2032-09-26', '2032-09-01'),
	('2032-09-27', '2032-09-01'),
	('2032-09-28', '2032-09-01'),
	('2032-09-29', '2032-09-01'),
	('2032-09-30', '2032-09-01'),
	('2032-10-01', '2032-10-01'),
	('2032-10-02', '2032-10-01'),
	('2032-10-03', '2032-10-01'),
	('2032-10-04', '2032-10-01'),
	('2032-10-05', '2032-10-01'),
	('2032-10-06', '2032-10-01'),
	('2032-10-07', '2032-10-01'),
	('2032-10-08', '2032-10-01'),
	('2032-10-09', '2032-10-01'),
	('2032-10-10', '2032-10-01'),
	('2032-10-11', '2032-10-01'),
	('2032-10-12', '2032-10-01'),
	('2032-10-13', '2032-10-01'),
	('2032-10-14', '2032-10-01'),
	('2032-10-15', '2032-10-01'),
	('2032-10-16', '2032-10-01'),
	('2032-10-17', '2032-10-01'),
	('2032-10-18', '2032-10-01'),
	('2032-10-19', '2032-10-01'),
	('2032-10-20', '2032-10-01'),
	('2032-10-21', '2032-10-01'),
	('2032-10-22', '2032-10-01'),
	('2032-10-23', '2032-10-01'),
	('2032-10-24', '2032-10-01'),
	('2032-10-25', '2032-10-01'),
	('2032-10-26', '2032-10-01'),
	('2032-10-27', '2032-10-01'),
	('2032-10-28', '2032-10-01'),
	('2032-10-29', '2032-10-01'),
	('2032-10-30', '2032-10-01'),
	('2032-10-31', '2032-10-01'),
	('2032-11-01', '2032-11-01'),
	('2032-11-02', '2032-11-01'),
	('2032-11-03', '2032-11-01'),
	('2032-11-04', '2032-11-01'),
	('2032-11-05', '2032-11-01'),
	('2032-11-06', '2032-11-01'),
	('2032-11-07', '2032-11-01'),
	('2032-11-08', '2032-11-01'),
	('2032-11-09', '2032-11-01'),
	('2032-11-10', '2032-11-01'),
	('2032-11-11', '2032-11-01'),
	('2032-11-12', '2032-11-01'),
	('2032-11-13', '2032-11-01'),
	('2032-11-14', '2032-11-01'),
	('2032-11-15', '2032-11-01'),
	('2032-11-16', '2032-11-01'),
	('2032-11-17', '2032-11-01'),
	('2032-11-18', '2032-11-01'),
	('2032-11-19', '2032-11-01'),
	('2032-11-20', '2032-11-01'),
	('2032-11-21', '2032-11-01'),
	('2032-11-22', '2032-11-01'),
	('2032-11-23', '2032-11-01'),
	('2032-11-24', '2032-11-01'),
	('2032-11-25', '2032-11-01'),
	('2032-11-26', '2032-11-01'),
	('2032-11-27', '2032-11-01'),
	('2032-11-28', '2032-11-01'),
	('2032-11-29', '2032-11-01'),
	('2032-11-30', '2032-11-01'),
	('2032-12-01', '2032-12-01'),
	('2032-12-02', '2032-12-01'),
	('2032-12-03', '2032-12-01'),
	('2032-12-04', '2032-12-01'),
	('2032-12-05', '2032-12-01'),
	('2032-12-06', '2032-12-01'),
	('2032-12-07', '2032-12-01'),
	('2032-12-08', '2032-12-01'),
	('2032-12-09', '2032-12-01'),
	('2032-12-10', '2032-12-01'),
	('2032-12-11', '2032-12-01'),
	('2032-12-12', '2032-12-01'),
	('2032-12-13', '2032-12-01'),
	('2032-12-14', '2032-12-01'),
	('2032-12-15', '2032-12-01'),
	('2032-12-16', '2032-12-01'),
	('2032-12-17', '2032-12-01'),
	('2032-12-18', '2032-12-01'),
	('2032-12-19', '2032-12-01'),
	('2032-12-20', '2032-12-01'),
	('2032-12-21', '2032-12-01'),
	('2032-12-22', '2032-12-01'),
	('2032-12-23', '2032-12-01'),
	('2032-12-24', '2032-12-01'),
	('2032-12-25', '2032-12-01'),
	('2032-12-26', '2032-12-01'),
	('2032-12-27', '2032-12-01'),
	('2032-12-28', '2032-12-01'),
	('2032-12-29', '2032-12-01'),
	('2032-12-30', '2032-12-01'),
	('2032-12-31', '2032-12-01'),
	('2033-01-01', '2033-01-01'),
	('2033-01-02', '2033-01-01'),
	('2033-01-03', '2033-01-01'),
	('2033-01-04', '2033-01-01'),
	('2033-01-05', '2033-01-01'),
	('2033-01-06', '2033-01-01'),
	('2033-01-07', '2033-01-01'),
	('2033-01-08', '2033-01-01'),
	('2033-01-09', '2033-01-01'),
	('2033-01-10', '2033-01-01'),
	('2033-01-11', '2033-01-01'),
	('2033-01-12', '2033-01-01'),
	('2033-01-13', '2033-01-01'),
	('2033-01-14', '2033-01-01'),
	('2033-01-15', '2033-01-01'),
	('2033-01-16', '2033-01-01'),
	('2033-01-17', '2033-01-01'),
	('2033-01-18', '2033-01-01'),
	('2033-01-19', '2033-01-01'),
	('2033-01-20', '2033-01-01'),
	('2033-01-21', '2033-01-01'),
	('2033-01-22', '2033-01-01'),
	('2033-01-23', '2033-01-01'),
	('2033-01-24', '2033-01-01'),
	('2033-01-25', '2033-01-01'),
	('2033-01-26', '2033-01-01'),
	('2033-01-27', '2033-01-01'),
	('2033-01-28', '2033-01-01'),
	('2033-01-29', '2033-01-01'),
	('2033-01-30', '2033-01-01'),
	('2033-01-31', '2033-01-01'),
	('2033-02-01', '2033-02-01'),
	('2033-02-02', '2033-02-01'),
	('2033-02-03', '2033-02-01'),
	('2033-02-04', '2033-02-01'),
	('2033-02-05', '2033-02-01'),
	('2033-02-06', '2033-02-01'),
	('2033-02-07', '2033-02-01'),
	('2033-02-08', '2033-02-01'),
	('2033-02-09', '2033-02-01'),
	('2033-02-10', '2033-02-01'),
	('2033-02-11', '2033-02-01'),
	('2033-02-12', '2033-02-01'),
	('2033-02-13', '2033-02-01'),
	('2033-02-14', '2033-02-01'),
	('2033-02-15', '2033-02-01'),
	('2033-02-16', '2033-02-01'),
	('2033-02-17', '2033-02-01'),
	('2033-02-18', '2033-02-01'),
	('2033-02-19', '2033-02-01'),
	('2033-02-20', '2033-02-01'),
	('2033-02-21', '2033-02-01'),
	('2033-02-22', '2033-02-01'),
	('2033-02-23', '2033-02-01'),
	('2033-02-24', '2033-02-01'),
	('2033-02-25', '2033-02-01'),
	('2033-02-26', '2033-02-01'),
	('2033-02-27', '2033-02-01'),
	('2033-02-28', '2033-02-01'),
	('2033-03-01', '2033-03-01'),
	('2033-03-02', '2033-03-01'),
	('2033-03-03', '2033-03-01'),
	('2033-03-04', '2033-03-01'),
	('2033-03-05', '2033-03-01'),
	('2033-03-06', '2033-03-01'),
	('2033-03-07', '2033-03-01'),
	('2033-03-08', '2033-03-01'),
	('2033-03-09', '2033-03-01'),
	('2033-03-10', '2033-03-01'),
	('2033-03-11', '2033-03-01'),
	('2033-03-12', '2033-03-01'),
	('2033-03-13', '2033-03-01'),
	('2033-03-14', '2033-03-01'),
	('2033-03-15', '2033-03-01'),
	('2033-03-16', '2033-03-01'),
	('2033-03-17', '2033-03-01'),
	('2033-03-18', '2033-03-01'),
	('2033-03-19', '2033-03-01'),
	('2033-03-20', '2033-03-01'),
	('2033-03-21', '2033-03-01'),
	('2033-03-22', '2033-03-01'),
	('2033-03-23', '2033-03-01'),
	('2033-03-24', '2033-03-01'),
	('2033-03-25', '2033-03-01'),
	('2033-03-26', '2033-03-01'),
	('2033-03-27', '2033-03-01'),
	('2033-03-28', '2033-03-01'),
	('2033-03-29', '2033-03-01'),
	('2033-03-30', '2033-03-01'),
	('2033-03-31', '2033-03-01'),
	('2033-04-01', '2033-04-01'),
	('2033-04-02', '2033-04-01'),
	('2033-04-03', '2033-04-01'),
	('2033-04-04', '2033-04-01'),
	('2033-04-05', '2033-04-01'),
	('2033-04-06', '2033-04-01'),
	('2033-04-07', '2033-04-01'),
	('2033-04-08', '2033-04-01'),
	('2033-04-09', '2033-04-01'),
	('2033-04-10', '2033-04-01'),
	('2033-04-11', '2033-04-01'),
	('2033-04-12', '2033-04-01'),
	('2033-04-13', '2033-04-01'),
	('2033-04-14', '2033-04-01'),
	('2033-04-15', '2033-04-01'),
	('2033-04-16', '2033-04-01'),
	('2033-04-17', '2033-04-01'),
	('2033-04-18', '2033-04-01'),
	('2033-04-19', '2033-04-01'),
	('2033-04-20', '2033-04-01'),
	('2033-04-21', '2033-04-01'),
	('2033-04-22', '2033-04-01'),
	('2033-04-23', '2033-04-01'),
	('2033-04-24', '2033-04-01'),
	('2033-04-25', '2033-04-01'),
	('2033-04-26', '2033-04-01'),
	('2033-04-27', '2033-04-01'),
	('2033-04-28', '2033-04-01'),
	('2033-04-29', '2033-04-01'),
	('2033-04-30', '2033-04-01'),
	('2033-05-01', '2033-05-01'),
	('2033-05-02', '2033-05-01'),
	('2033-05-03', '2033-05-01'),
	('2033-05-04', '2033-05-01'),
	('2033-05-05', '2033-05-01'),
	('2033-05-06', '2033-05-01'),
	('2033-05-07', '2033-05-01'),
	('2033-05-08', '2033-05-01'),
	('2033-05-09', '2033-05-01'),
	('2033-05-10', '2033-05-01'),
	('2033-05-11', '2033-05-01'),
	('2033-05-12', '2033-05-01'),
	('2033-05-13', '2033-05-01'),
	('2033-05-14', '2033-05-01'),
	('2033-05-15', '2033-05-01'),
	('2033-05-16', '2033-05-01'),
	('2033-05-17', '2033-05-01'),
	('2033-05-18', '2033-05-01'),
	('2033-05-19', '2033-05-01'),
	('2033-05-20', '2033-05-01'),
	('2033-05-21', '2033-05-01'),
	('2033-05-22', '2033-05-01'),
	('2033-05-23', '2033-05-01'),
	('2033-05-24', '2033-05-01'),
	('2033-05-25', '2033-05-01'),
	('2033-05-26', '2033-05-01'),
	('2033-05-27', '2033-05-01'),
	('2033-05-28', '2033-05-01'),
	('2033-05-29', '2033-05-01'),
	('2033-05-30', '2033-05-01'),
	('2033-05-31', '2033-05-01'),
	('2033-06-01', '2033-06-01'),
	('2033-06-02', '2033-06-01'),
	('2033-06-03', '2033-06-01'),
	('2033-06-04', '2033-06-01'),
	('2033-06-05', '2033-06-01'),
	('2033-06-06', '2033-06-01'),
	('2033-06-07', '2033-06-01'),
	('2033-06-08', '2033-06-01'),
	('2033-06-09', '2033-06-01'),
	('2033-06-10', '2033-06-01'),
	('2033-06-11', '2033-06-01'),
	('2033-06-12', '2033-06-01'),
	('2033-06-13', '2033-06-01'),
	('2033-06-14', '2033-06-01'),
	('2033-06-15', '2033-06-01'),
	('2033-06-16', '2033-06-01'),
	('2033-06-17', '2033-06-01'),
	('2033-06-18', '2033-06-01'),
	('2033-06-19', '2033-06-01'),
	('2033-06-20', '2033-06-01'),
	('2033-06-21', '2033-06-01'),
	('2033-06-22', '2033-06-01'),
	('2033-06-23', '2033-06-01'),
	('2033-06-24', '2033-06-01'),
	('2033-06-25', '2033-06-01'),
	('2033-06-26', '2033-06-01'),
	('2033-06-27', '2033-06-01'),
	('2033-06-28', '2033-06-01'),
	('2033-06-29', '2033-06-01'),
	('2033-06-30', '2033-06-01'),
	('2033-07-01', '2033-07-01'),
	('2033-07-02', '2033-07-01'),
	('2033-07-03', '2033-07-01'),
	('2033-07-04', '2033-07-01'),
	('2033-07-05', '2033-07-01'),
	('2033-07-06', '2033-07-01'),
	('2033-07-07', '2033-07-01'),
	('2033-07-08', '2033-07-01'),
	('2033-07-09', '2033-07-01'),
	('2033-07-10', '2033-07-01'),
	('2033-07-11', '2033-07-01'),
	('2033-07-12', '2033-07-01'),
	('2033-07-13', '2033-07-01'),
	('2033-07-14', '2033-07-01'),
	('2033-07-15', '2033-07-01'),
	('2033-07-16', '2033-07-01'),
	('2033-07-17', '2033-07-01'),
	('2033-07-18', '2033-07-01'),
	('2033-07-19', '2033-07-01'),
	('2033-07-20', '2033-07-01'),
	('2033-07-21', '2033-07-01'),
	('2033-07-22', '2033-07-01'),
	('2033-07-23', '2033-07-01'),
	('2033-07-24', '2033-07-01'),
	('2033-07-25', '2033-07-01'),
	('2033-07-26', '2033-07-01'),
	('2033-07-27', '2033-07-01'),
	('2033-07-28', '2033-07-01'),
	('2033-07-29', '2033-07-01'),
	('2033-07-30', '2033-07-01'),
	('2033-07-31', '2033-07-01'),
	('2033-08-01', '2033-08-01'),
	('2033-08-02', '2033-08-01'),
	('2033-08-03', '2033-08-01'),
	('2033-08-04', '2033-08-01'),
	('2033-08-05', '2033-08-01'),
	('2033-08-06', '2033-08-01'),
	('2033-08-07', '2033-08-01'),
	('2033-08-08', '2033-08-01'),
	('2033-08-09', '2033-08-01'),
	('2033-08-10', '2033-08-01'),
	('2033-08-11', '2033-08-01'),
	('2033-08-12', '2033-08-01'),
	('2033-08-13', '2033-08-01'),
	('2033-08-14', '2033-08-01'),
	('2033-08-15', '2033-08-01'),
	('2033-08-16', '2033-08-01'),
	('2033-08-17', '2033-08-01'),
	('2033-08-18', '2033-08-01'),
	('2033-08-19', '2033-08-01'),
	('2033-08-20', '2033-08-01'),
	('2033-08-21', '2033-08-01'),
	('2033-08-22', '2033-08-01'),
	('2033-08-23', '2033-08-01'),
	('2033-08-24', '2033-08-01'),
	('2033-08-25', '2033-08-01'),
	('2033-08-26', '2033-08-01'),
	('2033-08-27', '2033-08-01'),
	('2033-08-28', '2033-08-01'),
	('2033-08-29', '2033-08-01'),
	('2033-08-30', '2033-08-01'),
	('2033-08-31', '2033-08-01'),
	('2033-09-01', '2033-09-01'),
	('2033-09-02', '2033-09-01'),
	('2033-09-03', '2033-09-01'),
	('2033-09-04', '2033-09-01'),
	('2033-09-05', '2033-09-01'),
	('2033-09-06', '2033-09-01'),
	('2033-09-07', '2033-09-01'),
	('2033-09-08', '2033-09-01'),
	('2033-09-09', '2033-09-01'),
	('2033-09-10', '2033-09-01'),
	('2033-09-11', '2033-09-01'),
	('2033-09-12', '2033-09-01'),
	('2033-09-13', '2033-09-01'),
	('2033-09-14', '2033-09-01'),
	('2033-09-15', '2033-09-01'),
	('2033-09-16', '2033-09-01'),
	('2033-09-17', '2033-09-01'),
	('2033-09-18', '2033-09-01'),
	('2033-09-19', '2033-09-01'),
	('2033-09-20', '2033-09-01'),
	('2033-09-21', '2033-09-01'),
	('2033-09-22', '2033-09-01'),
	('2033-09-23', '2033-09-01'),
	('2033-09-24', '2033-09-01'),
	('2033-09-25', '2033-09-01'),
	('2033-09-26', '2033-09-01'),
	('2033-09-27', '2033-09-01'),
	('2033-09-28', '2033-09-01'),
	('2033-09-29', '2033-09-01'),
	('2033-09-30', '2033-09-01'),
	('2033-10-01', '2033-10-01'),
	('2033-10-02', '2033-10-01'),
	('2033-10-03', '2033-10-01'),
	('2033-10-04', '2033-10-01'),
	('2033-10-05', '2033-10-01'),
	('2033-10-06', '2033-10-01'),
	('2033-10-07', '2033-10-01'),
	('2033-10-08', '2033-10-01'),
	('2033-10-09', '2033-10-01'),
	('2033-10-10', '2033-10-01'),
	('2033-10-11', '2033-10-01'),
	('2033-10-12', '2033-10-01'),
	('2033-10-13', '2033-10-01'),
	('2033-10-14', '2033-10-01'),
	('2033-10-15', '2033-10-01'),
	('2033-10-16', '2033-10-01'),
	('2033-10-17', '2033-10-01'),
	('2033-10-18', '2033-10-01'),
	('2033-10-19', '2033-10-01'),
	('2033-10-20', '2033-10-01'),
	('2033-10-21', '2033-10-01'),
	('2033-10-22', '2033-10-01'),
	('2033-10-23', '2033-10-01'),
	('2033-10-24', '2033-10-01'),
	('2033-10-25', '2033-10-01'),
	('2033-10-26', '2033-10-01'),
	('2033-10-27', '2033-10-01'),
	('2033-10-28', '2033-10-01'),
	('2033-10-29', '2033-10-01'),
	('2033-10-30', '2033-10-01'),
	('2033-10-31', '2033-10-01'),
	('2033-11-01', '2033-11-01'),
	('2033-11-02', '2033-11-01'),
	('2033-11-03', '2033-11-01'),
	('2033-11-04', '2033-11-01'),
	('2033-11-05', '2033-11-01'),
	('2033-11-06', '2033-11-01'),
	('2033-11-07', '2033-11-01'),
	('2033-11-08', '2033-11-01'),
	('2033-11-09', '2033-11-01'),
	('2033-11-10', '2033-11-01'),
	('2033-11-11', '2033-11-01'),
	('2033-11-12', '2033-11-01'),
	('2033-11-13', '2033-11-01'),
	('2033-11-14', '2033-11-01'),
	('2033-11-15', '2033-11-01'),
	('2033-11-16', '2033-11-01'),
	('2033-11-17', '2033-11-01'),
	('2033-11-18', '2033-11-01'),
	('2033-11-19', '2033-11-01'),
	('2033-11-20', '2033-11-01'),
	('2033-11-21', '2033-11-01'),
	('2033-11-22', '2033-11-01'),
	('2033-11-23', '2033-11-01'),
	('2033-11-24', '2033-11-01'),
	('2033-11-25', '2033-11-01'),
	('2033-11-26', '2033-11-01'),
	('2033-11-27', '2033-11-01'),
	('2033-11-28', '2033-11-01'),
	('2033-11-29', '2033-11-01'),
	('2033-11-30', '2033-11-01'),
	('2033-12-01', '2033-12-01'),
	('2033-12-02', '2033-12-01'),
	('2033-12-03', '2033-12-01'),
	('2033-12-04', '2033-12-01'),
	('2033-12-05', '2033-12-01'),
	('2033-12-06', '2033-12-01'),
	('2033-12-07', '2033-12-01'),
	('2033-12-08', '2033-12-01'),
	('2033-12-09', '2033-12-01'),
	('2033-12-10', '2033-12-01'),
	('2033-12-11', '2033-12-01'),
	('2033-12-12', '2033-12-01'),
	('2033-12-13', '2033-12-01'),
	('2033-12-14', '2033-12-01'),
	('2033-12-15', '2033-12-01'),
	('2033-12-16', '2033-12-01'),
	('2033-12-17', '2033-12-01'),
	('2033-12-18', '2033-12-01'),
	('2033-12-19', '2033-12-01'),
	('2033-12-20', '2033-12-01'),
	('2033-12-21', '2033-12-01'),
	('2033-12-22', '2033-12-01'),
	('2033-12-23', '2033-12-01'),
	('2033-12-24', '2033-12-01'),
	('2033-12-25', '2033-12-01'),
	('2033-12-26', '2033-12-01'),
	('2033-12-27', '2033-12-01'),
	('2033-12-28', '2033-12-01'),
	('2033-12-29', '2033-12-01'),
	('2033-12-30', '2033-12-01'),
	('2033-12-31', '2033-12-01'),
	('2034-01-01', '2034-01-01'),
	('2034-01-02', '2034-01-01'),
	('2034-01-03', '2034-01-01'),
	('2034-01-04', '2034-01-01'),
	('2034-01-05', '2034-01-01'),
	('2034-01-06', '2034-01-01'),
	('2034-01-07', '2034-01-01'),
	('2034-01-08', '2034-01-01'),
	('2034-01-09', '2034-01-01'),
	('2034-01-10', '2034-01-01'),
	('2034-01-11', '2034-01-01'),
	('2034-01-12', '2034-01-01'),
	('2034-01-13', '2034-01-01'),
	('2034-01-14', '2034-01-01'),
	('2034-01-15', '2034-01-01'),
	('2034-01-16', '2034-01-01'),
	('2034-01-17', '2034-01-01'),
	('2034-01-18', '2034-01-01'),
	('2034-01-19', '2034-01-01'),
	('2034-01-20', '2034-01-01'),
	('2034-01-21', '2034-01-01'),
	('2034-01-22', '2034-01-01'),
	('2034-01-23', '2034-01-01'),
	('2034-01-24', '2034-01-01'),
	('2034-01-25', '2034-01-01'),
	('2034-01-26', '2034-01-01'),
	('2034-01-27', '2034-01-01'),
	('2034-01-28', '2034-01-01'),
	('2034-01-29', '2034-01-01'),
	('2034-01-30', '2034-01-01'),
	('2034-01-31', '2034-01-01'),
	('2034-02-01', '2034-02-01'),
	('2034-02-02', '2034-02-01'),
	('2034-02-03', '2034-02-01'),
	('2034-02-04', '2034-02-01'),
	('2034-02-05', '2034-02-01'),
	('2034-02-06', '2034-02-01'),
	('2034-02-07', '2034-02-01'),
	('2034-02-08', '2034-02-01'),
	('2034-02-09', '2034-02-01'),
	('2034-02-10', '2034-02-01'),
	('2034-02-11', '2034-02-01'),
	('2034-02-12', '2034-02-01'),
	('2034-02-13', '2034-02-01'),
	('2034-02-14', '2034-02-01'),
	('2034-02-15', '2034-02-01'),
	('2034-02-16', '2034-02-01'),
	('2034-02-17', '2034-02-01'),
	('2034-02-18', '2034-02-01'),
	('2034-02-19', '2034-02-01'),
	('2034-02-20', '2034-02-01'),
	('2034-02-21', '2034-02-01'),
	('2034-02-22', '2034-02-01'),
	('2034-02-23', '2034-02-01'),
	('2034-02-24', '2034-02-01'),
	('2034-02-25', '2034-02-01'),
	('2034-02-26', '2034-02-01'),
	('2034-02-27', '2034-02-01'),
	('2034-02-28', '2034-02-01'),
	('2034-03-01', '2034-03-01'),
	('2034-03-02', '2034-03-01'),
	('2034-03-03', '2034-03-01'),
	('2034-03-04', '2034-03-01'),
	('2034-03-05', '2034-03-01'),
	('2034-03-06', '2034-03-01'),
	('2034-03-07', '2034-03-01'),
	('2034-03-08', '2034-03-01'),
	('2034-03-09', '2034-03-01'),
	('2034-03-10', '2034-03-01'),
	('2034-03-11', '2034-03-01'),
	('2034-03-12', '2034-03-01'),
	('2034-03-13', '2034-03-01'),
	('2034-03-14', '2034-03-01'),
	('2034-03-15', '2034-03-01'),
	('2034-03-16', '2034-03-01'),
	('2034-03-17', '2034-03-01'),
	('2034-03-18', '2034-03-01'),
	('2034-03-19', '2034-03-01'),
	('2034-03-20', '2034-03-01'),
	('2034-03-21', '2034-03-01'),
	('2034-03-22', '2034-03-01'),
	('2034-03-23', '2034-03-01'),
	('2034-03-24', '2034-03-01'),
	('2034-03-25', '2034-03-01'),
	('2034-03-26', '2034-03-01'),
	('2034-03-27', '2034-03-01'),
	('2034-03-28', '2034-03-01'),
	('2034-03-29', '2034-03-01'),
	('2034-03-30', '2034-03-01'),
	('2034-03-31', '2034-03-01'),
	('2034-04-01', '2034-04-01'),
	('2034-04-02', '2034-04-01'),
	('2034-04-03', '2034-04-01'),
	('2034-04-04', '2034-04-01'),
	('2034-04-05', '2034-04-01'),
	('2034-04-06', '2034-04-01'),
	('2034-04-07', '2034-04-01'),
	('2034-04-08', '2034-04-01'),
	('2034-04-09', '2034-04-01'),
	('2034-04-10', '2034-04-01'),
	('2034-04-11', '2034-04-01'),
	('2034-04-12', '2034-04-01'),
	('2034-04-13', '2034-04-01'),
	('2034-04-14', '2034-04-01'),
	('2034-04-15', '2034-04-01'),
	('2034-04-16', '2034-04-01'),
	('2034-04-17', '2034-04-01'),
	('2034-04-18', '2034-04-01'),
	('2034-04-19', '2034-04-01'),
	('2034-04-20', '2034-04-01'),
	('2034-04-21', '2034-04-01'),
	('2034-04-22', '2034-04-01'),
	('2034-04-23', '2034-04-01'),
	('2034-04-24', '2034-04-01'),
	('2034-04-25', '2034-04-01'),
	('2034-04-26', '2034-04-01'),
	('2034-04-27', '2034-04-01'),
	('2034-04-28', '2034-04-01'),
	('2034-04-29', '2034-04-01'),
	('2034-04-30', '2034-04-01'),
	('2034-05-01', '2034-05-01'),
	('2034-05-02', '2034-05-01'),
	('2034-05-03', '2034-05-01'),
	('2034-05-04', '2034-05-01'),
	('2034-05-05', '2034-05-01'),
	('2034-05-06', '2034-05-01'),
	('2034-05-07', '2034-05-01'),
	('2034-05-08', '2034-05-01'),
	('2034-05-09', '2034-05-01'),
	('2034-05-10', '2034-05-01'),
	('2034-05-11', '2034-05-01'),
	('2034-05-12', '2034-05-01'),
	('2034-05-13', '2034-05-01'),
	('2034-05-14', '2034-05-01'),
	('2034-05-15', '2034-05-01'),
	('2034-05-16', '2034-05-01'),
	('2034-05-17', '2034-05-01'),
	('2034-05-18', '2034-05-01'),
	('2034-05-19', '2034-05-01'),
	('2034-05-20', '2034-05-01'),
	('2034-05-21', '2034-05-01'),
	('2034-05-22', '2034-05-01'),
	('2034-05-23', '2034-05-01'),
	('2034-05-24', '2034-05-01'),
	('2034-05-25', '2034-05-01'),
	('2034-05-26', '2034-05-01'),
	('2034-05-27', '2034-05-01'),
	('2034-05-28', '2034-05-01'),
	('2034-05-29', '2034-05-01'),
	('2034-05-30', '2034-05-01'),
	('2034-05-31', '2034-05-01'),
	('2034-06-01', '2034-06-01'),
	('2034-06-02', '2034-06-01'),
	('2034-06-03', '2034-06-01'),
	('2034-06-04', '2034-06-01'),
	('2034-06-05', '2034-06-01'),
	('2034-06-06', '2034-06-01'),
	('2034-06-07', '2034-06-01'),
	('2034-06-08', '2034-06-01'),
	('2034-06-09', '2034-06-01'),
	('2034-06-10', '2034-06-01'),
	('2034-06-11', '2034-06-01'),
	('2034-06-12', '2034-06-01'),
	('2034-06-13', '2034-06-01'),
	('2034-06-14', '2034-06-01'),
	('2034-06-15', '2034-06-01'),
	('2034-06-16', '2034-06-01'),
	('2034-06-17', '2034-06-01'),
	('2034-06-18', '2034-06-01'),
	('2034-06-19', '2034-06-01'),
	('2034-06-20', '2034-06-01'),
	('2034-06-21', '2034-06-01'),
	('2034-06-22', '2034-06-01'),
	('2034-06-23', '2034-06-01'),
	('2034-06-24', '2034-06-01'),
	('2034-06-25', '2034-06-01'),
	('2034-06-26', '2034-06-01'),
	('2034-06-27', '2034-06-01'),
	('2034-06-28', '2034-06-01'),
	('2034-06-29', '2034-06-01'),
	('2034-06-30', '2034-06-01'),
	('2034-07-01', '2034-07-01'),
	('2034-07-02', '2034-07-01'),
	('2034-07-03', '2034-07-01'),
	('2034-07-04', '2034-07-01'),
	('2034-07-05', '2034-07-01'),
	('2034-07-06', '2034-07-01'),
	('2034-07-07', '2034-07-01'),
	('2034-07-08', '2034-07-01'),
	('2034-07-09', '2034-07-01'),
	('2034-07-10', '2034-07-01'),
	('2034-07-11', '2034-07-01'),
	('2034-07-12', '2034-07-01'),
	('2034-07-13', '2034-07-01'),
	('2034-07-14', '2034-07-01'),
	('2034-07-15', '2034-07-01'),
	('2034-07-16', '2034-07-01'),
	('2034-07-17', '2034-07-01'),
	('2034-07-18', '2034-07-01'),
	('2034-07-19', '2034-07-01'),
	('2034-07-20', '2034-07-01'),
	('2034-07-21', '2034-07-01'),
	('2034-07-22', '2034-07-01'),
	('2034-07-23', '2034-07-01'),
	('2034-07-24', '2034-07-01'),
	('2034-07-25', '2034-07-01'),
	('2034-07-26', '2034-07-01'),
	('2034-07-27', '2034-07-01'),
	('2034-07-28', '2034-07-01'),
	('2034-07-29', '2034-07-01'),
	('2034-07-30', '2034-07-01'),
	('2034-07-31', '2034-07-01'),
	('2034-08-01', '2034-08-01'),
	('2034-08-02', '2034-08-01'),
	('2034-08-03', '2034-08-01'),
	('2034-08-04', '2034-08-01'),
	('2034-08-05', '2034-08-01'),
	('2034-08-06', '2034-08-01'),
	('2034-08-07', '2034-08-01'),
	('2034-08-08', '2034-08-01'),
	('2034-08-09', '2034-08-01'),
	('2034-08-10', '2034-08-01'),
	('2034-08-11', '2034-08-01'),
	('2034-08-12', '2034-08-01'),
	('2034-08-13', '2034-08-01'),
	('2034-08-14', '2034-08-01'),
	('2034-08-15', '2034-08-01'),
	('2034-08-16', '2034-08-01'),
	('2034-08-17', '2034-08-01'),
	('2034-08-18', '2034-08-01'),
	('2034-08-19', '2034-08-01'),
	('2034-08-20', '2034-08-01'),
	('2034-08-21', '2034-08-01'),
	('2034-08-22', '2034-08-01'),
	('2034-08-23', '2034-08-01'),
	('2034-08-24', '2034-08-01'),
	('2034-08-25', '2034-08-01'),
	('2034-08-26', '2034-08-01'),
	('2034-08-27', '2034-08-01'),
	('2034-08-28', '2034-08-01'),
	('2034-08-29', '2034-08-01'),
	('2034-08-30', '2034-08-01'),
	('2034-08-31', '2034-08-01'),
	('2034-09-01', '2034-09-01'),
	('2034-09-02', '2034-09-01'),
	('2034-09-03', '2034-09-01'),
	('2034-09-04', '2034-09-01'),
	('2034-09-05', '2034-09-01'),
	('2034-09-06', '2034-09-01'),
	('2034-09-07', '2034-09-01'),
	('2034-09-08', '2034-09-01'),
	('2034-09-09', '2034-09-01'),
	('2034-09-10', '2034-09-01'),
	('2034-09-11', '2034-09-01'),
	('2034-09-12', '2034-09-01'),
	('2034-09-13', '2034-09-01'),
	('2034-09-14', '2034-09-01'),
	('2034-09-15', '2034-09-01'),
	('2034-09-16', '2034-09-01'),
	('2034-09-17', '2034-09-01'),
	('2034-09-18', '2034-09-01'),
	('2034-09-19', '2034-09-01'),
	('2034-09-20', '2034-09-01'),
	('2034-09-21', '2034-09-01'),
	('2034-09-22', '2034-09-01'),
	('2034-09-23', '2034-09-01'),
	('2034-09-24', '2034-09-01'),
	('2034-09-25', '2034-09-01'),
	('2034-09-26', '2034-09-01'),
	('2034-09-27', '2034-09-01'),
	('2034-09-28', '2034-09-01'),
	('2034-09-29', '2034-09-01'),
	('2034-09-30', '2034-09-01'),
	('2034-10-01', '2034-10-01'),
	('2034-10-02', '2034-10-01'),
	('2034-10-03', '2034-10-01'),
	('2034-10-04', '2034-10-01'),
	('2034-10-05', '2034-10-01'),
	('2034-10-06', '2034-10-01'),
	('2034-10-07', '2034-10-01'),
	('2034-10-08', '2034-10-01'),
	('2034-10-09', '2034-10-01'),
	('2034-10-10', '2034-10-01'),
	('2034-10-11', '2034-10-01'),
	('2034-10-12', '2034-10-01'),
	('2034-10-13', '2034-10-01'),
	('2034-10-14', '2034-10-01'),
	('2034-10-15', '2034-10-01'),
	('2034-10-16', '2034-10-01'),
	('2034-10-17', '2034-10-01'),
	('2034-10-18', '2034-10-01'),
	('2034-10-19', '2034-10-01'),
	('2034-10-20', '2034-10-01'),
	('2034-10-21', '2034-10-01'),
	('2034-10-22', '2034-10-01'),
	('2034-10-23', '2034-10-01'),
	('2034-10-24', '2034-10-01'),
	('2034-10-25', '2034-10-01'),
	('2034-10-26', '2034-10-01'),
	('2034-10-27', '2034-10-01'),
	('2034-10-28', '2034-10-01'),
	('2034-10-29', '2034-10-01'),
	('2034-10-30', '2034-10-01'),
	('2034-10-31', '2034-10-01'),
	('2034-11-01', '2034-11-01'),
	('2034-11-02', '2034-11-01'),
	('2034-11-03', '2034-11-01'),
	('2034-11-04', '2034-11-01'),
	('2034-11-05', '2034-11-01'),
	('2034-11-06', '2034-11-01'),
	('2034-11-07', '2034-11-01'),
	('2034-11-08', '2034-11-01'),
	('2034-11-09', '2034-11-01'),
	('2034-11-10', '2034-11-01'),
	('2034-11-11', '2034-11-01'),
	('2034-11-12', '2034-11-01'),
	('2034-11-13', '2034-11-01'),
	('2034-11-14', '2034-11-01'),
	('2034-11-15', '2034-11-01'),
	('2034-11-16', '2034-11-01'),
	('2034-11-17', '2034-11-01'),
	('2034-11-18', '2034-11-01'),
	('2034-11-19', '2034-11-01'),
	('2034-11-20', '2034-11-01'),
	('2034-11-21', '2034-11-01'),
	('2034-11-22', '2034-11-01'),
	('2034-11-23', '2034-11-01'),
	('2034-11-24', '2034-11-01'),
	('2034-11-25', '2034-11-01'),
	('2034-11-26', '2034-11-01'),
	('2034-11-27', '2034-11-01'),
	('2034-11-28', '2034-11-01'),
	('2034-11-29', '2034-11-01'),
	('2034-11-30', '2034-11-01'),
	('2034-12-01', '2034-12-01'),
	('2034-12-02', '2034-12-01'),
	('2034-12-03', '2034-12-01'),
	('2034-12-04', '2034-12-01'),
	('2034-12-05', '2034-12-01'),
	('2034-12-06', '2034-12-01'),
	('2034-12-07', '2034-12-01'),
	('2034-12-08', '2034-12-01'),
	('2034-12-09', '2034-12-01'),
	('2034-12-10', '2034-12-01'),
	('2034-12-11', '2034-12-01'),
	('2034-12-12', '2034-12-01'),
	('2034-12-13', '2034-12-01'),
	('2034-12-14', '2034-12-01'),
	('2034-12-15', '2034-12-01'),
	('2034-12-16', '2034-12-01'),
	('2034-12-17', '2034-12-01'),
	('2034-12-18', '2034-12-01'),
	('2034-12-19', '2034-12-01'),
	('2034-12-20', '2034-12-01'),
	('2034-12-21', '2034-12-01'),
	('2034-12-22', '2034-12-01'),
	('2034-12-23', '2034-12-01'),
	('2034-12-24', '2034-12-01'),
	('2034-12-25', '2034-12-01'),
	('2034-12-26', '2034-12-01'),
	('2034-12-27', '2034-12-01'),
	('2034-12-28', '2034-12-01'),
	('2034-12-29', '2034-12-01'),
	('2034-12-30', '2034-12-01'),
	('2034-12-31', '2034-12-01'),
	('2035-01-01', '2035-01-01'),
	('2035-01-02', '2035-01-01'),
	('2035-01-03', '2035-01-01'),
	('2035-01-04', '2035-01-01'),
	('2035-01-05', '2035-01-01'),
	('2035-01-06', '2035-01-01'),
	('2035-01-07', '2035-01-01'),
	('2035-01-08', '2035-01-01'),
	('2035-01-09', '2035-01-01'),
	('2035-01-10', '2035-01-01'),
	('2035-01-11', '2035-01-01'),
	('2035-01-12', '2035-01-01'),
	('2035-01-13', '2035-01-01'),
	('2035-01-14', '2035-01-01'),
	('2035-01-15', '2035-01-01'),
	('2035-01-16', '2035-01-01'),
	('2035-01-17', '2035-01-01'),
	('2035-01-18', '2035-01-01'),
	('2035-01-19', '2035-01-01'),
	('2035-01-20', '2035-01-01'),
	('2035-01-21', '2035-01-01'),
	('2035-01-22', '2035-01-01'),
	('2035-01-23', '2035-01-01'),
	('2035-01-24', '2035-01-01'),
	('2035-01-25', '2035-01-01'),
	('2035-01-26', '2035-01-01'),
	('2035-01-27', '2035-01-01'),
	('2035-01-28', '2035-01-01'),
	('2035-01-29', '2035-01-01'),
	('2035-01-30', '2035-01-01'),
	('2035-01-31', '2035-01-01'),
	('2035-02-01', '2035-02-01'),
	('2035-02-02', '2035-02-01'),
	('2035-02-03', '2035-02-01'),
	('2035-02-04', '2035-02-01'),
	('2035-02-05', '2035-02-01'),
	('2035-02-06', '2035-02-01'),
	('2035-02-07', '2035-02-01'),
	('2035-02-08', '2035-02-01'),
	('2035-02-09', '2035-02-01'),
	('2035-02-10', '2035-02-01'),
	('2035-02-11', '2035-02-01'),
	('2035-02-12', '2035-02-01'),
	('2035-02-13', '2035-02-01'),
	('2035-02-14', '2035-02-01'),
	('2035-02-15', '2035-02-01'),
	('2035-02-16', '2035-02-01'),
	('2035-02-17', '2035-02-01'),
	('2035-02-18', '2035-02-01'),
	('2035-02-19', '2035-02-01'),
	('2035-02-20', '2035-02-01'),
	('2035-02-21', '2035-02-01'),
	('2035-02-22', '2035-02-01'),
	('2035-02-23', '2035-02-01'),
	('2035-02-24', '2035-02-01'),
	('2035-02-25', '2035-02-01'),
	('2035-02-26', '2035-02-01'),
	('2035-02-27', '2035-02-01'),
	('2035-02-28', '2035-02-01'),
	('2035-03-01', '2035-03-01'),
	('2035-03-02', '2035-03-01'),
	('2035-03-03', '2035-03-01'),
	('2035-03-04', '2035-03-01'),
	('2035-03-05', '2035-03-01'),
	('2035-03-06', '2035-03-01'),
	('2035-03-07', '2035-03-01'),
	('2035-03-08', '2035-03-01'),
	('2035-03-09', '2035-03-01'),
	('2035-03-10', '2035-03-01'),
	('2035-03-11', '2035-03-01'),
	('2035-03-12', '2035-03-01'),
	('2035-03-13', '2035-03-01'),
	('2035-03-14', '2035-03-01'),
	('2035-03-15', '2035-03-01'),
	('2035-03-16', '2035-03-01'),
	('2035-03-17', '2035-03-01'),
	('2035-03-18', '2035-03-01'),
	('2035-03-19', '2035-03-01'),
	('2035-03-20', '2035-03-01'),
	('2035-03-21', '2035-03-01'),
	('2035-03-22', '2035-03-01'),
	('2035-03-23', '2035-03-01'),
	('2035-03-24', '2035-03-01'),
	('2035-03-25', '2035-03-01'),
	('2035-03-26', '2035-03-01'),
	('2035-03-27', '2035-03-01'),
	('2035-03-28', '2035-03-01'),
	('2035-03-29', '2035-03-01'),
	('2035-03-30', '2035-03-01'),
	('2035-03-31', '2035-03-01'),
	('2035-04-01', '2035-04-01'),
	('2035-04-02', '2035-04-01'),
	('2035-04-03', '2035-04-01'),
	('2035-04-04', '2035-04-01'),
	('2035-04-05', '2035-04-01'),
	('2035-04-06', '2035-04-01'),
	('2035-04-07', '2035-04-01'),
	('2035-04-08', '2035-04-01'),
	('2035-04-09', '2035-04-01'),
	('2035-04-10', '2035-04-01'),
	('2035-04-11', '2035-04-01'),
	('2035-04-12', '2035-04-01'),
	('2035-04-13', '2035-04-01'),
	('2035-04-14', '2035-04-01'),
	('2035-04-15', '2035-04-01'),
	('2035-04-16', '2035-04-01'),
	('2035-04-17', '2035-04-01'),
	('2035-04-18', '2035-04-01'),
	('2035-04-19', '2035-04-01'),
	('2035-04-20', '2035-04-01'),
	('2035-04-21', '2035-04-01'),
	('2035-04-22', '2035-04-01'),
	('2035-04-23', '2035-04-01'),
	('2035-04-24', '2035-04-01'),
	('2035-04-25', '2035-04-01'),
	('2035-04-26', '2035-04-01'),
	('2035-04-27', '2035-04-01'),
	('2035-04-28', '2035-04-01'),
	('2035-04-29', '2035-04-01'),
	('2035-04-30', '2035-04-01'),
	('2035-05-01', '2035-05-01'),
	('2035-05-02', '2035-05-01'),
	('2035-05-03', '2035-05-01'),
	('2035-05-04', '2035-05-01'),
	('2035-05-05', '2035-05-01'),
	('2035-05-06', '2035-05-01'),
	('2035-05-07', '2035-05-01'),
	('2035-05-08', '2035-05-01'),
	('2035-05-09', '2035-05-01'),
	('2035-05-10', '2035-05-01'),
	('2035-05-11', '2035-05-01'),
	('2035-05-12', '2035-05-01'),
	('2035-05-13', '2035-05-01'),
	('2035-05-14', '2035-05-01'),
	('2035-05-15', '2035-05-01'),
	('2035-05-16', '2035-05-01'),
	('2035-05-17', '2035-05-01'),
	('2035-05-18', '2035-05-01'),
	('2035-05-19', '2035-05-01'),
	('2035-05-20', '2035-05-01'),
	('2035-05-21', '2035-05-01'),
	('2035-05-22', '2035-05-01'),
	('2035-05-23', '2035-05-01'),
	('2035-05-24', '2035-05-01'),
	('2035-05-25', '2035-05-01'),
	('2035-05-26', '2035-05-01'),
	('2035-05-27', '2035-05-01'),
	('2035-05-28', '2035-05-01'),
	('2035-05-29', '2035-05-01'),
	('2035-05-30', '2035-05-01'),
	('2035-05-31', '2035-05-01'),
	('2035-06-01', '2035-06-01'),
	('2035-06-02', '2035-06-01'),
	('2035-06-03', '2035-06-01'),
	('2035-06-04', '2035-06-01'),
	('2035-06-05', '2035-06-01'),
	('2035-06-06', '2035-06-01'),
	('2035-06-07', '2035-06-01'),
	('2035-06-08', '2035-06-01'),
	('2035-06-09', '2035-06-01'),
	('2035-06-10', '2035-06-01'),
	('2035-06-11', '2035-06-01'),
	('2035-06-12', '2035-06-01'),
	('2035-06-13', '2035-06-01'),
	('2035-06-14', '2035-06-01'),
	('2035-06-15', '2035-06-01'),
	('2035-06-16', '2035-06-01'),
	('2035-06-17', '2035-06-01'),
	('2035-06-18', '2035-06-01'),
	('2035-06-19', '2035-06-01'),
	('2035-06-20', '2035-06-01'),
	('2035-06-21', '2035-06-01'),
	('2035-06-22', '2035-06-01'),
	('2035-06-23', '2035-06-01'),
	('2035-06-24', '2035-06-01'),
	('2035-06-25', '2035-06-01'),
	('2035-06-26', '2035-06-01'),
	('2035-06-27', '2035-06-01'),
	('2035-06-28', '2035-06-01'),
	('2035-06-29', '2035-06-01'),
	('2035-06-30', '2035-06-01'),
	('2035-07-01', '2035-07-01'),
	('2035-07-02', '2035-07-01'),
	('2035-07-03', '2035-07-01'),
	('2035-07-04', '2035-07-01'),
	('2035-07-05', '2035-07-01'),
	('2035-07-06', '2035-07-01'),
	('2035-07-07', '2035-07-01'),
	('2035-07-08', '2035-07-01'),
	('2035-07-09', '2035-07-01'),
	('2035-07-10', '2035-07-01'),
	('2035-07-11', '2035-07-01'),
	('2035-07-12', '2035-07-01'),
	('2035-07-13', '2035-07-01'),
	('2035-07-14', '2035-07-01'),
	('2035-07-15', '2035-07-01'),
	('2035-07-16', '2035-07-01'),
	('2035-07-17', '2035-07-01'),
	('2035-07-18', '2035-07-01'),
	('2035-07-19', '2035-07-01'),
	('2035-07-20', '2035-07-01'),
	('2035-07-21', '2035-07-01'),
	('2035-07-22', '2035-07-01'),
	('2035-07-23', '2035-07-01'),
	('2035-07-24', '2035-07-01'),
	('2035-07-25', '2035-07-01'),
	('2035-07-26', '2035-07-01'),
	('2035-07-27', '2035-07-01'),
	('2035-07-28', '2035-07-01'),
	('2035-07-29', '2035-07-01'),
	('2035-07-30', '2035-07-01'),
	('2035-07-31', '2035-07-01'),
	('2035-08-01', '2035-08-01'),
	('2035-08-02', '2035-08-01'),
	('2035-08-03', '2035-08-01'),
	('2035-08-04', '2035-08-01'),
	('2035-08-05', '2035-08-01'),
	('2035-08-06', '2035-08-01'),
	('2035-08-07', '2035-08-01'),
	('2035-08-08', '2035-08-01'),
	('2035-08-09', '2035-08-01'),
	('2035-08-10', '2035-08-01'),
	('2035-08-11', '2035-08-01'),
	('2035-08-12', '2035-08-01'),
	('2035-08-13', '2035-08-01'),
	('2035-08-14', '2035-08-01'),
	('2035-08-15', '2035-08-01'),
	('2035-08-16', '2035-08-01'),
	('2035-08-17', '2035-08-01'),
	('2035-08-18', '2035-08-01'),
	('2035-08-19', '2035-08-01'),
	('2035-08-20', '2035-08-01'),
	('2035-08-21', '2035-08-01'),
	('2035-08-22', '2035-08-01'),
	('2035-08-23', '2035-08-01'),
	('2035-08-24', '2035-08-01'),
	('2035-08-25', '2035-08-01'),
	('2035-08-26', '2035-08-01'),
	('2035-08-27', '2035-08-01'),
	('2035-08-28', '2035-08-01'),
	('2035-08-29', '2035-08-01'),
	('2035-08-30', '2035-08-01'),
	('2035-08-31', '2035-08-01'),
	('2035-09-01', '2035-09-01'),
	('2035-09-02', '2035-09-01'),
	('2035-09-03', '2035-09-01'),
	('2035-09-04', '2035-09-01'),
	('2035-09-05', '2035-09-01'),
	('2035-09-06', '2035-09-01'),
	('2035-09-07', '2035-09-01'),
	('2035-09-08', '2035-09-01'),
	('2035-09-09', '2035-09-01'),
	('2035-09-10', '2035-09-01'),
	('2035-09-11', '2035-09-01'),
	('2035-09-12', '2035-09-01'),
	('2035-09-13', '2035-09-01'),
	('2035-09-14', '2035-09-01'),
	('2035-09-15', '2035-09-01'),
	('2035-09-16', '2035-09-01'),
	('2035-09-17', '2035-09-01'),
	('2035-09-18', '2035-09-01'),
	('2035-09-19', '2035-09-01'),
	('2035-09-20', '2035-09-01'),
	('2035-09-21', '2035-09-01'),
	('2035-09-22', '2035-09-01'),
	('2035-09-23', '2035-09-01'),
	('2035-09-24', '2035-09-01'),
	('2035-09-25', '2035-09-01'),
	('2035-09-26', '2035-09-01'),
	('2035-09-27', '2035-09-01'),
	('2035-09-28', '2035-09-01'),
	('2035-09-29', '2035-09-01'),
	('2035-09-30', '2035-09-01'),
	('2035-10-01', '2035-10-01'),
	('2035-10-02', '2035-10-01'),
	('2035-10-03', '2035-10-01'),
	('2035-10-04', '2035-10-01'),
	('2035-10-05', '2035-10-01'),
	('2035-10-06', '2035-10-01'),
	('2035-10-07', '2035-10-01'),
	('2035-10-08', '2035-10-01'),
	('2035-10-09', '2035-10-01'),
	('2035-10-10', '2035-10-01'),
	('2035-10-11', '2035-10-01'),
	('2035-10-12', '2035-10-01'),
	('2035-10-13', '2035-10-01'),
	('2035-10-14', '2035-10-01'),
	('2035-10-15', '2035-10-01'),
	('2035-10-16', '2035-10-01'),
	('2035-10-17', '2035-10-01'),
	('2035-10-18', '2035-10-01'),
	('2035-10-19', '2035-10-01'),
	('2035-10-20', '2035-10-01'),
	('2035-10-21', '2035-10-01'),
	('2035-10-22', '2035-10-01'),
	('2035-10-23', '2035-10-01'),
	('2035-10-24', '2035-10-01'),
	('2035-10-25', '2035-10-01'),
	('2035-10-26', '2035-10-01'),
	('2035-10-27', '2035-10-01'),
	('2035-10-28', '2035-10-01'),
	('2035-10-29', '2035-10-01'),
	('2035-10-30', '2035-10-01'),
	('2035-10-31', '2035-10-01'),
	('2035-11-01', '2035-11-01'),
	('2035-11-02', '2035-11-01'),
	('2035-11-03', '2035-11-01'),
	('2035-11-04', '2035-11-01'),
	('2035-11-05', '2035-11-01'),
	('2035-11-06', '2035-11-01'),
	('2035-11-07', '2035-11-01'),
	('2035-11-08', '2035-11-01'),
	('2035-11-09', '2035-11-01'),
	('2035-11-10', '2035-11-01'),
	('2035-11-11', '2035-11-01'),
	('2035-11-12', '2035-11-01'),
	('2035-11-13', '2035-11-01'),
	('2035-11-14', '2035-11-01'),
	('2035-11-15', '2035-11-01'),
	('2035-11-16', '2035-11-01'),
	('2035-11-17', '2035-11-01'),
	('2035-11-18', '2035-11-01'),
	('2035-11-19', '2035-11-01'),
	('2035-11-20', '2035-11-01'),
	('2035-11-21', '2035-11-01'),
	('2035-11-22', '2035-11-01'),
	('2035-11-23', '2035-11-01'),
	('2035-11-24', '2035-11-01'),
	('2035-11-25', '2035-11-01'),
	('2035-11-26', '2035-11-01'),
	('2035-11-27', '2035-11-01'),
	('2035-11-28', '2035-11-01'),
	('2035-11-29', '2035-11-01'),
	('2035-11-30', '2035-11-01'),
	('2035-12-01', '2035-12-01'),
	('2035-12-02', '2035-12-01'),
	('2035-12-03', '2035-12-01'),
	('2035-12-04', '2035-12-01'),
	('2035-12-05', '2035-12-01'),
	('2035-12-06', '2035-12-01'),
	('2035-12-07', '2035-12-01'),
	('2035-12-08', '2035-12-01'),
	('2035-12-09', '2035-12-01'),
	('2035-12-10', '2035-12-01'),
	('2035-12-11', '2035-12-01'),
	('2035-12-12', '2035-12-01'),
	('2035-12-13', '2035-12-01'),
	('2035-12-14', '2035-12-01'),
	('2035-12-15', '2035-12-01'),
	('2035-12-16', '2035-12-01'),
	('2035-12-17', '2035-12-01'),
	('2035-12-18', '2035-12-01'),
	('2035-12-19', '2035-12-01'),
	('2035-12-20', '2035-12-01'),
	('2035-12-21', '2035-12-01'),
	('2035-12-22', '2035-12-01'),
	('2035-12-23', '2035-12-01'),
	('2035-12-24', '2035-12-01'),
	('2035-12-25', '2035-12-01'),
	('2035-12-26', '2035-12-01'),
	('2035-12-27', '2035-12-01'),
	('2035-12-28', '2035-12-01'),
	('2035-12-29', '2035-12-01'),
	('2035-12-30', '2035-12-01'),
	('2035-12-31', '2035-12-01'),
	('2036-01-01', '2036-01-01'),
	('2036-01-02', '2036-01-01'),
	('2036-01-03', '2036-01-01'),
	('2036-01-04', '2036-01-01'),
	('2036-01-05', '2036-01-01'),
	('2036-01-06', '2036-01-01'),
	('2036-01-07', '2036-01-01'),
	('2036-01-08', '2036-01-01'),
	('2036-01-09', '2036-01-01'),
	('2036-01-10', '2036-01-01'),
	('2036-01-11', '2036-01-01'),
	('2036-01-12', '2036-01-01'),
	('2036-01-13', '2036-01-01'),
	('2036-01-14', '2036-01-01'),
	('2036-01-15', '2036-01-01'),
	('2036-01-16', '2036-01-01'),
	('2036-01-17', '2036-01-01'),
	('2036-01-18', '2036-01-01'),
	('2036-01-19', '2036-01-01'),
	('2036-01-20', '2036-01-01'),
	('2036-01-21', '2036-01-01'),
	('2036-01-22', '2036-01-01'),
	('2036-01-23', '2036-01-01'),
	('2036-01-24', '2036-01-01'),
	('2036-01-25', '2036-01-01'),
	('2036-01-26', '2036-01-01'),
	('2036-01-27', '2036-01-01'),
	('2036-01-28', '2036-01-01'),
	('2036-01-29', '2036-01-01'),
	('2036-01-30', '2036-01-01'),
	('2036-01-31', '2036-01-01'),
	('2036-02-01', '2036-02-01'),
	('2036-02-02', '2036-02-01'),
	('2036-02-03', '2036-02-01'),
	('2036-02-04', '2036-02-01'),
	('2036-02-05', '2036-02-01'),
	('2036-02-06', '2036-02-01'),
	('2036-02-07', '2036-02-01'),
	('2036-02-08', '2036-02-01'),
	('2036-02-09', '2036-02-01'),
	('2036-02-10', '2036-02-01'),
	('2036-02-11', '2036-02-01'),
	('2036-02-12', '2036-02-01'),
	('2036-02-13', '2036-02-01'),
	('2036-02-14', '2036-02-01'),
	('2036-02-15', '2036-02-01'),
	('2036-02-16', '2036-02-01'),
	('2036-02-17', '2036-02-01'),
	('2036-02-18', '2036-02-01'),
	('2036-02-19', '2036-02-01'),
	('2036-02-20', '2036-02-01'),
	('2036-02-21', '2036-02-01'),
	('2036-02-22', '2036-02-01'),
	('2036-02-23', '2036-02-01'),
	('2036-02-24', '2036-02-01'),
	('2036-02-25', '2036-02-01'),
	('2036-02-26', '2036-02-01'),
	('2036-02-27', '2036-02-01'),
	('2036-02-28', '2036-02-01'),
	('2036-02-29', '2036-02-01'),
	('2036-03-01', '2036-03-01'),
	('2036-03-02', '2036-03-01'),
	('2036-03-03', '2036-03-01'),
	('2036-03-04', '2036-03-01'),
	('2036-03-05', '2036-03-01'),
	('2036-03-06', '2036-03-01'),
	('2036-03-07', '2036-03-01'),
	('2036-03-08', '2036-03-01'),
	('2036-03-09', '2036-03-01'),
	('2036-03-10', '2036-03-01'),
	('2036-03-11', '2036-03-01'),
	('2036-03-12', '2036-03-01'),
	('2036-03-13', '2036-03-01'),
	('2036-03-14', '2036-03-01'),
	('2036-03-15', '2036-03-01'),
	('2036-03-16', '2036-03-01'),
	('2036-03-17', '2036-03-01'),
	('2036-03-18', '2036-03-01'),
	('2036-03-19', '2036-03-01'),
	('2036-03-20', '2036-03-01'),
	('2036-03-21', '2036-03-01'),
	('2036-03-22', '2036-03-01'),
	('2036-03-23', '2036-03-01'),
	('2036-03-24', '2036-03-01'),
	('2036-03-25', '2036-03-01'),
	('2036-03-26', '2036-03-01'),
	('2036-03-27', '2036-03-01'),
	('2036-03-28', '2036-03-01'),
	('2036-03-29', '2036-03-01'),
	('2036-03-30', '2036-03-01'),
	('2036-03-31', '2036-03-01'),
	('2036-04-01', '2036-04-01'),
	('2036-04-02', '2036-04-01'),
	('2036-04-03', '2036-04-01'),
	('2036-04-04', '2036-04-01'),
	('2036-04-05', '2036-04-01'),
	('2036-04-06', '2036-04-01'),
	('2036-04-07', '2036-04-01'),
	('2036-04-08', '2036-04-01'),
	('2036-04-09', '2036-04-01'),
	('2036-04-10', '2036-04-01'),
	('2036-04-11', '2036-04-01'),
	('2036-04-12', '2036-04-01'),
	('2036-04-13', '2036-04-01'),
	('2036-04-14', '2036-04-01'),
	('2036-04-15', '2036-04-01'),
	('2036-04-16', '2036-04-01'),
	('2036-04-17', '2036-04-01'),
	('2036-04-18', '2036-04-01'),
	('2036-04-19', '2036-04-01'),
	('2036-04-20', '2036-04-01'),
	('2036-04-21', '2036-04-01'),
	('2036-04-22', '2036-04-01'),
	('2036-04-23', '2036-04-01'),
	('2036-04-24', '2036-04-01'),
	('2036-04-25', '2036-04-01'),
	('2036-04-26', '2036-04-01'),
	('2036-04-27', '2036-04-01'),
	('2036-04-28', '2036-04-01'),
	('2036-04-29', '2036-04-01'),
	('2036-04-30', '2036-04-01'),
	('2036-05-01', '2036-05-01'),
	('2036-05-02', '2036-05-01'),
	('2036-05-03', '2036-05-01'),
	('2036-05-04', '2036-05-01'),
	('2036-05-05', '2036-05-01'),
	('2036-05-06', '2036-05-01'),
	('2036-05-07', '2036-05-01'),
	('2036-05-08', '2036-05-01'),
	('2036-05-09', '2036-05-01'),
	('2036-05-10', '2036-05-01'),
	('2036-05-11', '2036-05-01'),
	('2036-05-12', '2036-05-01'),
	('2036-05-13', '2036-05-01'),
	('2036-05-14', '2036-05-01'),
	('2036-05-15', '2036-05-01'),
	('2036-05-16', '2036-05-01'),
	('2036-05-17', '2036-05-01'),
	('2036-05-18', '2036-05-01'),
	('2036-05-19', '2036-05-01'),
	('2036-05-20', '2036-05-01'),
	('2036-05-21', '2036-05-01'),
	('2036-05-22', '2036-05-01'),
	('2036-05-23', '2036-05-01'),
	('2036-05-24', '2036-05-01'),
	('2036-05-25', '2036-05-01'),
	('2036-05-26', '2036-05-01'),
	('2036-05-27', '2036-05-01'),
	('2036-05-28', '2036-05-01'),
	('2036-05-29', '2036-05-01'),
	('2036-05-30', '2036-05-01'),
	('2036-05-31', '2036-05-01'),
	('2036-06-01', '2036-06-01'),
	('2036-06-02', '2036-06-01'),
	('2036-06-03', '2036-06-01'),
	('2036-06-04', '2036-06-01'),
	('2036-06-05', '2036-06-01'),
	('2036-06-06', '2036-06-01'),
	('2036-06-07', '2036-06-01'),
	('2036-06-08', '2036-06-01'),
	('2036-06-09', '2036-06-01'),
	('2036-06-10', '2036-06-01'),
	('2036-06-11', '2036-06-01'),
	('2036-06-12', '2036-06-01'),
	('2036-06-13', '2036-06-01'),
	('2036-06-14', '2036-06-01'),
	('2036-06-15', '2036-06-01'),
	('2036-06-16', '2036-06-01'),
	('2036-06-17', '2036-06-01'),
	('2036-06-18', '2036-06-01'),
	('2036-06-19', '2036-06-01'),
	('2036-06-20', '2036-06-01'),
	('2036-06-21', '2036-06-01'),
	('2036-06-22', '2036-06-01'),
	('2036-06-23', '2036-06-01'),
	('2036-06-24', '2036-06-01'),
	('2036-06-25', '2036-06-01'),
	('2036-06-26', '2036-06-01'),
	('2036-06-27', '2036-06-01'),
	('2036-06-28', '2036-06-01'),
	('2036-06-29', '2036-06-01'),
	('2036-06-30', '2036-06-01'),
	('2036-07-01', '2036-07-01'),
	('2036-07-02', '2036-07-01'),
	('2036-07-03', '2036-07-01'),
	('2036-07-04', '2036-07-01'),
	('2036-07-05', '2036-07-01'),
	('2036-07-06', '2036-07-01'),
	('2036-07-07', '2036-07-01'),
	('2036-07-08', '2036-07-01'),
	('2036-07-09', '2036-07-01'),
	('2036-07-10', '2036-07-01'),
	('2036-07-11', '2036-07-01'),
	('2036-07-12', '2036-07-01'),
	('2036-07-13', '2036-07-01'),
	('2036-07-14', '2036-07-01'),
	('2036-07-15', '2036-07-01'),
	('2036-07-16', '2036-07-01'),
	('2036-07-17', '2036-07-01'),
	('2036-07-18', '2036-07-01'),
	('2036-07-19', '2036-07-01'),
	('2036-07-20', '2036-07-01'),
	('2036-07-21', '2036-07-01'),
	('2036-07-22', '2036-07-01'),
	('2036-07-23', '2036-07-01'),
	('2036-07-24', '2036-07-01'),
	('2036-07-25', '2036-07-01'),
	('2036-07-26', '2036-07-01'),
	('2036-07-27', '2036-07-01'),
	('2036-07-28', '2036-07-01'),
	('2036-07-29', '2036-07-01'),
	('2036-07-30', '2036-07-01'),
	('2036-07-31', '2036-07-01'),
	('2036-08-01', '2036-08-01'),
	('2036-08-02', '2036-08-01'),
	('2036-08-03', '2036-08-01'),
	('2036-08-04', '2036-08-01'),
	('2036-08-05', '2036-08-01'),
	('2036-08-06', '2036-08-01'),
	('2036-08-07', '2036-08-01'),
	('2036-08-08', '2036-08-01'),
	('2036-08-09', '2036-08-01'),
	('2036-08-10', '2036-08-01'),
	('2036-08-11', '2036-08-01'),
	('2036-08-12', '2036-08-01'),
	('2036-08-13', '2036-08-01'),
	('2036-08-14', '2036-08-01'),
	('2036-08-15', '2036-08-01'),
	('2036-08-16', '2036-08-01'),
	('2036-08-17', '2036-08-01'),
	('2036-08-18', '2036-08-01'),
	('2036-08-19', '2036-08-01'),
	('2036-08-20', '2036-08-01'),
	('2036-08-21', '2036-08-01'),
	('2036-08-22', '2036-08-01'),
	('2036-08-23', '2036-08-01'),
	('2036-08-24', '2036-08-01'),
	('2036-08-25', '2036-08-01'),
	('2036-08-26', '2036-08-01'),
	('2036-08-27', '2036-08-01'),
	('2036-08-28', '2036-08-01'),
	('2036-08-29', '2036-08-01'),
	('2036-08-30', '2036-08-01'),
	('2036-08-31', '2036-08-01'),
	('2036-09-01', '2036-09-01'),
	('2036-09-02', '2036-09-01'),
	('2036-09-03', '2036-09-01'),
	('2036-09-04', '2036-09-01'),
	('2036-09-05', '2036-09-01'),
	('2036-09-06', '2036-09-01'),
	('2036-09-07', '2036-09-01'),
	('2036-09-08', '2036-09-01'),
	('2036-09-09', '2036-09-01'),
	('2036-09-10', '2036-09-01'),
	('2036-09-11', '2036-09-01'),
	('2036-09-12', '2036-09-01'),
	('2036-09-13', '2036-09-01'),
	('2036-09-14', '2036-09-01'),
	('2036-09-15', '2036-09-01'),
	('2036-09-16', '2036-09-01'),
	('2036-09-17', '2036-09-01'),
	('2036-09-18', '2036-09-01'),
	('2036-09-19', '2036-09-01'),
	('2036-09-20', '2036-09-01'),
	('2036-09-21', '2036-09-01'),
	('2036-09-22', '2036-09-01'),
	('2036-09-23', '2036-09-01'),
	('2036-09-24', '2036-09-01'),
	('2036-09-25', '2036-09-01'),
	('2036-09-26', '2036-09-01'),
	('2036-09-27', '2036-09-01'),
	('2036-09-28', '2036-09-01'),
	('2036-09-29', '2036-09-01'),
	('2036-09-30', '2036-09-01'),
	('2036-10-01', '2036-10-01'),
	('2036-10-02', '2036-10-01'),
	('2036-10-03', '2036-10-01'),
	('2036-10-04', '2036-10-01'),
	('2036-10-05', '2036-10-01'),
	('2036-10-06', '2036-10-01'),
	('2036-10-07', '2036-10-01'),
	('2036-10-08', '2036-10-01'),
	('2036-10-09', '2036-10-01'),
	('2036-10-10', '2036-10-01'),
	('2036-10-11', '2036-10-01'),
	('2036-10-12', '2036-10-01'),
	('2036-10-13', '2036-10-01'),
	('2036-10-14', '2036-10-01'),
	('2036-10-15', '2036-10-01'),
	('2036-10-16', '2036-10-01'),
	('2036-10-17', '2036-10-01'),
	('2036-10-18', '2036-10-01'),
	('2036-10-19', '2036-10-01'),
	('2036-10-20', '2036-10-01'),
	('2036-10-21', '2036-10-01'),
	('2036-10-22', '2036-10-01'),
	('2036-10-23', '2036-10-01'),
	('2036-10-24', '2036-10-01'),
	('2036-10-25', '2036-10-01'),
	('2036-10-26', '2036-10-01'),
	('2036-10-27', '2036-10-01'),
	('2036-10-28', '2036-10-01'),
	('2036-10-29', '2036-10-01'),
	('2036-10-30', '2036-10-01'),
	('2036-10-31', '2036-10-01'),
	('2036-11-01', '2036-11-01'),
	('2036-11-02', '2036-11-01'),
	('2036-11-03', '2036-11-01'),
	('2036-11-04', '2036-11-01'),
	('2036-11-05', '2036-11-01'),
	('2036-11-06', '2036-11-01'),
	('2036-11-07', '2036-11-01'),
	('2036-11-08', '2036-11-01'),
	('2036-11-09', '2036-11-01'),
	('2036-11-10', '2036-11-01'),
	('2036-11-11', '2036-11-01'),
	('2036-11-12', '2036-11-01'),
	('2036-11-13', '2036-11-01'),
	('2036-11-14', '2036-11-01'),
	('2036-11-15', '2036-11-01'),
	('2036-11-16', '2036-11-01'),
	('2036-11-17', '2036-11-01'),
	('2036-11-18', '2036-11-01'),
	('2036-11-19', '2036-11-01'),
	('2036-11-20', '2036-11-01'),
	('2036-11-21', '2036-11-01'),
	('2036-11-22', '2036-11-01'),
	('2036-11-23', '2036-11-01'),
	('2036-11-24', '2036-11-01'),
	('2036-11-25', '2036-11-01'),
	('2036-11-26', '2036-11-01'),
	('2036-11-27', '2036-11-01'),
	('2036-11-28', '2036-11-01'),
	('2036-11-29', '2036-11-01'),
	('2036-11-30', '2036-11-01'),
	('2036-12-01', '2036-12-01'),
	('2036-12-02', '2036-12-01'),
	('2036-12-03', '2036-12-01'),
	('2036-12-04', '2036-12-01'),
	('2036-12-05', '2036-12-01'),
	('2036-12-06', '2036-12-01'),
	('2036-12-07', '2036-12-01'),
	('2036-12-08', '2036-12-01'),
	('2036-12-09', '2036-12-01'),
	('2036-12-10', '2036-12-01'),
	('2036-12-11', '2036-12-01'),
	('2036-12-12', '2036-12-01'),
	('2036-12-13', '2036-12-01'),
	('2036-12-14', '2036-12-01'),
	('2036-12-15', '2036-12-01'),
	('2036-12-16', '2036-12-01'),
	('2036-12-17', '2036-12-01'),
	('2036-12-18', '2036-12-01'),
	('2036-12-19', '2036-12-01'),
	('2036-12-20', '2036-12-01'),
	('2036-12-21', '2036-12-01'),
	('2036-12-22', '2036-12-01'),
	('2036-12-23', '2036-12-01'),
	('2036-12-24', '2036-12-01'),
	('2036-12-25', '2036-12-01'),
	('2036-12-26', '2036-12-01'),
	('2036-12-27', '2036-12-01'),
	('2036-12-28', '2036-12-01'),
	('2036-12-29', '2036-12-01'),
	('2036-12-30', '2036-12-01'),
	('2036-12-31', '2036-12-01'),
	('2037-01-01', '2037-01-01'),
	('2037-01-02', '2037-01-01'),
	('2037-01-03', '2037-01-01'),
	('2037-01-04', '2037-01-01'),
	('2037-01-05', '2037-01-01'),
	('2037-01-06', '2037-01-01'),
	('2037-01-07', '2037-01-01'),
	('2037-01-08', '2037-01-01'),
	('2037-01-09', '2037-01-01'),
	('2037-01-10', '2037-01-01'),
	('2037-01-11', '2037-01-01'),
	('2037-01-12', '2037-01-01'),
	('2037-01-13', '2037-01-01'),
	('2037-01-14', '2037-01-01'),
	('2037-01-15', '2037-01-01'),
	('2037-01-16', '2037-01-01'),
	('2037-01-17', '2037-01-01'),
	('2037-01-18', '2037-01-01'),
	('2037-01-19', '2037-01-01'),
	('2037-01-20', '2037-01-01'),
	('2037-01-21', '2037-01-01'),
	('2037-01-22', '2037-01-01'),
	('2037-01-23', '2037-01-01'),
	('2037-01-24', '2037-01-01'),
	('2037-01-25', '2037-01-01'),
	('2037-01-26', '2037-01-01'),
	('2037-01-27', '2037-01-01'),
	('2037-01-28', '2037-01-01'),
	('2037-01-29', '2037-01-01'),
	('2037-01-30', '2037-01-01'),
	('2037-01-31', '2037-01-01'),
	('2037-02-01', '2037-02-01'),
	('2037-02-02', '2037-02-01'),
	('2037-02-03', '2037-02-01'),
	('2037-02-04', '2037-02-01'),
	('2037-02-05', '2037-02-01'),
	('2037-02-06', '2037-02-01'),
	('2037-02-07', '2037-02-01'),
	('2037-02-08', '2037-02-01'),
	('2037-02-09', '2037-02-01'),
	('2037-02-10', '2037-02-01'),
	('2037-02-11', '2037-02-01'),
	('2037-02-12', '2037-02-01'),
	('2037-02-13', '2037-02-01'),
	('2037-02-14', '2037-02-01'),
	('2037-02-15', '2037-02-01'),
	('2037-02-16', '2037-02-01'),
	('2037-02-17', '2037-02-01'),
	('2037-02-18', '2037-02-01'),
	('2037-02-19', '2037-02-01'),
	('2037-02-20', '2037-02-01'),
	('2037-02-21', '2037-02-01'),
	('2037-02-22', '2037-02-01'),
	('2037-02-23', '2037-02-01'),
	('2037-02-24', '2037-02-01'),
	('2037-02-25', '2037-02-01'),
	('2037-02-26', '2037-02-01'),
	('2037-02-27', '2037-02-01'),
	('2037-02-28', '2037-02-01'),
	('2037-03-01', '2037-03-01'),
	('2037-03-02', '2037-03-01'),
	('2037-03-03', '2037-03-01'),
	('2037-03-04', '2037-03-01'),
	('2037-03-05', '2037-03-01'),
	('2037-03-06', '2037-03-01'),
	('2037-03-07', '2037-03-01'),
	('2037-03-08', '2037-03-01'),
	('2037-03-09', '2037-03-01'),
	('2037-03-10', '2037-03-01'),
	('2037-03-11', '2037-03-01'),
	('2037-03-12', '2037-03-01'),
	('2037-03-13', '2037-03-01'),
	('2037-03-14', '2037-03-01'),
	('2037-03-15', '2037-03-01'),
	('2037-03-16', '2037-03-01'),
	('2037-03-17', '2037-03-01'),
	('2037-03-18', '2037-03-01'),
	('2037-03-19', '2037-03-01'),
	('2037-03-20', '2037-03-01'),
	('2037-03-21', '2037-03-01'),
	('2037-03-22', '2037-03-01'),
	('2037-03-23', '2037-03-01'),
	('2037-03-24', '2037-03-01'),
	('2037-03-25', '2037-03-01'),
	('2037-03-26', '2037-03-01'),
	('2037-03-27', '2037-03-01'),
	('2037-03-28', '2037-03-01'),
	('2037-03-29', '2037-03-01'),
	('2037-03-30', '2037-03-01'),
	('2037-03-31', '2037-03-01'),
	('2037-04-01', '2037-04-01'),
	('2037-04-02', '2037-04-01'),
	('2037-04-03', '2037-04-01'),
	('2037-04-04', '2037-04-01'),
	('2037-04-05', '2037-04-01'),
	('2037-04-06', '2037-04-01'),
	('2037-04-07', '2037-04-01'),
	('2037-04-08', '2037-04-01'),
	('2037-04-09', '2037-04-01'),
	('2037-04-10', '2037-04-01'),
	('2037-04-11', '2037-04-01'),
	('2037-04-12', '2037-04-01'),
	('2037-04-13', '2037-04-01'),
	('2037-04-14', '2037-04-01'),
	('2037-04-15', '2037-04-01'),
	('2037-04-16', '2037-04-01'),
	('2037-04-17', '2037-04-01'),
	('2037-04-18', '2037-04-01'),
	('2037-04-19', '2037-04-01'),
	('2037-04-20', '2037-04-01'),
	('2037-04-21', '2037-04-01'),
	('2037-04-22', '2037-04-01'),
	('2037-04-23', '2037-04-01'),
	('2037-04-24', '2037-04-01'),
	('2037-04-25', '2037-04-01'),
	('2037-04-26', '2037-04-01'),
	('2037-04-27', '2037-04-01'),
	('2037-04-28', '2037-04-01'),
	('2037-04-29', '2037-04-01'),
	('2037-04-30', '2037-04-01'),
	('2037-05-01', '2037-05-01'),
	('2037-05-02', '2037-05-01'),
	('2037-05-03', '2037-05-01'),
	('2037-05-04', '2037-05-01'),
	('2037-05-05', '2037-05-01'),
	('2037-05-06', '2037-05-01'),
	('2037-05-07', '2037-05-01'),
	('2037-05-08', '2037-05-01'),
	('2037-05-09', '2037-05-01'),
	('2037-05-10', '2037-05-01'),
	('2037-05-11', '2037-05-01'),
	('2037-05-12', '2037-05-01'),
	('2037-05-13', '2037-05-01'),
	('2037-05-14', '2037-05-01'),
	('2037-05-15', '2037-05-01'),
	('2037-05-16', '2037-05-01'),
	('2037-05-17', '2037-05-01'),
	('2037-05-18', '2037-05-01'),
	('2037-05-19', '2037-05-01'),
	('2037-05-20', '2037-05-01'),
	('2037-05-21', '2037-05-01'),
	('2037-05-22', '2037-05-01'),
	('2037-05-23', '2037-05-01'),
	('2037-05-24', '2037-05-01'),
	('2037-05-25', '2037-05-01'),
	('2037-05-26', '2037-05-01'),
	('2037-05-27', '2037-05-01'),
	('2037-05-28', '2037-05-01'),
	('2037-05-29', '2037-05-01'),
	('2037-05-30', '2037-05-01'),
	('2037-05-31', '2037-05-01'),
	('2037-06-01', '2037-06-01'),
	('2037-06-02', '2037-06-01'),
	('2037-06-03', '2037-06-01'),
	('2037-06-04', '2037-06-01'),
	('2037-06-05', '2037-06-01'),
	('2037-06-06', '2037-06-01'),
	('2037-06-07', '2037-06-01'),
	('2037-06-08', '2037-06-01'),
	('2037-06-09', '2037-06-01'),
	('2037-06-10', '2037-06-01'),
	('2037-06-11', '2037-06-01'),
	('2037-06-12', '2037-06-01'),
	('2037-06-13', '2037-06-01'),
	('2037-06-14', '2037-06-01'),
	('2037-06-15', '2037-06-01'),
	('2037-06-16', '2037-06-01'),
	('2037-06-17', '2037-06-01'),
	('2037-06-18', '2037-06-01'),
	('2037-06-19', '2037-06-01'),
	('2037-06-20', '2037-06-01'),
	('2037-06-21', '2037-06-01'),
	('2037-06-22', '2037-06-01'),
	('2037-06-23', '2037-06-01'),
	('2037-06-24', '2037-06-01'),
	('2037-06-25', '2037-06-01'),
	('2037-06-26', '2037-06-01'),
	('2037-06-27', '2037-06-01'),
	('2037-06-28', '2037-06-01'),
	('2037-06-29', '2037-06-01'),
	('2037-06-30', '2037-06-01'),
	('2037-07-01', '2037-07-01'),
	('2037-07-02', '2037-07-01'),
	('2037-07-03', '2037-07-01'),
	('2037-07-04', '2037-07-01'),
	('2037-07-05', '2037-07-01'),
	('2037-07-06', '2037-07-01'),
	('2037-07-07', '2037-07-01'),
	('2037-07-08', '2037-07-01'),
	('2037-07-09', '2037-07-01'),
	('2037-07-10', '2037-07-01'),
	('2037-07-11', '2037-07-01'),
	('2037-07-12', '2037-07-01'),
	('2037-07-13', '2037-07-01'),
	('2037-07-14', '2037-07-01'),
	('2037-07-15', '2037-07-01'),
	('2037-07-16', '2037-07-01'),
	('2037-07-17', '2037-07-01'),
	('2037-07-18', '2037-07-01'),
	('2037-07-19', '2037-07-01'),
	('2037-07-20', '2037-07-01'),
	('2037-07-21', '2037-07-01'),
	('2037-07-22', '2037-07-01'),
	('2037-07-23', '2037-07-01'),
	('2037-07-24', '2037-07-01'),
	('2037-07-25', '2037-07-01'),
	('2037-07-26', '2037-07-01'),
	('2037-07-27', '2037-07-01'),
	('2037-07-28', '2037-07-01'),
	('2037-07-29', '2037-07-01'),
	('2037-07-30', '2037-07-01'),
	('2037-07-31', '2037-07-01'),
	('2037-08-01', '2037-08-01'),
	('2037-08-02', '2037-08-01'),
	('2037-08-03', '2037-08-01'),
	('2037-08-04', '2037-08-01'),
	('2037-08-05', '2037-08-01'),
	('2037-08-06', '2037-08-01'),
	('2037-08-07', '2037-08-01'),
	('2037-08-08', '2037-08-01'),
	('2037-08-09', '2037-08-01'),
	('2037-08-10', '2037-08-01'),
	('2037-08-11', '2037-08-01'),
	('2037-08-12', '2037-08-01'),
	('2037-08-13', '2037-08-01'),
	('2037-08-14', '2037-08-01'),
	('2037-08-15', '2037-08-01'),
	('2037-08-16', '2037-08-01'),
	('2037-08-17', '2037-08-01'),
	('2037-08-18', '2037-08-01'),
	('2037-08-19', '2037-08-01'),
	('2037-08-20', '2037-08-01'),
	('2037-08-21', '2037-08-01'),
	('2037-08-22', '2037-08-01'),
	('2037-08-23', '2037-08-01'),
	('2037-08-24', '2037-08-01'),
	('2037-08-25', '2037-08-01'),
	('2037-08-26', '2037-08-01'),
	('2037-08-27', '2037-08-01'),
	('2037-08-28', '2037-08-01'),
	('2037-08-29', '2037-08-01'),
	('2037-08-30', '2037-08-01'),
	('2037-08-31', '2037-08-01'),
	('2037-09-01', '2037-09-01'),
	('2037-09-02', '2037-09-01'),
	('2037-09-03', '2037-09-01'),
	('2037-09-04', '2037-09-01'),
	('2037-09-05', '2037-09-01'),
	('2037-09-06', '2037-09-01'),
	('2037-09-07', '2037-09-01'),
	('2037-09-08', '2037-09-01'),
	('2037-09-09', '2037-09-01'),
	('2037-09-10', '2037-09-01'),
	('2037-09-11', '2037-09-01'),
	('2037-09-12', '2037-09-01'),
	('2037-09-13', '2037-09-01'),
	('2037-09-14', '2037-09-01'),
	('2037-09-15', '2037-09-01'),
	('2037-09-16', '2037-09-01'),
	('2037-09-17', '2037-09-01'),
	('2037-09-18', '2037-09-01'),
	('2037-09-19', '2037-09-01'),
	('2037-09-20', '2037-09-01'),
	('2037-09-21', '2037-09-01'),
	('2037-09-22', '2037-09-01'),
	('2037-09-23', '2037-09-01'),
	('2037-09-24', '2037-09-01'),
	('2037-09-25', '2037-09-01'),
	('2037-09-26', '2037-09-01'),
	('2037-09-27', '2037-09-01'),
	('2037-09-28', '2037-09-01'),
	('2037-09-29', '2037-09-01'),
	('2037-09-30', '2037-09-01'),
	('2037-10-01', '2037-10-01'),
	('2037-10-02', '2037-10-01'),
	('2037-10-03', '2037-10-01'),
	('2037-10-04', '2037-10-01'),
	('2037-10-05', '2037-10-01'),
	('2037-10-06', '2037-10-01'),
	('2037-10-07', '2037-10-01'),
	('2037-10-08', '2037-10-01'),
	('2037-10-09', '2037-10-01'),
	('2037-10-10', '2037-10-01'),
	('2037-10-11', '2037-10-01'),
	('2037-10-12', '2037-10-01'),
	('2037-10-13', '2037-10-01'),
	('2037-10-14', '2037-10-01'),
	('2037-10-15', '2037-10-01'),
	('2037-10-16', '2037-10-01'),
	('2037-10-17', '2037-10-01'),
	('2037-10-18', '2037-10-01'),
	('2037-10-19', '2037-10-01'),
	('2037-10-20', '2037-10-01'),
	('2037-10-21', '2037-10-01'),
	('2037-10-22', '2037-10-01'),
	('2037-10-23', '2037-10-01'),
	('2037-10-24', '2037-10-01'),
	('2037-10-25', '2037-10-01'),
	('2037-10-26', '2037-10-01'),
	('2037-10-27', '2037-10-01'),
	('2037-10-28', '2037-10-01'),
	('2037-10-29', '2037-10-01'),
	('2037-10-30', '2037-10-01'),
	('2037-10-31', '2037-10-01'),
	('2037-11-01', '2037-11-01'),
	('2037-11-02', '2037-11-01'),
	('2037-11-03', '2037-11-01'),
	('2037-11-04', '2037-11-01'),
	('2037-11-05', '2037-11-01'),
	('2037-11-06', '2037-11-01'),
	('2037-11-07', '2037-11-01'),
	('2037-11-08', '2037-11-01'),
	('2037-11-09', '2037-11-01'),
	('2037-11-10', '2037-11-01'),
	('2037-11-11', '2037-11-01'),
	('2037-11-12', '2037-11-01'),
	('2037-11-13', '2037-11-01'),
	('2037-11-14', '2037-11-01'),
	('2037-11-15', '2037-11-01'),
	('2037-11-16', '2037-11-01'),
	('2037-11-17', '2037-11-01'),
	('2037-11-18', '2037-11-01'),
	('2037-11-19', '2037-11-01'),
	('2037-11-20', '2037-11-01'),
	('2037-11-21', '2037-11-01'),
	('2037-11-22', '2037-11-01'),
	('2037-11-23', '2037-11-01'),
	('2037-11-24', '2037-11-01'),
	('2037-11-25', '2037-11-01'),
	('2037-11-26', '2037-11-01'),
	('2037-11-27', '2037-11-01'),
	('2037-11-28', '2037-11-01'),
	('2037-11-29', '2037-11-01'),
	('2037-11-30', '2037-11-01'),
	('2037-12-01', '2037-12-01'),
	('2037-12-02', '2037-12-01'),
	('2037-12-03', '2037-12-01'),
	('2037-12-04', '2037-12-01'),
	('2037-12-05', '2037-12-01'),
	('2037-12-06', '2037-12-01'),
	('2037-12-07', '2037-12-01'),
	('2037-12-08', '2037-12-01'),
	('2037-12-09', '2037-12-01'),
	('2037-12-10', '2037-12-01'),
	('2037-12-11', '2037-12-01'),
	('2037-12-12', '2037-12-01'),
	('2037-12-13', '2037-12-01'),
	('2037-12-14', '2037-12-01'),
	('2037-12-15', '2037-12-01'),
	('2037-12-16', '2037-12-01'),
	('2037-12-17', '2037-12-01'),
	('2037-12-18', '2037-12-01'),
	('2037-12-19', '2037-12-01'),
	('2037-12-20', '2037-12-01'),
	('2037-12-21', '2037-12-01'),
	('2037-12-22', '2037-12-01'),
	('2037-12-23', '2037-12-01'),
	('2037-12-24', '2037-12-01'),
	('2037-12-25', '2037-12-01'),
	('2037-12-26', '2037-12-01'),
	('2037-12-27', '2037-12-01'),
	('2037-12-28', '2037-12-01'),
	('2037-12-29', '2037-12-01'),
	('2037-12-30', '2037-12-01'),
	('2037-12-31', '2037-12-01'),
	('2038-01-01', '2038-01-01'),
	('2038-01-02', '2038-01-01'),
	('2038-01-03', '2038-01-01'),
	('2038-01-04', '2038-01-01'),
	('2038-01-05', '2038-01-01'),
	('2038-01-06', '2038-01-01'),
	('2038-01-07', '2038-01-01'),
	('2038-01-08', '2038-01-01'),
	('2038-01-09', '2038-01-01'),
	('2038-01-10', '2038-01-01'),
	('2038-01-11', '2038-01-01'),
	('2038-01-12', '2038-01-01'),
	('2038-01-13', '2038-01-01'),
	('2038-01-14', '2038-01-01'),
	('2038-01-15', '2038-01-01'),
	('2038-01-16', '2038-01-01'),
	('2038-01-17', '2038-01-01'),
	('2038-01-18', '2038-01-01'),
	('2038-01-19', '2038-01-01'),
	('2038-01-20', '2038-01-01'),
	('2038-01-21', '2038-01-01'),
	('2038-01-22', '2038-01-01'),
	('2038-01-23', '2038-01-01'),
	('2038-01-24', '2038-01-01'),
	('2038-01-25', '2038-01-01'),
	('2038-01-26', '2038-01-01'),
	('2038-01-27', '2038-01-01'),
	('2038-01-28', '2038-01-01'),
	('2038-01-29', '2038-01-01'),
	('2038-01-30', '2038-01-01'),
	('2038-01-31', '2038-01-01'),
	('2038-02-01', '2038-02-01'),
	('2038-02-02', '2038-02-01'),
	('2038-02-03', '2038-02-01'),
	('2038-02-04', '2038-02-01'),
	('2038-02-05', '2038-02-01'),
	('2038-02-06', '2038-02-01'),
	('2038-02-07', '2038-02-01'),
	('2038-02-08', '2038-02-01'),
	('2038-02-09', '2038-02-01'),
	('2038-02-10', '2038-02-01'),
	('2038-02-11', '2038-02-01'),
	('2038-02-12', '2038-02-01'),
	('2038-02-13', '2038-02-01'),
	('2038-02-14', '2038-02-01'),
	('2038-02-15', '2038-02-01'),
	('2038-02-16', '2038-02-01'),
	('2038-02-17', '2038-02-01'),
	('2038-02-18', '2038-02-01'),
	('2038-02-19', '2038-02-01'),
	('2038-02-20', '2038-02-01'),
	('2038-02-21', '2038-02-01'),
	('2038-02-22', '2038-02-01'),
	('2038-02-23', '2038-02-01'),
	('2038-02-24', '2038-02-01'),
	('2038-02-25', '2038-02-01'),
	('2038-02-26', '2038-02-01'),
	('2038-02-27', '2038-02-01'),
	('2038-02-28', '2038-02-01'),
	('2038-03-01', '2038-03-01'),
	('2038-03-02', '2038-03-01'),
	('2038-03-03', '2038-03-01'),
	('2038-03-04', '2038-03-01'),
	('2038-03-05', '2038-03-01'),
	('2038-03-06', '2038-03-01'),
	('2038-03-07', '2038-03-01'),
	('2038-03-08', '2038-03-01'),
	('2038-03-09', '2038-03-01'),
	('2038-03-10', '2038-03-01'),
	('2038-03-11', '2038-03-01'),
	('2038-03-12', '2038-03-01'),
	('2038-03-13', '2038-03-01'),
	('2038-03-14', '2038-03-01'),
	('2038-03-15', '2038-03-01'),
	('2038-03-16', '2038-03-01'),
	('2038-03-17', '2038-03-01'),
	('2038-03-18', '2038-03-01'),
	('2038-03-19', '2038-03-01'),
	('2038-03-20', '2038-03-01'),
	('2038-03-21', '2038-03-01'),
	('2038-03-22', '2038-03-01'),
	('2038-03-23', '2038-03-01'),
	('2038-03-24', '2038-03-01'),
	('2038-03-25', '2038-03-01'),
	('2038-03-26', '2038-03-01'),
	('2038-03-27', '2038-03-01'),
	('2038-03-28', '2038-03-01'),
	('2038-03-29', '2038-03-01'),
	('2038-03-30', '2038-03-01'),
	('2038-03-31', '2038-03-01'),
	('2038-04-01', '2038-04-01'),
	('2038-04-02', '2038-04-01'),
	('2038-04-03', '2038-04-01'),
	('2038-04-04', '2038-04-01'),
	('2038-04-05', '2038-04-01'),
	('2038-04-06', '2038-04-01'),
	('2038-04-07', '2038-04-01'),
	('2038-04-08', '2038-04-01'),
	('2038-04-09', '2038-04-01'),
	('2038-04-10', '2038-04-01'),
	('2038-04-11', '2038-04-01'),
	('2038-04-12', '2038-04-01'),
	('2038-04-13', '2038-04-01'),
	('2038-04-14', '2038-04-01'),
	('2038-04-15', '2038-04-01'),
	('2038-04-16', '2038-04-01'),
	('2038-04-17', '2038-04-01'),
	('2038-04-18', '2038-04-01'),
	('2038-04-19', '2038-04-01'),
	('2038-04-20', '2038-04-01'),
	('2038-04-21', '2038-04-01'),
	('2038-04-22', '2038-04-01'),
	('2038-04-23', '2038-04-01'),
	('2038-04-24', '2038-04-01'),
	('2038-04-25', '2038-04-01'),
	('2038-04-26', '2038-04-01'),
	('2038-04-27', '2038-04-01'),
	('2038-04-28', '2038-04-01'),
	('2038-04-29', '2038-04-01'),
	('2038-04-30', '2038-04-01'),
	('2038-05-01', '2038-05-01'),
	('2038-05-02', '2038-05-01'),
	('2038-05-03', '2038-05-01'),
	('2038-05-04', '2038-05-01'),
	('2038-05-05', '2038-05-01'),
	('2038-05-06', '2038-05-01'),
	('2038-05-07', '2038-05-01'),
	('2038-05-08', '2038-05-01'),
	('2038-05-09', '2038-05-01'),
	('2038-05-10', '2038-05-01'),
	('2038-05-11', '2038-05-01'),
	('2038-05-12', '2038-05-01'),
	('2038-05-13', '2038-05-01'),
	('2038-05-14', '2038-05-01'),
	('2038-05-15', '2038-05-01'),
	('2038-05-16', '2038-05-01'),
	('2038-05-17', '2038-05-01'),
	('2038-05-18', '2038-05-01'),
	('2038-05-19', '2038-05-01'),
	('2038-05-20', '2038-05-01'),
	('2038-05-21', '2038-05-01'),
	('2038-05-22', '2038-05-01'),
	('2038-05-23', '2038-05-01'),
	('2038-05-24', '2038-05-01'),
	('2038-05-25', '2038-05-01'),
	('2038-05-26', '2038-05-01'),
	('2038-05-27', '2038-05-01'),
	('2038-05-28', '2038-05-01'),
	('2038-05-29', '2038-05-01'),
	('2038-05-30', '2038-05-01'),
	('2038-05-31', '2038-05-01'),
	('2038-06-01', '2038-06-01'),
	('2038-06-02', '2038-06-01'),
	('2038-06-03', '2038-06-01'),
	('2038-06-04', '2038-06-01'),
	('2038-06-05', '2038-06-01'),
	('2038-06-06', '2038-06-01'),
	('2038-06-07', '2038-06-01'),
	('2038-06-08', '2038-06-01'),
	('2038-06-09', '2038-06-01'),
	('2038-06-10', '2038-06-01'),
	('2038-06-11', '2038-06-01'),
	('2038-06-12', '2038-06-01'),
	('2038-06-13', '2038-06-01'),
	('2038-06-14', '2038-06-01'),
	('2038-06-15', '2038-06-01'),
	('2038-06-16', '2038-06-01'),
	('2038-06-17', '2038-06-01'),
	('2038-06-18', '2038-06-01'),
	('2038-06-19', '2038-06-01'),
	('2038-06-20', '2038-06-01'),
	('2038-06-21', '2038-06-01'),
	('2038-06-22', '2038-06-01'),
	('2038-06-23', '2038-06-01'),
	('2038-06-24', '2038-06-01'),
	('2038-06-25', '2038-06-01'),
	('2038-06-26', '2038-06-01'),
	('2038-06-27', '2038-06-01'),
	('2038-06-28', '2038-06-01'),
	('2038-06-29', '2038-06-01'),
	('2038-06-30', '2038-06-01'),
	('2038-07-01', '2038-07-01'),
	('2038-07-02', '2038-07-01'),
	('2038-07-03', '2038-07-01'),
	('2038-07-04', '2038-07-01'),
	('2038-07-05', '2038-07-01'),
	('2038-07-06', '2038-07-01'),
	('2038-07-07', '2038-07-01'),
	('2038-07-08', '2038-07-01'),
	('2038-07-09', '2038-07-01'),
	('2038-07-10', '2038-07-01'),
	('2038-07-11', '2038-07-01'),
	('2038-07-12', '2038-07-01'),
	('2038-07-13', '2038-07-01'),
	('2038-07-14', '2038-07-01'),
	('2038-07-15', '2038-07-01'),
	('2038-07-16', '2038-07-01'),
	('2038-07-17', '2038-07-01'),
	('2038-07-18', '2038-07-01'),
	('2038-07-19', '2038-07-01'),
	('2038-07-20', '2038-07-01'),
	('2038-07-21', '2038-07-01'),
	('2038-07-22', '2038-07-01'),
	('2038-07-23', '2038-07-01'),
	('2038-07-24', '2038-07-01'),
	('2038-07-25', '2038-07-01'),
	('2038-07-26', '2038-07-01'),
	('2038-07-27', '2038-07-01'),
	('2038-07-28', '2038-07-01'),
	('2038-07-29', '2038-07-01'),
	('2038-07-30', '2038-07-01'),
	('2038-07-31', '2038-07-01'),
	('2038-08-01', '2038-08-01'),
	('2038-08-02', '2038-08-01'),
	('2038-08-03', '2038-08-01'),
	('2038-08-04', '2038-08-01'),
	('2038-08-05', '2038-08-01'),
	('2038-08-06', '2038-08-01'),
	('2038-08-07', '2038-08-01'),
	('2038-08-08', '2038-08-01'),
	('2038-08-09', '2038-08-01'),
	('2038-08-10', '2038-08-01'),
	('2038-08-11', '2038-08-01'),
	('2038-08-12', '2038-08-01'),
	('2038-08-13', '2038-08-01'),
	('2038-08-14', '2038-08-01'),
	('2038-08-15', '2038-08-01'),
	('2038-08-16', '2038-08-01'),
	('2038-08-17', '2038-08-01'),
	('2038-08-18', '2038-08-01'),
	('2038-08-19', '2038-08-01'),
	('2038-08-20', '2038-08-01'),
	('2038-08-21', '2038-08-01'),
	('2038-08-22', '2038-08-01'),
	('2038-08-23', '2038-08-01'),
	('2038-08-24', '2038-08-01'),
	('2038-08-25', '2038-08-01'),
	('2038-08-26', '2038-08-01'),
	('2038-08-27', '2038-08-01'),
	('2038-08-28', '2038-08-01'),
	('2038-08-29', '2038-08-01'),
	('2038-08-30', '2038-08-01'),
	('2038-08-31', '2038-08-01'),
	('2038-09-01', '2038-09-01'),
	('2038-09-02', '2038-09-01'),
	('2038-09-03', '2038-09-01'),
	('2038-09-04', '2038-09-01'),
	('2038-09-05', '2038-09-01'),
	('2038-09-06', '2038-09-01'),
	('2038-09-07', '2038-09-01'),
	('2038-09-08', '2038-09-01'),
	('2038-09-09', '2038-09-01'),
	('2038-09-10', '2038-09-01'),
	('2038-09-11', '2038-09-01'),
	('2038-09-12', '2038-09-01'),
	('2038-09-13', '2038-09-01'),
	('2038-09-14', '2038-09-01'),
	('2038-09-15', '2038-09-01'),
	('2038-09-16', '2038-09-01'),
	('2038-09-17', '2038-09-01'),
	('2038-09-18', '2038-09-01'),
	('2038-09-19', '2038-09-01'),
	('2038-09-20', '2038-09-01'),
	('2038-09-21', '2038-09-01'),
	('2038-09-22', '2038-09-01'),
	('2038-09-23', '2038-09-01'),
	('2038-09-24', '2038-09-01'),
	('2038-09-25', '2038-09-01'),
	('2038-09-26', '2038-09-01'),
	('2038-09-27', '2038-09-01'),
	('2038-09-28', '2038-09-01'),
	('2038-09-29', '2038-09-01'),
	('2038-09-30', '2038-09-01'),
	('2038-10-01', '2038-10-01'),
	('2038-10-02', '2038-10-01'),
	('2038-10-03', '2038-10-01'),
	('2038-10-04', '2038-10-01'),
	('2038-10-05', '2038-10-01'),
	('2038-10-06', '2038-10-01'),
	('2038-10-07', '2038-10-01'),
	('2038-10-08', '2038-10-01'),
	('2038-10-09', '2038-10-01'),
	('2038-10-10', '2038-10-01'),
	('2038-10-11', '2038-10-01'),
	('2038-10-12', '2038-10-01'),
	('2038-10-13', '2038-10-01'),
	('2038-10-14', '2038-10-01'),
	('2038-10-15', '2038-10-01'),
	('2038-10-16', '2038-10-01'),
	('2038-10-17', '2038-10-01'),
	('2038-10-18', '2038-10-01'),
	('2038-10-19', '2038-10-01'),
	('2038-10-20', '2038-10-01'),
	('2038-10-21', '2038-10-01'),
	('2038-10-22', '2038-10-01'),
	('2038-10-23', '2038-10-01'),
	('2038-10-24', '2038-10-01'),
	('2038-10-25', '2038-10-01'),
	('2038-10-26', '2038-10-01'),
	('2038-10-27', '2038-10-01'),
	('2038-10-28', '2038-10-01'),
	('2038-10-29', '2038-10-01'),
	('2038-10-30', '2038-10-01'),
	('2038-10-31', '2038-10-01'),
	('2038-11-01', '2038-11-01'),
	('2038-11-02', '2038-11-01'),
	('2038-11-03', '2038-11-01'),
	('2038-11-04', '2038-11-01'),
	('2038-11-05', '2038-11-01'),
	('2038-11-06', '2038-11-01'),
	('2038-11-07', '2038-11-01'),
	('2038-11-08', '2038-11-01'),
	('2038-11-09', '2038-11-01'),
	('2038-11-10', '2038-11-01'),
	('2038-11-11', '2038-11-01'),
	('2038-11-12', '2038-11-01'),
	('2038-11-13', '2038-11-01'),
	('2038-11-14', '2038-11-01'),
	('2038-11-15', '2038-11-01'),
	('2038-11-16', '2038-11-01'),
	('2038-11-17', '2038-11-01'),
	('2038-11-18', '2038-11-01'),
	('2038-11-19', '2038-11-01'),
	('2038-11-20', '2038-11-01'),
	('2038-11-21', '2038-11-01'),
	('2038-11-22', '2038-11-01'),
	('2038-11-23', '2038-11-01'),
	('2038-11-24', '2038-11-01'),
	('2038-11-25', '2038-11-01'),
	('2038-11-26', '2038-11-01'),
	('2038-11-27', '2038-11-01'),
	('2038-11-28', '2038-11-01'),
	('2038-11-29', '2038-11-01'),
	('2038-11-30', '2038-11-01'),
	('2038-12-01', '2038-12-01'),
	('2038-12-02', '2038-12-01'),
	('2038-12-03', '2038-12-01'),
	('2038-12-04', '2038-12-01'),
	('2038-12-05', '2038-12-01'),
	('2038-12-06', '2038-12-01'),
	('2038-12-07', '2038-12-01'),
	('2038-12-08', '2038-12-01'),
	('2038-12-09', '2038-12-01'),
	('2038-12-10', '2038-12-01'),
	('2038-12-11', '2038-12-01'),
	('2038-12-12', '2038-12-01'),
	('2038-12-13', '2038-12-01'),
	('2038-12-14', '2038-12-01'),
	('2038-12-15', '2038-12-01'),
	('2038-12-16', '2038-12-01'),
	('2038-12-17', '2038-12-01'),
	('2038-12-18', '2038-12-01'),
	('2038-12-19', '2038-12-01'),
	('2038-12-20', '2038-12-01'),
	('2038-12-21', '2038-12-01'),
	('2038-12-22', '2038-12-01'),
	('2038-12-23', '2038-12-01'),
	('2038-12-24', '2038-12-01'),
	('2038-12-25', '2038-12-01'),
	('2038-12-26', '2038-12-01'),
	('2038-12-27', '2038-12-01'),
	('2038-12-28', '2038-12-01'),
	('2038-12-29', '2038-12-01'),
	('2038-12-30', '2038-12-01'),
	('2038-12-31', '2038-12-01'),
	('2039-01-01', '2039-01-01'),
	('2039-01-02', '2039-01-01'),
	('2039-01-03', '2039-01-01'),
	('2039-01-04', '2039-01-01'),
	('2039-01-05', '2039-01-01'),
	('2039-01-06', '2039-01-01'),
	('2039-01-07', '2039-01-01'),
	('2039-01-08', '2039-01-01'),
	('2039-01-09', '2039-01-01'),
	('2039-01-10', '2039-01-01'),
	('2039-01-11', '2039-01-01'),
	('2039-01-12', '2039-01-01'),
	('2039-01-13', '2039-01-01'),
	('2039-01-14', '2039-01-01'),
	('2039-01-15', '2039-01-01'),
	('2039-01-16', '2039-01-01'),
	('2039-01-17', '2039-01-01'),
	('2039-01-18', '2039-01-01'),
	('2039-01-19', '2039-01-01'),
	('2039-01-20', '2039-01-01'),
	('2039-01-21', '2039-01-01'),
	('2039-01-22', '2039-01-01'),
	('2039-01-23', '2039-01-01'),
	('2039-01-24', '2039-01-01'),
	('2039-01-25', '2039-01-01'),
	('2039-01-26', '2039-01-01'),
	('2039-01-27', '2039-01-01'),
	('2039-01-28', '2039-01-01'),
	('2039-01-29', '2039-01-01'),
	('2039-01-30', '2039-01-01'),
	('2039-01-31', '2039-01-01'),
	('2039-02-01', '2039-02-01'),
	('2039-02-02', '2039-02-01'),
	('2039-02-03', '2039-02-01'),
	('2039-02-04', '2039-02-01'),
	('2039-02-05', '2039-02-01'),
	('2039-02-06', '2039-02-01'),
	('2039-02-07', '2039-02-01'),
	('2039-02-08', '2039-02-01'),
	('2039-02-09', '2039-02-01'),
	('2039-02-10', '2039-02-01'),
	('2039-02-11', '2039-02-01'),
	('2039-02-12', '2039-02-01'),
	('2039-02-13', '2039-02-01'),
	('2039-02-14', '2039-02-01'),
	('2039-02-15', '2039-02-01'),
	('2039-02-16', '2039-02-01'),
	('2039-02-17', '2039-02-01'),
	('2039-02-18', '2039-02-01'),
	('2039-02-19', '2039-02-01'),
	('2039-02-20', '2039-02-01'),
	('2039-02-21', '2039-02-01'),
	('2039-02-22', '2039-02-01'),
	('2039-02-23', '2039-02-01'),
	('2039-02-24', '2039-02-01'),
	('2039-02-25', '2039-02-01'),
	('2039-02-26', '2039-02-01'),
	('2039-02-27', '2039-02-01'),
	('2039-02-28', '2039-02-01'),
	('2039-03-01', '2039-03-01'),
	('2039-03-02', '2039-03-01'),
	('2039-03-03', '2039-03-01'),
	('2039-03-04', '2039-03-01'),
	('2039-03-05', '2039-03-01'),
	('2039-03-06', '2039-03-01'),
	('2039-03-07', '2039-03-01'),
	('2039-03-08', '2039-03-01'),
	('2039-03-09', '2039-03-01'),
	('2039-03-10', '2039-03-01'),
	('2039-03-11', '2039-03-01'),
	('2039-03-12', '2039-03-01'),
	('2039-03-13', '2039-03-01'),
	('2039-03-14', '2039-03-01'),
	('2039-03-15', '2039-03-01'),
	('2039-03-16', '2039-03-01'),
	('2039-03-17', '2039-03-01'),
	('2039-03-18', '2039-03-01'),
	('2039-03-19', '2039-03-01'),
	('2039-03-20', '2039-03-01'),
	('2039-03-21', '2039-03-01'),
	('2039-03-22', '2039-03-01'),
	('2039-03-23', '2039-03-01'),
	('2039-03-24', '2039-03-01'),
	('2039-03-25', '2039-03-01'),
	('2039-03-26', '2039-03-01'),
	('2039-03-27', '2039-03-01'),
	('2039-03-28', '2039-03-01'),
	('2039-03-29', '2039-03-01'),
	('2039-03-30', '2039-03-01'),
	('2039-03-31', '2039-03-01'),
	('2039-04-01', '2039-04-01'),
	('2039-04-02', '2039-04-01'),
	('2039-04-03', '2039-04-01'),
	('2039-04-04', '2039-04-01'),
	('2039-04-05', '2039-04-01'),
	('2039-04-06', '2039-04-01'),
	('2039-04-07', '2039-04-01'),
	('2039-04-08', '2039-04-01'),
	('2039-04-09', '2039-04-01'),
	('2039-04-10', '2039-04-01'),
	('2039-04-11', '2039-04-01'),
	('2039-04-12', '2039-04-01'),
	('2039-04-13', '2039-04-01'),
	('2039-04-14', '2039-04-01'),
	('2039-04-15', '2039-04-01'),
	('2039-04-16', '2039-04-01'),
	('2039-04-17', '2039-04-01'),
	('2039-04-18', '2039-04-01'),
	('2039-04-19', '2039-04-01'),
	('2039-04-20', '2039-04-01'),
	('2039-04-21', '2039-04-01'),
	('2039-04-22', '2039-04-01'),
	('2039-04-23', '2039-04-01'),
	('2039-04-24', '2039-04-01'),
	('2039-04-25', '2039-04-01'),
	('2039-04-26', '2039-04-01'),
	('2039-04-27', '2039-04-01'),
	('2039-04-28', '2039-04-01'),
	('2039-04-29', '2039-04-01'),
	('2039-04-30', '2039-04-01'),
	('2039-05-01', '2039-05-01'),
	('2039-05-02', '2039-05-01'),
	('2039-05-03', '2039-05-01'),
	('2039-05-04', '2039-05-01'),
	('2039-05-05', '2039-05-01'),
	('2039-05-06', '2039-05-01'),
	('2039-05-07', '2039-05-01'),
	('2039-05-08', '2039-05-01'),
	('2039-05-09', '2039-05-01'),
	('2039-05-10', '2039-05-01'),
	('2039-05-11', '2039-05-01'),
	('2039-05-12', '2039-05-01'),
	('2039-05-13', '2039-05-01'),
	('2039-05-14', '2039-05-01'),
	('2039-05-15', '2039-05-01'),
	('2039-05-16', '2039-05-01'),
	('2039-05-17', '2039-05-01'),
	('2039-05-18', '2039-05-01'),
	('2039-05-19', '2039-05-01'),
	('2039-05-20', '2039-05-01'),
	('2039-05-21', '2039-05-01'),
	('2039-05-22', '2039-05-01'),
	('2039-05-23', '2039-05-01'),
	('2039-05-24', '2039-05-01'),
	('2039-05-25', '2039-05-01'),
	('2039-05-26', '2039-05-01'),
	('2039-05-27', '2039-05-01'),
	('2039-05-28', '2039-05-01'),
	('2039-05-29', '2039-05-01'),
	('2039-05-30', '2039-05-01'),
	('2039-05-31', '2039-05-01'),
	('2039-06-01', '2039-06-01'),
	('2039-06-02', '2039-06-01'),
	('2039-06-03', '2039-06-01'),
	('2039-06-04', '2039-06-01'),
	('2039-06-05', '2039-06-01'),
	('2039-06-06', '2039-06-01'),
	('2039-06-07', '2039-06-01'),
	('2039-06-08', '2039-06-01'),
	('2039-06-09', '2039-06-01'),
	('2039-06-10', '2039-06-01'),
	('2039-06-11', '2039-06-01'),
	('2039-06-12', '2039-06-01'),
	('2039-06-13', '2039-06-01'),
	('2039-06-14', '2039-06-01'),
	('2039-06-15', '2039-06-01'),
	('2039-06-16', '2039-06-01'),
	('2039-06-17', '2039-06-01'),
	('2039-06-18', '2039-06-01'),
	('2039-06-19', '2039-06-01'),
	('2039-06-20', '2039-06-01'),
	('2039-06-21', '2039-06-01'),
	('2039-06-22', '2039-06-01'),
	('2039-06-23', '2039-06-01'),
	('2039-06-24', '2039-06-01'),
	('2039-06-25', '2039-06-01'),
	('2039-06-26', '2039-06-01'),
	('2039-06-27', '2039-06-01'),
	('2039-06-28', '2039-06-01'),
	('2039-06-29', '2039-06-01'),
	('2039-06-30', '2039-06-01'),
	('2039-07-01', '2039-07-01'),
	('2039-07-02', '2039-07-01'),
	('2039-07-03', '2039-07-01'),
	('2039-07-04', '2039-07-01'),
	('2039-07-05', '2039-07-01'),
	('2039-07-06', '2039-07-01'),
	('2039-07-07', '2039-07-01'),
	('2039-07-08', '2039-07-01'),
	('2039-07-09', '2039-07-01'),
	('2039-07-10', '2039-07-01'),
	('2039-07-11', '2039-07-01'),
	('2039-07-12', '2039-07-01'),
	('2039-07-13', '2039-07-01'),
	('2039-07-14', '2039-07-01'),
	('2039-07-15', '2039-07-01'),
	('2039-07-16', '2039-07-01'),
	('2039-07-17', '2039-07-01'),
	('2039-07-18', '2039-07-01'),
	('2039-07-19', '2039-07-01'),
	('2039-07-20', '2039-07-01'),
	('2039-07-21', '2039-07-01'),
	('2039-07-22', '2039-07-01'),
	('2039-07-23', '2039-07-01'),
	('2039-07-24', '2039-07-01'),
	('2039-07-25', '2039-07-01'),
	('2039-07-26', '2039-07-01'),
	('2039-07-27', '2039-07-01'),
	('2039-07-28', '2039-07-01'),
	('2039-07-29', '2039-07-01'),
	('2039-07-30', '2039-07-01'),
	('2039-07-31', '2039-07-01'),
	('2039-08-01', '2039-08-01'),
	('2039-08-02', '2039-08-01'),
	('2039-08-03', '2039-08-01'),
	('2039-08-04', '2039-08-01'),
	('2039-08-05', '2039-08-01'),
	('2039-08-06', '2039-08-01'),
	('2039-08-07', '2039-08-01'),
	('2039-08-08', '2039-08-01'),
	('2039-08-09', '2039-08-01'),
	('2039-08-10', '2039-08-01'),
	('2039-08-11', '2039-08-01'),
	('2039-08-12', '2039-08-01'),
	('2039-08-13', '2039-08-01'),
	('2039-08-14', '2039-08-01'),
	('2039-08-15', '2039-08-01'),
	('2039-08-16', '2039-08-01'),
	('2039-08-17', '2039-08-01'),
	('2039-08-18', '2039-08-01'),
	('2039-08-19', '2039-08-01'),
	('2039-08-20', '2039-08-01'),
	('2039-08-21', '2039-08-01'),
	('2039-08-22', '2039-08-01'),
	('2039-08-23', '2039-08-01'),
	('2039-08-24', '2039-08-01'),
	('2039-08-25', '2039-08-01'),
	('2039-08-26', '2039-08-01'),
	('2039-08-27', '2039-08-01'),
	('2039-08-28', '2039-08-01'),
	('2039-08-29', '2039-08-01'),
	('2039-08-30', '2039-08-01'),
	('2039-08-31', '2039-08-01'),
	('2039-09-01', '2039-09-01'),
	('2039-09-02', '2039-09-01'),
	('2039-09-03', '2039-09-01'),
	('2039-09-04', '2039-09-01'),
	('2039-09-05', '2039-09-01'),
	('2039-09-06', '2039-09-01'),
	('2039-09-07', '2039-09-01'),
	('2039-09-08', '2039-09-01'),
	('2039-09-09', '2039-09-01'),
	('2039-09-10', '2039-09-01'),
	('2039-09-11', '2039-09-01'),
	('2039-09-12', '2039-09-01'),
	('2039-09-13', '2039-09-01'),
	('2039-09-14', '2039-09-01'),
	('2039-09-15', '2039-09-01'),
	('2039-09-16', '2039-09-01'),
	('2039-09-17', '2039-09-01'),
	('2039-09-18', '2039-09-01'),
	('2039-09-19', '2039-09-01'),
	('2039-09-20', '2039-09-01'),
	('2039-09-21', '2039-09-01'),
	('2039-09-22', '2039-09-01'),
	('2039-09-23', '2039-09-01'),
	('2039-09-24', '2039-09-01'),
	('2039-09-25', '2039-09-01'),
	('2039-09-26', '2039-09-01'),
	('2039-09-27', '2039-09-01'),
	('2039-09-28', '2039-09-01'),
	('2039-09-29', '2039-09-01'),
	('2039-09-30', '2039-09-01'),
	('2039-10-01', '2039-10-01'),
	('2039-10-02', '2039-10-01'),
	('2039-10-03', '2039-10-01'),
	('2039-10-04', '2039-10-01'),
	('2039-10-05', '2039-10-01'),
	('2039-10-06', '2039-10-01'),
	('2039-10-07', '2039-10-01'),
	('2039-10-08', '2039-10-01'),
	('2039-10-09', '2039-10-01'),
	('2039-10-10', '2039-10-01'),
	('2039-10-11', '2039-10-01'),
	('2039-10-12', '2039-10-01'),
	('2039-10-13', '2039-10-01'),
	('2039-10-14', '2039-10-01'),
	('2039-10-15', '2039-10-01'),
	('2039-10-16', '2039-10-01'),
	('2039-10-17', '2039-10-01'),
	('2039-10-18', '2039-10-01'),
	('2039-10-19', '2039-10-01'),
	('2039-10-20', '2039-10-01'),
	('2039-10-21', '2039-10-01'),
	('2039-10-22', '2039-10-01'),
	('2039-10-23', '2039-10-01'),
	('2039-10-24', '2039-10-01'),
	('2039-10-25', '2039-10-01'),
	('2039-10-26', '2039-10-01'),
	('2039-10-27', '2039-10-01'),
	('2039-10-28', '2039-10-01'),
	('2039-10-29', '2039-10-01'),
	('2039-10-30', '2039-10-01'),
	('2039-10-31', '2039-10-01'),
	('2039-11-01', '2039-11-01'),
	('2039-11-02', '2039-11-01'),
	('2039-11-03', '2039-11-01'),
	('2039-11-04', '2039-11-01'),
	('2039-11-05', '2039-11-01'),
	('2039-11-06', '2039-11-01'),
	('2039-11-07', '2039-11-01'),
	('2039-11-08', '2039-11-01'),
	('2039-11-09', '2039-11-01'),
	('2039-11-10', '2039-11-01'),
	('2039-11-11', '2039-11-01'),
	('2039-11-12', '2039-11-01'),
	('2039-11-13', '2039-11-01'),
	('2039-11-14', '2039-11-01'),
	('2039-11-15', '2039-11-01'),
	('2039-11-16', '2039-11-01'),
	('2039-11-17', '2039-11-01'),
	('2039-11-18', '2039-11-01'),
	('2039-11-19', '2039-11-01'),
	('2039-11-20', '2039-11-01'),
	('2039-11-21', '2039-11-01'),
	('2039-11-22', '2039-11-01'),
	('2039-11-23', '2039-11-01'),
	('2039-11-24', '2039-11-01'),
	('2039-11-25', '2039-11-01'),
	('2039-11-26', '2039-11-01'),
	('2039-11-27', '2039-11-01'),
	('2039-11-28', '2039-11-01'),
	('2039-11-29', '2039-11-01'),
	('2039-11-30', '2039-11-01'),
	('2039-12-01', '2039-12-01'),
	('2039-12-02', '2039-12-01'),
	('2039-12-03', '2039-12-01'),
	('2039-12-04', '2039-12-01'),
	('2039-12-05', '2039-12-01'),
	('2039-12-06', '2039-12-01'),
	('2039-12-07', '2039-12-01'),
	('2039-12-08', '2039-12-01'),
	('2039-12-09', '2039-12-01'),
	('2039-12-10', '2039-12-01'),
	('2039-12-11', '2039-12-01'),
	('2039-12-12', '2039-12-01'),
	('2039-12-13', '2039-12-01'),
	('2039-12-14', '2039-12-01'),
	('2039-12-15', '2039-12-01'),
	('2039-12-16', '2039-12-01'),
	('2039-12-17', '2039-12-01'),
	('2039-12-18', '2039-12-01'),
	('2039-12-19', '2039-12-01'),
	('2039-12-20', '2039-12-01'),
	('2039-12-21', '2039-12-01'),
	('2039-12-22', '2039-12-01'),
	('2039-12-23', '2039-12-01'),
	('2039-12-24', '2039-12-01'),
	('2039-12-25', '2039-12-01'),
	('2039-12-26', '2039-12-01'),
	('2039-12-27', '2039-12-01'),
	('2039-12-28', '2039-12-01'),
	('2039-12-29', '2039-12-01'),
	('2039-12-30', '2039-12-01'),
	('2039-12-31', '2039-12-01'),
	('2040-01-01', '2040-01-01'),
	('2040-01-02', '2040-01-01'),
	('2040-01-03', '2040-01-01'),
	('2040-01-04', '2040-01-01'),
	('2040-01-05', '2040-01-01'),
	('2040-01-06', '2040-01-01'),
	('2040-01-07', '2040-01-01'),
	('2040-01-08', '2040-01-01'),
	('2040-01-09', '2040-01-01'),
	('2040-01-10', '2040-01-01'),
	('2040-01-11', '2040-01-01'),
	('2040-01-12', '2040-01-01'),
	('2040-01-13', '2040-01-01'),
	('2040-01-14', '2040-01-01'),
	('2040-01-15', '2040-01-01'),
	('2040-01-16', '2040-01-01'),
	('2040-01-17', '2040-01-01'),
	('2040-01-18', '2040-01-01'),
	('2040-01-19', '2040-01-01'),
	('2040-01-20', '2040-01-01'),
	('2040-01-21', '2040-01-01'),
	('2040-01-22', '2040-01-01'),
	('2040-01-23', '2040-01-01'),
	('2040-01-24', '2040-01-01'),
	('2040-01-25', '2040-01-01'),
	('2040-01-26', '2040-01-01'),
	('2040-01-27', '2040-01-01'),
	('2040-01-28', '2040-01-01'),
	('2040-01-29', '2040-01-01'),
	('2040-01-30', '2040-01-01'),
	('2040-01-31', '2040-01-01'),
	('2040-02-01', '2040-02-01'),
	('2040-02-02', '2040-02-01'),
	('2040-02-03', '2040-02-01'),
	('2040-02-04', '2040-02-01'),
	('2040-02-05', '2040-02-01'),
	('2040-02-06', '2040-02-01'),
	('2040-02-07', '2040-02-01'),
	('2040-02-08', '2040-02-01'),
	('2040-02-09', '2040-02-01'),
	('2040-02-10', '2040-02-01'),
	('2040-02-11', '2040-02-01'),
	('2040-02-12', '2040-02-01'),
	('2040-02-13', '2040-02-01'),
	('2040-02-14', '2040-02-01'),
	('2040-02-15', '2040-02-01'),
	('2040-02-16', '2040-02-01'),
	('2040-02-17', '2040-02-01'),
	('2040-02-18', '2040-02-01'),
	('2040-02-19', '2040-02-01'),
	('2040-02-20', '2040-02-01'),
	('2040-02-21', '2040-02-01'),
	('2040-02-22', '2040-02-01'),
	('2040-02-23', '2040-02-01'),
	('2040-02-24', '2040-02-01'),
	('2040-02-25', '2040-02-01'),
	('2040-02-26', '2040-02-01'),
	('2040-02-27', '2040-02-01'),
	('2040-02-28', '2040-02-01'),
	('2040-02-29', '2040-02-01'),
	('2040-03-01', '2040-03-01'),
	('2040-03-02', '2040-03-01'),
	('2040-03-03', '2040-03-01'),
	('2040-03-04', '2040-03-01'),
	('2040-03-05', '2040-03-01'),
	('2040-03-06', '2040-03-01'),
	('2040-03-07', '2040-03-01'),
	('2040-03-08', '2040-03-01'),
	('2040-03-09', '2040-03-01'),
	('2040-03-10', '2040-03-01'),
	('2040-03-11', '2040-03-01'),
	('2040-03-12', '2040-03-01'),
	('2040-03-13', '2040-03-01'),
	('2040-03-14', '2040-03-01'),
	('2040-03-15', '2040-03-01'),
	('2040-03-16', '2040-03-01'),
	('2040-03-17', '2040-03-01'),
	('2040-03-18', '2040-03-01'),
	('2040-03-19', '2040-03-01'),
	('2040-03-20', '2040-03-01'),
	('2040-03-21', '2040-03-01'),
	('2040-03-22', '2040-03-01'),
	('2040-03-23', '2040-03-01'),
	('2040-03-24', '2040-03-01'),
	('2040-03-25', '2040-03-01'),
	('2040-03-26', '2040-03-01'),
	('2040-03-27', '2040-03-01'),
	('2040-03-28', '2040-03-01'),
	('2040-03-29', '2040-03-01'),
	('2040-03-30', '2040-03-01'),
	('2040-03-31', '2040-03-01'),
	('2040-04-01', '2040-04-01'),
	('2040-04-02', '2040-04-01'),
	('2040-04-03', '2040-04-01'),
	('2040-04-04', '2040-04-01'),
	('2040-04-05', '2040-04-01'),
	('2040-04-06', '2040-04-01'),
	('2040-04-07', '2040-04-01'),
	('2040-04-08', '2040-04-01'),
	('2040-04-09', '2040-04-01'),
	('2040-04-10', '2040-04-01'),
	('2040-04-11', '2040-04-01'),
	('2040-04-12', '2040-04-01'),
	('2040-04-13', '2040-04-01'),
	('2040-04-14', '2040-04-01'),
	('2040-04-15', '2040-04-01'),
	('2040-04-16', '2040-04-01'),
	('2040-04-17', '2040-04-01'),
	('2040-04-18', '2040-04-01'),
	('2040-04-19', '2040-04-01'),
	('2040-04-20', '2040-04-01'),
	('2040-04-21', '2040-04-01'),
	('2040-04-22', '2040-04-01'),
	('2040-04-23', '2040-04-01'),
	('2040-04-24', '2040-04-01'),
	('2040-04-25', '2040-04-01'),
	('2040-04-26', '2040-04-01'),
	('2040-04-27', '2040-04-01'),
	('2040-04-28', '2040-04-01'),
	('2040-04-29', '2040-04-01'),
	('2040-04-30', '2040-04-01'),
	('2040-05-01', '2040-05-01'),
	('2040-05-02', '2040-05-01'),
	('2040-05-03', '2040-05-01'),
	('2040-05-04', '2040-05-01'),
	('2040-05-05', '2040-05-01'),
	('2040-05-06', '2040-05-01'),
	('2040-05-07', '2040-05-01'),
	('2040-05-08', '2040-05-01'),
	('2040-05-09', '2040-05-01'),
	('2040-05-10', '2040-05-01'),
	('2040-05-11', '2040-05-01'),
	('2040-05-12', '2040-05-01'),
	('2040-05-13', '2040-05-01'),
	('2040-05-14', '2040-05-01'),
	('2040-05-15', '2040-05-01'),
	('2040-05-16', '2040-05-01'),
	('2040-05-17', '2040-05-01'),
	('2040-05-18', '2040-05-01'),
	('2040-05-19', '2040-05-01'),
	('2040-05-20', '2040-05-01'),
	('2040-05-21', '2040-05-01'),
	('2040-05-22', '2040-05-01'),
	('2040-05-23', '2040-05-01'),
	('2040-05-24', '2040-05-01'),
	('2040-05-25', '2040-05-01'),
	('2040-05-26', '2040-05-01'),
	('2040-05-27', '2040-05-01'),
	('2040-05-28', '2040-05-01'),
	('2040-05-29', '2040-05-01'),
	('2040-05-30', '2040-05-01'),
	('2040-05-31', '2040-05-01'),
	('2040-06-01', '2040-06-01'),
	('2040-06-02', '2040-06-01'),
	('2040-06-03', '2040-06-01'),
	('2040-06-04', '2040-06-01'),
	('2040-06-05', '2040-06-01'),
	('2040-06-06', '2040-06-01'),
	('2040-06-07', '2040-06-01'),
	('2040-06-08', '2040-06-01'),
	('2040-06-09', '2040-06-01'),
	('2040-06-10', '2040-06-01'),
	('2040-06-11', '2040-06-01'),
	('2040-06-12', '2040-06-01'),
	('2040-06-13', '2040-06-01'),
	('2040-06-14', '2040-06-01'),
	('2040-06-15', '2040-06-01'),
	('2040-06-16', '2040-06-01'),
	('2040-06-17', '2040-06-01'),
	('2040-06-18', '2040-06-01'),
	('2040-06-19', '2040-06-01'),
	('2040-06-20', '2040-06-01'),
	('2040-06-21', '2040-06-01'),
	('2040-06-22', '2040-06-01'),
	('2040-06-23', '2040-06-01'),
	('2040-06-24', '2040-06-01'),
	('2040-06-25', '2040-06-01'),
	('2040-06-26', '2040-06-01'),
	('2040-06-27', '2040-06-01'),
	('2040-06-28', '2040-06-01'),
	('2040-06-29', '2040-06-01'),
	('2040-06-30', '2040-06-01'),
	('2040-07-01', '2040-07-01'),
	('2040-07-02', '2040-07-01'),
	('2040-07-03', '2040-07-01'),
	('2040-07-04', '2040-07-01'),
	('2040-07-05', '2040-07-01'),
	('2040-07-06', '2040-07-01'),
	('2040-07-07', '2040-07-01'),
	('2040-07-08', '2040-07-01'),
	('2040-07-09', '2040-07-01'),
	('2040-07-10', '2040-07-01'),
	('2040-07-11', '2040-07-01'),
	('2040-07-12', '2040-07-01'),
	('2040-07-13', '2040-07-01'),
	('2040-07-14', '2040-07-01'),
	('2040-07-15', '2040-07-01'),
	('2040-07-16', '2040-07-01'),
	('2040-07-17', '2040-07-01'),
	('2040-07-18', '2040-07-01'),
	('2040-07-19', '2040-07-01'),
	('2040-07-20', '2040-07-01'),
	('2040-07-21', '2040-07-01'),
	('2040-07-22', '2040-07-01'),
	('2040-07-23', '2040-07-01'),
	('2040-07-24', '2040-07-01'),
	('2040-07-25', '2040-07-01'),
	('2040-07-26', '2040-07-01'),
	('2040-07-27', '2040-07-01'),
	('2040-07-28', '2040-07-01'),
	('2040-07-29', '2040-07-01'),
	('2040-07-30', '2040-07-01'),
	('2040-07-31', '2040-07-01'),
	('2040-08-01', '2040-08-01'),
	('2040-08-02', '2040-08-01'),
	('2040-08-03', '2040-08-01'),
	('2040-08-04', '2040-08-01'),
	('2040-08-05', '2040-08-01'),
	('2040-08-06', '2040-08-01'),
	('2040-08-07', '2040-08-01'),
	('2040-08-08', '2040-08-01'),
	('2040-08-09', '2040-08-01'),
	('2040-08-10', '2040-08-01'),
	('2040-08-11', '2040-08-01'),
	('2040-08-12', '2040-08-01'),
	('2040-08-13', '2040-08-01'),
	('2040-08-14', '2040-08-01'),
	('2040-08-15', '2040-08-01'),
	('2040-08-16', '2040-08-01'),
	('2040-08-17', '2040-08-01'),
	('2040-08-18', '2040-08-01'),
	('2040-08-19', '2040-08-01'),
	('2040-08-20', '2040-08-01'),
	('2040-08-21', '2040-08-01'),
	('2040-08-22', '2040-08-01'),
	('2040-08-23', '2040-08-01'),
	('2040-08-24', '2040-08-01'),
	('2040-08-25', '2040-08-01'),
	('2040-08-26', '2040-08-01'),
	('2040-08-27', '2040-08-01'),
	('2040-08-28', '2040-08-01'),
	('2040-08-29', '2040-08-01'),
	('2040-08-30', '2040-08-01'),
	('2040-08-31', '2040-08-01'),
	('2040-09-01', '2040-09-01'),
	('2040-09-02', '2040-09-01'),
	('2040-09-03', '2040-09-01'),
	('2040-09-04', '2040-09-01'),
	('2040-09-05', '2040-09-01'),
	('2040-09-06', '2040-09-01'),
	('2040-09-07', '2040-09-01'),
	('2040-09-08', '2040-09-01'),
	('2040-09-09', '2040-09-01'),
	('2040-09-10', '2040-09-01'),
	('2040-09-11', '2040-09-01'),
	('2040-09-12', '2040-09-01'),
	('2040-09-13', '2040-09-01'),
	('2040-09-14', '2040-09-01'),
	('2040-09-15', '2040-09-01'),
	('2040-09-16', '2040-09-01'),
	('2040-09-17', '2040-09-01'),
	('2040-09-18', '2040-09-01'),
	('2040-09-19', '2040-09-01'),
	('2040-09-20', '2040-09-01'),
	('2040-09-21', '2040-09-01'),
	('2040-09-22', '2040-09-01'),
	('2040-09-23', '2040-09-01'),
	('2040-09-24', '2040-09-01'),
	('2040-09-25', '2040-09-01'),
	('2040-09-26', '2040-09-01'),
	('2040-09-27', '2040-09-01'),
	('2040-09-28', '2040-09-01'),
	('2040-09-29', '2040-09-01'),
	('2040-09-30', '2040-09-01'),
	('2040-10-01', '2040-10-01'),
	('2040-10-02', '2040-10-01'),
	('2040-10-03', '2040-10-01'),
	('2040-10-04', '2040-10-01'),
	('2040-10-05', '2040-10-01'),
	('2040-10-06', '2040-10-01'),
	('2040-10-07', '2040-10-01'),
	('2040-10-08', '2040-10-01'),
	('2040-10-09', '2040-10-01'),
	('2040-10-10', '2040-10-01'),
	('2040-10-11', '2040-10-01'),
	('2040-10-12', '2040-10-01'),
	('2040-10-13', '2040-10-01'),
	('2040-10-14', '2040-10-01'),
	('2040-10-15', '2040-10-01'),
	('2040-10-16', '2040-10-01'),
	('2040-10-17', '2040-10-01'),
	('2040-10-18', '2040-10-01'),
	('2040-10-19', '2040-10-01'),
	('2040-10-20', '2040-10-01'),
	('2040-10-21', '2040-10-01'),
	('2040-10-22', '2040-10-01'),
	('2040-10-23', '2040-10-01'),
	('2040-10-24', '2040-10-01'),
	('2040-10-25', '2040-10-01'),
	('2040-10-26', '2040-10-01'),
	('2040-10-27', '2040-10-01'),
	('2040-10-28', '2040-10-01'),
	('2040-10-29', '2040-10-01'),
	('2040-10-30', '2040-10-01'),
	('2040-10-31', '2040-10-01'),
	('2040-11-01', '2040-11-01'),
	('2040-11-02', '2040-11-01'),
	('2040-11-03', '2040-11-01'),
	('2040-11-04', '2040-11-01'),
	('2040-11-05', '2040-11-01'),
	('2040-11-06', '2040-11-01'),
	('2040-11-07', '2040-11-01'),
	('2040-11-08', '2040-11-01'),
	('2040-11-09', '2040-11-01'),
	('2040-11-10', '2040-11-01'),
	('2040-11-11', '2040-11-01'),
	('2040-11-12', '2040-11-01'),
	('2040-11-13', '2040-11-01'),
	('2040-11-14', '2040-11-01'),
	('2040-11-15', '2040-11-01'),
	('2040-11-16', '2040-11-01'),
	('2040-11-17', '2040-11-01'),
	('2040-11-18', '2040-11-01'),
	('2040-11-19', '2040-11-01'),
	('2040-11-20', '2040-11-01'),
	('2040-11-21', '2040-11-01'),
	('2040-11-22', '2040-11-01'),
	('2040-11-23', '2040-11-01'),
	('2040-11-24', '2040-11-01'),
	('2040-11-25', '2040-11-01'),
	('2040-11-26', '2040-11-01'),
	('2040-11-27', '2040-11-01'),
	('2040-11-28', '2040-11-01'),
	('2040-11-29', '2040-11-01'),
	('2040-11-30', '2040-11-01'),
	('2040-12-01', '2040-12-01'),
	('2040-12-02', '2040-12-01'),
	('2040-12-03', '2040-12-01'),
	('2040-12-04', '2040-12-01'),
	('2040-12-05', '2040-12-01'),
	('2040-12-06', '2040-12-01'),
	('2040-12-07', '2040-12-01'),
	('2040-12-08', '2040-12-01'),
	('2040-12-09', '2040-12-01'),
	('2040-12-10', '2040-12-01'),
	('2040-12-11', '2040-12-01'),
	('2040-12-12', '2040-12-01'),
	('2040-12-13', '2040-12-01'),
	('2040-12-14', '2040-12-01'),
	('2040-12-15', '2040-12-01'),
	('2040-12-16', '2040-12-01'),
	('2040-12-17', '2040-12-01'),
	('2040-12-18', '2040-12-01'),
	('2040-12-19', '2040-12-01'),
	('2040-12-20', '2040-12-01'),
	('2040-12-21', '2040-12-01'),
	('2040-12-22', '2040-12-01'),
	('2040-12-23', '2040-12-01'),
	('2040-12-24', '2040-12-01'),
	('2040-12-25', '2040-12-01'),
	('2040-12-26', '2040-12-01'),
	('2040-12-27', '2040-12-01'),
	('2040-12-28', '2040-12-01'),
	('2040-12-29', '2040-12-01'),
	('2040-12-30', '2040-12-01'),
	('2040-12-31', '2040-12-01'),
	('2041-01-01', '2041-01-01'),
	('2041-01-02', '2041-01-01'),
	('2041-01-03', '2041-01-01'),
	('2041-01-04', '2041-01-01'),
	('2041-01-05', '2041-01-01'),
	('2041-01-06', '2041-01-01'),
	('2041-01-07', '2041-01-01'),
	('2041-01-08', '2041-01-01'),
	('2041-01-09', '2041-01-01'),
	('2041-01-10', '2041-01-01'),
	('2041-01-11', '2041-01-01'),
	('2041-01-12', '2041-01-01'),
	('2041-01-13', '2041-01-01'),
	('2041-01-14', '2041-01-01'),
	('2041-01-15', '2041-01-01'),
	('2041-01-16', '2041-01-01'),
	('2041-01-17', '2041-01-01'),
	('2041-01-18', '2041-01-01'),
	('2041-01-19', '2041-01-01'),
	('2041-01-20', '2041-01-01'),
	('2041-01-21', '2041-01-01'),
	('2041-01-22', '2041-01-01'),
	('2041-01-23', '2041-01-01'),
	('2041-01-24', '2041-01-01'),
	('2041-01-25', '2041-01-01'),
	('2041-01-26', '2041-01-01'),
	('2041-01-27', '2041-01-01'),
	('2041-01-28', '2041-01-01'),
	('2041-01-29', '2041-01-01'),
	('2041-01-30', '2041-01-01'),
	('2041-01-31', '2041-01-01'),
	('2041-02-01', '2041-02-01'),
	('2041-02-02', '2041-02-01'),
	('2041-02-03', '2041-02-01'),
	('2041-02-04', '2041-02-01'),
	('2041-02-05', '2041-02-01'),
	('2041-02-06', '2041-02-01'),
	('2041-02-07', '2041-02-01'),
	('2041-02-08', '2041-02-01'),
	('2041-02-09', '2041-02-01'),
	('2041-02-10', '2041-02-01'),
	('2041-02-11', '2041-02-01'),
	('2041-02-12', '2041-02-01'),
	('2041-02-13', '2041-02-01'),
	('2041-02-14', '2041-02-01'),
	('2041-02-15', '2041-02-01'),
	('2041-02-16', '2041-02-01'),
	('2041-02-17', '2041-02-01'),
	('2041-02-18', '2041-02-01'),
	('2041-02-19', '2041-02-01'),
	('2041-02-20', '2041-02-01'),
	('2041-02-21', '2041-02-01'),
	('2041-02-22', '2041-02-01'),
	('2041-02-23', '2041-02-01'),
	('2041-02-24', '2041-02-01'),
	('2041-02-25', '2041-02-01'),
	('2041-02-26', '2041-02-01'),
	('2041-02-27', '2041-02-01'),
	('2041-02-28', '2041-02-01'),
	('2041-03-01', '2041-03-01'),
	('2041-03-02', '2041-03-01'),
	('2041-03-03', '2041-03-01'),
	('2041-03-04', '2041-03-01'),
	('2041-03-05', '2041-03-01'),
	('2041-03-06', '2041-03-01'),
	('2041-03-07', '2041-03-01'),
	('2041-03-08', '2041-03-01'),
	('2041-03-09', '2041-03-01'),
	('2041-03-10', '2041-03-01'),
	('2041-03-11', '2041-03-01'),
	('2041-03-12', '2041-03-01'),
	('2041-03-13', '2041-03-01'),
	('2041-03-14', '2041-03-01'),
	('2041-03-15', '2041-03-01'),
	('2041-03-16', '2041-03-01'),
	('2041-03-17', '2041-03-01'),
	('2041-03-18', '2041-03-01'),
	('2041-03-19', '2041-03-01'),
	('2041-03-20', '2041-03-01'),
	('2041-03-21', '2041-03-01'),
	('2041-03-22', '2041-03-01'),
	('2041-03-23', '2041-03-01'),
	('2041-03-24', '2041-03-01'),
	('2041-03-25', '2041-03-01'),
	('2041-03-26', '2041-03-01'),
	('2041-03-27', '2041-03-01'),
	('2041-03-28', '2041-03-01'),
	('2041-03-29', '2041-03-01'),
	('2041-03-30', '2041-03-01'),
	('2041-03-31', '2041-03-01'),
	('2041-04-01', '2041-04-01'),
	('2041-04-02', '2041-04-01'),
	('2041-04-03', '2041-04-01'),
	('2041-04-04', '2041-04-01'),
	('2041-04-05', '2041-04-01'),
	('2041-04-06', '2041-04-01'),
	('2041-04-07', '2041-04-01'),
	('2041-04-08', '2041-04-01'),
	('2041-04-09', '2041-04-01'),
	('2041-04-10', '2041-04-01'),
	('2041-04-11', '2041-04-01'),
	('2041-04-12', '2041-04-01'),
	('2041-04-13', '2041-04-01'),
	('2041-04-14', '2041-04-01'),
	('2041-04-15', '2041-04-01'),
	('2041-04-16', '2041-04-01'),
	('2041-04-17', '2041-04-01'),
	('2041-04-18', '2041-04-01'),
	('2041-04-19', '2041-04-01'),
	('2041-04-20', '2041-04-01'),
	('2041-04-21', '2041-04-01'),
	('2041-04-22', '2041-04-01'),
	('2041-04-23', '2041-04-01'),
	('2041-04-24', '2041-04-01'),
	('2041-04-25', '2041-04-01'),
	('2041-04-26', '2041-04-01'),
	('2041-04-27', '2041-04-01'),
	('2041-04-28', '2041-04-01'),
	('2041-04-29', '2041-04-01'),
	('2041-04-30', '2041-04-01'),
	('2041-05-01', '2041-05-01'),
	('2041-05-02', '2041-05-01'),
	('2041-05-03', '2041-05-01'),
	('2041-05-04', '2041-05-01'),
	('2041-05-05', '2041-05-01'),
	('2041-05-06', '2041-05-01'),
	('2041-05-07', '2041-05-01'),
	('2041-05-08', '2041-05-01'),
	('2041-05-09', '2041-05-01'),
	('2041-05-10', '2041-05-01'),
	('2041-05-11', '2041-05-01'),
	('2041-05-12', '2041-05-01'),
	('2041-05-13', '2041-05-01'),
	('2041-05-14', '2041-05-01'),
	('2041-05-15', '2041-05-01'),
	('2041-05-16', '2041-05-01'),
	('2041-05-17', '2041-05-01'),
	('2041-05-18', '2041-05-01'),
	('2041-05-19', '2041-05-01'),
	('2041-05-20', '2041-05-01'),
	('2041-05-21', '2041-05-01'),
	('2041-05-22', '2041-05-01'),
	('2041-05-23', '2041-05-01'),
	('2041-05-24', '2041-05-01'),
	('2041-05-25', '2041-05-01'),
	('2041-05-26', '2041-05-01'),
	('2041-05-27', '2041-05-01'),
	('2041-05-28', '2041-05-01'),
	('2041-05-29', '2041-05-01'),
	('2041-05-30', '2041-05-01'),
	('2041-05-31', '2041-05-01'),
	('2041-06-01', '2041-06-01'),
	('2041-06-02', '2041-06-01'),
	('2041-06-03', '2041-06-01'),
	('2041-06-04', '2041-06-01'),
	('2041-06-05', '2041-06-01'),
	('2041-06-06', '2041-06-01'),
	('2041-06-07', '2041-06-01'),
	('2041-06-08', '2041-06-01'),
	('2041-06-09', '2041-06-01'),
	('2041-06-10', '2041-06-01'),
	('2041-06-11', '2041-06-01'),
	('2041-06-12', '2041-06-01'),
	('2041-06-13', '2041-06-01'),
	('2041-06-14', '2041-06-01'),
	('2041-06-15', '2041-06-01'),
	('2041-06-16', '2041-06-01'),
	('2041-06-17', '2041-06-01'),
	('2041-06-18', '2041-06-01'),
	('2041-06-19', '2041-06-01'),
	('2041-06-20', '2041-06-01'),
	('2041-06-21', '2041-06-01'),
	('2041-06-22', '2041-06-01'),
	('2041-06-23', '2041-06-01'),
	('2041-06-24', '2041-06-01'),
	('2041-06-25', '2041-06-01'),
	('2041-06-26', '2041-06-01'),
	('2041-06-27', '2041-06-01'),
	('2041-06-28', '2041-06-01'),
	('2041-06-29', '2041-06-01'),
	('2041-06-30', '2041-06-01'),
	('2041-07-01', '2041-07-01'),
	('2041-07-02', '2041-07-01'),
	('2041-07-03', '2041-07-01'),
	('2041-07-04', '2041-07-01'),
	('2041-07-05', '2041-07-01'),
	('2041-07-06', '2041-07-01'),
	('2041-07-07', '2041-07-01'),
	('2041-07-08', '2041-07-01'),
	('2041-07-09', '2041-07-01'),
	('2041-07-10', '2041-07-01'),
	('2041-07-11', '2041-07-01'),
	('2041-07-12', '2041-07-01'),
	('2041-07-13', '2041-07-01'),
	('2041-07-14', '2041-07-01'),
	('2041-07-15', '2041-07-01'),
	('2041-07-16', '2041-07-01'),
	('2041-07-17', '2041-07-01'),
	('2041-07-18', '2041-07-01'),
	('2041-07-19', '2041-07-01'),
	('2041-07-20', '2041-07-01'),
	('2041-07-21', '2041-07-01'),
	('2041-07-22', '2041-07-01'),
	('2041-07-23', '2041-07-01'),
	('2041-07-24', '2041-07-01'),
	('2041-07-25', '2041-07-01'),
	('2041-07-26', '2041-07-01'),
	('2041-07-27', '2041-07-01'),
	('2041-07-28', '2041-07-01'),
	('2041-07-29', '2041-07-01'),
	('2041-07-30', '2041-07-01'),
	('2041-07-31', '2041-07-01'),
	('2041-08-01', '2041-08-01'),
	('2041-08-02', '2041-08-01'),
	('2041-08-03', '2041-08-01'),
	('2041-08-04', '2041-08-01'),
	('2041-08-05', '2041-08-01'),
	('2041-08-06', '2041-08-01'),
	('2041-08-07', '2041-08-01'),
	('2041-08-08', '2041-08-01'),
	('2041-08-09', '2041-08-01'),
	('2041-08-10', '2041-08-01'),
	('2041-08-11', '2041-08-01'),
	('2041-08-12', '2041-08-01'),
	('2041-08-13', '2041-08-01'),
	('2041-08-14', '2041-08-01'),
	('2041-08-15', '2041-08-01'),
	('2041-08-16', '2041-08-01'),
	('2041-08-17', '2041-08-01'),
	('2041-08-18', '2041-08-01'),
	('2041-08-19', '2041-08-01'),
	('2041-08-20', '2041-08-01'),
	('2041-08-21', '2041-08-01'),
	('2041-08-22', '2041-08-01'),
	('2041-08-23', '2041-08-01'),
	('2041-08-24', '2041-08-01'),
	('2041-08-25', '2041-08-01'),
	('2041-08-26', '2041-08-01'),
	('2041-08-27', '2041-08-01'),
	('2041-08-28', '2041-08-01'),
	('2041-08-29', '2041-08-01'),
	('2041-08-30', '2041-08-01'),
	('2041-08-31', '2041-08-01'),
	('2041-09-01', '2041-09-01'),
	('2041-09-02', '2041-09-01'),
	('2041-09-03', '2041-09-01'),
	('2041-09-04', '2041-09-01'),
	('2041-09-05', '2041-09-01'),
	('2041-09-06', '2041-09-01'),
	('2041-09-07', '2041-09-01'),
	('2041-09-08', '2041-09-01'),
	('2041-09-09', '2041-09-01'),
	('2041-09-10', '2041-09-01'),
	('2041-09-11', '2041-09-01'),
	('2041-09-12', '2041-09-01'),
	('2041-09-13', '2041-09-01'),
	('2041-09-14', '2041-09-01'),
	('2041-09-15', '2041-09-01'),
	('2041-09-16', '2041-09-01'),
	('2041-09-17', '2041-09-01'),
	('2041-09-18', '2041-09-01'),
	('2041-09-19', '2041-09-01'),
	('2041-09-20', '2041-09-01'),
	('2041-09-21', '2041-09-01'),
	('2041-09-22', '2041-09-01'),
	('2041-09-23', '2041-09-01'),
	('2041-09-24', '2041-09-01'),
	('2041-09-25', '2041-09-01'),
	('2041-09-26', '2041-09-01'),
	('2041-09-27', '2041-09-01'),
	('2041-09-28', '2041-09-01'),
	('2041-09-29', '2041-09-01'),
	('2041-09-30', '2041-09-01'),
	('2041-10-01', '2041-10-01'),
	('2041-10-02', '2041-10-01'),
	('2041-10-03', '2041-10-01'),
	('2041-10-04', '2041-10-01'),
	('2041-10-05', '2041-10-01'),
	('2041-10-06', '2041-10-01'),
	('2041-10-07', '2041-10-01'),
	('2041-10-08', '2041-10-01'),
	('2041-10-09', '2041-10-01'),
	('2041-10-10', '2041-10-01'),
	('2041-10-11', '2041-10-01'),
	('2041-10-12', '2041-10-01'),
	('2041-10-13', '2041-10-01'),
	('2041-10-14', '2041-10-01'),
	('2041-10-15', '2041-10-01'),
	('2041-10-16', '2041-10-01'),
	('2041-10-17', '2041-10-01'),
	('2041-10-18', '2041-10-01'),
	('2041-10-19', '2041-10-01'),
	('2041-10-20', '2041-10-01'),
	('2041-10-21', '2041-10-01'),
	('2041-10-22', '2041-10-01'),
	('2041-10-23', '2041-10-01'),
	('2041-10-24', '2041-10-01'),
	('2041-10-25', '2041-10-01'),
	('2041-10-26', '2041-10-01'),
	('2041-10-27', '2041-10-01'),
	('2041-10-28', '2041-10-01'),
	('2041-10-29', '2041-10-01'),
	('2041-10-30', '2041-10-01'),
	('2041-10-31', '2041-10-01'),
	('2041-11-01', '2041-11-01'),
	('2041-11-02', '2041-11-01'),
	('2041-11-03', '2041-11-01'),
	('2041-11-04', '2041-11-01'),
	('2041-11-05', '2041-11-01'),
	('2041-11-06', '2041-11-01'),
	('2041-11-07', '2041-11-01'),
	('2041-11-08', '2041-11-01'),
	('2041-11-09', '2041-11-01'),
	('2041-11-10', '2041-11-01'),
	('2041-11-11', '2041-11-01'),
	('2041-11-12', '2041-11-01'),
	('2041-11-13', '2041-11-01'),
	('2041-11-14', '2041-11-01'),
	('2041-11-15', '2041-11-01'),
	('2041-11-16', '2041-11-01'),
	('2041-11-17', '2041-11-01'),
	('2041-11-18', '2041-11-01'),
	('2041-11-19', '2041-11-01'),
	('2041-11-20', '2041-11-01'),
	('2041-11-21', '2041-11-01'),
	('2041-11-22', '2041-11-01'),
	('2041-11-23', '2041-11-01'),
	('2041-11-24', '2041-11-01'),
	('2041-11-25', '2041-11-01'),
	('2041-11-26', '2041-11-01'),
	('2041-11-27', '2041-11-01'),
	('2041-11-28', '2041-11-01'),
	('2041-11-29', '2041-11-01'),
	('2041-11-30', '2041-11-01'),
	('2041-12-01', '2041-12-01'),
	('2041-12-02', '2041-12-01'),
	('2041-12-03', '2041-12-01'),
	('2041-12-04', '2041-12-01'),
	('2041-12-05', '2041-12-01'),
	('2041-12-06', '2041-12-01'),
	('2041-12-07', '2041-12-01'),
	('2041-12-08', '2041-12-01'),
	('2041-12-09', '2041-12-01'),
	('2041-12-10', '2041-12-01'),
	('2041-12-11', '2041-12-01'),
	('2041-12-12', '2041-12-01'),
	('2041-12-13', '2041-12-01'),
	('2041-12-14', '2041-12-01'),
	('2041-12-15', '2041-12-01'),
	('2041-12-16', '2041-12-01'),
	('2041-12-17', '2041-12-01'),
	('2041-12-18', '2041-12-01'),
	('2041-12-19', '2041-12-01'),
	('2041-12-20', '2041-12-01'),
	('2041-12-21', '2041-12-01'),
	('2041-12-22', '2041-12-01'),
	('2041-12-23', '2041-12-01'),
	('2041-12-24', '2041-12-01'),
	('2041-12-25', '2041-12-01'),
	('2041-12-26', '2041-12-01'),
	('2041-12-27', '2041-12-01'),
	('2041-12-28', '2041-12-01'),
	('2041-12-29', '2041-12-01'),
	('2041-12-30', '2041-12-01'),
	('2041-12-31', '2041-12-01'),
	('2042-01-01', '2042-01-01'),
	('2042-01-02', '2042-01-01'),
	('2042-01-03', '2042-01-01'),
	('2042-01-04', '2042-01-01'),
	('2042-01-05', '2042-01-01'),
	('2042-01-06', '2042-01-01'),
	('2042-01-07', '2042-01-01'),
	('2042-01-08', '2042-01-01'),
	('2042-01-09', '2042-01-01'),
	('2042-01-10', '2042-01-01'),
	('2042-01-11', '2042-01-01'),
	('2042-01-12', '2042-01-01'),
	('2042-01-13', '2042-01-01'),
	('2042-01-14', '2042-01-01'),
	('2042-01-15', '2042-01-01'),
	('2042-01-16', '2042-01-01'),
	('2042-01-17', '2042-01-01'),
	('2042-01-18', '2042-01-01'),
	('2042-01-19', '2042-01-01'),
	('2042-01-20', '2042-01-01'),
	('2042-01-21', '2042-01-01'),
	('2042-01-22', '2042-01-01'),
	('2042-01-23', '2042-01-01'),
	('2042-01-24', '2042-01-01'),
	('2042-01-25', '2042-01-01'),
	('2042-01-26', '2042-01-01'),
	('2042-01-27', '2042-01-01'),
	('2042-01-28', '2042-01-01'),
	('2042-01-29', '2042-01-01'),
	('2042-01-30', '2042-01-01'),
	('2042-01-31', '2042-01-01'),
	('2042-02-01', '2042-02-01'),
	('2042-02-02', '2042-02-01'),
	('2042-02-03', '2042-02-01'),
	('2042-02-04', '2042-02-01'),
	('2042-02-05', '2042-02-01'),
	('2042-02-06', '2042-02-01'),
	('2042-02-07', '2042-02-01'),
	('2042-02-08', '2042-02-01'),
	('2042-02-09', '2042-02-01'),
	('2042-02-10', '2042-02-01'),
	('2042-02-11', '2042-02-01'),
	('2042-02-12', '2042-02-01'),
	('2042-02-13', '2042-02-01'),
	('2042-02-14', '2042-02-01'),
	('2042-02-15', '2042-02-01'),
	('2042-02-16', '2042-02-01'),
	('2042-02-17', '2042-02-01'),
	('2042-02-18', '2042-02-01'),
	('2042-02-19', '2042-02-01'),
	('2042-02-20', '2042-02-01'),
	('2042-02-21', '2042-02-01'),
	('2042-02-22', '2042-02-01'),
	('2042-02-23', '2042-02-01'),
	('2042-02-24', '2042-02-01'),
	('2042-02-25', '2042-02-01'),
	('2042-02-26', '2042-02-01'),
	('2042-02-27', '2042-02-01'),
	('2042-02-28', '2042-02-01'),
	('2042-03-01', '2042-03-01'),
	('2042-03-02', '2042-03-01'),
	('2042-03-03', '2042-03-01'),
	('2042-03-04', '2042-03-01'),
	('2042-03-05', '2042-03-01'),
	('2042-03-06', '2042-03-01'),
	('2042-03-07', '2042-03-01'),
	('2042-03-08', '2042-03-01'),
	('2042-03-09', '2042-03-01'),
	('2042-03-10', '2042-03-01'),
	('2042-03-11', '2042-03-01'),
	('2042-03-12', '2042-03-01'),
	('2042-03-13', '2042-03-01'),
	('2042-03-14', '2042-03-01'),
	('2042-03-15', '2042-03-01'),
	('2042-03-16', '2042-03-01'),
	('2042-03-17', '2042-03-01'),
	('2042-03-18', '2042-03-01'),
	('2042-03-19', '2042-03-01'),
	('2042-03-20', '2042-03-01'),
	('2042-03-21', '2042-03-01'),
	('2042-03-22', '2042-03-01'),
	('2042-03-23', '2042-03-01'),
	('2042-03-24', '2042-03-01'),
	('2042-03-25', '2042-03-01'),
	('2042-03-26', '2042-03-01'),
	('2042-03-27', '2042-03-01'),
	('2042-03-28', '2042-03-01'),
	('2042-03-29', '2042-03-01'),
	('2042-03-30', '2042-03-01'),
	('2042-03-31', '2042-03-01'),
	('2042-04-01', '2042-04-01'),
	('2042-04-02', '2042-04-01'),
	('2042-04-03', '2042-04-01'),
	('2042-04-04', '2042-04-01'),
	('2042-04-05', '2042-04-01'),
	('2042-04-06', '2042-04-01'),
	('2042-04-07', '2042-04-01'),
	('2042-04-08', '2042-04-01'),
	('2042-04-09', '2042-04-01'),
	('2042-04-10', '2042-04-01'),
	('2042-04-11', '2042-04-01'),
	('2042-04-12', '2042-04-01'),
	('2042-04-13', '2042-04-01'),
	('2042-04-14', '2042-04-01'),
	('2042-04-15', '2042-04-01'),
	('2042-04-16', '2042-04-01'),
	('2042-04-17', '2042-04-01'),
	('2042-04-18', '2042-04-01'),
	('2042-04-19', '2042-04-01'),
	('2042-04-20', '2042-04-01'),
	('2042-04-21', '2042-04-01'),
	('2042-04-22', '2042-04-01'),
	('2042-04-23', '2042-04-01'),
	('2042-04-24', '2042-04-01'),
	('2042-04-25', '2042-04-01'),
	('2042-04-26', '2042-04-01'),
	('2042-04-27', '2042-04-01'),
	('2042-04-28', '2042-04-01'),
	('2042-04-29', '2042-04-01'),
	('2042-04-30', '2042-04-01'),
	('2042-05-01', '2042-05-01'),
	('2042-05-02', '2042-05-01'),
	('2042-05-03', '2042-05-01'),
	('2042-05-04', '2042-05-01'),
	('2042-05-05', '2042-05-01'),
	('2042-05-06', '2042-05-01'),
	('2042-05-07', '2042-05-01'),
	('2042-05-08', '2042-05-01'),
	('2042-05-09', '2042-05-01'),
	('2042-05-10', '2042-05-01'),
	('2042-05-11', '2042-05-01'),
	('2042-05-12', '2042-05-01'),
	('2042-05-13', '2042-05-01'),
	('2042-05-14', '2042-05-01'),
	('2042-05-15', '2042-05-01'),
	('2042-05-16', '2042-05-01'),
	('2042-05-17', '2042-05-01'),
	('2042-05-18', '2042-05-01'),
	('2042-05-19', '2042-05-01'),
	('2042-05-20', '2042-05-01'),
	('2042-05-21', '2042-05-01'),
	('2042-05-22', '2042-05-01'),
	('2042-05-23', '2042-05-01'),
	('2042-05-24', '2042-05-01'),
	('2042-05-25', '2042-05-01'),
	('2042-05-26', '2042-05-01'),
	('2042-05-27', '2042-05-01'),
	('2042-05-28', '2042-05-01'),
	('2042-05-29', '2042-05-01'),
	('2042-05-30', '2042-05-01'),
	('2042-05-31', '2042-05-01'),
	('2042-06-01', '2042-06-01'),
	('2042-06-02', '2042-06-01'),
	('2042-06-03', '2042-06-01'),
	('2042-06-04', '2042-06-01'),
	('2042-06-05', '2042-06-01'),
	('2042-06-06', '2042-06-01'),
	('2042-06-07', '2042-06-01'),
	('2042-06-08', '2042-06-01'),
	('2042-06-09', '2042-06-01'),
	('2042-06-10', '2042-06-01'),
	('2042-06-11', '2042-06-01'),
	('2042-06-12', '2042-06-01'),
	('2042-06-13', '2042-06-01'),
	('2042-06-14', '2042-06-01'),
	('2042-06-15', '2042-06-01'),
	('2042-06-16', '2042-06-01'),
	('2042-06-17', '2042-06-01'),
	('2042-06-18', '2042-06-01'),
	('2042-06-19', '2042-06-01'),
	('2042-06-20', '2042-06-01'),
	('2042-06-21', '2042-06-01'),
	('2042-06-22', '2042-06-01'),
	('2042-06-23', '2042-06-01'),
	('2042-06-24', '2042-06-01'),
	('2042-06-25', '2042-06-01'),
	('2042-06-26', '2042-06-01'),
	('2042-06-27', '2042-06-01'),
	('2042-06-28', '2042-06-01'),
	('2042-06-29', '2042-06-01'),
	('2042-06-30', '2042-06-01'),
	('2042-07-01', '2042-07-01'),
	('2042-07-02', '2042-07-01'),
	('2042-07-03', '2042-07-01'),
	('2042-07-04', '2042-07-01'),
	('2042-07-05', '2042-07-01'),
	('2042-07-06', '2042-07-01'),
	('2042-07-07', '2042-07-01'),
	('2042-07-08', '2042-07-01'),
	('2042-07-09', '2042-07-01'),
	('2042-07-10', '2042-07-01'),
	('2042-07-11', '2042-07-01'),
	('2042-07-12', '2042-07-01'),
	('2042-07-13', '2042-07-01'),
	('2042-07-14', '2042-07-01'),
	('2042-07-15', '2042-07-01'),
	('2042-07-16', '2042-07-01'),
	('2042-07-17', '2042-07-01'),
	('2042-07-18', '2042-07-01'),
	('2042-07-19', '2042-07-01'),
	('2042-07-20', '2042-07-01'),
	('2042-07-21', '2042-07-01'),
	('2042-07-22', '2042-07-01'),
	('2042-07-23', '2042-07-01'),
	('2042-07-24', '2042-07-01'),
	('2042-07-25', '2042-07-01'),
	('2042-07-26', '2042-07-01'),
	('2042-07-27', '2042-07-01'),
	('2042-07-28', '2042-07-01'),
	('2042-07-29', '2042-07-01'),
	('2042-07-30', '2042-07-01'),
	('2042-07-31', '2042-07-01'),
	('2042-08-01', '2042-08-01'),
	('2042-08-02', '2042-08-01'),
	('2042-08-03', '2042-08-01'),
	('2042-08-04', '2042-08-01'),
	('2042-08-05', '2042-08-01'),
	('2042-08-06', '2042-08-01'),
	('2042-08-07', '2042-08-01'),
	('2042-08-08', '2042-08-01'),
	('2042-08-09', '2042-08-01'),
	('2042-08-10', '2042-08-01'),
	('2042-08-11', '2042-08-01'),
	('2042-08-12', '2042-08-01'),
	('2042-08-13', '2042-08-01'),
	('2042-08-14', '2042-08-01'),
	('2042-08-15', '2042-08-01'),
	('2042-08-16', '2042-08-01'),
	('2042-08-17', '2042-08-01'),
	('2042-08-18', '2042-08-01'),
	('2042-08-19', '2042-08-01'),
	('2042-08-20', '2042-08-01'),
	('2042-08-21', '2042-08-01'),
	('2042-08-22', '2042-08-01'),
	('2042-08-23', '2042-08-01'),
	('2042-08-24', '2042-08-01'),
	('2042-08-25', '2042-08-01'),
	('2042-08-26', '2042-08-01'),
	('2042-08-27', '2042-08-01'),
	('2042-08-28', '2042-08-01'),
	('2042-08-29', '2042-08-01'),
	('2042-08-30', '2042-08-01'),
	('2042-08-31', '2042-08-01'),
	('2042-09-01', '2042-09-01'),
	('2042-09-02', '2042-09-01'),
	('2042-09-03', '2042-09-01'),
	('2042-09-04', '2042-09-01'),
	('2042-09-05', '2042-09-01'),
	('2042-09-06', '2042-09-01'),
	('2042-09-07', '2042-09-01'),
	('2042-09-08', '2042-09-01'),
	('2042-09-09', '2042-09-01'),
	('2042-09-10', '2042-09-01'),
	('2042-09-11', '2042-09-01'),
	('2042-09-12', '2042-09-01'),
	('2042-09-13', '2042-09-01'),
	('2042-09-14', '2042-09-01'),
	('2042-09-15', '2042-09-01'),
	('2042-09-16', '2042-09-01'),
	('2042-09-17', '2042-09-01'),
	('2042-09-18', '2042-09-01'),
	('2042-09-19', '2042-09-01'),
	('2042-09-20', '2042-09-01'),
	('2042-09-21', '2042-09-01'),
	('2042-09-22', '2042-09-01'),
	('2042-09-23', '2042-09-01'),
	('2042-09-24', '2042-09-01'),
	('2042-09-25', '2042-09-01'),
	('2042-09-26', '2042-09-01'),
	('2042-09-27', '2042-09-01'),
	('2042-09-28', '2042-09-01'),
	('2042-09-29', '2042-09-01'),
	('2042-09-30', '2042-09-01'),
	('2042-10-01', '2042-10-01'),
	('2042-10-02', '2042-10-01'),
	('2042-10-03', '2042-10-01'),
	('2042-10-04', '2042-10-01'),
	('2042-10-05', '2042-10-01'),
	('2042-10-06', '2042-10-01'),
	('2042-10-07', '2042-10-01'),
	('2042-10-08', '2042-10-01'),
	('2042-10-09', '2042-10-01'),
	('2042-10-10', '2042-10-01'),
	('2042-10-11', '2042-10-01'),
	('2042-10-12', '2042-10-01'),
	('2042-10-13', '2042-10-01'),
	('2042-10-14', '2042-10-01'),
	('2042-10-15', '2042-10-01'),
	('2042-10-16', '2042-10-01'),
	('2042-10-17', '2042-10-01'),
	('2042-10-18', '2042-10-01'),
	('2042-10-19', '2042-10-01'),
	('2042-10-20', '2042-10-01'),
	('2042-10-21', '2042-10-01'),
	('2042-10-22', '2042-10-01'),
	('2042-10-23', '2042-10-01'),
	('2042-10-24', '2042-10-01'),
	('2042-10-25', '2042-10-01'),
	('2042-10-26', '2042-10-01'),
	('2042-10-27', '2042-10-01'),
	('2042-10-28', '2042-10-01'),
	('2042-10-29', '2042-10-01'),
	('2042-10-30', '2042-10-01'),
	('2042-10-31', '2042-10-01'),
	('2042-11-01', '2042-11-01'),
	('2042-11-02', '2042-11-01'),
	('2042-11-03', '2042-11-01'),
	('2042-11-04', '2042-11-01'),
	('2042-11-05', '2042-11-01'),
	('2042-11-06', '2042-11-01'),
	('2042-11-07', '2042-11-01'),
	('2042-11-08', '2042-11-01'),
	('2042-11-09', '2042-11-01'),
	('2042-11-10', '2042-11-01'),
	('2042-11-11', '2042-11-01'),
	('2042-11-12', '2042-11-01'),
	('2042-11-13', '2042-11-01'),
	('2042-11-14', '2042-11-01'),
	('2042-11-15', '2042-11-01'),
	('2042-11-16', '2042-11-01'),
	('2042-11-17', '2042-11-01'),
	('2042-11-18', '2042-11-01'),
	('2042-11-19', '2042-11-01'),
	('2042-11-20', '2042-11-01'),
	('2042-11-21', '2042-11-01'),
	('2042-11-22', '2042-11-01'),
	('2042-11-23', '2042-11-01'),
	('2042-11-24', '2042-11-01'),
	('2042-11-25', '2042-11-01'),
	('2042-11-26', '2042-11-01'),
	('2042-11-27', '2042-11-01'),
	('2042-11-28', '2042-11-01'),
	('2042-11-29', '2042-11-01'),
	('2042-11-30', '2042-11-01'),
	('2042-12-01', '2042-12-01'),
	('2042-12-02', '2042-12-01'),
	('2042-12-03', '2042-12-01'),
	('2042-12-04', '2042-12-01'),
	('2042-12-05', '2042-12-01'),
	('2042-12-06', '2042-12-01'),
	('2042-12-07', '2042-12-01'),
	('2042-12-08', '2042-12-01'),
	('2042-12-09', '2042-12-01'),
	('2042-12-10', '2042-12-01'),
	('2042-12-11', '2042-12-01'),
	('2042-12-12', '2042-12-01'),
	('2042-12-13', '2042-12-01'),
	('2042-12-14', '2042-12-01'),
	('2042-12-15', '2042-12-01'),
	('2042-12-16', '2042-12-01'),
	('2042-12-17', '2042-12-01'),
	('2042-12-18', '2042-12-01'),
	('2042-12-19', '2042-12-01'),
	('2042-12-20', '2042-12-01'),
	('2042-12-21', '2042-12-01'),
	('2042-12-22', '2042-12-01'),
	('2042-12-23', '2042-12-01'),
	('2042-12-24', '2042-12-01'),
	('2042-12-25', '2042-12-01'),
	('2042-12-26', '2042-12-01'),
	('2042-12-27', '2042-12-01'),
	('2042-12-28', '2042-12-01'),
	('2042-12-29', '2042-12-01'),
	('2042-12-30', '2042-12-01'),
	('2042-12-31', '2042-12-01'),
	('2043-01-01', '2043-01-01'),
	('2043-01-02', '2043-01-01'),
	('2043-01-03', '2043-01-01'),
	('2043-01-04', '2043-01-01'),
	('2043-01-05', '2043-01-01'),
	('2043-01-06', '2043-01-01'),
	('2043-01-07', '2043-01-01'),
	('2043-01-08', '2043-01-01'),
	('2043-01-09', '2043-01-01'),
	('2043-01-10', '2043-01-01'),
	('2043-01-11', '2043-01-01'),
	('2043-01-12', '2043-01-01'),
	('2043-01-13', '2043-01-01'),
	('2043-01-14', '2043-01-01'),
	('2043-01-15', '2043-01-01'),
	('2043-01-16', '2043-01-01'),
	('2043-01-17', '2043-01-01'),
	('2043-01-18', '2043-01-01'),
	('2043-01-19', '2043-01-01'),
	('2043-01-20', '2043-01-01'),
	('2043-01-21', '2043-01-01'),
	('2043-01-22', '2043-01-01'),
	('2043-01-23', '2043-01-01'),
	('2043-01-24', '2043-01-01'),
	('2043-01-25', '2043-01-01'),
	('2043-01-26', '2043-01-01'),
	('2043-01-27', '2043-01-01'),
	('2043-01-28', '2043-01-01'),
	('2043-01-29', '2043-01-01'),
	('2043-01-30', '2043-01-01'),
	('2043-01-31', '2043-01-01'),
	('2043-02-01', '2043-02-01'),
	('2043-02-02', '2043-02-01'),
	('2043-02-03', '2043-02-01'),
	('2043-02-04', '2043-02-01'),
	('2043-02-05', '2043-02-01'),
	('2043-02-06', '2043-02-01'),
	('2043-02-07', '2043-02-01'),
	('2043-02-08', '2043-02-01'),
	('2043-02-09', '2043-02-01'),
	('2043-02-10', '2043-02-01'),
	('2043-02-11', '2043-02-01'),
	('2043-02-12', '2043-02-01'),
	('2043-02-13', '2043-02-01'),
	('2043-02-14', '2043-02-01'),
	('2043-02-15', '2043-02-01'),
	('2043-02-16', '2043-02-01'),
	('2043-02-17', '2043-02-01'),
	('2043-02-18', '2043-02-01'),
	('2043-02-19', '2043-02-01'),
	('2043-02-20', '2043-02-01'),
	('2043-02-21', '2043-02-01'),
	('2043-02-22', '2043-02-01'),
	('2043-02-23', '2043-02-01'),
	('2043-02-24', '2043-02-01'),
	('2043-02-25', '2043-02-01'),
	('2043-02-26', '2043-02-01'),
	('2043-02-27', '2043-02-01'),
	('2043-02-28', '2043-02-01'),
	('2043-03-01', '2043-03-01'),
	('2043-03-02', '2043-03-01'),
	('2043-03-03', '2043-03-01'),
	('2043-03-04', '2043-03-01'),
	('2043-03-05', '2043-03-01'),
	('2043-03-06', '2043-03-01'),
	('2043-03-07', '2043-03-01'),
	('2043-03-08', '2043-03-01'),
	('2043-03-09', '2043-03-01'),
	('2043-03-10', '2043-03-01'),
	('2043-03-11', '2043-03-01'),
	('2043-03-12', '2043-03-01'),
	('2043-03-13', '2043-03-01'),
	('2043-03-14', '2043-03-01'),
	('2043-03-15', '2043-03-01'),
	('2043-03-16', '2043-03-01'),
	('2043-03-17', '2043-03-01'),
	('2043-03-18', '2043-03-01'),
	('2043-03-19', '2043-03-01'),
	('2043-03-20', '2043-03-01'),
	('2043-03-21', '2043-03-01'),
	('2043-03-22', '2043-03-01'),
	('2043-03-23', '2043-03-01'),
	('2043-03-24', '2043-03-01'),
	('2043-03-25', '2043-03-01'),
	('2043-03-26', '2043-03-01'),
	('2043-03-27', '2043-03-01'),
	('2043-03-28', '2043-03-01'),
	('2043-03-29', '2043-03-01'),
	('2043-03-30', '2043-03-01'),
	('2043-03-31', '2043-03-01'),
	('2043-04-01', '2043-04-01'),
	('2043-04-02', '2043-04-01'),
	('2043-04-03', '2043-04-01'),
	('2043-04-04', '2043-04-01'),
	('2043-04-05', '2043-04-01'),
	('2043-04-06', '2043-04-01'),
	('2043-04-07', '2043-04-01'),
	('2043-04-08', '2043-04-01'),
	('2043-04-09', '2043-04-01'),
	('2043-04-10', '2043-04-01'),
	('2043-04-11', '2043-04-01'),
	('2043-04-12', '2043-04-01'),
	('2043-04-13', '2043-04-01'),
	('2043-04-14', '2043-04-01'),
	('2043-04-15', '2043-04-01'),
	('2043-04-16', '2043-04-01'),
	('2043-04-17', '2043-04-01'),
	('2043-04-18', '2043-04-01'),
	('2043-04-19', '2043-04-01'),
	('2043-04-20', '2043-04-01'),
	('2043-04-21', '2043-04-01'),
	('2043-04-22', '2043-04-01'),
	('2043-04-23', '2043-04-01'),
	('2043-04-24', '2043-04-01'),
	('2043-04-25', '2043-04-01'),
	('2043-04-26', '2043-04-01'),
	('2043-04-27', '2043-04-01'),
	('2043-04-28', '2043-04-01'),
	('2043-04-29', '2043-04-01'),
	('2043-04-30', '2043-04-01'),
	('2043-05-01', '2043-05-01'),
	('2043-05-02', '2043-05-01'),
	('2043-05-03', '2043-05-01'),
	('2043-05-04', '2043-05-01'),
	('2043-05-05', '2043-05-01'),
	('2043-05-06', '2043-05-01'),
	('2043-05-07', '2043-05-01'),
	('2043-05-08', '2043-05-01'),
	('2043-05-09', '2043-05-01'),
	('2043-05-10', '2043-05-01'),
	('2043-05-11', '2043-05-01'),
	('2043-05-12', '2043-05-01'),
	('2043-05-13', '2043-05-01'),
	('2043-05-14', '2043-05-01'),
	('2043-05-15', '2043-05-01'),
	('2043-05-16', '2043-05-01'),
	('2043-05-17', '2043-05-01'),
	('2043-05-18', '2043-05-01'),
	('2043-05-19', '2043-05-01'),
	('2043-05-20', '2043-05-01'),
	('2043-05-21', '2043-05-01'),
	('2043-05-22', '2043-05-01'),
	('2043-05-23', '2043-05-01'),
	('2043-05-24', '2043-05-01'),
	('2043-05-25', '2043-05-01'),
	('2043-05-26', '2043-05-01'),
	('2043-05-27', '2043-05-01'),
	('2043-05-28', '2043-05-01'),
	('2043-05-29', '2043-05-01'),
	('2043-05-30', '2043-05-01'),
	('2043-05-31', '2043-05-01'),
	('2043-06-01', '2043-06-01'),
	('2043-06-02', '2043-06-01'),
	('2043-06-03', '2043-06-01'),
	('2043-06-04', '2043-06-01'),
	('2043-06-05', '2043-06-01'),
	('2043-06-06', '2043-06-01'),
	('2043-06-07', '2043-06-01'),
	('2043-06-08', '2043-06-01'),
	('2043-06-09', '2043-06-01'),
	('2043-06-10', '2043-06-01'),
	('2043-06-11', '2043-06-01'),
	('2043-06-12', '2043-06-01'),
	('2043-06-13', '2043-06-01'),
	('2043-06-14', '2043-06-01'),
	('2043-06-15', '2043-06-01'),
	('2043-06-16', '2043-06-01'),
	('2043-06-17', '2043-06-01'),
	('2043-06-18', '2043-06-01'),
	('2043-06-19', '2043-06-01'),
	('2043-06-20', '2043-06-01'),
	('2043-06-21', '2043-06-01'),
	('2043-06-22', '2043-06-01'),
	('2043-06-23', '2043-06-01'),
	('2043-06-24', '2043-06-01'),
	('2043-06-25', '2043-06-01'),
	('2043-06-26', '2043-06-01'),
	('2043-06-27', '2043-06-01'),
	('2043-06-28', '2043-06-01'),
	('2043-06-29', '2043-06-01'),
	('2043-06-30', '2043-06-01'),
	('2043-07-01', '2043-07-01'),
	('2043-07-02', '2043-07-01'),
	('2043-07-03', '2043-07-01'),
	('2043-07-04', '2043-07-01'),
	('2043-07-05', '2043-07-01'),
	('2043-07-06', '2043-07-01'),
	('2043-07-07', '2043-07-01'),
	('2043-07-08', '2043-07-01'),
	('2043-07-09', '2043-07-01'),
	('2043-07-10', '2043-07-01'),
	('2043-07-11', '2043-07-01'),
	('2043-07-12', '2043-07-01'),
	('2043-07-13', '2043-07-01'),
	('2043-07-14', '2043-07-01'),
	('2043-07-15', '2043-07-01'),
	('2043-07-16', '2043-07-01'),
	('2043-07-17', '2043-07-01'),
	('2043-07-18', '2043-07-01'),
	('2043-07-19', '2043-07-01'),
	('2043-07-20', '2043-07-01'),
	('2043-07-21', '2043-07-01'),
	('2043-07-22', '2043-07-01'),
	('2043-07-23', '2043-07-01'),
	('2043-07-24', '2043-07-01'),
	('2043-07-25', '2043-07-01'),
	('2043-07-26', '2043-07-01'),
	('2043-07-27', '2043-07-01'),
	('2043-07-28', '2043-07-01'),
	('2043-07-29', '2043-07-01'),
	('2043-07-30', '2043-07-01'),
	('2043-07-31', '2043-07-01'),
	('2043-08-01', '2043-08-01'),
	('2043-08-02', '2043-08-01'),
	('2043-08-03', '2043-08-01'),
	('2043-08-04', '2043-08-01'),
	('2043-08-05', '2043-08-01'),
	('2043-08-06', '2043-08-01'),
	('2043-08-07', '2043-08-01'),
	('2043-08-08', '2043-08-01'),
	('2043-08-09', '2043-08-01'),
	('2043-08-10', '2043-08-01'),
	('2043-08-11', '2043-08-01'),
	('2043-08-12', '2043-08-01'),
	('2043-08-13', '2043-08-01'),
	('2043-08-14', '2043-08-01'),
	('2043-08-15', '2043-08-01'),
	('2043-08-16', '2043-08-01'),
	('2043-08-17', '2043-08-01'),
	('2043-08-18', '2043-08-01'),
	('2043-08-19', '2043-08-01'),
	('2043-08-20', '2043-08-01'),
	('2043-08-21', '2043-08-01'),
	('2043-08-22', '2043-08-01'),
	('2043-08-23', '2043-08-01'),
	('2043-08-24', '2043-08-01'),
	('2043-08-25', '2043-08-01'),
	('2043-08-26', '2043-08-01'),
	('2043-08-27', '2043-08-01'),
	('2043-08-28', '2043-08-01'),
	('2043-08-29', '2043-08-01'),
	('2043-08-30', '2043-08-01'),
	('2043-08-31', '2043-08-01'),
	('2043-09-01', '2043-09-01'),
	('2043-09-02', '2043-09-01'),
	('2043-09-03', '2043-09-01'),
	('2043-09-04', '2043-09-01'),
	('2043-09-05', '2043-09-01'),
	('2043-09-06', '2043-09-01'),
	('2043-09-07', '2043-09-01'),
	('2043-09-08', '2043-09-01'),
	('2043-09-09', '2043-09-01'),
	('2043-09-10', '2043-09-01'),
	('2043-09-11', '2043-09-01'),
	('2043-09-12', '2043-09-01'),
	('2043-09-13', '2043-09-01'),
	('2043-09-14', '2043-09-01'),
	('2043-09-15', '2043-09-01'),
	('2043-09-16', '2043-09-01'),
	('2043-09-17', '2043-09-01'),
	('2043-09-18', '2043-09-01'),
	('2043-09-19', '2043-09-01'),
	('2043-09-20', '2043-09-01'),
	('2043-09-21', '2043-09-01'),
	('2043-09-22', '2043-09-01'),
	('2043-09-23', '2043-09-01'),
	('2043-09-24', '2043-09-01'),
	('2043-09-25', '2043-09-01'),
	('2043-09-26', '2043-09-01'),
	('2043-09-27', '2043-09-01'),
	('2043-09-28', '2043-09-01'),
	('2043-09-29', '2043-09-01'),
	('2043-09-30', '2043-09-01'),
	('2043-10-01', '2043-10-01'),
	('2043-10-02', '2043-10-01'),
	('2043-10-03', '2043-10-01'),
	('2043-10-04', '2043-10-01'),
	('2043-10-05', '2043-10-01'),
	('2043-10-06', '2043-10-01'),
	('2043-10-07', '2043-10-01'),
	('2043-10-08', '2043-10-01'),
	('2043-10-09', '2043-10-01'),
	('2043-10-10', '2043-10-01'),
	('2043-10-11', '2043-10-01'),
	('2043-10-12', '2043-10-01'),
	('2043-10-13', '2043-10-01'),
	('2043-10-14', '2043-10-01'),
	('2043-10-15', '2043-10-01'),
	('2043-10-16', '2043-10-01'),
	('2043-10-17', '2043-10-01'),
	('2043-10-18', '2043-10-01'),
	('2043-10-19', '2043-10-01'),
	('2043-10-20', '2043-10-01'),
	('2043-10-21', '2043-10-01'),
	('2043-10-22', '2043-10-01'),
	('2043-10-23', '2043-10-01'),
	('2043-10-24', '2043-10-01'),
	('2043-10-25', '2043-10-01'),
	('2043-10-26', '2043-10-01'),
	('2043-10-27', '2043-10-01'),
	('2043-10-28', '2043-10-01'),
	('2043-10-29', '2043-10-01'),
	('2043-10-30', '2043-10-01'),
	('2043-10-31', '2043-10-01'),
	('2043-11-01', '2043-11-01'),
	('2043-11-02', '2043-11-01'),
	('2043-11-03', '2043-11-01'),
	('2043-11-04', '2043-11-01'),
	('2043-11-05', '2043-11-01'),
	('2043-11-06', '2043-11-01'),
	('2043-11-07', '2043-11-01'),
	('2043-11-08', '2043-11-01'),
	('2043-11-09', '2043-11-01'),
	('2043-11-10', '2043-11-01'),
	('2043-11-11', '2043-11-01'),
	('2043-11-12', '2043-11-01'),
	('2043-11-13', '2043-11-01'),
	('2043-11-14', '2043-11-01'),
	('2043-11-15', '2043-11-01'),
	('2043-11-16', '2043-11-01'),
	('2043-11-17', '2043-11-01'),
	('2043-11-18', '2043-11-01'),
	('2043-11-19', '2043-11-01'),
	('2043-11-20', '2043-11-01'),
	('2043-11-21', '2043-11-01'),
	('2043-11-22', '2043-11-01'),
	('2043-11-23', '2043-11-01'),
	('2043-11-24', '2043-11-01'),
	('2043-11-25', '2043-11-01'),
	('2043-11-26', '2043-11-01'),
	('2043-11-27', '2043-11-01'),
	('2043-11-28', '2043-11-01'),
	('2043-11-29', '2043-11-01'),
	('2043-11-30', '2043-11-01'),
	('2043-12-01', '2043-12-01'),
	('2043-12-02', '2043-12-01'),
	('2043-12-03', '2043-12-01'),
	('2043-12-04', '2043-12-01'),
	('2043-12-05', '2043-12-01'),
	('2043-12-06', '2043-12-01'),
	('2043-12-07', '2043-12-01'),
	('2043-12-08', '2043-12-01'),
	('2043-12-09', '2043-12-01'),
	('2043-12-10', '2043-12-01'),
	('2043-12-11', '2043-12-01'),
	('2043-12-12', '2043-12-01'),
	('2043-12-13', '2043-12-01'),
	('2043-12-14', '2043-12-01'),
	('2043-12-15', '2043-12-01'),
	('2043-12-16', '2043-12-01'),
	('2043-12-17', '2043-12-01'),
	('2043-12-18', '2043-12-01'),
	('2043-12-19', '2043-12-01'),
	('2043-12-20', '2043-12-01'),
	('2043-12-21', '2043-12-01'),
	('2043-12-22', '2043-12-01'),
	('2043-12-23', '2043-12-01'),
	('2043-12-24', '2043-12-01'),
	('2043-12-25', '2043-12-01'),
	('2043-12-26', '2043-12-01'),
	('2043-12-27', '2043-12-01'),
	('2043-12-28', '2043-12-01'),
	('2043-12-29', '2043-12-01'),
	('2043-12-30', '2043-12-01'),
	('2043-12-31', '2043-12-01'),
	('2044-01-01', '2044-01-01'),
	('2044-01-02', '2044-01-01'),
	('2044-01-03', '2044-01-01'),
	('2044-01-04', '2044-01-01'),
	('2044-01-05', '2044-01-01'),
	('2044-01-06', '2044-01-01'),
	('2044-01-07', '2044-01-01'),
	('2044-01-08', '2044-01-01'),
	('2044-01-09', '2044-01-01'),
	('2044-01-10', '2044-01-01'),
	('2044-01-11', '2044-01-01'),
	('2044-01-12', '2044-01-01'),
	('2044-01-13', '2044-01-01'),
	('2044-01-14', '2044-01-01'),
	('2044-01-15', '2044-01-01'),
	('2044-01-16', '2044-01-01'),
	('2044-01-17', '2044-01-01'),
	('2044-01-18', '2044-01-01'),
	('2044-01-19', '2044-01-01'),
	('2044-01-20', '2044-01-01'),
	('2044-01-21', '2044-01-01'),
	('2044-01-22', '2044-01-01'),
	('2044-01-23', '2044-01-01'),
	('2044-01-24', '2044-01-01'),
	('2044-01-25', '2044-01-01'),
	('2044-01-26', '2044-01-01'),
	('2044-01-27', '2044-01-01'),
	('2044-01-28', '2044-01-01'),
	('2044-01-29', '2044-01-01'),
	('2044-01-30', '2044-01-01'),
	('2044-01-31', '2044-01-01'),
	('2044-02-01', '2044-02-01'),
	('2044-02-02', '2044-02-01'),
	('2044-02-03', '2044-02-01'),
	('2044-02-04', '2044-02-01'),
	('2044-02-05', '2044-02-01'),
	('2044-02-06', '2044-02-01'),
	('2044-02-07', '2044-02-01'),
	('2044-02-08', '2044-02-01'),
	('2044-02-09', '2044-02-01'),
	('2044-02-10', '2044-02-01'),
	('2044-02-11', '2044-02-01'),
	('2044-02-12', '2044-02-01'),
	('2044-02-13', '2044-02-01'),
	('2044-02-14', '2044-02-01'),
	('2044-02-15', '2044-02-01'),
	('2044-02-16', '2044-02-01'),
	('2044-02-17', '2044-02-01'),
	('2044-02-18', '2044-02-01'),
	('2044-02-19', '2044-02-01'),
	('2044-02-20', '2044-02-01'),
	('2044-02-21', '2044-02-01'),
	('2044-02-22', '2044-02-01'),
	('2044-02-23', '2044-02-01'),
	('2044-02-24', '2044-02-01'),
	('2044-02-25', '2044-02-01'),
	('2044-02-26', '2044-02-01'),
	('2044-02-27', '2044-02-01'),
	('2044-02-28', '2044-02-01'),
	('2044-02-29', '2044-02-01'),
	('2044-03-01', '2044-03-01'),
	('2044-03-02', '2044-03-01'),
	('2044-03-03', '2044-03-01'),
	('2044-03-04', '2044-03-01'),
	('2044-03-05', '2044-03-01'),
	('2044-03-06', '2044-03-01'),
	('2044-03-07', '2044-03-01'),
	('2044-03-08', '2044-03-01'),
	('2044-03-09', '2044-03-01'),
	('2044-03-10', '2044-03-01'),
	('2044-03-11', '2044-03-01'),
	('2044-03-12', '2044-03-01'),
	('2044-03-13', '2044-03-01'),
	('2044-03-14', '2044-03-01'),
	('2044-03-15', '2044-03-01'),
	('2044-03-16', '2044-03-01'),
	('2044-03-17', '2044-03-01'),
	('2044-03-18', '2044-03-01'),
	('2044-03-19', '2044-03-01'),
	('2044-03-20', '2044-03-01'),
	('2044-03-21', '2044-03-01'),
	('2044-03-22', '2044-03-01'),
	('2044-03-23', '2044-03-01'),
	('2044-03-24', '2044-03-01'),
	('2044-03-25', '2044-03-01'),
	('2044-03-26', '2044-03-01'),
	('2044-03-27', '2044-03-01'),
	('2044-03-28', '2044-03-01'),
	('2044-03-29', '2044-03-01'),
	('2044-03-30', '2044-03-01'),
	('2044-03-31', '2044-03-01'),
	('2044-04-01', '2044-04-01'),
	('2044-04-02', '2044-04-01'),
	('2044-04-03', '2044-04-01'),
	('2044-04-04', '2044-04-01'),
	('2044-04-05', '2044-04-01'),
	('2044-04-06', '2044-04-01'),
	('2044-04-07', '2044-04-01'),
	('2044-04-08', '2044-04-01'),
	('2044-04-09', '2044-04-01'),
	('2044-04-10', '2044-04-01'),
	('2044-04-11', '2044-04-01'),
	('2044-04-12', '2044-04-01'),
	('2044-04-13', '2044-04-01'),
	('2044-04-14', '2044-04-01'),
	('2044-04-15', '2044-04-01'),
	('2044-04-16', '2044-04-01'),
	('2044-04-17', '2044-04-01'),
	('2044-04-18', '2044-04-01'),
	('2044-04-19', '2044-04-01'),
	('2044-04-20', '2044-04-01'),
	('2044-04-21', '2044-04-01'),
	('2044-04-22', '2044-04-01'),
	('2044-04-23', '2044-04-01'),
	('2044-04-24', '2044-04-01'),
	('2044-04-25', '2044-04-01'),
	('2044-04-26', '2044-04-01'),
	('2044-04-27', '2044-04-01'),
	('2044-04-28', '2044-04-01'),
	('2044-04-29', '2044-04-01'),
	('2044-04-30', '2044-04-01'),
	('2044-05-01', '2044-05-01'),
	('2044-05-02', '2044-05-01'),
	('2044-05-03', '2044-05-01'),
	('2044-05-04', '2044-05-01'),
	('2044-05-05', '2044-05-01'),
	('2044-05-06', '2044-05-01'),
	('2044-05-07', '2044-05-01'),
	('2044-05-08', '2044-05-01'),
	('2044-05-09', '2044-05-01'),
	('2044-05-10', '2044-05-01'),
	('2044-05-11', '2044-05-01'),
	('2044-05-12', '2044-05-01'),
	('2044-05-13', '2044-05-01'),
	('2044-05-14', '2044-05-01'),
	('2044-05-15', '2044-05-01'),
	('2044-05-16', '2044-05-01'),
	('2044-05-17', '2044-05-01'),
	('2044-05-18', '2044-05-01'),
	('2044-05-19', '2044-05-01'),
	('2044-05-20', '2044-05-01'),
	('2044-05-21', '2044-05-01'),
	('2044-05-22', '2044-05-01'),
	('2044-05-23', '2044-05-01'),
	('2044-05-24', '2044-05-01'),
	('2044-05-25', '2044-05-01'),
	('2044-05-26', '2044-05-01'),
	('2044-05-27', '2044-05-01'),
	('2044-05-28', '2044-05-01'),
	('2044-05-29', '2044-05-01'),
	('2044-05-30', '2044-05-01'),
	('2044-05-31', '2044-05-01'),
	('2044-06-01', '2044-06-01'),
	('2044-06-02', '2044-06-01'),
	('2044-06-03', '2044-06-01'),
	('2044-06-04', '2044-06-01'),
	('2044-06-05', '2044-06-01'),
	('2044-06-06', '2044-06-01'),
	('2044-06-07', '2044-06-01'),
	('2044-06-08', '2044-06-01'),
	('2044-06-09', '2044-06-01'),
	('2044-06-10', '2044-06-01'),
	('2044-06-11', '2044-06-01'),
	('2044-06-12', '2044-06-01'),
	('2044-06-13', '2044-06-01'),
	('2044-06-14', '2044-06-01'),
	('2044-06-15', '2044-06-01'),
	('2044-06-16', '2044-06-01'),
	('2044-06-17', '2044-06-01'),
	('2044-06-18', '2044-06-01'),
	('2044-06-19', '2044-06-01'),
	('2044-06-20', '2044-06-01'),
	('2044-06-21', '2044-06-01'),
	('2044-06-22', '2044-06-01'),
	('2044-06-23', '2044-06-01'),
	('2044-06-24', '2044-06-01'),
	('2044-06-25', '2044-06-01'),
	('2044-06-26', '2044-06-01'),
	('2044-06-27', '2044-06-01'),
	('2044-06-28', '2044-06-01'),
	('2044-06-29', '2044-06-01'),
	('2044-06-30', '2044-06-01'),
	('2044-07-01', '2044-07-01'),
	('2044-07-02', '2044-07-01'),
	('2044-07-03', '2044-07-01'),
	('2044-07-04', '2044-07-01'),
	('2044-07-05', '2044-07-01'),
	('2044-07-06', '2044-07-01'),
	('2044-07-07', '2044-07-01'),
	('2044-07-08', '2044-07-01'),
	('2044-07-09', '2044-07-01'),
	('2044-07-10', '2044-07-01'),
	('2044-07-11', '2044-07-01'),
	('2044-07-12', '2044-07-01'),
	('2044-07-13', '2044-07-01'),
	('2044-07-14', '2044-07-01'),
	('2044-07-15', '2044-07-01'),
	('2044-07-16', '2044-07-01'),
	('2044-07-17', '2044-07-01'),
	('2044-07-18', '2044-07-01'),
	('2044-07-19', '2044-07-01'),
	('2044-07-20', '2044-07-01'),
	('2044-07-21', '2044-07-01'),
	('2044-07-22', '2044-07-01'),
	('2044-07-23', '2044-07-01'),
	('2044-07-24', '2044-07-01'),
	('2044-07-25', '2044-07-01'),
	('2044-07-26', '2044-07-01'),
	('2044-07-27', '2044-07-01'),
	('2044-07-28', '2044-07-01'),
	('2044-07-29', '2044-07-01'),
	('2044-07-30', '2044-07-01'),
	('2044-07-31', '2044-07-01'),
	('2044-08-01', '2044-08-01'),
	('2044-08-02', '2044-08-01'),
	('2044-08-03', '2044-08-01'),
	('2044-08-04', '2044-08-01'),
	('2044-08-05', '2044-08-01'),
	('2044-08-06', '2044-08-01'),
	('2044-08-07', '2044-08-01'),
	('2044-08-08', '2044-08-01'),
	('2044-08-09', '2044-08-01'),
	('2044-08-10', '2044-08-01'),
	('2044-08-11', '2044-08-01'),
	('2044-08-12', '2044-08-01'),
	('2044-08-13', '2044-08-01'),
	('2044-08-14', '2044-08-01'),
	('2044-08-15', '2044-08-01'),
	('2044-08-16', '2044-08-01'),
	('2044-08-17', '2044-08-01'),
	('2044-08-18', '2044-08-01'),
	('2044-08-19', '2044-08-01'),
	('2044-08-20', '2044-08-01'),
	('2044-08-21', '2044-08-01'),
	('2044-08-22', '2044-08-01'),
	('2044-08-23', '2044-08-01'),
	('2044-08-24', '2044-08-01'),
	('2044-08-25', '2044-08-01'),
	('2044-08-26', '2044-08-01'),
	('2044-08-27', '2044-08-01'),
	('2044-08-28', '2044-08-01'),
	('2044-08-29', '2044-08-01'),
	('2044-08-30', '2044-08-01'),
	('2044-08-31', '2044-08-01'),
	('2044-09-01', '2044-09-01'),
	('2044-09-02', '2044-09-01'),
	('2044-09-03', '2044-09-01'),
	('2044-09-04', '2044-09-01'),
	('2044-09-05', '2044-09-01'),
	('2044-09-06', '2044-09-01'),
	('2044-09-07', '2044-09-01'),
	('2044-09-08', '2044-09-01'),
	('2044-09-09', '2044-09-01'),
	('2044-09-10', '2044-09-01'),
	('2044-09-11', '2044-09-01'),
	('2044-09-12', '2044-09-01'),
	('2044-09-13', '2044-09-01'),
	('2044-09-14', '2044-09-01'),
	('2044-09-15', '2044-09-01'),
	('2044-09-16', '2044-09-01'),
	('2044-09-17', '2044-09-01'),
	('2044-09-18', '2044-09-01'),
	('2044-09-19', '2044-09-01'),
	('2044-09-20', '2044-09-01'),
	('2044-09-21', '2044-09-01'),
	('2044-09-22', '2044-09-01'),
	('2044-09-23', '2044-09-01'),
	('2044-09-24', '2044-09-01'),
	('2044-09-25', '2044-09-01'),
	('2044-09-26', '2044-09-01'),
	('2044-09-27', '2044-09-01'),
	('2044-09-28', '2044-09-01'),
	('2044-09-29', '2044-09-01'),
	('2044-09-30', '2044-09-01'),
	('2044-10-01', '2044-10-01'),
	('2044-10-02', '2044-10-01'),
	('2044-10-03', '2044-10-01'),
	('2044-10-04', '2044-10-01'),
	('2044-10-05', '2044-10-01'),
	('2044-10-06', '2044-10-01'),
	('2044-10-07', '2044-10-01'),
	('2044-10-08', '2044-10-01'),
	('2044-10-09', '2044-10-01'),
	('2044-10-10', '2044-10-01'),
	('2044-10-11', '2044-10-01'),
	('2044-10-12', '2044-10-01'),
	('2044-10-13', '2044-10-01'),
	('2044-10-14', '2044-10-01'),
	('2044-10-15', '2044-10-01'),
	('2044-10-16', '2044-10-01'),
	('2044-10-17', '2044-10-01'),
	('2044-10-18', '2044-10-01'),
	('2044-10-19', '2044-10-01'),
	('2044-10-20', '2044-10-01'),
	('2044-10-21', '2044-10-01'),
	('2044-10-22', '2044-10-01'),
	('2044-10-23', '2044-10-01'),
	('2044-10-24', '2044-10-01'),
	('2044-10-25', '2044-10-01'),
	('2044-10-26', '2044-10-01'),
	('2044-10-27', '2044-10-01'),
	('2044-10-28', '2044-10-01'),
	('2044-10-29', '2044-10-01'),
	('2044-10-30', '2044-10-01'),
	('2044-10-31', '2044-10-01'),
	('2044-11-01', '2044-11-01'),
	('2044-11-02', '2044-11-01'),
	('2044-11-03', '2044-11-01'),
	('2044-11-04', '2044-11-01'),
	('2044-11-05', '2044-11-01'),
	('2044-11-06', '2044-11-01'),
	('2044-11-07', '2044-11-01'),
	('2044-11-08', '2044-11-01'),
	('2044-11-09', '2044-11-01'),
	('2044-11-10', '2044-11-01'),
	('2044-11-11', '2044-11-01'),
	('2044-11-12', '2044-11-01'),
	('2044-11-13', '2044-11-01'),
	('2044-11-14', '2044-11-01'),
	('2044-11-15', '2044-11-01'),
	('2044-11-16', '2044-11-01'),
	('2044-11-17', '2044-11-01'),
	('2044-11-18', '2044-11-01'),
	('2044-11-19', '2044-11-01'),
	('2044-11-20', '2044-11-01'),
	('2044-11-21', '2044-11-01'),
	('2044-11-22', '2044-11-01'),
	('2044-11-23', '2044-11-01'),
	('2044-11-24', '2044-11-01'),
	('2044-11-25', '2044-11-01'),
	('2044-11-26', '2044-11-01'),
	('2044-11-27', '2044-11-01'),
	('2044-11-28', '2044-11-01'),
	('2044-11-29', '2044-11-01'),
	('2044-11-30', '2044-11-01'),
	('2044-12-01', '2044-12-01'),
	('2044-12-02', '2044-12-01'),
	('2044-12-03', '2044-12-01'),
	('2044-12-04', '2044-12-01'),
	('2044-12-05', '2044-12-01'),
	('2044-12-06', '2044-12-01'),
	('2044-12-07', '2044-12-01'),
	('2044-12-08', '2044-12-01'),
	('2044-12-09', '2044-12-01'),
	('2044-12-10', '2044-12-01'),
	('2044-12-11', '2044-12-01'),
	('2044-12-12', '2044-12-01'),
	('2044-12-13', '2044-12-01'),
	('2044-12-14', '2044-12-01'),
	('2044-12-15', '2044-12-01'),
	('2044-12-16', '2044-12-01'),
	('2044-12-17', '2044-12-01'),
	('2044-12-18', '2044-12-01'),
	('2044-12-19', '2044-12-01'),
	('2044-12-20', '2044-12-01'),
	('2044-12-21', '2044-12-01'),
	('2044-12-22', '2044-12-01'),
	('2044-12-23', '2044-12-01'),
	('2044-12-24', '2044-12-01'),
	('2044-12-25', '2044-12-01'),
	('2044-12-26', '2044-12-01'),
	('2044-12-27', '2044-12-01'),
	('2044-12-28', '2044-12-01'),
	('2044-12-29', '2044-12-01'),
	('2044-12-30', '2044-12-01'),
	('2044-12-31', '2044-12-01'),
	('2045-01-01', '2045-01-01'),
	('2045-01-02', '2045-01-01'),
	('2045-01-03', '2045-01-01'),
	('2045-01-04', '2045-01-01'),
	('2045-01-05', '2045-01-01'),
	('2045-01-06', '2045-01-01'),
	('2045-01-07', '2045-01-01'),
	('2045-01-08', '2045-01-01'),
	('2045-01-09', '2045-01-01'),
	('2045-01-10', '2045-01-01'),
	('2045-01-11', '2045-01-01'),
	('2045-01-12', '2045-01-01'),
	('2045-01-13', '2045-01-01'),
	('2045-01-14', '2045-01-01'),
	('2045-01-15', '2045-01-01'),
	('2045-01-16', '2045-01-01'),
	('2045-01-17', '2045-01-01'),
	('2045-01-18', '2045-01-01'),
	('2045-01-19', '2045-01-01'),
	('2045-01-20', '2045-01-01'),
	('2045-01-21', '2045-01-01'),
	('2045-01-22', '2045-01-01'),
	('2045-01-23', '2045-01-01'),
	('2045-01-24', '2045-01-01'),
	('2045-01-25', '2045-01-01'),
	('2045-01-26', '2045-01-01'),
	('2045-01-27', '2045-01-01'),
	('2045-01-28', '2045-01-01'),
	('2045-01-29', '2045-01-01'),
	('2045-01-30', '2045-01-01'),
	('2045-01-31', '2045-01-01'),
	('2045-02-01', '2045-02-01'),
	('2045-02-02', '2045-02-01'),
	('2045-02-03', '2045-02-01'),
	('2045-02-04', '2045-02-01'),
	('2045-02-05', '2045-02-01'),
	('2045-02-06', '2045-02-01'),
	('2045-02-07', '2045-02-01'),
	('2045-02-08', '2045-02-01'),
	('2045-02-09', '2045-02-01'),
	('2045-02-10', '2045-02-01'),
	('2045-02-11', '2045-02-01'),
	('2045-02-12', '2045-02-01'),
	('2045-02-13', '2045-02-01'),
	('2045-02-14', '2045-02-01'),
	('2045-02-15', '2045-02-01'),
	('2045-02-16', '2045-02-01'),
	('2045-02-17', '2045-02-01'),
	('2045-02-18', '2045-02-01'),
	('2045-02-19', '2045-02-01'),
	('2045-02-20', '2045-02-01'),
	('2045-02-21', '2045-02-01'),
	('2045-02-22', '2045-02-01'),
	('2045-02-23', '2045-02-01'),
	('2045-02-24', '2045-02-01'),
	('2045-02-25', '2045-02-01'),
	('2045-02-26', '2045-02-01'),
	('2045-02-27', '2045-02-01'),
	('2045-02-28', '2045-02-01'),
	('2045-03-01', '2045-03-01'),
	('2045-03-02', '2045-03-01'),
	('2045-03-03', '2045-03-01'),
	('2045-03-04', '2045-03-01'),
	('2045-03-05', '2045-03-01'),
	('2045-03-06', '2045-03-01'),
	('2045-03-07', '2045-03-01'),
	('2045-03-08', '2045-03-01'),
	('2045-03-09', '2045-03-01'),
	('2045-03-10', '2045-03-01'),
	('2045-03-11', '2045-03-01'),
	('2045-03-12', '2045-03-01'),
	('2045-03-13', '2045-03-01'),
	('2045-03-14', '2045-03-01'),
	('2045-03-15', '2045-03-01'),
	('2045-03-16', '2045-03-01'),
	('2045-03-17', '2045-03-01'),
	('2045-03-18', '2045-03-01'),
	('2045-03-19', '2045-03-01'),
	('2045-03-20', '2045-03-01'),
	('2045-03-21', '2045-03-01'),
	('2045-03-22', '2045-03-01'),
	('2045-03-23', '2045-03-01'),
	('2045-03-24', '2045-03-01'),
	('2045-03-25', '2045-03-01'),
	('2045-03-26', '2045-03-01'),
	('2045-03-27', '2045-03-01'),
	('2045-03-28', '2045-03-01'),
	('2045-03-29', '2045-03-01'),
	('2045-03-30', '2045-03-01'),
	('2045-03-31', '2045-03-01'),
	('2045-04-01', '2045-04-01'),
	('2045-04-02', '2045-04-01'),
	('2045-04-03', '2045-04-01'),
	('2045-04-04', '2045-04-01'),
	('2045-04-05', '2045-04-01'),
	('2045-04-06', '2045-04-01'),
	('2045-04-07', '2045-04-01'),
	('2045-04-08', '2045-04-01'),
	('2045-04-09', '2045-04-01'),
	('2045-04-10', '2045-04-01'),
	('2045-04-11', '2045-04-01'),
	('2045-04-12', '2045-04-01'),
	('2045-04-13', '2045-04-01'),
	('2045-04-14', '2045-04-01'),
	('2045-04-15', '2045-04-01'),
	('2045-04-16', '2045-04-01'),
	('2045-04-17', '2045-04-01'),
	('2045-04-18', '2045-04-01'),
	('2045-04-19', '2045-04-01'),
	('2045-04-20', '2045-04-01'),
	('2045-04-21', '2045-04-01'),
	('2045-04-22', '2045-04-01'),
	('2045-04-23', '2045-04-01'),
	('2045-04-24', '2045-04-01'),
	('2045-04-25', '2045-04-01'),
	('2045-04-26', '2045-04-01'),
	('2045-04-27', '2045-04-01'),
	('2045-04-28', '2045-04-01'),
	('2045-04-29', '2045-04-01'),
	('2045-04-30', '2045-04-01'),
	('2045-05-01', '2045-05-01'),
	('2045-05-02', '2045-05-01'),
	('2045-05-03', '2045-05-01'),
	('2045-05-04', '2045-05-01'),
	('2045-05-05', '2045-05-01'),
	('2045-05-06', '2045-05-01'),
	('2045-05-07', '2045-05-01'),
	('2045-05-08', '2045-05-01'),
	('2045-05-09', '2045-05-01'),
	('2045-05-10', '2045-05-01'),
	('2045-05-11', '2045-05-01'),
	('2045-05-12', '2045-05-01'),
	('2045-05-13', '2045-05-01'),
	('2045-05-14', '2045-05-01'),
	('2045-05-15', '2045-05-01'),
	('2045-05-16', '2045-05-01'),
	('2045-05-17', '2045-05-01'),
	('2045-05-18', '2045-05-01'),
	('2045-05-19', '2045-05-01'),
	('2045-05-20', '2045-05-01'),
	('2045-05-21', '2045-05-01'),
	('2045-05-22', '2045-05-01'),
	('2045-05-23', '2045-05-01'),
	('2045-05-24', '2045-05-01'),
	('2045-05-25', '2045-05-01'),
	('2045-05-26', '2045-05-01'),
	('2045-05-27', '2045-05-01'),
	('2045-05-28', '2045-05-01'),
	('2045-05-29', '2045-05-01'),
	('2045-05-30', '2045-05-01'),
	('2045-05-31', '2045-05-01'),
	('2045-06-01', '2045-06-01'),
	('2045-06-02', '2045-06-01'),
	('2045-06-03', '2045-06-01'),
	('2045-06-04', '2045-06-01'),
	('2045-06-05', '2045-06-01'),
	('2045-06-06', '2045-06-01'),
	('2045-06-07', '2045-06-01'),
	('2045-06-08', '2045-06-01'),
	('2045-06-09', '2045-06-01'),
	('2045-06-10', '2045-06-01'),
	('2045-06-11', '2045-06-01'),
	('2045-06-12', '2045-06-01'),
	('2045-06-13', '2045-06-01'),
	('2045-06-14', '2045-06-01'),
	('2045-06-15', '2045-06-01'),
	('2045-06-16', '2045-06-01'),
	('2045-06-17', '2045-06-01'),
	('2045-06-18', '2045-06-01'),
	('2045-06-19', '2045-06-01'),
	('2045-06-20', '2045-06-01'),
	('2045-06-21', '2045-06-01'),
	('2045-06-22', '2045-06-01'),
	('2045-06-23', '2045-06-01'),
	('2045-06-24', '2045-06-01'),
	('2045-06-25', '2045-06-01'),
	('2045-06-26', '2045-06-01'),
	('2045-06-27', '2045-06-01'),
	('2045-06-28', '2045-06-01'),
	('2045-06-29', '2045-06-01'),
	('2045-06-30', '2045-06-01'),
	('2045-07-01', '2045-07-01'),
	('2045-07-02', '2045-07-01'),
	('2045-07-03', '2045-07-01'),
	('2045-07-04', '2045-07-01'),
	('2045-07-05', '2045-07-01'),
	('2045-07-06', '2045-07-01'),
	('2045-07-07', '2045-07-01'),
	('2045-07-08', '2045-07-01'),
	('2045-07-09', '2045-07-01'),
	('2045-07-10', '2045-07-01'),
	('2045-07-11', '2045-07-01'),
	('2045-07-12', '2045-07-01'),
	('2045-07-13', '2045-07-01'),
	('2045-07-14', '2045-07-01'),
	('2045-07-15', '2045-07-01'),
	('2045-07-16', '2045-07-01'),
	('2045-07-17', '2045-07-01'),
	('2045-07-18', '2045-07-01'),
	('2045-07-19', '2045-07-01'),
	('2045-07-20', '2045-07-01'),
	('2045-07-21', '2045-07-01'),
	('2045-07-22', '2045-07-01'),
	('2045-07-23', '2045-07-01'),
	('2045-07-24', '2045-07-01'),
	('2045-07-25', '2045-07-01'),
	('2045-07-26', '2045-07-01'),
	('2045-07-27', '2045-07-01'),
	('2045-07-28', '2045-07-01'),
	('2045-07-29', '2045-07-01'),
	('2045-07-30', '2045-07-01'),
	('2045-07-31', '2045-07-01'),
	('2045-08-01', '2045-08-01'),
	('2045-08-02', '2045-08-01'),
	('2045-08-03', '2045-08-01'),
	('2045-08-04', '2045-08-01'),
	('2045-08-05', '2045-08-01'),
	('2045-08-06', '2045-08-01'),
	('2045-08-07', '2045-08-01'),
	('2045-08-08', '2045-08-01'),
	('2045-08-09', '2045-08-01'),
	('2045-08-10', '2045-08-01'),
	('2045-08-11', '2045-08-01'),
	('2045-08-12', '2045-08-01'),
	('2045-08-13', '2045-08-01'),
	('2045-08-14', '2045-08-01'),
	('2045-08-15', '2045-08-01'),
	('2045-08-16', '2045-08-01'),
	('2045-08-17', '2045-08-01'),
	('2045-08-18', '2045-08-01'),
	('2045-08-19', '2045-08-01'),
	('2045-08-20', '2045-08-01'),
	('2045-08-21', '2045-08-01'),
	('2045-08-22', '2045-08-01'),
	('2045-08-23', '2045-08-01'),
	('2045-08-24', '2045-08-01'),
	('2045-08-25', '2045-08-01'),
	('2045-08-26', '2045-08-01'),
	('2045-08-27', '2045-08-01'),
	('2045-08-28', '2045-08-01'),
	('2045-08-29', '2045-08-01'),
	('2045-08-30', '2045-08-01'),
	('2045-08-31', '2045-08-01'),
	('2045-09-01', '2045-09-01'),
	('2045-09-02', '2045-09-01'),
	('2045-09-03', '2045-09-01'),
	('2045-09-04', '2045-09-01'),
	('2045-09-05', '2045-09-01'),
	('2045-09-06', '2045-09-01'),
	('2045-09-07', '2045-09-01'),
	('2045-09-08', '2045-09-01'),
	('2045-09-09', '2045-09-01'),
	('2045-09-10', '2045-09-01'),
	('2045-09-11', '2045-09-01'),
	('2045-09-12', '2045-09-01'),
	('2045-09-13', '2045-09-01'),
	('2045-09-14', '2045-09-01'),
	('2045-09-15', '2045-09-01'),
	('2045-09-16', '2045-09-01'),
	('2045-09-17', '2045-09-01'),
	('2045-09-18', '2045-09-01'),
	('2045-09-19', '2045-09-01'),
	('2045-09-20', '2045-09-01'),
	('2045-09-21', '2045-09-01'),
	('2045-09-22', '2045-09-01'),
	('2045-09-23', '2045-09-01'),
	('2045-09-24', '2045-09-01'),
	('2045-09-25', '2045-09-01'),
	('2045-09-26', '2045-09-01'),
	('2045-09-27', '2045-09-01'),
	('2045-09-28', '2045-09-01'),
	('2045-09-29', '2045-09-01'),
	('2045-09-30', '2045-09-01'),
	('2045-10-01', '2045-10-01'),
	('2045-10-02', '2045-10-01'),
	('2045-10-03', '2045-10-01'),
	('2045-10-04', '2045-10-01'),
	('2045-10-05', '2045-10-01'),
	('2045-10-06', '2045-10-01'),
	('2045-10-07', '2045-10-01'),
	('2045-10-08', '2045-10-01'),
	('2045-10-09', '2045-10-01'),
	('2045-10-10', '2045-10-01'),
	('2045-10-11', '2045-10-01'),
	('2045-10-12', '2045-10-01'),
	('2045-10-13', '2045-10-01'),
	('2045-10-14', '2045-10-01'),
	('2045-10-15', '2045-10-01'),
	('2045-10-16', '2045-10-01'),
	('2045-10-17', '2045-10-01'),
	('2045-10-18', '2045-10-01'),
	('2045-10-19', '2045-10-01'),
	('2045-10-20', '2045-10-01'),
	('2045-10-21', '2045-10-01'),
	('2045-10-22', '2045-10-01'),
	('2045-10-23', '2045-10-01'),
	('2045-10-24', '2045-10-01'),
	('2045-10-25', '2045-10-01'),
	('2045-10-26', '2045-10-01'),
	('2045-10-27', '2045-10-01'),
	('2045-10-28', '2045-10-01'),
	('2045-10-29', '2045-10-01'),
	('2045-10-30', '2045-10-01'),
	('2045-10-31', '2045-10-01'),
	('2045-11-01', '2045-11-01'),
	('2045-11-02', '2045-11-01'),
	('2045-11-03', '2045-11-01'),
	('2045-11-04', '2045-11-01'),
	('2045-11-05', '2045-11-01'),
	('2045-11-06', '2045-11-01'),
	('2045-11-07', '2045-11-01'),
	('2045-11-08', '2045-11-01'),
	('2045-11-09', '2045-11-01'),
	('2045-11-10', '2045-11-01'),
	('2045-11-11', '2045-11-01'),
	('2045-11-12', '2045-11-01'),
	('2045-11-13', '2045-11-01'),
	('2045-11-14', '2045-11-01'),
	('2045-11-15', '2045-11-01'),
	('2045-11-16', '2045-11-01'),
	('2045-11-17', '2045-11-01'),
	('2045-11-18', '2045-11-01'),
	('2045-11-19', '2045-11-01'),
	('2045-11-20', '2045-11-01'),
	('2045-11-21', '2045-11-01'),
	('2045-11-22', '2045-11-01'),
	('2045-11-23', '2045-11-01'),
	('2045-11-24', '2045-11-01'),
	('2045-11-25', '2045-11-01'),
	('2045-11-26', '2045-11-01'),
	('2045-11-27', '2045-11-01'),
	('2045-11-28', '2045-11-01'),
	('2045-11-29', '2045-11-01'),
	('2045-11-30', '2045-11-01'),
	('2045-12-01', '2045-12-01'),
	('2045-12-02', '2045-12-01'),
	('2045-12-03', '2045-12-01'),
	('2045-12-04', '2045-12-01'),
	('2045-12-05', '2045-12-01'),
	('2045-12-06', '2045-12-01'),
	('2045-12-07', '2045-12-01'),
	('2045-12-08', '2045-12-01'),
	('2045-12-09', '2045-12-01'),
	('2045-12-10', '2045-12-01'),
	('2045-12-11', '2045-12-01'),
	('2045-12-12', '2045-12-01'),
	('2045-12-13', '2045-12-01'),
	('2045-12-14', '2045-12-01'),
	('2045-12-15', '2045-12-01'),
	('2045-12-16', '2045-12-01'),
	('2045-12-17', '2045-12-01'),
	('2045-12-18', '2045-12-01'),
	('2045-12-19', '2045-12-01'),
	('2045-12-20', '2045-12-01'),
	('2045-12-21', '2045-12-01'),
	('2045-12-22', '2045-12-01'),
	('2045-12-23', '2045-12-01'),
	('2045-12-24', '2045-12-01'),
	('2045-12-25', '2045-12-01'),
	('2045-12-26', '2045-12-01'),
	('2045-12-27', '2045-12-01'),
	('2045-12-28', '2045-12-01'),
	('2045-12-29', '2045-12-01'),
	('2045-12-30', '2045-12-01'),
	('2045-12-31', '2045-12-01'),
	('2046-01-01', '2046-01-01'),
	('2046-01-02', '2046-01-01'),
	('2046-01-03', '2046-01-01'),
	('2046-01-04', '2046-01-01'),
	('2046-01-05', '2046-01-01'),
	('2046-01-06', '2046-01-01'),
	('2046-01-07', '2046-01-01'),
	('2046-01-08', '2046-01-01'),
	('2046-01-09', '2046-01-01'),
	('2046-01-10', '2046-01-01'),
	('2046-01-11', '2046-01-01'),
	('2046-01-12', '2046-01-01'),
	('2046-01-13', '2046-01-01'),
	('2046-01-14', '2046-01-01'),
	('2046-01-15', '2046-01-01'),
	('2046-01-16', '2046-01-01'),
	('2046-01-17', '2046-01-01'),
	('2046-01-18', '2046-01-01'),
	('2046-01-19', '2046-01-01'),
	('2046-01-20', '2046-01-01'),
	('2046-01-21', '2046-01-01'),
	('2046-01-22', '2046-01-01'),
	('2046-01-23', '2046-01-01'),
	('2046-01-24', '2046-01-01'),
	('2046-01-25', '2046-01-01'),
	('2046-01-26', '2046-01-01'),
	('2046-01-27', '2046-01-01'),
	('2046-01-28', '2046-01-01'),
	('2046-01-29', '2046-01-01'),
	('2046-01-30', '2046-01-01'),
	('2046-01-31', '2046-01-01'),
	('2046-02-01', '2046-02-01'),
	('2046-02-02', '2046-02-01'),
	('2046-02-03', '2046-02-01'),
	('2046-02-04', '2046-02-01'),
	('2046-02-05', '2046-02-01'),
	('2046-02-06', '2046-02-01'),
	('2046-02-07', '2046-02-01'),
	('2046-02-08', '2046-02-01'),
	('2046-02-09', '2046-02-01'),
	('2046-02-10', '2046-02-01'),
	('2046-02-11', '2046-02-01'),
	('2046-02-12', '2046-02-01'),
	('2046-02-13', '2046-02-01'),
	('2046-02-14', '2046-02-01'),
	('2046-02-15', '2046-02-01'),
	('2046-02-16', '2046-02-01'),
	('2046-02-17', '2046-02-01'),
	('2046-02-18', '2046-02-01'),
	('2046-02-19', '2046-02-01'),
	('2046-02-20', '2046-02-01'),
	('2046-02-21', '2046-02-01'),
	('2046-02-22', '2046-02-01'),
	('2046-02-23', '2046-02-01'),
	('2046-02-24', '2046-02-01'),
	('2046-02-25', '2046-02-01'),
	('2046-02-26', '2046-02-01'),
	('2046-02-27', '2046-02-01'),
	('2046-02-28', '2046-02-01'),
	('2046-03-01', '2046-03-01'),
	('2046-03-02', '2046-03-01'),
	('2046-03-03', '2046-03-01'),
	('2046-03-04', '2046-03-01'),
	('2046-03-05', '2046-03-01'),
	('2046-03-06', '2046-03-01'),
	('2046-03-07', '2046-03-01'),
	('2046-03-08', '2046-03-01'),
	('2046-03-09', '2046-03-01'),
	('2046-03-10', '2046-03-01'),
	('2046-03-11', '2046-03-01'),
	('2046-03-12', '2046-03-01'),
	('2046-03-13', '2046-03-01'),
	('2046-03-14', '2046-03-01'),
	('2046-03-15', '2046-03-01'),
	('2046-03-16', '2046-03-01'),
	('2046-03-17', '2046-03-01'),
	('2046-03-18', '2046-03-01'),
	('2046-03-19', '2046-03-01'),
	('2046-03-20', '2046-03-01'),
	('2046-03-21', '2046-03-01'),
	('2046-03-22', '2046-03-01'),
	('2046-03-23', '2046-03-01'),
	('2046-03-24', '2046-03-01'),
	('2046-03-25', '2046-03-01'),
	('2046-03-26', '2046-03-01'),
	('2046-03-27', '2046-03-01'),
	('2046-03-28', '2046-03-01'),
	('2046-03-29', '2046-03-01'),
	('2046-03-30', '2046-03-01'),
	('2046-03-31', '2046-03-01'),
	('2046-04-01', '2046-04-01'),
	('2046-04-02', '2046-04-01'),
	('2046-04-03', '2046-04-01'),
	('2046-04-04', '2046-04-01'),
	('2046-04-05', '2046-04-01'),
	('2046-04-06', '2046-04-01'),
	('2046-04-07', '2046-04-01'),
	('2046-04-08', '2046-04-01'),
	('2046-04-09', '2046-04-01'),
	('2046-04-10', '2046-04-01'),
	('2046-04-11', '2046-04-01'),
	('2046-04-12', '2046-04-01'),
	('2046-04-13', '2046-04-01'),
	('2046-04-14', '2046-04-01'),
	('2046-04-15', '2046-04-01'),
	('2046-04-16', '2046-04-01'),
	('2046-04-17', '2046-04-01'),
	('2046-04-18', '2046-04-01'),
	('2046-04-19', '2046-04-01'),
	('2046-04-20', '2046-04-01'),
	('2046-04-21', '2046-04-01'),
	('2046-04-22', '2046-04-01'),
	('2046-04-23', '2046-04-01'),
	('2046-04-24', '2046-04-01'),
	('2046-04-25', '2046-04-01'),
	('2046-04-26', '2046-04-01'),
	('2046-04-27', '2046-04-01'),
	('2046-04-28', '2046-04-01'),
	('2046-04-29', '2046-04-01'),
	('2046-04-30', '2046-04-01'),
	('2046-05-01', '2046-05-01'),
	('2046-05-02', '2046-05-01'),
	('2046-05-03', '2046-05-01'),
	('2046-05-04', '2046-05-01'),
	('2046-05-05', '2046-05-01'),
	('2046-05-06', '2046-05-01'),
	('2046-05-07', '2046-05-01'),
	('2046-05-08', '2046-05-01'),
	('2046-05-09', '2046-05-01'),
	('2046-05-10', '2046-05-01'),
	('2046-05-11', '2046-05-01'),
	('2046-05-12', '2046-05-01'),
	('2046-05-13', '2046-05-01'),
	('2046-05-14', '2046-05-01'),
	('2046-05-15', '2046-05-01'),
	('2046-05-16', '2046-05-01'),
	('2046-05-17', '2046-05-01'),
	('2046-05-18', '2046-05-01'),
	('2046-05-19', '2046-05-01'),
	('2046-05-20', '2046-05-01'),
	('2046-05-21', '2046-05-01'),
	('2046-05-22', '2046-05-01'),
	('2046-05-23', '2046-05-01'),
	('2046-05-24', '2046-05-01'),
	('2046-05-25', '2046-05-01'),
	('2046-05-26', '2046-05-01'),
	('2046-05-27', '2046-05-01'),
	('2046-05-28', '2046-05-01'),
	('2046-05-29', '2046-05-01'),
	('2046-05-30', '2046-05-01'),
	('2046-05-31', '2046-05-01'),
	('2046-06-01', '2046-06-01'),
	('2046-06-02', '2046-06-01'),
	('2046-06-03', '2046-06-01'),
	('2046-06-04', '2046-06-01'),
	('2046-06-05', '2046-06-01'),
	('2046-06-06', '2046-06-01'),
	('2046-06-07', '2046-06-01'),
	('2046-06-08', '2046-06-01'),
	('2046-06-09', '2046-06-01'),
	('2046-06-10', '2046-06-01'),
	('2046-06-11', '2046-06-01'),
	('2046-06-12', '2046-06-01'),
	('2046-06-13', '2046-06-01'),
	('2046-06-14', '2046-06-01'),
	('2046-06-15', '2046-06-01'),
	('2046-06-16', '2046-06-01'),
	('2046-06-17', '2046-06-01'),
	('2046-06-18', '2046-06-01'),
	('2046-06-19', '2046-06-01'),
	('2046-06-20', '2046-06-01'),
	('2046-06-21', '2046-06-01'),
	('2046-06-22', '2046-06-01'),
	('2046-06-23', '2046-06-01'),
	('2046-06-24', '2046-06-01'),
	('2046-06-25', '2046-06-01'),
	('2046-06-26', '2046-06-01'),
	('2046-06-27', '2046-06-01'),
	('2046-06-28', '2046-06-01'),
	('2046-06-29', '2046-06-01'),
	('2046-06-30', '2046-06-01'),
	('2046-07-01', '2046-07-01'),
	('2046-07-02', '2046-07-01'),
	('2046-07-03', '2046-07-01'),
	('2046-07-04', '2046-07-01'),
	('2046-07-05', '2046-07-01'),
	('2046-07-06', '2046-07-01'),
	('2046-07-07', '2046-07-01'),
	('2046-07-08', '2046-07-01'),
	('2046-07-09', '2046-07-01'),
	('2046-07-10', '2046-07-01'),
	('2046-07-11', '2046-07-01'),
	('2046-07-12', '2046-07-01'),
	('2046-07-13', '2046-07-01'),
	('2046-07-14', '2046-07-01'),
	('2046-07-15', '2046-07-01'),
	('2046-07-16', '2046-07-01'),
	('2046-07-17', '2046-07-01'),
	('2046-07-18', '2046-07-01'),
	('2046-07-19', '2046-07-01'),
	('2046-07-20', '2046-07-01'),
	('2046-07-21', '2046-07-01'),
	('2046-07-22', '2046-07-01'),
	('2046-07-23', '2046-07-01'),
	('2046-07-24', '2046-07-01'),
	('2046-07-25', '2046-07-01'),
	('2046-07-26', '2046-07-01'),
	('2046-07-27', '2046-07-01'),
	('2046-07-28', '2046-07-01'),
	('2046-07-29', '2046-07-01'),
	('2046-07-30', '2046-07-01'),
	('2046-07-31', '2046-07-01'),
	('2046-08-01', '2046-08-01'),
	('2046-08-02', '2046-08-01'),
	('2046-08-03', '2046-08-01'),
	('2046-08-04', '2046-08-01'),
	('2046-08-05', '2046-08-01'),
	('2046-08-06', '2046-08-01'),
	('2046-08-07', '2046-08-01'),
	('2046-08-08', '2046-08-01'),
	('2046-08-09', '2046-08-01'),
	('2046-08-10', '2046-08-01'),
	('2046-08-11', '2046-08-01'),
	('2046-08-12', '2046-08-01'),
	('2046-08-13', '2046-08-01'),
	('2046-08-14', '2046-08-01'),
	('2046-08-15', '2046-08-01'),
	('2046-08-16', '2046-08-01'),
	('2046-08-17', '2046-08-01'),
	('2046-08-18', '2046-08-01'),
	('2046-08-19', '2046-08-01'),
	('2046-08-20', '2046-08-01'),
	('2046-08-21', '2046-08-01'),
	('2046-08-22', '2046-08-01'),
	('2046-08-23', '2046-08-01'),
	('2046-08-24', '2046-08-01'),
	('2046-08-25', '2046-08-01'),
	('2046-08-26', '2046-08-01'),
	('2046-08-27', '2046-08-01'),
	('2046-08-28', '2046-08-01'),
	('2046-08-29', '2046-08-01'),
	('2046-08-30', '2046-08-01'),
	('2046-08-31', '2046-08-01'),
	('2046-09-01', '2046-09-01'),
	('2046-09-02', '2046-09-01'),
	('2046-09-03', '2046-09-01'),
	('2046-09-04', '2046-09-01'),
	('2046-09-05', '2046-09-01'),
	('2046-09-06', '2046-09-01'),
	('2046-09-07', '2046-09-01'),
	('2046-09-08', '2046-09-01'),
	('2046-09-09', '2046-09-01'),
	('2046-09-10', '2046-09-01'),
	('2046-09-11', '2046-09-01'),
	('2046-09-12', '2046-09-01'),
	('2046-09-13', '2046-09-01'),
	('2046-09-14', '2046-09-01'),
	('2046-09-15', '2046-09-01'),
	('2046-09-16', '2046-09-01'),
	('2046-09-17', '2046-09-01'),
	('2046-09-18', '2046-09-01'),
	('2046-09-19', '2046-09-01'),
	('2046-09-20', '2046-09-01'),
	('2046-09-21', '2046-09-01'),
	('2046-09-22', '2046-09-01'),
	('2046-09-23', '2046-09-01'),
	('2046-09-24', '2046-09-01'),
	('2046-09-25', '2046-09-01'),
	('2046-09-26', '2046-09-01'),
	('2046-09-27', '2046-09-01'),
	('2046-09-28', '2046-09-01'),
	('2046-09-29', '2046-09-01'),
	('2046-09-30', '2046-09-01'),
	('2046-10-01', '2046-10-01'),
	('2046-10-02', '2046-10-01'),
	('2046-10-03', '2046-10-01'),
	('2046-10-04', '2046-10-01'),
	('2046-10-05', '2046-10-01'),
	('2046-10-06', '2046-10-01'),
	('2046-10-07', '2046-10-01'),
	('2046-10-08', '2046-10-01'),
	('2046-10-09', '2046-10-01'),
	('2046-10-10', '2046-10-01'),
	('2046-10-11', '2046-10-01'),
	('2046-10-12', '2046-10-01'),
	('2046-10-13', '2046-10-01'),
	('2046-10-14', '2046-10-01'),
	('2046-10-15', '2046-10-01'),
	('2046-10-16', '2046-10-01'),
	('2046-10-17', '2046-10-01'),
	('2046-10-18', '2046-10-01'),
	('2046-10-19', '2046-10-01'),
	('2046-10-20', '2046-10-01'),
	('2046-10-21', '2046-10-01'),
	('2046-10-22', '2046-10-01'),
	('2046-10-23', '2046-10-01'),
	('2046-10-24', '2046-10-01'),
	('2046-10-25', '2046-10-01'),
	('2046-10-26', '2046-10-01'),
	('2046-10-27', '2046-10-01'),
	('2046-10-28', '2046-10-01'),
	('2046-10-29', '2046-10-01'),
	('2046-10-30', '2046-10-01'),
	('2046-10-31', '2046-10-01'),
	('2046-11-01', '2046-11-01'),
	('2046-11-02', '2046-11-01'),
	('2046-11-03', '2046-11-01'),
	('2046-11-04', '2046-11-01'),
	('2046-11-05', '2046-11-01'),
	('2046-11-06', '2046-11-01'),
	('2046-11-07', '2046-11-01'),
	('2046-11-08', '2046-11-01'),
	('2046-11-09', '2046-11-01'),
	('2046-11-10', '2046-11-01'),
	('2046-11-11', '2046-11-01'),
	('2046-11-12', '2046-11-01'),
	('2046-11-13', '2046-11-01'),
	('2046-11-14', '2046-11-01'),
	('2046-11-15', '2046-11-01'),
	('2046-11-16', '2046-11-01'),
	('2046-11-17', '2046-11-01'),
	('2046-11-18', '2046-11-01'),
	('2046-11-19', '2046-11-01'),
	('2046-11-20', '2046-11-01'),
	('2046-11-21', '2046-11-01'),
	('2046-11-22', '2046-11-01'),
	('2046-11-23', '2046-11-01'),
	('2046-11-24', '2046-11-01'),
	('2046-11-25', '2046-11-01'),
	('2046-11-26', '2046-11-01'),
	('2046-11-27', '2046-11-01'),
	('2046-11-28', '2046-11-01'),
	('2046-11-29', '2046-11-01'),
	('2046-11-30', '2046-11-01'),
	('2046-12-01', '2046-12-01'),
	('2046-12-02', '2046-12-01'),
	('2046-12-03', '2046-12-01'),
	('2046-12-04', '2046-12-01'),
	('2046-12-05', '2046-12-01'),
	('2046-12-06', '2046-12-01'),
	('2046-12-07', '2046-12-01'),
	('2046-12-08', '2046-12-01'),
	('2046-12-09', '2046-12-01'),
	('2046-12-10', '2046-12-01'),
	('2046-12-11', '2046-12-01'),
	('2046-12-12', '2046-12-01'),
	('2046-12-13', '2046-12-01'),
	('2046-12-14', '2046-12-01'),
	('2046-12-15', '2046-12-01'),
	('2046-12-16', '2046-12-01'),
	('2046-12-17', '2046-12-01'),
	('2046-12-18', '2046-12-01'),
	('2046-12-19', '2046-12-01'),
	('2046-12-20', '2046-12-01'),
	('2046-12-21', '2046-12-01'),
	('2046-12-22', '2046-12-01'),
	('2046-12-23', '2046-12-01'),
	('2046-12-24', '2046-12-01'),
	('2046-12-25', '2046-12-01'),
	('2046-12-26', '2046-12-01'),
	('2046-12-27', '2046-12-01'),
	('2046-12-28', '2046-12-01'),
	('2046-12-29', '2046-12-01'),
	('2046-12-30', '2046-12-01'),
	('2046-12-31', '2046-12-01'),
	('2047-01-01', '2047-01-01'),
	('2047-01-02', '2047-01-01'),
	('2047-01-03', '2047-01-01'),
	('2047-01-04', '2047-01-01'),
	('2047-01-05', '2047-01-01'),
	('2047-01-06', '2047-01-01'),
	('2047-01-07', '2047-01-01'),
	('2047-01-08', '2047-01-01'),
	('2047-01-09', '2047-01-01'),
	('2047-01-10', '2047-01-01'),
	('2047-01-11', '2047-01-01'),
	('2047-01-12', '2047-01-01'),
	('2047-01-13', '2047-01-01'),
	('2047-01-14', '2047-01-01'),
	('2047-01-15', '2047-01-01'),
	('2047-01-16', '2047-01-01'),
	('2047-01-17', '2047-01-01'),
	('2047-01-18', '2047-01-01'),
	('2047-01-19', '2047-01-01'),
	('2047-01-20', '2047-01-01'),
	('2047-01-21', '2047-01-01'),
	('2047-01-22', '2047-01-01'),
	('2047-01-23', '2047-01-01'),
	('2047-01-24', '2047-01-01'),
	('2047-01-25', '2047-01-01'),
	('2047-01-26', '2047-01-01'),
	('2047-01-27', '2047-01-01'),
	('2047-01-28', '2047-01-01'),
	('2047-01-29', '2047-01-01'),
	('2047-01-30', '2047-01-01'),
	('2047-01-31', '2047-01-01'),
	('2047-02-01', '2047-02-01'),
	('2047-02-02', '2047-02-01'),
	('2047-02-03', '2047-02-01'),
	('2047-02-04', '2047-02-01'),
	('2047-02-05', '2047-02-01'),
	('2047-02-06', '2047-02-01'),
	('2047-02-07', '2047-02-01'),
	('2047-02-08', '2047-02-01'),
	('2047-02-09', '2047-02-01'),
	('2047-02-10', '2047-02-01'),
	('2047-02-11', '2047-02-01'),
	('2047-02-12', '2047-02-01'),
	('2047-02-13', '2047-02-01'),
	('2047-02-14', '2047-02-01'),
	('2047-02-15', '2047-02-01'),
	('2047-02-16', '2047-02-01'),
	('2047-02-17', '2047-02-01'),
	('2047-02-18', '2047-02-01'),
	('2047-02-19', '2047-02-01'),
	('2047-02-20', '2047-02-01'),
	('2047-02-21', '2047-02-01'),
	('2047-02-22', '2047-02-01'),
	('2047-02-23', '2047-02-01'),
	('2047-02-24', '2047-02-01'),
	('2047-02-25', '2047-02-01'),
	('2047-02-26', '2047-02-01'),
	('2047-02-27', '2047-02-01'),
	('2047-02-28', '2047-02-01'),
	('2047-03-01', '2047-03-01'),
	('2047-03-02', '2047-03-01'),
	('2047-03-03', '2047-03-01'),
	('2047-03-04', '2047-03-01'),
	('2047-03-05', '2047-03-01'),
	('2047-03-06', '2047-03-01'),
	('2047-03-07', '2047-03-01'),
	('2047-03-08', '2047-03-01'),
	('2047-03-09', '2047-03-01'),
	('2047-03-10', '2047-03-01'),
	('2047-03-11', '2047-03-01'),
	('2047-03-12', '2047-03-01'),
	('2047-03-13', '2047-03-01'),
	('2047-03-14', '2047-03-01'),
	('2047-03-15', '2047-03-01'),
	('2047-03-16', '2047-03-01'),
	('2047-03-17', '2047-03-01'),
	('2047-03-18', '2047-03-01'),
	('2047-03-19', '2047-03-01'),
	('2047-03-20', '2047-03-01'),
	('2047-03-21', '2047-03-01'),
	('2047-03-22', '2047-03-01'),
	('2047-03-23', '2047-03-01'),
	('2047-03-24', '2047-03-01'),
	('2047-03-25', '2047-03-01'),
	('2047-03-26', '2047-03-01'),
	('2047-03-27', '2047-03-01'),
	('2047-03-28', '2047-03-01'),
	('2047-03-29', '2047-03-01'),
	('2047-03-30', '2047-03-01'),
	('2047-03-31', '2047-03-01'),
	('2047-04-01', '2047-04-01'),
	('2047-04-02', '2047-04-01'),
	('2047-04-03', '2047-04-01'),
	('2047-04-04', '2047-04-01'),
	('2047-04-05', '2047-04-01'),
	('2047-04-06', '2047-04-01'),
	('2047-04-07', '2047-04-01'),
	('2047-04-08', '2047-04-01'),
	('2047-04-09', '2047-04-01'),
	('2047-04-10', '2047-04-01'),
	('2047-04-11', '2047-04-01'),
	('2047-04-12', '2047-04-01'),
	('2047-04-13', '2047-04-01'),
	('2047-04-14', '2047-04-01'),
	('2047-04-15', '2047-04-01'),
	('2047-04-16', '2047-04-01'),
	('2047-04-17', '2047-04-01'),
	('2047-04-18', '2047-04-01'),
	('2047-04-19', '2047-04-01'),
	('2047-04-20', '2047-04-01'),
	('2047-04-21', '2047-04-01'),
	('2047-04-22', '2047-04-01'),
	('2047-04-23', '2047-04-01'),
	('2047-04-24', '2047-04-01'),
	('2047-04-25', '2047-04-01'),
	('2047-04-26', '2047-04-01'),
	('2047-04-27', '2047-04-01'),
	('2047-04-28', '2047-04-01'),
	('2047-04-29', '2047-04-01'),
	('2047-04-30', '2047-04-01'),
	('2047-05-01', '2047-05-01'),
	('2047-05-02', '2047-05-01'),
	('2047-05-03', '2047-05-01'),
	('2047-05-04', '2047-05-01'),
	('2047-05-05', '2047-05-01'),
	('2047-05-06', '2047-05-01'),
	('2047-05-07', '2047-05-01'),
	('2047-05-08', '2047-05-01'),
	('2047-05-09', '2047-05-01'),
	('2047-05-10', '2047-05-01'),
	('2047-05-11', '2047-05-01'),
	('2047-05-12', '2047-05-01'),
	('2047-05-13', '2047-05-01'),
	('2047-05-14', '2047-05-01'),
	('2047-05-15', '2047-05-01'),
	('2047-05-16', '2047-05-01'),
	('2047-05-17', '2047-05-01'),
	('2047-05-18', '2047-05-01'),
	('2047-05-19', '2047-05-01'),
	('2047-05-20', '2047-05-01'),
	('2047-05-21', '2047-05-01'),
	('2047-05-22', '2047-05-01'),
	('2047-05-23', '2047-05-01'),
	('2047-05-24', '2047-05-01'),
	('2047-05-25', '2047-05-01'),
	('2047-05-26', '2047-05-01'),
	('2047-05-27', '2047-05-01'),
	('2047-05-28', '2047-05-01'),
	('2047-05-29', '2047-05-01'),
	('2047-05-30', '2047-05-01'),
	('2047-05-31', '2047-05-01'),
	('2047-06-01', '2047-06-01'),
	('2047-06-02', '2047-06-01'),
	('2047-06-03', '2047-06-01'),
	('2047-06-04', '2047-06-01'),
	('2047-06-05', '2047-06-01'),
	('2047-06-06', '2047-06-01'),
	('2047-06-07', '2047-06-01'),
	('2047-06-08', '2047-06-01'),
	('2047-06-09', '2047-06-01'),
	('2047-06-10', '2047-06-01'),
	('2047-06-11', '2047-06-01'),
	('2047-06-12', '2047-06-01'),
	('2047-06-13', '2047-06-01'),
	('2047-06-14', '2047-06-01'),
	('2047-06-15', '2047-06-01'),
	('2047-06-16', '2047-06-01'),
	('2047-06-17', '2047-06-01'),
	('2047-06-18', '2047-06-01'),
	('2047-06-19', '2047-06-01'),
	('2047-06-20', '2047-06-01'),
	('2047-06-21', '2047-06-01'),
	('2047-06-22', '2047-06-01'),
	('2047-06-23', '2047-06-01'),
	('2047-06-24', '2047-06-01'),
	('2047-06-25', '2047-06-01'),
	('2047-06-26', '2047-06-01'),
	('2047-06-27', '2047-06-01'),
	('2047-06-28', '2047-06-01'),
	('2047-06-29', '2047-06-01'),
	('2047-06-30', '2047-06-01'),
	('2047-07-01', '2047-07-01'),
	('2047-07-02', '2047-07-01'),
	('2047-07-03', '2047-07-01'),
	('2047-07-04', '2047-07-01'),
	('2047-07-05', '2047-07-01'),
	('2047-07-06', '2047-07-01'),
	('2047-07-07', '2047-07-01'),
	('2047-07-08', '2047-07-01'),
	('2047-07-09', '2047-07-01'),
	('2047-07-10', '2047-07-01'),
	('2047-07-11', '2047-07-01'),
	('2047-07-12', '2047-07-01'),
	('2047-07-13', '2047-07-01'),
	('2047-07-14', '2047-07-01'),
	('2047-07-15', '2047-07-01'),
	('2047-07-16', '2047-07-01'),
	('2047-07-17', '2047-07-01'),
	('2047-07-18', '2047-07-01'),
	('2047-07-19', '2047-07-01'),
	('2047-07-20', '2047-07-01'),
	('2047-07-21', '2047-07-01'),
	('2047-07-22', '2047-07-01'),
	('2047-07-23', '2047-07-01'),
	('2047-07-24', '2047-07-01'),
	('2047-07-25', '2047-07-01'),
	('2047-07-26', '2047-07-01'),
	('2047-07-27', '2047-07-01'),
	('2047-07-28', '2047-07-01'),
	('2047-07-29', '2047-07-01'),
	('2047-07-30', '2047-07-01'),
	('2047-07-31', '2047-07-01'),
	('2047-08-01', '2047-08-01'),
	('2047-08-02', '2047-08-01'),
	('2047-08-03', '2047-08-01'),
	('2047-08-04', '2047-08-01'),
	('2047-08-05', '2047-08-01'),
	('2047-08-06', '2047-08-01'),
	('2047-08-07', '2047-08-01'),
	('2047-08-08', '2047-08-01'),
	('2047-08-09', '2047-08-01'),
	('2047-08-10', '2047-08-01'),
	('2047-08-11', '2047-08-01'),
	('2047-08-12', '2047-08-01'),
	('2047-08-13', '2047-08-01'),
	('2047-08-14', '2047-08-01'),
	('2047-08-15', '2047-08-01'),
	('2047-08-16', '2047-08-01'),
	('2047-08-17', '2047-08-01'),
	('2047-08-18', '2047-08-01'),
	('2047-08-19', '2047-08-01'),
	('2047-08-20', '2047-08-01'),
	('2047-08-21', '2047-08-01'),
	('2047-08-22', '2047-08-01'),
	('2047-08-23', '2047-08-01'),
	('2047-08-24', '2047-08-01'),
	('2047-08-25', '2047-08-01'),
	('2047-08-26', '2047-08-01'),
	('2047-08-27', '2047-08-01'),
	('2047-08-28', '2047-08-01'),
	('2047-08-29', '2047-08-01'),
	('2047-08-30', '2047-08-01'),
	('2047-08-31', '2047-08-01'),
	('2047-09-01', '2047-09-01'),
	('2047-09-02', '2047-09-01'),
	('2047-09-03', '2047-09-01'),
	('2047-09-04', '2047-09-01'),
	('2047-09-05', '2047-09-01'),
	('2047-09-06', '2047-09-01'),
	('2047-09-07', '2047-09-01'),
	('2047-09-08', '2047-09-01'),
	('2047-09-09', '2047-09-01'),
	('2047-09-10', '2047-09-01'),
	('2047-09-11', '2047-09-01'),
	('2047-09-12', '2047-09-01'),
	('2047-09-13', '2047-09-01'),
	('2047-09-14', '2047-09-01'),
	('2047-09-15', '2047-09-01'),
	('2047-09-16', '2047-09-01'),
	('2047-09-17', '2047-09-01'),
	('2047-09-18', '2047-09-01'),
	('2047-09-19', '2047-09-01'),
	('2047-09-20', '2047-09-01'),
	('2047-09-21', '2047-09-01'),
	('2047-09-22', '2047-09-01'),
	('2047-09-23', '2047-09-01'),
	('2047-09-24', '2047-09-01'),
	('2047-09-25', '2047-09-01'),
	('2047-09-26', '2047-09-01'),
	('2047-09-27', '2047-09-01'),
	('2047-09-28', '2047-09-01'),
	('2047-09-29', '2047-09-01'),
	('2047-09-30', '2047-09-01'),
	('2047-10-01', '2047-10-01'),
	('2047-10-02', '2047-10-01'),
	('2047-10-03', '2047-10-01'),
	('2047-10-04', '2047-10-01'),
	('2047-10-05', '2047-10-01'),
	('2047-10-06', '2047-10-01'),
	('2047-10-07', '2047-10-01'),
	('2047-10-08', '2047-10-01'),
	('2047-10-09', '2047-10-01'),
	('2047-10-10', '2047-10-01'),
	('2047-10-11', '2047-10-01'),
	('2047-10-12', '2047-10-01'),
	('2047-10-13', '2047-10-01'),
	('2047-10-14', '2047-10-01'),
	('2047-10-15', '2047-10-01'),
	('2047-10-16', '2047-10-01'),
	('2047-10-17', '2047-10-01'),
	('2047-10-18', '2047-10-01'),
	('2047-10-19', '2047-10-01'),
	('2047-10-20', '2047-10-01'),
	('2047-10-21', '2047-10-01'),
	('2047-10-22', '2047-10-01'),
	('2047-10-23', '2047-10-01'),
	('2047-10-24', '2047-10-01'),
	('2047-10-25', '2047-10-01'),
	('2047-10-26', '2047-10-01'),
	('2047-10-27', '2047-10-01'),
	('2047-10-28', '2047-10-01'),
	('2047-10-29', '2047-10-01'),
	('2047-10-30', '2047-10-01'),
	('2047-10-31', '2047-10-01'),
	('2047-11-01', '2047-11-01'),
	('2047-11-02', '2047-11-01'),
	('2047-11-03', '2047-11-01'),
	('2047-11-04', '2047-11-01'),
	('2047-11-05', '2047-11-01'),
	('2047-11-06', '2047-11-01'),
	('2047-11-07', '2047-11-01'),
	('2047-11-08', '2047-11-01'),
	('2047-11-09', '2047-11-01'),
	('2047-11-10', '2047-11-01'),
	('2047-11-11', '2047-11-01'),
	('2047-11-12', '2047-11-01'),
	('2047-11-13', '2047-11-01'),
	('2047-11-14', '2047-11-01'),
	('2047-11-15', '2047-11-01'),
	('2047-11-16', '2047-11-01'),
	('2047-11-17', '2047-11-01'),
	('2047-11-18', '2047-11-01'),
	('2047-11-19', '2047-11-01'),
	('2047-11-20', '2047-11-01'),
	('2047-11-21', '2047-11-01'),
	('2047-11-22', '2047-11-01'),
	('2047-11-23', '2047-11-01'),
	('2047-11-24', '2047-11-01'),
	('2047-11-25', '2047-11-01'),
	('2047-11-26', '2047-11-01'),
	('2047-11-27', '2047-11-01'),
	('2047-11-28', '2047-11-01'),
	('2047-11-29', '2047-11-01'),
	('2047-11-30', '2047-11-01'),
	('2047-12-01', '2047-12-01'),
	('2047-12-02', '2047-12-01'),
	('2047-12-03', '2047-12-01'),
	('2047-12-04', '2047-12-01'),
	('2047-12-05', '2047-12-01'),
	('2047-12-06', '2047-12-01'),
	('2047-12-07', '2047-12-01'),
	('2047-12-08', '2047-12-01'),
	('2047-12-09', '2047-12-01'),
	('2047-12-10', '2047-12-01'),
	('2047-12-11', '2047-12-01'),
	('2047-12-12', '2047-12-01'),
	('2047-12-13', '2047-12-01'),
	('2047-12-14', '2047-12-01'),
	('2047-12-15', '2047-12-01'),
	('2047-12-16', '2047-12-01'),
	('2047-12-17', '2047-12-01'),
	('2047-12-18', '2047-12-01'),
	('2047-12-19', '2047-12-01'),
	('2047-12-20', '2047-12-01'),
	('2047-12-21', '2047-12-01'),
	('2047-12-22', '2047-12-01'),
	('2047-12-23', '2047-12-01'),
	('2047-12-24', '2047-12-01'),
	('2047-12-25', '2047-12-01'),
	('2047-12-26', '2047-12-01'),
	('2047-12-27', '2047-12-01'),
	('2047-12-28', '2047-12-01'),
	('2047-12-29', '2047-12-01'),
	('2047-12-30', '2047-12-01'),
	('2047-12-31', '2047-12-01'),
	('2048-01-01', '2048-01-01'),
	('2048-01-02', '2048-01-01'),
	('2048-01-03', '2048-01-01'),
	('2048-01-04', '2048-01-01'),
	('2048-01-05', '2048-01-01'),
	('2048-01-06', '2048-01-01'),
	('2048-01-07', '2048-01-01'),
	('2048-01-08', '2048-01-01'),
	('2048-01-09', '2048-01-01'),
	('2048-01-10', '2048-01-01'),
	('2048-01-11', '2048-01-01'),
	('2048-01-12', '2048-01-01'),
	('2048-01-13', '2048-01-01'),
	('2048-01-14', '2048-01-01'),
	('2048-01-15', '2048-01-01'),
	('2048-01-16', '2048-01-01'),
	('2048-01-17', '2048-01-01'),
	('2048-01-18', '2048-01-01'),
	('2048-01-19', '2048-01-01'),
	('2048-01-20', '2048-01-01'),
	('2048-01-21', '2048-01-01'),
	('2048-01-22', '2048-01-01'),
	('2048-01-23', '2048-01-01'),
	('2048-01-24', '2048-01-01'),
	('2048-01-25', '2048-01-01'),
	('2048-01-26', '2048-01-01'),
	('2048-01-27', '2048-01-01'),
	('2048-01-28', '2048-01-01'),
	('2048-01-29', '2048-01-01'),
	('2048-01-30', '2048-01-01'),
	('2048-01-31', '2048-01-01'),
	('2048-02-01', '2048-02-01'),
	('2048-02-02', '2048-02-01'),
	('2048-02-03', '2048-02-01'),
	('2048-02-04', '2048-02-01'),
	('2048-02-05', '2048-02-01'),
	('2048-02-06', '2048-02-01'),
	('2048-02-07', '2048-02-01'),
	('2048-02-08', '2048-02-01'),
	('2048-02-09', '2048-02-01'),
	('2048-02-10', '2048-02-01'),
	('2048-02-11', '2048-02-01'),
	('2048-02-12', '2048-02-01'),
	('2048-02-13', '2048-02-01'),
	('2048-02-14', '2048-02-01'),
	('2048-02-15', '2048-02-01'),
	('2048-02-16', '2048-02-01'),
	('2048-02-17', '2048-02-01'),
	('2048-02-18', '2048-02-01'),
	('2048-02-19', '2048-02-01'),
	('2048-02-20', '2048-02-01'),
	('2048-02-21', '2048-02-01'),
	('2048-02-22', '2048-02-01'),
	('2048-02-23', '2048-02-01'),
	('2048-02-24', '2048-02-01'),
	('2048-02-25', '2048-02-01'),
	('2048-02-26', '2048-02-01'),
	('2048-02-27', '2048-02-01'),
	('2048-02-28', '2048-02-01'),
	('2048-02-29', '2048-02-01'),
	('2048-03-01', '2048-03-01'),
	('2048-03-02', '2048-03-01'),
	('2048-03-03', '2048-03-01'),
	('2048-03-04', '2048-03-01'),
	('2048-03-05', '2048-03-01'),
	('2048-03-06', '2048-03-01'),
	('2048-03-07', '2048-03-01'),
	('2048-03-08', '2048-03-01'),
	('2048-03-09', '2048-03-01'),
	('2048-03-10', '2048-03-01'),
	('2048-03-11', '2048-03-01'),
	('2048-03-12', '2048-03-01'),
	('2048-03-13', '2048-03-01'),
	('2048-03-14', '2048-03-01'),
	('2048-03-15', '2048-03-01'),
	('2048-03-16', '2048-03-01'),
	('2048-03-17', '2048-03-01'),
	('2048-03-18', '2048-03-01'),
	('2048-03-19', '2048-03-01'),
	('2048-03-20', '2048-03-01'),
	('2048-03-21', '2048-03-01'),
	('2048-03-22', '2048-03-01'),
	('2048-03-23', '2048-03-01'),
	('2048-03-24', '2048-03-01'),
	('2048-03-25', '2048-03-01'),
	('2048-03-26', '2048-03-01'),
	('2048-03-27', '2048-03-01'),
	('2048-03-28', '2048-03-01'),
	('2048-03-29', '2048-03-01'),
	('2048-03-30', '2048-03-01'),
	('2048-03-31', '2048-03-01'),
	('2048-04-01', '2048-04-01'),
	('2048-04-02', '2048-04-01'),
	('2048-04-03', '2048-04-01'),
	('2048-04-04', '2048-04-01'),
	('2048-04-05', '2048-04-01'),
	('2048-04-06', '2048-04-01'),
	('2048-04-07', '2048-04-01'),
	('2048-04-08', '2048-04-01'),
	('2048-04-09', '2048-04-01'),
	('2048-04-10', '2048-04-01'),
	('2048-04-11', '2048-04-01'),
	('2048-04-12', '2048-04-01'),
	('2048-04-13', '2048-04-01'),
	('2048-04-14', '2048-04-01'),
	('2048-04-15', '2048-04-01'),
	('2048-04-16', '2048-04-01'),
	('2048-04-17', '2048-04-01'),
	('2048-04-18', '2048-04-01'),
	('2048-04-19', '2048-04-01'),
	('2048-04-20', '2048-04-01'),
	('2048-04-21', '2048-04-01'),
	('2048-04-22', '2048-04-01'),
	('2048-04-23', '2048-04-01'),
	('2048-04-24', '2048-04-01'),
	('2048-04-25', '2048-04-01'),
	('2048-04-26', '2048-04-01'),
	('2048-04-27', '2048-04-01'),
	('2048-04-28', '2048-04-01'),
	('2048-04-29', '2048-04-01'),
	('2048-04-30', '2048-04-01'),
	('2048-05-01', '2048-05-01'),
	('2048-05-02', '2048-05-01'),
	('2048-05-03', '2048-05-01'),
	('2048-05-04', '2048-05-01'),
	('2048-05-05', '2048-05-01'),
	('2048-05-06', '2048-05-01'),
	('2048-05-07', '2048-05-01'),
	('2048-05-08', '2048-05-01'),
	('2048-05-09', '2048-05-01'),
	('2048-05-10', '2048-05-01'),
	('2048-05-11', '2048-05-01'),
	('2048-05-12', '2048-05-01'),
	('2048-05-13', '2048-05-01'),
	('2048-05-14', '2048-05-01'),
	('2048-05-15', '2048-05-01'),
	('2048-05-16', '2048-05-01'),
	('2048-05-17', '2048-05-01'),
	('2048-05-18', '2048-05-01'),
	('2048-05-19', '2048-05-01'),
	('2048-05-20', '2048-05-01'),
	('2048-05-21', '2048-05-01'),
	('2048-05-22', '2048-05-01'),
	('2048-05-23', '2048-05-01'),
	('2048-05-24', '2048-05-01'),
	('2048-05-25', '2048-05-01'),
	('2048-05-26', '2048-05-01'),
	('2048-05-27', '2048-05-01'),
	('2048-05-28', '2048-05-01'),
	('2048-05-29', '2048-05-01'),
	('2048-05-30', '2048-05-01'),
	('2048-05-31', '2048-05-01'),
	('2048-06-01', '2048-06-01'),
	('2048-06-02', '2048-06-01'),
	('2048-06-03', '2048-06-01'),
	('2048-06-04', '2048-06-01'),
	('2048-06-05', '2048-06-01'),
	('2048-06-06', '2048-06-01'),
	('2048-06-07', '2048-06-01'),
	('2048-06-08', '2048-06-01'),
	('2048-06-09', '2048-06-01'),
	('2048-06-10', '2048-06-01'),
	('2048-06-11', '2048-06-01'),
	('2048-06-12', '2048-06-01'),
	('2048-06-13', '2048-06-01'),
	('2048-06-14', '2048-06-01'),
	('2048-06-15', '2048-06-01'),
	('2048-06-16', '2048-06-01'),
	('2048-06-17', '2048-06-01'),
	('2048-06-18', '2048-06-01'),
	('2048-06-19', '2048-06-01'),
	('2048-06-20', '2048-06-01'),
	('2048-06-21', '2048-06-01'),
	('2048-06-22', '2048-06-01'),
	('2048-06-23', '2048-06-01'),
	('2048-06-24', '2048-06-01'),
	('2048-06-25', '2048-06-01'),
	('2048-06-26', '2048-06-01'),
	('2048-06-27', '2048-06-01'),
	('2048-06-28', '2048-06-01'),
	('2048-06-29', '2048-06-01'),
	('2048-06-30', '2048-06-01'),
	('2048-07-01', '2048-07-01'),
	('2048-07-02', '2048-07-01'),
	('2048-07-03', '2048-07-01'),
	('2048-07-04', '2048-07-01'),
	('2048-07-05', '2048-07-01'),
	('2048-07-06', '2048-07-01'),
	('2048-07-07', '2048-07-01'),
	('2048-07-08', '2048-07-01'),
	('2048-07-09', '2048-07-01'),
	('2048-07-10', '2048-07-01'),
	('2048-07-11', '2048-07-01'),
	('2048-07-12', '2048-07-01'),
	('2048-07-13', '2048-07-01'),
	('2048-07-14', '2048-07-01'),
	('2048-07-15', '2048-07-01'),
	('2048-07-16', '2048-07-01'),
	('2048-07-17', '2048-07-01'),
	('2048-07-18', '2048-07-01'),
	('2048-07-19', '2048-07-01'),
	('2048-07-20', '2048-07-01'),
	('2048-07-21', '2048-07-01'),
	('2048-07-22', '2048-07-01'),
	('2048-07-23', '2048-07-01'),
	('2048-07-24', '2048-07-01'),
	('2048-07-25', '2048-07-01'),
	('2048-07-26', '2048-07-01'),
	('2048-07-27', '2048-07-01'),
	('2048-07-28', '2048-07-01'),
	('2048-07-29', '2048-07-01'),
	('2048-07-30', '2048-07-01'),
	('2048-07-31', '2048-07-01'),
	('2048-08-01', '2048-08-01'),
	('2048-08-02', '2048-08-01'),
	('2048-08-03', '2048-08-01'),
	('2048-08-04', '2048-08-01'),
	('2048-08-05', '2048-08-01'),
	('2048-08-06', '2048-08-01'),
	('2048-08-07', '2048-08-01'),
	('2048-08-08', '2048-08-01'),
	('2048-08-09', '2048-08-01'),
	('2048-08-10', '2048-08-01'),
	('2048-08-11', '2048-08-01'),
	('2048-08-12', '2048-08-01'),
	('2048-08-13', '2048-08-01'),
	('2048-08-14', '2048-08-01'),
	('2048-08-15', '2048-08-01'),
	('2048-08-16', '2048-08-01'),
	('2048-08-17', '2048-08-01'),
	('2048-08-18', '2048-08-01'),
	('2048-08-19', '2048-08-01'),
	('2048-08-20', '2048-08-01'),
	('2048-08-21', '2048-08-01'),
	('2048-08-22', '2048-08-01'),
	('2048-08-23', '2048-08-01'),
	('2048-08-24', '2048-08-01'),
	('2048-08-25', '2048-08-01'),
	('2048-08-26', '2048-08-01'),
	('2048-08-27', '2048-08-01'),
	('2048-08-28', '2048-08-01'),
	('2048-08-29', '2048-08-01'),
	('2048-08-30', '2048-08-01'),
	('2048-08-31', '2048-08-01'),
	('2048-09-01', '2048-09-01'),
	('2048-09-02', '2048-09-01'),
	('2048-09-03', '2048-09-01'),
	('2048-09-04', '2048-09-01'),
	('2048-09-05', '2048-09-01'),
	('2048-09-06', '2048-09-01'),
	('2048-09-07', '2048-09-01'),
	('2048-09-08', '2048-09-01'),
	('2048-09-09', '2048-09-01'),
	('2048-09-10', '2048-09-01'),
	('2048-09-11', '2048-09-01'),
	('2048-09-12', '2048-09-01'),
	('2048-09-13', '2048-09-01'),
	('2048-09-14', '2048-09-01'),
	('2048-09-15', '2048-09-01'),
	('2048-09-16', '2048-09-01'),
	('2048-09-17', '2048-09-01'),
	('2048-09-18', '2048-09-01'),
	('2048-09-19', '2048-09-01'),
	('2048-09-20', '2048-09-01'),
	('2048-09-21', '2048-09-01'),
	('2048-09-22', '2048-09-01'),
	('2048-09-23', '2048-09-01'),
	('2048-09-24', '2048-09-01'),
	('2048-09-25', '2048-09-01'),
	('2048-09-26', '2048-09-01'),
	('2048-09-27', '2048-09-01'),
	('2048-09-28', '2048-09-01'),
	('2048-09-29', '2048-09-01'),
	('2048-09-30', '2048-09-01'),
	('2048-10-01', '2048-10-01'),
	('2048-10-02', '2048-10-01'),
	('2048-10-03', '2048-10-01'),
	('2048-10-04', '2048-10-01'),
	('2048-10-05', '2048-10-01'),
	('2048-10-06', '2048-10-01'),
	('2048-10-07', '2048-10-01'),
	('2048-10-08', '2048-10-01'),
	('2048-10-09', '2048-10-01'),
	('2048-10-10', '2048-10-01'),
	('2048-10-11', '2048-10-01'),
	('2048-10-12', '2048-10-01'),
	('2048-10-13', '2048-10-01'),
	('2048-10-14', '2048-10-01'),
	('2048-10-15', '2048-10-01'),
	('2048-10-16', '2048-10-01'),
	('2048-10-17', '2048-10-01'),
	('2048-10-18', '2048-10-01'),
	('2048-10-19', '2048-10-01'),
	('2048-10-20', '2048-10-01'),
	('2048-10-21', '2048-10-01'),
	('2048-10-22', '2048-10-01'),
	('2048-10-23', '2048-10-01'),
	('2048-10-24', '2048-10-01'),
	('2048-10-25', '2048-10-01'),
	('2048-10-26', '2048-10-01'),
	('2048-10-27', '2048-10-01'),
	('2048-10-28', '2048-10-01'),
	('2048-10-29', '2048-10-01'),
	('2048-10-30', '2048-10-01'),
	('2048-10-31', '2048-10-01'),
	('2048-11-01', '2048-11-01'),
	('2048-11-02', '2048-11-01'),
	('2048-11-03', '2048-11-01'),
	('2048-11-04', '2048-11-01'),
	('2048-11-05', '2048-11-01'),
	('2048-11-06', '2048-11-01'),
	('2048-11-07', '2048-11-01'),
	('2048-11-08', '2048-11-01'),
	('2048-11-09', '2048-11-01'),
	('2048-11-10', '2048-11-01'),
	('2048-11-11', '2048-11-01'),
	('2048-11-12', '2048-11-01'),
	('2048-11-13', '2048-11-01'),
	('2048-11-14', '2048-11-01'),
	('2048-11-15', '2048-11-01'),
	('2048-11-16', '2048-11-01'),
	('2048-11-17', '2048-11-01'),
	('2048-11-18', '2048-11-01'),
	('2048-11-19', '2048-11-01'),
	('2048-11-20', '2048-11-01'),
	('2048-11-21', '2048-11-01'),
	('2048-11-22', '2048-11-01'),
	('2048-11-23', '2048-11-01'),
	('2048-11-24', '2048-11-01'),
	('2048-11-25', '2048-11-01'),
	('2048-11-26', '2048-11-01'),
	('2048-11-27', '2048-11-01'),
	('2048-11-28', '2048-11-01'),
	('2048-11-29', '2048-11-01'),
	('2048-11-30', '2048-11-01'),
	('2048-12-01', '2048-12-01'),
	('2048-12-02', '2048-12-01'),
	('2048-12-03', '2048-12-01'),
	('2048-12-04', '2048-12-01'),
	('2048-12-05', '2048-12-01'),
	('2048-12-06', '2048-12-01'),
	('2048-12-07', '2048-12-01'),
	('2048-12-08', '2048-12-01'),
	('2048-12-09', '2048-12-01'),
	('2048-12-10', '2048-12-01'),
	('2048-12-11', '2048-12-01'),
	('2048-12-12', '2048-12-01'),
	('2048-12-13', '2048-12-01'),
	('2048-12-14', '2048-12-01'),
	('2048-12-15', '2048-12-01'),
	('2048-12-16', '2048-12-01'),
	('2048-12-17', '2048-12-01'),
	('2048-12-18', '2048-12-01'),
	('2048-12-19', '2048-12-01'),
	('2048-12-20', '2048-12-01'),
	('2048-12-21', '2048-12-01'),
	('2048-12-22', '2048-12-01'),
	('2048-12-23', '2048-12-01'),
	('2048-12-24', '2048-12-01'),
	('2048-12-25', '2048-12-01'),
	('2048-12-26', '2048-12-01'),
	('2048-12-27', '2048-12-01'),
	('2048-12-28', '2048-12-01'),
	('2048-12-29', '2048-12-01'),
	('2048-12-30', '2048-12-01'),
	('2048-12-31', '2048-12-01'),
	('2049-01-01', '2049-01-01'),
	('2049-01-02', '2049-01-01'),
	('2049-01-03', '2049-01-01'),
	('2049-01-04', '2049-01-01'),
	('2049-01-05', '2049-01-01'),
	('2049-01-06', '2049-01-01'),
	('2049-01-07', '2049-01-01'),
	('2049-01-08', '2049-01-01'),
	('2049-01-09', '2049-01-01'),
	('2049-01-10', '2049-01-01'),
	('2049-01-11', '2049-01-01'),
	('2049-01-12', '2049-01-01'),
	('2049-01-13', '2049-01-01'),
	('2049-01-14', '2049-01-01'),
	('2049-01-15', '2049-01-01'),
	('2049-01-16', '2049-01-01'),
	('2049-01-17', '2049-01-01'),
	('2049-01-18', '2049-01-01'),
	('2049-01-19', '2049-01-01'),
	('2049-01-20', '2049-01-01'),
	('2049-01-21', '2049-01-01'),
	('2049-01-22', '2049-01-01'),
	('2049-01-23', '2049-01-01'),
	('2049-01-24', '2049-01-01'),
	('2049-01-25', '2049-01-01'),
	('2049-01-26', '2049-01-01'),
	('2049-01-27', '2049-01-01'),
	('2049-01-28', '2049-01-01'),
	('2049-01-29', '2049-01-01'),
	('2049-01-30', '2049-01-01'),
	('2049-01-31', '2049-01-01'),
	('2049-02-01', '2049-02-01'),
	('2049-02-02', '2049-02-01'),
	('2049-02-03', '2049-02-01'),
	('2049-02-04', '2049-02-01'),
	('2049-02-05', '2049-02-01'),
	('2049-02-06', '2049-02-01'),
	('2049-02-07', '2049-02-01'),
	('2049-02-08', '2049-02-01'),
	('2049-02-09', '2049-02-01'),
	('2049-02-10', '2049-02-01'),
	('2049-02-11', '2049-02-01'),
	('2049-02-12', '2049-02-01'),
	('2049-02-13', '2049-02-01'),
	('2049-02-14', '2049-02-01'),
	('2049-02-15', '2049-02-01'),
	('2049-02-16', '2049-02-01'),
	('2049-02-17', '2049-02-01'),
	('2049-02-18', '2049-02-01'),
	('2049-02-19', '2049-02-01'),
	('2049-02-20', '2049-02-01'),
	('2049-02-21', '2049-02-01'),
	('2049-02-22', '2049-02-01'),
	('2049-02-23', '2049-02-01'),
	('2049-02-24', '2049-02-01'),
	('2049-02-25', '2049-02-01'),
	('2049-02-26', '2049-02-01'),
	('2049-02-27', '2049-02-01'),
	('2049-02-28', '2049-02-01'),
	('2049-03-01', '2049-03-01'),
	('2049-03-02', '2049-03-01'),
	('2049-03-03', '2049-03-01'),
	('2049-03-04', '2049-03-01'),
	('2049-03-05', '2049-03-01'),
	('2049-03-06', '2049-03-01'),
	('2049-03-07', '2049-03-01'),
	('2049-03-08', '2049-03-01'),
	('2049-03-09', '2049-03-01'),
	('2049-03-10', '2049-03-01'),
	('2049-03-11', '2049-03-01'),
	('2049-03-12', '2049-03-01'),
	('2049-03-13', '2049-03-01'),
	('2049-03-14', '2049-03-01'),
	('2049-03-15', '2049-03-01'),
	('2049-03-16', '2049-03-01'),
	('2049-03-17', '2049-03-01'),
	('2049-03-18', '2049-03-01'),
	('2049-03-19', '2049-03-01'),
	('2049-03-20', '2049-03-01'),
	('2049-03-21', '2049-03-01'),
	('2049-03-22', '2049-03-01'),
	('2049-03-23', '2049-03-01'),
	('2049-03-24', '2049-03-01'),
	('2049-03-25', '2049-03-01'),
	('2049-03-26', '2049-03-01'),
	('2049-03-27', '2049-03-01'),
	('2049-03-28', '2049-03-01'),
	('2049-03-29', '2049-03-01'),
	('2049-03-30', '2049-03-01'),
	('2049-03-31', '2049-03-01'),
	('2049-04-01', '2049-04-01'),
	('2049-04-02', '2049-04-01'),
	('2049-04-03', '2049-04-01'),
	('2049-04-04', '2049-04-01'),
	('2049-04-05', '2049-04-01'),
	('2049-04-06', '2049-04-01'),
	('2049-04-07', '2049-04-01'),
	('2049-04-08', '2049-04-01'),
	('2049-04-09', '2049-04-01'),
	('2049-04-10', '2049-04-01'),
	('2049-04-11', '2049-04-01'),
	('2049-04-12', '2049-04-01'),
	('2049-04-13', '2049-04-01'),
	('2049-04-14', '2049-04-01'),
	('2049-04-15', '2049-04-01'),
	('2049-04-16', '2049-04-01'),
	('2049-04-17', '2049-04-01'),
	('2049-04-18', '2049-04-01'),
	('2049-04-19', '2049-04-01'),
	('2049-04-20', '2049-04-01'),
	('2049-04-21', '2049-04-01'),
	('2049-04-22', '2049-04-01'),
	('2049-04-23', '2049-04-01'),
	('2049-04-24', '2049-04-01'),
	('2049-04-25', '2049-04-01'),
	('2049-04-26', '2049-04-01'),
	('2049-04-27', '2049-04-01'),
	('2049-04-28', '2049-04-01'),
	('2049-04-29', '2049-04-01'),
	('2049-04-30', '2049-04-01'),
	('2049-05-01', '2049-05-01'),
	('2049-05-02', '2049-05-01'),
	('2049-05-03', '2049-05-01'),
	('2049-05-04', '2049-05-01'),
	('2049-05-05', '2049-05-01'),
	('2049-05-06', '2049-05-01'),
	('2049-05-07', '2049-05-01'),
	('2049-05-08', '2049-05-01'),
	('2049-05-09', '2049-05-01'),
	('2049-05-10', '2049-05-01'),
	('2049-05-11', '2049-05-01'),
	('2049-05-12', '2049-05-01'),
	('2049-05-13', '2049-05-01'),
	('2049-05-14', '2049-05-01'),
	('2049-05-15', '2049-05-01'),
	('2049-05-16', '2049-05-01'),
	('2049-05-17', '2049-05-01'),
	('2049-05-18', '2049-05-01'),
	('2049-05-19', '2049-05-01'),
	('2049-05-20', '2049-05-01'),
	('2049-05-21', '2049-05-01'),
	('2049-05-22', '2049-05-01'),
	('2049-05-23', '2049-05-01'),
	('2049-05-24', '2049-05-01'),
	('2049-05-25', '2049-05-01'),
	('2049-05-26', '2049-05-01'),
	('2049-05-27', '2049-05-01'),
	('2049-05-28', '2049-05-01'),
	('2049-05-29', '2049-05-01'),
	('2049-05-30', '2049-05-01'),
	('2049-05-31', '2049-05-01'),
	('2049-06-01', '2049-06-01'),
	('2049-06-02', '2049-06-01'),
	('2049-06-03', '2049-06-01'),
	('2049-06-04', '2049-06-01'),
	('2049-06-05', '2049-06-01'),
	('2049-06-06', '2049-06-01'),
	('2049-06-07', '2049-06-01'),
	('2049-06-08', '2049-06-01'),
	('2049-06-09', '2049-06-01'),
	('2049-06-10', '2049-06-01'),
	('2049-06-11', '2049-06-01'),
	('2049-06-12', '2049-06-01'),
	('2049-06-13', '2049-06-01'),
	('2049-06-14', '2049-06-01'),
	('2049-06-15', '2049-06-01'),
	('2049-06-16', '2049-06-01'),
	('2049-06-17', '2049-06-01'),
	('2049-06-18', '2049-06-01'),
	('2049-06-19', '2049-06-01'),
	('2049-06-20', '2049-06-01'),
	('2049-06-21', '2049-06-01'),
	('2049-06-22', '2049-06-01'),
	('2049-06-23', '2049-06-01'),
	('2049-06-24', '2049-06-01'),
	('2049-06-25', '2049-06-01'),
	('2049-06-26', '2049-06-01'),
	('2049-06-27', '2049-06-01'),
	('2049-06-28', '2049-06-01'),
	('2049-06-29', '2049-06-01'),
	('2049-06-30', '2049-06-01'),
	('2049-07-01', '2049-07-01'),
	('2049-07-02', '2049-07-01'),
	('2049-07-03', '2049-07-01'),
	('2049-07-04', '2049-07-01'),
	('2049-07-05', '2049-07-01'),
	('2049-07-06', '2049-07-01'),
	('2049-07-07', '2049-07-01'),
	('2049-07-08', '2049-07-01'),
	('2049-07-09', '2049-07-01'),
	('2049-07-10', '2049-07-01'),
	('2049-07-11', '2049-07-01'),
	('2049-07-12', '2049-07-01'),
	('2049-07-13', '2049-07-01'),
	('2049-07-14', '2049-07-01'),
	('2049-07-15', '2049-07-01'),
	('2049-07-16', '2049-07-01'),
	('2049-07-17', '2049-07-01'),
	('2049-07-18', '2049-07-01'),
	('2049-07-19', '2049-07-01'),
	('2049-07-20', '2049-07-01'),
	('2049-07-21', '2049-07-01'),
	('2049-07-22', '2049-07-01'),
	('2049-07-23', '2049-07-01'),
	('2049-07-24', '2049-07-01'),
	('2049-07-25', '2049-07-01'),
	('2049-07-26', '2049-07-01'),
	('2049-07-27', '2049-07-01'),
	('2049-07-28', '2049-07-01'),
	('2049-07-29', '2049-07-01'),
	('2049-07-30', '2049-07-01'),
	('2049-07-31', '2049-07-01'),
	('2049-08-01', '2049-08-01'),
	('2049-08-02', '2049-08-01'),
	('2049-08-03', '2049-08-01'),
	('2049-08-04', '2049-08-01'),
	('2049-08-05', '2049-08-01'),
	('2049-08-06', '2049-08-01'),
	('2049-08-07', '2049-08-01'),
	('2049-08-08', '2049-08-01'),
	('2049-08-09', '2049-08-01'),
	('2049-08-10', '2049-08-01'),
	('2049-08-11', '2049-08-01'),
	('2049-08-12', '2049-08-01'),
	('2049-08-13', '2049-08-01'),
	('2049-08-14', '2049-08-01'),
	('2049-08-15', '2049-08-01'),
	('2049-08-16', '2049-08-01'),
	('2049-08-17', '2049-08-01'),
	('2049-08-18', '2049-08-01'),
	('2049-08-19', '2049-08-01'),
	('2049-08-20', '2049-08-01'),
	('2049-08-21', '2049-08-01'),
	('2049-08-22', '2049-08-01'),
	('2049-08-23', '2049-08-01'),
	('2049-08-24', '2049-08-01'),
	('2049-08-25', '2049-08-01'),
	('2049-08-26', '2049-08-01'),
	('2049-08-27', '2049-08-01'),
	('2049-08-28', '2049-08-01'),
	('2049-08-29', '2049-08-01'),
	('2049-08-30', '2049-08-01'),
	('2049-08-31', '2049-08-01'),
	('2049-09-01', '2049-09-01'),
	('2049-09-02', '2049-09-01'),
	('2049-09-03', '2049-09-01'),
	('2049-09-04', '2049-09-01'),
	('2049-09-05', '2049-09-01'),
	('2049-09-06', '2049-09-01'),
	('2049-09-07', '2049-09-01'),
	('2049-09-08', '2049-09-01'),
	('2049-09-09', '2049-09-01'),
	('2049-09-10', '2049-09-01'),
	('2049-09-11', '2049-09-01'),
	('2049-09-12', '2049-09-01'),
	('2049-09-13', '2049-09-01'),
	('2049-09-14', '2049-09-01'),
	('2049-09-15', '2049-09-01'),
	('2049-09-16', '2049-09-01'),
	('2049-09-17', '2049-09-01'),
	('2049-09-18', '2049-09-01'),
	('2049-09-19', '2049-09-01'),
	('2049-09-20', '2049-09-01'),
	('2049-09-21', '2049-09-01'),
	('2049-09-22', '2049-09-01'),
	('2049-09-23', '2049-09-01'),
	('2049-09-24', '2049-09-01'),
	('2049-09-25', '2049-09-01'),
	('2049-09-26', '2049-09-01'),
	('2049-09-27', '2049-09-01'),
	('2049-09-28', '2049-09-01'),
	('2049-09-29', '2049-09-01'),
	('2049-09-30', '2049-09-01'),
	('2049-10-01', '2049-10-01'),
	('2049-10-02', '2049-10-01'),
	('2049-10-03', '2049-10-01'),
	('2049-10-04', '2049-10-01'),
	('2049-10-05', '2049-10-01'),
	('2049-10-06', '2049-10-01'),
	('2049-10-07', '2049-10-01'),
	('2049-10-08', '2049-10-01'),
	('2049-10-09', '2049-10-01'),
	('2049-10-10', '2049-10-01'),
	('2049-10-11', '2049-10-01'),
	('2049-10-12', '2049-10-01'),
	('2049-10-13', '2049-10-01'),
	('2049-10-14', '2049-10-01'),
	('2049-10-15', '2049-10-01'),
	('2049-10-16', '2049-10-01'),
	('2049-10-17', '2049-10-01'),
	('2049-10-18', '2049-10-01'),
	('2049-10-19', '2049-10-01'),
	('2049-10-20', '2049-10-01'),
	('2049-10-21', '2049-10-01'),
	('2049-10-22', '2049-10-01'),
	('2049-10-23', '2049-10-01'),
	('2049-10-24', '2049-10-01'),
	('2049-10-25', '2049-10-01'),
	('2049-10-26', '2049-10-01'),
	('2049-10-27', '2049-10-01'),
	('2049-10-28', '2049-10-01'),
	('2049-10-29', '2049-10-01'),
	('2049-10-30', '2049-10-01'),
	('2049-10-31', '2049-10-01'),
	('2049-11-01', '2049-11-01'),
	('2049-11-02', '2049-11-01'),
	('2049-11-03', '2049-11-01'),
	('2049-11-04', '2049-11-01'),
	('2049-11-05', '2049-11-01'),
	('2049-11-06', '2049-11-01'),
	('2049-11-07', '2049-11-01'),
	('2049-11-08', '2049-11-01'),
	('2049-11-09', '2049-11-01'),
	('2049-11-10', '2049-11-01'),
	('2049-11-11', '2049-11-01'),
	('2049-11-12', '2049-11-01'),
	('2049-11-13', '2049-11-01'),
	('2049-11-14', '2049-11-01'),
	('2049-11-15', '2049-11-01'),
	('2049-11-16', '2049-11-01'),
	('2049-11-17', '2049-11-01'),
	('2049-11-18', '2049-11-01'),
	('2049-11-19', '2049-11-01'),
	('2049-11-20', '2049-11-01'),
	('2049-11-21', '2049-11-01'),
	('2049-11-22', '2049-11-01'),
	('2049-11-23', '2049-11-01'),
	('2049-11-24', '2049-11-01'),
	('2049-11-25', '2049-11-01'),
	('2049-11-26', '2049-11-01'),
	('2049-11-27', '2049-11-01'),
	('2049-11-28', '2049-11-01'),
	('2049-11-29', '2049-11-01'),
	('2049-11-30', '2049-11-01'),
	('2049-12-01', '2049-12-01'),
	('2049-12-02', '2049-12-01'),
	('2049-12-03', '2049-12-01'),
	('2049-12-04', '2049-12-01'),
	('2049-12-05', '2049-12-01'),
	('2049-12-06', '2049-12-01'),
	('2049-12-07', '2049-12-01'),
	('2049-12-08', '2049-12-01'),
	('2049-12-09', '2049-12-01'),
	('2049-12-10', '2049-12-01'),
	('2049-12-11', '2049-12-01'),
	('2049-12-12', '2049-12-01'),
	('2049-12-13', '2049-12-01'),
	('2049-12-14', '2049-12-01'),
	('2049-12-15', '2049-12-01'),
	('2049-12-16', '2049-12-01'),
	('2049-12-17', '2049-12-01'),
	('2049-12-18', '2049-12-01'),
	('2049-12-19', '2049-12-01'),
	('2049-12-20', '2049-12-01'),
	('2049-12-21', '2049-12-01'),
	('2049-12-22', '2049-12-01'),
	('2049-12-23', '2049-12-01'),
	('2049-12-24', '2049-12-01'),
	('2049-12-25', '2049-12-01'),
	('2049-12-26', '2049-12-01'),
	('2049-12-27', '2049-12-01'),
	('2049-12-28', '2049-12-01'),
	('2049-12-29', '2049-12-01'),
	('2049-12-30', '2049-12-01'),
	('2049-12-31', '2049-12-01'),
	('2050-01-01', '2050-01-01'),
	('2050-01-02', '2050-01-01'),
	('2050-01-03', '2050-01-01'),
	('2050-01-04', '2050-01-01'),
	('2050-01-05', '2050-01-01'),
	('2050-01-06', '2050-01-01'),
	('2050-01-07', '2050-01-01'),
	('2050-01-08', '2050-01-01'),
	('2050-01-09', '2050-01-01'),
	('2050-01-10', '2050-01-01'),
	('2050-01-11', '2050-01-01'),
	('2050-01-12', '2050-01-01'),
	('2050-01-13', '2050-01-01'),
	('2050-01-14', '2050-01-01'),
	('2050-01-15', '2050-01-01'),
	('2050-01-16', '2050-01-01'),
	('2050-01-17', '2050-01-01'),
	('2050-01-18', '2050-01-01'),
	('2050-01-19', '2050-01-01'),
	('2050-01-20', '2050-01-01'),
	('2050-01-21', '2050-01-01'),
	('2050-01-22', '2050-01-01'),
	('2050-01-23', '2050-01-01'),
	('2050-01-24', '2050-01-01'),
	('2050-01-25', '2050-01-01'),
	('2050-01-26', '2050-01-01'),
	('2050-01-27', '2050-01-01'),
	('2050-01-28', '2050-01-01'),
	('2050-01-29', '2050-01-01'),
	('2050-01-30', '2050-01-01'),
	('2050-01-31', '2050-01-01'),
	('2050-02-01', '2050-02-01'),
	('2050-02-02', '2050-02-01'),
	('2050-02-03', '2050-02-01'),
	('2050-02-04', '2050-02-01'),
	('2050-02-05', '2050-02-01'),
	('2050-02-06', '2050-02-01'),
	('2050-02-07', '2050-02-01'),
	('2050-02-08', '2050-02-01'),
	('2050-02-09', '2050-02-01'),
	('2050-02-10', '2050-02-01'),
	('2050-02-11', '2050-02-01'),
	('2050-02-12', '2050-02-01'),
	('2050-02-13', '2050-02-01'),
	('2050-02-14', '2050-02-01'),
	('2050-02-15', '2050-02-01'),
	('2050-02-16', '2050-02-01'),
	('2050-02-17', '2050-02-01'),
	('2050-02-18', '2050-02-01'),
	('2050-02-19', '2050-02-01'),
	('2050-02-20', '2050-02-01'),
	('2050-02-21', '2050-02-01'),
	('2050-02-22', '2050-02-01'),
	('2050-02-23', '2050-02-01'),
	('2050-02-24', '2050-02-01'),
	('2050-02-25', '2050-02-01'),
	('2050-02-26', '2050-02-01'),
	('2050-02-27', '2050-02-01'),
	('2050-02-28', '2050-02-01'),
	('2050-03-01', '2050-03-01'),
	('2050-03-02', '2050-03-01'),
	('2050-03-03', '2050-03-01'),
	('2050-03-04', '2050-03-01'),
	('2050-03-05', '2050-03-01'),
	('2050-03-06', '2050-03-01'),
	('2050-03-07', '2050-03-01'),
	('2050-03-08', '2050-03-01'),
	('2050-03-09', '2050-03-01'),
	('2050-03-10', '2050-03-01'),
	('2050-03-11', '2050-03-01'),
	('2050-03-12', '2050-03-01'),
	('2050-03-13', '2050-03-01'),
	('2050-03-14', '2050-03-01'),
	('2050-03-15', '2050-03-01'),
	('2050-03-16', '2050-03-01'),
	('2050-03-17', '2050-03-01'),
	('2050-03-18', '2050-03-01'),
	('2050-03-19', '2050-03-01'),
	('2050-03-20', '2050-03-01'),
	('2050-03-21', '2050-03-01'),
	('2050-03-22', '2050-03-01'),
	('2050-03-23', '2050-03-01'),
	('2050-03-24', '2050-03-01'),
	('2050-03-25', '2050-03-01'),
	('2050-03-26', '2050-03-01'),
	('2050-03-27', '2050-03-01'),
	('2050-03-28', '2050-03-01'),
	('2050-03-29', '2050-03-01'),
	('2050-03-30', '2050-03-01'),
	('2050-03-31', '2050-03-01'),
	('2050-04-01', '2050-04-01'),
	('2050-04-02', '2050-04-01'),
	('2050-04-03', '2050-04-01'),
	('2050-04-04', '2050-04-01'),
	('2050-04-05', '2050-04-01'),
	('2050-04-06', '2050-04-01'),
	('2050-04-07', '2050-04-01'),
	('2050-04-08', '2050-04-01'),
	('2050-04-09', '2050-04-01'),
	('2050-04-10', '2050-04-01'),
	('2050-04-11', '2050-04-01'),
	('2050-04-12', '2050-04-01'),
	('2050-04-13', '2050-04-01'),
	('2050-04-14', '2050-04-01'),
	('2050-04-15', '2050-04-01'),
	('2050-04-16', '2050-04-01'),
	('2050-04-17', '2050-04-01'),
	('2050-04-18', '2050-04-01'),
	('2050-04-19', '2050-04-01'),
	('2050-04-20', '2050-04-01'),
	('2050-04-21', '2050-04-01'),
	('2050-04-22', '2050-04-01'),
	('2050-04-23', '2050-04-01'),
	('2050-04-24', '2050-04-01'),
	('2050-04-25', '2050-04-01'),
	('2050-04-26', '2050-04-01'),
	('2050-04-27', '2050-04-01'),
	('2050-04-28', '2050-04-01'),
	('2050-04-29', '2050-04-01'),
	('2050-04-30', '2050-04-01'),
	('2050-05-01', '2050-05-01'),
	('2050-05-02', '2050-05-01'),
	('2050-05-03', '2050-05-01'),
	('2050-05-04', '2050-05-01'),
	('2050-05-05', '2050-05-01'),
	('2050-05-06', '2050-05-01'),
	('2050-05-07', '2050-05-01'),
	('2050-05-08', '2050-05-01'),
	('2050-05-09', '2050-05-01'),
	('2050-05-10', '2050-05-01'),
	('2050-05-11', '2050-05-01'),
	('2050-05-12', '2050-05-01'),
	('2050-05-13', '2050-05-01'),
	('2050-05-14', '2050-05-01'),
	('2050-05-15', '2050-05-01'),
	('2050-05-16', '2050-05-01'),
	('2050-05-17', '2050-05-01'),
	('2050-05-18', '2050-05-01'),
	('2050-05-19', '2050-05-01'),
	('2050-05-20', '2050-05-01'),
	('2050-05-21', '2050-05-01'),
	('2050-05-22', '2050-05-01'),
	('2050-05-23', '2050-05-01'),
	('2050-05-24', '2050-05-01'),
	('2050-05-25', '2050-05-01'),
	('2050-05-26', '2050-05-01'),
	('2050-05-27', '2050-05-01'),
	('2050-05-28', '2050-05-01'),
	('2050-05-29', '2050-05-01'),
	('2050-05-30', '2050-05-01'),
	('2050-05-31', '2050-05-01'),
	('2050-06-01', '2050-06-01'),
	('2050-06-02', '2050-06-01'),
	('2050-06-03', '2050-06-01'),
	('2050-06-04', '2050-06-01'),
	('2050-06-05', '2050-06-01'),
	('2050-06-06', '2050-06-01'),
	('2050-06-07', '2050-06-01'),
	('2050-06-08', '2050-06-01'),
	('2050-06-09', '2050-06-01'),
	('2050-06-10', '2050-06-01'),
	('2050-06-11', '2050-06-01'),
	('2050-06-12', '2050-06-01'),
	('2050-06-13', '2050-06-01'),
	('2050-06-14', '2050-06-01'),
	('2050-06-15', '2050-06-01'),
	('2050-06-16', '2050-06-01'),
	('2050-06-17', '2050-06-01'),
	('2050-06-18', '2050-06-01'),
	('2050-06-19', '2050-06-01'),
	('2050-06-20', '2050-06-01'),
	('2050-06-21', '2050-06-01'),
	('2050-06-22', '2050-06-01'),
	('2050-06-23', '2050-06-01'),
	('2050-06-24', '2050-06-01'),
	('2050-06-25', '2050-06-01'),
	('2050-06-26', '2050-06-01'),
	('2050-06-27', '2050-06-01'),
	('2050-06-28', '2050-06-01'),
	('2050-06-29', '2050-06-01'),
	('2050-06-30', '2050-06-01'),
	('2050-07-01', '2050-07-01'),
	('2050-07-02', '2050-07-01'),
	('2050-07-03', '2050-07-01'),
	('2050-07-04', '2050-07-01'),
	('2050-07-05', '2050-07-01'),
	('2050-07-06', '2050-07-01'),
	('2050-07-07', '2050-07-01'),
	('2050-07-08', '2050-07-01'),
	('2050-07-09', '2050-07-01'),
	('2050-07-10', '2050-07-01'),
	('2050-07-11', '2050-07-01'),
	('2050-07-12', '2050-07-01'),
	('2050-07-13', '2050-07-01'),
	('2050-07-14', '2050-07-01'),
	('2050-07-15', '2050-07-01'),
	('2050-07-16', '2050-07-01'),
	('2050-07-17', '2050-07-01'),
	('2050-07-18', '2050-07-01'),
	('2050-07-19', '2050-07-01'),
	('2050-07-20', '2050-07-01'),
	('2050-07-21', '2050-07-01'),
	('2050-07-22', '2050-07-01'),
	('2050-07-23', '2050-07-01'),
	('2050-07-24', '2050-07-01'),
	('2050-07-25', '2050-07-01'),
	('2050-07-26', '2050-07-01'),
	('2050-07-27', '2050-07-01'),
	('2050-07-28', '2050-07-01'),
	('2050-07-29', '2050-07-01'),
	('2050-07-30', '2050-07-01'),
	('2050-07-31', '2050-07-01'),
	('2050-08-01', '2050-08-01'),
	('2050-08-02', '2050-08-01'),
	('2050-08-03', '2050-08-01'),
	('2050-08-04', '2050-08-01'),
	('2050-08-05', '2050-08-01'),
	('2050-08-06', '2050-08-01'),
	('2050-08-07', '2050-08-01'),
	('2050-08-08', '2050-08-01'),
	('2050-08-09', '2050-08-01'),
	('2050-08-10', '2050-08-01'),
	('2050-08-11', '2050-08-01'),
	('2050-08-12', '2050-08-01'),
	('2050-08-13', '2050-08-01'),
	('2050-08-14', '2050-08-01'),
	('2050-08-15', '2050-08-01'),
	('2050-08-16', '2050-08-01'),
	('2050-08-17', '2050-08-01'),
	('2050-08-18', '2050-08-01'),
	('2050-08-19', '2050-08-01'),
	('2050-08-20', '2050-08-01'),
	('2050-08-21', '2050-08-01'),
	('2050-08-22', '2050-08-01'),
	('2050-08-23', '2050-08-01'),
	('2050-08-24', '2050-08-01'),
	('2050-08-25', '2050-08-01'),
	('2050-08-26', '2050-08-01'),
	('2050-08-27', '2050-08-01'),
	('2050-08-28', '2050-08-01'),
	('2050-08-29', '2050-08-01'),
	('2050-08-30', '2050-08-01'),
	('2050-08-31', '2050-08-01'),
	('2050-09-01', '2050-09-01'),
	('2050-09-02', '2050-09-01'),
	('2050-09-03', '2050-09-01'),
	('2050-09-04', '2050-09-01'),
	('2050-09-05', '2050-09-01'),
	('2050-09-06', '2050-09-01'),
	('2050-09-07', '2050-09-01'),
	('2050-09-08', '2050-09-01'),
	('2050-09-09', '2050-09-01'),
	('2050-09-10', '2050-09-01'),
	('2050-09-11', '2050-09-01'),
	('2050-09-12', '2050-09-01'),
	('2050-09-13', '2050-09-01'),
	('2050-09-14', '2050-09-01'),
	('2050-09-15', '2050-09-01'),
	('2050-09-16', '2050-09-01'),
	('2050-09-17', '2050-09-01'),
	('2050-09-18', '2050-09-01'),
	('2050-09-19', '2050-09-01'),
	('2050-09-20', '2050-09-01'),
	('2050-09-21', '2050-09-01'),
	('2050-09-22', '2050-09-01'),
	('2050-09-23', '2050-09-01'),
	('2050-09-24', '2050-09-01'),
	('2050-09-25', '2050-09-01'),
	('2050-09-26', '2050-09-01'),
	('2050-09-27', '2050-09-01'),
	('2050-09-28', '2050-09-01'),
	('2050-09-29', '2050-09-01'),
	('2050-09-30', '2050-09-01'),
	('2050-10-01', '2050-10-01'),
	('2050-10-02', '2050-10-01'),
	('2050-10-03', '2050-10-01'),
	('2050-10-04', '2050-10-01'),
	('2050-10-05', '2050-10-01'),
	('2050-10-06', '2050-10-01'),
	('2050-10-07', '2050-10-01'),
	('2050-10-08', '2050-10-01'),
	('2050-10-09', '2050-10-01'),
	('2050-10-10', '2050-10-01'),
	('2050-10-11', '2050-10-01'),
	('2050-10-12', '2050-10-01'),
	('2050-10-13', '2050-10-01'),
	('2050-10-14', '2050-10-01'),
	('2050-10-15', '2050-10-01'),
	('2050-10-16', '2050-10-01'),
	('2050-10-17', '2050-10-01'),
	('2050-10-18', '2050-10-01'),
	('2050-10-19', '2050-10-01'),
	('2050-10-20', '2050-10-01'),
	('2050-10-21', '2050-10-01'),
	('2050-10-22', '2050-10-01'),
	('2050-10-23', '2050-10-01'),
	('2050-10-24', '2050-10-01'),
	('2050-10-25', '2050-10-01'),
	('2050-10-26', '2050-10-01'),
	('2050-10-27', '2050-10-01'),
	('2050-10-28', '2050-10-01'),
	('2050-10-29', '2050-10-01'),
	('2050-10-30', '2050-10-01'),
	('2050-10-31', '2050-10-01'),
	('2050-11-01', '2050-11-01'),
	('2050-11-02', '2050-11-01'),
	('2050-11-03', '2050-11-01'),
	('2050-11-04', '2050-11-01'),
	('2050-11-05', '2050-11-01'),
	('2050-11-06', '2050-11-01'),
	('2050-11-07', '2050-11-01'),
	('2050-11-08', '2050-11-01'),
	('2050-11-09', '2050-11-01'),
	('2050-11-10', '2050-11-01'),
	('2050-11-11', '2050-11-01'),
	('2050-11-12', '2050-11-01'),
	('2050-11-13', '2050-11-01'),
	('2050-11-14', '2050-11-01'),
	('2050-11-15', '2050-11-01'),
	('2050-11-16', '2050-11-01'),
	('2050-11-17', '2050-11-01'),
	('2050-11-18', '2050-11-01'),
	('2050-11-19', '2050-11-01'),
	('2050-11-20', '2050-11-01'),
	('2050-11-21', '2050-11-01'),
	('2050-11-22', '2050-11-01'),
	('2050-11-23', '2050-11-01'),
	('2050-11-24', '2050-11-01'),
	('2050-11-25', '2050-11-01'),
	('2050-11-26', '2050-11-01'),
	('2050-11-27', '2050-11-01'),
	('2050-11-28', '2050-11-01'),
	('2050-11-29', '2050-11-01'),
	('2050-11-30', '2050-11-01'),
	('2050-12-01', '2050-12-01'),
	('2050-12-02', '2050-12-01'),
	('2050-12-03', '2050-12-01'),
	('2050-12-04', '2050-12-01'),
	('2050-12-05', '2050-12-01'),
	('2050-12-06', '2050-12-01'),
	('2050-12-07', '2050-12-01'),
	('2050-12-08', '2050-12-01'),
	('2050-12-09', '2050-12-01'),
	('2050-12-10', '2050-12-01'),
	('2050-12-11', '2050-12-01'),
	('2050-12-12', '2050-12-01'),
	('2050-12-13', '2050-12-01'),
	('2050-12-14', '2050-12-01'),
	('2050-12-15', '2050-12-01'),
	('2050-12-16', '2050-12-01'),
	('2050-12-17', '2050-12-01'),
	('2050-12-18', '2050-12-01'),
	('2050-12-19', '2050-12-01'),
	('2050-12-20', '2050-12-01'),
	('2050-12-21', '2050-12-01'),
	('2050-12-22', '2050-12-01'),
	('2050-12-23', '2050-12-01'),
	('2050-12-24', '2050-12-01'),
	('2050-12-25', '2050-12-01'),
	('2050-12-26', '2050-12-01'),
	('2050-12-27', '2050-12-01'),
	('2050-12-28', '2050-12-01'),
	('2050-12-29', '2050-12-01'),
	('2050-12-30', '2050-12-01'),
	('2050-12-31', '2050-12-01'),
	('2051-01-01', '2051-01-01'),
	('2051-01-02', '2051-01-01'),
	('2051-01-03', '2051-01-01'),
	('2051-01-04', '2051-01-01'),
	('2051-01-05', '2051-01-01'),
	('2051-01-06', '2051-01-01'),
	('2051-01-07', '2051-01-01'),
	('2051-01-08', '2051-01-01'),
	('2051-01-09', '2051-01-01'),
	('2051-01-10', '2051-01-01'),
	('2051-01-11', '2051-01-01'),
	('2051-01-12', '2051-01-01'),
	('2051-01-13', '2051-01-01'),
	('2051-01-14', '2051-01-01'),
	('2051-01-15', '2051-01-01'),
	('2051-01-16', '2051-01-01'),
	('2051-01-17', '2051-01-01'),
	('2051-01-18', '2051-01-01'),
	('2051-01-19', '2051-01-01'),
	('2051-01-20', '2051-01-01'),
	('2051-01-21', '2051-01-01'),
	('2051-01-22', '2051-01-01'),
	('2051-01-23', '2051-01-01'),
	('2051-01-24', '2051-01-01'),
	('2051-01-25', '2051-01-01'),
	('2051-01-26', '2051-01-01'),
	('2051-01-27', '2051-01-01'),
	('2051-01-28', '2051-01-01'),
	('2051-01-29', '2051-01-01'),
	('2051-01-30', '2051-01-01'),
	('2051-01-31', '2051-01-01'),
	('2051-02-01', '2051-02-01'),
	('2051-02-02', '2051-02-01'),
	('2051-02-03', '2051-02-01'),
	('2051-02-04', '2051-02-01'),
	('2051-02-05', '2051-02-01'),
	('2051-02-06', '2051-02-01'),
	('2051-02-07', '2051-02-01'),
	('2051-02-08', '2051-02-01'),
	('2051-02-09', '2051-02-01'),
	('2051-02-10', '2051-02-01'),
	('2051-02-11', '2051-02-01'),
	('2051-02-12', '2051-02-01'),
	('2051-02-13', '2051-02-01'),
	('2051-02-14', '2051-02-01'),
	('2051-02-15', '2051-02-01'),
	('2051-02-16', '2051-02-01'),
	('2051-02-17', '2051-02-01'),
	('2051-02-18', '2051-02-01'),
	('2051-02-19', '2051-02-01'),
	('2051-02-20', '2051-02-01'),
	('2051-02-21', '2051-02-01'),
	('2051-02-22', '2051-02-01'),
	('2051-02-23', '2051-02-01'),
	('2051-02-24', '2051-02-01'),
	('2051-02-25', '2051-02-01'),
	('2051-02-26', '2051-02-01'),
	('2051-02-27', '2051-02-01'),
	('2051-02-28', '2051-02-01'),
	('2051-03-01', '2051-03-01'),
	('2051-03-02', '2051-03-01'),
	('2051-03-03', '2051-03-01'),
	('2051-03-04', '2051-03-01'),
	('2051-03-05', '2051-03-01'),
	('2051-03-06', '2051-03-01'),
	('2051-03-07', '2051-03-01'),
	('2051-03-08', '2051-03-01'),
	('2051-03-09', '2051-03-01'),
	('2051-03-10', '2051-03-01'),
	('2051-03-11', '2051-03-01'),
	('2051-03-12', '2051-03-01'),
	('2051-03-13', '2051-03-01'),
	('2051-03-14', '2051-03-01'),
	('2051-03-15', '2051-03-01'),
	('2051-03-16', '2051-03-01'),
	('2051-03-17', '2051-03-01'),
	('2051-03-18', '2051-03-01'),
	('2051-03-19', '2051-03-01'),
	('2051-03-20', '2051-03-01'),
	('2051-03-21', '2051-03-01'),
	('2051-03-22', '2051-03-01'),
	('2051-03-23', '2051-03-01'),
	('2051-03-24', '2051-03-01'),
	('2051-03-25', '2051-03-01'),
	('2051-03-26', '2051-03-01'),
	('2051-03-27', '2051-03-01'),
	('2051-03-28', '2051-03-01'),
	('2051-03-29', '2051-03-01'),
	('2051-03-30', '2051-03-01'),
	('2051-03-31', '2051-03-01'),
	('2051-04-01', '2051-04-01'),
	('2051-04-02', '2051-04-01'),
	('2051-04-03', '2051-04-01'),
	('2051-04-04', '2051-04-01'),
	('2051-04-05', '2051-04-01'),
	('2051-04-06', '2051-04-01'),
	('2051-04-07', '2051-04-01'),
	('2051-04-08', '2051-04-01'),
	('2051-04-09', '2051-04-01'),
	('2051-04-10', '2051-04-01'),
	('2051-04-11', '2051-04-01'),
	('2051-04-12', '2051-04-01'),
	('2051-04-13', '2051-04-01'),
	('2051-04-14', '2051-04-01'),
	('2051-04-15', '2051-04-01'),
	('2051-04-16', '2051-04-01'),
	('2051-04-17', '2051-04-01'),
	('2051-04-18', '2051-04-01'),
	('2051-04-19', '2051-04-01'),
	('2051-04-20', '2051-04-01'),
	('2051-04-21', '2051-04-01'),
	('2051-04-22', '2051-04-01'),
	('2051-04-23', '2051-04-01'),
	('2051-04-24', '2051-04-01'),
	('2051-04-25', '2051-04-01'),
	('2051-04-26', '2051-04-01'),
	('2051-04-27', '2051-04-01'),
	('2051-04-28', '2051-04-01'),
	('2051-04-29', '2051-04-01'),
	('2051-04-30', '2051-04-01'),
	('2051-05-01', '2051-05-01'),
	('2051-05-02', '2051-05-01'),
	('2051-05-03', '2051-05-01'),
	('2051-05-04', '2051-05-01'),
	('2051-05-05', '2051-05-01'),
	('2051-05-06', '2051-05-01'),
	('2051-05-07', '2051-05-01'),
	('2051-05-08', '2051-05-01'),
	('2051-05-09', '2051-05-01'),
	('2051-05-10', '2051-05-01'),
	('2051-05-11', '2051-05-01'),
	('2051-05-12', '2051-05-01'),
	('2051-05-13', '2051-05-01'),
	('2051-05-14', '2051-05-01'),
	('2051-05-15', '2051-05-01'),
	('2051-05-16', '2051-05-01'),
	('2051-05-17', '2051-05-01'),
	('2051-05-18', '2051-05-01'),
	('2051-05-19', '2051-05-01'),
	('2051-05-20', '2051-05-01'),
	('2051-05-21', '2051-05-01'),
	('2051-05-22', '2051-05-01'),
	('2051-05-23', '2051-05-01'),
	('2051-05-24', '2051-05-01'),
	('2051-05-25', '2051-05-01'),
	('2051-05-26', '2051-05-01'),
	('2051-05-27', '2051-05-01'),
	('2051-05-28', '2051-05-01'),
	('2051-05-29', '2051-05-01'),
	('2051-05-30', '2051-05-01'),
	('2051-05-31', '2051-05-01'),
	('2051-06-01', '2051-06-01'),
	('2051-06-02', '2051-06-01'),
	('2051-06-03', '2051-06-01'),
	('2051-06-04', '2051-06-01'),
	('2051-06-05', '2051-06-01'),
	('2051-06-06', '2051-06-01'),
	('2051-06-07', '2051-06-01'),
	('2051-06-08', '2051-06-01'),
	('2051-06-09', '2051-06-01'),
	('2051-06-10', '2051-06-01'),
	('2051-06-11', '2051-06-01'),
	('2051-06-12', '2051-06-01'),
	('2051-06-13', '2051-06-01'),
	('2051-06-14', '2051-06-01'),
	('2051-06-15', '2051-06-01'),
	('2051-06-16', '2051-06-01'),
	('2051-06-17', '2051-06-01'),
	('2051-06-18', '2051-06-01'),
	('2051-06-19', '2051-06-01'),
	('2051-06-20', '2051-06-01'),
	('2051-06-21', '2051-06-01'),
	('2051-06-22', '2051-06-01'),
	('2051-06-23', '2051-06-01'),
	('2051-06-24', '2051-06-01'),
	('2051-06-25', '2051-06-01'),
	('2051-06-26', '2051-06-01'),
	('2051-06-27', '2051-06-01'),
	('2051-06-28', '2051-06-01'),
	('2051-06-29', '2051-06-01'),
	('2051-06-30', '2051-06-01'),
	('2051-07-01', '2051-07-01'),
	('2051-07-02', '2051-07-01'),
	('2051-07-03', '2051-07-01'),
	('2051-07-04', '2051-07-01'),
	('2051-07-05', '2051-07-01'),
	('2051-07-06', '2051-07-01'),
	('2051-07-07', '2051-07-01'),
	('2051-07-08', '2051-07-01'),
	('2051-07-09', '2051-07-01'),
	('2051-07-10', '2051-07-01'),
	('2051-07-11', '2051-07-01'),
	('2051-07-12', '2051-07-01'),
	('2051-07-13', '2051-07-01'),
	('2051-07-14', '2051-07-01'),
	('2051-07-15', '2051-07-01'),
	('2051-07-16', '2051-07-01'),
	('2051-07-17', '2051-07-01'),
	('2051-07-18', '2051-07-01'),
	('2051-07-19', '2051-07-01'),
	('2051-07-20', '2051-07-01'),
	('2051-07-21', '2051-07-01'),
	('2051-07-22', '2051-07-01'),
	('2051-07-23', '2051-07-01'),
	('2051-07-24', '2051-07-01'),
	('2051-07-25', '2051-07-01'),
	('2051-07-26', '2051-07-01'),
	('2051-07-27', '2051-07-01'),
	('2051-07-28', '2051-07-01'),
	('2051-07-29', '2051-07-01'),
	('2051-07-30', '2051-07-01'),
	('2051-07-31', '2051-07-01'),
	('2051-08-01', '2051-08-01'),
	('2051-08-02', '2051-08-01'),
	('2051-08-03', '2051-08-01'),
	('2051-08-04', '2051-08-01'),
	('2051-08-05', '2051-08-01'),
	('2051-08-06', '2051-08-01'),
	('2051-08-07', '2051-08-01'),
	('2051-08-08', '2051-08-01'),
	('2051-08-09', '2051-08-01'),
	('2051-08-10', '2051-08-01'),
	('2051-08-11', '2051-08-01'),
	('2051-08-12', '2051-08-01'),
	('2051-08-13', '2051-08-01'),
	('2051-08-14', '2051-08-01'),
	('2051-08-15', '2051-08-01'),
	('2051-08-16', '2051-08-01'),
	('2051-08-17', '2051-08-01'),
	('2051-08-18', '2051-08-01'),
	('2051-08-19', '2051-08-01'),
	('2051-08-20', '2051-08-01'),
	('2051-08-21', '2051-08-01'),
	('2051-08-22', '2051-08-01'),
	('2051-08-23', '2051-08-01'),
	('2051-08-24', '2051-08-01'),
	('2051-08-25', '2051-08-01'),
	('2051-08-26', '2051-08-01'),
	('2051-08-27', '2051-08-01'),
	('2051-08-28', '2051-08-01'),
	('2051-08-29', '2051-08-01'),
	('2051-08-30', '2051-08-01'),
	('2051-08-31', '2051-08-01'),
	('2051-09-01', '2051-09-01'),
	('2051-09-02', '2051-09-01'),
	('2051-09-03', '2051-09-01'),
	('2051-09-04', '2051-09-01'),
	('2051-09-05', '2051-09-01'),
	('2051-09-06', '2051-09-01'),
	('2051-09-07', '2051-09-01'),
	('2051-09-08', '2051-09-01'),
	('2051-09-09', '2051-09-01'),
	('2051-09-10', '2051-09-01'),
	('2051-09-11', '2051-09-01'),
	('2051-09-12', '2051-09-01'),
	('2051-09-13', '2051-09-01'),
	('2051-09-14', '2051-09-01'),
	('2051-09-15', '2051-09-01'),
	('2051-09-16', '2051-09-01'),
	('2051-09-17', '2051-09-01'),
	('2051-09-18', '2051-09-01'),
	('2051-09-19', '2051-09-01'),
	('2051-09-20', '2051-09-01'),
	('2051-09-21', '2051-09-01'),
	('2051-09-22', '2051-09-01'),
	('2051-09-23', '2051-09-01'),
	('2051-09-24', '2051-09-01'),
	('2051-09-25', '2051-09-01'),
	('2051-09-26', '2051-09-01'),
	('2051-09-27', '2051-09-01'),
	('2051-09-28', '2051-09-01'),
	('2051-09-29', '2051-09-01'),
	('2051-09-30', '2051-09-01'),
	('2051-10-01', '2051-10-01'),
	('2051-10-02', '2051-10-01'),
	('2051-10-03', '2051-10-01'),
	('2051-10-04', '2051-10-01'),
	('2051-10-05', '2051-10-01'),
	('2051-10-06', '2051-10-01'),
	('2051-10-07', '2051-10-01'),
	('2051-10-08', '2051-10-01'),
	('2051-10-09', '2051-10-01'),
	('2051-10-10', '2051-10-01'),
	('2051-10-11', '2051-10-01'),
	('2051-10-12', '2051-10-01'),
	('2051-10-13', '2051-10-01'),
	('2051-10-14', '2051-10-01'),
	('2051-10-15', '2051-10-01'),
	('2051-10-16', '2051-10-01'),
	('2051-10-17', '2051-10-01'),
	('2051-10-18', '2051-10-01'),
	('2051-10-19', '2051-10-01'),
	('2051-10-20', '2051-10-01'),
	('2051-10-21', '2051-10-01'),
	('2051-10-22', '2051-10-01'),
	('2051-10-23', '2051-10-01'),
	('2051-10-24', '2051-10-01'),
	('2051-10-25', '2051-10-01'),
	('2051-10-26', '2051-10-01'),
	('2051-10-27', '2051-10-01'),
	('2051-10-28', '2051-10-01'),
	('2051-10-29', '2051-10-01'),
	('2051-10-30', '2051-10-01'),
	('2051-10-31', '2051-10-01'),
	('2051-11-01', '2051-11-01'),
	('2051-11-02', '2051-11-01'),
	('2051-11-03', '2051-11-01'),
	('2051-11-04', '2051-11-01'),
	('2051-11-05', '2051-11-01'),
	('2051-11-06', '2051-11-01'),
	('2051-11-07', '2051-11-01'),
	('2051-11-08', '2051-11-01'),
	('2051-11-09', '2051-11-01'),
	('2051-11-10', '2051-11-01'),
	('2051-11-11', '2051-11-01'),
	('2051-11-12', '2051-11-01'),
	('2051-11-13', '2051-11-01'),
	('2051-11-14', '2051-11-01'),
	('2051-11-15', '2051-11-01'),
	('2051-11-16', '2051-11-01'),
	('2051-11-17', '2051-11-01'),
	('2051-11-18', '2051-11-01'),
	('2051-11-19', '2051-11-01'),
	('2051-11-20', '2051-11-01'),
	('2051-11-21', '2051-11-01'),
	('2051-11-22', '2051-11-01'),
	('2051-11-23', '2051-11-01'),
	('2051-11-24', '2051-11-01'),
	('2051-11-25', '2051-11-01'),
	('2051-11-26', '2051-11-01'),
	('2051-11-27', '2051-11-01'),
	('2051-11-28', '2051-11-01'),
	('2051-11-29', '2051-11-01'),
	('2051-11-30', '2051-11-01'),
	('2051-12-01', '2051-12-01'),
	('2051-12-02', '2051-12-01'),
	('2051-12-03', '2051-12-01'),
	('2051-12-04', '2051-12-01'),
	('2051-12-05', '2051-12-01'),
	('2051-12-06', '2051-12-01'),
	('2051-12-07', '2051-12-01'),
	('2051-12-08', '2051-12-01'),
	('2051-12-09', '2051-12-01'),
	('2051-12-10', '2051-12-01'),
	('2051-12-11', '2051-12-01'),
	('2051-12-12', '2051-12-01'),
	('2051-12-13', '2051-12-01'),
	('2051-12-14', '2051-12-01'),
	('2051-12-15', '2051-12-01'),
	('2051-12-16', '2051-12-01'),
	('2051-12-17', '2051-12-01'),
	('2051-12-18', '2051-12-01'),
	('2051-12-19', '2051-12-01'),
	('2051-12-20', '2051-12-01'),
	('2051-12-21', '2051-12-01'),
	('2051-12-22', '2051-12-01'),
	('2051-12-23', '2051-12-01'),
	('2051-12-24', '2051-12-01'),
	('2051-12-25', '2051-12-01'),
	('2051-12-26', '2051-12-01'),
	('2051-12-27', '2051-12-01'),
	('2051-12-28', '2051-12-01'),
	('2051-12-29', '2051-12-01'),
	('2051-12-30', '2051-12-01'),
	('2051-12-31', '2051-12-01'),
	('2052-01-01', '2052-01-01'),
	('2052-01-02', '2052-01-01'),
	('2052-01-03', '2052-01-01'),
	('2052-01-04', '2052-01-01'),
	('2052-01-05', '2052-01-01'),
	('2052-01-06', '2052-01-01'),
	('2052-01-07', '2052-01-01'),
	('2052-01-08', '2052-01-01'),
	('2052-01-09', '2052-01-01'),
	('2052-01-10', '2052-01-01'),
	('2052-01-11', '2052-01-01'),
	('2052-01-12', '2052-01-01'),
	('2052-01-13', '2052-01-01'),
	('2052-01-14', '2052-01-01'),
	('2052-01-15', '2052-01-01'),
	('2052-01-16', '2052-01-01'),
	('2052-01-17', '2052-01-01'),
	('2052-01-18', '2052-01-01'),
	('2052-01-19', '2052-01-01'),
	('2052-01-20', '2052-01-01'),
	('2052-01-21', '2052-01-01'),
	('2052-01-22', '2052-01-01'),
	('2052-01-23', '2052-01-01'),
	('2052-01-24', '2052-01-01'),
	('2052-01-25', '2052-01-01'),
	('2052-01-26', '2052-01-01'),
	('2052-01-27', '2052-01-01'),
	('2052-01-28', '2052-01-01'),
	('2052-01-29', '2052-01-01'),
	('2052-01-30', '2052-01-01'),
	('2052-01-31', '2052-01-01'),
	('2052-02-01', '2052-02-01'),
	('2052-02-02', '2052-02-01'),
	('2052-02-03', '2052-02-01'),
	('2052-02-04', '2052-02-01'),
	('2052-02-05', '2052-02-01'),
	('2052-02-06', '2052-02-01'),
	('2052-02-07', '2052-02-01'),
	('2052-02-08', '2052-02-01'),
	('2052-02-09', '2052-02-01'),
	('2052-02-10', '2052-02-01'),
	('2052-02-11', '2052-02-01'),
	('2052-02-12', '2052-02-01'),
	('2052-02-13', '2052-02-01'),
	('2052-02-14', '2052-02-01'),
	('2052-02-15', '2052-02-01'),
	('2052-02-16', '2052-02-01'),
	('2052-02-17', '2052-02-01'),
	('2052-02-18', '2052-02-01'),
	('2052-02-19', '2052-02-01'),
	('2052-02-20', '2052-02-01'),
	('2052-02-21', '2052-02-01'),
	('2052-02-22', '2052-02-01'),
	('2052-02-23', '2052-02-01'),
	('2052-02-24', '2052-02-01'),
	('2052-02-25', '2052-02-01'),
	('2052-02-26', '2052-02-01'),
	('2052-02-27', '2052-02-01'),
	('2052-02-28', '2052-02-01'),
	('2052-02-29', '2052-02-01'),
	('2052-03-01', '2052-03-01'),
	('2052-03-02', '2052-03-01'),
	('2052-03-03', '2052-03-01'),
	('2052-03-04', '2052-03-01'),
	('2052-03-05', '2052-03-01'),
	('2052-03-06', '2052-03-01'),
	('2052-03-07', '2052-03-01'),
	('2052-03-08', '2052-03-01'),
	('2052-03-09', '2052-03-01'),
	('2052-03-10', '2052-03-01'),
	('2052-03-11', '2052-03-01'),
	('2052-03-12', '2052-03-01'),
	('2052-03-13', '2052-03-01'),
	('2052-03-14', '2052-03-01'),
	('2052-03-15', '2052-03-01'),
	('2052-03-16', '2052-03-01'),
	('2052-03-17', '2052-03-01'),
	('2052-03-18', '2052-03-01'),
	('2052-03-19', '2052-03-01'),
	('2052-03-20', '2052-03-01'),
	('2052-03-21', '2052-03-01'),
	('2052-03-22', '2052-03-01'),
	('2052-03-23', '2052-03-01'),
	('2052-03-24', '2052-03-01'),
	('2052-03-25', '2052-03-01'),
	('2052-03-26', '2052-03-01'),
	('2052-03-27', '2052-03-01'),
	('2052-03-28', '2052-03-01'),
	('2052-03-29', '2052-03-01'),
	('2052-03-30', '2052-03-01'),
	('2052-03-31', '2052-03-01'),
	('2052-04-01', '2052-04-01'),
	('2052-04-02', '2052-04-01'),
	('2052-04-03', '2052-04-01'),
	('2052-04-04', '2052-04-01'),
	('2052-04-05', '2052-04-01'),
	('2052-04-06', '2052-04-01'),
	('2052-04-07', '2052-04-01'),
	('2052-04-08', '2052-04-01'),
	('2052-04-09', '2052-04-01'),
	('2052-04-10', '2052-04-01'),
	('2052-04-11', '2052-04-01'),
	('2052-04-12', '2052-04-01'),
	('2052-04-13', '2052-04-01'),
	('2052-04-14', '2052-04-01'),
	('2052-04-15', '2052-04-01'),
	('2052-04-16', '2052-04-01'),
	('2052-04-17', '2052-04-01'),
	('2052-04-18', '2052-04-01'),
	('2052-04-19', '2052-04-01'),
	('2052-04-20', '2052-04-01'),
	('2052-04-21', '2052-04-01'),
	('2052-04-22', '2052-04-01'),
	('2052-04-23', '2052-04-01'),
	('2052-04-24', '2052-04-01'),
	('2052-04-25', '2052-04-01'),
	('2052-04-26', '2052-04-01'),
	('2052-04-27', '2052-04-01'),
	('2052-04-28', '2052-04-01'),
	('2052-04-29', '2052-04-01'),
	('2052-04-30', '2052-04-01'),
	('2052-05-01', '2052-05-01'),
	('2052-05-02', '2052-05-01'),
	('2052-05-03', '2052-05-01'),
	('2052-05-04', '2052-05-01'),
	('2052-05-05', '2052-05-01'),
	('2052-05-06', '2052-05-01'),
	('2052-05-07', '2052-05-01'),
	('2052-05-08', '2052-05-01'),
	('2052-05-09', '2052-05-01'),
	('2052-05-10', '2052-05-01'),
	('2052-05-11', '2052-05-01'),
	('2052-05-12', '2052-05-01'),
	('2052-05-13', '2052-05-01'),
	('2052-05-14', '2052-05-01'),
	('2052-05-15', '2052-05-01'),
	('2052-05-16', '2052-05-01'),
	('2052-05-17', '2052-05-01'),
	('2052-05-18', '2052-05-01'),
	('2052-05-19', '2052-05-01'),
	('2052-05-20', '2052-05-01'),
	('2052-05-21', '2052-05-01'),
	('2052-05-22', '2052-05-01'),
	('2052-05-23', '2052-05-01'),
	('2052-05-24', '2052-05-01'),
	('2052-05-25', '2052-05-01'),
	('2052-05-26', '2052-05-01'),
	('2052-05-27', '2052-05-01'),
	('2052-05-28', '2052-05-01'),
	('2052-05-29', '2052-05-01'),
	('2052-05-30', '2052-05-01'),
	('2052-05-31', '2052-05-01'),
	('2052-06-01', '2052-06-01'),
	('2052-06-02', '2052-06-01'),
	('2052-06-03', '2052-06-01'),
	('2052-06-04', '2052-06-01'),
	('2052-06-05', '2052-06-01'),
	('2052-06-06', '2052-06-01'),
	('2052-06-07', '2052-06-01'),
	('2052-06-08', '2052-06-01'),
	('2052-06-09', '2052-06-01'),
	('2052-06-10', '2052-06-01'),
	('2052-06-11', '2052-06-01'),
	('2052-06-12', '2052-06-01'),
	('2052-06-13', '2052-06-01'),
	('2052-06-14', '2052-06-01'),
	('2052-06-15', '2052-06-01'),
	('2052-06-16', '2052-06-01'),
	('2052-06-17', '2052-06-01'),
	('2052-06-18', '2052-06-01'),
	('2052-06-19', '2052-06-01'),
	('2052-06-20', '2052-06-01'),
	('2052-06-21', '2052-06-01'),
	('2052-06-22', '2052-06-01'),
	('2052-06-23', '2052-06-01'),
	('2052-06-24', '2052-06-01'),
	('2052-06-25', '2052-06-01'),
	('2052-06-26', '2052-06-01'),
	('2052-06-27', '2052-06-01'),
	('2052-06-28', '2052-06-01'),
	('2052-06-29', '2052-06-01'),
	('2052-06-30', '2052-06-01'),
	('2052-07-01', '2052-07-01'),
	('2052-07-02', '2052-07-01'),
	('2052-07-03', '2052-07-01'),
	('2052-07-04', '2052-07-01'),
	('2052-07-05', '2052-07-01'),
	('2052-07-06', '2052-07-01'),
	('2052-07-07', '2052-07-01'),
	('2052-07-08', '2052-07-01'),
	('2052-07-09', '2052-07-01'),
	('2052-07-10', '2052-07-01'),
	('2052-07-11', '2052-07-01'),
	('2052-07-12', '2052-07-01'),
	('2052-07-13', '2052-07-01'),
	('2052-07-14', '2052-07-01'),
	('2052-07-15', '2052-07-01'),
	('2052-07-16', '2052-07-01'),
	('2052-07-17', '2052-07-01'),
	('2052-07-18', '2052-07-01'),
	('2052-07-19', '2052-07-01'),
	('2052-07-20', '2052-07-01'),
	('2052-07-21', '2052-07-01'),
	('2052-07-22', '2052-07-01'),
	('2052-07-23', '2052-07-01'),
	('2052-07-24', '2052-07-01'),
	('2052-07-25', '2052-07-01'),
	('2052-07-26', '2052-07-01'),
	('2052-07-27', '2052-07-01'),
	('2052-07-28', '2052-07-01'),
	('2052-07-29', '2052-07-01'),
	('2052-07-30', '2052-07-01'),
	('2052-07-31', '2052-07-01'),
	('2052-08-01', '2052-08-01'),
	('2052-08-02', '2052-08-01'),
	('2052-08-03', '2052-08-01'),
	('2052-08-04', '2052-08-01'),
	('2052-08-05', '2052-08-01'),
	('2052-08-06', '2052-08-01'),
	('2052-08-07', '2052-08-01'),
	('2052-08-08', '2052-08-01'),
	('2052-08-09', '2052-08-01'),
	('2052-08-10', '2052-08-01'),
	('2052-08-11', '2052-08-01'),
	('2052-08-12', '2052-08-01'),
	('2052-08-13', '2052-08-01'),
	('2052-08-14', '2052-08-01'),
	('2052-08-15', '2052-08-01'),
	('2052-08-16', '2052-08-01'),
	('2052-08-17', '2052-08-01'),
	('2052-08-18', '2052-08-01'),
	('2052-08-19', '2052-08-01'),
	('2052-08-20', '2052-08-01'),
	('2052-08-21', '2052-08-01'),
	('2052-08-22', '2052-08-01'),
	('2052-08-23', '2052-08-01'),
	('2052-08-24', '2052-08-01'),
	('2052-08-25', '2052-08-01'),
	('2052-08-26', '2052-08-01'),
	('2052-08-27', '2052-08-01'),
	('2052-08-28', '2052-08-01'),
	('2052-08-29', '2052-08-01'),
	('2052-08-30', '2052-08-01'),
	('2052-08-31', '2052-08-01'),
	('2052-09-01', '2052-09-01'),
	('2052-09-02', '2052-09-01'),
	('2052-09-03', '2052-09-01'),
	('2052-09-04', '2052-09-01'),
	('2052-09-05', '2052-09-01'),
	('2052-09-06', '2052-09-01'),
	('2052-09-07', '2052-09-01'),
	('2052-09-08', '2052-09-01'),
	('2052-09-09', '2052-09-01'),
	('2052-09-10', '2052-09-01'),
	('2052-09-11', '2052-09-01'),
	('2052-09-12', '2052-09-01'),
	('2052-09-13', '2052-09-01'),
	('2052-09-14', '2052-09-01'),
	('2052-09-15', '2052-09-01'),
	('2052-09-16', '2052-09-01'),
	('2052-09-17', '2052-09-01'),
	('2052-09-18', '2052-09-01'),
	('2052-09-19', '2052-09-01'),
	('2052-09-20', '2052-09-01'),
	('2052-09-21', '2052-09-01'),
	('2052-09-22', '2052-09-01'),
	('2052-09-23', '2052-09-01'),
	('2052-09-24', '2052-09-01'),
	('2052-09-25', '2052-09-01'),
	('2052-09-26', '2052-09-01'),
	('2052-09-27', '2052-09-01'),
	('2052-09-28', '2052-09-01'),
	('2052-09-29', '2052-09-01'),
	('2052-09-30', '2052-09-01'),
	('2052-10-01', '2052-10-01'),
	('2052-10-02', '2052-10-01'),
	('2052-10-03', '2052-10-01'),
	('2052-10-04', '2052-10-01'),
	('2052-10-05', '2052-10-01'),
	('2052-10-06', '2052-10-01'),
	('2052-10-07', '2052-10-01'),
	('2052-10-08', '2052-10-01'),
	('2052-10-09', '2052-10-01'),
	('2052-10-10', '2052-10-01'),
	('2052-10-11', '2052-10-01'),
	('2052-10-12', '2052-10-01'),
	('2052-10-13', '2052-10-01'),
	('2052-10-14', '2052-10-01'),
	('2052-10-15', '2052-10-01'),
	('2052-10-16', '2052-10-01'),
	('2052-10-17', '2052-10-01'),
	('2052-10-18', '2052-10-01'),
	('2052-10-19', '2052-10-01'),
	('2052-10-20', '2052-10-01'),
	('2052-10-21', '2052-10-01'),
	('2052-10-22', '2052-10-01'),
	('2052-10-23', '2052-10-01'),
	('2052-10-24', '2052-10-01'),
	('2052-10-25', '2052-10-01'),
	('2052-10-26', '2052-10-01'),
	('2052-10-27', '2052-10-01'),
	('2052-10-28', '2052-10-01'),
	('2052-10-29', '2052-10-01'),
	('2052-10-30', '2052-10-01'),
	('2052-10-31', '2052-10-01'),
	('2052-11-01', '2052-11-01'),
	('2052-11-02', '2052-11-01'),
	('2052-11-03', '2052-11-01'),
	('2052-11-04', '2052-11-01'),
	('2052-11-05', '2052-11-01'),
	('2052-11-06', '2052-11-01'),
	('2052-11-07', '2052-11-01'),
	('2052-11-08', '2052-11-01'),
	('2052-11-09', '2052-11-01'),
	('2052-11-10', '2052-11-01'),
	('2052-11-11', '2052-11-01'),
	('2052-11-12', '2052-11-01'),
	('2052-11-13', '2052-11-01'),
	('2052-11-14', '2052-11-01'),
	('2052-11-15', '2052-11-01'),
	('2052-11-16', '2052-11-01'),
	('2052-11-17', '2052-11-01'),
	('2052-11-18', '2052-11-01'),
	('2052-11-19', '2052-11-01'),
	('2052-11-20', '2052-11-01'),
	('2052-11-21', '2052-11-01'),
	('2052-11-22', '2052-11-01'),
	('2052-11-23', '2052-11-01'),
	('2052-11-24', '2052-11-01'),
	('2052-11-25', '2052-11-01'),
	('2052-11-26', '2052-11-01'),
	('2052-11-27', '2052-11-01'),
	('2052-11-28', '2052-11-01'),
	('2052-11-29', '2052-11-01'),
	('2052-11-30', '2052-11-01'),
	('2052-12-01', '2052-12-01'),
	('2052-12-02', '2052-12-01'),
	('2052-12-03', '2052-12-01'),
	('2052-12-04', '2052-12-01'),
	('2052-12-05', '2052-12-01'),
	('2052-12-06', '2052-12-01'),
	('2052-12-07', '2052-12-01'),
	('2052-12-08', '2052-12-01'),
	('2052-12-09', '2052-12-01'),
	('2052-12-10', '2052-12-01'),
	('2052-12-11', '2052-12-01'),
	('2052-12-12', '2052-12-01'),
	('2052-12-13', '2052-12-01'),
	('2052-12-14', '2052-12-01'),
	('2052-12-15', '2052-12-01'),
	('2052-12-16', '2052-12-01'),
	('2052-12-17', '2052-12-01'),
	('2052-12-18', '2052-12-01'),
	('2052-12-19', '2052-12-01'),
	('2052-12-20', '2052-12-01'),
	('2052-12-21', '2052-12-01'),
	('2052-12-22', '2052-12-01'),
	('2052-12-23', '2052-12-01'),
	('2052-12-24', '2052-12-01'),
	('2052-12-25', '2052-12-01'),
	('2052-12-26', '2052-12-01'),
	('2052-12-27', '2052-12-01'),
	('2052-12-28', '2052-12-01'),
	('2052-12-29', '2052-12-01'),
	('2052-12-30', '2052-12-01'),
	('2052-12-31', '2052-12-01'),
	('2053-01-01', '2053-01-01'),
	('2053-01-02', '2053-01-01'),
	('2053-01-03', '2053-01-01'),
	('2053-01-04', '2053-01-01'),
	('2053-01-05', '2053-01-01'),
	('2053-01-06', '2053-01-01'),
	('2053-01-07', '2053-01-01'),
	('2053-01-08', '2053-01-01'),
	('2053-01-09', '2053-01-01'),
	('2053-01-10', '2053-01-01'),
	('2053-01-11', '2053-01-01'),
	('2053-01-12', '2053-01-01'),
	('2053-01-13', '2053-01-01'),
	('2053-01-14', '2053-01-01'),
	('2053-01-15', '2053-01-01'),
	('2053-01-16', '2053-01-01'),
	('2053-01-17', '2053-01-01'),
	('2053-01-18', '2053-01-01'),
	('2053-01-19', '2053-01-01'),
	('2053-01-20', '2053-01-01'),
	('2053-01-21', '2053-01-01'),
	('2053-01-22', '2053-01-01'),
	('2053-01-23', '2053-01-01'),
	('2053-01-24', '2053-01-01'),
	('2053-01-25', '2053-01-01'),
	('2053-01-26', '2053-01-01'),
	('2053-01-27', '2053-01-01'),
	('2053-01-28', '2053-01-01'),
	('2053-01-29', '2053-01-01'),
	('2053-01-30', '2053-01-01'),
	('2053-01-31', '2053-01-01'),
	('2053-02-01', '2053-02-01'),
	('2053-02-02', '2053-02-01'),
	('2053-02-03', '2053-02-01'),
	('2053-02-04', '2053-02-01'),
	('2053-02-05', '2053-02-01'),
	('2053-02-06', '2053-02-01'),
	('2053-02-07', '2053-02-01'),
	('2053-02-08', '2053-02-01'),
	('2053-02-09', '2053-02-01'),
	('2053-02-10', '2053-02-01'),
	('2053-02-11', '2053-02-01'),
	('2053-02-12', '2053-02-01'),
	('2053-02-13', '2053-02-01'),
	('2053-02-14', '2053-02-01'),
	('2053-02-15', '2053-02-01'),
	('2053-02-16', '2053-02-01'),
	('2053-02-17', '2053-02-01'),
	('2053-02-18', '2053-02-01'),
	('2053-02-19', '2053-02-01'),
	('2053-02-20', '2053-02-01'),
	('2053-02-21', '2053-02-01'),
	('2053-02-22', '2053-02-01'),
	('2053-02-23', '2053-02-01'),
	('2053-02-24', '2053-02-01'),
	('2053-02-25', '2053-02-01'),
	('2053-02-26', '2053-02-01'),
	('2053-02-27', '2053-02-01'),
	('2053-02-28', '2053-02-01'),
	('2053-03-01', '2053-03-01'),
	('2053-03-02', '2053-03-01'),
	('2053-03-03', '2053-03-01'),
	('2053-03-04', '2053-03-01'),
	('2053-03-05', '2053-03-01'),
	('2053-03-06', '2053-03-01'),
	('2053-03-07', '2053-03-01'),
	('2053-03-08', '2053-03-01'),
	('2053-03-09', '2053-03-01'),
	('2053-03-10', '2053-03-01'),
	('2053-03-11', '2053-03-01'),
	('2053-03-12', '2053-03-01'),
	('2053-03-13', '2053-03-01'),
	('2053-03-14', '2053-03-01'),
	('2053-03-15', '2053-03-01'),
	('2053-03-16', '2053-03-01'),
	('2053-03-17', '2053-03-01'),
	('2053-03-18', '2053-03-01'),
	('2053-03-19', '2053-03-01'),
	('2053-03-20', '2053-03-01'),
	('2053-03-21', '2053-03-01'),
	('2053-03-22', '2053-03-01'),
	('2053-03-23', '2053-03-01'),
	('2053-03-24', '2053-03-01'),
	('2053-03-25', '2053-03-01'),
	('2053-03-26', '2053-03-01'),
	('2053-03-27', '2053-03-01'),
	('2053-03-28', '2053-03-01'),
	('2053-03-29', '2053-03-01'),
	('2053-03-30', '2053-03-01'),
	('2053-03-31', '2053-03-01'),
	('2053-04-01', '2053-04-01'),
	('2053-04-02', '2053-04-01'),
	('2053-04-03', '2053-04-01'),
	('2053-04-04', '2053-04-01'),
	('2053-04-05', '2053-04-01'),
	('2053-04-06', '2053-04-01'),
	('2053-04-07', '2053-04-01'),
	('2053-04-08', '2053-04-01'),
	('2053-04-09', '2053-04-01'),
	('2053-04-10', '2053-04-01'),
	('2053-04-11', '2053-04-01'),
	('2053-04-12', '2053-04-01'),
	('2053-04-13', '2053-04-01'),
	('2053-04-14', '2053-04-01'),
	('2053-04-15', '2053-04-01'),
	('2053-04-16', '2053-04-01'),
	('2053-04-17', '2053-04-01'),
	('2053-04-18', '2053-04-01'),
	('2053-04-19', '2053-04-01'),
	('2053-04-20', '2053-04-01'),
	('2053-04-21', '2053-04-01'),
	('2053-04-22', '2053-04-01'),
	('2053-04-23', '2053-04-01'),
	('2053-04-24', '2053-04-01'),
	('2053-04-25', '2053-04-01'),
	('2053-04-26', '2053-04-01'),
	('2053-04-27', '2053-04-01'),
	('2053-04-28', '2053-04-01'),
	('2053-04-29', '2053-04-01'),
	('2053-04-30', '2053-04-01'),
	('2053-05-01', '2053-05-01'),
	('2053-05-02', '2053-05-01'),
	('2053-05-03', '2053-05-01'),
	('2053-05-04', '2053-05-01'),
	('2053-05-05', '2053-05-01'),
	('2053-05-06', '2053-05-01'),
	('2053-05-07', '2053-05-01'),
	('2053-05-08', '2053-05-01'),
	('2053-05-09', '2053-05-01'),
	('2053-05-10', '2053-05-01'),
	('2053-05-11', '2053-05-01'),
	('2053-05-12', '2053-05-01'),
	('2053-05-13', '2053-05-01'),
	('2053-05-14', '2053-05-01'),
	('2053-05-15', '2053-05-01'),
	('2053-05-16', '2053-05-01'),
	('2053-05-17', '2053-05-01'),
	('2053-05-18', '2053-05-01'),
	('2053-05-19', '2053-05-01'),
	('2053-05-20', '2053-05-01'),
	('2053-05-21', '2053-05-01'),
	('2053-05-22', '2053-05-01'),
	('2053-05-23', '2053-05-01'),
	('2053-05-24', '2053-05-01'),
	('2053-05-25', '2053-05-01'),
	('2053-05-26', '2053-05-01'),
	('2053-05-27', '2053-05-01'),
	('2053-05-28', '2053-05-01'),
	('2053-05-29', '2053-05-01'),
	('2053-05-30', '2053-05-01'),
	('2053-05-31', '2053-05-01'),
	('2053-06-01', '2053-06-01'),
	('2053-06-02', '2053-06-01'),
	('2053-06-03', '2053-06-01'),
	('2053-06-04', '2053-06-01'),
	('2053-06-05', '2053-06-01'),
	('2053-06-06', '2053-06-01'),
	('2053-06-07', '2053-06-01'),
	('2053-06-08', '2053-06-01'),
	('2053-06-09', '2053-06-01'),
	('2053-06-10', '2053-06-01'),
	('2053-06-11', '2053-06-01'),
	('2053-06-12', '2053-06-01'),
	('2053-06-13', '2053-06-01'),
	('2053-06-14', '2053-06-01'),
	('2053-06-15', '2053-06-01'),
	('2053-06-16', '2053-06-01'),
	('2053-06-17', '2053-06-01'),
	('2053-06-18', '2053-06-01'),
	('2053-06-19', '2053-06-01'),
	('2053-06-20', '2053-06-01'),
	('2053-06-21', '2053-06-01'),
	('2053-06-22', '2053-06-01'),
	('2053-06-23', '2053-06-01'),
	('2053-06-24', '2053-06-01'),
	('2053-06-25', '2053-06-01'),
	('2053-06-26', '2053-06-01'),
	('2053-06-27', '2053-06-01'),
	('2053-06-28', '2053-06-01'),
	('2053-06-29', '2053-06-01'),
	('2053-06-30', '2053-06-01'),
	('2053-07-01', '2053-07-01'),
	('2053-07-02', '2053-07-01'),
	('2053-07-03', '2053-07-01'),
	('2053-07-04', '2053-07-01'),
	('2053-07-05', '2053-07-01'),
	('2053-07-06', '2053-07-01'),
	('2053-07-07', '2053-07-01'),
	('2053-07-08', '2053-07-01'),
	('2053-07-09', '2053-07-01'),
	('2053-07-10', '2053-07-01'),
	('2053-07-11', '2053-07-01'),
	('2053-07-12', '2053-07-01'),
	('2053-07-13', '2053-07-01'),
	('2053-07-14', '2053-07-01'),
	('2053-07-15', '2053-07-01'),
	('2053-07-16', '2053-07-01'),
	('2053-07-17', '2053-07-01'),
	('2053-07-18', '2053-07-01'),
	('2053-07-19', '2053-07-01'),
	('2053-07-20', '2053-07-01'),
	('2053-07-21', '2053-07-01'),
	('2053-07-22', '2053-07-01'),
	('2053-07-23', '2053-07-01'),
	('2053-07-24', '2053-07-01'),
	('2053-07-25', '2053-07-01'),
	('2053-07-26', '2053-07-01'),
	('2053-07-27', '2053-07-01'),
	('2053-07-28', '2053-07-01'),
	('2053-07-29', '2053-07-01'),
	('2053-07-30', '2053-07-01'),
	('2053-07-31', '2053-07-01'),
	('2053-08-01', '2053-08-01'),
	('2053-08-02', '2053-08-01'),
	('2053-08-03', '2053-08-01'),
	('2053-08-04', '2053-08-01'),
	('2053-08-05', '2053-08-01'),
	('2053-08-06', '2053-08-01'),
	('2053-08-07', '2053-08-01'),
	('2053-08-08', '2053-08-01'),
	('2053-08-09', '2053-08-01'),
	('2053-08-10', '2053-08-01'),
	('2053-08-11', '2053-08-01'),
	('2053-08-12', '2053-08-01'),
	('2053-08-13', '2053-08-01'),
	('2053-08-14', '2053-08-01'),
	('2053-08-15', '2053-08-01'),
	('2053-08-16', '2053-08-01'),
	('2053-08-17', '2053-08-01'),
	('2053-08-18', '2053-08-01'),
	('2053-08-19', '2053-08-01'),
	('2053-08-20', '2053-08-01'),
	('2053-08-21', '2053-08-01'),
	('2053-08-22', '2053-08-01'),
	('2053-08-23', '2053-08-01'),
	('2053-08-24', '2053-08-01'),
	('2053-08-25', '2053-08-01'),
	('2053-08-26', '2053-08-01'),
	('2053-08-27', '2053-08-01'),
	('2053-08-28', '2053-08-01'),
	('2053-08-29', '2053-08-01'),
	('2053-08-30', '2053-08-01'),
	('2053-08-31', '2053-08-01'),
	('2053-09-01', '2053-09-01'),
	('2053-09-02', '2053-09-01'),
	('2053-09-03', '2053-09-01'),
	('2053-09-04', '2053-09-01'),
	('2053-09-05', '2053-09-01'),
	('2053-09-06', '2053-09-01'),
	('2053-09-07', '2053-09-01'),
	('2053-09-08', '2053-09-01'),
	('2053-09-09', '2053-09-01'),
	('2053-09-10', '2053-09-01'),
	('2053-09-11', '2053-09-01'),
	('2053-09-12', '2053-09-01'),
	('2053-09-13', '2053-09-01'),
	('2053-09-14', '2053-09-01'),
	('2053-09-15', '2053-09-01'),
	('2053-09-16', '2053-09-01'),
	('2053-09-17', '2053-09-01'),
	('2053-09-18', '2053-09-01'),
	('2053-09-19', '2053-09-01'),
	('2053-09-20', '2053-09-01'),
	('2053-09-21', '2053-09-01'),
	('2053-09-22', '2053-09-01'),
	('2053-09-23', '2053-09-01'),
	('2053-09-24', '2053-09-01'),
	('2053-09-25', '2053-09-01'),
	('2053-09-26', '2053-09-01'),
	('2053-09-27', '2053-09-01'),
	('2053-09-28', '2053-09-01'),
	('2053-09-29', '2053-09-01'),
	('2053-09-30', '2053-09-01'),
	('2053-10-01', '2053-10-01'),
	('2053-10-02', '2053-10-01'),
	('2053-10-03', '2053-10-01'),
	('2053-10-04', '2053-10-01'),
	('2053-10-05', '2053-10-01'),
	('2053-10-06', '2053-10-01'),
	('2053-10-07', '2053-10-01'),
	('2053-10-08', '2053-10-01'),
	('2053-10-09', '2053-10-01'),
	('2053-10-10', '2053-10-01'),
	('2053-10-11', '2053-10-01'),
	('2053-10-12', '2053-10-01'),
	('2053-10-13', '2053-10-01'),
	('2053-10-14', '2053-10-01'),
	('2053-10-15', '2053-10-01'),
	('2053-10-16', '2053-10-01'),
	('2053-10-17', '2053-10-01'),
	('2053-10-18', '2053-10-01'),
	('2053-10-19', '2053-10-01'),
	('2053-10-20', '2053-10-01'),
	('2053-10-21', '2053-10-01'),
	('2053-10-22', '2053-10-01'),
	('2053-10-23', '2053-10-01'),
	('2053-10-24', '2053-10-01'),
	('2053-10-25', '2053-10-01'),
	('2053-10-26', '2053-10-01'),
	('2053-10-27', '2053-10-01'),
	('2053-10-28', '2053-10-01'),
	('2053-10-29', '2053-10-01'),
	('2053-10-30', '2053-10-01'),
	('2053-10-31', '2053-10-01'),
	('2053-11-01', '2053-11-01'),
	('2053-11-02', '2053-11-01'),
	('2053-11-03', '2053-11-01'),
	('2053-11-04', '2053-11-01'),
	('2053-11-05', '2053-11-01'),
	('2053-11-06', '2053-11-01'),
	('2053-11-07', '2053-11-01'),
	('2053-11-08', '2053-11-01'),
	('2053-11-09', '2053-11-01'),
	('2053-11-10', '2053-11-01'),
	('2053-11-11', '2053-11-01'),
	('2053-11-12', '2053-11-01'),
	('2053-11-13', '2053-11-01'),
	('2053-11-14', '2053-11-01'),
	('2053-11-15', '2053-11-01'),
	('2053-11-16', '2053-11-01'),
	('2053-11-17', '2053-11-01'),
	('2053-11-18', '2053-11-01'),
	('2053-11-19', '2053-11-01'),
	('2053-11-20', '2053-11-01'),
	('2053-11-21', '2053-11-01'),
	('2053-11-22', '2053-11-01'),
	('2053-11-23', '2053-11-01'),
	('2053-11-24', '2053-11-01'),
	('2053-11-25', '2053-11-01'),
	('2053-11-26', '2053-11-01'),
	('2053-11-27', '2053-11-01'),
	('2053-11-28', '2053-11-01'),
	('2053-11-29', '2053-11-01'),
	('2053-11-30', '2053-11-01'),
	('2053-12-01', '2053-12-01'),
	('2053-12-02', '2053-12-01'),
	('2053-12-03', '2053-12-01'),
	('2053-12-04', '2053-12-01'),
	('2053-12-05', '2053-12-01'),
	('2053-12-06', '2053-12-01'),
	('2053-12-07', '2053-12-01'),
	('2053-12-08', '2053-12-01'),
	('2053-12-09', '2053-12-01'),
	('2053-12-10', '2053-12-01'),
	('2053-12-11', '2053-12-01'),
	('2053-12-12', '2053-12-01'),
	('2053-12-13', '2053-12-01'),
	('2053-12-14', '2053-12-01'),
	('2053-12-15', '2053-12-01'),
	('2053-12-16', '2053-12-01'),
	('2053-12-17', '2053-12-01'),
	('2053-12-18', '2053-12-01'),
	('2053-12-19', '2053-12-01'),
	('2053-12-20', '2053-12-01'),
	('2053-12-21', '2053-12-01'),
	('2053-12-22', '2053-12-01'),
	('2053-12-23', '2053-12-01'),
	('2053-12-24', '2053-12-01'),
	('2053-12-25', '2053-12-01'),
	('2053-12-26', '2053-12-01'),
	('2053-12-27', '2053-12-01'),
	('2053-12-28', '2053-12-01'),
	('2053-12-29', '2053-12-01'),
	('2053-12-30', '2053-12-01'),
	('2053-12-31', '2053-12-01'),
	('2054-01-01', '2054-01-01'),
	('2054-01-02', '2054-01-01'),
	('2054-01-03', '2054-01-01'),
	('2054-01-04', '2054-01-01'),
	('2054-01-05', '2054-01-01'),
	('2054-01-06', '2054-01-01'),
	('2054-01-07', '2054-01-01'),
	('2054-01-08', '2054-01-01'),
	('2054-01-09', '2054-01-01'),
	('2054-01-10', '2054-01-01'),
	('2054-01-11', '2054-01-01'),
	('2054-01-12', '2054-01-01'),
	('2054-01-13', '2054-01-01'),
	('2054-01-14', '2054-01-01'),
	('2054-01-15', '2054-01-01'),
	('2054-01-16', '2054-01-01'),
	('2054-01-17', '2054-01-01'),
	('2054-01-18', '2054-01-01'),
	('2054-01-19', '2054-01-01'),
	('2054-01-20', '2054-01-01'),
	('2054-01-21', '2054-01-01'),
	('2054-01-22', '2054-01-01'),
	('2054-01-23', '2054-01-01'),
	('2054-01-24', '2054-01-01'),
	('2054-01-25', '2054-01-01'),
	('2054-01-26', '2054-01-01'),
	('2054-01-27', '2054-01-01'),
	('2054-01-28', '2054-01-01'),
	('2054-01-29', '2054-01-01'),
	('2054-01-30', '2054-01-01'),
	('2054-01-31', '2054-01-01'),
	('2054-02-01', '2054-02-01'),
	('2054-02-02', '2054-02-01'),
	('2054-02-03', '2054-02-01'),
	('2054-02-04', '2054-02-01'),
	('2054-02-05', '2054-02-01'),
	('2054-02-06', '2054-02-01'),
	('2054-02-07', '2054-02-01'),
	('2054-02-08', '2054-02-01'),
	('2054-02-09', '2054-02-01'),
	('2054-02-10', '2054-02-01'),
	('2054-02-11', '2054-02-01'),
	('2054-02-12', '2054-02-01'),
	('2054-02-13', '2054-02-01'),
	('2054-02-14', '2054-02-01'),
	('2054-02-15', '2054-02-01'),
	('2054-02-16', '2054-02-01'),
	('2054-02-17', '2054-02-01'),
	('2054-02-18', '2054-02-01'),
	('2054-02-19', '2054-02-01'),
	('2054-02-20', '2054-02-01'),
	('2054-02-21', '2054-02-01'),
	('2054-02-22', '2054-02-01'),
	('2054-02-23', '2054-02-01'),
	('2054-02-24', '2054-02-01'),
	('2054-02-25', '2054-02-01'),
	('2054-02-26', '2054-02-01'),
	('2054-02-27', '2054-02-01'),
	('2054-02-28', '2054-02-01'),
	('2054-03-01', '2054-03-01'),
	('2054-03-02', '2054-03-01'),
	('2054-03-03', '2054-03-01'),
	('2054-03-04', '2054-03-01'),
	('2054-03-05', '2054-03-01'),
	('2054-03-06', '2054-03-01'),
	('2054-03-07', '2054-03-01'),
	('2054-03-08', '2054-03-01'),
	('2054-03-09', '2054-03-01'),
	('2054-03-10', '2054-03-01'),
	('2054-03-11', '2054-03-01'),
	('2054-03-12', '2054-03-01'),
	('2054-03-13', '2054-03-01'),
	('2054-03-14', '2054-03-01'),
	('2054-03-15', '2054-03-01'),
	('2054-03-16', '2054-03-01'),
	('2054-03-17', '2054-03-01'),
	('2054-03-18', '2054-03-01'),
	('2054-03-19', '2054-03-01'),
	('2054-03-20', '2054-03-01'),
	('2054-03-21', '2054-03-01'),
	('2054-03-22', '2054-03-01'),
	('2054-03-23', '2054-03-01'),
	('2054-03-24', '2054-03-01'),
	('2054-03-25', '2054-03-01'),
	('2054-03-26', '2054-03-01'),
	('2054-03-27', '2054-03-01'),
	('2054-03-28', '2054-03-01'),
	('2054-03-29', '2054-03-01'),
	('2054-03-30', '2054-03-01'),
	('2054-03-31', '2054-03-01'),
	('2054-04-01', '2054-04-01'),
	('2054-04-02', '2054-04-01'),
	('2054-04-03', '2054-04-01'),
	('2054-04-04', '2054-04-01'),
	('2054-04-05', '2054-04-01'),
	('2054-04-06', '2054-04-01'),
	('2054-04-07', '2054-04-01'),
	('2054-04-08', '2054-04-01'),
	('2054-04-09', '2054-04-01'),
	('2054-04-10', '2054-04-01'),
	('2054-04-11', '2054-04-01'),
	('2054-04-12', '2054-04-01'),
	('2054-04-13', '2054-04-01'),
	('2054-04-14', '2054-04-01'),
	('2054-04-15', '2054-04-01'),
	('2054-04-16', '2054-04-01'),
	('2054-04-17', '2054-04-01'),
	('2054-04-18', '2054-04-01'),
	('2054-04-19', '2054-04-01'),
	('2054-04-20', '2054-04-01'),
	('2054-04-21', '2054-04-01'),
	('2054-04-22', '2054-04-01'),
	('2054-04-23', '2054-04-01'),
	('2054-04-24', '2054-04-01'),
	('2054-04-25', '2054-04-01'),
	('2054-04-26', '2054-04-01'),
	('2054-04-27', '2054-04-01'),
	('2054-04-28', '2054-04-01'),
	('2054-04-29', '2054-04-01'),
	('2054-04-30', '2054-04-01'),
	('2054-05-01', '2054-05-01'),
	('2054-05-02', '2054-05-01'),
	('2054-05-03', '2054-05-01'),
	('2054-05-04', '2054-05-01'),
	('2054-05-05', '2054-05-01'),
	('2054-05-06', '2054-05-01'),
	('2054-05-07', '2054-05-01'),
	('2054-05-08', '2054-05-01'),
	('2054-05-09', '2054-05-01'),
	('2054-05-10', '2054-05-01'),
	('2054-05-11', '2054-05-01'),
	('2054-05-12', '2054-05-01'),
	('2054-05-13', '2054-05-01'),
	('2054-05-14', '2054-05-01'),
	('2054-05-15', '2054-05-01'),
	('2054-05-16', '2054-05-01'),
	('2054-05-17', '2054-05-01'),
	('2054-05-18', '2054-05-01'),
	('2054-05-19', '2054-05-01'),
	('2054-05-20', '2054-05-01'),
	('2054-05-21', '2054-05-01'),
	('2054-05-22', '2054-05-01'),
	('2054-05-23', '2054-05-01'),
	('2054-05-24', '2054-05-01'),
	('2054-05-25', '2054-05-01'),
	('2054-05-26', '2054-05-01'),
	('2054-05-27', '2054-05-01'),
	('2054-05-28', '2054-05-01'),
	('2054-05-29', '2054-05-01'),
	('2054-05-30', '2054-05-01'),
	('2054-05-31', '2054-05-01'),
	('2054-06-01', '2054-06-01'),
	('2054-06-02', '2054-06-01'),
	('2054-06-03', '2054-06-01'),
	('2054-06-04', '2054-06-01'),
	('2054-06-05', '2054-06-01'),
	('2054-06-06', '2054-06-01'),
	('2054-06-07', '2054-06-01'),
	('2054-06-08', '2054-06-01'),
	('2054-06-09', '2054-06-01'),
	('2054-06-10', '2054-06-01'),
	('2054-06-11', '2054-06-01'),
	('2054-06-12', '2054-06-01'),
	('2054-06-13', '2054-06-01'),
	('2054-06-14', '2054-06-01'),
	('2054-06-15', '2054-06-01'),
	('2054-06-16', '2054-06-01'),
	('2054-06-17', '2054-06-01'),
	('2054-06-18', '2054-06-01'),
	('2054-06-19', '2054-06-01'),
	('2054-06-20', '2054-06-01'),
	('2054-06-21', '2054-06-01'),
	('2054-06-22', '2054-06-01'),
	('2054-06-23', '2054-06-01'),
	('2054-06-24', '2054-06-01'),
	('2054-06-25', '2054-06-01'),
	('2054-06-26', '2054-06-01'),
	('2054-06-27', '2054-06-01'),
	('2054-06-28', '2054-06-01'),
	('2054-06-29', '2054-06-01'),
	('2054-06-30', '2054-06-01'),
	('2054-07-01', '2054-07-01'),
	('2054-07-02', '2054-07-01'),
	('2054-07-03', '2054-07-01'),
	('2054-07-04', '2054-07-01'),
	('2054-07-05', '2054-07-01'),
	('2054-07-06', '2054-07-01'),
	('2054-07-07', '2054-07-01'),
	('2054-07-08', '2054-07-01'),
	('2054-07-09', '2054-07-01'),
	('2054-07-10', '2054-07-01'),
	('2054-07-11', '2054-07-01'),
	('2054-07-12', '2054-07-01'),
	('2054-07-13', '2054-07-01'),
	('2054-07-14', '2054-07-01'),
	('2054-07-15', '2054-07-01'),
	('2054-07-16', '2054-07-01'),
	('2054-07-17', '2054-07-01'),
	('2054-07-18', '2054-07-01'),
	('2054-07-19', '2054-07-01'),
	('2054-07-20', '2054-07-01'),
	('2054-07-21', '2054-07-01'),
	('2054-07-22', '2054-07-01'),
	('2054-07-23', '2054-07-01'),
	('2054-07-24', '2054-07-01'),
	('2054-07-25', '2054-07-01'),
	('2054-07-26', '2054-07-01'),
	('2054-07-27', '2054-07-01'),
	('2054-07-28', '2054-07-01'),
	('2054-07-29', '2054-07-01'),
	('2054-07-30', '2054-07-01'),
	('2054-07-31', '2054-07-01'),
	('2054-08-01', '2054-08-01'),
	('2054-08-02', '2054-08-01'),
	('2054-08-03', '2054-08-01'),
	('2054-08-04', '2054-08-01'),
	('2054-08-05', '2054-08-01'),
	('2054-08-06', '2054-08-01'),
	('2054-08-07', '2054-08-01'),
	('2054-08-08', '2054-08-01'),
	('2054-08-09', '2054-08-01'),
	('2054-08-10', '2054-08-01'),
	('2054-08-11', '2054-08-01'),
	('2054-08-12', '2054-08-01'),
	('2054-08-13', '2054-08-01'),
	('2054-08-14', '2054-08-01'),
	('2054-08-15', '2054-08-01'),
	('2054-08-16', '2054-08-01'),
	('2054-08-17', '2054-08-01'),
	('2054-08-18', '2054-08-01'),
	('2054-08-19', '2054-08-01'),
	('2054-08-20', '2054-08-01'),
	('2054-08-21', '2054-08-01'),
	('2054-08-22', '2054-08-01'),
	('2054-08-23', '2054-08-01'),
	('2054-08-24', '2054-08-01'),
	('2054-08-25', '2054-08-01'),
	('2054-08-26', '2054-08-01'),
	('2054-08-27', '2054-08-01'),
	('2054-08-28', '2054-08-01'),
	('2054-08-29', '2054-08-01'),
	('2054-08-30', '2054-08-01'),
	('2054-08-31', '2054-08-01'),
	('2054-09-01', '2054-09-01'),
	('2054-09-02', '2054-09-01'),
	('2054-09-03', '2054-09-01'),
	('2054-09-04', '2054-09-01'),
	('2054-09-05', '2054-09-01'),
	('2054-09-06', '2054-09-01'),
	('2054-09-07', '2054-09-01'),
	('2054-09-08', '2054-09-01'),
	('2054-09-09', '2054-09-01'),
	('2054-09-10', '2054-09-01'),
	('2054-09-11', '2054-09-01'),
	('2054-09-12', '2054-09-01'),
	('2054-09-13', '2054-09-01'),
	('2054-09-14', '2054-09-01'),
	('2054-09-15', '2054-09-01'),
	('2054-09-16', '2054-09-01'),
	('2054-09-17', '2054-09-01'),
	('2054-09-18', '2054-09-01'),
	('2054-09-19', '2054-09-01'),
	('2054-09-20', '2054-09-01'),
	('2054-09-21', '2054-09-01'),
	('2054-09-22', '2054-09-01'),
	('2054-09-23', '2054-09-01'),
	('2054-09-24', '2054-09-01'),
	('2054-09-25', '2054-09-01'),
	('2054-09-26', '2054-09-01'),
	('2054-09-27', '2054-09-01'),
	('2054-09-28', '2054-09-01'),
	('2054-09-29', '2054-09-01'),
	('2054-09-30', '2054-09-01'),
	('2054-10-01', '2054-10-01'),
	('2054-10-02', '2054-10-01'),
	('2054-10-03', '2054-10-01'),
	('2054-10-04', '2054-10-01'),
	('2054-10-05', '2054-10-01'),
	('2054-10-06', '2054-10-01'),
	('2054-10-07', '2054-10-01'),
	('2054-10-08', '2054-10-01'),
	('2054-10-09', '2054-10-01'),
	('2054-10-10', '2054-10-01'),
	('2054-10-11', '2054-10-01'),
	('2054-10-12', '2054-10-01'),
	('2054-10-13', '2054-10-01'),
	('2054-10-14', '2054-10-01'),
	('2054-10-15', '2054-10-01'),
	('2054-10-16', '2054-10-01'),
	('2054-10-17', '2054-10-01'),
	('2054-10-18', '2054-10-01'),
	('2054-10-19', '2054-10-01'),
	('2054-10-20', '2054-10-01'),
	('2054-10-21', '2054-10-01'),
	('2054-10-22', '2054-10-01'),
	('2054-10-23', '2054-10-01'),
	('2054-10-24', '2054-10-01'),
	('2054-10-25', '2054-10-01'),
	('2054-10-26', '2054-10-01'),
	('2054-10-27', '2054-10-01'),
	('2054-10-28', '2054-10-01'),
	('2054-10-29', '2054-10-01'),
	('2054-10-30', '2054-10-01'),
	('2054-10-31', '2054-10-01'),
	('2054-11-01', '2054-11-01'),
	('2054-11-02', '2054-11-01'),
	('2054-11-03', '2054-11-01'),
	('2054-11-04', '2054-11-01'),
	('2054-11-05', '2054-11-01'),
	('2054-11-06', '2054-11-01'),
	('2054-11-07', '2054-11-01'),
	('2054-11-08', '2054-11-01'),
	('2054-11-09', '2054-11-01'),
	('2054-11-10', '2054-11-01'),
	('2054-11-11', '2054-11-01'),
	('2054-11-12', '2054-11-01'),
	('2054-11-13', '2054-11-01'),
	('2054-11-14', '2054-11-01'),
	('2054-11-15', '2054-11-01'),
	('2054-11-16', '2054-11-01'),
	('2054-11-17', '2054-11-01'),
	('2054-11-18', '2054-11-01'),
	('2054-11-19', '2054-11-01'),
	('2054-11-20', '2054-11-01'),
	('2054-11-21', '2054-11-01'),
	('2054-11-22', '2054-11-01'),
	('2054-11-23', '2054-11-01'),
	('2054-11-24', '2054-11-01'),
	('2054-11-25', '2054-11-01'),
	('2054-11-26', '2054-11-01'),
	('2054-11-27', '2054-11-01'),
	('2054-11-28', '2054-11-01'),
	('2054-11-29', '2054-11-01'),
	('2054-11-30', '2054-11-01'),
	('2054-12-01', '2054-12-01'),
	('2054-12-02', '2054-12-01'),
	('2054-12-03', '2054-12-01'),
	('2054-12-04', '2054-12-01'),
	('2054-12-05', '2054-12-01'),
	('2054-12-06', '2054-12-01'),
	('2054-12-07', '2054-12-01'),
	('2054-12-08', '2054-12-01'),
	('2054-12-09', '2054-12-01'),
	('2054-12-10', '2054-12-01'),
	('2054-12-11', '2054-12-01'),
	('2054-12-12', '2054-12-01'),
	('2054-12-13', '2054-12-01'),
	('2054-12-14', '2054-12-01'),
	('2054-12-15', '2054-12-01'),
	('2054-12-16', '2054-12-01'),
	('2054-12-17', '2054-12-01'),
	('2054-12-18', '2054-12-01'),
	('2054-12-19', '2054-12-01'),
	('2054-12-20', '2054-12-01'),
	('2054-12-21', '2054-12-01'),
	('2054-12-22', '2054-12-01'),
	('2054-12-23', '2054-12-01'),
	('2054-12-24', '2054-12-01'),
	('2054-12-25', '2054-12-01'),
	('2054-12-26', '2054-12-01'),
	('2054-12-27', '2054-12-01'),
	('2054-12-28', '2054-12-01'),
	('2054-12-29', '2054-12-01'),
	('2054-12-30', '2054-12-01'),
	('2054-12-31', '2054-12-01'),
	('2055-01-01', '2055-01-01'),
	('2055-01-02', '2055-01-01'),
	('2055-01-03', '2055-01-01'),
	('2055-01-04', '2055-01-01'),
	('2055-01-05', '2055-01-01'),
	('2055-01-06', '2055-01-01'),
	('2055-01-07', '2055-01-01'),
	('2055-01-08', '2055-01-01'),
	('2055-01-09', '2055-01-01'),
	('2055-01-10', '2055-01-01'),
	('2055-01-11', '2055-01-01'),
	('2055-01-12', '2055-01-01'),
	('2055-01-13', '2055-01-01'),
	('2055-01-14', '2055-01-01'),
	('2055-01-15', '2055-01-01'),
	('2055-01-16', '2055-01-01'),
	('2055-01-17', '2055-01-01'),
	('2055-01-18', '2055-01-01'),
	('2055-01-19', '2055-01-01'),
	('2055-01-20', '2055-01-01'),
	('2055-01-21', '2055-01-01'),
	('2055-01-22', '2055-01-01'),
	('2055-01-23', '2055-01-01'),
	('2055-01-24', '2055-01-01'),
	('2055-01-25', '2055-01-01'),
	('2055-01-26', '2055-01-01'),
	('2055-01-27', '2055-01-01'),
	('2055-01-28', '2055-01-01'),
	('2055-01-29', '2055-01-01'),
	('2055-01-30', '2055-01-01'),
	('2055-01-31', '2055-01-01'),
	('2055-02-01', '2055-02-01'),
	('2055-02-02', '2055-02-01'),
	('2055-02-03', '2055-02-01'),
	('2055-02-04', '2055-02-01'),
	('2055-02-05', '2055-02-01'),
	('2055-02-06', '2055-02-01'),
	('2055-02-07', '2055-02-01'),
	('2055-02-08', '2055-02-01'),
	('2055-02-09', '2055-02-01'),
	('2055-02-10', '2055-02-01'),
	('2055-02-11', '2055-02-01'),
	('2055-02-12', '2055-02-01'),
	('2055-02-13', '2055-02-01'),
	('2055-02-14', '2055-02-01'),
	('2055-02-15', '2055-02-01'),
	('2055-02-16', '2055-02-01'),
	('2055-02-17', '2055-02-01'),
	('2055-02-18', '2055-02-01'),
	('2055-02-19', '2055-02-01'),
	('2055-02-20', '2055-02-01'),
	('2055-02-21', '2055-02-01'),
	('2055-02-22', '2055-02-01'),
	('2055-02-23', '2055-02-01'),
	('2055-02-24', '2055-02-01'),
	('2055-02-25', '2055-02-01'),
	('2055-02-26', '2055-02-01'),
	('2055-02-27', '2055-02-01'),
	('2055-02-28', '2055-02-01'),
	('2055-03-01', '2055-03-01'),
	('2055-03-02', '2055-03-01'),
	('2055-03-03', '2055-03-01'),
	('2055-03-04', '2055-03-01'),
	('2055-03-05', '2055-03-01'),
	('2055-03-06', '2055-03-01'),
	('2055-03-07', '2055-03-01'),
	('2055-03-08', '2055-03-01'),
	('2055-03-09', '2055-03-01'),
	('2055-03-10', '2055-03-01'),
	('2055-03-11', '2055-03-01'),
	('2055-03-12', '2055-03-01'),
	('2055-03-13', '2055-03-01'),
	('2055-03-14', '2055-03-01'),
	('2055-03-15', '2055-03-01'),
	('2055-03-16', '2055-03-01'),
	('2055-03-17', '2055-03-01'),
	('2055-03-18', '2055-03-01'),
	('2055-03-19', '2055-03-01'),
	('2055-03-20', '2055-03-01'),
	('2055-03-21', '2055-03-01'),
	('2055-03-22', '2055-03-01'),
	('2055-03-23', '2055-03-01'),
	('2055-03-24', '2055-03-01'),
	('2055-03-25', '2055-03-01'),
	('2055-03-26', '2055-03-01'),
	('2055-03-27', '2055-03-01'),
	('2055-03-28', '2055-03-01'),
	('2055-03-29', '2055-03-01'),
	('2055-03-30', '2055-03-01'),
	('2055-03-31', '2055-03-01'),
	('2055-04-01', '2055-04-01'),
	('2055-04-02', '2055-04-01'),
	('2055-04-03', '2055-04-01'),
	('2055-04-04', '2055-04-01'),
	('2055-04-05', '2055-04-01'),
	('2055-04-06', '2055-04-01'),
	('2055-04-07', '2055-04-01'),
	('2055-04-08', '2055-04-01'),
	('2055-04-09', '2055-04-01'),
	('2055-04-10', '2055-04-01'),
	('2055-04-11', '2055-04-01'),
	('2055-04-12', '2055-04-01'),
	('2055-04-13', '2055-04-01'),
	('2055-04-14', '2055-04-01'),
	('2055-04-15', '2055-04-01'),
	('2055-04-16', '2055-04-01'),
	('2055-04-17', '2055-04-01'),
	('2055-04-18', '2055-04-01'),
	('2055-04-19', '2055-04-01'),
	('2055-04-20', '2055-04-01'),
	('2055-04-21', '2055-04-01'),
	('2055-04-22', '2055-04-01'),
	('2055-04-23', '2055-04-01'),
	('2055-04-24', '2055-04-01'),
	('2055-04-25', '2055-04-01'),
	('2055-04-26', '2055-04-01'),
	('2055-04-27', '2055-04-01'),
	('2055-04-28', '2055-04-01'),
	('2055-04-29', '2055-04-01'),
	('2055-04-30', '2055-04-01'),
	('2055-05-01', '2055-05-01'),
	('2055-05-02', '2055-05-01'),
	('2055-05-03', '2055-05-01'),
	('2055-05-04', '2055-05-01'),
	('2055-05-05', '2055-05-01'),
	('2055-05-06', '2055-05-01'),
	('2055-05-07', '2055-05-01'),
	('2055-05-08', '2055-05-01'),
	('2055-05-09', '2055-05-01'),
	('2055-05-10', '2055-05-01'),
	('2055-05-11', '2055-05-01'),
	('2055-05-12', '2055-05-01'),
	('2055-05-13', '2055-05-01'),
	('2055-05-14', '2055-05-01'),
	('2055-05-15', '2055-05-01'),
	('2055-05-16', '2055-05-01'),
	('2055-05-17', '2055-05-01'),
	('2055-05-18', '2055-05-01'),
	('2055-05-19', '2055-05-01'),
	('2055-05-20', '2055-05-01'),
	('2055-05-21', '2055-05-01'),
	('2055-05-22', '2055-05-01'),
	('2055-05-23', '2055-05-01'),
	('2055-05-24', '2055-05-01'),
	('2055-05-25', '2055-05-01'),
	('2055-05-26', '2055-05-01'),
	('2055-05-27', '2055-05-01'),
	('2055-05-28', '2055-05-01'),
	('2055-05-29', '2055-05-01'),
	('2055-05-30', '2055-05-01'),
	('2055-05-31', '2055-05-01'),
	('2055-06-01', '2055-06-01'),
	('2055-06-02', '2055-06-01'),
	('2055-06-03', '2055-06-01'),
	('2055-06-04', '2055-06-01'),
	('2055-06-05', '2055-06-01'),
	('2055-06-06', '2055-06-01'),
	('2055-06-07', '2055-06-01'),
	('2055-06-08', '2055-06-01'),
	('2055-06-09', '2055-06-01'),
	('2055-06-10', '2055-06-01'),
	('2055-06-11', '2055-06-01'),
	('2055-06-12', '2055-06-01'),
	('2055-06-13', '2055-06-01'),
	('2055-06-14', '2055-06-01'),
	('2055-06-15', '2055-06-01'),
	('2055-06-16', '2055-06-01'),
	('2055-06-17', '2055-06-01'),
	('2055-06-18', '2055-06-01'),
	('2055-06-19', '2055-06-01'),
	('2055-06-20', '2055-06-01'),
	('2055-06-21', '2055-06-01'),
	('2055-06-22', '2055-06-01'),
	('2055-06-23', '2055-06-01'),
	('2055-06-24', '2055-06-01'),
	('2055-06-25', '2055-06-01'),
	('2055-06-26', '2055-06-01'),
	('2055-06-27', '2055-06-01'),
	('2055-06-28', '2055-06-01'),
	('2055-06-29', '2055-06-01'),
	('2055-06-30', '2055-06-01'),
	('2055-07-01', '2055-07-01'),
	('2055-07-02', '2055-07-01'),
	('2055-07-03', '2055-07-01'),
	('2055-07-04', '2055-07-01'),
	('2055-07-05', '2055-07-01'),
	('2055-07-06', '2055-07-01'),
	('2055-07-07', '2055-07-01'),
	('2055-07-08', '2055-07-01'),
	('2055-07-09', '2055-07-01'),
	('2055-07-10', '2055-07-01'),
	('2055-07-11', '2055-07-01'),
	('2055-07-12', '2055-07-01'),
	('2055-07-13', '2055-07-01'),
	('2055-07-14', '2055-07-01'),
	('2055-07-15', '2055-07-01'),
	('2055-07-16', '2055-07-01'),
	('2055-07-17', '2055-07-01'),
	('2055-07-18', '2055-07-01'),
	('2055-07-19', '2055-07-01'),
	('2055-07-20', '2055-07-01'),
	('2055-07-21', '2055-07-01'),
	('2055-07-22', '2055-07-01'),
	('2055-07-23', '2055-07-01'),
	('2055-07-24', '2055-07-01'),
	('2055-07-25', '2055-07-01'),
	('2055-07-26', '2055-07-01'),
	('2055-07-27', '2055-07-01'),
	('2055-07-28', '2055-07-01'),
	('2055-07-29', '2055-07-01'),
	('2055-07-30', '2055-07-01'),
	('2055-07-31', '2055-07-01'),
	('2055-08-01', '2055-08-01'),
	('2055-08-02', '2055-08-01'),
	('2055-08-03', '2055-08-01'),
	('2055-08-04', '2055-08-01'),
	('2055-08-05', '2055-08-01'),
	('2055-08-06', '2055-08-01'),
	('2055-08-07', '2055-08-01'),
	('2055-08-08', '2055-08-01'),
	('2055-08-09', '2055-08-01'),
	('2055-08-10', '2055-08-01'),
	('2055-08-11', '2055-08-01'),
	('2055-08-12', '2055-08-01'),
	('2055-08-13', '2055-08-01'),
	('2055-08-14', '2055-08-01'),
	('2055-08-15', '2055-08-01'),
	('2055-08-16', '2055-08-01'),
	('2055-08-17', '2055-08-01'),
	('2055-08-18', '2055-08-01'),
	('2055-08-19', '2055-08-01'),
	('2055-08-20', '2055-08-01'),
	('2055-08-21', '2055-08-01'),
	('2055-08-22', '2055-08-01'),
	('2055-08-23', '2055-08-01'),
	('2055-08-24', '2055-08-01'),
	('2055-08-25', '2055-08-01'),
	('2055-08-26', '2055-08-01'),
	('2055-08-27', '2055-08-01'),
	('2055-08-28', '2055-08-01'),
	('2055-08-29', '2055-08-01'),
	('2055-08-30', '2055-08-01'),
	('2055-08-31', '2055-08-01'),
	('2055-09-01', '2055-09-01'),
	('2055-09-02', '2055-09-01'),
	('2055-09-03', '2055-09-01'),
	('2055-09-04', '2055-09-01'),
	('2055-09-05', '2055-09-01'),
	('2055-09-06', '2055-09-01'),
	('2055-09-07', '2055-09-01'),
	('2055-09-08', '2055-09-01'),
	('2055-09-09', '2055-09-01'),
	('2055-09-10', '2055-09-01'),
	('2055-09-11', '2055-09-01'),
	('2055-09-12', '2055-09-01'),
	('2055-09-13', '2055-09-01'),
	('2055-09-14', '2055-09-01'),
	('2055-09-15', '2055-09-01'),
	('2055-09-16', '2055-09-01'),
	('2055-09-17', '2055-09-01'),
	('2055-09-18', '2055-09-01'),
	('2055-09-19', '2055-09-01'),
	('2055-09-20', '2055-09-01'),
	('2055-09-21', '2055-09-01'),
	('2055-09-22', '2055-09-01'),
	('2055-09-23', '2055-09-01'),
	('2055-09-24', '2055-09-01'),
	('2055-09-25', '2055-09-01'),
	('2055-09-26', '2055-09-01'),
	('2055-09-27', '2055-09-01'),
	('2055-09-28', '2055-09-01'),
	('2055-09-29', '2055-09-01'),
	('2055-09-30', '2055-09-01'),
	('2055-10-01', '2055-10-01'),
	('2055-10-02', '2055-10-01'),
	('2055-10-03', '2055-10-01'),
	('2055-10-04', '2055-10-01'),
	('2055-10-05', '2055-10-01'),
	('2055-10-06', '2055-10-01'),
	('2055-10-07', '2055-10-01'),
	('2055-10-08', '2055-10-01'),
	('2055-10-09', '2055-10-01'),
	('2055-10-10', '2055-10-01'),
	('2055-10-11', '2055-10-01'),
	('2055-10-12', '2055-10-01'),
	('2055-10-13', '2055-10-01'),
	('2055-10-14', '2055-10-01'),
	('2055-10-15', '2055-10-01'),
	('2055-10-16', '2055-10-01'),
	('2055-10-17', '2055-10-01'),
	('2055-10-18', '2055-10-01'),
	('2055-10-19', '2055-10-01'),
	('2055-10-20', '2055-10-01'),
	('2055-10-21', '2055-10-01'),
	('2055-10-22', '2055-10-01'),
	('2055-10-23', '2055-10-01'),
	('2055-10-24', '2055-10-01'),
	('2055-10-25', '2055-10-01'),
	('2055-10-26', '2055-10-01'),
	('2055-10-27', '2055-10-01'),
	('2055-10-28', '2055-10-01'),
	('2055-10-29', '2055-10-01'),
	('2055-10-30', '2055-10-01'),
	('2055-10-31', '2055-10-01'),
	('2055-11-01', '2055-11-01'),
	('2055-11-02', '2055-11-01'),
	('2055-11-03', '2055-11-01'),
	('2055-11-04', '2055-11-01'),
	('2055-11-05', '2055-11-01'),
	('2055-11-06', '2055-11-01'),
	('2055-11-07', '2055-11-01'),
	('2055-11-08', '2055-11-01'),
	('2055-11-09', '2055-11-01'),
	('2055-11-10', '2055-11-01'),
	('2055-11-11', '2055-11-01'),
	('2055-11-12', '2055-11-01'),
	('2055-11-13', '2055-11-01'),
	('2055-11-14', '2055-11-01'),
	('2055-11-15', '2055-11-01'),
	('2055-11-16', '2055-11-01'),
	('2055-11-17', '2055-11-01'),
	('2055-11-18', '2055-11-01'),
	('2055-11-19', '2055-11-01'),
	('2055-11-20', '2055-11-01'),
	('2055-11-21', '2055-11-01'),
	('2055-11-22', '2055-11-01'),
	('2055-11-23', '2055-11-01'),
	('2055-11-24', '2055-11-01'),
	('2055-11-25', '2055-11-01'),
	('2055-11-26', '2055-11-01'),
	('2055-11-27', '2055-11-01'),
	('2055-11-28', '2055-11-01'),
	('2055-11-29', '2055-11-01'),
	('2055-11-30', '2055-11-01'),
	('2055-12-01', '2055-12-01'),
	('2055-12-02', '2055-12-01'),
	('2055-12-03', '2055-12-01'),
	('2055-12-04', '2055-12-01'),
	('2055-12-05', '2055-12-01'),
	('2055-12-06', '2055-12-01'),
	('2055-12-07', '2055-12-01'),
	('2055-12-08', '2055-12-01'),
	('2055-12-09', '2055-12-01'),
	('2055-12-10', '2055-12-01'),
	('2055-12-11', '2055-12-01'),
	('2055-12-12', '2055-12-01'),
	('2055-12-13', '2055-12-01'),
	('2055-12-14', '2055-12-01'),
	('2055-12-15', '2055-12-01'),
	('2055-12-16', '2055-12-01'),
	('2055-12-17', '2055-12-01'),
	('2055-12-18', '2055-12-01'),
	('2055-12-19', '2055-12-01'),
	('2055-12-20', '2055-12-01'),
	('2055-12-21', '2055-12-01'),
	('2055-12-22', '2055-12-01'),
	('2055-12-23', '2055-12-01'),
	('2055-12-24', '2055-12-01'),
	('2055-12-25', '2055-12-01'),
	('2055-12-26', '2055-12-01'),
	('2055-12-27', '2055-12-01'),
	('2055-12-28', '2055-12-01'),
	('2055-12-29', '2055-12-01'),
	('2055-12-30', '2055-12-01'),
	('2055-12-31', '2055-12-01'),
	('2056-01-01', '2056-01-01'),
	('2056-01-02', '2056-01-01'),
	('2056-01-03', '2056-01-01'),
	('2056-01-04', '2056-01-01'),
	('2056-01-05', '2056-01-01'),
	('2056-01-06', '2056-01-01'),
	('2056-01-07', '2056-01-01'),
	('2056-01-08', '2056-01-01'),
	('2056-01-09', '2056-01-01'),
	('2056-01-10', '2056-01-01'),
	('2056-01-11', '2056-01-01'),
	('2056-01-12', '2056-01-01'),
	('2056-01-13', '2056-01-01'),
	('2056-01-14', '2056-01-01'),
	('2056-01-15', '2056-01-01'),
	('2056-01-16', '2056-01-01'),
	('2056-01-17', '2056-01-01'),
	('2056-01-18', '2056-01-01'),
	('2056-01-19', '2056-01-01'),
	('2056-01-20', '2056-01-01'),
	('2056-01-21', '2056-01-01'),
	('2056-01-22', '2056-01-01'),
	('2056-01-23', '2056-01-01'),
	('2056-01-24', '2056-01-01'),
	('2056-01-25', '2056-01-01'),
	('2056-01-26', '2056-01-01'),
	('2056-01-27', '2056-01-01'),
	('2056-01-28', '2056-01-01'),
	('2056-01-29', '2056-01-01'),
	('2056-01-30', '2056-01-01'),
	('2056-01-31', '2056-01-01'),
	('2056-02-01', '2056-02-01'),
	('2056-02-02', '2056-02-01'),
	('2056-02-03', '2056-02-01'),
	('2056-02-04', '2056-02-01'),
	('2056-02-05', '2056-02-01'),
	('2056-02-06', '2056-02-01'),
	('2056-02-07', '2056-02-01'),
	('2056-02-08', '2056-02-01'),
	('2056-02-09', '2056-02-01'),
	('2056-02-10', '2056-02-01'),
	('2056-02-11', '2056-02-01'),
	('2056-02-12', '2056-02-01'),
	('2056-02-13', '2056-02-01'),
	('2056-02-14', '2056-02-01'),
	('2056-02-15', '2056-02-01'),
	('2056-02-16', '2056-02-01'),
	('2056-02-17', '2056-02-01'),
	('2056-02-18', '2056-02-01'),
	('2056-02-19', '2056-02-01'),
	('2056-02-20', '2056-02-01'),
	('2056-02-21', '2056-02-01'),
	('2056-02-22', '2056-02-01'),
	('2056-02-23', '2056-02-01'),
	('2056-02-24', '2056-02-01'),
	('2056-02-25', '2056-02-01'),
	('2056-02-26', '2056-02-01'),
	('2056-02-27', '2056-02-01'),
	('2056-02-28', '2056-02-01'),
	('2056-02-29', '2056-02-01'),
	('2056-03-01', '2056-03-01'),
	('2056-03-02', '2056-03-01'),
	('2056-03-03', '2056-03-01'),
	('2056-03-04', '2056-03-01'),
	('2056-03-05', '2056-03-01'),
	('2056-03-06', '2056-03-01'),
	('2056-03-07', '2056-03-01'),
	('2056-03-08', '2056-03-01'),
	('2056-03-09', '2056-03-01'),
	('2056-03-10', '2056-03-01'),
	('2056-03-11', '2056-03-01'),
	('2056-03-12', '2056-03-01'),
	('2056-03-13', '2056-03-01'),
	('2056-03-14', '2056-03-01'),
	('2056-03-15', '2056-03-01'),
	('2056-03-16', '2056-03-01'),
	('2056-03-17', '2056-03-01'),
	('2056-03-18', '2056-03-01'),
	('2056-03-19', '2056-03-01'),
	('2056-03-20', '2056-03-01'),
	('2056-03-21', '2056-03-01'),
	('2056-03-22', '2056-03-01'),
	('2056-03-23', '2056-03-01'),
	('2056-03-24', '2056-03-01'),
	('2056-03-25', '2056-03-01'),
	('2056-03-26', '2056-03-01'),
	('2056-03-27', '2056-03-01'),
	('2056-03-28', '2056-03-01'),
	('2056-03-29', '2056-03-01'),
	('2056-03-30', '2056-03-01'),
	('2056-03-31', '2056-03-01'),
	('2056-04-01', '2056-04-01'),
	('2056-04-02', '2056-04-01'),
	('2056-04-03', '2056-04-01'),
	('2056-04-04', '2056-04-01'),
	('2056-04-05', '2056-04-01'),
	('2056-04-06', '2056-04-01'),
	('2056-04-07', '2056-04-01'),
	('2056-04-08', '2056-04-01'),
	('2056-04-09', '2056-04-01'),
	('2056-04-10', '2056-04-01'),
	('2056-04-11', '2056-04-01'),
	('2056-04-12', '2056-04-01'),
	('2056-04-13', '2056-04-01'),
	('2056-04-14', '2056-04-01'),
	('2056-04-15', '2056-04-01'),
	('2056-04-16', '2056-04-01'),
	('2056-04-17', '2056-04-01'),
	('2056-04-18', '2056-04-01'),
	('2056-04-19', '2056-04-01'),
	('2056-04-20', '2056-04-01'),
	('2056-04-21', '2056-04-01'),
	('2056-04-22', '2056-04-01'),
	('2056-04-23', '2056-04-01'),
	('2056-04-24', '2056-04-01'),
	('2056-04-25', '2056-04-01'),
	('2056-04-26', '2056-04-01'),
	('2056-04-27', '2056-04-01'),
	('2056-04-28', '2056-04-01'),
	('2056-04-29', '2056-04-01'),
	('2056-04-30', '2056-04-01'),
	('2056-05-01', '2056-05-01'),
	('2056-05-02', '2056-05-01'),
	('2056-05-03', '2056-05-01'),
	('2056-05-04', '2056-05-01'),
	('2056-05-05', '2056-05-01'),
	('2056-05-06', '2056-05-01'),
	('2056-05-07', '2056-05-01'),
	('2056-05-08', '2056-05-01'),
	('2056-05-09', '2056-05-01'),
	('2056-05-10', '2056-05-01'),
	('2056-05-11', '2056-05-01'),
	('2056-05-12', '2056-05-01'),
	('2056-05-13', '2056-05-01'),
	('2056-05-14', '2056-05-01'),
	('2056-05-15', '2056-05-01'),
	('2056-05-16', '2056-05-01'),
	('2056-05-17', '2056-05-01'),
	('2056-05-18', '2056-05-01'),
	('2056-05-19', '2056-05-01'),
	('2056-05-20', '2056-05-01'),
	('2056-05-21', '2056-05-01'),
	('2056-05-22', '2056-05-01'),
	('2056-05-23', '2056-05-01'),
	('2056-05-24', '2056-05-01'),
	('2056-05-25', '2056-05-01'),
	('2056-05-26', '2056-05-01'),
	('2056-05-27', '2056-05-01'),
	('2056-05-28', '2056-05-01'),
	('2056-05-29', '2056-05-01'),
	('2056-05-30', '2056-05-01'),
	('2056-05-31', '2056-05-01'),
	('2056-06-01', '2056-06-01'),
	('2056-06-02', '2056-06-01'),
	('2056-06-03', '2056-06-01'),
	('2056-06-04', '2056-06-01'),
	('2056-06-05', '2056-06-01'),
	('2056-06-06', '2056-06-01'),
	('2056-06-07', '2056-06-01'),
	('2056-06-08', '2056-06-01'),
	('2056-06-09', '2056-06-01'),
	('2056-06-10', '2056-06-01'),
	('2056-06-11', '2056-06-01'),
	('2056-06-12', '2056-06-01'),
	('2056-06-13', '2056-06-01'),
	('2056-06-14', '2056-06-01'),
	('2056-06-15', '2056-06-01'),
	('2056-06-16', '2056-06-01'),
	('2056-06-17', '2056-06-01'),
	('2056-06-18', '2056-06-01'),
	('2056-06-19', '2056-06-01'),
	('2056-06-20', '2056-06-01'),
	('2056-06-21', '2056-06-01'),
	('2056-06-22', '2056-06-01'),
	('2056-06-23', '2056-06-01'),
	('2056-06-24', '2056-06-01'),
	('2056-06-25', '2056-06-01'),
	('2056-06-26', '2056-06-01'),
	('2056-06-27', '2056-06-01'),
	('2056-06-28', '2056-06-01'),
	('2056-06-29', '2056-06-01'),
	('2056-06-30', '2056-06-01'),
	('2056-07-01', '2056-07-01'),
	('2056-07-02', '2056-07-01'),
	('2056-07-03', '2056-07-01'),
	('2056-07-04', '2056-07-01'),
	('2056-07-05', '2056-07-01'),
	('2056-07-06', '2056-07-01'),
	('2056-07-07', '2056-07-01'),
	('2056-07-08', '2056-07-01'),
	('2056-07-09', '2056-07-01'),
	('2056-07-10', '2056-07-01'),
	('2056-07-11', '2056-07-01'),
	('2056-07-12', '2056-07-01'),
	('2056-07-13', '2056-07-01'),
	('2056-07-14', '2056-07-01'),
	('2056-07-15', '2056-07-01'),
	('2056-07-16', '2056-07-01'),
	('2056-07-17', '2056-07-01'),
	('2056-07-18', '2056-07-01'),
	('2056-07-19', '2056-07-01'),
	('2056-07-20', '2056-07-01'),
	('2056-07-21', '2056-07-01'),
	('2056-07-22', '2056-07-01'),
	('2056-07-23', '2056-07-01'),
	('2056-07-24', '2056-07-01'),
	('2056-07-25', '2056-07-01'),
	('2056-07-26', '2056-07-01'),
	('2056-07-27', '2056-07-01'),
	('2056-07-28', '2056-07-01'),
	('2056-07-29', '2056-07-01'),
	('2056-07-30', '2056-07-01'),
	('2056-07-31', '2056-07-01'),
	('2056-08-01', '2056-08-01'),
	('2056-08-02', '2056-08-01'),
	('2056-08-03', '2056-08-01'),
	('2056-08-04', '2056-08-01'),
	('2056-08-05', '2056-08-01'),
	('2056-08-06', '2056-08-01'),
	('2056-08-07', '2056-08-01'),
	('2056-08-08', '2056-08-01'),
	('2056-08-09', '2056-08-01'),
	('2056-08-10', '2056-08-01'),
	('2056-08-11', '2056-08-01'),
	('2056-08-12', '2056-08-01'),
	('2056-08-13', '2056-08-01'),
	('2056-08-14', '2056-08-01'),
	('2056-08-15', '2056-08-01'),
	('2056-08-16', '2056-08-01'),
	('2056-08-17', '2056-08-01'),
	('2056-08-18', '2056-08-01'),
	('2056-08-19', '2056-08-01'),
	('2056-08-20', '2056-08-01'),
	('2056-08-21', '2056-08-01'),
	('2056-08-22', '2056-08-01'),
	('2056-08-23', '2056-08-01'),
	('2056-08-24', '2056-08-01'),
	('2056-08-25', '2056-08-01'),
	('2056-08-26', '2056-08-01'),
	('2056-08-27', '2056-08-01'),
	('2056-08-28', '2056-08-01'),
	('2056-08-29', '2056-08-01'),
	('2056-08-30', '2056-08-01'),
	('2056-08-31', '2056-08-01'),
	('2056-09-01', '2056-09-01'),
	('2056-09-02', '2056-09-01'),
	('2056-09-03', '2056-09-01'),
	('2056-09-04', '2056-09-01'),
	('2056-09-05', '2056-09-01'),
	('2056-09-06', '2056-09-01'),
	('2056-09-07', '2056-09-01'),
	('2056-09-08', '2056-09-01'),
	('2056-09-09', '2056-09-01'),
	('2056-09-10', '2056-09-01'),
	('2056-09-11', '2056-09-01'),
	('2056-09-12', '2056-09-01'),
	('2056-09-13', '2056-09-01'),
	('2056-09-14', '2056-09-01'),
	('2056-09-15', '2056-09-01'),
	('2056-09-16', '2056-09-01'),
	('2056-09-17', '2056-09-01'),
	('2056-09-18', '2056-09-01'),
	('2056-09-19', '2056-09-01'),
	('2056-09-20', '2056-09-01'),
	('2056-09-21', '2056-09-01'),
	('2056-09-22', '2056-09-01'),
	('2056-09-23', '2056-09-01'),
	('2056-09-24', '2056-09-01'),
	('2056-09-25', '2056-09-01'),
	('2056-09-26', '2056-09-01'),
	('2056-09-27', '2056-09-01'),
	('2056-09-28', '2056-09-01'),
	('2056-09-29', '2056-09-01'),
	('2056-09-30', '2056-09-01'),
	('2056-10-01', '2056-10-01'),
	('2056-10-02', '2056-10-01'),
	('2056-10-03', '2056-10-01'),
	('2056-10-04', '2056-10-01'),
	('2056-10-05', '2056-10-01'),
	('2056-10-06', '2056-10-01'),
	('2056-10-07', '2056-10-01'),
	('2056-10-08', '2056-10-01'),
	('2056-10-09', '2056-10-01'),
	('2056-10-10', '2056-10-01'),
	('2056-10-11', '2056-10-01'),
	('2056-10-12', '2056-10-01'),
	('2056-10-13', '2056-10-01'),
	('2056-10-14', '2056-10-01'),
	('2056-10-15', '2056-10-01'),
	('2056-10-16', '2056-10-01'),
	('2056-10-17', '2056-10-01'),
	('2056-10-18', '2056-10-01'),
	('2056-10-19', '2056-10-01'),
	('2056-10-20', '2056-10-01'),
	('2056-10-21', '2056-10-01'),
	('2056-10-22', '2056-10-01'),
	('2056-10-23', '2056-10-01'),
	('2056-10-24', '2056-10-01'),
	('2056-10-25', '2056-10-01'),
	('2056-10-26', '2056-10-01'),
	('2056-10-27', '2056-10-01'),
	('2056-10-28', '2056-10-01'),
	('2056-10-29', '2056-10-01'),
	('2056-10-30', '2056-10-01'),
	('2056-10-31', '2056-10-01'),
	('2056-11-01', '2056-11-01'),
	('2056-11-02', '2056-11-01'),
	('2056-11-03', '2056-11-01'),
	('2056-11-04', '2056-11-01'),
	('2056-11-05', '2056-11-01'),
	('2056-11-06', '2056-11-01'),
	('2056-11-07', '2056-11-01'),
	('2056-11-08', '2056-11-01'),
	('2056-11-09', '2056-11-01'),
	('2056-11-10', '2056-11-01'),
	('2056-11-11', '2056-11-01'),
	('2056-11-12', '2056-11-01'),
	('2056-11-13', '2056-11-01'),
	('2056-11-14', '2056-11-01'),
	('2056-11-15', '2056-11-01'),
	('2056-11-16', '2056-11-01'),
	('2056-11-17', '2056-11-01'),
	('2056-11-18', '2056-11-01'),
	('2056-11-19', '2056-11-01'),
	('2056-11-20', '2056-11-01'),
	('2056-11-21', '2056-11-01'),
	('2056-11-22', '2056-11-01'),
	('2056-11-23', '2056-11-01'),
	('2056-11-24', '2056-11-01'),
	('2056-11-25', '2056-11-01'),
	('2056-11-26', '2056-11-01'),
	('2056-11-27', '2056-11-01'),
	('2056-11-28', '2056-11-01'),
	('2056-11-29', '2056-11-01'),
	('2056-11-30', '2056-11-01'),
	('2056-12-01', '2056-12-01'),
	('2056-12-02', '2056-12-01'),
	('2056-12-03', '2056-12-01'),
	('2056-12-04', '2056-12-01'),
	('2056-12-05', '2056-12-01'),
	('2056-12-06', '2056-12-01'),
	('2056-12-07', '2056-12-01'),
	('2056-12-08', '2056-12-01'),
	('2056-12-09', '2056-12-01'),
	('2056-12-10', '2056-12-01'),
	('2056-12-11', '2056-12-01'),
	('2056-12-12', '2056-12-01'),
	('2056-12-13', '2056-12-01'),
	('2056-12-14', '2056-12-01'),
	('2056-12-15', '2056-12-01'),
	('2056-12-16', '2056-12-01'),
	('2056-12-17', '2056-12-01'),
	('2056-12-18', '2056-12-01'),
	('2056-12-19', '2056-12-01'),
	('2056-12-20', '2056-12-01'),
	('2056-12-21', '2056-12-01'),
	('2056-12-22', '2056-12-01'),
	('2056-12-23', '2056-12-01'),
	('2056-12-24', '2056-12-01'),
	('2056-12-25', '2056-12-01'),
	('2056-12-26', '2056-12-01'),
	('2056-12-27', '2056-12-01'),
	('2056-12-28', '2056-12-01'),
	('2056-12-29', '2056-12-01'),
	('2056-12-30', '2056-12-01'),
	('2056-12-31', '2056-12-01'),
	('2057-01-01', '2057-01-01'),
	('2057-01-02', '2057-01-01'),
	('2057-01-03', '2057-01-01'),
	('2057-01-04', '2057-01-01'),
	('2057-01-05', '2057-01-01'),
	('2057-01-06', '2057-01-01'),
	('2057-01-07', '2057-01-01'),
	('2057-01-08', '2057-01-01'),
	('2057-01-09', '2057-01-01'),
	('2057-01-10', '2057-01-01'),
	('2057-01-11', '2057-01-01'),
	('2057-01-12', '2057-01-01'),
	('2057-01-13', '2057-01-01'),
	('2057-01-14', '2057-01-01'),
	('2057-01-15', '2057-01-01'),
	('2057-01-16', '2057-01-01'),
	('2057-01-17', '2057-01-01'),
	('2057-01-18', '2057-01-01'),
	('2057-01-19', '2057-01-01'),
	('2057-01-20', '2057-01-01'),
	('2057-01-21', '2057-01-01'),
	('2057-01-22', '2057-01-01'),
	('2057-01-23', '2057-01-01'),
	('2057-01-24', '2057-01-01'),
	('2057-01-25', '2057-01-01'),
	('2057-01-26', '2057-01-01'),
	('2057-01-27', '2057-01-01'),
	('2057-01-28', '2057-01-01'),
	('2057-01-29', '2057-01-01'),
	('2057-01-30', '2057-01-01'),
	('2057-01-31', '2057-01-01'),
	('2057-02-01', '2057-02-01'),
	('2057-02-02', '2057-02-01'),
	('2057-02-03', '2057-02-01'),
	('2057-02-04', '2057-02-01'),
	('2057-02-05', '2057-02-01'),
	('2057-02-06', '2057-02-01'),
	('2057-02-07', '2057-02-01'),
	('2057-02-08', '2057-02-01'),
	('2057-02-09', '2057-02-01'),
	('2057-02-10', '2057-02-01'),
	('2057-02-11', '2057-02-01'),
	('2057-02-12', '2057-02-01'),
	('2057-02-13', '2057-02-01'),
	('2057-02-14', '2057-02-01'),
	('2057-02-15', '2057-02-01'),
	('2057-02-16', '2057-02-01'),
	('2057-02-17', '2057-02-01'),
	('2057-02-18', '2057-02-01'),
	('2057-02-19', '2057-02-01'),
	('2057-02-20', '2057-02-01'),
	('2057-02-21', '2057-02-01'),
	('2057-02-22', '2057-02-01'),
	('2057-02-23', '2057-02-01'),
	('2057-02-24', '2057-02-01'),
	('2057-02-25', '2057-02-01'),
	('2057-02-26', '2057-02-01'),
	('2057-02-27', '2057-02-01'),
	('2057-02-28', '2057-02-01'),
	('2057-03-01', '2057-03-01'),
	('2057-03-02', '2057-03-01'),
	('2057-03-03', '2057-03-01'),
	('2057-03-04', '2057-03-01'),
	('2057-03-05', '2057-03-01'),
	('2057-03-06', '2057-03-01'),
	('2057-03-07', '2057-03-01'),
	('2057-03-08', '2057-03-01'),
	('2057-03-09', '2057-03-01'),
	('2057-03-10', '2057-03-01'),
	('2057-03-11', '2057-03-01'),
	('2057-03-12', '2057-03-01'),
	('2057-03-13', '2057-03-01'),
	('2057-03-14', '2057-03-01'),
	('2057-03-15', '2057-03-01'),
	('2057-03-16', '2057-03-01'),
	('2057-03-17', '2057-03-01'),
	('2057-03-18', '2057-03-01'),
	('2057-03-19', '2057-03-01'),
	('2057-03-20', '2057-03-01'),
	('2057-03-21', '2057-03-01'),
	('2057-03-22', '2057-03-01'),
	('2057-03-23', '2057-03-01'),
	('2057-03-24', '2057-03-01'),
	('2057-03-25', '2057-03-01'),
	('2057-03-26', '2057-03-01'),
	('2057-03-27', '2057-03-01'),
	('2057-03-28', '2057-03-01'),
	('2057-03-29', '2057-03-01'),
	('2057-03-30', '2057-03-01'),
	('2057-03-31', '2057-03-01'),
	('2057-04-01', '2057-04-01'),
	('2057-04-02', '2057-04-01'),
	('2057-04-03', '2057-04-01'),
	('2057-04-04', '2057-04-01'),
	('2057-04-05', '2057-04-01'),
	('2057-04-06', '2057-04-01'),
	('2057-04-07', '2057-04-01'),
	('2057-04-08', '2057-04-01'),
	('2057-04-09', '2057-04-01'),
	('2057-04-10', '2057-04-01'),
	('2057-04-11', '2057-04-01'),
	('2057-04-12', '2057-04-01'),
	('2057-04-13', '2057-04-01'),
	('2057-04-14', '2057-04-01'),
	('2057-04-15', '2057-04-01'),
	('2057-04-16', '2057-04-01'),
	('2057-04-17', '2057-04-01'),
	('2057-04-18', '2057-04-01'),
	('2057-04-19', '2057-04-01'),
	('2057-04-20', '2057-04-01'),
	('2057-04-21', '2057-04-01'),
	('2057-04-22', '2057-04-01'),
	('2057-04-23', '2057-04-01'),
	('2057-04-24', '2057-04-01'),
	('2057-04-25', '2057-04-01'),
	('2057-04-26', '2057-04-01'),
	('2057-04-27', '2057-04-01'),
	('2057-04-28', '2057-04-01'),
	('2057-04-29', '2057-04-01'),
	('2057-04-30', '2057-04-01'),
	('2057-05-01', '2057-05-01'),
	('2057-05-02', '2057-05-01'),
	('2057-05-03', '2057-05-01'),
	('2057-05-04', '2057-05-01'),
	('2057-05-05', '2057-05-01'),
	('2057-05-06', '2057-05-01'),
	('2057-05-07', '2057-05-01'),
	('2057-05-08', '2057-05-01'),
	('2057-05-09', '2057-05-01'),
	('2057-05-10', '2057-05-01'),
	('2057-05-11', '2057-05-01'),
	('2057-05-12', '2057-05-01'),
	('2057-05-13', '2057-05-01'),
	('2057-05-14', '2057-05-01'),
	('2057-05-15', '2057-05-01'),
	('2057-05-16', '2057-05-01'),
	('2057-05-17', '2057-05-01'),
	('2057-05-18', '2057-05-01'),
	('2057-05-19', '2057-05-01'),
	('2057-05-20', '2057-05-01'),
	('2057-05-21', '2057-05-01'),
	('2057-05-22', '2057-05-01'),
	('2057-05-23', '2057-05-01'),
	('2057-05-24', '2057-05-01'),
	('2057-05-25', '2057-05-01'),
	('2057-05-26', '2057-05-01'),
	('2057-05-27', '2057-05-01'),
	('2057-05-28', '2057-05-01'),
	('2057-05-29', '2057-05-01'),
	('2057-05-30', '2057-05-01'),
	('2057-05-31', '2057-05-01'),
	('2057-06-01', '2057-06-01'),
	('2057-06-02', '2057-06-01'),
	('2057-06-03', '2057-06-01'),
	('2057-06-04', '2057-06-01'),
	('2057-06-05', '2057-06-01'),
	('2057-06-06', '2057-06-01'),
	('2057-06-07', '2057-06-01'),
	('2057-06-08', '2057-06-01'),
	('2057-06-09', '2057-06-01'),
	('2057-06-10', '2057-06-01'),
	('2057-06-11', '2057-06-01'),
	('2057-06-12', '2057-06-01'),
	('2057-06-13', '2057-06-01'),
	('2057-06-14', '2057-06-01'),
	('2057-06-15', '2057-06-01'),
	('2057-06-16', '2057-06-01'),
	('2057-06-17', '2057-06-01'),
	('2057-06-18', '2057-06-01'),
	('2057-06-19', '2057-06-01'),
	('2057-06-20', '2057-06-01'),
	('2057-06-21', '2057-06-01'),
	('2057-06-22', '2057-06-01'),
	('2057-06-23', '2057-06-01'),
	('2057-06-24', '2057-06-01'),
	('2057-06-25', '2057-06-01'),
	('2057-06-26', '2057-06-01'),
	('2057-06-27', '2057-06-01'),
	('2057-06-28', '2057-06-01'),
	('2057-06-29', '2057-06-01'),
	('2057-06-30', '2057-06-01'),
	('2057-07-01', '2057-07-01'),
	('2057-07-02', '2057-07-01'),
	('2057-07-03', '2057-07-01'),
	('2057-07-04', '2057-07-01'),
	('2057-07-05', '2057-07-01'),
	('2057-07-06', '2057-07-01'),
	('2057-07-07', '2057-07-01'),
	('2057-07-08', '2057-07-01'),
	('2057-07-09', '2057-07-01'),
	('2057-07-10', '2057-07-01'),
	('2057-07-11', '2057-07-01'),
	('2057-07-12', '2057-07-01'),
	('2057-07-13', '2057-07-01'),
	('2057-07-14', '2057-07-01'),
	('2057-07-15', '2057-07-01'),
	('2057-07-16', '2057-07-01'),
	('2057-07-17', '2057-07-01'),
	('2057-07-18', '2057-07-01'),
	('2057-07-19', '2057-07-01'),
	('2057-07-20', '2057-07-01'),
	('2057-07-21', '2057-07-01'),
	('2057-07-22', '2057-07-01'),
	('2057-07-23', '2057-07-01'),
	('2057-07-24', '2057-07-01'),
	('2057-07-25', '2057-07-01'),
	('2057-07-26', '2057-07-01'),
	('2057-07-27', '2057-07-01'),
	('2057-07-28', '2057-07-01'),
	('2057-07-29', '2057-07-01'),
	('2057-07-30', '2057-07-01'),
	('2057-07-31', '2057-07-01'),
	('2057-08-01', '2057-08-01'),
	('2057-08-02', '2057-08-01'),
	('2057-08-03', '2057-08-01'),
	('2057-08-04', '2057-08-01'),
	('2057-08-05', '2057-08-01'),
	('2057-08-06', '2057-08-01'),
	('2057-08-07', '2057-08-01'),
	('2057-08-08', '2057-08-01'),
	('2057-08-09', '2057-08-01'),
	('2057-08-10', '2057-08-01'),
	('2057-08-11', '2057-08-01'),
	('2057-08-12', '2057-08-01'),
	('2057-08-13', '2057-08-01'),
	('2057-08-14', '2057-08-01'),
	('2057-08-15', '2057-08-01'),
	('2057-08-16', '2057-08-01'),
	('2057-08-17', '2057-08-01'),
	('2057-08-18', '2057-08-01'),
	('2057-08-19', '2057-08-01'),
	('2057-08-20', '2057-08-01'),
	('2057-08-21', '2057-08-01'),
	('2057-08-22', '2057-08-01'),
	('2057-08-23', '2057-08-01'),
	('2057-08-24', '2057-08-01'),
	('2057-08-25', '2057-08-01'),
	('2057-08-26', '2057-08-01'),
	('2057-08-27', '2057-08-01'),
	('2057-08-28', '2057-08-01'),
	('2057-08-29', '2057-08-01'),
	('2057-08-30', '2057-08-01'),
	('2057-08-31', '2057-08-01'),
	('2057-09-01', '2057-09-01'),
	('2057-09-02', '2057-09-01'),
	('2057-09-03', '2057-09-01'),
	('2057-09-04', '2057-09-01'),
	('2057-09-05', '2057-09-01'),
	('2057-09-06', '2057-09-01'),
	('2057-09-07', '2057-09-01'),
	('2057-09-08', '2057-09-01'),
	('2057-09-09', '2057-09-01'),
	('2057-09-10', '2057-09-01'),
	('2057-09-11', '2057-09-01'),
	('2057-09-12', '2057-09-01'),
	('2057-09-13', '2057-09-01'),
	('2057-09-14', '2057-09-01'),
	('2057-09-15', '2057-09-01'),
	('2057-09-16', '2057-09-01'),
	('2057-09-17', '2057-09-01'),
	('2057-09-18', '2057-09-01'),
	('2057-09-19', '2057-09-01'),
	('2057-09-20', '2057-09-01'),
	('2057-09-21', '2057-09-01'),
	('2057-09-22', '2057-09-01'),
	('2057-09-23', '2057-09-01'),
	('2057-09-24', '2057-09-01'),
	('2057-09-25', '2057-09-01'),
	('2057-09-26', '2057-09-01'),
	('2057-09-27', '2057-09-01'),
	('2057-09-28', '2057-09-01'),
	('2057-09-29', '2057-09-01'),
	('2057-09-30', '2057-09-01'),
	('2057-10-01', '2057-10-01'),
	('2057-10-02', '2057-10-01'),
	('2057-10-03', '2057-10-01'),
	('2057-10-04', '2057-10-01'),
	('2057-10-05', '2057-10-01'),
	('2057-10-06', '2057-10-01'),
	('2057-10-07', '2057-10-01'),
	('2057-10-08', '2057-10-01'),
	('2057-10-09', '2057-10-01'),
	('2057-10-10', '2057-10-01'),
	('2057-10-11', '2057-10-01'),
	('2057-10-12', '2057-10-01'),
	('2057-10-13', '2057-10-01'),
	('2057-10-14', '2057-10-01'),
	('2057-10-15', '2057-10-01'),
	('2057-10-16', '2057-10-01'),
	('2057-10-17', '2057-10-01'),
	('2057-10-18', '2057-10-01'),
	('2057-10-19', '2057-10-01'),
	('2057-10-20', '2057-10-01'),
	('2057-10-21', '2057-10-01'),
	('2057-10-22', '2057-10-01'),
	('2057-10-23', '2057-10-01'),
	('2057-10-24', '2057-10-01'),
	('2057-10-25', '2057-10-01'),
	('2057-10-26', '2057-10-01'),
	('2057-10-27', '2057-10-01'),
	('2057-10-28', '2057-10-01'),
	('2057-10-29', '2057-10-01'),
	('2057-10-30', '2057-10-01'),
	('2057-10-31', '2057-10-01'),
	('2057-11-01', '2057-11-01'),
	('2057-11-02', '2057-11-01'),
	('2057-11-03', '2057-11-01'),
	('2057-11-04', '2057-11-01'),
	('2057-11-05', '2057-11-01'),
	('2057-11-06', '2057-11-01'),
	('2057-11-07', '2057-11-01'),
	('2057-11-08', '2057-11-01'),
	('2057-11-09', '2057-11-01'),
	('2057-11-10', '2057-11-01'),
	('2057-11-11', '2057-11-01'),
	('2057-11-12', '2057-11-01'),
	('2057-11-13', '2057-11-01'),
	('2057-11-14', '2057-11-01'),
	('2057-11-15', '2057-11-01'),
	('2057-11-16', '2057-11-01'),
	('2057-11-17', '2057-11-01'),
	('2057-11-18', '2057-11-01'),
	('2057-11-19', '2057-11-01'),
	('2057-11-20', '2057-11-01'),
	('2057-11-21', '2057-11-01'),
	('2057-11-22', '2057-11-01'),
	('2057-11-23', '2057-11-01'),
	('2057-11-24', '2057-11-01'),
	('2057-11-25', '2057-11-01'),
	('2057-11-26', '2057-11-01'),
	('2057-11-27', '2057-11-01'),
	('2057-11-28', '2057-11-01'),
	('2057-11-29', '2057-11-01'),
	('2057-11-30', '2057-11-01'),
	('2057-12-01', '2057-12-01'),
	('2057-12-02', '2057-12-01'),
	('2057-12-03', '2057-12-01'),
	('2057-12-04', '2057-12-01'),
	('2057-12-05', '2057-12-01'),
	('2057-12-06', '2057-12-01'),
	('2057-12-07', '2057-12-01'),
	('2057-12-08', '2057-12-01'),
	('2057-12-09', '2057-12-01'),
	('2057-12-10', '2057-12-01'),
	('2057-12-11', '2057-12-01'),
	('2057-12-12', '2057-12-01'),
	('2057-12-13', '2057-12-01'),
	('2057-12-14', '2057-12-01'),
	('2057-12-15', '2057-12-01'),
	('2057-12-16', '2057-12-01'),
	('2057-12-17', '2057-12-01'),
	('2057-12-18', '2057-12-01'),
	('2057-12-19', '2057-12-01'),
	('2057-12-20', '2057-12-01'),
	('2057-12-21', '2057-12-01'),
	('2057-12-22', '2057-12-01'),
	('2057-12-23', '2057-12-01'),
	('2057-12-24', '2057-12-01'),
	('2057-12-25', '2057-12-01'),
	('2057-12-26', '2057-12-01'),
	('2057-12-27', '2057-12-01'),
	('2057-12-28', '2057-12-01'),
	('2057-12-29', '2057-12-01'),
	('2057-12-30', '2057-12-01'),
	('2057-12-31', '2057-12-01'),
	('2058-01-01', '2058-01-01'),
	('2058-01-02', '2058-01-01'),
	('2058-01-03', '2058-01-01'),
	('2058-01-04', '2058-01-01'),
	('2058-01-05', '2058-01-01'),
	('2058-01-06', '2058-01-01'),
	('2058-01-07', '2058-01-01'),
	('2058-01-08', '2058-01-01'),
	('2058-01-09', '2058-01-01'),
	('2058-01-10', '2058-01-01'),
	('2058-01-11', '2058-01-01'),
	('2058-01-12', '2058-01-01'),
	('2058-01-13', '2058-01-01'),
	('2058-01-14', '2058-01-01'),
	('2058-01-15', '2058-01-01'),
	('2058-01-16', '2058-01-01'),
	('2058-01-17', '2058-01-01'),
	('2058-01-18', '2058-01-01'),
	('2058-01-19', '2058-01-01'),
	('2058-01-20', '2058-01-01'),
	('2058-01-21', '2058-01-01'),
	('2058-01-22', '2058-01-01'),
	('2058-01-23', '2058-01-01'),
	('2058-01-24', '2058-01-01'),
	('2058-01-25', '2058-01-01'),
	('2058-01-26', '2058-01-01'),
	('2058-01-27', '2058-01-01'),
	('2058-01-28', '2058-01-01'),
	('2058-01-29', '2058-01-01'),
	('2058-01-30', '2058-01-01'),
	('2058-01-31', '2058-01-01'),
	('2058-02-01', '2058-02-01'),
	('2058-02-02', '2058-02-01'),
	('2058-02-03', '2058-02-01'),
	('2058-02-04', '2058-02-01'),
	('2058-02-05', '2058-02-01'),
	('2058-02-06', '2058-02-01'),
	('2058-02-07', '2058-02-01'),
	('2058-02-08', '2058-02-01'),
	('2058-02-09', '2058-02-01'),
	('2058-02-10', '2058-02-01'),
	('2058-02-11', '2058-02-01'),
	('2058-02-12', '2058-02-01'),
	('2058-02-13', '2058-02-01'),
	('2058-02-14', '2058-02-01'),
	('2058-02-15', '2058-02-01'),
	('2058-02-16', '2058-02-01'),
	('2058-02-17', '2058-02-01'),
	('2058-02-18', '2058-02-01'),
	('2058-02-19', '2058-02-01'),
	('2058-02-20', '2058-02-01'),
	('2058-02-21', '2058-02-01'),
	('2058-02-22', '2058-02-01'),
	('2058-02-23', '2058-02-01'),
	('2058-02-24', '2058-02-01'),
	('2058-02-25', '2058-02-01'),
	('2058-02-26', '2058-02-01'),
	('2058-02-27', '2058-02-01'),
	('2058-02-28', '2058-02-01'),
	('2058-03-01', '2058-03-01'),
	('2058-03-02', '2058-03-01'),
	('2058-03-03', '2058-03-01'),
	('2058-03-04', '2058-03-01'),
	('2058-03-05', '2058-03-01'),
	('2058-03-06', '2058-03-01'),
	('2058-03-07', '2058-03-01'),
	('2058-03-08', '2058-03-01'),
	('2058-03-09', '2058-03-01'),
	('2058-03-10', '2058-03-01'),
	('2058-03-11', '2058-03-01'),
	('2058-03-12', '2058-03-01'),
	('2058-03-13', '2058-03-01'),
	('2058-03-14', '2058-03-01'),
	('2058-03-15', '2058-03-01'),
	('2058-03-16', '2058-03-01'),
	('2058-03-17', '2058-03-01'),
	('2058-03-18', '2058-03-01'),
	('2058-03-19', '2058-03-01'),
	('2058-03-20', '2058-03-01'),
	('2058-03-21', '2058-03-01'),
	('2058-03-22', '2058-03-01'),
	('2058-03-23', '2058-03-01'),
	('2058-03-24', '2058-03-01'),
	('2058-03-25', '2058-03-01'),
	('2058-03-26', '2058-03-01'),
	('2058-03-27', '2058-03-01'),
	('2058-03-28', '2058-03-01'),
	('2058-03-29', '2058-03-01'),
	('2058-03-30', '2058-03-01'),
	('2058-03-31', '2058-03-01'),
	('2058-04-01', '2058-04-01'),
	('2058-04-02', '2058-04-01'),
	('2058-04-03', '2058-04-01'),
	('2058-04-04', '2058-04-01'),
	('2058-04-05', '2058-04-01'),
	('2058-04-06', '2058-04-01'),
	('2058-04-07', '2058-04-01'),
	('2058-04-08', '2058-04-01'),
	('2058-04-09', '2058-04-01'),
	('2058-04-10', '2058-04-01'),
	('2058-04-11', '2058-04-01'),
	('2058-04-12', '2058-04-01'),
	('2058-04-13', '2058-04-01'),
	('2058-04-14', '2058-04-01'),
	('2058-04-15', '2058-04-01'),
	('2058-04-16', '2058-04-01'),
	('2058-04-17', '2058-04-01'),
	('2058-04-18', '2058-04-01'),
	('2058-04-19', '2058-04-01'),
	('2058-04-20', '2058-04-01'),
	('2058-04-21', '2058-04-01'),
	('2058-04-22', '2058-04-01'),
	('2058-04-23', '2058-04-01'),
	('2058-04-24', '2058-04-01'),
	('2058-04-25', '2058-04-01'),
	('2058-04-26', '2058-04-01'),
	('2058-04-27', '2058-04-01'),
	('2058-04-28', '2058-04-01'),
	('2058-04-29', '2058-04-01'),
	('2058-04-30', '2058-04-01'),
	('2058-05-01', '2058-05-01'),
	('2058-05-02', '2058-05-01'),
	('2058-05-03', '2058-05-01'),
	('2058-05-04', '2058-05-01'),
	('2058-05-05', '2058-05-01'),
	('2058-05-06', '2058-05-01'),
	('2058-05-07', '2058-05-01'),
	('2058-05-08', '2058-05-01'),
	('2058-05-09', '2058-05-01'),
	('2058-05-10', '2058-05-01'),
	('2058-05-11', '2058-05-01'),
	('2058-05-12', '2058-05-01'),
	('2058-05-13', '2058-05-01'),
	('2058-05-14', '2058-05-01'),
	('2058-05-15', '2058-05-01'),
	('2058-05-16', '2058-05-01'),
	('2058-05-17', '2058-05-01'),
	('2058-05-18', '2058-05-01'),
	('2058-05-19', '2058-05-01'),
	('2058-05-20', '2058-05-01'),
	('2058-05-21', '2058-05-01'),
	('2058-05-22', '2058-05-01'),
	('2058-05-23', '2058-05-01'),
	('2058-05-24', '2058-05-01'),
	('2058-05-25', '2058-05-01'),
	('2058-05-26', '2058-05-01'),
	('2058-05-27', '2058-05-01'),
	('2058-05-28', '2058-05-01'),
	('2058-05-29', '2058-05-01'),
	('2058-05-30', '2058-05-01'),
	('2058-05-31', '2058-05-01'),
	('2058-06-01', '2058-06-01'),
	('2058-06-02', '2058-06-01'),
	('2058-06-03', '2058-06-01'),
	('2058-06-04', '2058-06-01'),
	('2058-06-05', '2058-06-01'),
	('2058-06-06', '2058-06-01'),
	('2058-06-07', '2058-06-01'),
	('2058-06-08', '2058-06-01'),
	('2058-06-09', '2058-06-01'),
	('2058-06-10', '2058-06-01'),
	('2058-06-11', '2058-06-01'),
	('2058-06-12', '2058-06-01'),
	('2058-06-13', '2058-06-01'),
	('2058-06-14', '2058-06-01'),
	('2058-06-15', '2058-06-01'),
	('2058-06-16', '2058-06-01'),
	('2058-06-17', '2058-06-01'),
	('2058-06-18', '2058-06-01'),
	('2058-06-19', '2058-06-01'),
	('2058-06-20', '2058-06-01'),
	('2058-06-21', '2058-06-01'),
	('2058-06-22', '2058-06-01'),
	('2058-06-23', '2058-06-01'),
	('2058-06-24', '2058-06-01'),
	('2058-06-25', '2058-06-01'),
	('2058-06-26', '2058-06-01'),
	('2058-06-27', '2058-06-01'),
	('2058-06-28', '2058-06-01'),
	('2058-06-29', '2058-06-01'),
	('2058-06-30', '2058-06-01'),
	('2058-07-01', '2058-07-01'),
	('2058-07-02', '2058-07-01'),
	('2058-07-03', '2058-07-01'),
	('2058-07-04', '2058-07-01'),
	('2058-07-05', '2058-07-01'),
	('2058-07-06', '2058-07-01'),
	('2058-07-07', '2058-07-01'),
	('2058-07-08', '2058-07-01'),
	('2058-07-09', '2058-07-01'),
	('2058-07-10', '2058-07-01'),
	('2058-07-11', '2058-07-01'),
	('2058-07-12', '2058-07-01'),
	('2058-07-13', '2058-07-01'),
	('2058-07-14', '2058-07-01'),
	('2058-07-15', '2058-07-01'),
	('2058-07-16', '2058-07-01'),
	('2058-07-17', '2058-07-01'),
	('2058-07-18', '2058-07-01'),
	('2058-07-19', '2058-07-01'),
	('2058-07-20', '2058-07-01'),
	('2058-07-21', '2058-07-01'),
	('2058-07-22', '2058-07-01'),
	('2058-07-23', '2058-07-01'),
	('2058-07-24', '2058-07-01'),
	('2058-07-25', '2058-07-01'),
	('2058-07-26', '2058-07-01'),
	('2058-07-27', '2058-07-01'),
	('2058-07-28', '2058-07-01'),
	('2058-07-29', '2058-07-01'),
	('2058-07-30', '2058-07-01'),
	('2058-07-31', '2058-07-01'),
	('2058-08-01', '2058-08-01'),
	('2058-08-02', '2058-08-01'),
	('2058-08-03', '2058-08-01'),
	('2058-08-04', '2058-08-01'),
	('2058-08-05', '2058-08-01'),
	('2058-08-06', '2058-08-01'),
	('2058-08-07', '2058-08-01'),
	('2058-08-08', '2058-08-01'),
	('2058-08-09', '2058-08-01'),
	('2058-08-10', '2058-08-01'),
	('2058-08-11', '2058-08-01'),
	('2058-08-12', '2058-08-01'),
	('2058-08-13', '2058-08-01'),
	('2058-08-14', '2058-08-01'),
	('2058-08-15', '2058-08-01'),
	('2058-08-16', '2058-08-01'),
	('2058-08-17', '2058-08-01'),
	('2058-08-18', '2058-08-01'),
	('2058-08-19', '2058-08-01'),
	('2058-08-20', '2058-08-01'),
	('2058-08-21', '2058-08-01'),
	('2058-08-22', '2058-08-01'),
	('2058-08-23', '2058-08-01'),
	('2058-08-24', '2058-08-01'),
	('2058-08-25', '2058-08-01'),
	('2058-08-26', '2058-08-01'),
	('2058-08-27', '2058-08-01'),
	('2058-08-28', '2058-08-01'),
	('2058-08-29', '2058-08-01'),
	('2058-08-30', '2058-08-01'),
	('2058-08-31', '2058-08-01'),
	('2058-09-01', '2058-09-01'),
	('2058-09-02', '2058-09-01'),
	('2058-09-03', '2058-09-01'),
	('2058-09-04', '2058-09-01'),
	('2058-09-05', '2058-09-01'),
	('2058-09-06', '2058-09-01'),
	('2058-09-07', '2058-09-01'),
	('2058-09-08', '2058-09-01'),
	('2058-09-09', '2058-09-01'),
	('2058-09-10', '2058-09-01'),
	('2058-09-11', '2058-09-01'),
	('2058-09-12', '2058-09-01'),
	('2058-09-13', '2058-09-01'),
	('2058-09-14', '2058-09-01'),
	('2058-09-15', '2058-09-01'),
	('2058-09-16', '2058-09-01'),
	('2058-09-17', '2058-09-01'),
	('2058-09-18', '2058-09-01'),
	('2058-09-19', '2058-09-01'),
	('2058-09-20', '2058-09-01'),
	('2058-09-21', '2058-09-01'),
	('2058-09-22', '2058-09-01'),
	('2058-09-23', '2058-09-01'),
	('2058-09-24', '2058-09-01'),
	('2058-09-25', '2058-09-01'),
	('2058-09-26', '2058-09-01'),
	('2058-09-27', '2058-09-01'),
	('2058-09-28', '2058-09-01'),
	('2058-09-29', '2058-09-01'),
	('2058-09-30', '2058-09-01'),
	('2058-10-01', '2058-10-01'),
	('2058-10-02', '2058-10-01'),
	('2058-10-03', '2058-10-01'),
	('2058-10-04', '2058-10-01'),
	('2058-10-05', '2058-10-01'),
	('2058-10-06', '2058-10-01'),
	('2058-10-07', '2058-10-01'),
	('2058-10-08', '2058-10-01'),
	('2058-10-09', '2058-10-01'),
	('2058-10-10', '2058-10-01'),
	('2058-10-11', '2058-10-01'),
	('2058-10-12', '2058-10-01'),
	('2058-10-13', '2058-10-01'),
	('2058-10-14', '2058-10-01'),
	('2058-10-15', '2058-10-01'),
	('2058-10-16', '2058-10-01'),
	('2058-10-17', '2058-10-01'),
	('2058-10-18', '2058-10-01'),
	('2058-10-19', '2058-10-01'),
	('2058-10-20', '2058-10-01'),
	('2058-10-21', '2058-10-01'),
	('2058-10-22', '2058-10-01'),
	('2058-10-23', '2058-10-01'),
	('2058-10-24', '2058-10-01'),
	('2058-10-25', '2058-10-01'),
	('2058-10-26', '2058-10-01'),
	('2058-10-27', '2058-10-01'),
	('2058-10-28', '2058-10-01'),
	('2058-10-29', '2058-10-01'),
	('2058-10-30', '2058-10-01'),
	('2058-10-31', '2058-10-01'),
	('2058-11-01', '2058-11-01'),
	('2058-11-02', '2058-11-01'),
	('2058-11-03', '2058-11-01'),
	('2058-11-04', '2058-11-01'),
	('2058-11-05', '2058-11-01'),
	('2058-11-06', '2058-11-01'),
	('2058-11-07', '2058-11-01'),
	('2058-11-08', '2058-11-01'),
	('2058-11-09', '2058-11-01'),
	('2058-11-10', '2058-11-01'),
	('2058-11-11', '2058-11-01'),
	('2058-11-12', '2058-11-01'),
	('2058-11-13', '2058-11-01'),
	('2058-11-14', '2058-11-01'),
	('2058-11-15', '2058-11-01'),
	('2058-11-16', '2058-11-01'),
	('2058-11-17', '2058-11-01'),
	('2058-11-18', '2058-11-01'),
	('2058-11-19', '2058-11-01'),
	('2058-11-20', '2058-11-01'),
	('2058-11-21', '2058-11-01'),
	('2058-11-22', '2058-11-01'),
	('2058-11-23', '2058-11-01'),
	('2058-11-24', '2058-11-01'),
	('2058-11-25', '2058-11-01'),
	('2058-11-26', '2058-11-01'),
	('2058-11-27', '2058-11-01'),
	('2058-11-28', '2058-11-01'),
	('2058-11-29', '2058-11-01'),
	('2058-11-30', '2058-11-01'),
	('2058-12-01', '2058-12-01'),
	('2058-12-02', '2058-12-01'),
	('2058-12-03', '2058-12-01'),
	('2058-12-04', '2058-12-01'),
	('2058-12-05', '2058-12-01'),
	('2058-12-06', '2058-12-01'),
	('2058-12-07', '2058-12-01'),
	('2058-12-08', '2058-12-01'),
	('2058-12-09', '2058-12-01'),
	('2058-12-10', '2058-12-01'),
	('2058-12-11', '2058-12-01'),
	('2058-12-12', '2058-12-01'),
	('2058-12-13', '2058-12-01'),
	('2058-12-14', '2058-12-01'),
	('2058-12-15', '2058-12-01'),
	('2058-12-16', '2058-12-01'),
	('2058-12-17', '2058-12-01'),
	('2058-12-18', '2058-12-01'),
	('2058-12-19', '2058-12-01'),
	('2058-12-20', '2058-12-01'),
	('2058-12-21', '2058-12-01'),
	('2058-12-22', '2058-12-01'),
	('2058-12-23', '2058-12-01'),
	('2058-12-24', '2058-12-01'),
	('2058-12-25', '2058-12-01'),
	('2058-12-26', '2058-12-01'),
	('2058-12-27', '2058-12-01'),
	('2058-12-28', '2058-12-01'),
	('2058-12-29', '2058-12-01'),
	('2058-12-30', '2058-12-01'),
	('2058-12-31', '2058-12-01'),
	('2059-01-01', '2059-01-01'),
	('2059-01-02', '2059-01-01'),
	('2059-01-03', '2059-01-01'),
	('2059-01-04', '2059-01-01'),
	('2059-01-05', '2059-01-01'),
	('2059-01-06', '2059-01-01'),
	('2059-01-07', '2059-01-01'),
	('2059-01-08', '2059-01-01'),
	('2059-01-09', '2059-01-01'),
	('2059-01-10', '2059-01-01'),
	('2059-01-11', '2059-01-01'),
	('2059-01-12', '2059-01-01'),
	('2059-01-13', '2059-01-01'),
	('2059-01-14', '2059-01-01'),
	('2059-01-15', '2059-01-01'),
	('2059-01-16', '2059-01-01'),
	('2059-01-17', '2059-01-01'),
	('2059-01-18', '2059-01-01'),
	('2059-01-19', '2059-01-01'),
	('2059-01-20', '2059-01-01'),
	('2059-01-21', '2059-01-01'),
	('2059-01-22', '2059-01-01'),
	('2059-01-23', '2059-01-01'),
	('2059-01-24', '2059-01-01'),
	('2059-01-25', '2059-01-01'),
	('2059-01-26', '2059-01-01'),
	('2059-01-27', '2059-01-01'),
	('2059-01-28', '2059-01-01'),
	('2059-01-29', '2059-01-01'),
	('2059-01-30', '2059-01-01'),
	('2059-01-31', '2059-01-01'),
	('2059-02-01', '2059-02-01'),
	('2059-02-02', '2059-02-01'),
	('2059-02-03', '2059-02-01'),
	('2059-02-04', '2059-02-01'),
	('2059-02-05', '2059-02-01'),
	('2059-02-06', '2059-02-01'),
	('2059-02-07', '2059-02-01'),
	('2059-02-08', '2059-02-01'),
	('2059-02-09', '2059-02-01'),
	('2059-02-10', '2059-02-01'),
	('2059-02-11', '2059-02-01'),
	('2059-02-12', '2059-02-01'),
	('2059-02-13', '2059-02-01'),
	('2059-02-14', '2059-02-01'),
	('2059-02-15', '2059-02-01'),
	('2059-02-16', '2059-02-01'),
	('2059-02-17', '2059-02-01'),
	('2059-02-18', '2059-02-01'),
	('2059-02-19', '2059-02-01'),
	('2059-02-20', '2059-02-01'),
	('2059-02-21', '2059-02-01'),
	('2059-02-22', '2059-02-01'),
	('2059-02-23', '2059-02-01'),
	('2059-02-24', '2059-02-01'),
	('2059-02-25', '2059-02-01'),
	('2059-02-26', '2059-02-01'),
	('2059-02-27', '2059-02-01'),
	('2059-02-28', '2059-02-01'),
	('2059-03-01', '2059-03-01'),
	('2059-03-02', '2059-03-01'),
	('2059-03-03', '2059-03-01'),
	('2059-03-04', '2059-03-01'),
	('2059-03-05', '2059-03-01'),
	('2059-03-06', '2059-03-01'),
	('2059-03-07', '2059-03-01'),
	('2059-03-08', '2059-03-01'),
	('2059-03-09', '2059-03-01'),
	('2059-03-10', '2059-03-01'),
	('2059-03-11', '2059-03-01'),
	('2059-03-12', '2059-03-01'),
	('2059-03-13', '2059-03-01'),
	('2059-03-14', '2059-03-01'),
	('2059-03-15', '2059-03-01'),
	('2059-03-16', '2059-03-01'),
	('2059-03-17', '2059-03-01'),
	('2059-03-18', '2059-03-01'),
	('2059-03-19', '2059-03-01'),
	('2059-03-20', '2059-03-01'),
	('2059-03-21', '2059-03-01'),
	('2059-03-22', '2059-03-01'),
	('2059-03-23', '2059-03-01'),
	('2059-03-24', '2059-03-01'),
	('2059-03-25', '2059-03-01'),
	('2059-03-26', '2059-03-01'),
	('2059-03-27', '2059-03-01'),
	('2059-03-28', '2059-03-01'),
	('2059-03-29', '2059-03-01'),
	('2059-03-30', '2059-03-01'),
	('2059-03-31', '2059-03-01'),
	('2059-04-01', '2059-04-01'),
	('2059-04-02', '2059-04-01'),
	('2059-04-03', '2059-04-01'),
	('2059-04-04', '2059-04-01'),
	('2059-04-05', '2059-04-01'),
	('2059-04-06', '2059-04-01'),
	('2059-04-07', '2059-04-01'),
	('2059-04-08', '2059-04-01'),
	('2059-04-09', '2059-04-01'),
	('2059-04-10', '2059-04-01'),
	('2059-04-11', '2059-04-01'),
	('2059-04-12', '2059-04-01'),
	('2059-04-13', '2059-04-01'),
	('2059-04-14', '2059-04-01'),
	('2059-04-15', '2059-04-01'),
	('2059-04-16', '2059-04-01'),
	('2059-04-17', '2059-04-01'),
	('2059-04-18', '2059-04-01'),
	('2059-04-19', '2059-04-01'),
	('2059-04-20', '2059-04-01'),
	('2059-04-21', '2059-04-01'),
	('2059-04-22', '2059-04-01'),
	('2059-04-23', '2059-04-01'),
	('2059-04-24', '2059-04-01'),
	('2059-04-25', '2059-04-01'),
	('2059-04-26', '2059-04-01'),
	('2059-04-27', '2059-04-01'),
	('2059-04-28', '2059-04-01'),
	('2059-04-29', '2059-04-01'),
	('2059-04-30', '2059-04-01'),
	('2059-05-01', '2059-05-01'),
	('2059-05-02', '2059-05-01'),
	('2059-05-03', '2059-05-01'),
	('2059-05-04', '2059-05-01'),
	('2059-05-05', '2059-05-01'),
	('2059-05-06', '2059-05-01'),
	('2059-05-07', '2059-05-01'),
	('2059-05-08', '2059-05-01'),
	('2059-05-09', '2059-05-01'),
	('2059-05-10', '2059-05-01'),
	('2059-05-11', '2059-05-01'),
	('2059-05-12', '2059-05-01'),
	('2059-05-13', '2059-05-01'),
	('2059-05-14', '2059-05-01'),
	('2059-05-15', '2059-05-01'),
	('2059-05-16', '2059-05-01'),
	('2059-05-17', '2059-05-01'),
	('2059-05-18', '2059-05-01'),
	('2059-05-19', '2059-05-01'),
	('2059-05-20', '2059-05-01'),
	('2059-05-21', '2059-05-01'),
	('2059-05-22', '2059-05-01'),
	('2059-05-23', '2059-05-01'),
	('2059-05-24', '2059-05-01'),
	('2059-05-25', '2059-05-01'),
	('2059-05-26', '2059-05-01'),
	('2059-05-27', '2059-05-01'),
	('2059-05-28', '2059-05-01'),
	('2059-05-29', '2059-05-01'),
	('2059-05-30', '2059-05-01'),
	('2059-05-31', '2059-05-01'),
	('2059-06-01', '2059-06-01'),
	('2059-06-02', '2059-06-01'),
	('2059-06-03', '2059-06-01'),
	('2059-06-04', '2059-06-01'),
	('2059-06-05', '2059-06-01'),
	('2059-06-06', '2059-06-01'),
	('2059-06-07', '2059-06-01'),
	('2059-06-08', '2059-06-01'),
	('2059-06-09', '2059-06-01'),
	('2059-06-10', '2059-06-01'),
	('2059-06-11', '2059-06-01'),
	('2059-06-12', '2059-06-01'),
	('2059-06-13', '2059-06-01'),
	('2059-06-14', '2059-06-01'),
	('2059-06-15', '2059-06-01'),
	('2059-06-16', '2059-06-01'),
	('2059-06-17', '2059-06-01'),
	('2059-06-18', '2059-06-01'),
	('2059-06-19', '2059-06-01'),
	('2059-06-20', '2059-06-01'),
	('2059-06-21', '2059-06-01'),
	('2059-06-22', '2059-06-01'),
	('2059-06-23', '2059-06-01'),
	('2059-06-24', '2059-06-01'),
	('2059-06-25', '2059-06-01'),
	('2059-06-26', '2059-06-01'),
	('2059-06-27', '2059-06-01'),
	('2059-06-28', '2059-06-01'),
	('2059-06-29', '2059-06-01'),
	('2059-06-30', '2059-06-01'),
	('2059-07-01', '2059-07-01'),
	('2059-07-02', '2059-07-01'),
	('2059-07-03', '2059-07-01'),
	('2059-07-04', '2059-07-01'),
	('2059-07-05', '2059-07-01'),
	('2059-07-06', '2059-07-01'),
	('2059-07-07', '2059-07-01'),
	('2059-07-08', '2059-07-01'),
	('2059-07-09', '2059-07-01'),
	('2059-07-10', '2059-07-01'),
	('2059-07-11', '2059-07-01'),
	('2059-07-12', '2059-07-01'),
	('2059-07-13', '2059-07-01'),
	('2059-07-14', '2059-07-01'),
	('2059-07-15', '2059-07-01'),
	('2059-07-16', '2059-07-01'),
	('2059-07-17', '2059-07-01'),
	('2059-07-18', '2059-07-01'),
	('2059-07-19', '2059-07-01'),
	('2059-07-20', '2059-07-01'),
	('2059-07-21', '2059-07-01'),
	('2059-07-22', '2059-07-01'),
	('2059-07-23', '2059-07-01'),
	('2059-07-24', '2059-07-01'),
	('2059-07-25', '2059-07-01'),
	('2059-07-26', '2059-07-01'),
	('2059-07-27', '2059-07-01'),
	('2059-07-28', '2059-07-01'),
	('2059-07-29', '2059-07-01'),
	('2059-07-30', '2059-07-01'),
	('2059-07-31', '2059-07-01'),
	('2059-08-01', '2059-08-01'),
	('2059-08-02', '2059-08-01'),
	('2059-08-03', '2059-08-01'),
	('2059-08-04', '2059-08-01'),
	('2059-08-05', '2059-08-01'),
	('2059-08-06', '2059-08-01'),
	('2059-08-07', '2059-08-01'),
	('2059-08-08', '2059-08-01'),
	('2059-08-09', '2059-08-01'),
	('2059-08-10', '2059-08-01'),
	('2059-08-11', '2059-08-01'),
	('2059-08-12', '2059-08-01'),
	('2059-08-13', '2059-08-01'),
	('2059-08-14', '2059-08-01'),
	('2059-08-15', '2059-08-01'),
	('2059-08-16', '2059-08-01'),
	('2059-08-17', '2059-08-01'),
	('2059-08-18', '2059-08-01'),
	('2059-08-19', '2059-08-01'),
	('2059-08-20', '2059-08-01'),
	('2059-08-21', '2059-08-01'),
	('2059-08-22', '2059-08-01'),
	('2059-08-23', '2059-08-01'),
	('2059-08-24', '2059-08-01'),
	('2059-08-25', '2059-08-01'),
	('2059-08-26', '2059-08-01'),
	('2059-08-27', '2059-08-01'),
	('2059-08-28', '2059-08-01'),
	('2059-08-29', '2059-08-01'),
	('2059-08-30', '2059-08-01'),
	('2059-08-31', '2059-08-01'),
	('2059-09-01', '2059-09-01'),
	('2059-09-02', '2059-09-01'),
	('2059-09-03', '2059-09-01'),
	('2059-09-04', '2059-09-01'),
	('2059-09-05', '2059-09-01'),
	('2059-09-06', '2059-09-01'),
	('2059-09-07', '2059-09-01'),
	('2059-09-08', '2059-09-01'),
	('2059-09-09', '2059-09-01'),
	('2059-09-10', '2059-09-01'),
	('2059-09-11', '2059-09-01'),
	('2059-09-12', '2059-09-01'),
	('2059-09-13', '2059-09-01'),
	('2059-09-14', '2059-09-01'),
	('2059-09-15', '2059-09-01'),
	('2059-09-16', '2059-09-01'),
	('2059-09-17', '2059-09-01'),
	('2059-09-18', '2059-09-01'),
	('2059-09-19', '2059-09-01'),
	('2059-09-20', '2059-09-01'),
	('2059-09-21', '2059-09-01'),
	('2059-09-22', '2059-09-01'),
	('2059-09-23', '2059-09-01'),
	('2059-09-24', '2059-09-01'),
	('2059-09-25', '2059-09-01'),
	('2059-09-26', '2059-09-01'),
	('2059-09-27', '2059-09-01'),
	('2059-09-28', '2059-09-01'),
	('2059-09-29', '2059-09-01'),
	('2059-09-30', '2059-09-01'),
	('2059-10-01', '2059-10-01'),
	('2059-10-02', '2059-10-01'),
	('2059-10-03', '2059-10-01'),
	('2059-10-04', '2059-10-01'),
	('2059-10-05', '2059-10-01'),
	('2059-10-06', '2059-10-01'),
	('2059-10-07', '2059-10-01'),
	('2059-10-08', '2059-10-01'),
	('2059-10-09', '2059-10-01'),
	('2059-10-10', '2059-10-01'),
	('2059-10-11', '2059-10-01'),
	('2059-10-12', '2059-10-01'),
	('2059-10-13', '2059-10-01'),
	('2059-10-14', '2059-10-01'),
	('2059-10-15', '2059-10-01'),
	('2059-10-16', '2059-10-01'),
	('2059-10-17', '2059-10-01'),
	('2059-10-18', '2059-10-01'),
	('2059-10-19', '2059-10-01'),
	('2059-10-20', '2059-10-01'),
	('2059-10-21', '2059-10-01'),
	('2059-10-22', '2059-10-01'),
	('2059-10-23', '2059-10-01'),
	('2059-10-24', '2059-10-01'),
	('2059-10-25', '2059-10-01'),
	('2059-10-26', '2059-10-01'),
	('2059-10-27', '2059-10-01'),
	('2059-10-28', '2059-10-01'),
	('2059-10-29', '2059-10-01'),
	('2059-10-30', '2059-10-01'),
	('2059-10-31', '2059-10-01'),
	('2059-11-01', '2059-11-01'),
	('2059-11-02', '2059-11-01'),
	('2059-11-03', '2059-11-01'),
	('2059-11-04', '2059-11-01'),
	('2059-11-05', '2059-11-01'),
	('2059-11-06', '2059-11-01'),
	('2059-11-07', '2059-11-01'),
	('2059-11-08', '2059-11-01'),
	('2059-11-09', '2059-11-01'),
	('2059-11-10', '2059-11-01'),
	('2059-11-11', '2059-11-01'),
	('2059-11-12', '2059-11-01'),
	('2059-11-13', '2059-11-01'),
	('2059-11-14', '2059-11-01'),
	('2059-11-15', '2059-11-01'),
	('2059-11-16', '2059-11-01'),
	('2059-11-17', '2059-11-01'),
	('2059-11-18', '2059-11-01'),
	('2059-11-19', '2059-11-01'),
	('2059-11-20', '2059-11-01'),
	('2059-11-21', '2059-11-01'),
	('2059-11-22', '2059-11-01'),
	('2059-11-23', '2059-11-01'),
	('2059-11-24', '2059-11-01'),
	('2059-11-25', '2059-11-01'),
	('2059-11-26', '2059-11-01'),
	('2059-11-27', '2059-11-01'),
	('2059-11-28', '2059-11-01'),
	('2059-11-29', '2059-11-01'),
	('2059-11-30', '2059-11-01'),
	('2059-12-01', '2059-12-01'),
	('2059-12-02', '2059-12-01'),
	('2059-12-03', '2059-12-01'),
	('2059-12-04', '2059-12-01'),
	('2059-12-05', '2059-12-01'),
	('2059-12-06', '2059-12-01'),
	('2059-12-07', '2059-12-01'),
	('2059-12-08', '2059-12-01'),
	('2059-12-09', '2059-12-01'),
	('2059-12-10', '2059-12-01'),
	('2059-12-11', '2059-12-01'),
	('2059-12-12', '2059-12-01'),
	('2059-12-13', '2059-12-01'),
	('2059-12-14', '2059-12-01'),
	('2059-12-15', '2059-12-01'),
	('2059-12-16', '2059-12-01'),
	('2059-12-17', '2059-12-01'),
	('2059-12-18', '2059-12-01'),
	('2059-12-19', '2059-12-01'),
	('2059-12-20', '2059-12-01'),
	('2059-12-21', '2059-12-01'),
	('2059-12-22', '2059-12-01'),
	('2059-12-23', '2059-12-01'),
	('2059-12-24', '2059-12-01'),
	('2059-12-25', '2059-12-01'),
	('2059-12-26', '2059-12-01'),
	('2059-12-27', '2059-12-01'),
	('2059-12-28', '2059-12-01'),
	('2059-12-29', '2059-12-01'),
	('2059-12-30', '2059-12-01'),
	('2059-12-31', '2059-12-01'),
	('2060-01-01', '2060-01-01');
/*!40000 ALTER TABLE `days` ENABLE KEYS */;

-- Dumping structure for table emcor.dc
CREATE TABLE IF NOT EXISTS `dc` (
  `dc_id` tinyint(3) unsigned NOT NULL COMMENT 'Sprendimo identifikatorius',
  `dc_name` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'Sprendimo pavadinimas',
  PRIMARY KEY (`dc_id`),
  UNIQUE KEY `dc_name_u` (`dc_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Galimi sprendimai';

-- Dumping data for table emcor.dc: ~3 rows (approximately)
/*!40000 ALTER TABLE `dc` DISABLE KEYS */;
INSERT INTO `dc` (`dc_id`, `dc_name`) VALUES
	(2, 'Atmesti'),
	(1, 'Priimti'),
	(3, 'Tęsti');
/*!40000 ALTER TABLE `dc` ENABLE KEYS */;

-- Dumping structure for table emcor.dev
CREATE TABLE IF NOT EXISTS `dev` (
  `dev_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Duomenų koncentratoriaus identifikatorius',
  `dev_type_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų koncentratoriaus tipo identifikatorius',
  `dev_number` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų koncentratoriaus numeris',
  `imei` varchar(20) COLLATE utf8_bin DEFAULT NULL COMMENT 'IMEI',
  PRIMARY KEY (`dev_id`),
  UNIQUE KEY `dev_number_u` (`dev_number`,`dev_type_id`),
  UNIQUE KEY `dev_imei_u` (`imei`),
  KEY `dev_dev_type_i` (`dev_type_id`),
  CONSTRAINT `dev_dev_type_fk` FOREIGN KEY (`dev_type_id`) REFERENCES `dev_type` (`dev_type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų koncentratoriai';

-- Dumping data for table emcor.dev: ~0 rows (approximately)
/*!40000 ALTER TABLE `dev` DISABLE KEYS */;
/*!40000 ALTER TABLE `dev` ENABLE KEYS */;

-- Dumping structure for table emcor.devdp
CREATE TABLE IF NOT EXISTS `devdp` (
  `devdp_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Koncentratoriaus periodo duomenų nuskaitymo taške identifikatorius',
  `dev_id` int(10) unsigned NOT NULL COMMENT 'Duomenų koncentratoriaus identifikatorius',
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `dev_dp_bt` datetime DEFAULT NULL COMMENT 'Duomenų koncentratoriaus periodo pradžia duomenų nuskaitymo taške',
  `dev_dp_et` datetime DEFAULT NULL COMMENT 'Duomenų koncentratoriaus periodo pabaiga duomenų nuskaitymo taške',
  PRIMARY KEY (`devdp_id`),
  KEY `devdp_dev_i` (`dev_id`,`dev_dp_bt`,`dev_dp_et`),
  KEY `devdp_dp_i` (`dp_id`),
  CONSTRAINT `devdp_dev_fk` FOREIGN KEY (`dev_id`) REFERENCES `dev` (`dev_id`) ON DELETE CASCADE,
  CONSTRAINT `devdp_dp_fk` FOREIGN KEY (`dp_id`) REFERENCES `dp` (`dp_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų koncentratorių montavimų duomenų nuskaitymo taškuose istorija';

-- Dumping data for table emcor.devdp: ~0 rows (approximately)
/*!40000 ALTER TABLE `devdp` DISABLE KEYS */;
/*!40000 ALTER TABLE `devdp` ENABLE KEYS */;

-- Dumping structure for table emcor.dev_type
CREATE TABLE IF NOT EXISTS `dev_type` (
  `dev_type_id` smallint(5) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Duomenų koncentratoriaus tipo identifikatorius',
  `dev_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų koncentratoriaus tipo pavadinimas',
  PRIMARY KEY (`dev_type_id`),
  UNIQUE KEY `dev_type_name_u` (`dev_type_name`)
) ENGINE=InnoDB AUTO_INCREMENT=63 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų koncentratorių tipai';

-- Dumping data for table emcor.dev_type: ~4 rows (approximately)
/*!40000 ALTER TABLE `dev_type` DISABLE KEYS */;
INSERT INTO `dev_type` (`dev_type_id`, `dev_type_name`) VALUES
	(6, 'MCL'),
	(5, 'MDC'),
	(62, 'SICON 200'),
	(7, 'VALSENA');
/*!40000 ALTER TABLE `dev_type` ENABLE KEYS */;

-- Dumping structure for table emcor.dew
CREATE TABLE IF NOT EXISTS `dew` (
  `dew_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Koncentratorių įvykių, registruojamų įvykių registre, sąlygos ID',
  `dew_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Koncentratorių įvykių, registruojamų įvykių registre, sąlygos pavadinimas',
  `dew_enabled` tinyint(1) NOT NULL COMMENT 'Koncentratorių įvykių, registruojamų įvykių registre, sąlygos galiojimo požymis',
  `withe_type_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų vytelių tipo identifikatorius',
  `withe_id` mediumint(8) DEFAULT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `dp_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `dew_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Parų kiekis, apibrėžiantis paieškos gylį prietaisų įvykių žurnale',
  PRIMARY KEY (`dew_id`),
  UNIQUE KEY `dew_name_u` (`dew_name`),
  KEY `dew_dp_i` (`dp_id`),
  KEY `dew_withe_i` (`withe_id`),
  KEY `dew_withe_type_i` (`withe_type_id`),
  CONSTRAINT `dew_dp_fk` FOREIGN KEY (`dp_id`) REFERENCES `dp` (`dp_id`) ON DELETE CASCADE,
  CONSTRAINT `dew_withe_fk` FOREIGN KEY (`withe_id`) REFERENCES `withe` (`withe_id`) ON DELETE CASCADE,
  CONSTRAINT `dew_withe_type_fk` FOREIGN KEY (`withe_type_id`) REFERENCES `withe_type` (`withe_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Koncentratorių įvykiai, registruojami įvykių registre';

-- Dumping data for table emcor.dew: ~0 rows (approximately)
/*!40000 ALTER TABLE `dew` DISABLE KEYS */;
/*!40000 ALTER TABLE `dew` ENABLE KEYS */;

-- Dumping structure for table emcor.di
CREATE TABLE IF NOT EXISTS `di` (
  `di_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Nuskaitomų duomenų elemento identifikatorius',
  `di_enabled` tinyint(1) NOT NULL COMMENT 'Nuskaitymo požymis',
  `pl_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
  `ds_id` int(10) unsigned DEFAULT NULL COMMENT 'Apskaitos būsenos signalo identifikatorius',
  `lp_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio prioritetų profilio identifikatorius',
  `sheaf_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Duomenų pluošto identifikatorius',
  `point_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo taško identifikatorius',
  `dp_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `witheset_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų vytelių rinkinio identifikatorius',
  PRIMARY KEY (`di_id`),
  UNIQUE KEY `di_ak` (`pl_id`,`ds_id`,`sheaf_id`,`point_id`,`dp_id`,`witheset_id`),
  KEY `di_dp_i` (`dp_id`),
  KEY `di_ds_i` (`ds_id`),
  KEY `di_lp_i` (`lp_id`),
  KEY `di_point_i` (`point_id`),
  KEY `di_sheaf_i` (`sheaf_id`),
  KEY `di_witheset_i` (`witheset_id`),
  CONSTRAINT `di_dp_fk` FOREIGN KEY (`dp_id`) REFERENCES `dp` (`dp_id`) ON DELETE CASCADE,
  CONSTRAINT `di_ds_fk` FOREIGN KEY (`ds_id`) REFERENCES `ds` (`ds_id`) ON DELETE CASCADE,
  CONSTRAINT `di_lp_fk` FOREIGN KEY (`lp_id`) REFERENCES `lp` (`lp_id`),
  CONSTRAINT `di_pl_fk` FOREIGN KEY (`pl_id`) REFERENCES `pl` (`pl_id`) ON DELETE CASCADE,
  CONSTRAINT `di_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `di_sheaf_fk` FOREIGN KEY (`sheaf_id`) REFERENCES `sheaf` (`sheaf_id`) ON DELETE CASCADE,
  CONSTRAINT `di_witheset_fk` FOREIGN KEY (`witheset_id`) REFERENCES `witheset` (`witheset_id`),
  CONSTRAINT `DI_NOT_IN_4_CHK` CHECK (`pl_id` is not null and `ds_id` is null and `sheaf_id` is null and `point_id` is null and `dp_id` is null and `witheset_id` is null or `pl_id` is null and `ds_id` is not null and `sheaf_id` is null and `dp_id` is null and `witheset_id` is null or `pl_id` is null and `ds_id` is null and `sheaf_id` is not null and `point_id` is not null and `dp_id` is null and (case when `sheaf_id` in (2,22,19,16) then NULL else `witheset_id` end) is null or `pl_id` is null and `ds_id` is null and `sheaf_id` is not null and `point_id` is null and `dp_id` is not null and (case when `sheaf_id` in (2,22,19,16) then NULL else `witheset_id` end) is null)
) ENGINE=InnoDB AUTO_INCREMENT=39 DEFAULT CHARSET=utf8 COMMENT='Nuskaitomi duomenų elementai';

-- Dumping data for table emcor.di: ~34 rows (approximately)
/*!40000 ALTER TABLE `di` DISABLE KEYS */;
INSERT INTO `di` (`di_id`, `di_enabled`, `pl_id`, `ds_id`, `lp_id`, `sheaf_id`, `point_id`, `dp_id`, `witheset_id`) VALUES
	(1, 1, 1, NULL, 1, NULL, NULL, NULL, NULL),
	(2, 1, 2, NULL, 1, NULL, NULL, NULL, NULL),
	(3, 1, 3, NULL, 1, NULL, NULL, NULL, NULL),
	(4, 1, 4, NULL, 1, NULL, NULL, NULL, NULL),
	(5, 1, 5, NULL, 1, NULL, NULL, NULL, NULL),
	(6, 1, 6, NULL, 1, NULL, NULL, NULL, NULL),
	(7, 1, 7, NULL, 1, NULL, NULL, NULL, NULL),
	(8, 1, 8, NULL, 1, NULL, NULL, NULL, NULL),
	(9, 1, 9, NULL, 1, NULL, NULL, NULL, NULL),
	(10, 1, 10, NULL, 1, NULL, NULL, NULL, NULL),
	(11, 1, 11, NULL, 1, NULL, NULL, NULL, NULL),
	(12, 1, 12, NULL, 1, NULL, NULL, NULL, NULL),
	(13, 1, 13, NULL, 1, NULL, NULL, NULL, NULL),
	(14, 1, 14, NULL, 1, NULL, NULL, NULL, NULL),
	(15, 1, 15, NULL, 1, NULL, NULL, NULL, NULL),
	(16, 1, 16, NULL, 1, NULL, NULL, NULL, NULL),
	(17, 1, 17, NULL, 1, NULL, NULL, NULL, NULL),
	(18, 1, 18, NULL, 1, NULL, NULL, NULL, NULL),
	(19, 1, 19, NULL, 1, NULL, NULL, NULL, NULL),
	(20, 1, 20, NULL, 1, NULL, NULL, NULL, NULL),
	(21, 1, 21, NULL, 1, NULL, NULL, NULL, NULL),
	(26, 1, 26, NULL, 1, NULL, NULL, NULL, NULL),
	(27, 1, 27, NULL, 1, NULL, NULL, NULL, NULL),
	(28, 1, 28, NULL, 1, NULL, NULL, NULL, NULL),
	(29, 1, 29, NULL, 1, NULL, NULL, NULL, NULL),
	(30, 1, 30, NULL, 1, NULL, NULL, NULL, NULL),
	(31, 1, 31, NULL, 1, NULL, NULL, NULL, NULL),
	(32, 1, 32, NULL, 1, NULL, NULL, NULL, NULL),
	(33, 1, 33, NULL, 1, NULL, NULL, NULL, NULL),
	(34, 1, 34, NULL, 1, NULL, NULL, NULL, NULL),
	(35, 1, 35, NULL, 1, NULL, NULL, NULL, NULL),
	(36, 1, 36, NULL, 1, NULL, NULL, NULL, NULL),
	(37, 1, 37, NULL, 1, NULL, NULL, NULL, NULL),
	(38, 1, 38, NULL, 1, NULL, NULL, NULL, NULL);
/*!40000 ALTER TABLE `di` ENABLE KEYS */;

-- Dumping structure for table emcor.dip
CREATE TABLE IF NOT EXISTS `dip` (
  `di_id` int(10) unsigned NOT NULL COMMENT 'Nuskaitomų duomenų elemento identifikatorius',
  `di_bt` datetime NOT NULL DEFAULT '1899-12-30 00:00:00' COMMENT 'Nuskaitomų duomenų elemento galiojimo pradžia',
  `di_et` datetime DEFAULT NULL COMMENT 'Nuskaitomų duomenų elemento galiojimo pabaiga',
  PRIMARY KEY (`di_id`,`di_bt`),
  CONSTRAINT `dip_di_fk` FOREIGN KEY (`di_id`) REFERENCES `di` (`di_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitomų duomenų elementų galiojimo periodai';

-- Dumping data for table emcor.dip: ~34 rows (approximately)
/*!40000 ALTER TABLE `dip` DISABLE KEYS */;
INSERT INTO `dip` (`di_id`, `di_bt`, `di_et`) VALUES
	(1, '1899-12-30 00:00:00', NULL),
	(2, '1899-12-30 00:00:00', NULL),
	(3, '1899-12-30 00:00:00', NULL),
	(4, '1899-12-30 00:00:00', NULL),
	(5, '1899-12-30 00:00:00', NULL),
	(6, '1899-12-30 00:00:00', NULL),
	(7, '1899-12-30 00:00:00', NULL),
	(8, '1899-12-30 00:00:00', NULL),
	(9, '1899-12-30 00:00:00', NULL),
	(10, '1899-12-30 00:00:00', NULL),
	(11, '1899-12-30 00:00:00', NULL),
	(12, '1899-12-30 00:00:00', NULL),
	(13, '1899-12-30 00:00:00', NULL),
	(14, '1899-12-30 00:00:00', NULL),
	(15, '1899-12-30 00:00:00', NULL),
	(16, '1899-12-30 00:00:00', NULL),
	(17, '1899-12-30 00:00:00', NULL),
	(18, '1899-12-30 00:00:00', NULL),
	(19, '1899-12-30 00:00:00', NULL),
	(20, '1899-12-30 00:00:00', NULL),
	(21, '1899-12-30 00:00:00', NULL),
	(26, '1899-12-30 00:00:00', NULL),
	(27, '1899-12-30 00:00:00', NULL),
	(28, '1899-12-30 00:00:00', NULL),
	(29, '1899-12-30 00:00:00', NULL),
	(30, '1899-12-30 00:00:00', NULL),
	(31, '1899-12-30 00:00:00', NULL),
	(32, '1899-12-30 00:00:00', NULL),
	(33, '1899-12-30 00:00:00', NULL),
	(34, '1899-12-30 00:00:00', NULL),
	(35, '1899-12-30 00:00:00', NULL),
	(36, '1899-12-30 00:00:00', NULL),
	(37, '1899-12-30 00:00:00', NULL),
	(38, '1899-12-30 00:00:00', NULL);
/*!40000 ALTER TABLE `dip` ENABLE KEYS */;

-- Dumping structure for table emcor.dir
CREATE TABLE IF NOT EXISTS `dir` (
  `dir_id` tinyint(4) NOT NULL COMMENT 'Krypties identifikatorius',
  `dir_code` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Krypties kodas',
  `dir_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Krypties pavadinimas',
  PRIMARY KEY (`dir_id`),
  UNIQUE KEY `dir_code_u` (`dir_code`),
  UNIQUE KEY `dir_name_u` (`dir_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Kryptys';

-- Dumping data for table emcor.dir: ~14 rows (approximately)
/*!40000 ALTER TABLE `dir` DISABLE KEYS */;
INSERT INTO `dir` (`dir_id`, `dir_code`, `dir_name`) VALUES
	(-4, 'FEED', 'Pamaitinimas'),
	(-3, 'QUADRANT 2+3', '2 ir 3 kvadrantų suma'),
	(-2, 'QUADRANT 1+4', '1 ir 4 kvadrantų suma'),
	(-1, 'QUADRANT 2+4', '2 ir 4 kvadrantų suma'),
	(0, 'NO_DIRECTION', 'Be krypties'),
	(1, '+', 'Tiekimo kryptis'),
	(2, '-', 'Grįžtama kryptis'),
	(3, 'DELTA', 'Tiekiamos ir grįžtamos krypčių skirtumas'),
	(4, 'NEG_DELTA', 'Grįžtamos ir tiekiamos krypties skirtumas'),
	(5, 'QUADRANT 1', 'Kvadrantas 1'),
	(6, 'QUADRANT 2', 'Kvadrantas 2'),
	(7, 'QUADRANT 3', 'Kvadrantas 3'),
	(8, 'QUADRANT 4', 'Kvadrantas 4'),
	(9, 'QUADRANT 1+3', '1 ir 3 kvadrantų suma');
/*!40000 ALTER TABLE `dir` ENABLE KEYS */;

-- Dumping structure for table emcor.dirp
CREATE TABLE IF NOT EXISTS `dirp` (
  `di_id` int(10) unsigned NOT NULL COMMENT 'Nuskaitomų duomenų elemento identifikatorius',
  `bt` datetime NOT NULL COMMENT 'Periodo pradžia',
  `et` datetime NOT NULL COMMENT 'Periodo pabaiga',
  PRIMARY KEY (`di_id`,`bt`,`et`),
  CONSTRAINT `dirp_di_fk` FOREIGN KEY (`di_id`) REFERENCES `di` (`di_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitomų duomenų elementų nuskaityti periodai';

-- Dumping data for table emcor.dirp: ~0 rows (approximately)
/*!40000 ALTER TABLE `dirp` DISABLE KEYS */;
/*!40000 ALTER TABLE `dirp` ENABLE KEYS */;

-- Dumping structure for table emcor.di_withe_missing
CREATE TABLE IF NOT EXISTS `di_withe_missing` (
  `di_id` int(10) unsigned NOT NULL COMMENT 'Nuskaitomų duomenų elemento identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `bt` datetime DEFAULT NULL COMMENT 'Periodo pradžia',
  PRIMARY KEY (`di_id`,`withe_id`),
  CONSTRAINT `di_withe_missing_di_fk` FOREIGN KEY (`di_id`) REFERENCES `di` (`di_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitomų duomenų elementų nepavykę duomenų vytelių nuskaitymai';

-- Dumping data for table emcor.di_withe_missing: ~0 rows (approximately)
/*!40000 ALTER TABLE `di_withe_missing` DISABLE KEYS */;
/*!40000 ALTER TABLE `di_withe_missing` ENABLE KEYS */;

-- Dumping structure for table emcor.dl_type
CREATE TABLE IF NOT EXISTS `dl_type` (
  `dl_type_id` smallint(5) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Duomenų išdėstymo tipo identifikatorius',
  `dl_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų išsidėstymo tipo pavadinimas',
  PRIMARY KEY (`dl_type_id`),
  UNIQUE KEY `dl_type_name_u` (`dl_type_name`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų išsidėstymo tipai';

-- Dumping data for table emcor.dl_type: ~2 rows (approximately)
/*!40000 ALTER TABLE `dl_type` DISABLE KEYS */;
INSERT INTO `dl_type` (`dl_type_id`, `dl_type_name`) VALUES
	(1, 'Koncentratoriuje'),
	(2, 'Skaitiklyje');
/*!40000 ALTER TABLE `dl_type` ENABLE KEYS */;

-- Dumping structure for table emcor.dp
CREATE TABLE IF NOT EXISTS `dp` (
  `dp_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `dp_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų nuskaitymo taško kodas',
  `dp_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų nuskaitymo taško pavadinimas',
  `dp_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taškų tipo identifikatorius',
  `dp_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Nuskaitymo taško naudojimo požymis',
  `dp_deleted` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Ištrinto nuskaitymo taško požymis',
  `dp_internal` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Vidinio duomenų nuskaitymo taško požymis',
  PRIMARY KEY (`dp_id`),
  UNIQUE KEY `dp_code_u` (`dp_code`),
  UNIQUE KEY `dp_name_u` (`dp_name`),
  KEY `dp_dp_type_i` (`dp_type_id`),
  CONSTRAINT `dp_dp_type_fk` FOREIGN KEY (`dp_type_id`) REFERENCES `dp_type` (`dp_type_id`)
) ENGINE=InnoDB AUTO_INCREMENT=601 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų nuskaitymo taškai';

-- Dumping data for table emcor.dp: ~2 rows (approximately)
/*!40000 ALTER TABLE `dp` DISABLE KEYS */;
INSERT INTO `dp` (`dp_id`, `dp_code`, `dp_name`, `dp_type_id`, `dp_enabled`, `dp_deleted`, `dp_internal`) VALUES
	(454, 'GENERATED_BY_ORACLE', 'Duomenų bazėje generuojami duomenys ', 1, 1, 0, 1),
	(600, 'IMPORTED', 'Importuojami duomenys', 1, 1, 0, 1);
/*!40000 ALTER TABLE `dp` ENABLE KEYS */;

-- Dumping structure for table emcor.dpr
CREATE TABLE IF NOT EXISTS `dpr` (
  `dpr_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Tarifų plano dienų programos identifikatorius',
  `dpr_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Tarifų plano dienų programos pavadinimas',
  PRIMARY KEY (`dpr_id`),
  UNIQUE KEY `dpr_name_u` (`dpr_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Tarifų plano dienų programos';

-- Dumping data for table emcor.dpr: ~0 rows (approximately)
/*!40000 ALTER TABLE `dpr` DISABLE KEYS */;
/*!40000 ALTER TABLE `dpr` ENABLE KEYS */;

-- Dumping structure for table emcor.dpr_data
CREATE TABLE IF NOT EXISTS `dpr_data` (
  `dpr_id` mediumint(8) unsigned NOT NULL COMMENT 'Tarifų plano dienų programos identifikatorius',
  `bhh` tinyint(3) unsigned NOT NULL COMMENT 'Tarifo veikimo pradžia valandomis',
  `ehh` tinyint(3) unsigned NOT NULL COMMENT 'Tarifo veikimo pabaiga valandomis',
  `tff_id` tinyint(3) unsigned NOT NULL COMMENT 'Tarifo identifikatorius',
  PRIMARY KEY (`dpr_id`,`bhh`,`ehh`),
  KEY `dpr_data_tff_i` (`tff_id`),
  CONSTRAINT `dpr_data_dp_fk` FOREIGN KEY (`dpr_id`) REFERENCES `dpr` (`dpr_id`) ON DELETE CASCADE,
  CONSTRAINT `dpr_data_tff_fk` FOREIGN KEY (`tff_id`) REFERENCES `tff` (`tff_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Tarifų plano dienų programų duomenys';

-- Dumping data for table emcor.dpr_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `dpr_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `dpr_data` ENABLE KEYS */;

-- Dumping structure for table emcor.dp_das
CREATE TABLE IF NOT EXISTS `dp_das` (
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  `atom_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Atomo naudojimo požymis',
  `atom_activated` datetime NOT NULL DEFAULT '1899-12-30 00:00:00' COMMENT 'Atomo paskutinio aktyvavimo data',
  PRIMARY KEY (`dp_id`),
  KEY `dp_das_das_fk` (`das_id`),
  CONSTRAINT `dp_das_das_fk` FOREIGN KEY (`das_id`) REFERENCES `das` (`das_id`) ON DELETE CASCADE,
  CONSTRAINT `dp_das_dp_fk` FOREIGN KEY (`dp_id`) REFERENCES `dp` (`dp_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų nuskaitymo taškų automatinis priskyrimas duomenų surinkimo serveriams';

-- Dumping data for table emcor.dp_das: ~0 rows (approximately)
/*!40000 ALTER TABLE `dp_das` DISABLE KEYS */;
/*!40000 ALTER TABLE `dp_das` ENABLE KEYS */;

-- Dumping structure for table emcor.dp_das_frc
CREATE TABLE IF NOT EXISTS `dp_das_frc` (
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  PRIMARY KEY (`dp_id`,`das_id`),
  KEY `dp_das_frc_das_fk` (`das_id`),
  CONSTRAINT `dp_das_frc_das_fk` FOREIGN KEY (`das_id`) REFERENCES `das` (`das_id`) ON DELETE CASCADE,
  CONSTRAINT `dp_das_frc_dp_fk` FOREIGN KEY (`dp_id`) REFERENCES `dp` (`dp_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų nuskaitymo taškų priverstinis priskyrimas duomenų surinkimo serveriams';

-- Dumping data for table emcor.dp_das_frc: ~0 rows (approximately)
/*!40000 ALTER TABLE `dp_das_frc` DISABLE KEYS */;
/*!40000 ALTER TABLE `dp_das_frc` ENABLE KEYS */;

-- Dumping structure for table emcor.dp_das_log
CREATE TABLE IF NOT EXISTS `dp_das_log` (
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `atom_log_id` mediumint(8) unsigned NOT NULL COMMENT 'Atomų priskyrimo duomenų surinkimo serveriams istorijos įrašo ID',
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  `atom_enabled` tinyint(1) NOT NULL COMMENT 'Atomo naudojimo požymis',
  `atom_activated` datetime NOT NULL COMMENT 'Atomo paskutinio aktyvavimo data',
  PRIMARY KEY (`db_time`,`atom_log_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų nuskaitymo taškų automatinio priskyrimo duomenų surinkimo serveriams istorija';

-- Dumping data for table emcor.dp_das_log: ~0 rows (approximately)
/*!40000 ALTER TABLE `dp_das_log` DISABLE KEYS */;
/*!40000 ALTER TABLE `dp_das_log` ENABLE KEYS */;

-- Dumping structure for table emcor.dp_lpty
CREATE TABLE IF NOT EXISTS `dp_lpty` (
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `lpty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ryšio modulių savybės reikšmė',
  PRIMARY KEY (`dp_id`,`lpty_id`),
  KEY `dp_lpty_lpty_i` (`lpty_id`),
  CONSTRAINT `dp_lpty_dp_fk` FOREIGN KEY (`dp_id`) REFERENCES `dp` (`dp_id`) ON DELETE CASCADE,
  CONSTRAINT `dp_lpty_lpty_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų nuskaitymo taškų savybės';

-- Dumping data for table emcor.dp_lpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `dp_lpty` DISABLE KEYS */;
/*!40000 ALTER TABLE `dp_lpty` ENABLE KEYS */;

-- Dumping structure for table emcor.dp_param
CREATE TABLE IF NOT EXISTS `dp_param` (
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `dp_param_nr` smallint(5) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško parametro numeris',
  `dp_param_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų nuskaitymo taško parametro reikšmė',
  PRIMARY KEY (`dp_id`,`dp_param_nr`),
  CONSTRAINT `dp_param_dp_fk` FOREIGN KEY (`dp_id`) REFERENCES `dp` (`dp_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų nuskaitymo taškų parametrai';

-- Dumping data for table emcor.dp_param: ~0 rows (approximately)
/*!40000 ALTER TABLE `dp_param` DISABLE KEYS */;
/*!40000 ALTER TABLE `dp_param` ENABLE KEYS */;

-- Dumping structure for table emcor.dp_tpl
CREATE TABLE IF NOT EXISTS `dp_tpl` (
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `ph_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius',
  `dl_type_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų išdėstymo tipo identifikatorius',
  PRIMARY KEY (`dp_id`),
  KEY `dp_tpl_dl_type_i` (`dl_type_id`),
  KEY `dp_tpl_ph_type_i` (`ph_type_id`),
  CONSTRAINT `dp_tpl_dl_type_fk` FOREIGN KEY (`dl_type_id`) REFERENCES `dl_type` (`dl_type_id`) ON DELETE CASCADE,
  CONSTRAINT `dp_tpl_dp_fk` FOREIGN KEY (`dp_id`) REFERENCES `dp` (`dp_id`) ON DELETE CASCADE,
  CONSTRAINT `dp_tpl_ph_type_fk` FOREIGN KEY (`ph_type_id`) REFERENCES `ph_type` (`ph_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitymo taškų paskutinių sėkmingų nuskaitymų maršrutai';

-- Dumping data for table emcor.dp_tpl: ~0 rows (approximately)
/*!40000 ALTER TABLE `dp_tpl` DISABLE KEYS */;
/*!40000 ALTER TABLE `dp_tpl` ENABLE KEYS */;

-- Dumping structure for table emcor.dp_type
CREATE TABLE IF NOT EXISTS `dp_type` (
  `dp_type_id` tinyint(3) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Duomenų nuskaitymo taškų tipo identifikatorius',
  `dp_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų nuskaitymo taškų tipo pavadinimas',
  PRIMARY KEY (`dp_type_id`),
  UNIQUE KEY `dp_type_name_u` (`dp_type_name`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų nuskaitymo taškų tipai';

-- Dumping data for table emcor.dp_type: ~2 rows (approximately)
/*!40000 ALTER TABLE `dp_type` DISABLE KEYS */;
INSERT INTO `dp_type` (`dp_type_id`, `dp_type_name`) VALUES
	(1, 'Pagrindinis kontūras'),
	(2, 'Rezervinis kontūras');
/*!40000 ALTER TABLE `dp_type` ENABLE KEYS */;

-- Dumping structure for table emcor.ds
CREATE TABLE IF NOT EXISTS `ds` (
  `ds_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Apskaitos būsenos signalo identifikatorius',
  `ds_code` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Apskaitos būsenų signalo kodas',
  `ds_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Apskaitos būsenos signalo pavadinimas',
  `ds_type_id` int(10) unsigned NOT NULL DEFAULT 1 COMMENT 'Apskaitos būsenų signalų tipo identifikatorius',
  `ds_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Apskaitos būsenos signalo naudojimo požymis',
  `ds_event_log` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Apskaitos būsenos signalo pasikeitimų registravimo įvykių registre požymis',
  `ds_rt_enabled` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Apskaitos būsenos signalo naudojimo realaus laiko mnemoschemose požymis',
  `ds_binary` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Apskaitos būsenos signalo dvejetainių reikšmių požymis',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  `point_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo taško identifikatorius',
  PRIMARY KEY (`ds_id`),
  UNIQUE KEY `ds_code_u` (`ds_code`),
  KEY `ds_ds_type_i` (`ds_type_id`),
  KEY `ds_enum_i` (`enum_id`),
  KEY `ds_name_i` (`ds_name`),
  KEY `ds_point_i` (`point_id`),
  CONSTRAINT `ds_ds_type_fk` FOREIGN KEY (`ds_type_id`) REFERENCES `ds_type` (`ds_type_id`),
  CONSTRAINT `ds_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`),
  CONSTRAINT `ds_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apskaitos būsenų signalai';

-- Dumping data for table emcor.ds: ~0 rows (approximately)
/*!40000 ALTER TABLE `ds` DISABLE KEYS */;
/*!40000 ALTER TABLE `ds` ENABLE KEYS */;

-- Dumping structure for table emcor.ds_data
CREATE TABLE IF NOT EXISTS `ds_data` (
  `ds_id` int(10) unsigned NOT NULL COMMENT 'Apskaitos būsenos signalo identifikatorius',
  `ds_t` datetime(3) NOT NULL COMMENT 'Apskaitos būsenos duomenų laikas',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `ds_rt` datetime DEFAULT NULL COMMENT 'Apskaitos būsenos duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `ds_v` tinyint(3) unsigned DEFAULT NULL COMMENT 'Apskaitos būsenos reikšmė',
  `sep_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `dstatus` varbinary(20) DEFAULT NULL COMMENT 'Duomenų statuso kodinė išraiška',
  `tstatus` tinyint(3) unsigned DEFAULT NULL COMMENT 'Transformuotas duomenų statusas',
  `ds_data_desc` varchar(1024) COLLATE utf8_bin DEFAULT NULL COMMENT 'Apskaitos būsenos persijungimo aprašymas',
  PRIMARY KEY (`ds_id`,`ds_t`),
  KEY `ds_data_db_time_i` (`db_time`),
  KEY `ds_data_ds_t_i` (`ds_t`),
  CONSTRAINT `ds_data_ds_fk` FOREIGN KEY (`ds_id`) REFERENCES `ds` (`ds_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apskaitos būsenų duomenys';

-- Dumping data for table emcor.ds_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `ds_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `ds_data` ENABLE KEYS */;

-- Dumping structure for table emcor.ds_data_intervals
CREATE TABLE IF NOT EXISTS `ds_data_intervals` (
  `ds_id` int(10) unsigned NOT NULL COMMENT 'Apskaitos būsenos signalo identifikatorius',
  `ds_bt` datetime(3) NOT NULL COMMENT 'Apskaitos būsenos intervalo pradžios laikas',
  `ds_v` tinyint(3) unsigned NOT NULL COMMENT 'Apskaitos būsenos reikšmė',
  `ds_et` datetime(3) DEFAULT NULL COMMENT 'Apskaitos būsenos intervalo pabaigos laikas',
  KEY `ds_data_intervals_ds_i` (`ds_id`,`ds_bt`,`ds_et`),
  CONSTRAINT `ds_data_intervals_ds_fk` FOREIGN KEY (`ds_id`) REFERENCES `ds` (`ds_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apskaitos būsenų intervalai';

-- Dumping data for table emcor.ds_data_intervals: ~0 rows (approximately)
/*!40000 ALTER TABLE `ds_data_intervals` DISABLE KEYS */;
/*!40000 ALTER TABLE `ds_data_intervals` ENABLE KEYS */;

-- Dumping structure for table emcor.ds_data_nv
CREATE TABLE IF NOT EXISTS `ds_data_nv` (
  `ds_id` int(10) unsigned NOT NULL COMMENT 'Apskaitos būsenos signalo identifikatorius',
  `ds_t` datetime(3) NOT NULL COMMENT 'Apskaitos būsenos duomenų laikas',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `ds_rt` datetime DEFAULT NULL COMMENT 'Apskaitos būsenos duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `ds_v` tinyint(3) unsigned DEFAULT NULL COMMENT 'Apskaitos būsenos reikšmė',
  `sep_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `dstatus` varbinary(20) DEFAULT NULL COMMENT 'Duomenų statuso kodinė išraiška',
  `tstatus` tinyint(3) unsigned DEFAULT NULL COMMENT 'Transformuotas duomenų statusas',
  PRIMARY KEY (`ds_id`,`ds_t`,`db_time`),
  KEY `ds_data_nv_db_time_i` (`db_time`),
  KEY `ds_data_nv_sep_i` (`sep_id`),
  CONSTRAINT `ds_data_nv_ds_fk` FOREIGN KEY (`ds_id`) REFERENCES `ds` (`ds_id`) ON DELETE CASCADE,
  CONSTRAINT `ds_data_nv_sep_fk` FOREIGN KEY (`sep_id`) REFERENCES `sep` (`sep_id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apskaitos būsenų negaliojantys duomenys';

-- Dumping data for table emcor.ds_data_nv: ~0 rows (approximately)
/*!40000 ALTER TABLE `ds_data_nv` DISABLE KEYS */;
/*!40000 ALTER TABLE `ds_data_nv` ENABLE KEYS */;

-- Dumping structure for table emcor.ds_gr
CREATE TABLE IF NOT EXISTS `ds_gr` (
  `ds_id` int(10) unsigned NOT NULL COMMENT 'Apskaitos būsenos signalo identifikatorius',
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  `ds_nr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Apskaitos būsenos signalo eilės numeris',
  PRIMARY KEY (`ds_id`,`gr_id`),
  KEY `ds_gr_gr_i` (`gr_id`),
  CONSTRAINT `ds_gr_ds_fk` FOREIGN KEY (`ds_id`) REFERENCES `ds` (`ds_id`) ON DELETE CASCADE,
  CONSTRAINT `ds_gr_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apskaitos būsenų priklausomybė grupėms';

-- Dumping data for table emcor.ds_gr: ~0 rows (approximately)
/*!40000 ALTER TABLE `ds_gr` DISABLE KEYS */;
/*!40000 ALTER TABLE `ds_gr` ENABLE KEYS */;

-- Dumping structure for table emcor.ds_type
CREATE TABLE IF NOT EXISTS `ds_type` (
  `ds_type_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Apskaitos būsenų signalų tipo identifikatorius',
  `ds_type_code` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'Apskaitos būsenų signalų tipo kodas',
  `ds_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Apskaitos būsenų signalų tipo pavadinimas',
  `ds_event_log` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Apskaitos būsenos signalo pasikeitimų registravimo įvykių registre požymis',
  `ds_rt_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Apskaitos būsenos signalo naudojimo realaus laiko mnemoschemose požymis',
  `ds_binary` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Apskaitos būsenos signalo dvejetainių reikšmių požymis',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  PRIMARY KEY (`ds_type_id`),
  UNIQUE KEY `ds_type_code_u` (`ds_type_code`),
  UNIQUE KEY `ds_type_name_u` (`ds_type_name`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apskaitos būsenų signalų tipai';

-- Dumping data for table emcor.ds_type: ~0 rows (approximately)
/*!40000 ALTER TABLE `ds_type` DISABLE KEYS */;
INSERT INTO `ds_type` (`ds_type_id`, `ds_type_code`, `ds_type_name`, `ds_event_log`, `ds_rt_enabled`, `ds_binary`, `enum_id`) VALUES
	(1, 'OTHER', 'Kiti', 0, 1, 1, NULL);
/*!40000 ALTER TABLE `ds_type` ENABLE KEYS */;

-- Dumping structure for table emcor.ds_type_gr
CREATE TABLE IF NOT EXISTS `ds_type_gr` (
  `ds_type_id` int(10) unsigned NOT NULL COMMENT 'Apskaitos būsenų signalų tipo identifikatorius',
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  `ds_type_gr_priority` smallint(5) unsigned NOT NULL DEFAULT 5 COMMENT 'Grupės prioritetas apskaitos būsenų tipų taisyklių pasirinkime',
  `withe_id` mediumint(8) DEFAULT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `sam_id` int(10) unsigned DEFAULT NULL COMMENT 'Šablono identifikatorius',
  `verge_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Kraštinės ID',
  `ml_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Matavimo linijos identifikatorius',
  `gmod_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Sugrupuotų duomenų modifikacijos ID',
  `gprc` tinyint(3) unsigned DEFAULT NULL COMMENT 'Grupės procentinės reikšmės naudojimo požymis',
  `ec_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Ekonominės kategorijos identifikatorius',
  `ec_in` tinyint(1) DEFAULT NULL COMMENT 'Ekonominės kategorijos pajamų/išlaidų požymis',
  PRIMARY KEY (`ds_type_id`,`gr_id`),
  KEY `ds_type_gr_ec_i` (`ec_id`),
  KEY `ds_type_gr_gmod_i` (`gmod_id`),
  KEY `ds_type_gr_gr_i` (`gr_id`),
  KEY `ds_type_gr_sam_i` (`sam_id`),
  KEY `ds_type_gr_verge_i` (`verge_id`),
  KEY `ds_type_gr_ml_fk` (`ml_id`),
  KEY `ds_type_gr_withe_fk` (`withe_id`),
  CONSTRAINT `ds_type_gr_ds_type_fk` FOREIGN KEY (`ds_type_id`) REFERENCES `ds_type` (`ds_type_id`) ON DELETE CASCADE,
  CONSTRAINT `ds_type_gr_ec_fk` FOREIGN KEY (`ec_id`) REFERENCES `ec` (`ec_id`) ON DELETE CASCADE,
  CONSTRAINT `ds_type_gr_gmod_fk` FOREIGN KEY (`gmod_id`) REFERENCES `gmod` (`gmod_id`) ON DELETE CASCADE,
  CONSTRAINT `ds_type_gr_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE,
  CONSTRAINT `ds_type_gr_ml_fk` FOREIGN KEY (`ml_id`) REFERENCES `ml` (`ml_id`) ON DELETE CASCADE,
  CONSTRAINT `ds_type_gr_sam_fk` FOREIGN KEY (`sam_id`) REFERENCES `sam` (`sam_id`) ON DELETE CASCADE,
  CONSTRAINT `ds_type_gr_verge_fk` FOREIGN KEY (`verge_id`) REFERENCES `verge` (`verge_id`) ON DELETE CASCADE,
  CONSTRAINT `ds_type_gr_withe_fk` FOREIGN KEY (`withe_id`) REFERENCES `withe` (`withe_id`) ON DELETE CASCADE,
  CONSTRAINT `DS_TYPE_GR_NOT_IN_6_CHK` CHECK (`withe_id` is not null or `withe_id` is null and `sam_id` is not null or `withe_id` is null and `sam_id` is null and `verge_id` is not null and `ml_id` is not null and `gmod_id` is null and `gprc` is null and `ec_id` is null and `ec_in` is null or `withe_id` is null and `sam_id` is null and `verge_id` is not null and `ml_id` is not null and `gprc` is not null and `gprc` in (0,1,2) and `ec_id` is null and `ec_in` is null or `withe_id` is null and `sam_id` is null and `verge_id` is not null and `ml_id` is not null and `gprc` is not null and `gprc` = 0 and `ec_id` is null and `ec_in` is not null and `ec_in` in (0,1) or `withe_id` is null and `sam_id` is null and `verge_id` is not null and `ml_id` is not null and `gprc` is not null and `gprc` = 0 and `ec_id` is not null and `ec_in` is null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apskaitos būsenų signalų automatinio pildymo taisyklės';

-- Dumping data for table emcor.ds_type_gr: ~0 rows (approximately)
/*!40000 ALTER TABLE `ds_type_gr` DISABLE KEYS */;
/*!40000 ALTER TABLE `ds_type_gr` ENABLE KEYS */;

-- Dumping structure for table emcor.dt
CREATE TABLE IF NOT EXISTS `dt` (
  `dt_id` tinyint(3) unsigned NOT NULL COMMENT 'Duomenų tipo identifikatorius',
  `dt_code` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų tipo kodas',
  PRIMARY KEY (`dt_id`),
  UNIQUE KEY `dt_code_u` (`dt_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Draiverių naudojami duomenų tipai';

-- Dumping data for table emcor.dt: ~6 rows (approximately)
/*!40000 ALTER TABLE `dt` DISABLE KEYS */;
INSERT INTO `dt` (`dt_id`, `dt_code`) VALUES
	(3, 'ASCII'),
	(5, 'Bool'),
	(4, 'Date'),
	(1, 'Float'),
	(2, 'Int'),
	(6, 'Time');
/*!40000 ALTER TABLE `dt` ENABLE KEYS */;

-- Dumping structure for table emcor.dtl
CREATE TABLE IF NOT EXISTS `dtl` (
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `req_type_code` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Užklausų tipo kodas',
  `rodo_id` int(10) unsigned NOT NULL COMMENT 'Užsakymo ID',
  `urgent` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Skubaus vykdymo požymis'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Atidėtų ryšio užduočių eilė';

-- Dumping data for table emcor.dtl: ~0 rows (approximately)
/*!40000 ALTER TABLE `dtl` DISABLE KEYS */;
/*!40000 ALTER TABLE `dtl` ENABLE KEYS */;

-- Dumping structure for table emcor.dw0_buf
CREATE TABLE IF NOT EXISTS `dw0_buf` (
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `req_from` datetime NOT NULL,
  `req_to` datetime DEFAULT NULL,
  `dw_rt` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `req_withe_id` mediumint(8) unsigned DEFAULT NULL,
  PRIMARY KEY (`dp_id`,`withe_id`,`req_from`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Tarpinė lentelė nuskaitymo taškų duomenų vytelių nuskaitytiems periodams be įrašų';

-- Dumping data for table emcor.dw0_buf: ~0 rows (approximately)
/*!40000 ALTER TABLE `dw0_buf` DISABLE KEYS */;
/*!40000 ALTER TABLE `dw0_buf` ENABLE KEYS */;

-- Dumping structure for table emcor.dw_buf
CREATE TABLE IF NOT EXISTS `dw_buf` (
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `dw_v` varbinary(1024) DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų reikšmė',
  `dw_rt` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `dw_t` datetime(3) NOT NULL,
  `req_from` datetime DEFAULT NULL,
  `req_to` datetime DEFAULT NULL,
  `req_withe_id` mediumint(8) unsigned DEFAULT NULL,
  PRIMARY KEY (`dp_id`,`withe_id`,`dw_t`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Tarpinė lentelė nuskaitymo taškų nuskaitytoms duomenų vytelėms';

-- Dumping data for table emcor.dw_buf: ~0 rows (approximately)
/*!40000 ALTER TABLE `dw_buf` DISABLE KEYS */;
/*!40000 ALTER TABLE `dw_buf` ENABLE KEYS */;

-- Dumping structure for table emcor.dw_data
CREATE TABLE IF NOT EXISTS `dw_data` (
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `dw_t` datetime(3) NOT NULL COMMENT 'Nuskaitymo taško vytelės duomenų laikas',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `dw_v` varbinary(1024) DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų reikšmė',
  `dw_rt` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  PRIMARY KEY (`dp_id`,`withe_id`,`dw_t`),
  KEY `dw_data_db_time_i` (`db_time`),
  KEY `dw_data_dp_i` (`dp_id`,`dw_t`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitymo taškų vytelių duomenys'
 PARTITION BY RANGE (
    to_days(dw_t))
(PARTITION par_189912 VALUES LESS THAN (693961) ENGINE = InnoDB,
 PARTITION par_201701 VALUES LESS THAN (736726) ENGINE = InnoDB,
 PARTITION par_201702 VALUES LESS THAN (736754) ENGINE = InnoDB,
 PARTITION par_201703 VALUES LESS THAN (736785) ENGINE = InnoDB,
 PARTITION par_201704 VALUES LESS THAN (736815) ENGINE = InnoDB,
 PARTITION par_201705 VALUES LESS THAN (736846) ENGINE = InnoDB);

-- Dumping data for table emcor.dw_data: ~6 rows (approximately)
/*!40000 ALTER TABLE `dw_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `dw_data` ENABLE KEYS */;

-- Dumping structure for table emcor.dw_data_nv
CREATE TABLE IF NOT EXISTS `dw_data_nv` (
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `dw_t` datetime(3) NOT NULL COMMENT 'Nuskaitymo taško vytelės duomenų laikas',
  `db_time` datetime NOT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `dw_v` varbinary(1024) DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų reikšmė',
  `dw_rt` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  PRIMARY KEY (`dp_id`,`withe_id`,`dw_t`,`db_time`),
  KEY `dw_data_nv_db_time_i` (`db_time`),
  KEY `dw_data_nv_sep_i` (`sep_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitymo taškų vytelių negaliojantys duomenys'
 PARTITION BY RANGE (
    to_days(dw_t))
(PARTITION par_201701 VALUES LESS THAN (736726) ENGINE = InnoDB,
 PARTITION par_201702 VALUES LESS THAN (736754) ENGINE = InnoDB,
 PARTITION par_201703 VALUES LESS THAN (736785) ENGINE = InnoDB,
 PARTITION par_201704 VALUES LESS THAN (736815) ENGINE = InnoDB,
 PARTITION par_201705 VALUES LESS THAN (736846) ENGINE = InnoDB);

-- Dumping data for table emcor.dw_data_nv: ~5 rows (approximately)
/*!40000 ALTER TABLE `dw_data_nv` DISABLE KEYS */;
/*!40000 ALTER TABLE `dw_data_nv` ENABLE KEYS */;

-- Dumping structure for table emcor.dw_mbuf
CREATE TABLE IF NOT EXISTS `dw_mbuf` (
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `enr` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus elemento numeris',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `dw_v` varbinary(1024) DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų reikšmė',
  `dw_rt` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  PRIMARY KEY (`dp_id`,`withe_id`,`ind1`,`ind2`,`ind3`,`enr`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Tarpinė lentelė nuskaitymo taškų prietaisų konfigūraciniams masyviniams parametrams';

-- Dumping data for table emcor.dw_mbuf: ~0 rows (approximately)
/*!40000 ALTER TABLE `dw_mbuf` DISABLE KEYS */;
/*!40000 ALTER TABLE `dw_mbuf` ENABLE KEYS */;

-- Dumping structure for table emcor.dw_msetting
CREATE TABLE IF NOT EXISTS `dw_msetting` (
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `enr` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus elemento numeris',
  `dw_t` datetime(3) NOT NULL COMMENT 'Nuskaitymo taško vytelės duomenų laikas',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `dw_v` varbinary(1024) DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų reikšmė',
  `dw_rt` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `dw_last_rt` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų paskutinio nuskaitymo laikas',
  `user_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Vartotojo identifikatorius',
  `pck_last_t` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės paskutinio duomenų nuskaitymo paketo laiko žymė',
  PRIMARY KEY (`dp_id`,`withe_id`,`ind1`,`ind2`,`ind3`,`enr`),
  KEY `dw_msetting_db_time_i` (`db_time`),
  KEY `dw_msetting_sep_i` (`sep_id`),
  KEY `dw_msetting_user_i` (`user_id`),
  CONSTRAINT `dw_msetting_dp_fk` FOREIGN KEY (`dp_id`) REFERENCES `dp` (`dp_id`) ON DELETE CASCADE,
  CONSTRAINT `dw_msetting_sep_fk` FOREIGN KEY (`sep_id`) REFERENCES `sep` (`sep_id`) ON DELETE CASCADE,
  CONSTRAINT `dw_msetting_users_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitymo taškų prietaisų konfigūracinių masyvinių parametrų duomenys';

-- Dumping data for table emcor.dw_msetting: ~0 rows (approximately)
/*!40000 ALTER TABLE `dw_msetting` DISABLE KEYS */;
/*!40000 ALTER TABLE `dw_msetting` ENABLE KEYS */;

-- Dumping structure for table emcor.dw_msetting_history
CREATE TABLE IF NOT EXISTS `dw_msetting_history` (
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `enr` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus elemento numeris',
  `dw_t` datetime(3) NOT NULL COMMENT 'Nuskaitymo taško vytelės duomenų laikas',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `dw_v` varbinary(1024) DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų reikšmė',
  `dw_rt` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `dw_last_rt` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų paskutinio nuskaitymo laikas',
  `user_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Vartotojo identifikatorius',
  `pck_last_t` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės paskutinio duomenų nuskaitymo paketo laiko žymė',
  PRIMARY KEY (`dp_id`,`withe_id`,`ind1`,`ind2`,`ind3`,`enr`,`dw_t`),
  KEY `dw_msetting_history_db_time_i` (`db_time`),
  KEY `dw_msetting_history_dp_i` (`dp_id`,`dw_t`),
  KEY `dw_msetting_history_dw_t_i` (`dw_t`),
  KEY `dw_msetting_history_sep_i` (`sep_id`),
  KEY `dw_msetting_history_user_i` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitymo taškų prietaisų konfigūracinių masyvinių parametrų istoriniai duomenys'
 PARTITION BY RANGE (
    to_days(dw_t))
(PARTITION par_189912 VALUES LESS THAN (693961) ENGINE = InnoDB,
 PARTITION par_201701 VALUES LESS THAN (736726) ENGINE = InnoDB,
 PARTITION par_201702 VALUES LESS THAN (736754) ENGINE = InnoDB,
 PARTITION par_201703 VALUES LESS THAN (736785) ENGINE = InnoDB,
 PARTITION par_201704 VALUES LESS THAN (736815) ENGINE = InnoDB,
 PARTITION par_201705 VALUES LESS THAN (736846) ENGINE = InnoDB);

-- Dumping data for table emcor.dw_msetting_history: ~6 rows (approximately)
/*!40000 ALTER TABLE `dw_msetting_history` DISABLE KEYS */;
/*!40000 ALTER TABLE `dw_msetting_history` ENABLE KEYS */;

-- Dumping structure for table emcor.dw_setting
CREATE TABLE IF NOT EXISTS `dw_setting` (
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `dw_t` datetime(3) NOT NULL COMMENT 'Nuskaitymo taško vytelės duomenų laikas',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `dw_v` varbinary(1024) DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų reikšmė',
  `dw_rt` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `dw_last_rt` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų paskutinio nuskaitymo laikas',
  `user_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Vartotojo identifikatorius',
  `pck_last_t` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės paskutinio duomenų nuskaitymo paketo laiko žymė',
  PRIMARY KEY (`dp_id`,`withe_id`),
  KEY `dw_setting_db_time_i` (`db_time`),
  KEY `dw_setting_sep_i` (`sep_id`),
  KEY `dw_setting_user_i` (`user_id`),
  CONSTRAINT `dw_setting_dp_fk` FOREIGN KEY (`dp_id`) REFERENCES `dp` (`dp_id`) ON DELETE CASCADE,
  CONSTRAINT `dw_setting_sep_fk` FOREIGN KEY (`sep_id`) REFERENCES `sep` (`sep_id`) ON DELETE CASCADE,
  CONSTRAINT `dw_setting_users_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitymo taškų prietaisų konfigūracinių parametrų duomenys';

-- Dumping data for table emcor.dw_setting: ~0 rows (approximately)
/*!40000 ALTER TABLE `dw_setting` DISABLE KEYS */;
/*!40000 ALTER TABLE `dw_setting` ENABLE KEYS */;

-- Dumping structure for table emcor.dw_setting_history
CREATE TABLE IF NOT EXISTS `dw_setting_history` (
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `dw_t` datetime(3) NOT NULL COMMENT 'Nuskaitymo taško vytelės duomenų laikas',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `dw_v` varbinary(1024) DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų reikšmė',
  `dw_rt` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `dw_last_rt` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų paskutinio nuskaitymo laikas',
  `user_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Vartotojo identifikatorius',
  `pck_last_t` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės paskutinio duomenų nuskaitymo paketo laiko žymė',
  PRIMARY KEY (`dp_id`,`withe_id`,`dw_t`),
  KEY `dw_setting_history_db_time_i` (`db_time`),
  KEY `dw_setting_history_dp_i` (`dp_id`,`dw_t`),
  KEY `dw_setting_history_dw_t_i` (`dw_t`),
  KEY `dw_setting_history_sep_i` (`sep_id`),
  KEY `dw_setting_history_user_i` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitymo taškų prietaisų konfigūracinių parametrų istoriniai duomenys'
 PARTITION BY RANGE (
    to_days(dw_t))
(PARTITION par_189912 VALUES LESS THAN (693961) ENGINE = InnoDB,
 PARTITION par_201701 VALUES LESS THAN (736726) ENGINE = InnoDB,
 PARTITION par_201702 VALUES LESS THAN (736754) ENGINE = InnoDB,
 PARTITION par_201703 VALUES LESS THAN (736785) ENGINE = InnoDB,
 PARTITION par_201704 VALUES LESS THAN (736815) ENGINE = InnoDB,
 PARTITION par_201705 VALUES LESS THAN (736846) ENGINE = InnoDB);

-- Dumping data for table emcor.dw_setting_history: ~6 rows (approximately)
/*!40000 ALTER TABLE `dw_setting_history` DISABLE KEYS */;
/*!40000 ALTER TABLE `dw_setting_history` ENABLE KEYS */;

-- Dumping structure for table emcor.dw_state
CREATE TABLE IF NOT EXISTS `dw_state` (
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `dw_t` datetime(3) NOT NULL COMMENT 'Nuskaitymo taško vytelės duomenų laikas',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `dw_v` varbinary(1024) DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų reikšmė',
  `dw_rt` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  PRIMARY KEY (`dp_id`,`withe_id`),
  KEY `dw_state_db_time_i` (`db_time`),
  KEY `dw_state_dp_i` (`dp_id`,`dw_t`),
  CONSTRAINT `dw_state_dp_fk` FOREIGN KEY (`dp_id`) REFERENCES `dp` (`dp_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitymo taškų vytelių duomenys';

-- Dumping data for table emcor.dw_state: ~0 rows (approximately)
/*!40000 ALTER TABLE `dw_state` DISABLE KEYS */;
/*!40000 ALTER TABLE `dw_state` ENABLE KEYS */;

-- Dumping structure for table emcor.eapp
CREATE TABLE IF NOT EXISTS `eapp` (
  `eapp_time` datetime NOT NULL COMMENT 'Aplikacijos voko sukūrimo laikas',
  `eapp_id` int(10) unsigned NOT NULL COMMENT 'Aplikacijos voko identifikatorius',
  `rc_id` tinyint(3) unsigned NOT NULL COMMENT 'Užklausų priežasties identifikatorius',
  `estatus_id` tinyint(3) unsigned NOT NULL COMMENT 'Vokų statuso identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `ch_nr` mediumint(8) unsigned NOT NULL DEFAULT 0 COMMENT 'Pakeitimo numeris',
  `sch_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Tvarkaraščio identifikatorius',
  `sch_time` datetime DEFAULT NULL COMMENT 'Tvarkaraščio suveikimo laikas',
  `rodo_id` int(10) unsigned DEFAULT NULL COMMENT 'Užsakymo ID',
  `user_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Vartotojo identifikatorius',
  PRIMARY KEY (`eapp_id`),
  UNIQUE KEY `eapp_sch_rodo_u` (`sch_id`,`sch_time`,`rodo_id`),
  KEY `eapp_estatus_fk` (`estatus_id`),
  KEY `eapp_rc_fk` (`rc_id`),
  CONSTRAINT `eapp_estatus_fk` FOREIGN KEY (`estatus_id`) REFERENCES `estatus` (`estatus_id`),
  CONSTRAINT `eapp_rc_fk` FOREIGN KEY (`rc_id`) REFERENCES `rc` (`rc_id`),
  CONSTRAINT `eapp_sch_fk` FOREIGN KEY (`sch_id`) REFERENCES `sch` (`sch_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Aplikacijos vokai';

-- Dumping data for table emcor.eapp: ~0 rows (approximately)
/*!40000 ALTER TABLE `eapp` DISABLE KEYS */;
/*!40000 ALTER TABLE `eapp` ENABLE KEYS */;

-- Dumping structure for table emcor.eapp_log
CREATE TABLE IF NOT EXISTS `eapp_log` (
  `eapp_time` datetime NOT NULL COMMENT 'Aplikacijos voko sukūrimo laikas',
  `eapp_id` int(10) unsigned NOT NULL COMMENT 'Aplikacijos voko identifikatorius',
  `ch_nr` mediumint(8) unsigned NOT NULL COMMENT 'Pakeitimo numeris',
  `rc_id` tinyint(3) unsigned NOT NULL COMMENT 'Užklausų priežasties identifikatorius',
  `estatus_id` tinyint(3) unsigned NOT NULL COMMENT 'Vokų statuso identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `sch_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Tvarkaraščio identifikatorius',
  `sch_time` datetime DEFAULT NULL COMMENT 'Tvarkaraščio suveikimo laikas',
  `rodo_id` int(10) unsigned DEFAULT NULL COMMENT 'Užsakymo ID',
  `user_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Vartotojo identifikatorius',
  PRIMARY KEY (`eapp_time`,`eapp_id`,`ch_nr`),
  KEY `eapp_log_db_time_i` (`db_time`),
  KEY `eapp_log_estatus_fk` (`estatus_id`),
  KEY `eapp_log_rc_fk` (`rc_id`),
  KEY `eapp_log_sch_fk` (`sch_id`),
  CONSTRAINT `eapp_log_estatus_fk` FOREIGN KEY (`estatus_id`) REFERENCES `estatus` (`estatus_id`),
  CONSTRAINT `eapp_log_rc_fk` FOREIGN KEY (`rc_id`) REFERENCES `rc` (`rc_id`),
  CONSTRAINT `eapp_log_sch_fk` FOREIGN KEY (`sch_id`) REFERENCES `sch` (`sch_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Aplikacijos vokų istorija';

-- Dumping data for table emcor.eapp_log: ~0 rows (approximately)
/*!40000 ALTER TABLE `eapp_log` DISABLE KEYS */;
/*!40000 ALTER TABLE `eapp_log` ENABLE KEYS */;

-- Dumping structure for table emcor.ec
CREATE TABLE IF NOT EXISTS `ec` (
  `ec_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Ekonominės kategorijos identifikatorius',
  `ec_code` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'Ekonominės kategorijos kodas',
  `ec_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ekonominės kategorijos pavadinimas',
  `ec_in` tinyint(1) DEFAULT NULL COMMENT 'Ekonominės kategorijos pajamų/išlaidų požymis',
  PRIMARY KEY (`ec_id`),
  UNIQUE KEY `ec_code_u` (`ec_code`),
  UNIQUE KEY `ec_name_u` (`ec_name`)
) ENGINE=InnoDB AUTO_INCREMENT=23 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ekonominės kategorijos';

-- Dumping data for table emcor.ec: ~4 rows (approximately)
/*!40000 ALTER TABLE `ec` DISABLE KEYS */;
INSERT INTO `ec` (`ec_id`, `ec_code`, `ec_name`, `ec_in`) VALUES
	(1, 'INLET', 'Gaunama iš tinklų', 1),
	(2, 'OUTLET', 'Atleidimas vartotojui', 0),
	(21, 'OWN', 'Savos reikmės', 0),
	(22, 'GENERATION', 'Generacija', 1);
/*!40000 ALTER TABLE `ec` ENABLE KEYS */;

-- Dumping structure for table emcor.ecp
CREATE TABLE IF NOT EXISTS `ecp` (
  `ecp_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Taško ekonominio profilio identifikatorius',
  `ecp_code` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'Taško ekonominio profilio kodas',
  `ecp_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Taško ekonominio profilio pavadinimas',
  PRIMARY KEY (`ecp_id`),
  UNIQUE KEY `ecp_code_u` (`ecp_code`),
  UNIQUE KEY `ecp_name_u` (`ecp_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Taškų ekonominiai profiliai';

-- Dumping data for table emcor.ecp: ~0 rows (approximately)
/*!40000 ALTER TABLE `ecp` DISABLE KEYS */;
/*!40000 ALTER TABLE `ecp` ENABLE KEYS */;

-- Dumping structure for table emcor.ecp_data
CREATE TABLE IF NOT EXISTS `ecp_data` (
  `ecp_id` mediumint(8) unsigned NOT NULL COMMENT 'Taško ekonominio profilio identifikatorius',
  `ms_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimo identifikatorius',
  `dir_id` tinyint(4) NOT NULL COMMENT 'Krypties identifikatorius',
  `ec_id` mediumint(8) unsigned NOT NULL COMMENT 'Ekonominės kategorijos identifikatorius',
  `gr_ms_id` smallint(5) unsigned NOT NULL COMMENT 'Apskaitos grupės matavimo identifikatorius',
  `gr_dir_id` tinyint(4) NOT NULL COMMENT 'Grupės matavimo krypties identifikatorius',
  `gr_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Apskaitos grupių tipo identifikatorius',
  `coef` double NOT NULL DEFAULT 1 COMMENT 'Koeficientas',
  PRIMARY KEY (`ecp_id`,`ms_id`,`dir_id`,`ec_id`,`gr_ms_id`,`gr_dir_id`,`gr_type_id`),
  KEY `ecp_dir_i` (`dir_id`),
  KEY `ecp_ec_i` (`ec_id`),
  KEY `ecp_gr_dir_i` (`gr_dir_id`),
  KEY `ecp_gr_ms_i` (`gr_ms_id`),
  KEY `ecp_gr_type_i` (`gr_type_id`),
  KEY `ecp_ms_i` (`ms_id`),
  CONSTRAINT `ecp_data_dir_fk` FOREIGN KEY (`dir_id`) REFERENCES `dir` (`dir_id`),
  CONSTRAINT `ecp_data_ec_fk` FOREIGN KEY (`ec_id`) REFERENCES `ec` (`ec_id`),
  CONSTRAINT `ecp_data_ecp_fk` FOREIGN KEY (`ecp_id`) REFERENCES `ecp` (`ecp_id`) ON DELETE CASCADE,
  CONSTRAINT `ecp_data_gr_dir_fk` FOREIGN KEY (`gr_dir_id`) REFERENCES `dir` (`dir_id`),
  CONSTRAINT `ecp_data_gr_ms_fk` FOREIGN KEY (`gr_ms_id`) REFERENCES `ms` (`ms_id`),
  CONSTRAINT `ecp_data_gr_type_fk` FOREIGN KEY (`gr_type_id`) REFERENCES `gr_type` (`gr_type_id`) ON DELETE CASCADE,
  CONSTRAINT `ecp_data_ms_fk` FOREIGN KEY (`ms_id`) REFERENCES `ms` (`ms_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Taškų ekonominių profilių konfigūracija';

-- Dumping data for table emcor.ecp_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `ecp_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `ecp_data` ENABLE KEYS */;

-- Dumping structure for table emcor.edev
CREATE TABLE IF NOT EXISTS `edev` (
  `eapp_time` datetime NOT NULL COMMENT 'Aplikacijos voko sukūrimo laikas',
  `eapp_id` int(10) unsigned NOT NULL COMMENT 'Aplikacijos voko identifikatorius',
  `edev_id` int(10) unsigned NOT NULL COMMENT 'Prietaiso voko identifikatorius',
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `estatus_id` tinyint(3) unsigned NOT NULL COMMENT 'Vokų statuso identifikatorius',
  `edev_step_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Prietaiso voko žingsnio tipo identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `ch_nr` mediumint(8) unsigned NOT NULL DEFAULT 0 COMMENT 'Pakeitimo numeris',
  `edev_msg` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Prietaiso voko pranešimas',
  PRIMARY KEY (`edev_id`),
  KEY `edev_eapp_i` (`eapp_id`),
  KEY `edev_edev_step_type_fk` (`edev_step_type_id`),
  KEY `edev_estatus_fk` (`estatus_id`),
  CONSTRAINT `edev_eapp_fk` FOREIGN KEY (`eapp_id`) REFERENCES `eapp` (`eapp_id`) ON DELETE CASCADE,
  CONSTRAINT `edev_edev_step_type_fk` FOREIGN KEY (`edev_step_type_id`) REFERENCES `edev_step_type` (`edev_step_type_id`),
  CONSTRAINT `edev_estatus_fk` FOREIGN KEY (`estatus_id`) REFERENCES `estatus` (`estatus_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Prietaisų vokai';

-- Dumping data for table emcor.edev: ~0 rows (approximately)
/*!40000 ALTER TABLE `edev` DISABLE KEYS */;
/*!40000 ALTER TABLE `edev` ENABLE KEYS */;

-- Dumping structure for table emcor.edevprq
CREATE TABLE IF NOT EXISTS `edevprq` (
  `eapp_time` datetime NOT NULL COMMENT 'Aplikacijos voko sukūrimo laikas',
  `eapp_id` int(10) unsigned NOT NULL COMMENT 'Aplikacijos voko identifikatorius',
  `edev_id` int(10) unsigned NOT NULL COMMENT 'Prietaiso voko identifikatorius',
  `edevprq_id` int(10) unsigned NOT NULL COMMENT 'Vokų vykdymo užklausos identifikatorius',
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `di_id` int(10) unsigned NOT NULL COMMENT 'Nuskaitomų duomenų elemento identifikatorius',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `rc_id` tinyint(3) unsigned NOT NULL COMMENT 'Užklausų priežasties identifikatorius',
  `estatus_id` tinyint(3) unsigned NOT NULL COMMENT 'Vokų statuso identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `ch_nr` mediumint(8) unsigned NOT NULL DEFAULT 0 COMMENT 'Pakeitimo numeris',
  `stobis` mediumint(8) DEFAULT NULL COMMENT 'Kodas STOBIS',
  `data_discret` int(10) unsigned DEFAULT NULL,
  `exp_t` datetime DEFAULT NULL COMMENT 'Galiojimo pabaigos laiko žymė',
  `delayed_until` datetime DEFAULT NULL COMMENT 'Atidėto vykdymo laikas',
  `prq_bt` datetime DEFAULT NULL COMMENT 'Duomenų laiko intervalo pradžia',
  `prq_et` datetime DEFAULT NULL COMMENT 'Duomenų laiko intervalo pabaiga',
  `ee_id` int(10) unsigned DEFAULT NULL COMMENT 'Voko elemento identifikatorius',
  `withe_id` mediumint(8) DEFAULT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `enr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus elemento numeris',
  `write2device` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo reikšmė',
  `edevprq_msg` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Voko vykdymo užlausos pranešimas',
  `edevprq_gr_nr` smallint(5) unsigned DEFAULT NULL COMMENT 'Vokų vykdymo užklausos grupės numeris',
  PRIMARY KEY (`edev_id`,`edevprq_id`),
  KEY `edevprq_di_i` (`di_id`),
  KEY `edevprq_sep_i` (`sep_id`),
  KEY `edevprq_estatus_fk` (`estatus_id`),
  CONSTRAINT `edevprq_di_fk` FOREIGN KEY (`di_id`) REFERENCES `di` (`di_id`) ON DELETE CASCADE,
  CONSTRAINT `edevprq_edev_fk` FOREIGN KEY (`edev_id`) REFERENCES `edev` (`edev_id`) ON DELETE CASCADE,
  CONSTRAINT `edevprq_estatus_fk` FOREIGN KEY (`estatus_id`) REFERENCES `estatus` (`estatus_id`),
  CONSTRAINT `edevprq_sep_fk` FOREIGN KEY (`sep_id`) REFERENCES `sep` (`sep_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Vokų vykdymo užklausos';

-- Dumping data for table emcor.edevprq: ~0 rows (approximately)
/*!40000 ALTER TABLE `edevprq` DISABLE KEYS */;
/*!40000 ALTER TABLE `edevprq` ENABLE KEYS */;

-- Dumping structure for table emcor.edevprq_log
CREATE TABLE IF NOT EXISTS `edevprq_log` (
  `eapp_time` datetime NOT NULL COMMENT 'Aplikacijos voko sukūrimo laikas',
  `eapp_id` int(10) unsigned NOT NULL COMMENT 'Aplikacijos voko identifikatorius',
  `edev_id` int(10) unsigned NOT NULL COMMENT 'Prietaiso voko identifikatorius',
  `edevprq_id` int(10) unsigned NOT NULL COMMENT 'Vokų vykdymo užklausos identifikatorius',
  `ch_nr` mediumint(8) unsigned NOT NULL COMMENT 'Pakeitimo numeris',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `rc_id` tinyint(3) unsigned NOT NULL COMMENT 'Užklausų priežasties identifikatorius',
  `estatus_id` tinyint(3) unsigned NOT NULL COMMENT 'Vokų statuso identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `stobis` mediumint(8) DEFAULT NULL COMMENT 'Kodas STOBIS',
  `data_discret` int(10) unsigned DEFAULT NULL,
  `exp_t` datetime DEFAULT NULL COMMENT 'Galiojimo pabaigos laiko žymė',
  `delayed_until` datetime DEFAULT NULL COMMENT 'Atidėto vykdymo laikas',
  `prq_bt` datetime DEFAULT NULL COMMENT 'Duomenų laiko intervalo pradžia',
  `prq_et` datetime DEFAULT NULL COMMENT 'Duomenų laiko intervalo pabaiga',
  `ee_id` int(10) unsigned DEFAULT NULL COMMENT 'Voko elemento identifikatorius',
  `withe_id` mediumint(8) DEFAULT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `enr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus elemento numeris',
  `write2device` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo reikšmė',
  `edev_estatus_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Prietaiso voko statuso identifikatorius',
  `edev_step_type_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Prietaiso voko žingsnio tipo identifikatorius',
  `edevprq_msg` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Voko vykdymo užlausos pranešimas',
  `edevprq_gr_nr` smallint(5) unsigned DEFAULT NULL COMMENT 'Vokų vykdymo užklausos grupės numeris',
  PRIMARY KEY (`eapp_time`,`eapp_id`,`edev_id`,`edevprq_id`,`ch_nr`),
  KEY `edevprq_log_db_time_i` (`db_time`),
  KEY `edevprq_log_estatus_fk` (`estatus_id`),
  CONSTRAINT `edevprq_log_estatus_fk` FOREIGN KEY (`estatus_id`) REFERENCES `estatus` (`estatus_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Vokų vykdymo užklausų istorija';

-- Dumping data for table emcor.edevprq_log: ~0 rows (approximately)
/*!40000 ALTER TABLE `edevprq_log` DISABLE KEYS */;
/*!40000 ALTER TABLE `edevprq_log` ENABLE KEYS */;

-- Dumping structure for table emcor.edevprq_opty
CREATE TABLE IF NOT EXISTS `edevprq_opty` (
  `edev_id` int(10) unsigned NOT NULL COMMENT 'Prietaiso voko identifikatorius',
  `edevprq_id` int(10) unsigned NOT NULL COMMENT 'Vokų vykdymo užklausos identifikatorius',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`edev_id`,`edevprq_id`,`opty_id`),
  KEY `edevprq_opty_opty_fk` (`opty_id`),
  CONSTRAINT `edevprq_opty_edevprq_fk` FOREIGN KEY (`edev_id`, `edevprq_id`) REFERENCES `edevprq` (`edev_id`, `edevprq_id`) ON DELETE CASCADE,
  CONSTRAINT `edevprq_opty_opty_fk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Vokų vykdymo užklausų parametrai';

-- Dumping data for table emcor.edevprq_opty: ~0 rows (approximately)
/*!40000 ALTER TABLE `edevprq_opty` DISABLE KEYS */;
/*!40000 ALTER TABLE `edevprq_opty` ENABLE KEYS */;

-- Dumping structure for table emcor.edev_log
CREATE TABLE IF NOT EXISTS `edev_log` (
  `eapp_time` datetime NOT NULL COMMENT 'Aplikacijos voko sukūrimo laikas',
  `eapp_id` int(10) unsigned NOT NULL COMMENT 'Aplikacijos voko identifikatorius',
  `edev_id` int(10) unsigned NOT NULL COMMENT 'Prietaiso voko identifikatorius',
  `ch_nr` mediumint(8) unsigned NOT NULL COMMENT 'Pakeitimo numeris',
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `estatus_id` tinyint(3) unsigned NOT NULL COMMENT 'Vokų statuso identifikatorius',
  `edev_step_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Prietaiso voko žingsnio tipo identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `edev_msg` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Prietaiso voko pranešimas',
  PRIMARY KEY (`eapp_time`,`eapp_id`,`edev_id`,`ch_nr`),
  KEY `edev_log_db_time_i` (`db_time`),
  KEY `edev_log_edev_step_type_fk` (`edev_step_type_id`),
  KEY `edev_log_estatus_fk` (`estatus_id`),
  CONSTRAINT `edev_log_edev_step_type_fk` FOREIGN KEY (`edev_step_type_id`) REFERENCES `edev_step_type` (`edev_step_type_id`),
  CONSTRAINT `edev_log_estatus_fk` FOREIGN KEY (`estatus_id`) REFERENCES `estatus` (`estatus_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Prietaisų vokų istorija';

-- Dumping data for table emcor.edev_log: ~0 rows (approximately)
/*!40000 ALTER TABLE `edev_log` DISABLE KEYS */;
/*!40000 ALTER TABLE `edev_log` ENABLE KEYS */;

-- Dumping structure for table emcor.edev_opty
CREATE TABLE IF NOT EXISTS `edev_opty` (
  `edev_id` int(10) unsigned NOT NULL COMMENT 'Prietaiso voko identifikatorius',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`edev_id`,`opty_id`),
  KEY `edev_opty_opty_fk` (`opty_id`),
  CONSTRAINT `edev_opty_edev_fk` FOREIGN KEY (`edev_id`) REFERENCES `edev` (`edev_id`) ON DELETE CASCADE,
  CONSTRAINT `edev_opty_opty_fk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Prietaisų vokų parametrai';

-- Dumping data for table emcor.edev_opty: ~0 rows (approximately)
/*!40000 ALTER TABLE `edev_opty` DISABLE KEYS */;
/*!40000 ALTER TABLE `edev_opty` ENABLE KEYS */;

-- Dumping structure for table emcor.edev_step_type
CREATE TABLE IF NOT EXISTS `edev_step_type` (
  `edev_step_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Prietaiso voko žingsnio tipo identifikatorius',
  `edev_step_type_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Prietaiso voko žingsnio tipo kodas',
  `edev_step_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Prietaiso voko žingsnio tipo pavadinimas',
  PRIMARY KEY (`edev_step_type_id`),
  UNIQUE KEY `edev_step_type_code_u` (`edev_step_type_code`),
  UNIQUE KEY `edev_step_type_name_u` (`edev_step_type_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Prietaiso vokų žingsnių tipai';

-- Dumping data for table emcor.edev_step_type: ~5 rows (approximately)
/*!40000 ALTER TABLE `edev_step_type` DISABLE KEYS */;
INSERT INTO `edev_step_type` (`edev_step_type_id`, `edev_step_type_code`, `edev_step_type_name`) VALUES
	(1, 'CREATION', 'Voko sukūrimas'),
	(2, 'CREATE_RESOURCE', 'Kuriamas resursas'),
	(3, 'READ_RESOURCE', 'Nuskaitomas resursas'),
	(4, 'DELETE_RESOURCE', 'Naikinamas resursas'),
	(5, 'END', 'Baigta');
/*!40000 ALTER TABLE `edev_step_type` ENABLE KEYS */;

-- Dumping structure for table emcor.ee
CREATE TABLE IF NOT EXISTS `ee` (
  `eapp_time` datetime NOT NULL COMMENT 'Aplikacijos voko sukūrimo laikas',
  `eapp_id` int(10) unsigned NOT NULL COMMENT 'Aplikacijos voko identifikatorius',
  `ee_id` int(10) unsigned NOT NULL COMMENT 'Voko elemento identifikatorius',
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `ph_id` int(10) unsigned NOT NULL COMMENT 'Ryšio kanalo identifikatorius',
  `di_id` int(10) unsigned NOT NULL COMMENT 'Nuskaitomų duomenų elemento identifikatorius',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `estatus_id` tinyint(3) unsigned NOT NULL COMMENT 'Vokų statuso identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `ch_nr` mediumint(8) unsigned NOT NULL DEFAULT 0 COMMENT 'Pakeitimo numeris',
  `stobis` mediumint(8) NOT NULL COMMENT 'Kodas STOBIS',
  `data_discret` int(10) unsigned DEFAULT NULL,
  `exp_t` datetime DEFAULT NULL COMMENT 'Galiojimo pabaigos laiko žymė',
  `rodo_nr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Užsakymo elemento numeris',
  `edev_id` int(10) unsigned DEFAULT NULL COMMENT 'Prietaiso voko identifikatorius',
  `ee_bt` datetime DEFAULT NULL COMMENT 'Duomenų laiko intervalo pradžia',
  `ee_et` datetime DEFAULT NULL COMMENT 'Duomenų laiko intervalo pabaiga',
  `withe_id` mediumint(8) DEFAULT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `enr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus elemento numeris',
  `write2device` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo reikšmė',
  `ee_msg` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Voko elemento pranešimas',
  PRIMARY KEY (`eapp_id`,`ee_id`),
  KEY `ee_di_i` (`di_id`),
  KEY `ee_dp_i` (`dp_id`),
  KEY `ee_eapp_i` (`eapp_id`),
  KEY `ee_edev_i` (`edev_id`),
  KEY `ee_sep_i` (`sep_id`),
  KEY `ee_estatus_fk` (`estatus_id`),
  CONSTRAINT `ee_di_fk` FOREIGN KEY (`di_id`) REFERENCES `di` (`di_id`) ON DELETE CASCADE,
  CONSTRAINT `ee_eapp_fk` FOREIGN KEY (`eapp_id`) REFERENCES `eapp` (`eapp_id`) ON DELETE CASCADE,
  CONSTRAINT `ee_estatus_fk` FOREIGN KEY (`estatus_id`) REFERENCES `estatus` (`estatus_id`),
  CONSTRAINT `ee_sep_fk` FOREIGN KEY (`sep_id`) REFERENCES `sep` (`sep_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Vokų elementai';

-- Dumping data for table emcor.ee: ~0 rows (approximately)
/*!40000 ALTER TABLE `ee` DISABLE KEYS */;
/*!40000 ALTER TABLE `ee` ENABLE KEYS */;

-- Dumping structure for table emcor.ee_log
CREATE TABLE IF NOT EXISTS `ee_log` (
  `eapp_time` datetime NOT NULL COMMENT 'Aplikacijos voko sukūrimo laikas',
  `eapp_id` int(10) unsigned NOT NULL COMMENT 'Aplikacijos voko identifikatorius',
  `ee_id` int(10) unsigned NOT NULL COMMENT 'Voko elemento identifikatorius',
  `ch_nr` mediumint(8) unsigned NOT NULL COMMENT 'Pakeitimo numeris',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `estatus_id` tinyint(3) unsigned NOT NULL COMMENT 'Vokų statuso identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `stobis` mediumint(8) NOT NULL COMMENT 'Kodas STOBIS',
  `data_discret` int(10) unsigned DEFAULT NULL,
  `exp_t` datetime DEFAULT NULL COMMENT 'Galiojimo pabaigos laiko žymė',
  `rodo_nr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Užsakymo elemento numeris',
  `edev_id` int(10) unsigned DEFAULT NULL COMMENT 'Prietaiso voko identifikatorius',
  `ee_bt` datetime DEFAULT NULL COMMENT 'Duomenų laiko intervalo pradžia',
  `ee_et` datetime DEFAULT NULL COMMENT 'Duomenų laiko intervalo pabaiga',
  `withe_id` mediumint(8) DEFAULT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `enr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus elemento numeris',
  `write2device` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo reikšmė',
  `ee_msg` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Voko elemento pranešimas',
  PRIMARY KEY (`eapp_time`,`eapp_id`,`ee_id`,`ch_nr`),
  KEY `ee_log_db_time_i` (`db_time`),
  KEY `ee_log_estatus_fk` (`estatus_id`),
  CONSTRAINT `ee_log_estatus_fk` FOREIGN KEY (`estatus_id`) REFERENCES `estatus` (`estatus_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Vokų elementų istorija';

-- Dumping data for table emcor.ee_log: ~0 rows (approximately)
/*!40000 ALTER TABLE `ee_log` DISABLE KEYS */;
/*!40000 ALTER TABLE `ee_log` ENABLE KEYS */;

-- Dumping structure for table emcor.enum
CREATE TABLE IF NOT EXISTS `enum` (
  `enum_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Išvardinimo identifikatorius',
  `enum_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Išvardinimo kodas',
  `enum_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Išvardinimo pavadinimas',
  `enum_type_id` mediumint(8) unsigned NOT NULL DEFAULT 0 COMMENT 'Išvardinimų naudojimo tipo ID',
  PRIMARY KEY (`enum_id`),
  UNIQUE KEY `enum_code_u` (`enum_code`),
  UNIQUE KEY `enum_name_u` (`enum_name`),
  KEY `enum_type_fk` (`enum_type_id`),
  CONSTRAINT `enum_enum_type_fk` FOREIGN KEY (`enum_type_id`) REFERENCES `enum_type` (`enum_type_id`)
) ENGINE=InnoDB AUTO_INCREMENT=1159 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Išvardinimai';

-- Dumping data for table emcor.enum: ~909 rows (approximately)
/*!40000 ALTER TABLE `enum` DISABLE KEYS */;
INSERT INTO `enum` (`enum_id`, `enum_code`, `enum_name`, `enum_type_id`) VALUES
	(1, 'Protocol', 'Protokolas', 1),
	(2, 'StopBits', 'Sustojimo bitai', 0),
	(3, 'DataBits', 'Duomenų bitai', 0),
	(4, 'Parity', 'Lyginumas', 0),
	(5, 'HwHandshake', 'HwHandshake', 1),
	(6, 'SwHandshake', 'SwHandshake', 1),
	(7, 'RTSToggle', 'RTSToggle', 1),
	(8, 'BaudRate', 'BaudRate', 0),
	(9, 'IP_Kind', 'IP_Kind', 1),
	(41, 'OnOff', 'OnOff', 1),
	(61, 'MsType', 'MsType', 1),
	(82, 'YesNo', 'TaipNe', 0),
	(83, 'Voltage', 'Nominali įtampa', 1),
	(84, 'ABB_TypeCode', 'ABB prietaiso tipas', 1),
	(88, 'Disp', 'Duomenų išdėstymas Excel ataskaitose', 2),
	(92, 'UseTransport', 'Transporto tipo panaudojimas', 1),
	(96, 'BinaryXML', 'Priedo formatas', 2),
	(107, 'Language', 'Kalba', 0),
	(116, 'PointDataRead', 'Matavimų archyvų nuskaitymo metodas', 1),
	(117, 'Manufacturer_MBus', 'MBus prietaiso modelis', 0),
	(121, 'Protocol_MultiCal', 'Protokolų rinkinys MultiCal', 1),
	(122, 'Protocol_DK', 'Protokolų rinkinys DK', 1),
	(123, 'Protocol_EKOM', 'Protokolų rinkinys EKOM', 1),
	(124, 'Protocol_MBus', 'Protokolų rinkinys MBus', 1),
	(126, 'Protocol_Only_MBus', 'Protokolas MBus', 1),
	(136, 'DataSheet', 'Suformuotoje ataskaitoje "data" lapą', 2),
	(141, 'DAYTYPE', 'Dienos tipas', 2),
	(146, 'W10012E', 'Maitinimo elementas pakrautas', 3),
	(147, 'W10009E', 'Fatalinė klaida', 3),
	(148, 'W10007E', 'Fazių seka korektiška', 3),
	(149, 'W10000E', 'Fazė L1', 3),
	(150, 'W10001E', 'Fazė L2', 3),
	(151, 'W10002E', 'Fazė L3', 3),
	(152, 'W10029E', 'Maitinimas', 3),
	(153, 'W10003E', 'Magnetinio lauko poveikis skaitikliui', 3),
	(154, 'W10004E', 'Netinkama temperatura', 3),
	(155, 'W10005E', 'Ryšio blokavimas', 3),
	(156, 'W10006E', 'Leidimas gamykliniam parametravimui', 3),
	(157, 'W10008E', 'Laikrodžio sutrikimas', 3),
	(158, 'W10010E', 'Relės nr.1 jungimas', 3),
	(159, 'W10011E', 'Relės nr.2 jungimas', 3),
	(160, 'W10013E', 'Vasaros laikas', 3),
	(161, 'W10030E', 'Skaitiklis rezerviniame maitinime', 3),
	(162, 'W10261E', 'Sesijos atidarymas', 3),
	(163, 'W10264E', 'Sujungimo nustatymas', 3),
	(164, 'W10266E', 'Ryšys su moduliu', 3),
	(165, 'W10267E', 'Ryšys su modulių grupe', 3),
	(166, 'W10268E', 'Konfiguracijos klaida', 3),
	(167, 'W10269E', 'Skaičiavimo klaida', 3),
	(168, 'W10270E', 'Diapazono viršijimas', 3),
	(169, 'W10053E', 'Prietaiso jungimas', 3),
	(170, 'W10056E', 'Prieigos prie skaitiklio nėra', 3),
	(171, 'W10062E', 'Atidarytas COM-tunelis', 3),
	(172, 'W10063E', 'Testo išjungimas', 3),
	(173, 'W10064E', 'Bloko atsisakymas', 3),
	(174, 'W10065E', 'Specialus signalas', 3),
	(175, 'W10066E', 'Jutiklio gedimas', 3),
	(176, 'W10067E', 'Jutiklis - išėjimas už MAX', 3),
	(177, 'W10068E', 'Jutiklis - išėjimas už MIN', 3),
	(178, 'W10078E', 'Paleidimas', 3),
	(179, 'W10079E', 'Apkrovos viršijimas', 3),
	(180, 'W10080E', 'Laiko korekcija blokuota', 3),
	(181, 'W10084E', 'Limito viršijimas', 3),
	(182, 'W10096E', 'Galios ribos peržengimas', 3),
	(183, 'W10097E', 'Įtampos iškraipymų koeficiento ribos peržengimas', 3),
	(184, 'W10098E', 'Dažnio viršutinės ribos peržengimas', 3),
	(185, 'W10099E', 'Dažnio apatinės ribos peržengimas', 3),
	(186, 'W10100E', 'Tiesioginės sekos įtampos U1(1) viršutinės ribos peržengimas', 3),
	(187, 'W10101E', 'Tiesioginės sekos įtampos U1(1) apatinės ribos peržengimas', 3),
	(188, 'W10102E', '1 fazės įtampos viršutinės ribos peržengimas', 3),
	(189, 'W10103E', '1 fazės įtampos apatinės ribos peržengimas', 3),
	(190, 'W10104E', '2 fazės įtampos viršutinės ribos peržengimas', 3),
	(191, 'W10105E', '2 fazės įtampos apatinės ribos peržengimas', 3),
	(192, 'W10106E', '3 fazės įtampos viršutinės ribos peržengimas', 3),
	(193, 'W10107E', '3 fazės įtampos apatinės ribos peržengimas', 3),
	(194, 'W10119E', 'Dažnio viršutinės ALVR peržengimas', 3),
	(195, 'W10120E', 'Dažnio viršutinės NLVR peržengimas', 3),
	(196, 'W10121E', 'Dažnio apatinės ALVR peržengimas', 3),
	(197, 'W10122E', 'Dažnio apatinės NLVR peržengimas', 3),
	(198, 'W10123E', 'Tiesioginės sekos įtampos U1(1) viršutinės ALVR peržengimas', 3),
	(199, 'W10124E', 'Tiesioginės sekos įtampos U1(1) viršutinės NLVR peržengimas', 3),
	(200, 'W10125E', 'Tiesioginės sekos įtampos U1(1) apatinės ALVR peržengimas', 3),
	(201, 'W10126E', 'Tiesioginės sekos įtampos U1(1) apatinės NLVR peržengimas', 3),
	(202, 'W10127E', '1 fazės įtampos viršutinės ALVR peržengimas', 3),
	(203, 'W10128E', '1 fazės įtampos viršutinės NLVR peržengimas', 3),
	(204, 'W10129E', '1 fazės įtampos apatinės ALVR peržengimas', 3),
	(205, 'W10130E', '1 fazės įtampos apatinės NLVR peržengimas', 3),
	(206, 'W10131E', '2 fazės įtampos viršutinės ALVR peržengimas', 3),
	(207, 'W10132E', '2 fazės įtampos viršutinės NLVR peržengimas', 3),
	(208, 'W10133E', '2 fazės įtampos apatinės ALVR peržengimas', 3),
	(209, 'W10134E', '2 fazės įtampos apatinės NLVR peržengimas', 3),
	(210, 'W10135E', '3 fazės įtampos viršutinės ALVR peržengimas', 3),
	(211, 'W10136E', '3 fazės įtampos viršutinės NLVR peržengimas', 3),
	(212, 'W10137E', '3 fazės įtampos apatinės ALVR peržengimas', 3),
	(213, 'W10138E', '3 fazės įtampos apatinės NLVR peržengimas', 3),
	(214, 'W10139E', 'Įtampos tarp fazių 12 viršutinės ALVR peržengimas', 3),
	(215, 'W10140E', 'Įtampos tarp fazių 12 viršutinės NLVR peržengimas', 3),
	(216, 'W10141E', 'Įtampos tarp fazių 12 apatinės ALVR peržengimas', 3),
	(217, 'W10142E', 'Įtampos tarp fazių 12 apatinės NLVR peržengimas', 3),
	(218, 'W10143E', 'Įtampos tarp fazių 23 viršutinės ALVR peržengimas', 3),
	(219, 'W10144E', 'Įtampos tarp fazių 23 viršutinės NLVR peržengimas', 3),
	(220, 'W10145E', 'Įtampos tarp fazių 23 apatinės ALVR peržengimas', 3),
	(221, 'W10146E', 'Įtampos tarp fazių 23 apatinės NLVR peržengimas', 3),
	(222, 'W10147E', 'Įtampos tarp fazių 31 viršutinės ALVR peržengimas', 3),
	(223, 'W10148E', 'Įtampos tarp fazių 31 viršutinės NLVR peržengimas', 3),
	(224, 'W10149E', 'Įtampos tarp fazių 31 apatinės ALVR peržengimas', 3),
	(225, 'W10150E', 'Įtampos tarp fazių 31 apatinės NLVR peržengimas', 3),
	(226, 'W10151E', '1 fazės įtampos iškraipymų koeficiento ALVR peržengimas', 3),
	(227, 'W10152E', '1 fazės įtampos iškraipymų koeficiento NLVR peržengimas', 3),
	(228, 'W10153E', '2 fazės įtampos iškraipymų koeficiento ALVR peržengimas', 3),
	(229, 'W10154E', '2 fazės įtampos iškraipymų koeficiento NLVR peržengimas', 3),
	(230, 'W10155E', '3 fazės įtampos iškraipymų koeficiento ALVR peržengimas', 3),
	(231, 'W10156E', '3 fazės įtampos iškraipymų koeficiento NLVR peržengimas', 3),
	(232, 'W10157E', 'Įtampos iškraipymų koeficiento tarp fazių 12 ALVR peržengimas', 3),
	(233, 'W10158E', 'Įtampos iškraipymų koeficiento tarp fazių 12 NLVR peržengimas', 3),
	(234, 'W10159E', 'Įtampos iškraipymų koeficiento tarp fazių 23 ALVR peržengimas', 3),
	(235, 'W10160E', 'Įtampos iškraipymų koeficiento tarp fazių 23 NLVR peržengimas', 3),
	(236, 'W10161E', 'Įtampos iškraipymų koeficiento tarp fazių 31 ALVR peržengimas', 3),
	(237, 'W10162E', 'Įtampos iškraipymų koeficiento tarp fazių 31 NLVR peržengimas', 3),
	(238, 'W10163E', 'Nulinės sekos nesimetrinės įtampos koeficiento ALVR peržengimas', 3),
	(239, 'W10164E', 'Nulinės sekos nesimetrinės įtampos koeficiento NLVR peržengimas', 3),
	(240, 'W10165E', 'Atvirkštinės sekos nesimetrinės įtampos koeficiento ALVR peržengimas', 3),
	(241, 'W10166E', 'Atvirkštinės sekos nesimetrinės įtampos koeficiento NLVR peržengimas', 3),
	(242, 'W10242E', 'Blogas ryšys su prietaisu', 3),
	(243, 'W10243E', 'Prietaisas neatsako', 3),
	(244, 'W10244E', 'Neteisingas prietaiso priėjimo slaptažodis', 3),
	(245, 'W10245E', 'Netinkamas prietaiso aprašymas', 3),
	(246, 'W10246E', 'Neteisingai sukonfiguruotas prietaisas', 3),
	(247, 'W10247E', 'Netinkamas parametro aprašymas', 3),
	(248, 'W10248E', 'Prietaiso atsakymas su klaidos kodu', 3),
	(249, 'W10249E', 'Nežinoma klaida', 3),
	(250, 'W10250E', 'Skaitiklio kleminio dangčio atidarymas', 3),
	(251, 'Journal_number', 'Žurnalo numeris', 1),
	(252, 'W10299E', 'Konfiguravimas uždraustas', 3),
	(253, 'W10300E', 'Ryšys IEC 870-5-101 yra', 3),
	(254, 'W10301E', 'Ryšys IEC 870-5-104 yra', 3),
	(255, 'W10302E', 'Maitinimas iš elemento', 3),
	(256, 'W10303E', 'Įtampa - išėjimas už MAX', 3),
	(257, 'W10304E', 'Įtampa - išėjimas už MIN', 3),
	(258, 'W10305E', 'Srovė - išėjimas už MIN', 3),
	(259, 'W10306E', 'Ribos peržengimas', 3),
	(260, 'W10307E', 'Galios koeficiento ribos peržengimas', 3),
	(261, 'W10308E', '2 harmoninės srovės ribos peržengimas', 3),
	(262, 'W10309E', 'Nesinusoidinės srovės ribos peržengimas', 3),
	(263, 'W10310E', 'Fazių įtampų atitikimo ribos peržengimas', 3),
	(264, 'W10311E', 'Fazių srovių atitikimo ribos peržengimas', 3),
	(265, 'W10312E', 'Apkrovos iškreipimo ribos peržengimas', 3),
	(266, 'W10313E', 'dP ribos peržengimas', 3),
	(267, 'W10314E', 'dP apatinės ribos peržengimas', 3),
	(268, 'W10315E', 'dP viršutinės ribos peržengimas', 3),
	(269, 'W10316E', 'dP išėjimas po atkirtą', 3),
	(270, 'W10317E', 'Dažnio viršutinės ribos peržengimas, kanalas 1', 3),
	(271, 'W10318E', 'Dažnio viršutinės ribos peržengimas, kanalas 2', 3),
	(272, 'W10319E', 'Dažnio viršutinės ribos peržengimas, kanalas 3', 3),
	(273, 'W10320E', 'Dažnio viršutinės ribos peržengimas, kanalas 4', 3),
	(274, 'W10321E', 'Suvartojimo viršutinės ribos peržengimas', 3),
	(275, 'W10322E', 'Suvartojimo apatinės ribos peržengimas', 3),
	(276, 'W10323E', 'Suvartojimo viršutinės ribos peržengimas, kanalas 1', 3),
	(277, 'W10324E', 'Suvartojimo apatinės ribos peržengimas, kanalas 1', 3),
	(278, 'W10325E', 'Suvartojimo viršutinės ribos peržengimas, kanalas 2', 3),
	(279, 'W10326E', 'Suvartojimo apatinės ribos peržengimas, kanalas 2', 3),
	(280, 'W10327E', 'Suvartojimo viršutinės ribos peržengimas, kanalas 3', 3),
	(281, 'W10328E', 'Suvartojimo apatinės ribos peržengimas, kanalas 3', 3),
	(282, 'W10329E', 'Suvartojimo viršutinės ribos peržengimas, kanalas 4', 3),
	(283, 'W10330E', 'Suvartojimo apatinės ribos peržengimas, kanalas 4', 3),
	(284, 'W10331E', 'Suvartojimo viršutinio slenksčio peržengimas', 3),
	(285, 'W10332E', 'Suvartojimo apatinio slenksčio peržengimas', 3),
	(286, 'W10333E', 'Suvartojimo viršutinio slenksčio peržengimas, kanalas 1', 3),
	(287, 'W10334E', 'Suvartojimo apatinio slenksčio peržengimas, kanalas 1', 3),
	(288, 'W10335E', 'Suvartojimo viršutinio slenksčio peržengimas, kanalas 2', 3),
	(289, 'W10336E', 'Suvartojimo apatinio slenksčio peržengimas, kanalas 2', 3),
	(290, 'W10337E', 'Suvartojimo viršutinio slenksčio peržengimas, kanalas 3', 3),
	(291, 'W10338E', 'Suvartojimo apatinio slenksčio peržengimas, kanalas 3', 3),
	(292, 'W10339E', 'Suvartojimo viršutinio slenksčio peržengimas, kanalas 4', 3),
	(293, 'W10340E', 'Suvartojimo apatinio slenksčio peržengimas, kanalas 4', 3),
	(294, 'W10341E', 'Suvartojimo viršutinio apribojimo peržengimas', 3),
	(295, 'W10342E', 'Suvartojimo apatinio apribojimo peržengimas', 3),
	(296, 'W10343E', 'Suvartojimo viršutinio apribojimo peržengimas, kanalas 1', 3),
	(297, 'W10344E', 'Suvartojimo apatinio apribojimo peržengimas, kanalas 1', 3),
	(298, 'W10345E', 'Suvartojimo viršutinio apribojimo peržengimas, kanalas 2', 3),
	(299, 'W10346E', 'Suvartojimo apatinio apribojimo peržengimas, kanalas 2', 3),
	(300, 'W10347E', 'Suvartojimo viršutinio apribojimo peržengimas, kanalas 3', 3),
	(301, 'W10348E', 'Suvartojimo apatinio apribojimo peržengimas, kanalas 3', 3),
	(302, 'W10349E', 'Suvartojimo viršutinio apribojimo peržengimas, kanalas 4', 3),
	(303, 'W10350E', 'Suvartojimo apatinio apribojimo peržengimas, kanalas 4', 3),
	(304, 'W10400E', 'Analoginio įėjimo apatinės ribos peržengimas', 3),
	(305, 'W10401E', 'Analoginio įėjimo viršutinės ribos peržengimas', 3),
	(306, 'W10402E', 'T viršutinės ribos peržengimas', 3),
	(307, 'W10403E', 'T apatinės ribos peržengimas', 3),
	(308, 'W10404E', 'P viršutinės ribos peržengimas', 3),
	(309, 'W10405E', 'P apatinės ribos peržengimas', 3),
	(310, 'W10446E', 'GPS laikas atstatytas', 3),
	(311, 'W10447E', 'Apkrovos įjungimas', 3),
	(312, 'W10450E', '1 fazės srovė be įtampos', 3),
	(313, 'W10451E', '2 fazės srovė be įtampos', 3),
	(314, 'W10452E', '3 fazės srovė be įtampos', 3),
	(315, 'W10454E', 'Testas IM1 - sėkmingai', 3),
	(316, 'W10455E', 'Testas IM2 - sėkmingai', 3),
	(317, 'W10456E', 'Testas IM3 - sėkmingai', 3),
	(318, 'W10457E', 'Testas IM4 - sėkmingai', 3),
	(319, 'W10458E', 'Apsaugos jungiklis IM1 įjungtas', 3),
	(320, 'W10459E', 'Apsaugos jungiklis IM2 įjungtas', 3),
	(321, 'W10460E', 'Apsaugos jungiklis IM3 įjungtas', 3),
	(322, 'W10461E', 'Apsaugos jungiklis IM4 įjungtas', 3),
	(323, 'W10465E', 'Režimas "Neetatinis"', 3),
	(324, 'W10466E', 'Įjungimo leidimas pagal komandą', 3),
	(325, 'W10467E', 'Fazės atsistatymas', 3),
	(326, 'W10468E', 'Įjungimo leidimas pagal kredito nustatymą', 3),
	(327, 'W10469E', 'Skaičiavimo atnaujinimas', 3),
	(328, 'W10470E', 'Testas RAM IM1 - sėkmingai', 3),
	(329, 'W10471E', 'Testas RAM IM2 - sėkmingai', 3),
	(330, 'W10472E', 'Testas RAM IM3 - sėkmingai', 3),
	(331, 'W10473E', 'Testas RAM IM4 - sėkmingai', 3),
	(332, 'W10477E', 'RTC skaitymo klaida', 3),
	(333, 'W10478E', 'Įjungimo leidimas dėl temperatūros sumažėjimo', 3),
	(334, 'W10481E', 'RTC įrašymo klaida', 3),
	(335, 'W10482E', 'EEPROM skaitymo klaida', 3),
	(336, 'W10483E', 'EEPROM įrašymo klaida', 3),
	(337, 'W10484E', 'Suveikė apribojimas', 3),
	(338, 'W10485E', 'Skaitiklio sisteminė klaida', 3),
	(339, 'W10486E', 'EEPROM IM1 parametrų skatymo/rašymo klaida', 3),
	(340, 'W10487E', 'EEPROM IM2 parametrų skatymo/rašymo klaida', 3),
	(341, 'W10488E', 'EEPROM IM3 parametrų skatymo/rašymo klaida', 3),
	(342, 'W10489E', 'EEPROM IM4 parametrų skatymo/rašymo klaida', 3),
	(343, 'W10490E', 'Ryšys su IM1 atstatytas', 3),
	(344, 'W10491E', 'Ryšys su IM2 atstatytas', 3),
	(345, 'W10492E', 'Ryšys su IM3 atstatytas', 3),
	(346, 'W10493E', 'Ryšys su IM4 atstatytas', 3),
	(347, 'W10503E', 'Gedimas RS-485', 3),
	(348, 'W10504E', 'Gedimas PIC', 3),
	(349, 'W10509E', 'Procesoriaus gedimas', 3),
	(350, 'W10510E', 'Taimerio gedimas', 3),
	(351, 'W10511E', 'Flash atminties gedimas', 3),
	(352, 'W10512E', 'I ritės MAX peržengimas', 3),
	(353, 'W10513E', 'ABB gedimas', 3),
	(354, 'W10514E', 'ABB grandinės klaida', 3),
	(355, 'W10515E', 'ABB srovės įėjimo kanale klaida', 3),
	(356, 'W10516E', 'ABB varžos įėjimo kanale klaida', 3),
	(357, 'METER_TYPES_MND', 'Matavimo prietaisų tipai MND', 0),
	(361, 'ASKP_DATE_USE', 'Datos naudojimas ASKP dokumento pavadinime', 2),
	(362, 'ASKP_VERSION', 'ASKP failo versija', 2),
	(366, 'TestMode', 'Technologinės informacijos išvedimas', 1),
	(371, 'ROLES', 'Vartotojų rolių aprašymai', 0),
	(377, 'DeviceType', 'Prietaiso tipas', 1),
	(381, 'TypeCode68', 'Tipo kodas (68)', 1),
	(382, 'TypeCode69', 'Tipo kodas (69)', 1),
	(383, 'TypeCode79', 'Tipo kodas (79)', 1),
	(384, 'TypeCode80', 'Tipo kodas (80)', 1),
	(391, 'Manufacturer_Danfoss_Sharky', 'Manufacturer Danfoss Sharky', 1),
	(392, 'Manufacturer_ABB_SVM_F2', 'Manufacturer ABB_SVM F2', 1),
	(393, 'Manufacturer_PadPuls_M2C ', 'Manufacturer PadPuls M2C ', 1),
	(394, 'Manufacturer_Sonometer_1000', 'Manufacturer Danfoss Sonometer 1000', 1),
	(395, 'Manufacturer_MultiCal', 'Manufacturer MultiCal', 1),
	(396, 'Manufacturer_Combimeter_Q', 'Manufacturer Combimeter Q', 1),
	(397, 'Manufacturer_Infocal5', 'Manufacturer Infocal 5', 1),
	(398, 'Manufacturer_Hydro_Port', 'Manufacturer Hydro Port', 1),
	(399, 'Manufacturer_SiemensPulse_adapter', 'Manufacturer Siemens Pulse-adapter', 1),
	(400, 'Manufacturer_Siemens_WTT16', 'Manufacturer Siemens_WTT16', 1),
	(401, 'Manufacturer_Siemens_WFC21', 'Manufacturer Siemens_WFC21', 1),
	(402, 'Manufacturer_Siemens_WFM21', 'Manufacturer Siemens-WFM21', 1),
	(403, 'Manufacturer_Sensus_HRI ', 'Manufacturer Sensus-HRI ', 1),
	(404, 'Manufacturer_Siemens_AEW310', 'Manufacturer Siemens AEW310', 1),
	(405, 'Manufacturer_Siemens_UH50', 'Manufacturer Siemens UH50', 1),
	(406, 'Protocol_SET_PSC', 'Protokolų rinkinys SET PSC', 1),
	(411, 'Manufacturer_Actaris_CF_55', 'Manufacturer Actaris CF 55', 1),
	(416, 'HIDE_1', 'HIDE_1', 3),
	(421, 'W10548E', 'Atvirkštinės krypties energijos tėkmė', 3),
	(422, 'W10549E', 'Atvirkštinės krypties energijos tėkmė 1-je fazėje', 3),
	(423, 'W10550E', 'Atvirkštinės krypties energijos tėkmė 2-je fazėje', 3),
	(424, 'W10551E', 'Atvirkštinės krypties energijos tėkmė 3-je fazėje', 3),
	(425, 'W10554E', 'Srovės dingimas', 3),
	(426, 'W10562E', 'Įtampos dingimas', 3),
	(431, 'TypeCode101', 'Tipo kodas (101)', 1),
	(441, 'User', 'Vartotojas', 1),
	(442, 'TypeCodeMCL', 'MCL tipo kodas', 1),
	(456, 'W10581E', 'Nepatikimas išorinis valdymas', 3),
	(461, 'HalfHourSum', 'Imti duomenis iš', 1),
	(466, 'SubDirs', 'Subkatalogų struktūros pateikimas', 1),
	(467, 'WHAT_TIME', 'Siųsti papildomai laiką', 2),
	(471, 'UNIQUE_KEYS', 'Unikalių raktų aprašymai', 0),
	(472, 'CHECK_KEYS', 'Patikrinimo raktų aprašymai', 0),
	(476, 'CODEPAGE', 'Koduotė', 2),
	(477, 'ASKP_UNIT', 'ASKP formos matavimo vienetai', 2),
	(481, 'EXPORT_TIMEZONE', 'Eksportuoti duomenis:', 2),
	(486, 'SendErrorifBoud', 'Jei pasiekta duomenų keitimo laiko riba - siųsti ', 1),
	(491, 'W10591', '1 fazės matavimo požymis', 3),
	(492, 'W10592', '2 fazės matavimo požymis', 3),
	(493, 'W10593', '3 fazės matavimo požymis', 3),
	(494, 'W10594', '1 fazės srovės kryptis', 3),
	(495, 'W10595', '2 fazės srovės kryptis', 3),
	(496, 'W10596', '3 fazės srovės kryptis', 3),
	(497, 'W10598', 'Profilio rodyklių apdorojimas', 3),
	(498, 'W10599', 'Dienų rodyklių apdorojimas', 3),
	(499, 'W10600', 'Mėnesių rodyklių apdorojimas', 3),
	(500, 'W10689', 'Maitinimas 12 V', 3),
	(501, 'W10690', 'Įvykių būklė maitinimo dingimų žurnale ', 3),
	(502, 'W10691', 'Įvykių būklė fazių perjungimų žurnale ', 3),
	(503, 'W10692', 'Įvykių būklė žurnale ', 3),
	(504, 'W10693', 'Ryšys parametravimui per optinę galvutę', 3),
	(505, 'W10694', 'Ryšys skaitymui per optinę galvutę', 3),
	(506, 'W10695', 'Integravimo periodo būklė', 3),
	(507, 'W10696', 'Dienos būklė', 3),
	(508, 'W10697', 'Mėnesio būklė', 3),
	(509, 'W10698', 'Metų būklė', 3),
	(510, 'W10699', 'Laiko korekcijos ribos būklė', 3),
	(511, 'W10700', 'Blogas VKM', 3),
	(512, 'W10726', 'Vasaros laiko režimas', 3),
	(513, 'W10730', 'Parduotuvės režimas skaitiklyje', 3),
	(514, 'W10736', 'Įrenginio izoliacijos būklė', 3),
	(515, 'Power', 'Galia ryšiui', 1),
	(516, 'RadioChannel', 'Radiosignalo numeris', 1),
	(522, 'Off|On', 'Off|On', 0),
	(523, 'DeviceTypeWM22EM4', 'Prietaiso tipas WM22/EM4', 1),
	(524, 'Protocol_EA', 'Protokolų rinkinys EuroAlpha', 1),
	(525, 'TRUE/FALSE', 'TRUE/FALSE', 1),
	(526, 'TypeCode161', 'Tipo kodas (161)', 1),
	(527, 'WS_Type', 'Web serviso tipas', 2),
	(528, 'Action', 'Operacija', 0),
	(529, 'DeviceTypeMDC', 'Prietaiso tipas MDC', 1),
	(530, 'DeviceTypeMDC_EPQS', 'Prietaiso tipas MDC_EPQS', 1),
	(531, 'DeviceTypeMDC_EPQM', 'Prietaiso tipas MDC_EPQM', 1),
	(532, 'DeviceTypeMDC_EMS', 'Prietaiso tipas MDC_EMS', 1),
	(533, 'DeviceTypeMDC_GAMA', 'Prietaiso tipas MDC_GAMA', 1),
	(534, 'Manufacturer_Wehrle_ETK_EAX', 'Manufacturer Wehrle ETK-EAX', 1),
	(535, 'Gateway_through', 'Rišamasi ', 1),
	(536, 'StoredData', 'Duomenys ', 1),
	(537, 'DeviceVersionMDC', 'MDC prietaiso versija', 1),
	(538, 'AddInc', 'Prieaugio reikšmę ', 1),
	(539, 'ThreewireFourwire', 'TrilaidisKeturlaidis', 1),
	(540, 'TypeCodeCEEO', 'Kodo tipas CEEO', 1),
	(541, 'TypeCodeDmz', 'Kodo tipas Dmz', 1),
	(542, 'DeviceTypeDKEG', 'Prietaiso tipas DKEG', 1),
	(543, 'Mercury_225_RemoteBaudRate', 'Mercury_225 COM greitis', 1),
	(544, 'Mercury_225_RemoteDataBits', 'Mercury_225 duomenų bitai', 1),
	(545, 'Mercury_225_RemoteParity', 'Mercury_225 lyginumas', 1),
	(546, 'Mercury_225_RemoteStopBits', 'Mercury_225 sustojimo bitai', 1),
	(547, 'Mercury_230_RemoteBaudRate', 'Mercury_230 COM greitis', 1),
	(548, 'Mercury_230_RemoteDataBits', 'Mercury_230 duomenų bitai', 1),
	(549, 'Mercury_230_RemoteParity', 'Mercury_230 lyginumas', 1),
	(550, 'Mercury_230_RemoteStopBits', 'Mercury_230 sustojimo bitai', 1),
	(551, 'DeviceVersionOblik', 'Oblik prietaiso versija', 1),
	(553, 'W10772', 'Fazės įtampos dingimas', 3),
	(554, 'W10775', 'Įtampos testavimas', 3),
	(555, 'W10776', 'Įtampa normos ribose', 3),
	(556, 'W10777', 'Įtampa normos ribose', 3),
	(557, 'W10778', 'Įtampos reverso koeficiento testavimas', 3),
	(558, 'W10779', 'Srovė yra normos ribose', 3),
	(559, 'W10780', 'Įtampos koeficiento testavimas', 3),
	(560, 'W10781', 'Antra harmoninė srovė yra normos ribose', 3),
	(561, 'W10782', 'Nesinusoidinės srovės koeficientas yra normos ribose', 3),
	(562, 'W10783', 'Nesinusoidinės įtampos koeficientas yra normos ribose', 3),
	(563, 'W10784', 'Fazinių įtampų atitikties koeficientas normos ribose', 3),
	(564, 'W10785', 'Fazinių srovių atitikties koeficientas normos ribose', 3),
	(565, 'W10786', 'Bendras įtampos iškraipymų koeficientas normos ribose', 3),
	(566, 'W10787', 'Ryšio su apklausos tašku dingimas', 3),
	(567, 'W10789', 'Automatinės apklausos pradžia', 3),
	(568, 'W10791', 'Ryšio su žemesnio lygio koncentratoriumi dingimas', 3),
	(569, 'W10798', 'Surinkimo sustabdymas dėl parametravimo klaidos', 3),
	(570, 'Binary/XML', 'DataSet duomenų perdavimo formatas', 1),
	(573, 'TypeCode137', 'Tipo kodas (137)', 0),
	(578, '1/2', '1/2', 1),
	(579, '1/2/3', '1/2/3', 1),
	(580, 'V_Protocol', 'V_Protocol', 1),
	(581, 'P_Protocol', 'P_Protocol', 1),
	(582, 'W10799', 'Srovės ir įtampos priešingoji fazė', 3),
	(583, 'W10800', 'Srovės perkrova', 3),
	(584, 'W10801', 'Įtampos perkrova', 3),
	(586, 'Proxy', 'Prisijungimo parametrai', 1),
	(588, 'Priority', 'Prioritetas', 1),
	(589, 'W10744', 'Srovės perkrovos visose fazėse', 3),
	(590, 'W10745', 'Srovės perkrovos 1 fazėje', 3),
	(591, 'W10746', 'Srovės perkrovos 2 fazėje', 3),
	(592, 'W10747', 'Srovės perkrovos 3 fazėje', 3),
	(593, 'W10749', 'Elektroninės plombos suveikimas', 3),
	(594, 'W-50182', 'Relinio išvado funkcija', 3),
	(595, 'W-50187', 'Galios rūšis', 3),
	(596, 'W10837', 'Relės įjungimas pagal limitus', 3),
	(597, 'W10841', 'Apkrovos valdymas', 3),
	(598, 'W10842', 'Tarifų tvarkaraščių įrašymo užduočių būsenos', 3),
	(599, 'W10843', 'Pajungtų prietaisų informacija', 3),
	(600, 'W10844', 'Apsikeitimo su skaitikliu rezultatas', 3),
	(601, 'W10849', 'Srovės perkrova neutralėje', 3),
	(602, 'W10845', 'RAM testavimo rezultatai', 3),
	(603, 'W10846', 'Atminties testavimo rezultatai', 3),
	(604, 'W10847', 'CAN sąsajos klaida', 3),
	(605, 'W10848', 'Nenumatyta situacija', 3),
	(606, 'W10854', 'Relės valdymas', 3),
	(607, 'W10875', 'Limitų įrašymas į skaitiklius', 3),
	(608, 'W10876', 'Slaptažodžių įrašymas į skaitiklius', 3),
	(609, 'W10889', 'Duomenų surinkimas pagal užklausą', 3),
	(610, 'W-50208', 'Laiko korekcijos komandų sąsaja-šaltinis', 3),
	(611, 'W-50216', 'Pasijungimo tipas', 3),
	(612, 'W-50218', 'Apsikeitimo protokolas', 3),
	(613, 'W-50220', 'Pariteto kontrolė', 3),
	(614, 'W-50223', 'Tiesioginė prieiga prie sąsajos', 3),
	(615, 'W-50231', 'IDC darbo režimas', 3),
	(616, 'W-50232', 'Registavimas IDC būsenų pasikeitimų žurnale', 3),
	(617, 'W-50242', 'Skait. skaitiklio tipas', 3),
	(618, 'W-50245', 'Sujungimo tipas', 3),
	(619, 'W-50250', 'Slaptažodžio tipas', 3),
	(620, 'W-50268', 'Telesignalizacijos jungimo tipas', 3),
	(621, 'W-50270', 'Telesignalizacijos numerio rinkimo režimas', 3),
	(622, 'W-50273', 'Signalizacijos kanalo tipas', 3),
	(623, 'W-50277', 'Duomenų saugojimo ir perdavimo formatas', 3),
	(624, 'W-50284', 'Ryšio kanalo pajungimo tipas', 3),
	(625, 'W-50286', 'Pajungtų prietaisų tinklo skenavimo periodas', 3),
	(626, 'W-50295', 'Vartotojo tipas', 3),
	(627, 'W-50296', 'Apskaitos kanalų duomenų šaltinio tipas', 3),
	(628, 'W-50298', 'Matavimo dydžio kodas', 3),
	(629, 'W-50305', 'Profilio dydžio tipas', 3),
	(630, 'W-50308', 'Duomenų apskaitos gairė', 3),
	(631, 'W-50309', 'Užduoties tipas', 3),
	(632, 'Protocol_ZE311', 'Protokolas ZE311', 1),
	(633, 'BaudRate2_ZE311', 'BaudRate2 ZE311', 1),
	(634, 'ConnectVia_ZE311', 'ConnectVia ZE311', 1),
	(635, 'TypeCodeRiM099', 'Tipo kodas RiM099 ', 1),
	(636, 'CosemDataType', 'Įrašomų duomenų tipas', 1),
	(637, 'TypeCodeHXE', 'Tipo kodas HXE12/34', 1),
	(638, 'W10934', '12 V įtampa', 3),
	(639, 'W10935', 'Įtampos dingimo viršutinė riba fazėje A', 3),
	(640, 'W10936', 'Įtampos dingimo viršutinė riba fazėje B', 3),
	(641, 'W10937', 'Įtampos dingimo viršutinė riba fazėje C', 3),
	(642, 'W10938', 'tg(fi) viršutinė riba fazėje ?', 3),
	(643, 'W10939', 'tg(fi) viršutinė riba fazėje B', 3),
	(644, 'W10940', 'tg(fi) viršutinė riba fazėje C', 3),
	(645, 'ConnectVia_PafalEa', 'ConnectVia PafalEa', 1),
	(646, 'W10284', 'Atvirkštinės krypties tėkmė', 3),
	(647, 'W10553', 'Skaitiklio kleminio dangčio atidarymas', 3),
	(648, 'W-50201', 'Tarifų tvarkaraščio įrašymo į skaitiklius prioritetas', 3),
	(649, 'REALTIME_DATA_STORAGE_MODE', 'Realaus laiko matavimų saugojimo režimas', 8),
	(650, 'W10946', 'Nuotolinio galios daviklio 5 statusas', 3),
	(651, 'W10947', 'Nuotolinio galios daviklio suvartojimas', 3),
	(652, 'DATADATE_BEGIN_END', 'Duomenų datos atvaizdavimas išeities dokumente', 2),
	(653, 'W10951', 'Relės nr.3 jungimas', 3),
	(654, 'W10950', 'Tiesioginės prieigos teikimas', 3),
	(655, 'Interface_USPD_164_01', 'Interfeiso tipas, nurodomas šaltiniui', 1),
	(656, 'W10893', 'Kreditas pasiekė 0', 3),
	(657, 'W10894', 'Aptiktas galios disbalansas (3 fazėse)', 3),
	(658, 'W10895', 'Aptiktas įtampos disbalansas', 3),
	(659, 'W10896', 'Aptiktas temperatūros viršijimas', 3),
	(660, 'W10897', 'Aptiktas temperatūros sumažėjimas', 3),
	(661, 'W10898', 'Aptiktas aktyvios galios viršijimas', 3),
	(662, 'W10899', 'Fazėje A aptiktas aktyvios galios viršijimas', 3),
	(663, 'W10900', 'Fazėje B aptiktas aktyvios galios viršijimas', 3),
	(664, 'W10901', 'Fazėje C aptiktas aktyvios galios viršijimas', 3),
	(665, 'W10902', 'Aptiktas reaktyvios galios viršijimas', 3),
	(666, 'W10903', 'Fazėje A aptiktas reaktyvios galios viršijimas', 3),
	(667, 'W10904', 'Fazėje B aptiktas reaktyvios galios viršijimas', 3),
	(668, 'W10905', 'Fazėje C aptiktas aktyreaktyviosvios galios viršijimas', 3),
	(669, 'W10906', 'Aptiktas galios koeficiento (imp) sumažėjimas', 3),
	(670, 'W10907', 'Fazėje A aptiktas galios koeficiento (imp) sumažėjimas', 3),
	(671, 'W10908', 'Fazėje B aptiktas galios koeficiento (imp) sumažėjimas', 3),
	(672, 'W10909', 'Fazėje C aptiktas galios koeficiento (imp) sumažėjimas', 3),
	(673, 'W10910', 'STS režimas įjungtas', 3),
	(674, 'W10911', 'Aptiktas AB kampo reikšmės viršijimas', 3),
	(675, 'W10912', 'Aptiktas AB kampo reikšmės sumažejimas', 3),
	(676, 'W10913', 'Aptiktas AC kampo reikšmės viršijimas', 3),
	(677, 'W10914', 'Aptiktas AC kampo reikšmės sumažejimas', 3),
	(678, 'W10915', 'Aptiktas galios koeficiento (exp) sumažėjimas', 3),
	(679, 'W10916', 'Fazėje A aptiktas galios koeficiento (exp) sumažėjimas', 3),
	(680, 'W10917', 'Fazėje B aptiktas galios koeficiento (exp) sumažėjimas', 3),
	(681, 'W10918', 'Fazėje C aptiktas galios koeficiento (exp) sumažėjimas', 3),
	(682, 'W10919', 'LV modemas nerastas', 3),
	(683, 'W10920', 'LV ryšys nerastas', 3),
	(684, 'W10921', 'GPRS modemas nerastas', 3),
	(685, 'W10922', 'GPRS ryšys nerastas', 3),
	(686, 'TypeCode_CE102', 'Tipo kodas CE 102', 1),
	(689, 'CheckMeterNr', 'Skaitiklių numerių tikrinimas', 1),
	(690, 'StopKadr', 'Stop kadrai', 1),
	(691, 'W10971', 'Savaitgalių tarifikavimo įjungimas', 3),
	(692, 'W10972', 'Automatinio vasaros/žiemos laiko pervedimo įjungimas', 3),
	(693, 'W10973', 'Relės suveikimo įjungimas viršijant energijos ribą', 3),
	(694, 'W10974', 'Relės suveikimo įjungimas viršijant galios ribą', 3),
	(695, 'W10975', 'Relės suveikimo įjungimas viršijant suminės energijos ribą', 3),
	(696, 'W10976', 'Sąsajos užblokavimo įjungimas įvedant 3 neteisingus slaptažodžius', 3),
	(697, 'W-50381', 'ConnectionScheme', 3),
	(698, 'W-50198', 'Laiko juostos kodas', 0),
	(699, 'DeviceTypeMercury230', 'Prietaiso tipas Mercury 230', 1),
	(700, 'W-50401', 'Indikacijos režimas', 3),
	(701, 'LATEST_SUCCESSFUL_READINGS_INFO_USAGE', 'Informacijos apie paskutinius sėkmingus nuskaitymus panaudojimas vykdant įprastinį tiesioginį nuskaitymą', 8),
	(704, 'W-50440', 'Sąrašo atrankinis skaitymas vartotojo su slaptažodžiu', 0),
	(705, 'W-50441', 'Bendro skaitymo pagal sąrašą išvestis', 0),
	(706, 'W-50442', 'Sekančių to paties pavadinimo parametrų be pavadinimo išvestis', 0),
	(707, 'W-50444', 'Rodyti apkrovos profilių papildomą informaciją', 0),
	(708, 'W-50445', 'Sąsajos atsakymo laikas ne mažiau 20 ms', 0),
	(709, 'W-50446', 'Parametrų automatinės peržiūros per LCD draudimas', 0),
	(710, 'W-50447', 'Programavimas leidžiamas be mygtuko «DSTP» paspausdimo', 3),
	(711, 'W-50448', 'Sukauptų dienos ir mėnesio energijų išvestis per LCD', 0),
	(712, 'W-50449', 'Perjungti į pradinį kadrą', 0),
	(713, 'W-50450', 'Energijos parametrų numetimo draudimas', 0),
	(714, 'W-50451', 'Parametrų pagal sąrašą peržiūra rankiniu režimu per LCD', 0),
	(715, 'W-50452', 'Sąsajos atsakymo laikas lygus sąsajos aktyvios veiklos reakcijos laikui', 0),
	(716, 'SystemVzletTCP024M', 'Matavimo sistema skaitiklyje Vzlet TCP 024M', 1),
	(717, 'ChannelVzletTCP024M', 'Kanalo numeris Vzlet TCP 024M', 1),
	(718, 'Kind', 'Archyvo tipas', 1),
	(719, 'Interface_ADD_SNMP', 'Interfeiso indeksas ADD SNMP', 1),
	(720, 'Phase_ADD_SNMP', 'Fazės numeris ADD SNMP', 1),
	(724, 'ChannelVzljot_TSRV_034', 'Kanalo numeris Vzljot TSRV-034', 1),
	(725, 'W11014', '1 vamzdyno temperatūros maksimumas', 0),
	(726, 'W11015', '2 vamzdyno temperatūros maksimumas', 0),
	(727, 'W11016', '3 vamzdyno temperatūros maksimumas', 0),
	(728, 'W11017', '4 vamzdyno temperatūros maksimumas', 0),
	(729, 'W11018', '1 vamzdyno temperatūros minimali riba', 0),
	(730, 'W11019', '2 vamzdyno temperatūros minimali riba', 0),
	(731, 'W11020', '3 vamzdyno temperatūros minimali riba', 0),
	(732, 'W11021', '4 vamzdyno temperatūros minimali riba', 0),
	(733, 'W11022', '1 vamzdyno sunaudojimas', 0),
	(734, 'W11023', '2 vamzdyno sunaudojimas', 0),
	(735, 'W11024', '3 vamzdyno sunaudojimas', 0),
	(736, 'W11025', '4 vamzdyno sunaudojimas', 0),
	(737, 'W11026', 'Kanalo reikšmės maksimumas', 0),
	(738, 'W11027', 'Kanalo reikšmės minimali riba', 0),
	(739, 'System_Vzljet_020', 'Matavimo sistema skaitiklyje TSRV-020(021)', 1),
	(740, 'Channel_Vzljet_020', 'Kanalo numeris TSRV-020(021)', 1),
	(741, 'System_Vzljet_010', 'Matavimo sistema skaitiklyje TSRV-010', 1),
	(742, 'Channel_Vzljet_010', 'Kanalo numeris TSRV-010', 1),
	(744, 'DeviceVersionAX_XMK_NX', 'AX_XMK_NX prietaiso versija', 1),
	(745, 'W11036', 'Avarinė situacija: t4 > t4max', 3),
	(746, 'W11037', 'Avarinė situacija: t4 < t4min', 3),
	(747, 'W11040', 'Avarinė situacija:Gv2 > 1.04*Gv2', 3),
	(748, 'W11041', 'Avarinė situacija: tx > tx max', 3),
	(749, 'W11042', 'Avarinė situacija: tx < tx max', 3),
	(750, 'W11043', 'Avarinė situacija: t2 > t2max', 3),
	(751, 'W11044', 'Avarinė situacija: t2 < t2min', 3),
	(752, 'W11045', 'Avarinė situacija: t1 > t1max', 3),
	(753, 'W11046', 'Avarinė situacija: t1 < t1min', 3),
	(754, 'W11047', 'Avarinė situacija: t1 - t2 > delta_tmax', 3),
	(755, 'W_gt_0', 'Avarinė situacija: W < 0', 3),
	(756, 'W11049', 'Avarinė situacija: P1 > P1max', 3),
	(757, 'W11050', 'Avarinė situacija: P1 < P1min', 3),
	(758, 'W11051', 'Avarinė situacija: P2 > P2max', 3),
	(759, 'W11052', 'Avarinė situacija: P2 < P2min', 3),
	(760, 'W11053', 'Klaidų kiekis per parą > maksimumą', 3),
	(761, 'W11054', 'Apsikeitimo su PPC klaida', 3),
	(762, 'W11055', 'PPC termometrų gedimas grandyje', 3),
	(763, 'W11056', 'KM-5 termometrų gedimas grandyje', 3),
	(764, 'W11057', 'KM-5 tuščio vamzdžio daviklio galutinis požymis', 3),
	(765, 'W11058', 'PPC tuščio vamzdžio daviklio galutinis požymis', 3),
	(766, 'TypeCodeKM5', 'KM5 Tipo kodas', 1),
	(767, 'W11063', 'Vidinis įspėjimas', 3),
	(768, 'W11073', 'GPS sujungimas', 3),
	(769, 'ProtocolTekon19', 'Ryšio protokolo tipas', 1),
	(770, 'ChannelEsmon', 'Esmon kanalas', 1),
	(774, 'W10018', 'Vietinis parametravimas', 3),
	(775, 'W11089', 'Naujo skaitiklio registracija', 3),
	(779, 'W-50504', 'Įjungta/išjungta funkcija LED išjungimo mygtuko paspaudimu', 3),
	(780, 'W-50505', 'Apskaitos periodo uždarymas', 3),
	(781, 'SOURCE_RP', 'Duomenys iš ataskaitos', 1),
	(784, 'ACTION_61968', 'Importo procedūros duomenų įrašymo variantai', 2),
	(785, 'FORCE_PERIOD', 'Priverstinis analizės gylis', 2),
	(786, 'Manufacturer_Integral_V_MaXX', 'Manufacturer Integral_V_MaXX', 1),
	(787, 'Online', 'Duomenų nuskaitymo režimas', 1),
	(788, 'user/operator', 'Vartotojo vardas', 1),
	(789, 'ConnectViaKm', 'Prietaiso tipas, per kurį yra rišamasi prie skaitiklio', 1),
	(790, 'Port_KSPD_5', 'KSPD portas', 1),
	(791, 'BaudRate_KSPD_5', 'KSPD ryšio greitis', 1),
	(792, 'W10014', 'Prietaiso korpuso atidarymas', 3),
	(793, 'W10431', 'Patikros režimas', 3),
	(794, 'W10518', 'Netinkamas laikas', 3),
	(795, 'W10554', 'Elektros srovės dingimas', 3),
	(796, 'W10562', 'Elektros įtampos dingimas', 3),
	(797, 'Manufacturer_Cyble', 'Manufacturer CYBLE', 1),
	(798, 'W_LIMITS', 'Ribų peržengimas', 3),
	(799, 'W_ON_OFF', 'Įjungimas/Išjungimas', 3),
	(800, 'N#0_512', 'Numeriai nuo 0 iki 512', 1),
	(801, 'N#1_64', 'Numeriai nuo 1 iki 64', 1),
	(802, 'N#1_32', 'Numeriai nuo 1 iki 32', 1),
	(803, 'W11321', 'Relės valdymo sutrikimas, einamoji būsena neatitinka išsaugotosios', 3),
	(804, 'W11322', 'Užregistruotas el. energijos grobstymas arba atvirkštinė energijos kryptis', 3),
	(805, 'N#1_512', 'Numeriai nuo 1 iki 512', 1),
	(806, 'ProfileNr1/2', 'Profilio numeris 1/2', 1),
	(807, 'ProfileNr_A1800', 'Profilio numeris A1800', 1),
	(808, 'Protocol_CVMk2', 'Protokolų rinkinys CVMk2', 1),
	(809, 'DataType_CVMk2', 'Registro tipas CVMk2', 1),
	(810, 'N#1_31', 'Numeriai nuo 1 iki 31', 1),
	(811, 'AUTO_ADD_NEW_LINES_FOR_GENERATION', 'Automatiškai įtraukti naujus generuojamus matavimus', 1),
	(812, 'W-50668', 'Reaktyvinės energijos matavimo tikslumo klasė', 3),
	(813, 'W-50669', 'Srovės kodas - reikšmės', 3),
	(814, 'W-50670', 'Įtampos kodas  - reikšmės', 3),
	(815, 'Level', 'Prieigos lygis', 1),
	(816, 'TypeCodeDalaOrman', 'Orman/Dala prietaiso tipas', 1),
	(817, 'Config', 'Duomenų kategorija:', 1),
	(818, 'MAJOR_ISSUE', 'Esminė problema', 6),
	(819, 'W10283', 'užblokuotas/neužblokuotas', 3),
	(820, 'PLCTimeRWMethod', 'Prietaiso laiko nuskaitymo metodas', 1),
	(821, 'W-50691', 'Prietaiso laiko nuskaitymo metodas', 1),
	(822, 'W11384', 'FQ signalo dažnis', 3),
	(823, 'WaterInSensor_Q', 'Vanduo Q daviklyje', 3),
	(824, 'W11386', 'Q daviklio stovis', 3),
	(825, 'W11387', 'Suvartojimas', 3),
	(826, 'W11388', 'Q signalo busena', 3),
	(827, 'W11389', 'Suvartojimo pulsacija', 3),
	(828, 'W11390', 'Dujų apskaita esant blogam signalui', 3),
	(829, 'W10280', 'Bendros avarinės signalizacijos', 3),
	(830, 'W10281', 'Nuotėkis šiuo metu', 3),
	(831, 'W10282', 'Nuotėkis praeityje', 3),
	(832, 'W10285', 'Pastovus perpildymas', 3),
	(833, 'W10286', 'Perteklinis srautas', 3),
	(834, 'W10287', 'Magnetinio lauko poveikis šiuo metu', 3),
	(835, 'W10288', 'Magnetinio lauko poveikis praeityje', 3),
	(836, 'W10289', 'Mechaninis poveikis šiuo metu', 3),
	(837, 'W10290', 'Mechaninis poveikis praeityje', 3),
	(838, 'W10601', 'Laikrodžio sekundė', 3),
	(839, 'W10688', 'Skaitiklio pajungimo schema', 3),
	(840, 'W11391', 'Darbinio suvartojimo ribos', 3),
	(841, 'W11392', 'Korekcijos koeficiento išskaičiavimas', 3),
	(842, 'W11393', 'Aliarmo temperatūrai ribos', 3),
	(843, 'W11394', 'Aliarmo slėgiui ribos', 3),
	(844, 'W11395', 'Dujų suspaudimo koeficiento išskaičiavimas', 3),
	(845, 'W11396', 'Realių dujų koeficiento išskaičiavimas', 3),
	(846, 'W11397', 'Klaida 1 įėjime', 3),
	(847, 'W11398', 'Klaida 2 įėjime', 3),
	(848, 'W11399', 'Klaida 1 išėjime', 3),
	(849, 'W11400', 'Klaida 2 išėjime', 3),
	(850, 'W11401', 'Klaida 3 išėjime', 3),
	(851, 'W11402', 'Klaida 4 išėjime', 3),
	(852, 'W11403', 'Perspėjimo riba pagal W', 3),
	(853, 'W11404', 'Standartinio kiekio suvartojimo ribos', 3),
	(854, 'W11405', 'Darbinio kiekio suvartojimo ribos', 3),
	(855, 'W11406', 'Temperatūros perspėjimo ribos', 3),
	(856, 'W11407', 'Slėgio perspėjimo ribos', 3),
	(857, 'W11408', 'Programinės įrangos klaida', 3),
	(858, 'W11409', 'Dujų suvartojimas per parą viršijo limitą', 3),
	(859, 'W11410', 'Nustatymų klaida', 3),
	(860, 'W11411', 'Nustatyta dujų suvartojimo riba per mėnesį', 3),
	(861, 'W11412', 'Perspėjimo signalas Įėjime 3', 3),
	(862, 'W11413', 'Maitinimo elementų likutinio veikimo laiko žemutinės riba', 3),
	(863, 'W11414', 'Remonto rėžimas', 3),
	(864, 'W11415', 'Ataskaitos signalas Įėjime 2', 3),
	(865, 'W11416', 'Ataskaitos signalas Įėjime 3', 3),
	(866, 'W11417', 'Kalibravimo spyna', 3),
	(867, 'W11418', 'Tiekėjo spyna', 3),
	(868, 'W11419', 'Vartotojo spyna', 3),
	(869, 'W11420', 'Duomenų  užklausimo patvirtinimo 1 laikinis intervalas', 3),
	(870, 'W11421', 'Duomenų  užklausimo patvirtinimo 2 laikinis intervalas', 3),
	(871, 'W11422', 'Duomenų  užklausimo patvirtinimo 3 laikinis intervalas', 3),
	(872, 'W11423', 'Duomenų  užklausimo patvirtinimo 4 laikinis intervalas', 3),
	(873, 'OptimizationByDT', 'Optimizavimas pagal laiką', 1),
	(874, 'DeviceAlarm_GUID', 'Prietaiso siunčiamus aliarmus', 1),
	(875, 'W11242', 'Pradžia/Pabaiga', 3),
	(876, 'RetDevTime_Orman', 'Prietaiso laiko grąžinimas iš Saiman Orman', 1),
	(877, 'ModbusValsenaTemperature', 'ModbusValsenaTemperature', 1),
	(879, 'PROFILE_PERIOD_1517', 'Duomenų profilio periodas, min', 2),
	(880, 'ATS_PRECISION', 'Reikšmių formavimo variantas', 2),
	(881, 'ATS_SEPARATOR', 'Trupmenų skyrybos ženklas', 2),
	(882, 'N#0_255', 'Numeriai nuo 0 iki 255', 1),
	(883, 'W-50695', 'Slėgio matavimo vienetai', 3),
	(884, 'W-50696', 'Energijos matavimo vienetai', 3),
	(885, 'W-50697', 'Galios matavimo vienetai', 3),
	(886, 'Manufacturer_SKU_03', 'Manufacturer SKU_03', 1),
	(887, 'UniversalModbus', 'UniversalModbus', 1),
	(888, 'N#1_255', 'Numeriai nuo 1 iki 255', 1),
	(889, 'N#1_2', 'Numeriai nuo 1 iki 2', 1),
	(890, 'N#1_3', 'Numeriai nuo 1 iki 3', 1),
	(891, 'KANS_PRECISION', 'Reikšmių formavimo variantas', 2),
	(892, 'AddressingType', 'Loginių Modbus adresų naudojimas', 1),
	(894, 'SecurityLevel', 'SecurityLevel', 1),
	(895, 'ASCII/binary', 'ASCII/binary', 2),
	(899, 'TypeCodeCorax', 'Corax prietaiso tipas', 1),
	(900, 'TotalActivePowerError', 'Suminė aktyvinė energija', 3),
	(901, 'PLCCommunication', 'Ryšio per optinį portą', 3),
	(902, 'OFDMCommFail', 'Susijungimas su OFDM modemu', 3),
	(903, 'ProfileNr342', 'Profilio numeris 342', 1),
	(904, 'PasswordErrKeyBoard', 'Slaptažodžio įvedimas klaviatūros pagalba', 3),
	(905, 'FlashDiskOverload', 'Flash diske vietos', 3),
	(906, 'TSPowerOn', 'Vidinių MP-4 maitinimas', 3),
	(907, 'W-50844', 'Šilumos tiekimo schema', 3),
	(908, 'W-50845', 'Magistralės tipas', 3),
	(909, 'TerminalCase_Open', 'Skaitiklio dangtelis ', 3),
	(910, 'UnbalancedByCurrent', 'Nebalanso pagal srovę ', 3),
	(911, 'Violation', 'Pažeidimo', 3),
	(912, 'LocalConnectionBegin', 'Lokalaus sujungimo', 3),
	(913, 'RemoutConnectionBegin', 'Nuotolinio sujungimo', 3),
	(914, 'COM_InsertedBad', 'COM modulis įstatytas', 3),
	(915, 'IO_InsertedBad', 'IO modulis įstatytas', 3),
	(916, 'PrepayTokenEnterOk', 'Išankstinio apmokėjimo simbolis įvestas', 3),
	(917, 'PrepayCreditExpired', 'Išankstinis apmokėjimas', 3),
	(918, 'Prepay_EM_CreditExpired', 'Išankstinis EM apmokėjimas', 3),
	(919, 'UserConnect', 'Vartotojas', 3),
	(924, 'W-50722', 'Bazinio skaitiklio tipas', 3),
	(925, 'W-50764', 'Galios numetimas autonuskaitant', 3),
	(926, 'W-50765', 'Sumuojančių registrų masyvas.', 3),
	(927, 'W-50791', 'Vykdoma funkcija (nepasikartojančios datos)', 3),
	(928, 'W-50794', 'Pasikartojančių datų tipas', 3),
	(929, 'W-50854', 'Nuoseklaus porto nuskaitymo būdas', 1),
	(930, 'W-50863', 'RTC sinchronizacija', 1),
	(931, 'W-50877', 'Aktyvinė srovinė kilpa', 1),
	(932, 'W-50878', 'Pasyvinė srovinė kilpa', 1),
	(933, 'ConnectViaZE114', 'ZE114 Prietaiso tipas', 1),
	(934, 'Device_type_S_or_C', 'Prietaiso tipas (kontroleris ar skaitiklis)', 1),
	(935, 'W11293E', 'Relės nr.4 jungimas', 3),
	(936, 'W11294E', 'Relės nr.5 jungimas', 3),
	(937, 'W11297E', 'Apkrova viršijus įtampą', 3),
	(938, 'W11298E', 'Apkrova viršijus vartojimą', 3),
	(939, 'W11301E', 'Operatorius apkrovą', 3),
	(940, 'W11306E', 'Keičiamo modulio skyrius', 3),
	(941, 'W11308E', 'Viršutinis įtampos slenkstis Nr.1', 3),
	(942, 'W11309E', 'Viršutinis įtampos slenkstis Nr.2', 3),
	(943, 'W11310E', 'Apatinis įtampos slenkstis Nr.1', 3),
	(944, 'W11311E', 'Apatinis įtampos slenkstis Nr.2', 3),
	(945, 'W11319E', 'Vartotojo balanso kritinė reikšmė', 3),
	(946, 'N#0_3', 'Numeriai nuo 0 iki 3', 1),
	(947, 'W-50079', 'Sezoninis laiko pervedimas', 1),
	(948, 'W11552', 'Prieiga prie skaitiklio viršijus blogų slaptažodžių limitą', 1),
	(949, 'Function', 'Nuskaitymo funkcija', 1),
	(950, 'W-50879', 'Skaitiklis 100A', 3),
	(951, 'W-50880', 'UART1 modulio tipas', 3),
	(952, 'W-50883', 'Skaitiklis su gatvės apšvietimu', 3),
	(953, 'W-50894', 'Relės valdymo paros grafikas - įjungtas', 3),
	(954, 'W-50900', 'Veikimo aprašymas pasiekus kritinį pinigų kiekį vartotojo balanse', 3),
	(955, 'W-50909', '"Pagal galią" atjungimo variantas', 3),
	(956, 'W-50910', '"Pagal galią" įjungimo variantas', 3),
	(957, 'DType', 'Duomenų gražinimo režimas:', 1),
	(958, 'W11337', 'Laikrodžio baterija', 1),
	(959, 'W11342', 'Atjungus relę', 1),
	(960, 'W11343', 'Atjungus relę fazėje A', 1),
	(961, 'W11344', 'Atjungus relę fazėje B', 1),
	(962, 'W11345', 'Atjungus relę fazėje C', 1),
	(963, 'W11350', 'Pagal temperatūrą relė fazėje A', 1),
	(964, 'W11351', 'Pagal temperatūrą relė fazėje B', 1),
	(965, 'W11352', 'Pagal temperatūrą relė fazėje C', 1),
	(966, 'W-50913', 'UART4 modulio tipas', 1),
	(967, 'UseGroupAddress_MIT_5000_MG', 'UseGroupAddress_MIT_5000_MG', 1),
	(968, 'Port_MIT_5000_MG', 'Port_MIT_5000_MG', 1),
	(969, 'BaudRate_MIT_5000_MG', 'BaudRate_MIT_5000_MG', 1),
	(970, 'StopBits_MIT_5000_MG', 'StopBits_MIT_5000_MG', 1),
	(971, 'HasCalibration_MIT_5000_MG', 'HasCalibration_MIT_5000_MG', 1),
	(972, 'EvenOrOddCalibration_MIT_5000_MG', 'EvenOrOddCalibration_MIT_5000_MG', 1),
	(973, 'DataBits_MIT_5000_MG', 'DataBits_MIT_5000_MG', 1),
	(974, 'ConnectVia_MIT_5000_MG', 'ConnectVia_MIT_5000_MG', 1),
	(975, 'ProfileNr_MIT_5000_MG', 'ProfileNr_MIT_5000_MG', 1),
	(976, 'STVzljotTSRV_TypeCode', 'Prietaiso tipas VZLJET TSRV', 1),
	(977, 'LogoScreenAddressingType', 'Registrų adresacijos tipas', 1),
	(978, 'LogoScreenDataType', 'Registro tipas LogoScreen', 1),
	(979, 'User_Mir_S', 'User Mir_S', 1),
	(982, 'N#1_24', 'Numeriai nuo 1 iki 24', 1),
	(983, 'N#1_6', 'Numeriai nuo 1 iki 6', 1),
	(987, 'Terminal_MIT_5000_MG', 'Ryšiui per skaitiklį ar terminalą', 1),
	(988, 'W11561', 'Maitinimo', 3),
	(989, 'W11562', 'MK taktavimo', 3),
	(990, 'W11563', 'Atminties"1" mikroschemos', 3),
	(991, 'W11564', 'Atminties"2" mikroschemos', 3),
	(992, 'W11565', 'Programos kontrolinės sumos', 3),
	(993, 'W11566', 'Radijo daviklio suveikimas', 3),
	(994, 'W11567', 'Avarinis tarifas', 3),
	(995, 'W11568', 'Energijos registrai ', 3),
	(996, 'W11569', 'Metrologinė kalibruotė', 3),
	(997, 'W11570', 'Parametravimas', 3),
	(998, 'W11573', 'Indikacija "Radijo"', 3),
	(999, 'W11574', 'Indikacija "Magn"', 3),
	(1000, 'W11575', 'Indikacija "Borg"', 3),
	(1001, 'W11576', 'Įtampa žemiau normos fazėje L1', 3),
	(1002, 'W11577', 'Įtampa žemiau normos fazėje L2', 3),
	(1003, 'W11578', 'Įtampa žemiau normos fazėje L3', 3),
	(1004, 'W11579', 'Įtampa aukščiau normos fazėje L1', 3),
	(1005, 'W11580', 'Įtampa aukščiau normos fazėje L2', 3),
	(1006, 'W11581', 'Įtampa aukščiau normos fazėje L3', 3),
	(1007, 'W11582', 'Srovė viršija normą fazėje L1', 3),
	(1008, 'W11583', 'Srovė viršija normą fazėje L2', 3),
	(1009, 'W11584', 'Srovė viršija normą fazėje L3', 3),
	(1010, 'W11585', 'Optoportas, vartotojo autorizacija aktyvi', 3),
	(1011, 'W11586', 'Optoportas, operatoriaus autorizacija aktyvi', 3),
	(1012, 'W11587', 'Optoportas, vartotojo autorizacija užblokuota', 3),
	(1013, 'W11588', 'Optoportas, operatoriaus autorizacija užblokuota', 3),
	(1014, 'W11589', 'Interfeisas 1, vartotojo autorizacija aktyvi', 3),
	(1015, 'W11590', 'Interfeisas 1, operatoriaus autorizacija aktyvi', 3),
	(1016, 'W11591', 'Interfeisas 1, vartotojo autorizacija užblokuota', 3),
	(1017, 'W11592', 'Interfeisas 1, operatoriaus autorizacija užblokuota', 3),
	(1018, 'W11593', 'Interfeisas 2, vartotojo autorizacija aktyvi', 3),
	(1019, 'W11594', 'Interfeisas 2, operatoriaus autorizacija aktyvi', 3),
	(1020, 'W11595', 'Interfeisas 2, vartotojo autorizacija užblokuota', 3),
	(1021, 'W11596', 'Interfeisas 2, operatoriaus autorizacija užblokuota', 3),
	(1022, 'W11597', 'Interfeisas 3, vartotojo autorizacija aktyvi', 3),
	(1023, 'W11598', 'Interfeisas 3, operatoriaus autorizacija aktyvi', 3),
	(1024, 'W11599', 'Interfeisas 3, vartotojo autorizacija užblokuota', 3),
	(1025, 'W11600', 'Interfeisas 3, operatoriaus autorizacija užblokuota', 3),
	(1026, 'W11631', 'Poveikio radijo lauku', 3),
	(1027, 'W11571', 'Apkrovos valdymo relė', 3),
	(1028, 'W4011E', 'Krovimo būklė', 3),
	(1029, 'W4013E', 'Vartotojo sąsajos (Cl in) būklė', 3),
	(1030, 'W4014E', 'Skaitiklio sąsajos (Cl out) būklė', 3),
	(1031, 'W4015E', 'Maitinimo (AC) būklė', 3),
	(1032, 'N#1_9', 'Numeriai nuo 1 iki 9', 1),
	(1033, 'Unigas_300_Channel', 'Unigas-300 Kanalo numeris', 1),
	(1034, 'MacMAT_Protocol', 'MacMAT Protokolas', 1),
	(1035, 'MacMAT_Channel', 'MacMAT Kanalo numeris', 1),
	(1036, 'N#1_8', 'Numeriai nuo 1 iki 8', 1),
	(1037, 'W11635', 'Reikšmės Z ir Zb intervalą', 1),
	(1038, 'W11636', 'Parametras p1 limitus I p1 arba u p1', 1),
	(1039, 'W11637', 'Parametras p2 limitus I p2 arba u p2', 1),
	(1040, 'W11638', 'Parametras Qb limitus I Qb arba u Qb', 1),
	(1041, 'W11639', 'Parametras Qm limitus I Qm arba u Qm', 1),
	(1042, 'W11640', 'Parametras dVbh limitą Vbh 3 ', 1),
	(1043, 'W11641', 'Parametras dVbh limitą Vbh 2', 1),
	(1044, 'W11642', 'Parametras dVbh limitą Vbh 1', 1),
	(1045, 'W11643', 'Skirtumas Vm-V2 toleranciją', 1),
	(1046, 'W11644', 'Dažnis LF limitą 2,5 kHz', 1),
	(1047, 'W11645', 'Parametras p1 intervalą nuo p1 min iki p1 max', 1),
	(1048, 'W11646', 'Parametras p2 intervalą nuo p2 min iki p2 max', 1),
	(1049, 'W11647', 'Temperatūra intervalą nuo t min iki t max', 1),
	(1050, 'W11648', 'Parametras Qb intervalą nuo Qm min iki Qm max', 1),
	(1051, 'W11649', 'Santykis HF / LF toleranciją', 1),
	(1052, 'W11650', 'Įteisinimas', 1),
	(1053, 'W11651', 'Pakeistas Vm', 1),
	(1054, 'W11652', 'Registravimo periodas pakeistas', 1),
	(1055, 'W11653', 'Impulsinių įėjimų konfigūracija pakeista', 1),
	(1056, 'W11654', 'DP reišmė pakeista', 1),
	(1057, 'W11655', 'DP tekstas pakeistas', 1),
	(1058, 'W11656', 'Pakeistas dūjų parametras', 1),
	(1059, 'W11657', 'Duomenys prietaise ištrinti', 1),
	(1060, 'W11658', 'Pasikeitė iėjimo S1 būsena', 1),
	(1061, 'W11659', 'Pasikeitė iėjimo S2 būsena', 1),
	(1062, 'W11660', 'Pasikeitė iėjimo S3 būsena', 1),
	(1063, 'W11661', 'Saulės baterijos veikimo', 1),
	(1064, 'W11662', 'Baterijos atsijungimo', 1),
	(1065, 'W11663', 'Klaviatūros gedimų', 1),
	(1066, 'W11664', 'Indikatoriaus perpildymo', 1),
	(1067, 'W11665', 'Kontrolinis kontaktas ', 1),
	(1068, 'W11666', 'Prietaiso užrakinimas uždraustas', 1),
	(1069, 'W11667', 'Iėjimo R1 reikšmė išėjo už ribų', 1),
	(1070, 'W11668', 'Iėjimo R2 reikšmė išėjo už ribų', 1),
	(1071, 'W11669', 'Iėjimo R3 reikšmė išėjo už ribų', 1),
	(1072, 'W11670', 'Iėjimo R4 reikšmė išėjo už ribų', 1),
	(1073, 'W11671', 'Atsijungė R1', 1),
	(1074, 'W11672', 'Atsijungė R2', 1),
	(1075, 'W11673', 'Atsijungė R3', 1),
	(1076, 'W11674', 'Pasikeitė statusas B aliarmo grupėje', 1),
	(1077, 'W11675', 'Pasikeitė statusas A aliarmo grupėje', 1),
	(1078, 'W11676', 'Pasikeitė iėjimo S4 būsena', 1),
	(1079, 'W11677', 'Pasikeitė iėjimo S5 būsena', 1),
	(1080, 'W11678', 'Pasikeitė iėjimo S6 būsena', 1),
	(1081, 'W11679', 'Pasikeitė iėjimo S7 būsena', 1),
	(1082, 'W11680', 'Pasikeitė iėjimo S8 būsena', 1),
	(1083, 'W11681', 'Parametras dEh limitą l dEh 1', 1),
	(1084, 'W11682', 'Parametras dEh limitą l dEh 2', 1),
	(1085, 'W11683', 'Parametras dEh limitą l dEh 3', 1),
	(1086, 'W11684', 'Sistemos įvykis', 1),
	(1087, 'W11685', 'Parametras eph limitą l eph1', 1),
	(1088, 'W11686', 'Parametras eph limitą l eph2', 1),
	(1089, 'W11687', 'Signalizacijos atminies užimtumas viršija 90%. ', 1),
	(1090, 'W11688', 'Signalizacijos atminies užimtumas viršija 50%. ', 1),
	(1091, 'W11689', 'Aplinkos temperatūra intervalo ribas nuo tamb min iki tamb max', 1),
	(1092, 'W11690', 'Primtinas dp/p santykis', 1),
	(1093, 'W11691', 'Parametras dp diapazoną  3.95 ÷ 20.2 mA', 1),
	(1094, 'W11692', 'Signalizacija suveiks kai p viršys diapazoną  3.95 ÷ 20.2 mA', 1),
	(1095, 'W11693', 'Signalizacija suveiks kai t viršys diapazoną  3.95 ÷ 20.2 mA', 1),
	(1096, 'W11694', 'Signalizacija suveiks kai rez1  viršys diapazoną 3.95 ÷ 20.2 mA', 1),
	(1097, 'W11695', 'Signalizacija suveiks kai rez2 viršys diapazoną  3.95 ÷ 20.2 mA', 1),
	(1098, 'W11696', 'Slėgio skirtumo dp reikšmė limitą', 1),
	(1099, 'W11697', 'Parametras rez1 limitą', 1),
	(1100, 'W11698', 'Parametras rez2 limitą', 1),
	(1101, 'W11699', 'Reinoldso skaičius', 1),
	(1102, 'W11700', 'Keitiklių poros slėgio skirtumas  limitus e dpL arba e dpH', 1),
	(1103, 'W11701', 'Keitiklių poros slėgio skirtumas 5%', 1),
	(1104, 'W11702', 'Impulsų įėjimai HF2 ir HF3 impulsų skaičius toleranciją', 1),
	(1105, 'W11703', 'Kompiūteris išjungtas klaviatūros pagalba', 1),
	(1106, 'W11704', 'Algoritmas ar matavimo kanalų tikrinimo moda', 1),
	(1107, 'W11705', 'Maksimalus dažnis', 1),
	(1108, 'W11706', 'Pakaitinis dujų sudėties skaičiavimas', 1),
	(1109, 'W11707', 'Atliekamas baterijos testas', 1),
	(1110, 'W11708', 'Baterija kraunama iš srauto kompjūterio', 1),
	(1111, 'W11709', 'UPS išsikrovęs', 1),
	(1112, 'W11710', 'Lauko temperatūra priimtino įkrovimo diapazono', 1),
	(1113, 'W11711', 'Ryšys su baterijos  moduliu', 1),
	(1114, 'W11712', 'Baterijos patikra atlikta', 1),
	(1115, 'W11713', 'S6-1 signalo aktyvumo', 1),
	(1116, 'W11714', 'S6-2 signalo aktyvumo', 1),
	(1117, 'W11715', 'S6-3 signalo aktyvumo', 1),
	(1118, 'W11716', 'S6-4 signalo aktyvumo', 1),
	(1119, 'W11717', 'S6-5 signalo aktyvumo', 1),
	(1120, 'W11718', 'S6-6 signalo aktyvumo', 1),
	(1121, 'W11719', 'SN4-1 signalo aktyvumo', 1),
	(1122, 'W11720', 'SN4-2 signalo aktyvumo', 1),
	(1123, 'W11721', 'SN4-3 signalo aktyvumo', 1),
	(1124, 'W11722', 'SN4-4 signalo aktyvumo', 1),
	(1125, 'W11723', 'SN4-N signalo aktyvumo', 1),
	(1126, 'W11724', 'Signalų aktyvumo', 1),
	(1127, 'W11725', 'SN6-1 signalo aktyvumo', 1),
	(1128, 'W11726', 'SN6-2 signalo aktyvumo', 1),
	(1129, 'W11727', 'SN6-3 signalo aktyvumo', 1),
	(1130, 'W11728', 'SN6-4 signalo aktyvumo', 1),
	(1131, 'W11729', 'SN6-5 signalo aktyvumo', 1),
	(1132, 'W11730', 'SN6-6 signalo aktyvumo', 1),
	(1133, 'W11731', 'SO-1 signalo aktyvumo', 1),
	(1134, 'W11732', 'SO-2 signalo aktyvumo', 1),
	(1135, 'W11733', 'SO-3 signalo aktyvumo', 1),
	(1136, 'W11734', 'SO-4 signalo aktyvumo', 1),
	(1137, 'W11735', 'SO-5 signalo aktyvumo', 1),
	(1138, 'W11736', 'SO-6 signalo aktyvumo', 1),
	(1139, 'W11737', 'Ryšys su modulių nr 1', 1),
	(1140, 'W11738', 'Ryšys su modulių nr 2', 1),
	(1141, 'W11739', 'Ryšys su modulių nr 3', 1),
	(1142, 'W11740', 'Ryšys su modulių nr 4', 1),
	(1143, 'W11741', 'Ryšys su modulių nr 5', 1),
	(1144, 'W11742', 'Sumatoriaus reikšmė maksimalią reikšmę', 1),
	(1145, 'W11743', 'Korekcijos klaida', 1),
	(1146, 'W11744', 'Vidaus temperatūra pasiekė primtiną reikšmę', 1),
	(1147, 'W11745', 'Aliarmas 1 ', 1),
	(1148, 'W11746', 'Aliarmas 2', 1),
	(1149, 'W11747', 'Aliarmas 3', 1),
	(1150, 'W11748', 'Aliarmas 4 ', 1),
	(1151, 'W11749', 'Patrametras rez3 intervalą 3.95 ÷ 20.2 mA', 1),
	(1152, 'W11750', 'Parametras rez3 limitą', 1),
	(1153, 'W11751', 'Įtampa rezU1 intervalą  -1 ÷ 0 V arba -2 ÷ 0 V', 1),
	(1154, 'W11752', 'Parametras rezU1 limitą', 1),
	(1155, 'W11753', 'Parametras p1w limitą ', 1),
	(1156, 'W11754', 'Aliarmų patvirtinimas', 1),
	(1157, 'W11755', 'Dalybos iš nulio', 1),
	(1158, 'W11756', 'Ryšio tarp procesoriaus ir analoginės dalies', 1);
/*!40000 ALTER TABLE `enum` ENABLE KEYS */;

-- Dumping structure for table emcor.enum_data
CREATE TABLE IF NOT EXISTS `enum_data` (
  `enum_id` mediumint(8) unsigned NOT NULL COMMENT 'Išvardinimo identifikatorius',
  `enum_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Išvardinimo reikšmė',
  `enum_value_desc` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Išvardinimo reikšmės aprašymas',
  `enum_data_nr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo reikšmės eilės numeris rušiavimui',
  PRIMARY KEY (`enum_id`,`enum_value`),
  CONSTRAINT `enum_data_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Išvardinimų duomenys';

-- Dumping data for table emcor.enum_data: ~4 616 rows (approximately)
/*!40000 ALTER TABLE `enum_data` DISABLE KEYS */;
INSERT INTO `enum_data` (`enum_id`, `enum_value`, `enum_value_desc`, `enum_data_nr`) VALUES
	(1, 'CAN', 'CAN', NULL),
	(1, 'HTTP', NULL, NULL),
	(1, 'MBUS', NULL, NULL),
	(1, 'MBUSByNr', NULL, NULL),
	(1, 'MODBUS', NULL, NULL),
	(1, 'ModbusAscii', NULL, NULL),
	(1, 'OPTICAL', NULL, NULL),
	(1, 'SLIP', 'SLIP', NULL),
	(2, '1', NULL, NULL),
	(2, '1.5', NULL, NULL),
	(2, '2', NULL, NULL),
	(3, '5', NULL, NULL),
	(3, '6', NULL, NULL),
	(3, '7', NULL, NULL),
	(3, '8', NULL, NULL),
	(4, 'Even', NULL, NULL),
	(4, 'Mark', NULL, NULL),
	(4, 'None', NULL, NULL),
	(4, 'Odd', NULL, NULL),
	(4, 'Space', NULL, NULL),
	(5, 'None', 'None', NULL),
	(5, 'RTSCTS', NULL, NULL),
	(6, 'None', NULL, NULL),
	(6, 'XONXOFF', NULL, NULL),
	(7, 'Off', NULL, NULL),
	(7, 'On', NULL, NULL),
	(8, '1200', NULL, NULL),
	(8, '19200', NULL, NULL),
	(8, '2400', NULL, NULL),
	(8, '300', NULL, NULL),
	(8, '38400', NULL, NULL),
	(8, '4800', NULL, NULL),
	(8, '600', NULL, NULL),
	(8, '9600', NULL, NULL),
	(9, 'TCP', NULL, NULL),
	(9, 'UDP', NULL, NULL),
	(41, 'Off', NULL, NULL),
	(41, 'On', NULL, NULL),
	(61, '0', 'Garas', NULL),
	(61, '1', 'Kondensatas', NULL),
	(61, '10', 'Šaltis', NULL),
	(61, '11', 'Karštas vanduo', NULL),
	(61, '2', 'Vanduo', NULL),
	(61, '3', 'Elektra', NULL),
	(61, '4', 'Dujos', NULL),
	(61, '5', 'Pienas', NULL),
	(61, '6', 'Oras', NULL),
	(61, '7', 'Lauko temperatūra', NULL),
	(61, '8', 'Normos', NULL),
	(61, '9', 'Termofikacinis vanduo', NULL),
	(82, '0', 'Ne', NULL),
	(82, '1', 'Taip', NULL),
	(83, '220', NULL, NULL),
	(83, '230', NULL, NULL),
	(84, '0', 'DBB23000', NULL),
	(84, '1', 'OD4165', NULL),
	(84, '2', 'DAB13000', NULL),
	(84, '3', 'A43_A44', NULL),
	(88, '1', 'Eilutėmis', NULL),
	(88, '2', 'Stulpeliais', NULL),
	(88, '3', 'Lapais', NULL),
	(92, 'Blank', 'Tuščias', NULL),
	(92, 'Normal', 'Normalus', NULL),
	(96, '1', 'XML', NULL),
	(96, '2', 'Binarinis', NULL),
	(107, 'BY', 'Baltarusų', NULL),
	(107, 'EN', 'Anglų', NULL),
	(107, 'LT', 'Lietuvių', NULL),
	(107, 'RU', 'Rusų', NULL),
	(116, '0', 'Automatinis', NULL),
	(116, '1', 'Taškais', NULL),
	(116, '2', 'Puslapiais', NULL),
	(117, '11309', 'MultiCal', NULL),
	(117, '12901', 'Siemens WFC21,WFM21,AEW310', NULL),
	(117, '12967', 'Siemens_UH50', NULL),
	(117, '18604', 'PadPuls_M2C', NULL),
	(117, '19630', 'Sensus HRI', NULL),
	(117, '19875', 'Siemens Pulse adapter AEW21_2', NULL),
	(117, '4307', 'Sonometer_1000', NULL),
	(117, '65535', 'Neišvardintas', NULL),
	(121, 'MBUS', 'MBUS', NULL),
	(121, 'MBUSByNr', 'MBUSByNr', NULL),
	(121, 'OPTICAL', 'OPTICAL', NULL),
	(122, 'MODBUS', 'MODBUS', NULL),
	(122, 'ModbusAscii', 'ModbusAscii', NULL),
	(123, 'HTTP', 'HTTP', NULL),
	(123, 'MODBUS', 'MODBUS', NULL),
	(124, 'MBUS', 'MBUS', NULL),
	(124, 'MBUSByNr', 'MBUSByNr', NULL),
	(126, 'MBUS', 'MBUS', NULL),
	(136, '1', 'Paslėpti', NULL),
	(136, '2', 'Pašalinti', NULL),
	(136, '3', 'Palikti', NULL),
	(141, '1', 'Darbo dienos', NULL),
	(141, '2', 'Šventinės dienos', NULL),
	(146, '30', 'Maitinimo elementas išsikrovė', NULL),
	(146, '31', 'Maitinimo elementas pasikrovė', NULL),
	(147, '30', 'Dingo fatalinė klaida', NULL),
	(147, '31', 'Aptikta fatalinė klaida', NULL),
	(148, '30', 'Fazių seka nekorektiška', NULL),
	(148, '31', 'Fazių seka korektiška', NULL),
	(149, '30', 'Įtampos dingimas fazėje A', NULL),
	(149, '31', 'Įtampos atsiradimas fazėje A', NULL),
	(150, '30', 'Įtampos dingimas fazėje B', NULL),
	(150, '31', 'Įtampos atsiradimas fazėje B', NULL),
	(151, '30', 'Įtampos dingimas fazėje C', NULL),
	(151, '31', 'Įtampos atsiradimas fazėje C', NULL),
	(152, '30', 'Pagrindinio maitinimo pertraukos periodo pradžia', NULL),
	(152, '31', 'Pagrindinio maitinimo pertraukos periodo pabaiga', NULL),
	(153, '30', 'Skaitiklio neveikia magnetinis laukas', NULL),
	(153, '31', 'Skaitiklį veikia magnetinis laukas', NULL),
	(154, '30', 'Netinkamos temperatūros periodo pabaiga', NULL),
	(154, '31', 'Netinkamos temperatūros periodo pradžia', NULL),
	(155, '30', 'Ryšys neblokuotas', NULL),
	(155, '31', 'Ryšys blokuotas', NULL),
	(156, '30', 'Draudžiamas gamyklinis parametravimas', NULL),
	(156, '31', 'Leidžiamas gamyklinis parametravimas', NULL),
	(157, '30', 'Laikrodžio sutrikimo periodo pabaiga', NULL),
	(157, '31', 'Laikrodžio sutrikimas', NULL),
	(158, '30', 'Relė nr.1 išjungta', NULL),
	(158, '31', 'Relė nr.1 įjungta', NULL),
	(158, '32', 'nežinoma', NULL),
	(158, '33', 'Reles įjungimas galimas - laukiama vartotojo patvirtinimo', NULL),
	(159, '30', 'Relė nr.2 išjungta', NULL),
	(159, '31', 'Relė nr.2 įjungta', NULL),
	(159, '32', 'nežinoma', NULL),
	(160, '30', 'Perėjimas į žiemos laiką', NULL),
	(160, '31', 'Perėjimas į vasaros laiką', NULL),
	(161, '30', 'Perėjimas į pagrindinį maitinimą', NULL),
	(161, '31', 'Perėjimas į rezervinį maitinimą', NULL),
	(162, '30', 'Sesija uždaryta', NULL),
	(162, '31', 'Sesija atidaryta', NULL),
	(163, '30', 'Sujungimas nutrūko', NULL),
	(163, '31', 'Sujungimas nustatytas', NULL),
	(164, '30', 'Ryšys su moduliu dingo', NULL),
	(164, '31', 'Ryšys su moduliu atstatytas', NULL),
	(165, '30', 'Ryšys su modulių grupe dingo', NULL),
	(165, '31', 'Ryšys su modulių grupe atstatytas', NULL),
	(166, '30', 'Konfiguracijos klaida dingo', NULL),
	(166, '31', 'Konfiguracijos klaida', NULL),
	(167, '30', 'Skaičiavimo klaida dingo', NULL),
	(167, '31', 'Skaičiavimo klaida', NULL),
	(168, '30', 'Grįžimas į diapazoną', NULL),
	(168, '31', 'Diapazono viršijimas', NULL),
	(169, '30', 'Prietaiso išjungimas', NULL),
	(169, '31', 'Prietaiso įjungimas', NULL),
	(170, '30', 'Prieiga prie skaitiklio yra', NULL),
	(170, '31', 'Prieigos prie skaitiklio nėra', NULL),
	(171, '30', 'Uždarytas COM-tunelis', NULL),
	(171, '31', 'Atidarytas COM-tunelis', NULL),
	(172, '30', 'Testo įjungimas', NULL),
	(172, '31', 'Testo išjungimas', NULL),
	(173, '30', 'Bloko atsisakymas dingo', NULL),
	(173, '31', 'Bloko atsisakymas', NULL),
	(174, '30', 'Specialus signalas dingo', NULL),
	(174, '31', 'Specialus signalas', NULL),
	(175, '30', 'Jutiklio gedimas dingo', NULL),
	(175, '31', 'Jutiklio gedimas', NULL),
	(176, '30', 'Jutiklio grąžinimas po išėjimo už MAX', NULL),
	(176, '31', 'Jutiklis - išėjimas už MAX', NULL),
	(177, '30', 'Jutiklio grąžinimas po išėjimo už MIN', NULL),
	(177, '31', 'Jutiklis - išėjimas už MIN', NULL),
	(178, '30', 'Sustabdymas', NULL),
	(178, '31', 'Paleidimas', NULL),
	(179, '30', 'Apkrova normali', NULL),
	(179, '31', 'Apkrovos viršijimas', NULL),
	(180, '30', 'Laiko korekcija išblokuota', NULL),
	(180, '31', 'Laiko korekcija blokuota', NULL),
	(181, '30', 'Limito viršijimo nuėmimas', NULL),
	(181, '31', 'Limito viršijimas', NULL),
	(182, '30', 'Grįžimas į galios ribą', NULL),
	(182, '31', 'Galios ribos viršijimas', NULL),
	(183, '30', 'Grįžimas į įtampos iškraipymų koeficiento ribą', NULL),
	(183, '31', 'Įtampos iškraipymų koeficiento ribos peržengimas', NULL),
	(184, '30', 'Grįžimas į dažnio viršutinę ribą', NULL),
	(184, '31', 'Dažnio viršutinės ribos peržengimas', NULL),
	(185, '30', 'Grįžimas į dažnio apatinės ribą', NULL),
	(185, '31', 'Dažnio apatinės ribos peržengimas', NULL),
	(186, '30', 'Grįžimas į tiesioginės sekos įtampos U1(1) viršutinę ribą', NULL),
	(186, '31', 'Tiesioginės sekos įtampos U1(1) viršutinės ribos peržengimas', NULL),
	(187, '30', 'Grįžimas į tiesioginės sekos įtampos U1(1) apatinę ribą', NULL),
	(187, '31', 'Tiesioginės sekos įtampos U1(1) apatinės ribos peržengimas', NULL),
	(188, '30', 'Grįžimas į 1 fazės įtampos viršutinę ribą', NULL),
	(188, '31', '1 fazės įtampos viršutinės ribos peržengimas', NULL),
	(189, '30', 'Grįžimas į 1 fazės įtampos apatinę ribą', NULL),
	(189, '31', '1 fazės įtampos apatinės ribos peržengimas', NULL),
	(190, '30', 'Grįžimas į 2 fazės įtampos viršutinę ribą', NULL),
	(190, '31', '2 fazės įtampos viršutinės ribos peržengimas', NULL),
	(191, '30', 'Grįžimas į 2 fazės įtampos apatinę ribą', NULL),
	(191, '31', '2 fazės įtampos apatinės ribos peržengimas', NULL),
	(192, '30', 'Grįžimas į 3 fazės įtampos viršutinę ribą', NULL),
	(192, '31', '3 fazės įtampos viršutinės ribos peržengimas', NULL),
	(193, '30', 'Grįžimas į 3 fazės įtampos apatinę ribą', NULL),
	(193, '31', '3 fazės įtampos apatinės ribos peržengimas', NULL),
	(194, '30', 'Grįžimas į dažnio viršutinę ALVR', NULL),
	(194, '31', 'Dažnio viršutinės ALVR peržengimas', NULL),
	(195, '30', 'Grįžimas į dažnio viršutinę NLVR', NULL),
	(195, '31', 'Dažnio viršutinės NLVR peržengimas', NULL),
	(196, '30', 'Grįžimas į dažnio apatinę ALVR', NULL),
	(196, '31', 'Dažnio apatinės ALVR peržengimas', NULL),
	(197, '30', 'Grįžimas į dažnio apatinę NLVR', NULL),
	(197, '31', 'Dažnio apatinės NLVR peržengimas', NULL),
	(198, '30', 'Grįžimas į tiesioginės sekos įtampos U1(1) viršutinę ALVR', NULL),
	(198, '31', 'Tiesioginės sekos įtampos U1(1) viršutinės ALVR peržengimas', NULL),
	(199, '30', 'Grįžimas į tiesioginės sekos įtampos U1(1) viršutinę NLVR', NULL),
	(199, '31', 'Tiesioginės sekos įtampos U1(1) viršutinės NLVR peržengimas', NULL),
	(200, '30', 'Grįžimas į tiesioginės sekos įtampos U1(1) apatinę ALVR', NULL),
	(200, '31', 'Tiesioginės sekos įtampos U1(1) apatinės ALVR peržengimas', NULL),
	(201, '30', 'Grįžimas į tiesioginės sekos įtampos U1(1) apatinę NLVR', NULL),
	(201, '31', 'Tiesioginės sekos įtampos U1(1) apatinės NLVR peržengimas', NULL),
	(202, '30', 'Grįžimas į 1 fazės įtampos viršutinę ALVR', NULL),
	(202, '31', '1 fazės įtampos viršutinės ALVR peržengimas', NULL),
	(203, '30', 'Grįžimas į 1 fazės įtampos viršutinę NLVR', NULL),
	(203, '31', '1 fazės įtampos viršutinės NLVR peržengimas', NULL),
	(204, '30', 'Grįžimas į 1 fazės įtampos apatinę ALVR', NULL),
	(204, '31', '1 fazės įtampos apatinės ALVR peržengimas', NULL),
	(205, '30', 'Grįžimas į 1 fazės įtampos apatinę NLVR', NULL),
	(205, '31', '1 fazės įtampos apatinės NLVR peržengimas', NULL),
	(206, '30', 'Grįžimas į 2 fazės įtampos viršutinę ALVR', NULL),
	(206, '31', '2 fazės įtampos viršutinės ALVR peržengimas', NULL),
	(207, '30', 'Grįžimas į 2 fazės įtampos viršutinę NLVR', NULL),
	(207, '31', '2 fazės įtampos viršutinės NLVR peržengimas', NULL),
	(208, '30', 'Grįžimas į 2 fazės įtampos apatinę ALVR', NULL),
	(208, '31', '2 fazės įtampos apatinės ALVR peržengimas', NULL),
	(209, '30', 'Grįžimas į 2 fazės įtampos apatinę NLVR', NULL),
	(209, '31', '2 fazės įtampos apatinės NLVR peržengimas', NULL),
	(210, '30', 'Grįžimas į 3 fazės įtampos viršutinę ALVR', NULL),
	(210, '31', '3 fazės įtampos viršutinės ALVR peržengimas', NULL),
	(211, '30', 'Grįžimas į 3 fazės įtampos viršutinę NLVR', NULL),
	(211, '31', '3 fazės įtampos viršutinės NLVR peržengimas', NULL),
	(212, '30', 'Grįžimas į 3 fazės įtampos apatinę ALVR', NULL),
	(212, '31', '3 fazės įtampos apatinės ALVR peržengimas', NULL),
	(213, '30', 'Grįžimas į 3 fazės įtampos apatinę NLVR', NULL),
	(213, '31', '3 fazės įtampos apatinės NLVR peržengimas', NULL),
	(214, '30', 'Grįžimas į įtampos tarp fazių 12 viršutinę ALVR', NULL),
	(214, '31', 'Įtampos tarp fazių 12 viršutinės ALVR peržengimas', NULL),
	(215, '30', 'Grįžimas į įtampos tarp fazių 12 viršutinę NLVR', NULL),
	(215, '31', 'Įtampos tarp fazių 12 viršutinės NLVR peržengimas', NULL),
	(216, '30', 'Grįžimas į įtampos tarp fazių 12 apatinę ALVR', NULL),
	(216, '31', 'Įtampos tarp fazių 12 apatinės ALVR peržengimas', NULL),
	(217, '30', 'Grįžimas į įtampos tarp fazių 12 apatinę NLVR', NULL),
	(217, '31', 'Įtampos tarp fazių 12 apatinės NLVR peržengimas', NULL),
	(218, '30', 'Grįžimas į įtampos tarp fazių 23 viršutinę ALVR', NULL),
	(218, '31', 'Įtampos tarp fazių 23 viršutinės ALVR peržengimas', NULL),
	(219, '30', 'Grįžimas į įtampos tarp fazių 23 viršutinę NLVR', NULL),
	(219, '31', 'Įtampos tarp fazių 23 viršutinės NLVR peržengimas', NULL),
	(220, '30', 'Grįžimas į įtampos tarp fazių 23 apatinę ALVR', NULL),
	(220, '31', 'Įtampos tarp fazių 23 apatinės ALVR peržengimas', NULL),
	(221, '30', 'Grįžimas į įtampos tarp fazių 23 apatinę NLVR', NULL),
	(221, '31', 'Įtampos tarp fazių 23 apatinės NLVR peržengimas', NULL),
	(222, '30', 'Grįžimas į įtampos tarp fazių 31 viršutinę ALVR', NULL),
	(222, '31', 'Įtampos tarp fazių 31 viršutinės ALVR peržengimas', NULL),
	(223, '30', 'Grįžimas į įtampos tarp fazių 31 viršutinę NLVR', NULL),
	(223, '31', 'Įtampos tarp fazių 31 viršutinės NLVR peržengimas', NULL),
	(224, '30', 'Grįžimas į įtampos tarp fazių 31 apatinę ALVR', NULL),
	(224, '31', 'Įtampos tarp fazių 31 apatinės ALVR peržengimas', NULL),
	(225, '30', 'Grįžimas į įtampos tarp fazių 31 apatinę NLVR', NULL),
	(225, '31', 'Įtampos tarp fazių 31 apatinės NLVR peržengimas', NULL),
	(226, '30', 'Grįžimas į 1 fazės įtampos iškraipymų koeficiento ALVR', NULL),
	(226, '31', '1 fazės įtampos iškraipymų koeficiento ALVR peržengimas', NULL),
	(227, '30', 'Grįžimas į 1 fazės įtampos iškraipymų koeficiento NLVR', NULL),
	(227, '31', '1 fazės įtampos iškraipymų koeficiento NLVR peržengimas', NULL),
	(228, '30', 'Grįžimas į 2 fazės įtampos iškraipymų koeficiento ALVR', NULL),
	(228, '31', '2 fazės įtampos iškraipymų koeficiento ALVR peržengimas', NULL),
	(229, '30', 'Grįžimas į 2 fazės įtampos iškraipymų koeficiento NLVR', NULL),
	(229, '31', '2 fazės įtampos iškraipymų koeficiento NLVR peržengimas', NULL),
	(230, '30', 'Grįžimas į 3 fazės įtampos iškraipymų koeficiento ALVR', NULL),
	(230, '31', '3 fazės įtampos iškraipymų koeficiento ALVR peržengimas', NULL),
	(231, '30', 'Grįžimas į 3 fazės įtampos iškraipymų koeficiento NLVR', NULL),
	(231, '31', '3 fazės įtampos iškraipymų koeficiento NLVR peržengimas', NULL),
	(232, '30', 'Grįžimas į įtampos iškraipymų koeficiento tarp fazių 12 ALVR', NULL),
	(232, '31', 'Įtampos iškraipymų koeficiento tarp fazių 12 ALVR peržengimas', NULL),
	(233, '30', 'Grįžimas į įtampos iškraipymų koeficiento tarp fazių 12 NLVR', NULL),
	(233, '31', 'Įtampos iškraipymų koeficiento tarp fazių 12 NLVR peržengimas', NULL),
	(234, '30', 'Grįžimas į įtampos iškraipymų koeficiento tarp fazių 23 ALVR', NULL),
	(234, '31', 'Įtampos iškraipymų koeficiento tarp fazių 23 ALVR peržengimas', NULL),
	(235, '30', 'Grįžimas į įtampos iškraipymų koeficiento tarp fazių 23 NLVR', NULL),
	(235, '31', 'Įtampos iškraipymų koeficiento tarp fazių 23 NLVR peržengimas', NULL),
	(236, '30', 'Grįžimas į įtampos iškraipymų koeficiento tarp fazių 31 ALVR', NULL),
	(236, '31', 'Įtampos iškraipymų koeficiento tarp fazių 31 ALVR peržengimas', NULL),
	(237, '30', 'Grįžimas į įtampos iškraipymų koeficiento tarp fazių 31 NLVR', NULL),
	(237, '31', 'Įtampos iškraipymų koeficiento tarp fazių 31 NLVR peržengimas', NULL),
	(238, '30', 'Grįžimas į nulinės sekos nesimetrinės įtampos koeficiento ALVR peržengimas', NULL),
	(238, '31', 'Nulinės sekos nesimetrinės įtampos koeficiento ALVR peržengimas', NULL),
	(239, '30', 'Grįžimas į nulinės sekos nesimetrinės įtampos koeficiento NLVR peržengimas', NULL),
	(239, '31', 'Nulinės sekos nesimetrinės įtampos koeficiento NLVR peržengimas', NULL),
	(240, '30', 'Grįžimas į atvirkštinės sekos nesimetrinės įtampos koeficiento ALVR peržengimas', NULL),
	(240, '31', 'Atvirkštinės sekos nesimetrinės įtampos koeficiento ALVR peržengimas', NULL),
	(241, '30', 'Grįžimas į atvirkštinės sekos nesimetrinės įtampos koeficiento NLVR peržengimas', NULL),
	(241, '31', 'Atvirkštinės sekos nesimetrinės įtampos koeficiento NLVR peržengimas', NULL),
	(242, '30', 'Nuimta būsena: Blogas ryšys su prietaisu', NULL),
	(242, '31', 'Blogas ryšys su prietaisu', NULL),
	(243, '30', 'Nuimta būsena: Prietaisas neatsako', NULL),
	(243, '31', 'Prietaisas neatsako', NULL),
	(244, '30', 'Nuimta būsena: Neteisingas prietaiso priėjimo slaptažodis', NULL),
	(244, '31', 'Neteisingas prietaiso priėjimo slaptažodis', NULL),
	(245, '30', 'Nuimta būsena: Netinkamas prietaiso aprašymas', NULL),
	(245, '31', 'Netinkamas prietaiso aprašymas', NULL),
	(246, '30', 'Nuimta būsena: Neteisingai sukonfiguruotas prietaisas', NULL),
	(246, '31', 'Neteisingai sukonfiguruotas prietaisas', NULL),
	(247, '30', 'Nuimta būsena: Netinkamas parametro aprašymas', NULL),
	(247, '31', 'Netinkamas parametro aprašymas', NULL),
	(248, '30', 'Nuimta būsena: Prietaiso atsakymas su klaidos kodu', NULL),
	(248, '31', 'Prietaiso atsakymas su klaidos kodu', NULL),
	(249, '30', 'Nuimta būsena: Nežinoma klaida', NULL),
	(249, '31', 'Nežinoma klaida', NULL),
	(250, '30', 'Skaitiklio kleminio dangčio uždarymas', NULL),
	(250, '31', 'Skaitiklio kleminio dangčio atidarymas', NULL),
	(251, '1', 'Application', NULL),
	(251, '2', 'Security', NULL),
	(251, '3', 'System', NULL),
	(251, '4', 'STUSPDService', NULL),
	(251, '5', 'USPDConfigurator', NULL),
	(251, '6', 'USPDDrvService', NULL),
	(251, '7', 'USPDMonitor', NULL),
	(251, '8', 'USPDService', NULL),
	(251, '9', 'Uspd_Logger', NULL),
	(252, '30', 'Konfiguravimas leistas', NULL),
	(252, '31', 'Konfiguravimas uždraustas', NULL),
	(253, '30', 'Ryšio IEC 870-5-101 nutrūkimas', NULL),
	(253, '31', 'Ryšys IEC 870-5-101 yra', NULL),
	(254, '30', 'Ryšio IEC 870-5-104 nutrūkimas', NULL),
	(254, '31', 'Ryšys IEC 870-5-104 yra', NULL),
	(255, '30', 'Maitinimas iš tinklo', NULL),
	(255, '31', 'Maitinimas iš elemento', NULL),
	(256, '30', 'Įtampos grįžimas po išėjimo už MAX', NULL),
	(256, '31', 'Įtampa - išėjimas už MAX', NULL),
	(257, '30', 'Įtampos grįžimas po išėjimo už MIN', NULL),
	(257, '31', 'Įtampa - išėjimas už MIN', NULL),
	(258, '30', 'Srovės grįžimas po išėjimo už MIN', NULL),
	(258, '31', 'Srovė - išėjimas už MIN', NULL),
	(259, '30', 'Grįžimas į normą', NULL),
	(259, '31', 'Ribos peržengimas', NULL),
	(260, '30', 'Galios koeficiento grįžimas į normą', NULL),
	(260, '31', 'Galios koeficiento ribos peržengimas', NULL),
	(261, '30', '2 harmoninės srovės grįžimas į normą', NULL),
	(261, '31', '2 harmoninės srovės ribos peržengimas', NULL),
	(262, '30', 'Nesinusoidinės srovės grįžimas į normą', NULL),
	(262, '31', 'Nesinusoidinės srovės ribos peržengimas', NULL),
	(263, '30', 'Fazių įtampų grįžimas į atitikimo normą', NULL),
	(263, '31', 'Fazių įtampų atitikimo ribos peržengimas', NULL),
	(264, '30', 'Fazių srovių grįžimas į atitikimo normą', NULL),
	(264, '31', 'Fazių srovių atitikimo ribos peržengimas', NULL),
	(265, '30', 'Apkrovos grįžimas į iškreipimo normą', NULL),
	(265, '31', 'Apkrovos iškreipimo ribos peržengimas', NULL),
	(266, '30', 'dP grįžimas į ribą', NULL),
	(266, '31', 'dP ribos peržengimas', NULL),
	(267, '30', 'dP grįžimas į apatinę ribą', NULL),
	(267, '31', 'dP apatinės ribos peržengimas', NULL),
	(268, '30', 'dP grįžimas į viršutinę ribą', NULL),
	(268, '31', 'dP viršutinės ribos peržengimas', NULL),
	(269, '30', 'dP grįžimas iš po atkirtos', NULL),
	(269, '31', 'dP išėjimas po atkirtą', NULL),
	(270, '30', 'Grįžimas į dažnio viršutinę ribą, kanalas 1', NULL),
	(270, '31', 'Dažnio viršutinės ribos peržengimas, kanalas 1', NULL),
	(271, '30', 'Grįžimas į dažnio viršutinę ribą, kanalas 2', NULL),
	(271, '31', 'Dažnio viršutinės ribos peržengimas, kanalas 2', NULL),
	(272, '30', 'Grįžimas į dažnio viršutinę ribą, kanalas 3', NULL),
	(272, '31', 'Dažnio viršutinės ribos peržengimas, kanalas 3', NULL),
	(273, '30', 'Grįžimas į dažnio viršutinę ribą, kanalas 4', NULL),
	(273, '31', 'Dažnio viršutinės ribos peržengimas, kanalas 4', NULL),
	(274, '30', 'Suvartojimo grįžimas į viršutinę ribą', NULL),
	(274, '31', 'Suvartojimo viršutinės ribos peržengimas', NULL),
	(275, '30', 'Suvartojimo grįžimas į apatinę ribą', NULL),
	(275, '31', 'Suvartojimo apatinės ribos peržengimas', NULL),
	(276, '30', 'Suvartojimo grįžimas į viršutinę ribą, kanalas 1', NULL),
	(276, '31', 'Suvartojimo viršutinės ribos peržengimas, kanalas 1', NULL),
	(277, '30', 'Suvartojimo grįžimas į apatinę ribą, kanalas 1', NULL),
	(277, '31', 'Suvartojimo apatinės ribos peržengimas, kanalas 1', NULL),
	(278, '30', 'Suvartojimo grįžimas į viršutinę ribą, kanalas 2', NULL),
	(278, '31', 'Suvartojimo viršutinės ribos peržengimas, kanalas 2', NULL),
	(279, '30', 'Suvartojimo grįžimas į apatinę ribą, kanalas 2', NULL),
	(279, '31', 'Suvartojimo apatinės ribos peržengimas, kanalas 2', NULL),
	(280, '30', 'Suvartojimo grįžimas į viršutinę ribą, kanalas 3', NULL),
	(280, '31', 'Suvartojimo viršutinės ribos peržengimas, kanalas 3', NULL),
	(281, '30', 'Suvartojimo grįžimas į apatinę ribą, kanalas 3', NULL),
	(281, '31', 'Suvartojimo apatinės ribos peržengimas, kanalas 3', NULL),
	(282, '30', 'Suvartojimo grįžimas į viršutinę ribą, kanalas 4', NULL),
	(282, '31', 'Suvartojimo viršutinės ribos peržengimas, kanalas 4', NULL),
	(283, '30', 'Suvartojimo grįžimas į apatinę ribą, kanalas 4', NULL),
	(283, '31', 'Suvartojimo apatinės ribos peržengimas, kanalas 4', NULL),
	(284, '30', 'Suvartojimo grįžimas į viršutinį slenkstį', NULL),
	(284, '31', 'Suvartojimo viršutinio slenksčio peržengimas', NULL),
	(285, '30', 'Suvartojimo grįžimas į apatinį slenkstį', NULL),
	(285, '31', 'Suvartojimo apatinio slenksčio peržengimas', NULL),
	(286, '30', 'Suvartojimo grįžimas į viršutinį slenkstį, kanalas 1', NULL),
	(286, '31', 'Suvartojimo viršutinio slenksčio peržengimas, kanalas 1', NULL),
	(287, '30', 'Suvartojimo grįžimas į apatinį slenkstį, kanalas 1', NULL),
	(287, '31', 'Suvartojimo apatinio slenksčio peržengimas, kanalas 1', NULL),
	(288, '30', 'Suvartojimo grįžimas į viršutinį slenkstį, kanalas 2', NULL),
	(288, '31', 'Suvartojimo viršutinio slenksčio peržengimas, kanalas 2', NULL),
	(289, '30', 'Suvartojimo grįžimas į apatinį slenkstį, kanalas 2', NULL),
	(289, '31', 'Suvartojimo apatinio slenksčio peržengimas, kanalas 2', NULL),
	(290, '30', 'Suvartojimo grįžimas į viršutinį slenkstį, kanalas 3', NULL),
	(290, '31', 'Suvartojimo viršutinio slenksčio peržengimas, kanalas 3', NULL),
	(291, '30', 'Suvartojimo grįžimas į apatinį slenkstį, kanalas 3', NULL),
	(291, '31', 'Suvartojimo apatinio slenksčio peržengimas, kanalas 3', NULL),
	(292, '30', 'Suvartojimo grįžimas į viršutinį slenkstį, kanalas 4', NULL),
	(292, '31', 'Suvartojimo viršutinio slenksčio peržengimas, kanalas 4', NULL),
	(293, '30', 'Suvartojimo grįžimas į apatinį slenkstį, kanalas 4', NULL),
	(293, '31', 'Suvartojimo apatinio slenksčio peržengimas, kanalas 4', NULL),
	(294, '30', 'Suvartojimo grįžimas į viršutinį apribojimą', NULL),
	(294, '31', 'Suvartojimo viršutinio apribojimo peržengimas', NULL),
	(295, '30', 'Suvartojimo grįžimas į apatinį apribojimą', NULL),
	(295, '31', 'Suvartojimo apatinio apribojimo peržengimas', NULL),
	(296, '30', 'Suvartojimo grįžimas į viršutinį apribojimą, kanalas 1', NULL),
	(296, '31', 'Suvartojimo viršutinio apribojimo peržengimas, kanalas 1', NULL),
	(297, '30', 'Suvartojimo grįžimas į apatinį apribojimą, kanalas 1', NULL),
	(297, '31', 'Suvartojimo apatinio apribojimo peržengimas, kanalas 1', NULL),
	(298, '30', 'Suvartojimo grįžimas į viršutinį apribojimą, kanalas 2', NULL),
	(298, '31', 'Suvartojimo viršutinio apribojimo peržengimas, kanalas 2', NULL),
	(299, '30', 'Suvartojimo grįžimas į apatinį apribojimą, kanalas 2', NULL),
	(299, '31', 'Suvartojimo apatinio apribojimo peržengimas, kanalas 2', NULL),
	(300, '30', 'Suvartojimo grįžimas į viršutinį apribojimą, kanalas 3', NULL),
	(300, '31', 'Suvartojimo viršutinio apribojimo peržengimas, kanalas 3', NULL),
	(301, '30', 'Suvartojimo grįžimas į apatinį apribojimą, kanalas 3', NULL),
	(301, '31', 'Suvartojimo apatinio apribojimo peržengimas, kanalas 3', NULL),
	(302, '30', 'Suvartojimo grįžimas į viršutinį apribojimą, kanalas 4', NULL),
	(302, '31', 'Suvartojimo viršutinio apribojimo peržengimas, kanalas 4', NULL),
	(303, '30', 'Suvartojimo grįžimas į apatinį apribojimą, kanalas 4', NULL),
	(303, '31', 'Suvartojimo apatinio apribojimo peržengimas, kanalas 4', NULL),
	(304, '30', 'Grįžimas į analoginio įėjimo apatinę ribą', NULL),
	(304, '31', 'Analoginio įėjimo apatinės ribos peržengimas', NULL),
	(305, '30', 'Grįžimas į analoginio įėjimo viršutinę ribą', NULL),
	(305, '31', 'Analoginio įėjimo viršutinės ribos peržengimas', NULL),
	(306, '30', 'T grįžimas į viršutinę ribą', NULL),
	(306, '31', 'T viršutinės ribos peržengimas', NULL),
	(307, '30', 'T grįžimas į apatinę ribą', NULL),
	(307, '31', 'T apatinės ribos peržengimas', NULL),
	(308, '30', 'P grįžimas į viršutinę ribą', NULL),
	(308, '31', 'P viršutinės ribos peržengimas', NULL),
	(309, '30', 'P grįžimas į apatinę ribą', NULL),
	(309, '31', 'P apatinės ribos peržengimas', NULL),
	(310, '30', 'GPS laikas dingo', NULL),
	(310, '31', 'GPS laikas atstatytas', NULL),
	(311, '30', 'Apkrovos išjungimas', NULL),
	(311, '31', 'Apkrovos įjungimas', NULL),
	(312, '30', '1 fazės srovė be įtampos, pabaiga', NULL),
	(312, '31', '1 fazės srovė be įtampos', NULL),
	(313, '30', '2 fazės srovė be įtampos, pabaiga', NULL),
	(313, '31', '2 fazės srovė be įtampos', NULL),
	(314, '30', '3 fazės srovė be įtampos, pabaiga', NULL),
	(314, '31', '3 fazės srovė be įtampos', NULL),
	(315, '30', 'Testas IM1 - klaida', NULL),
	(315, '31', 'Testas IM1 - sėkmingai', NULL),
	(316, '30', 'Testas IM2 - klaida', NULL),
	(316, '31', 'Testas IM2 - sėkmingai', NULL),
	(317, '30', 'Testas IM3 - klaida', NULL),
	(317, '31', 'Testas IM3 - sėkmingai', NULL),
	(318, '30', 'Testas IM4 - klaida', NULL),
	(318, '31', 'Testas IM4 - sėkmingai', NULL),
	(319, '30', 'Apsaugos jungiklis IM1 išjungtas', NULL),
	(319, '31', 'Apsaugos jungiklis IM1 įjungtas', NULL),
	(320, '30', 'Apsaugos jungiklis IM2 išjungtas', NULL),
	(320, '31', 'Apsaugos jungiklis IM2 įjungtas', NULL),
	(321, '30', 'Apsaugos jungiklis IM3 išjungtas', NULL),
	(321, '31', 'Apsaugos jungiklis IM3 įjungtas', NULL),
	(322, '30', 'Apsaugos jungiklis IM4 išjungtas', NULL),
	(322, '31', 'Apsaugos jungiklis IM4 įjungtas', NULL),
	(323, '30', 'Grįžimas iš režimo "Neetatinis"', NULL),
	(323, '31', 'Režimas "Neetatinis"', NULL),
	(324, '30', 'Apkrovos išjungimas pagal komandą', NULL),
	(324, '31', 'Įjungimo leidimas pagal komandą', NULL),
	(325, '30', 'Fazės dingimas', NULL),
	(325, '31', 'Fazės atsistatymas', NULL),
	(326, '30', 'Apkrovos išjungimas pagal kredito pabaigą', NULL),
	(326, '31', 'Įjungimo leidimas pagal kredito nustatymą', NULL),
	(327, '30', 'Skaičiavimo sustabdymas', NULL),
	(327, '31', 'Skaičiavimo atnaujinimas', NULL),
	(328, '30', 'Testas RAM IM1 - klaida', NULL),
	(328, '31', 'Testas RAM IM1 - sėkmingai', NULL),
	(329, '30', 'Testas RAM IM2 - klaida', NULL),
	(329, '31', 'Testas RAM IM2 - sėkmingai', NULL),
	(330, '30', 'Testas RAM IM3 - klaida', NULL),
	(330, '31', 'Testas RAM IM3 - sėkmingai', NULL),
	(331, '30', 'Testas RAM IM4 - klaida', NULL),
	(331, '31', 'Testas RAM IM4 - sėkmingai', NULL),
	(332, '30', 'RTC skaitymas atstatytas', NULL),
	(332, '31', 'RTC skaitymo klaida', NULL),
	(333, '30', 'Apkrovos išjungimas dėl perkaitinimo', NULL),
	(333, '31', 'Įjungimo leidimas dėl temperatūros sumažėjimo', NULL),
	(334, '30', 'RTC įrašymas atstatytas', NULL),
	(334, '31', 'RTC įrašymo klaida', NULL),
	(335, '30', 'EEPROM skaitymas atstatytas', NULL),
	(335, '31', 'EEPROM skaitymo klaida', NULL),
	(336, '30', 'EEPROM įrašymas atstatytas', NULL),
	(336, '31', 'EEPROM įrašymo klaida', NULL),
	(337, '30', 'Grįžimas į apribojimo ribą', NULL),
	(337, '31', 'Suveikė apribojimas', NULL),
	(338, '30', 'Skaitiklio sisteminės klaidos dingimas', NULL),
	(338, '31', 'Skaitiklio sisteminė klaida', NULL),
	(339, '30', 'EEPROM IM1 parametrų skatymas/rašymas atstatytas', NULL),
	(339, '31', 'EEPROM IM1 parametrų skatymo/rašymo klaida', NULL),
	(340, '30', 'EEPROM IM2 parametrų skatymas/rašymas atstatytas', NULL),
	(340, '31', 'EEPROM IM2 parametrų skatymo/rašymo klaida', NULL),
	(341, '30', 'EEPROM IM3 parametrų skatymas/rašymas atstatytas', NULL),
	(341, '31', 'EEPROM IM3 parametrų skatymo/rašymo klaida', NULL),
	(342, '30', 'EEPROM IM4 parametrų skatymas/rašymas atstatytas', NULL),
	(342, '31', 'EEPROM IM4 parametrų skatymo/rašymo klaida', NULL),
	(343, '30', 'Nėra ryšio su IM1', NULL),
	(343, '31', 'Ryšys su IM1 atstatytas', NULL),
	(344, '30', 'Nėra ryšio su IM2', NULL),
	(344, '31', 'Ryšys su IM2 atstatytas', NULL),
	(345, '30', 'Nėra ryšio su IM3', NULL),
	(345, '31', 'Ryšys su IM3 atstatytas', NULL),
	(346, '30', 'Nėra ryšio su IM4', NULL),
	(346, '31', 'Ryšys su IM4 atstatytas', NULL),
	(347, '30', 'RS-485 veikimo atstatymas', NULL),
	(347, '31', 'Gedimas RS-485', NULL),
	(348, '30', 'PIC veikimo atstatymas', NULL),
	(348, '31', 'Gedimas PIC', NULL),
	(349, '30', 'Procesoriaus veikimo atstatymas', NULL),
	(349, '31', 'Procesoriaus gedimas', NULL),
	(350, '30', 'Taimerio veikimo atstatymas', NULL),
	(350, '31', 'Taimerio gedimas', NULL),
	(351, '30', 'Flash veikimo atstatymas', NULL),
	(351, '31', 'Flash atminties gedimas', NULL),
	(352, '30', 'I ritės grįžimas į MAX', NULL),
	(352, '31', 'I ritės MAX peržengimas', NULL),
	(353, '30', 'ABB veikimo atstatymas', NULL),
	(353, '31', 'ABB gedimas', NULL),
	(354, '30', 'ABB grandinės klaidos dingimas', NULL),
	(354, '31', 'ABB grandinės klaida', NULL),
	(355, '30', 'ABB srovės įėjimo kanale klaidos dingimas', NULL),
	(355, '31', 'ABB srovės įėjimo kanale klaida', NULL),
	(356, '30', 'ABB varžos įėjimo kanale klaidos dingimas', NULL),
	(356, '31', 'ABB varžos įėjimo kanale klaida', NULL),
	(357, 'EMS', '/EGM_EMS_134.41.4V7', NULL),
	(357, 'EPQM', '/EGM_EPQM3V5', NULL),
	(357, 'EPQS', '/EGM_EPQS', NULL),
	(357, 'GAMA', '/EGM_G3B', NULL),
	(357, 'LZQM', '/EGM_LZQM V0', NULL),
	(357, 'SL7000', '/SLB_SL761', NULL),
	(361, 'askpdatadate', 'Duomenų data', NULL),
	(361, 'askpformdate', 'Dokumento data', NULL),
	(361, 'askpwithoutdate', 'Be datos', NULL),
	(362, 'askp1V', 'ASKP failo versija "1V"', NULL),
	(362, 'askp2V', 'ASKP failo versija "2V"', NULL),
	(362, 'askp3V', 'ASKP failo versija "3V"', NULL),
	(362, 'askp99', 'ASKP failo versija "99"', NULL),
	(362, 'askpUniversal', 'ASKP failo versija "Universal"', NULL),
	(366, '0', 'išjungtas', NULL),
	(366, '1', 'į ST4Test modulį', NULL),
	(366, '2', 'į bylą', NULL),
	(366, '3', 'į ST4Test modulį ir į bylą', NULL),
	(371, 'ST_ACT', 'Galimybė įvesti aktus ', NULL),
	(371, 'ST_ADMIN', 'Pilnas teisių rinkinys', NULL),
	(371, 'ST_ARCH_PRM_MOD', 'Galimybė įtraukti taškus, taškų matavimus, nustatyti jų naudojimą', NULL),
	(371, 'ST_ARCH_VIEW', 'Galimybė peržiūrėti archyvus iš duomenų bazės', NULL),
	(371, 'ST_AUDIT_VIEW', 'Galimybė peržiūrėti audito įrašus', NULL),
	(371, 'ST_BGA_EXECUTE', 'Galinybė parametruoti ir vykdyti tam tikras fonines užduotis', NULL),
	(371, 'ST_DEFAULT', 'Pradinė rolė (minimalus teisių rinkinys)', NULL),
	(371, 'ST_DEVICE_MOD', 'Galimybė parametruoti prietaisus', NULL),
	(371, 'ST_DEVICE_VIEW', 'Galimybė nuskaityti prietaisų konfigūraciją', NULL),
	(371, 'ST_DI_MOD', 'Galimybė redaguoti nuskaitomus duomenų elementus', NULL),
	(371, 'ST_DSC_DATA_MOD', 'Galimybė įvesti apskaitos būsenų signalų reikšmes', NULL),
	(371, 'ST_EVA_ACK', 'Galimybė patvirtinti įvykius', NULL),
	(371, 'ST_EVA_ACK_VIEW', 'Galimybė peržiūrėti vartotojų patvirtinamus įvykius', NULL),
	(371, 'ST_EVENTS_CONF', 'Galimybė keisti įvykių apdorojimo nustatymus', NULL),
	(371, 'ST_EVENTS_VIEW', 'Galimybė peržiūrėti įvykių registrą', NULL),
	(371, 'ST_EXPORT_MOD', 'Galimybė keisti duomenų apsikeitimo su kitomis sistemomis konfigūraciją', NULL),
	(371, 'ST_EXPORT_VIEW', 'Galimybė peržiūrėti duomenų apsikeitimo su kitomis sistemomis konfigūraciją', NULL),
	(371, 'ST_FILL_VIEW', 'Galimybė peržiūrėti rodmenų kokybės suvestines', NULL),
	(371, 'ST_FORCE_READ', 'Galimybė perrinkti rodmenis, pakeičiant senus', NULL),
	(371, 'ST_IMPERSONAL_ACT_MOD', 'Galimybė atšaukti ir naikinti svetimus aktus', NULL),
	(371, 'ST_IMPORT', 'Galimybė importuoti rodmenis', NULL),
	(371, 'ST_INIT_FILL', 'Galimybė inicijuoti trūkstamų rodmenų užpildymą', NULL),
	(371, 'ST_INSTANT_MOD', 'Galimybė nustatyti normatyvines ribas momentiniams skaitiklių parametrams', NULL),
	(371, 'ST_LINK_PAR_MOD', 'Galimybė nustatyti bazinius ryšio parametrus', NULL),
	(371, 'ST_LINK_PRM_MOD', 'Galimybė nustatyti ryšio parametrus', NULL),
	(371, 'ST_LINK_PRM_VIEW', 'Galimybė peržiūrėti ryšio parametrus', NULL),
	(371, 'ST_LOAD_DATA_FROM_FILE', 'Galimybė importuoti rodmenis iš failo', NULL),
	(371, 'ST_METER_MOD', 'Galimybė keisti skaitiklių konfigūraciją', NULL),
	(371, 'ST_POINT_PPTY_MOD', 'Galimybė redaguoti taškų savybes', NULL),
	(371, 'ST_REALTIME_MOD', 'Galimybė keisti realaus laiko duomenų schemas', NULL),
	(371, 'ST_REALTIME_VIEW', 'Galimybė peržiūrėti realaus laiko duomenų schemas', NULL),
	(371, 'ST_RPA_MOD', 'Galimybė keisti automatizuotų ataskaitų konfigūraciją', NULL),
	(371, 'ST_RP_MOD', 'Galimybė redaguoti ataskaitas', NULL),
	(371, 'ST_RP_VIEW', 'Galimybė vykdyti ataskaitas', NULL),
	(371, 'ST_SAMPLE_MOD', 'Galimybė kurti šablonus ir konfigūruoti monitoringą', NULL),
	(371, 'ST_SAMPLE_VIEW', 'Galimybė peržiūrėti šablonus ir monitoringą', NULL),
	(371, 'ST_SHOW_VIEW', 'Galimybė tiesiogiai užklausti duomenis iš skaitiklių', NULL),
	(371, 'ST_TARIFF_MOD', 'Galimybė keisti tarifinių planų konfigūraciją', NULL),
	(371, 'ST_UPLOAD_ANY_TO_WEB', 'Galimybė užkelti bet kokią bylą į Web serverį', NULL),
	(371, 'ST_UPLOAD_RP_TMPL_TO_WEB', 'Galimybė užkelti ataskaitos šablono bylą į Web serverį', NULL),
	(371, 'ST_WODS', 'Galimybė siųsti į prietaisus valdymo komandas', NULL),
	(371, 'ST_WOD_DTIME_CORRECTION', 'Galimybė atlikti duomenų koncentratoriaus laiko korekciją', NULL),
	(371, 'ST_WOD_DTIME_SET', 'Galimybė atlikti duomenų koncentratoriaus laiko nustatymą', NULL),
	(371, 'ST_WOD_DW', 'Galimybė atlikti duomenų koncentratoriaus parametravimą', NULL),
	(371, 'ST_WOD_PTIME_CORRECTION', 'Galimybė atlikti matavimo prietaiso laiko korekciją', NULL),
	(371, 'ST_WOD_PTIME_SET', 'Galimybė atlikti matavimo prietaiso laiko nustatymą', NULL),
	(371, 'ST_WOD_PW', 'Galimybė atlikti matavimo prietaiso parametravimą', NULL),
	(377, '33', 'EPQS', NULL),
	(377, '67', 'SET-4TA', NULL),
	(377, '68', 'SET-4TM', NULL),
	(377, '69', 'PSC-4TM', NULL),
	(377, '79', 'SET-4TM-01', NULL),
	(377, '80', 'SET-1M-01', NULL),
	(381, '1', 'SET_4TM_02', NULL),
	(381, '13', 'SEB_1TM_01', NULL),
	(381, '14', 'SEB_1TM_02', NULL),
	(381, '15', 'SEB_1TM_02D', NULL),
	(381, '16', 'SEO', NULL),
	(381, '2', 'SET_4TM_02M', NULL),
	(381, '3', 'SET_4TM_03', NULL),
	(381, '4', 'SET_4TM_03M', NULL),
	(382, '10', 'PSC_3TM_05', NULL),
	(382, '11', 'PSC_3TM_05M', NULL),
	(382, '12', 'PSC_3TM_05D', NULL),
	(382, '17', 'PSC_4TM_05MK', NULL),
	(382, '7', 'PSC_4TM_05', NULL),
	(382, '8', 'PSC_4TM_05M', NULL),
	(382, '9', 'PSC_4TM_05D', NULL),
	(383, '0', 'SET_4TM_01', NULL),
	(384, '5', 'SET_1M_01', NULL),
	(384, '6', 'SET_1M_01M', NULL),
	(391, '4307', '$10D3', NULL),
	(392, '20173', '$4ECD', NULL),
	(393, '18604', '$48AC', NULL),
	(395, '11309', '$2C2D', NULL),
	(399, '19875', '$4DA3', NULL),
	(401, '12901', '$3265', NULL),
	(402, '12901', '$3265', NULL),
	(403, '19630', '$4CAE', NULL),
	(403, '9686', '$25D6', NULL),
	(404, '12901', '$3265', NULL),
	(405, '12967', '$32A7', NULL),
	(406, 'Expanded', 'Expanded', NULL),
	(406, 'ModBus', 'ModBus', NULL),
	(411, '1143', '$477', NULL),
	(416, '31', ' ', NULL),
	(421, '30', 'Tiesioginė energijos tėkmė', NULL),
	(421, '31', 'Atvirkštinė energijos tėkmė', NULL),
	(422, '30', 'Tiesioginė energijos tėkmė 1-je fazėje', NULL),
	(422, '31', 'Atvirkštinė energijos tėkmė 1-je fazėje', NULL),
	(423, '30', 'Tiesioginė energijos tėkmė 2-je fazėje', NULL),
	(423, '31', 'Atvirkštinė energijos tėkmė 2-je fazėje', NULL),
	(424, '30', 'Tiesioginė energijos tėkmė 3-je fazėje', NULL),
	(424, '31', 'Atvirkštinė energijos tėkmė 3-je fazėje', NULL),
	(425, '30', 'Atsirado srovė', NULL),
	(425, '31', 'Dingo srovė', NULL),
	(426, '30', 'Atsirado įtampa', NULL),
	(426, '31', 'Dingo įtampa', NULL),
	(431, '0', 'Controller_DB', NULL),
	(431, '1', 'Multi_Number', NULL),
	(431, '2', 'Single_Number', NULL),
	(431, '3', 'Multi_Txt', NULL),
	(431, '4', 'Single_Txt', NULL),
	(441, '1', 'Vartotojas 1', NULL),
	(441, '2', 'Vartotojas 2', NULL),
	(442, '23', 'EMP', NULL),
	(442, '24', 'GEM', NULL),
	(442, '25', 'EMS', NULL),
	(456, '30', 'Nepatikimo išorinio valdymo pabaiga', NULL),
	(456, '31', 'Nepatikimas išorinis valdymas', NULL),
	(461, '0', 'sukonfiguruoto kanalo', NULL),
	(461, '1', 'kanalo pusvalandžių sumos', NULL),
	(466, '0', 'Nėra', NULL),
	(466, '1', 'Pagal metus', NULL),
	(466, '2', 'Pagal metus, mėnesį', NULL),
	(466, '3', 'Pagal metus, mėnesį, dieną', NULL),
	(466, '4', 'Pagal metus, mėnesį, dieną, valandą', NULL),
	(467, '0', 'Sistemos laiką siuntimo metu', NULL),
	(467, '1', 'Šaltinio laiką nuskaitymo metu', NULL),
	(471, 'DI_AK', 'Derinys \'Matavimo linija taške\',\'Signalas\',\'Duomenų pluoštas\',\'Matavimo taškas\',\'Nuskaitymo taškas\' turi būti unikalus', NULL),
	(471, 'ENUM_DATA_PK', 'Išvardinimo reikšmė turi būti unikali', NULL),
	(471, 'FFP_DATA_UNIQUE', 'Derinys \'Profilio lauko indeksas\',\'Profilio idenfikatorius\' turi būti unikalus', NULL),
	(471, 'METER_NUMBER_U', 'Derinys \'Skaitiklio numeris\',\'Skaitiklio tipas\' turi būti unikalus', NULL),
	(472, 'EXPL_START_DATA_CHECK', 'Matavimo prietaiso eksploatacijos pradžios data negali būti ankstesnė už pagaminimo datą', NULL),
	(472, 'GR_GPTY_SYMBOL_CHECK', 'Apskaitos grupės savybės reikšmėje aptikti nespausdintiniai simboliai', NULL),
	(472, 'METER_MPTY_SYMBOL_CHECK', 'Matavimo priemonės savybės reikšmėje aptikti nespausdintiniai simboliai', NULL),
	(472, 'REL_EPTY_SYMBOL_CHECK', 'Sąryšio savybės reikšmėje aptikti nespausdintiniai simboliai', NULL),
	(472, 'RPA_RPTY_SYMBOL_CHECK', 'Automatizuotos ataskaitos savybės reikšmėje aptikti nespausdintiniai simboliai', NULL),
	(472, 'RPQ_ADVANCED_CHK', 'Parametrizuotai užklausai nurodykitę lentelę arba įveskite užklausą', NULL),
	(472, 'RP_FPTY_SYMBOL_CHECK', 'Ataskaitos formato savybės reikšmėje aptikti nespausdintiniai simboliai', NULL),
	(472, 'SE_H_PER_ID_NOT_NULL_CHK', 'Negalima suvesti archyvo gylio, bet nesuvesti gylio vienetų', NULL),
	(472, 'SE_H_SE_H_DEPTH_NOT_NULL_CHK', 'Negalima nurodyti, kad elementas turi archyvus, bet nenurodyti, koks archyvų gylis', NULL),
	(472, 'XA_RPTY_SYMBOL_CHECK', 'Protokolo savybės reikšmėje aptikti nespausdintiniai simboliai', NULL),
	(472, 'XFAU_EMPTY_CN_CHK', 'Nuėmus kodo ir pavadinimo paveldėjimo požymį, nenurodytas nei kodas, nei pavadinimas', NULL),
	(476, 'CP866', 'Cyrillic (DOS) [866]', NULL),
	(476, 'CPKOI8R', 'Cyrillic (KOI8-R) [878]', NULL),
	(476, 'None', 'Nenurodyta', NULL),
	(477, 'KWT', 'Kilovatai/Kilovatvalandės', NULL),
	(477, 'MWT', 'Megavatai/Megavatvalandės', NULL),
	(481, '1', 'Savo laiku', NULL),
	(481, '2', 'CET žiemos laiku', NULL),
	(486, '0', 'klaidą', NULL),
	(486, '1', 'uždelsimą', NULL),
	(491, '30', '1 fazės matavimo požymis išungtas', NULL),
	(491, '31', '1 fazės matavimo požymis įjungtas', NULL),
	(492, '30', '2 fazės matavimo požymis išungtas', NULL),
	(492, '31', '2 fazės matavimo požymis įjungtas', NULL),
	(493, '30', '3 fazės matavimo požymis išungtas', NULL),
	(493, '31', '3 fazės matavimo požymis įjungtas', NULL),
	(494, '30', '1 fazės srovės kryptis neigiama', NULL),
	(494, '31', '1 fazės srovės kryptis teigiama', NULL),
	(495, '30', '2 fazės srovės kryptis neigiama', NULL),
	(495, '31', '2 fazės srovės kryptis teigiama', NULL),
	(496, '30', '2 fazės srovės kryptis neigiama', NULL),
	(496, '31', '3 fazės srovės kryptis teigiama', NULL),
	(497, '30', 'Profilio rodyklių apdorojimas nevyksta', NULL),
	(497, '31', 'Vyksta profilio rodyklių apdorojimas', NULL),
	(498, '30', 'Dienų rodyklių apdorojimas nevyksta', NULL),
	(498, '31', 'Vyksta dienų rodyklių apdorojimas', NULL),
	(499, '30', 'Mėnesių rodyklių apdorojimas nevyksta', NULL),
	(499, '31', 'Vyksta mėnesių rodyklių apdorojimas', NULL),
	(500, '30', 'Maitinimas ne 12 V', NULL),
	(500, '31', 'Maitinimas 12 V', NULL),
	(501, '30', 'Naujo įvykio maitinimo dingimų žurnale nėra', NULL),
	(501, '31', 'Naujas įvykis maitinimo dingimų žurnale ', NULL),
	(502, '30', 'Naujo įvykio fazių perjungimų žurnale nėra', NULL),
	(502, '31', 'Naujas įvykis fazių perjungimų žurnale ', NULL),
	(503, '30', 'Naujo įvykio žurnale nėra', NULL),
	(503, '31', 'Naujas įvykis žurnale ', NULL),
	(504, '30', 'Ryšys parametravimui per optinę galvutę nenustatytas', NULL),
	(504, '31', 'Ryšys parametravimui per optinę galvutę nustatytas', NULL),
	(505, '30', 'Ryšys skaitymui per optinę galvutę nenustatytas', NULL),
	(505, '31', 'Ryšys skaitymui per optinę galvutę nustatytas', NULL),
	(506, '30', 'Integravimo periodas nepasibaigė', NULL),
	(506, '31', 'Integravimo periodas pasibaigė', NULL),
	(507, '30', 'Diena nepasibaigė', NULL),
	(507, '31', 'Diena pasibaigė', NULL),
	(508, '30', 'Mėnuo nepasibaigė', NULL),
	(508, '31', 'Mėnuo pasibaigė', NULL),
	(509, '30', 'Metai nepasibaigė', NULL),
	(509, '31', 'Metai pasibaigė', NULL),
	(510, '30', 'Laiko korekcijos riba nepasiekta', NULL),
	(510, '31', 'Laiko korekcijos riba pasiekta', NULL),
	(511, '30', 'Geras VKM', NULL),
	(511, '31', 'Blogas VKM', NULL),
	(512, '30', 'Vasaros laiko režimas išungtas', NULL),
	(512, '31', 'Vasaros laiko režimas įjungtas', NULL),
	(513, '30', 'Parduotuvės režimas išungtas', NULL),
	(513, '31', 'Parduotuvės režimas įjungtas', NULL),
	(514, '30', 'Įrenginis nebeizoliuotas', NULL),
	(514, '31', 'Įrenginis izoliuotas', NULL),
	(515, '1', '1', NULL),
	(515, '10', '10', NULL),
	(515, '11', '11', NULL),
	(515, '12', '12', NULL),
	(515, '13', '13', NULL),
	(515, '14', '14', NULL),
	(515, '15', '15', NULL),
	(515, '2', '2', NULL),
	(515, '3', '3', NULL),
	(515, '4', '4', NULL),
	(515, '5', '5', NULL),
	(515, '6', '6', NULL),
	(515, '7', '7', NULL),
	(515, '8', '8', NULL),
	(515, '9', '9', NULL),
	(516, '0', '0', NULL),
	(516, '1', '1', NULL),
	(516, '2', '2', NULL),
	(516, '3', '3', NULL),
	(522, '0', 'Off', NULL),
	(522, '1', 'On', NULL),
	(523, '0', 'WM22', NULL),
	(523, '1', 'EM4 be skaitmeninių įvedimo modulių', NULL),
	(523, '2', 'EM4 su skaitmeniniu įvedimo moduliu. Elektros pirmo tarifo apskaita', NULL),
	(523, '3', 'EM4 su skaitmeniniu įvedimo moduliu. Vandens ir dujų apskaita', NULL),
	(523, '4', 'EM4 su skaitmeniniu įvedimo moduliu. Dujų nakties ir dienos tarifų apskaita.', NULL),
	(523, '5', 'EM21', NULL),
	(523, '6', 'EM24', NULL),
	(524, 'Manufacturer', 'Manufacturer', NULL),
	(524, 'OPTICAL', 'OPTICAL', NULL),
	(525, 'FALSE', 'Ne', NULL),
	(525, 'TRUE', 'Taip', NULL),
	(526, '0', 'CVM 96', NULL),
	(526, '1', 'CVM 96 HAR-IN', NULL),
	(526, '2', 'CVM-MINI-ITF-RS485-C2', NULL),
	(526, '3', 'CVM-MINI-ITF-HAR-RS485-C2', NULL),
	(527, '0', 'EMCOS Default', NULL),
	(528, 'Add', 'Įdėjimas', NULL),
	(528, 'Del', 'Trinimas', NULL),
	(528, 'Execute', 'Įvykdyti', NULL),
	(528, 'Read', 'Skaitymas', NULL),
	(528, 'Read_4Req', 'Skaitymas pagal užklausimą', NULL),
	(528, 'Write', 'Įrasymas', NULL),
	(529, '1', 'LZQM', NULL),
	(529, '127', 'GAMA', NULL),
	(529, '25', 'EMS', NULL),
	(529, '30', 'EPQM', NULL),
	(529, '33', 'EPQS', NULL),
	(529, '51', 'LZKM', NULL),
	(530, '33', 'EPQS', NULL),
	(531, '1', 'LZQM', NULL),
	(531, '30', 'EPQM', NULL),
	(531, '51', 'LZKM', NULL),
	(532, '25', 'EMS', NULL),
	(533, '127', 'GAMA', NULL),
	(534, '24391', '$5F47', NULL),
	(535, '-1', 'be šliuzo', NULL),
	(535, '1', 'per pirmą šliuzo portą', NULL),
	(535, '2', 'per antrą šliuzo portą', NULL),
	(536, '0', 'iš skaitiklio', NULL),
	(536, '1', 'iš buferio', NULL),
	(537, '1', '1.0', NULL),
	(537, '2', '2.0', NULL),
	(538, '0', 'nesumuoti', NULL),
	(538, '1', 'sumuoti', NULL),
	(539, '0', 'Keturlaidis', NULL),
	(539, '1', 'Trilaidis', NULL),
	(540, '2', 'CEEO', NULL),
	(541, '1', 'Dmz', NULL),
	(542, '10', 'FP93', NULL),
	(542, '19', 'SKM-01', NULL),
	(542, '26', 'SKU_01M', NULL),
	(542, '62', 'SKS-3', NULL),
	(543, '115200', '115200', NULL),
	(543, '1200', '1200', NULL),
	(543, '14400', '144001', NULL),
	(543, '19200', '19200', NULL),
	(543, '2400', '2400', NULL),
	(543, '28800', '28800', NULL),
	(543, '300', '300', NULL),
	(543, '38400', '38400', NULL),
	(543, '4800', '4800', NULL),
	(543, '57600', '57600', NULL),
	(543, '600', '600', NULL),
	(543, '9600', '9600', NULL),
	(544, '7', '7', NULL),
	(544, '8', '8', NULL),
	(545, 'Even', 'lyginis', NULL),
	(545, 'None', 'ne', NULL),
	(545, 'Odd', 'nelyginis', NULL),
	(546, '1', '1', NULL),
	(546, '2', '2', NULL),
	(547, '115200', '115200', NULL),
	(547, '1200', '1200', NULL),
	(547, '14400', '144001', NULL),
	(547, '19200', '19200', NULL),
	(547, '2400', '2400', NULL),
	(547, '28800', '28800', NULL),
	(547, '300', '300', NULL),
	(547, '38400', '38400', NULL),
	(547, '4800', '4800', NULL),
	(547, '57600', '57600', NULL),
	(547, '600', '600', NULL),
	(547, '9600', '9600', NULL),
	(548, '7', '7', NULL),
	(548, '8', '8', NULL),
	(549, 'Even', 'lyginis', NULL),
	(549, 'None', 'ne', NULL),
	(549, 'Odd', 'nelyginis', NULL),
	(550, '1', '1', NULL),
	(550, '2', '2', NULL),
	(551, '290', '290', NULL),
	(551, '293', '293', NULL),
	(553, '30', 'Fazės įtampa atstatyta ', NULL),
	(553, '31', 'Nustatytas fazės įtampos dingimas', NULL),
	(554, '30', 'Įtampos testavimo pabaiga', NULL),
	(554, '31', 'Įtampos testavimo pradžia', NULL),
	(555, '30', 'Įtampa pakilo iki normos ribų', NULL),
	(555, '31', 'Įtampa nukrito žemiau normos ribų', NULL),
	(556, '30', 'Įtampa nukrito iki normos ribų', NULL),
	(556, '31', 'Įtampa pakilo virš normos ribų', NULL),
	(557, '30', 'Įtampos reverso koeficiento reikšmė yra normos ribose', NULL),
	(557, '31', 'Įtampos reverso koeficiento reikšmės ribos peržengimas', NULL),
	(558, '30', 'Srovė yra normos ribose', NULL),
	(558, '31', 'Aptikta žema srovė', NULL),
	(559, '30', 'Įtampos koeficiento reikšmė yra normos ribose', NULL),
	(559, '31', 'Įtampos koeficiento reikšmės ribos peržengimas', NULL),
	(560, '30', 'Antra harmoninė srovė yra normos ribose', NULL),
	(560, '31', 'Antros harmoninės srovės ribos peržengimas', NULL),
	(561, '30', 'Nesinusoidinės srovės koeficientas yra normos ribose', NULL),
	(561, '31', 'Nesinusoidinės srovės koeficiento ribos peržengimas', NULL),
	(562, '30', 'Nesinusoidinės įtampos koeficientas yra normos ribose', NULL),
	(562, '31', 'Nesinusoidinės įtampos koeficiento ribos peržengimas', NULL),
	(563, '30', 'Fazinių įtampų atitikties koeficientas normos ribose', NULL),
	(563, '31', 'Fazinių įtampų atitikties koeficiento ribos peržengimas', NULL),
	(564, '30', 'Fazinių srovių atitikties koeficientas normos ribose', NULL),
	(564, '31', 'Fazinių srovių atitikties koeficiento ribos peržengimas', NULL),
	(565, '30', 'Bendras įtampos iškraipymų koeficientas normos ribose', NULL),
	(565, '31', 'Bendras įtampos iškraipymų koeficiento ribos peržengimas', NULL),
	(566, '30', 'Ryšio su apklausos tašku atstatymas', NULL),
	(566, '31', 'Ryšio su apklausos tašku dingimas', NULL),
	(567, '30', 'Automatinės apklausos pabaiga', NULL),
	(567, '31', 'Automatinės apklausos pradžia', NULL),
	(568, '30', 'Ryšio su žemesnio lygio koncentratoriumi atstatymas', NULL),
	(568, '31', 'Ryšio su žemesnio lygio koncentratoriumi dingimas', NULL),
	(569, '30', 'Surinkimo paleidimas po parametravimo klaidos likvidavimo', NULL),
	(569, '31', 'Surinkimo sustabdymas dėl parametravimo klaidos', NULL),
	(570, 'Binary', 'Binarinis', NULL),
	(570, 'Xml', 'Xml', NULL),
	(573, '0', 'USPD 164 01I', NULL),
	(573, '1', 'USPD 164 01M', NULL),
	(578, '1', '1', NULL),
	(578, '2', '2', NULL),
	(579, '1', '1', NULL),
	(579, '2', '2', NULL),
	(579, '3', '3', NULL),
	(580, 'ANSI', 'ANSI', NULL),
	(580, 'ANSIVALSENA', 'ANSIVALSENA', NULL),
	(581, 'P3.2', 'P3.2', NULL),
	(581, 'P3.2Ex', 'P3.2Ex', NULL),
	(582, '30', 'Srovė ir įtampa ne priešingojoje fazėje', NULL),
	(582, '31', 'Srovė ir įtampa priešingojoje fazėje', NULL),
	(583, '30', 'Srovės perkrovos nėra', NULL),
	(583, '31', 'Srovės perkrova', NULL),
	(584, '30', 'Įtampos perkrovos nėra', NULL),
	(584, '31', 'Įtampos perkrova', NULL),
	(586, '<FN>STProxyPI.dll</FN><Ver>1.0</Ver><Par Mode="C" ADS="55" TO="2000"/>', '"Command" režimas', NULL),
	(586, '<FN>STProxyPI.dll</FN><Ver>1.0</Ver><Par Mode="D" ADS="55" TO="2000"/>', '"CloseAll" režimas', NULL),
	(586, '<FN>STProxyPI.dll</FN><Ver>1.0</Ver><Par Mode="T" ADS="55" TO="10000"/>', '"Transparent" režimas', NULL),
	(586, '<FN>STProxyPI.dll</FN><Ver>1.0</Ver><Par Mode="T-T" ADS="55" TO="2000"/>', '"Transparent-Tunnel" režimas', NULL),
	(588, '1', 'Foninis', NULL),
	(588, '2', 'Žemiausias', NULL),
	(588, '3', 'Žemas', NULL),
	(588, '4', 'Normalus', NULL),
	(588, '5', 'Aukštas', NULL),
	(588, '6', 'Aukščiausias', NULL),
	(588, '7', 'Kritinis pagal laiką', NULL),
	(588, '8', 'Realaus laiko', NULL),
	(589, '30', 'Srovės perkrovų visose fazėse pabaiga', NULL),
	(589, '31', 'Srovės perkrovos visose fazėse', NULL),
	(590, '30', 'Srovės perkrovų 1 fazėje pabaiga', NULL),
	(590, '31', 'Srovės perkrovos 1 fazėje', NULL),
	(591, '30', 'Srovės perkrovų 2 fazėje pabaiga', NULL),
	(591, '31', 'Srovės perkrovos 2 fazėje', NULL),
	(592, '30', 'Srovės perkrovų 3 fazėje pabaiga', NULL),
	(592, '31', 'Srovės perkrovos 3 fazėje', NULL),
	(593, '30', 'Elektroninės plombos išjungimas', NULL),
	(593, '31', 'Elektroninės plombos suveikimas', NULL),
	(594, '30', 'nenaudojamas', NULL),
	(594, '31', 'relė įsijungia nurodytais paros intervalais', NULL),
	(594, '3132', 'įsijungia automatiškai iškarto po įjungimo komandos gavimo', NULL),
	(594, '3133', 'įsijungia mygtukų paspaudimu', NULL),
	(594, '3134', 'Išjungti relę', NULL),
	(594, '3135', '1 tarifo relės įjungimas', NULL),
	(594, '3136', '2 tarifo relės įjungimas', NULL),
	(594, '3137', '3 tarifo relės įjungimas', NULL),
	(594, '3138', '4 tarifo relės įjungimas', NULL),
	(594, '3139', '5 tarifo relės įjungimas', NULL),
	(594, '32', 'įsijungia, jei vidutinė galia po N sek. viršija nustatytą reikšmę, veikia iki integravimo periodo pabaigos', NULL),
	(594, '3230', 'Įjungimas SR ir VR ir išjungimas ĮVR po įtampos limito fazėje A viršijimo', NULL),
	(594, '3231', 'Įjungimas SR ir VR ir išjungimas ĮVR po įtampos limito fazėje B viršijimo', NULL),
	(594, '3232', 'Įjungimas SR ir VR ir išjungimas ĮVR po įtampos limito fazėje C viršijimo', NULL),
	(594, '3233', 'Įjungimas SR ir VR ir išjungimas ĮVR po įtampos limito visose fazėse viršijimo', NULL),
	(594, '3234', 'Įjungimas SR ir VR ir išjungimas ĮVR po įtampos limito bet kokioje fazėje viršijimo', NULL),
	(594, '3235', 'Įjungti relę', NULL),
	(594, '3236', 'Įjungimas SR ir VR ir išjungimas ĮVR po P+ limito viršijimo', NULL),
	(594, '3237', 'Įjungimas SR ir VR ir išjungimas ĮVR po P- limito viršijimo', NULL),
	(594, '3238', 'Įjungimas SR ir VR ir išjungimas ĮVR po Q+ limito viršijimo', NULL),
	(594, '3239', 'Įjungimas SR ir VR ir išjungimas ĮVR po Q- limito viršijimo', NULL),
	(594, '33', 'įsijungia, jei vidutinė galia po N sek. viršija nustatytą reikšmę, veikia iki kito integravimo periodo pabaigos', NULL),
	(594, '3330', 'Įjungimas SR ir VR ir išjungimas ĮVR po A+ limito viršijimo', NULL),
	(594, '3331', 'Įjungimas SR ir VR ir išjungimas ĮVR po A- limito viršijimo', NULL),
	(594, '3332', 'Įjungimas SR ir VR ir išjungimas ĮVR po R+ limito viršijimo', NULL),
	(594, '3333', 'Įjungimas SR ir VR ir išjungimas ĮVR po R- limito viršijimo', NULL),
	(594, '3334', 'Pagal galią', NULL),
	(594, '3335', 'Pagal įtampą', NULL),
	(594, '3336', 'Pagal vartojimą', NULL),
	(594, '3337', 'Pagal grafiką', NULL),
	(594, '3338', 'Įjungti relę tiktai po patvirtinimu mygtuku', NULL),
	(594, '34', 'relė įsijungia užregistravus įvykį arba būseną', NULL),
	(594, '35', 'relė įsijungia įsigaliojus nustatytam energijos arba galios tarifui', NULL),
	(594, '36', 'relės valdomos lygiu', NULL),
	(594, '37', 'relės valdomos impulsais', NULL),
	(594, '39', 'Pagal apšvietimo grafiką', NULL),
	(594, '40', 'Pagal magnetinio lauko poveikį', NULL),
	(595, '31', 'Aktyvioji galia', NULL),
	(595, '32', 'Reaktyvioji galia', NULL),
	(595, '33', 'Pilnoji galia', NULL),
	(596, '30', 'Relės išjungimas pagal limitus', NULL),
	(596, '31', 'Relės įjungimas pagal limitus', NULL),
	(597, '30', 'apkrovos išjungimo komanda', NULL),
	(597, '31', 'apkrovos įjungimo leidimo komanda', NULL),
	(597, '32', 'atšaukti apkrovos valdymo pirmesnę komandą', NULL),
	(597, '33', 'komandos vykdymas nereikalingas', NULL),
	(597, '34', 'apkrovos išjungimo komandos vykdymo laukimas', NULL),
	(597, '35', 'apkrovos įjungimo komandos vykdymo laukimas', NULL),
	(597, '36', 'klaida vykdant komandą', NULL),
	(598, '30', 'nebuvo vykdoma', NULL),
	(598, '31', 'įvykdyta sėkmingai', NULL),
	(598, '3130', 'nevykdomas (pasirinktų apskaitos grupių naudojamų tarifų kiekis viršija leistiną maksimumą)', NULL),
	(598, '3131', 'nevykdomas (vienoje apskaitos grupėje nėra tarifų tvarkaraščio, kuris turi įsigalioti sekančio mėnesio 1 dieną)', NULL),
	(598, '3132', 'nevykdomas (neturi būti išskirtinių dienų su dienos tipu \'šventė\')', NULL),
	(598, '3133', 'nevykdomas (neturi būti apskaitos grupių tarifų tvarkaraščių vienodų įsigaliojimo datų sekančiais metais)', NULL),
	(598, '3134', 'nevykdomas (nėra apskaitos grupių su užduotais slaptažodžiai įrašymui)', NULL),
	(598, '3135', 'pradėti tarifų tvarkaraščių įrašymą', NULL),
	(598, '3136', 'sustabdyti tarifų tvarkaraščių įrašymą', NULL),
	(598, '3137', 'įrašymo klaida', NULL),
	(598, '3138', 'vykdomas nustatytos tarifų konfigūracijos paskleidimas', NULL),
	(598, '3139', 'vykdomas nustatytos tarifų konfigūracijos įrašymas pagal adresą', NULL),
	(598, '32', 'nevykdomas (pasirinktų apskaitos grupių tarifų tvarkaraščiai turėtų įsigalioti 1 mėnesio dieną)', NULL),
	(598, '33', 'nevykdomas (pasirinktų apskaitos grupių tarifų tvarkaraščių darbo dienos privalo turėti vieną tarifikacijos grafiką)', NULL),
	(598, '34', 'nevykdomas (taškų kiekis tarifų keitimui viršija leistiną maksimumą)', NULL),
	(598, '35', 'nėra busimų tarifų tvarkaraščių', NULL),
	(598, '36', 'nevykdomas (pasirinktos apskaitos grupės neturi tarifų tvarkaraščių sekantiems 12 mėnesiams)', NULL),
	(598, '37', 'laukia vykdymo', NULL),
	(598, '38', 'vyksta', NULL),
	(598, '39', 'vyksta įrašymo sustabdymas', NULL),
	(599, '30', 'neprieinama', NULL),
	(599, '31', 'prieinama', NULL),
	(599, '32', 'laikinai neprieinama', NULL),
	(599, '33', 'rastas modemas', NULL),
	(599, '34', 'laukia patvirtinimo', NULL),
	(599, '35', 'registracijos klaida', NULL),
	(599, '36', 'neteisingas slaptažodis', NULL),
	(599, '37', 'išvesta', NULL),
	(599, '38', 'neužregistruota', NULL),
	(599, '39', 'atšaukta', NULL),
	(600, '30', 'apsikeitimas nebuvo vykdytas', NULL),
	(600, '31', 'atsakymas negautas', NULL),
	(600, '32', 'apsikeitimas nutrūko', NULL),
	(600, '33', 'apsikeitimas užbaigtas sėkmingai', NULL),
	(600, '34', 'vidinė klaida', NULL),
	(600, '35', 'gautas nekorektiškas atsakymas', NULL),
	(600, '36', 'skaitiklio data/laikas nekorektiški', NULL),
	(600, '37', 'priešlaikinis surinkimas', NULL),
	(600, '38', 'sąsaja užimta', NULL),
	(600, '39', 'nėra ryšio', NULL),
	(601, '30', 'Srovės perkrovos neutralėje pabaiga', NULL),
	(601, '31', 'Srovės perkrova neutralėje', NULL),
	(602, '30', 'RAM testavimo rezultatas nesėkmingas', NULL),
	(602, '31', 'RAM testavimo rezultatas sėkmingas', NULL),
	(603, '30', 'Atminties testavimo rezultatas nesėkmingas', NULL),
	(603, '31', 'Atminties testavimo rezultatas sėkmingas', NULL),
	(604, '30', 'CAN sąsaja atstatyta', NULL),
	(604, '31', 'CAN sąsajos klaida', NULL),
	(605, '30', 'Nenumatyta situacijos nėra', NULL),
	(605, '31', 'Nenumatyta situacija', NULL),
	(606, '100', 'Relės atjungimas pagal nustatymą, fazė B', NULL),
	(606, '101', 'Relės atjungimas pagal nustatymą, fazė C', NULL),
	(606, '102', 'Relės atjungimas ryšio kanalu, fazė A', NULL),
	(606, '103', 'Relės atjungimas ryšio kanalu, fazė B', NULL),
	(606, '104', 'Relės atjungimas ryšio kanalu, fazė C', NULL),
	(606, '105', 'Relės vietinio valdymo uždraudimas', NULL),
	(606, '106', 'Relės vietinio valdymo uždraudimas, fazė A', NULL),
	(606, '107', 'Relės vietinio valdymo uždraudimas, fazė B', NULL),
	(606, '108', 'Relės vietinio valdymo uždraudimas, fazė C', NULL),
	(606, '109', 'Relės įjungimas skaitiklio mygtuku, fazė A', NULL),
	(606, '110', 'Relės įjungimas skaitiklio mygtuku, fazė B', NULL),
	(606, '111', 'Relės įjungimas skaitiklio mygtuku, fazė C', NULL),
	(606, '112', 'Relės įjungimas pagal nustatymą', NULL),
	(606, '113', 'Relės įjungimas pagal nustatymą, fazė A', NULL),
	(606, '114', 'Relės įjungimas pagal nustatymą, fazė B', NULL),
	(606, '115', 'Relės įjungimas pagal nustatymą, fazė C', NULL),
	(606, '116', 'Relės įjungimas ryšio kanalu, fazė A', NULL),
	(606, '117', 'Relės įjungimas ryšio kanalu, fazė B', NULL),
	(606, '118', 'Relės įjungimas ryšio kanalu, fazė C', NULL),
	(606, '119', 'Relės vietinio valdymo leidimas', NULL),
	(606, '120', 'Relės vietinio valdymo leidimas, fazė A', NULL),
	(606, '121', 'Relės vietinio valdymo leidimas, fazė B', NULL),
	(606, '122', 'Relės vietinio valdymo leidimas, fazė C', NULL),
	(606, '30', 'atšaukti apkrovos valdymo pirmesnę komandą', NULL),
	(606, '31', 'išjungti 2 relę', NULL),
	(606, '3130', '2 relės įjungimo komanda įvykdyta', NULL),
	(606, '3131', '1 relės įjungimo komandos vykdymo laukimas', NULL),
	(606, '3132', '1 relės išjungimo komandos vykdymo laukimas', NULL),
	(606, '313233', 'Atjungtas likutinės energijos valdymas', NULL),
	(606, '313234', 'Įjungtas likutinės energijos valdymas', NULL),
	(606, '3133', '1 relės išjungimo komanda įvykdyta', NULL),
	(606, '3134', '1 relės įjungimo komanda įvykdyta', NULL),
	(606, '3135', 'Rankinis atsijungimas', NULL),
	(606, '3136', 'Rankinis pasijungimas', NULL),
	(606, '3137', 'Nuotolinis atsijungimas', NULL),
	(606, '3138', 'Nuotolinis pasijungimas', NULL),
	(606, '3139', 'Lokalus atsijungimas', NULL),
	(606, '32', 'įjungti/leisti 2 relės įjungimą', NULL),
	(606, '3230', 'Nuotolinis atsijungimas1', NULL),
	(606, '3231', 'Nuotolinis pasijungimas1', NULL),
	(606, '3232', 'Lokalus atsijungimas1', NULL),
	(606, '3233', 'Lokalus pasijungimas1', NULL),
	(606, '3234', 'Nuotolinis atsijungimas2', NULL),
	(606, '3235', 'Nuotolinis pasijungimas2', NULL),
	(606, '3236', 'Lokalus atsijungimas2', NULL),
	(606, '3237', 'Lokalus pasijungimas2', NULL),
	(606, '3238', 'užblokuoti', NULL),
	(606, '3239', 'išblokuoti', NULL),
	(606, '33', 'išjungti 1 relę', NULL),
	(606, '3330', 'nustatyti galios apribojimą', NULL),
	(606, '3331', 'nuimti galios apribojimą', NULL),
	(606, '3332', '1 - relės įjungimas pagal 1 tarifą', NULL),
	(606, '3333', '1 - relės įjungimas pagal 2 tarifą', NULL),
	(606, '3334', '1 - relės įjungimas pagal 3 tarifą', NULL),
	(606, '3335', '1 - relės įjungimas pagal 4 tarifą', NULL),
	(606, '3336', '1 - relės įjungimas pagal 5 tarifą', NULL),
	(606, '3337', '2 - relės įjungimas pagal 1 tarifą', NULL),
	(606, '3338', '2 - relės įjungimas pagal 2 tarifą', NULL),
	(606, '3339', '2 - relės įjungimas pagal 3 tarifą', NULL),
	(606, '34', 'įjungti/leisti 1 relės įjungimą', NULL),
	(606, '3430', '2 - relės įjungimas pagal 4 tarifą', NULL),
	(606, '3431', '2 - relės įjungimas pagal 5 tarifą', NULL),
	(606, '3432', '1 - Įjungimas SR ir VR ir išjungimas ĮVR po 1-os fazės įtampos limito viršijimo', NULL),
	(606, '3433', '1 - Įjungimas SR ir VR ir išjungimas ĮVR po 2-os fazės įtampos limito viršijimo', NULL),
	(606, '3434', '1 - Įjungimas SR ir VR ir išjungimas ĮVR po 3-os fazės įtampos limito viršijimo', NULL),
	(606, '3435', '1 - Įjungimas SR ir VR ir išjungimas ĮVR po visų fazių įtampos limitų viršijimo', NULL),
	(606, '3436', '1 - Įjungimas SR ir VR ir išjungimas ĮVR po bet kurios iš fazių įtampos limito viršijimo', NULL),
	(606, '3437', '1 - Įjungimas SR ir VR ir išjungimas ĮVR po P+ limito viršijimo', NULL),
	(606, '3439', '1 - Įjungimas SR ir VR ir išjungimas ĮVR po P- limito viršijimo', NULL),
	(606, '35', 'komandos vykdymas nereikalingas', NULL),
	(606, '3530', '1 - Įjungimas SR ir VR ir išjungimas ĮVR po Q+ limito viršijimo', NULL),
	(606, '3531', '1 - Įjungimas SR ir VR ir išjungimas ĮVR po Q- limito viršijimo', NULL),
	(606, '3532', '1 - Įjungimas SR ir VR ir išjungimas ĮVR po A+ limito viršijimo', NULL),
	(606, '3533', '1 - Įjungimas SR ir VR ir išjungimas ĮVR po A- limito viršijimo', NULL),
	(606, '3534', '1 - Įjungimas SR ir VR ir išjungimas ĮVR po R+ limito viršijimo', NULL),
	(606, '3535', '1 - Įjungimas SR ir VR ir išjungimas ĮVR po R- limito viršijimo', NULL),
	(606, '3536', '2 - Įjungimas SR ir VR ir išjungimas ĮVR po įtampos limito fazėje A viršijimo', NULL),
	(606, '3537', '2 - Įjungimas SR ir VR ir išjungimas ĮVR po įtampos limito fazėje B viršijimo', NULL),
	(606, '3538', '2 - Įjungimas SR ir VR ir išjungimas ĮVR po įtampos limito fazėje C viršijimo', NULL),
	(606, '3539', '2 - Įjungimas SR ir VR ir išjungimas ĮVR po įtampos limito visose fazėse viršijimo', NULL),
	(606, '36', '2 relės išjungimo komandos vykdymo laukimas', NULL),
	(606, '3630', '2 - Įjungimas SR ir VR ir išjungimas ĮVR po įtampos limito bet kokioje fazėje viršijimo', NULL),
	(606, '3631', '2 - Įjungimas SR ir VR ir išjungimas ĮVR po P+ limito viršijimo', NULL),
	(606, '3633', '2 - Įjungimas SR ir VR ir išjungimas ĮVR po P- limito viršijimo', NULL),
	(606, '3634', '2 - Įjungimas SR ir VR ir išjungimas ĮVR po Q+ limito viršijimo', NULL),
	(606, '3635', '2 - Įjungimas SR ir VR ir išjungimas ĮVR po Q- limito viršijimo', NULL),
	(606, '3636', '2 - Įjungimas SR ir VR ir išjungimas ĮVR po A+ limito viršijimo', NULL),
	(606, '3637', '2 - Įjungimas SR ir VR ir išjungimas ĮVR po A- limito viršijimo', NULL),
	(606, '3638', '2 - Įjungimas SR ir VR ir išjungimas ĮVR po R+ limito viršijimo', NULL),
	(606, '3639', '2 - Įjungimas SR ir VR ir išjungimas ĮVR po R- limito viršijimo', NULL),
	(606, '37', '2 relės įjungimo komandos vykdymo laukimas', NULL),
	(606, '3737', 'Relay_1_Prepare_for_Off', NULL),
	(606, '3738', 'Relay_1_Execute_Off', NULL),
	(606, '3739', 'Relay_1_Cancel_Off', NULL),
	(606, '38', 'klaida vykdant komandą', NULL),
	(606, '3830', 'Relay_1_Prepare_for_On', NULL),
	(606, '3831', 'Relay_1_Execute_On', NULL),
	(606, '3832', 'Relay_1_Cancel_On', NULL),
	(606, '3833', 'Relay_2_Prepare_for_Off', NULL),
	(606, '3834', 'Relay_2_Execute_Off', NULL),
	(606, '3835', 'Relay_2_Cancel_Off', NULL),
	(606, '3836', 'Relay_2_Prepare_for_On', NULL),
	(606, '3837', 'Relay_2_Execute_On', NULL),
	(606, '3838', 'Relay_2_Cancel_On', NULL),
	(606, '3839', 'Relay_3_Prepare_for_Off', NULL),
	(606, '39', '2 relės išjungimo komanda įvykdyta', NULL),
	(606, '3930', 'Relay_3_Execute_Off', NULL),
	(606, '3931', 'Relay_3_Cancel_Off', NULL),
	(606, '3932', 'Relay_3_Prepare_for_On', NULL),
	(606, '3933', 'Relay_3_Execute_On', NULL),
	(606, '3934', 'Relay_32_Cancel_On', NULL),
	(606, '95', 'Relės atjungimas skaitiklio mygtuku, fazė A', NULL),
	(606, '96', 'Relės atjungimas skaitiklio mygtuku, fazė B', NULL),
	(606, '97', 'Relės atjungimas skaitiklio mygtuku, fazė C', NULL),
	(606, '98', 'Relės atjungimas pagal nustatymą', NULL),
	(606, '99', 'Relės atjungimas pagal nustatymą, fazė A', NULL),
	(607, '30', 'įrašymas nereikalingas', NULL),
	(607, '31', 'įrašymo laukimas', NULL),
	(607, '32', 'įrašymas sėkmingas', NULL),
	(607, '33', 'įrašymo klaida', NULL),
	(607, '34', 'vykdomas įrašymas', NULL),
	(608, '30', 'pradžia', NULL),
	(608, '31', 'atšaukimas', NULL),
	(608, '3130', 'įrašymas nereikalingas', NULL),
	(608, '3131', 'įrašymo klaida', NULL),
	(608, '32', 'nebuvo vykdomas', NULL),
	(608, '33', 'laukia vykdymo', NULL),
	(608, '34', 'vykdomas', NULL),
	(608, '35', 'vykdomas atšaukimas', NULL),
	(608, '36', 'sustabdytas vartotojo', NULL),
	(608, '37', 'sustabdytas dėl konfigūracijos keitimų', NULL),
	(608, '38', 'nėra skaitm. sąsajos skaitiklių, kuriems reikia įrašyti slaptažodžius', NULL),
	(608, '39', 'įvykdyta sėkmingai', NULL),
	(609, '30', 'užduotis nebuvo vykdoma:užduotis nesuformuota', NULL),
	(609, '31', 'užduotis nebuvo vykdoma:užduotis įvykdyta', NULL),
	(609, '32', 'užduotis nebuvo vykdoma:užduotis laukia vykdymo', NULL),
	(609, '33', 'užduotis nebuvo vykdoma:užduotis vykdoma', NULL),
	(609, '34', 'užduotis buvo vykdoma:užduotis nesuformuota', NULL),
	(609, '35', 'užduotis buvo vykdoma:užduotis įvykdyta', NULL),
	(609, '36', 'užduotis buvo vykdoma:užduotis laukia vykdymo', NULL),
	(609, '37', 'užduotis buvo vykdoma:užduotis vykdoma', NULL),
	(610, '30', 'RS232', NULL),
	(610, '31', 'RS485-1', NULL),
	(610, '32', 'RS485-2', NULL),
	(610, '33', 'CAN', NULL),
	(610, '34', 'nėra sąsajų', NULL),
	(610, '35', 'visi', NULL),
	(611, '30', 'sąsaja neaktyvi', NULL),
	(611, '31', 'tiesioginis jungimas', NULL),
	(611, '32', 'HAYES-modemas', NULL),
	(612, '30', 'protokolas «CE_A»', NULL),
	(612, '32', 'protokolas «Sicon C1»', NULL),
	(612, '35', 'duomenų rinkimas iš skaitm. sąsajos skaitiklio', NULL),
	(613, '30', 'nėra kontrolės', NULL),
	(613, '31', 'nelyginumo kontrolė', NULL),
	(613, '32', 'lyginumo kontrolė', NULL),
	(614, '30', 'išjungta', NULL),
	(614, '31', 'per RS-232 iki RS-485-1', NULL),
	(614, '32', 'per CAN iki RS-485-1', NULL),
	(614, '33', 'per RS-232 iki RS-485-2', NULL),
	(614, '34', 'per CAN iki RS-485-2', NULL),
	(614, '35', 'per RS232 iki CAN', NULL),
	(615, '30', 'IDC (būsenos pasiketiomo registavimas)', NULL),
	(615, '31', 'elektros skaitiklis su impulsų išėjimu', NULL),
	(615, '32', 'vandens skaitiklis su impulsų išėjimu', NULL),
	(615, '33', 'dujų skaitiklis su impulsų išėjimu', NULL),
	(615, '34', 'šilumos skaitiklis su impulsų išėjimu', NULL),
	(616, '30', 'be registavimo', NULL),
	(616, '31', 'kontakto jungimas (log. «0» )', NULL),
	(616, '32', 'kontakto nutraukimas  (log. «1»)', NULL),
	(616, '33', 'kontakto būsenos keitimas', NULL),
	(617, '30', 'nėra', NULL),
	(617, '31', 'CE301', NULL),
	(617, '32', 'CE303', NULL),
	(617, '33', 'CE102 R5/S6/S7/R8/R8Q', NULL),
	(617, '34', 'CE6850M versijos 1.6 ir 2.2', NULL),
	(617, '35', 'CE102 S7 J.', NULL),
	(617, '36', 'CE301M', NULL),
	(617, '37', 'CE201', NULL),
	(617, '38', 'CE102 S7 J versija 10', NULL),
	(617, '39', 'CE301M versija 10', NULL),
	(618, '30', 'nėra', NULL),
	(618, '31', 'tiesioginis sujungimas', NULL),
	(618, '32', 'CE831', NULL),
	(618, '33', 'CE832', NULL),
	(618, '34', 'CE833', NULL),
	(618, '35', 'CE834', NULL),
	(618, '36', 'CE832C5', NULL),
	(619, '30', 'tik skaitymas', NULL),
	(619, '31', 'skaitymas ir rašymas', NULL),
	(619, '32', 'tik rašymas', NULL),
	(620, '30', 'jungimas per HAYES-modemą', NULL),
	(620, '31', 'tiesioginis jungimas', NULL),
	(621, '30', 'impulsinis', NULL),
	(621, '31', 'toninis', NULL),
	(622, '30', 'nėra', NULL),
	(622, '31', 'modulis VDK', NULL),
	(623, '30', '40 bitų (9 skaičių po kablelio)', NULL),
	(623, '31', '64 bitų (15 skaičių po kablelio)', NULL),
	(624, '30', 'ryšio kanalai nenaudojami', NULL),
	(624, '31', 'ryšys per CE833', NULL),
	(624, '32', 'ryšys per CE834', NULL),
	(625, '30', 'aperiodinis', NULL),
	(625, '31', 'minutės', NULL),
	(625, '32', 'valandos', NULL),
	(625, '33', 'paros', NULL),
	(625, '34', 'mėnesiai', NULL),
	(625, '35', 'metai', NULL),
	(626, '30', 'nėra', NULL),
	(626, '31', 'vartotojas', NULL),
	(626, '32', 'administratorius', NULL),
	(626, '33', 'sisteminis administratorius', NULL),
	(627, '30', 'nėra', NULL),
	(627, '31', 'impulsinis', NULL),
	(627, '32', 'skaitmeninis', NULL),
	(628, '31', 'Aktyvioji suvartota energija, kWh', NULL),
	(628, '3130', 'Dabartinė įtampos vertė fazėje B, V', NULL),
	(628, '3131', 'Dabartinė įtampos vertė fazėje C, V', NULL),
	(628, '3132', 'Kampas tarp įtampų (A ir B fazių), °', NULL),
	(628, '3133', 'Kampas tarp įtampų (B ir C fazių), °', NULL),
	(628, '3134', 'Kampas tarp įtampų (C ir A fazių), °', NULL),
	(628, '3135', 'Dabartinė srovės stiprumo vertė fazėje A, A', NULL),
	(628, '3136', 'Dabartinė srovės stiprumo vertė fazėje B, A', NULL),
	(628, '3137', 'Dabartinė srovės stiprumo vertė fazėje C, A', NULL),
	(628, '3138', 'Kampas tarp srovės ir įtampos fazėje A, °', NULL),
	(628, '3139', 'Kampas tarp srovės ir įtampos fazėje B, °', NULL),
	(628, '32', 'Aktyvioji atiduota energija, kWh', NULL),
	(628, '3230', 'Kampas tarp srovės ir įtampos fazėje C, °', NULL),
	(628, '3231', 'Aktyvioji galia fazėje A, kW', NULL),
	(628, '3232', 'Aktyvioji galia fazėje B, kW', NULL),
	(628, '3233', 'Aktyvioji galia fazėje C, kW', NULL),
	(628, '3234', 'Aktyvioji galia suminė, kW', NULL),
	(628, '3235', 'Aktyvioji suvartota galia suminė, kW', NULL),
	(628, '3236', 'Aktyvioji atiduota galia suminė, kW', NULL),
	(628, '3237', 'Reaktyvioji galia fazėje A, kVar', NULL),
	(628, '3238', 'Reaktyvioji galia fazėje B, kVar', NULL),
	(628, '3239', 'Reaktyvioji galia fazėje C, kVar', NULL),
	(628, '33', 'Reaktyvioji suvartota energija, kVarh', NULL),
	(628, '3330', 'Reaktyvioji galia suminė, kVar', NULL),
	(628, '3331', 'Reaktyvioji suvartota galia suminė, kVar', NULL),
	(628, '3332', 'Reaktyvioji atiduota galia suminė, kVar', NULL),
	(628, '3333', 'Pilnoji galia fazėje A, kVA', NULL),
	(628, '3334', 'Pilnoji galia fazėje B, kVA', NULL),
	(628, '3335', 'Pilnoji galia fazėje C, kVA', NULL),
	(628, '3336', 'Pilnoji galia suminė, kVA', NULL),
	(628, '3337', 'Aktyvioji nuostolių galia fazėje A, kW', NULL),
	(628, '3338', 'Aktyvioji nuostolių galia fazėje B, kW', NULL),
	(628, '3339', 'Aktyvioji nuostolių galia fazėje C, kW', NULL),
	(628, '34', 'Reaktyvioji atiduota energija, kVarh', NULL),
	(628, '3430', 'Aktyvioji nuostolių galia suminė, kW', NULL),
	(628, '3431', 'Aktyviosios galios koeficientas fazėje A', NULL),
	(628, '3432', 'Aktyviosios galios koeficientas fazėje B', NULL),
	(628, '3433', 'Aktyviosios galios koeficientas fazėje C', NULL),
	(628, '3434', 'Aktyviosios suminės galios koeficientas', NULL),
	(628, '3435', 'Reaktyviosios galios koeficientas fazėje A', NULL),
	(628, '3436', 'Reaktyviosios galios koeficientas fazėje B', NULL),
	(628, '3437', 'Reaktyviosios galios koeficientas fazėje C', NULL),
	(628, '3438', 'Reaktyviosios suminės galios koeficientas', NULL),
	(628, '3439', 'Dažnis, Hz', NULL),
	(628, '3530', 'Tiekiamo termof. vandens masės kiekis', NULL),
	(628, '3531', 'Grįžtamo termof. vandens masės kiekis', NULL),
	(628, '3532', 'Tiekiamo termof. vandens tūrio kiekis', NULL),
	(628, '3533', 'Grįžtamo termof. vandens tūrio kiekis', NULL),
	(628, '3534', 'Tiekiamo termof. vandens temperatūra', NULL),
	(628, '3535', 'Grįžtamo termof. vandens temperatūra', NULL),
	(628, '3536', 'Tiekiamo termof. vandens slėgis', NULL),
	(628, '3537', 'Grįžtamo termof. vandens slėgis', NULL),
	(628, '3538', 'Tiekiamo karšto vandens tūrio kiekis', NULL),
	(628, '3539', 'Tiekiamo karšto vandens masės kiekis', NULL),
	(628, '3630', 'Tiekiamo karšto vandens šilumos kiekis', NULL),
	(628, '3631', 'Tiekiamo karšto vandens temperatūra', NULL),
	(628, '3632', 'Grįžtamo karšto vandens temperatūra', NULL),
	(628, '39', 'Dabartinė įtampos vertė fazėje A, V', NULL),
	(629, '30', 'integralinis', NULL),
	(629, '31', 'dydis per intervalą', NULL),
	(629, '32', 'momentinis', NULL),
	(630, '30', 'duomenys nuskaitomi iš duomenų šaltinio', NULL),
	(630, '31', 'duomenys skaičiuojami pagal duomenų profilį-šaltinį', NULL),
	(631, '30', 'nėra', NULL),
	(631, '31', 'profilio duomenų surinkimas', NULL),
	(631, '32', 'laiko sinchronizacija', NULL),
	(631, '33', 'savitikra', NULL),
	(632, 'IEC62056_21_Mode_A', 'IEC62056_21_Mode_A', NULL),
	(632, 'IEC62056_21_Mode_C', 'IEC62056_21_Mode_C', NULL),
	(633, '1200', '1200', NULL),
	(633, '19200', '19200', NULL),
	(633, '2400', '2400', NULL),
	(633, '300', '300', NULL),
	(633, '4800', '4800', NULL),
	(633, '600', '600', NULL),
	(633, '9600', '9600', NULL),
	(634, '173', 'ZE 311.DR per DKEG', NULL),
	(634, '174', 'VALSENA DKEG-2', NULL),
	(635, '1', 'PLM-kartotuvas (tiltas)', NULL),
	(635, '10', 'RiM 315.02', NULL),
	(635, '11', 'RiM 515', NULL),
	(635, '12', 'RiM 586', NULL),
	(635, '13', 'RiM 615', NULL),
	(635, '14', 'RiM 789', NULL),
	(635, '15', 'RiM 109.02', NULL),
	(635, '16', 'konverteris rs485-PLM', NULL),
	(635, '17', 'trifazis 3 tarifų su rs485', NULL),
	(635, '18', 'trifazis 3 tarifų su rs485 (RiM 432)', NULL),
	(635, '19', 'trifazis 8 tarifų su rs485 (RiM 889)', NULL),
	(635, '2', 'PLM-koncentratorius su rs485', NULL),
	(635, '20', 'vienfazis 3 tarifų su radio', NULL),
	(635, '21', 'trifazis 3 tarifų su radio', NULL),
	(635, '22', 'trifazis 3 tarifų (DR) su radio', NULL),
	(635, '23', 'trifazis 3 tarifų (ZDR) su radio', NULL),
	(635, '24', 'vienfazis 1 tarifo su radio', NULL),
	(635, '25', 'RiM 532', NULL),
	(635, '26', 'RiM 732', NULL),
	(635, '27', 'Radio-koncentratorius su radio', NULL),
	(635, '28', 'valdiklis', NULL),
	(635, '29', 'Vienfazis 8 tarifų su RFPLC (RiM 181.01)', NULL),
	(635, '3', 'PLM- koncentratorius su radio', NULL),
	(635, '30', 'Vienfazis 8 tarifų su RFPLC (RiM 181.02)', NULL),
	(635, '31', 'Vienfazis 8 tarifų su RFPLC (RiM 189.01)', NULL),
	(635, '32', 'Vienfazis 8 tarifų su RFPLC (RiM 289.01)', NULL),
	(635, '33', 'Vienfazis 8 tarifų su RFPLC (RiM 489.01)', NULL),
	(635, '34', 'Vienfazis 8 tarifų su RFPLC (RiM 189.02)', NULL),
	(635, '35', 'Vienfazis 8 tarifų su RFPLC (RiM 289.02)', NULL),
	(635, '36', 'Trifazis 8 tarifų su RFPLC (RiM 489.02)', NULL),
	(635, '37', 'Konverteris PLC-RS485 skaitikliui RiM 889.xx', NULL),
	(635, '38', 'MKC', NULL),
	(635, '4', 'vienfazis 1 tarifo su PLM (RiM 115.01)', NULL),
	(635, '5', 'trifazis 1 tarifo su PLM (RiM 415.01)', NULL),
	(635, '6', 'vienfazis 3 tarifų su PLM', NULL),
	(635, '7', 'trifazis 8 tarifų su PLM (RiM 485)', NULL),
	(635, '8', 'RiM 109', NULL),
	(635, '9', 'RiM 115.02', NULL),
	(636, 'DoubleLong', 'DoubleLong', NULL),
	(636, 'DoubleLongUnsigned', 'DoubleLongUnsigned', NULL),
	(636, 'Enum', 'Enum', NULL),
	(636, 'Integer', 'Integer', NULL),
	(636, 'Long', 'Long', NULL),
	(636, 'Long64', 'Long64', NULL),
	(636, 'Long64Unsigned', 'Long64Unsigned', NULL),
	(636, 'LongUnsigned', 'LongUnsigned', NULL),
	(636, 'Unsigned', 'Unsigned', NULL),
	(637, '1', 'HXE12AS', NULL),
	(637, '2', 'HXE34AS', NULL),
	(637, '3', 'HXE12AS vienfazis skaitiklis', NULL),
	(638, '30', '12 V įtampa žemiau normos ribos', NULL),
	(638, '31', '12 V įtampa normos ribose', NULL),
	(639, '30', 'Įtampos dingimo grįžimas į ribą fazėje A', NULL),
	(639, '31', 'Įtampos dingimo viršutinės ribos peržengimas fazėje A', NULL),
	(640, '30', 'Įtampos dingimo grįžimas į ribą fazėje B', NULL),
	(640, '31', 'Įtampos dingimo viršutinės ribos peržengimas fazėje B', NULL),
	(641, '30', 'Įtampos dingimo grįžimas į ribą fazėje C', NULL),
	(641, '31', 'Įtampos dingimo viršutinės ribos peržengimas fazėje C', NULL),
	(642, '30', 'tg(fi) grįžimas į ribą fazėje ?', NULL),
	(642, '31', 'tg(fi) viršutinės ribos peržengimas fazėje ?', NULL),
	(643, '30', 'tg(fi) grįžimas į ribą fazėje B', NULL),
	(643, '31', 'tg(fi) viršutinės ribos peržengimas fazėje B', NULL),
	(644, '30', 'tg(fi) grįžimas į ribą fazėje C', NULL),
	(644, '31', 'tg(fi) viršutinės ribos peržengimas fazėje C', NULL),
	(645, '152', 'Ekomera EA52grn/1', NULL),
	(645, '174', 'Valsena DKEG-2', NULL),
	(646, '30', 'Atvirkštinės krypties tėkmė išnyko', NULL),
	(646, '31', 'Atvirkštinės krypties tėkmė aptikta', NULL),
	(647, '30', 'Skaitiklio kleminio dangčio uždarymas ', NULL),
	(647, '31', 'Skaitiklio kleminio dangčio atidarymas ', NULL),
	(648, '31', 'foninis', NULL),
	(648, '32', 'žemiausias', NULL),
	(648, '33', 'žemas', NULL),
	(648, '34', 'normalus', NULL),
	(648, '35', 'aukštas', NULL),
	(648, '36', 'aukščiausias', NULL),
	(648, '37', 'kritinis pagal laiką', NULL),
	(648, '38', 'realaus laiko', NULL),
	(649, '0', 'Nesaugoti', NULL),
	(649, '1', 'Pagal realaus laiko matavimų nuskaitymo profilį', NULL),
	(649, '2', 'Saugoti visų matavimų paskutines reikšmes', NULL),
	(650, '30', 'Išjungtas, įjungimas pultu uždraustas', NULL),
	(650, '31', 'Išjungtas, įjungimas pultu leistas', NULL),
	(650, '32', 'Įjungtas, išungimas pultu uždraustas', NULL),
	(650, '33', 'Įjungtas, išungimas pultu leistas', NULL),
	(651, '30', 'Suvartojimas normoje', NULL),
	(651, '31', 'Nuotolinio galios daviklio suvartojimas didesnis nei bazinio bloko suvartojimas', NULL),
	(651, '32', 'Nuotolinio galios daviklio suvartojimas mažesnis nei bazinio bloko suvartojimas', NULL),
	(652, '0', 'Originali duomenų data', NULL),
	(652, '1', 'Duomenų datos poslinkis viena diena atgal', NULL),
	(653, '30', 'Relė nr.3 išjungta', NULL),
	(653, '31', 'Relė nr.3 įjungta', NULL),
	(654, '30', 'Tiesioginė prieiga suteikta', NULL),
	(654, '31', 'Tiesioginė prieiga uždrausta', NULL),
	(654, '32', 'Laukiama tiesioginės prieigos suteikimo', NULL),
	(655, '0', 'RS232', NULL),
	(655, '1', 'RS485_1', NULL),
	(655, '2', 'RS485_2', NULL),
	(655, '3', 'CAN', NULL),
	(656, '30', 'Kreditas buvo 0 ir buvo padidintas', NULL),
	(656, '31', 'Kreditas pasiekė 0', NULL),
	(657, '30', 'Išnyko galios disbalansas (3 fazėse)', NULL),
	(657, '31', 'Aptiktas galios disbalansas (3 fazėse)', NULL),
	(658, '30', 'Išnyko įtampos disbalansas', NULL),
	(658, '31', 'Aptiktas įtampos disbalansas', NULL),
	(659, '30', 'Išnyko temperatūros viršijimas', NULL),
	(659, '31', 'Aptiktas temperatūros viršijimas', NULL),
	(660, '30', 'Išnyko temperatūros sumažėjimas', NULL),
	(660, '31', 'Aptiktas temperatūros sumažėjimas', NULL),
	(661, '30', 'Išnyko aktyvios galios viršijimas', NULL),
	(661, '31', 'Aptiktas aktyvios galios viršijimas', NULL),
	(662, '30', 'Fazėje A išnyko aktyvios galios viršijimas', NULL),
	(662, '31', 'Fazėje A aptiktas aktyvios galios viršijimas', NULL),
	(663, '30', 'Fazėje B išnyko aktyvios galios viršijimas', NULL),
	(663, '31', 'Fazėje B aptiktas aktyvios galios viršijimas', NULL),
	(664, '30', 'Fazėje C išnyko aktyvios galios viršijimas', NULL),
	(664, '31', 'Fazėje C aptiktas aktyvios galios viršijimas', NULL),
	(665, '30', 'Išnyko reaktyvios galios viršijimas', NULL),
	(665, '31', 'Aptiktas reaktyvios galios viršijimas', NULL),
	(666, '30', 'Fazėje A išnyko reaktyvios galios viršijimas', NULL),
	(666, '31', 'Fazėje A aptiktas reaktyvios galios viršijimas', NULL),
	(667, '30', 'Fazėje B išnyko reaktyvios galios viršijimas', NULL),
	(667, '31', 'Fazėje B aptiktas reaktyvios galios viršijimas', NULL),
	(668, '30', 'Fazėje C išnyko reaktyvios galios viršijimas', NULL),
	(668, '31', 'Fazėje C aptiktas aktyreaktyviosvios galios viršijimas', NULL),
	(669, '30', 'Išnyko galios koeficiento (imp) sumažėjimas', NULL),
	(669, '31', 'Aptiktas galios koeficiento (imp) sumažėjimas', NULL),
	(670, '30', 'Fazėje A išnyko galios koeficiento (imp) sumažėjimas', NULL),
	(670, '31', 'Fazėje A aptiktas galios koeficiento (imp) sumažėjimas', NULL),
	(671, '30', 'Fazėje B išnyko galios koeficiento (imp) sumažėjimas', NULL),
	(671, '31', 'Fazėje B aptiktas galios koeficiento (imp) sumažėjimas', NULL),
	(672, '30', 'Fazėje C išnyko galios koeficiento (imp) sumažėjimas', NULL),
	(672, '31', 'Fazėje C aptiktas galios koeficiento (imp) sumažėjimas', NULL),
	(673, '30', 'STS režimas išjungtas', NULL),
	(673, '31', 'STS režimas įjungtas', NULL),
	(674, '30', 'Išnyko AB kampo reikšmės viršijimas', NULL),
	(674, '31', 'Aptiktas AB kampo reikšmės viršijimas', NULL),
	(675, '30', 'Išnyko AB kampo reikšmės sumažejimas', NULL),
	(675, '31', 'Aptiktas AB kampo reikšmės sumažejimas', NULL),
	(676, '30', 'Išnyko AC kampo reikšmės viršijimas', NULL),
	(676, '31', 'Aptiktas AC kampo reikšmės viršijimas', NULL),
	(677, '30', 'Išnyko AC kampo reikšmės sumažejimas', NULL),
	(677, '31', 'Aptiktas AC kampo reikšmės sumažejimas', NULL),
	(678, '30', 'Išnyko galios koeficiento (exp) sumažėjimas', NULL),
	(678, '31', 'Aptiktas galios koeficiento (exp) sumažėjimas', NULL),
	(679, '30', 'Fazėje A išnyko galios koeficiento (exp) sumažėjimas', NULL),
	(679, '31', 'Fazėje A aptiktas galios koeficiento (exp) sumažėjimas', NULL),
	(680, '30', 'Fazėje B išnyko galios koeficiento (exp) sumažėjimas', NULL),
	(680, '31', 'Fazėje B aptiktas galios koeficiento (exp) sumažėjimas', NULL),
	(681, '30', 'Fazėje C išnyko galios koeficiento (exp) sumažėjimas', NULL),
	(681, '31', 'Fazėje C aptiktas galios koeficiento (exp) sumažėjimas', NULL),
	(682, '30', 'LV modemas rastas ir sėkmingai sukonfigūruotas', NULL),
	(682, '31', 'LV modemas nerastas', NULL),
	(683, '30', 'LV ryšys rastas', NULL),
	(683, '31', 'LV ryšys nerastas', NULL),
	(684, '30', 'GPRS modemas rastas ir sėkmingai sukonfigūruotas', NULL),
	(684, '31', 'GPRS modemas nerastas', NULL),
	(685, '30', 'GPRS ryšys rastas', NULL),
	(685, '31', 'GPRS ryšys nerastas', NULL),
	(686, '1', 'CE102_S6', NULL),
	(686, '2', 'CE102_S7', NULL),
	(686, '3', 'CE102_S7J', NULL),
	(686, '4', 'CE102_R5', NULL),
	(686, '5', 'CE102_R8', NULL),
	(686, '6', 'CE102_R8Q', NULL),
	(686, '7', 'CE301M_S31', NULL),
	(686, '8', 'CE301M_R33', NULL),
	(689, '0', 'Išjungti skaitiklių numerių tikrinimą', NULL),
	(689, '1', 'Įjungti skaitiklių numerių tikrinimą', NULL),
	(690, '0', 'Momentinių duomenų nuskaitymas', NULL),
	(690, '1', 'Stop kadrų nuskaitymas', NULL),
	(691, '30', 'Savaitgalių tarifikavimo išjungimas', NULL),
	(691, '31', 'Savaitgalių tarifikavimo įjungimas', NULL),
	(692, '30', 'Automatinio vasaros/žiemos laiko pervedimo išjungimas', NULL),
	(692, '31', 'Automatinio vasaros/žiemos laiko pervedimo įjungimas', NULL),
	(693, '30', 'Relės suveikimo išjungimas viršijant energijos ribą', NULL),
	(693, '31', 'Relės suveikimo įjungimas viršijant energijos ribą', NULL),
	(694, '30', 'Relės suveikimo išjungimas viršijant galios ribą', NULL),
	(694, '31', 'Relės suveikimo įjungimas viršijant galios ribą', NULL),
	(695, '30', 'Relės suveikimo išjungimas viršijant suminės energijos ribą', NULL),
	(695, '31', 'Relės suveikimo įjungimas viršijant suminės energijos ribą', NULL),
	(696, '30', 'Sąsajos užblokavimo išjungimas įvedant 3 neteisingus slaptažodžius', NULL),
	(696, '31', 'Sąsajos užblokavimo įjungimas įvedant 3 neteisingus slaptažodžius', NULL),
	(697, '30', 'nežinoma', NULL),
	(697, '31', 'tiesioginio įjungimo', NULL),
	(697, '32', 'įjungimo per transformatorių', NULL),
	(697, '33', 'trifazė keturių laidų', NULL),
	(697, '34', 'trifazė trijų laidų', NULL),
	(697, '35', 'Clou CL7331 demo mode', NULL),
	(698, '30', 'Datos keitimosi meridianas (vakarų)', NULL),
	(698, '31', 'Midvėjus, Samoa', NULL),
	(698, '3130', 'Centrinė Amerika', NULL),
	(698, '3131', 'Centrinis laikas (JAV ir Kanada)', NULL),
	(698, '3132', 'Bogota, Lima, Kitas', NULL),
	(698, '3133', 'Rytų laikas (JAV ir Kanada)', NULL),
	(698, '3134', 'Indiana (Rytai)', NULL),
	(698, '3135', 'Atlantinis laikas (Kanada)', NULL),
	(698, '3136', 'Karakasas, La Pazas', NULL),
	(698, '3137', 'Santjagas', NULL),
	(698, '3138', 'Niūfaundlendas', NULL),
	(698, '3139', 'Brazilija', NULL),
	(698, '32', 'Havajai', NULL),
	(698, '3230', 'Buenos Aires, Džordžtaunas', NULL),
	(698, '3231', 'Grenlandija', NULL),
	(698, '3232', 'Vidutinės laikas', NULL),
	(698, '3233', 'Azorų salos', NULL),
	(698, '3234', 'Žaliojo Kyšulio salos', NULL),
	(698, '3235', 'Dublinas, Londonas, Lisabona, Edinburgas', NULL),
	(698, '3236', 'Kasablanka, Monrovija', NULL),
	(698, '3237', 'Amsterdamas, Berlynas, Bernas, Viena, Roma, Stokholmas', NULL),
	(698, '3238', 'Belgradas, Bratislava, Budapeštas, Liublijana, Praha', NULL),
	(698, '3239', 'Briuselis, Kopenhaga, Madridas, Paryžius', NULL),
	(698, '33', 'Aliaska', NULL),
	(698, '3330', 'Varšuva, Zagrebas, Sarajevas, Skopjė', NULL),
	(698, '3331', 'Vakarų Vidurio Afrika', NULL),
	(698, '3332', 'Atėnai, Beirutas, Kijevas, Minskas, Stambulas', NULL),
	(698, '3333', 'Bukareštas', NULL),
	(698, '3334', 'Vilnius, Kijevas, Ryga, Sofija, Talinas, Helsinkis', NULL),
	(698, '3335', 'Jeruzalė', NULL),
	(698, '3336', 'Kairas', NULL),
	(698, '3337', 'Hararė, Pretorija', NULL),
	(698, '3338', 'Bagdadas', NULL),
	(698, '3339', 'Kuveitas, Rijadas', NULL),
	(698, '34', 'Ramiojo vandenyno laikas (JAV ir Kanada), Tijuana', NULL),
	(698, '3430', 'Maskva, Sankt Peterburgas, Volgogradas', NULL),
	(698, '3431', 'Nairobis', NULL),
	(698, '3432', 'Teheranas', NULL),
	(698, '3433', 'Abu Dabis, Muskatas', NULL),
	(698, '3434', 'Jerevanas, Baku, Tbilisis', NULL),
	(698, '3435', 'Kabulas', NULL),
	(698, '3436', 'Jekaterinburgas', NULL),
	(698, '3437', 'Islamabadas, Karačis, Taškentas', NULL),
	(698, '3438', 'Madras, Bombėjus, Kalkuta, Naujasis Delis', NULL),
	(698, '3439', 'Katmandu', NULL),
	(698, '35', 'Arizona', NULL),
	(698, '3530', 'Astana, Dhaka', NULL),
	(698, '3531', 'Omskas, Novosibirskas, Alma-Ata', NULL),
	(698, '3532', 'Šri Dzhayavardenepura', NULL),
	(698, '3533', 'Rangūnas', NULL),
	(698, '3534', 'Bankokas, Džakarta, Hanojus', NULL),
	(698, '3535', 'Krasnojarskas', NULL),
	(698, '3536', 'Honkongas, Pekinas, Urumčis', NULL),
	(698, '3537', 'Irkutskas, Ulan-Batoras', NULL),
	(698, '3538', 'Kvala Lumpūras, Singapūras', NULL),
	(698, '3539', 'Pertas', NULL),
	(698, '36', 'Kalnų laikas (JAV ir Kanada)', NULL),
	(698, '3630', 'Taipėjus', NULL),
	(698, '3631', 'Osaka, Saporas, Tokijas', NULL),
	(698, '3632', 'Seulas, Pietų Korėja', NULL),
	(698, '3633', 'Jakutskas', NULL),
	(698, '3634', 'Adelaidė', NULL),
	(698, '3635', 'Darvinas', NULL),
	(698, '3636', 'Brisbenas', NULL),
	(698, '3637', 'Vladivostokas', NULL),
	(698, '3638', 'Guamas, Port Morsbis', NULL),
	(698, '3639', 'Kanbera, Melburnas, Sidnėjus', NULL),
	(698, '37', 'La Pazas, Mizatlan, Čihuahua', NULL),
	(698, '3730', 'Hobartas', NULL),
	(698, '3731', 'Magadano, Sachalino Island, Saliamono Salos', NULL),
	(698, '3732', 'Kamčiatka, Fidžis, Maršalo salos', NULL),
	(698, '3733', 'Auckland, Wellington', NULL),
	(698, '3734', 'Nuku-Alofis', NULL),
	(698, '3735', 'Nėra', NULL),
	(698, '38', 'Gvadalachara, Meksika, Monterrey', NULL),
	(698, '39', 'Saskačevanas', NULL),
	(699, '1', 'Mercury 230 AR', NULL),
	(699, '2', 'Mercury 230 ART2', NULL),
	(699, '3', 'Mercury 234 ART', NULL),
	(700, '30', 'Nieko neatvaizduoja', NULL),
	(700, '31', 'Energijos ribos indikacija', NULL),
	(700, '3130', 'Papildomo sąsajos modulio greitis', NULL),
	(700, '313030', 'T6 energijos parodymai už 2 praeitus mėnesius', NULL),
	(700, '313031', 'T6 energijos parodymai už 3 praeitus mėnesius', NULL),
	(700, '313032', 'T6 energijos parodymai už 4 praeitus mėnesius', NULL),
	(700, '313033', 'T6 energijos parodymai už 5 praeitus mėnesius', NULL),
	(700, '313034', 'T6 energijos parodymai už 6 praeitus mėnesius', NULL),
	(700, '313035', 'T6 energijos parodymai už 7 praeitus mėnesius', NULL),
	(700, '313036', 'T6 energijos parodymai už 8 praeitus mėnesius', NULL),
	(700, '313037', 'T6 energijos parodymai už 9 praeitus mėnesius', NULL),
	(700, '313038', 'T6 energijos parodymai už 10 praeitų mėnesių', NULL),
	(700, '313039', 'T6 energijos parodymai už 11 praeitų mėnesių', NULL),
	(700, '3131', 'Optinės sąsajos greitis', NULL),
	(700, '313130', 'T6 energijos parodymai už 12 praeitų mėnesių', NULL),
	(700, '313131', 'T6 energijos parodymai už 13 praeitų mėnesių', NULL),
	(700, '313132', 'Dabartiniai T7 energijos parodymai', NULL),
	(700, '313133', 'T7 energijos parodymai už praeitą mėnesį', NULL),
	(700, '313134', 'T7 energijos parodymai už 2 praeitus mėnesius', NULL),
	(700, '313135', 'T7 energijos parodymai už 3 praeitus mėnesius', NULL),
	(700, '313136', 'T7 energijos parodymai už 4 praeitus mėnesius', NULL),
	(700, '313137', 'T7 energijos parodymai už 5 praeitus mėnesius', NULL),
	(700, '313138', 'T7 energijos parodymai už 6 praeitus mėnesius', NULL),
	(700, '313139', 'T7 energijos parodymai už 7 praeitus mėnesius', NULL),
	(700, '3132', 'Apkrovos valdymo relės rankinio įjungimo režimas', NULL),
	(700, '313230', 'T7 energijos parodymai už 8 praeitus mėnesius', NULL),
	(700, '313231', 'T7 energijos parodymai už 9 praeitus mėnesius', NULL),
	(700, '313232', 'T7 energijos parodymai už 10 praeitų mėnesių', NULL),
	(700, '313233', 'T7 energijos parodymai už 11 praeitų mėnesių', NULL),
	(700, '313234', 'T7 energijos parodymai už 12 praeitų mėnesių', NULL),
	(700, '313235', 'T7 energijos parodymai už 13 praeitų mėnesių', NULL),
	(700, '313236', 'Dabartiniai T8 energijos parodymai', NULL),
	(700, '313237', 'T8 energijos parodymai už praeitą mėnesį', NULL),
	(700, '313238', 'T8 energijos parodymai už 2 praeitus mėnesius', NULL),
	(700, '313239', 'T8 energijos parodymai už 3 praeitus mėnesius', NULL),
	(700, '3133', 'LCD testas', NULL),
	(700, '313330', 'T8 energijos parodymai už 4 praeitus mėnesius', NULL),
	(700, '313331', 'T8 energijos parodymai už 5 praeitus mėnesius', NULL),
	(700, '313332', 'T8 energijos parodymai už 6 praeitus mėnesius', NULL),
	(700, '313333', 'T8 energijos parodymai už 7 praeitus mėnesius', NULL),
	(700, '313334', 'T8 energijos parodymai už 8 praeitus mėnesius', NULL),
	(700, '313335', 'T8 energijos parodymai už 9 praeitus mėnesius', NULL),
	(700, '313336', 'T8 energijos parodymai už 10 praeitų mėnesių', NULL),
	(700, '313337', 'T8 energijos parodymai už 11 praeitų mėnesių', NULL),
	(700, '313338', 'T8 energijos parodymai už 12 praeitų mėnesių', NULL),
	(700, '313339', 'T8 energijos parodymai už 13 praeitų mėnesių', NULL),
	(700, '3134', 'Dabartinė suma pagal tarifus', NULL),
	(700, '3135', 'Suma pagal tarifus už praeitą mėnesį', NULL),
	(700, '3136', 'Suma pagal tarifus už 2 praeitus mėnesius', NULL),
	(700, '3137', 'Suma pagal tarifus už 3 praeitus mėnesius', NULL),
	(700, '3138', 'Suma pagal tarifus už 4 praeitus mėnesius', NULL),
	(700, '3139', 'Suma pagal tarifus už 5 praeitus mėnesius', NULL),
	(700, '32', 'Galios ribos indikacija', NULL),
	(700, '3230', 'Suma pagal tarifus už 6 praeitus mėnesius', NULL),
	(700, '3231', 'Suma pagal tarifus už 7 praeitus mėnesius', NULL),
	(700, '3232', 'Suma pagal tarifus už 8 praeitus mėnesius', NULL),
	(700, '3233', 'Suma pagal tarifus už 9 praeitus mėnesius', NULL),
	(700, '3234', 'Suma pagal tarifus už 10 praeitų mėnesių', NULL),
	(700, '3235', 'Suma pagal tarifus už 11 praeitų mėnesių', NULL),
	(700, '3236', 'Suma pagal tarifus už 12 praeitų mėnesių', NULL),
	(700, '3237', 'Suma pagal tarifus už 13 praeitų mėnesių', NULL),
	(700, '3238', 'Dabartiniai T1 energijos parodymai', NULL),
	(700, '3239', 'T1 energijos parodymai už praeitą mėnesį', NULL),
	(700, '33', '2 relės būsenos indikacija - apkrovos valdymas', NULL),
	(700, '3330', 'T1 energijos parodymai už 2 praeitus mėnesius', NULL),
	(700, '3331', 'T1 energijos parodymai už 3 praeitus mėnesius', NULL),
	(700, '3332', 'T1 energijos parodymai už 4 praeitus mėnesius', NULL),
	(700, '3333', 'T1 energijos parodymai už 5 praeitus mėnesius', NULL),
	(700, '3334', 'T1 energijos parodymai už 6 praeitus mėnesius', NULL),
	(700, '3335', 'T1 energijos parodymai už 7 praeitus mėnesius', NULL),
	(700, '3336', 'T1 energijos parodymai už 8 praeitus mėnesius', NULL),
	(700, '3337', 'T1 energijos parodymai už 9 praeitus mėnesius', NULL),
	(700, '3338', 'T1 energijos parodymai už 10 praeitų mėnesių', NULL),
	(700, '3339', 'T1 energijos parodymai už 11 praeitų mėnesių', NULL),
	(700, '34', 'Pagrindinis laikas', NULL),
	(700, '3430', 'T1 energijos parodymai už 12 praeitų mėnesių', NULL),
	(700, '3431', 'T1 energijos parodymai už 13 praeitų mėnesių', NULL),
	(700, '3432', 'Dabartiniai T2 energijos parodymai', NULL),
	(700, '3433', 'T2 energijos parodymai už praeitą mėnesį', NULL),
	(700, '3434', 'T2 energijos parodymai už 2 praeitus mėnesius', NULL),
	(700, '3435', 'T2 energijos parodymai už 3 praeitus mėnesius', NULL),
	(700, '3436', 'T2 energijos parodymai už 4 praeitus mėnesius', NULL),
	(700, '3437', 'T2 energijos parodymai už 5 praeitus mėnesius', NULL),
	(700, '3438', 'T2 energijos parodymai už 6 praeitus mėnesius', NULL),
	(700, '3439', 'T2 energijos parodymai už 7 praeitus mėnesius', NULL),
	(700, '35', 'Dabartinė data', NULL),
	(700, '3530', 'T2 energijos parodymai už 8 praeitus mėnesius', NULL),
	(700, '3531', 'T2 energijos parodymai už 9 praeitus mėnesius', NULL),
	(700, '3532', 'T2 energijos parodymai už 10 praeitų mėnesių', NULL),
	(700, '3533', 'T2 energijos parodymai už 11 praeitų mėnesių', NULL),
	(700, '3534', 'T2 energijos parodymai už 12 praeitų mėnesių', NULL),
	(700, '3535', 'T2 energijos parodymai už 13 praeitų mėnesių', NULL),
	(700, '3536', 'Dabartiniai T3 energijos parodymai', NULL),
	(700, '3537', 'T3 energijos parodymai už praeitą mėnesį', NULL),
	(700, '3538', 'T3 energijos parodymai už 2 praeitus mėnesius', NULL),
	(700, '3539', 'T3 energijos parodymai už 3 praeitus mėnesius', NULL),
	(700, '36', 'Momentinė galia', NULL),
	(700, '3630', 'T3 energijos parodymai už 4 praeitus mėnesius', NULL),
	(700, '3631', 'T3 energijos parodymai už 5 praeitus mėnesius', NULL),
	(700, '3632', 'T3 energijos parodymai už 6 praeitus mėnesius', NULL),
	(700, '3633', 'T3 energijos parodymai už 7 praeitus mėnesius', NULL),
	(700, '3634', 'T3 energijos parodymai už 8 praeitus mėnesius', NULL),
	(700, '3635', 'T3 energijos parodymai už 9 praeitus mėnesius', NULL),
	(700, '3636', 'T3 energijos parodymai už 10 praeitų mėnesių', NULL),
	(700, '3637', 'T3 energijos parodymai už 11 praeitų mėnesių', NULL),
	(700, '3638', 'T3 energijos parodymai už 12 praeitų mėnesių', NULL),
	(700, '3639', 'T3 energijos parodymai už 13 praeitų mėnesių', NULL),
	(700, '37', 'Tinklo adreso indikacija', NULL),
	(700, '3730', 'Dabartiniai T4 energijos parodymai', NULL),
	(700, '3731', 'T4 energijos parodymai už praeitą mėnesį', NULL),
	(700, '3732', 'T4 energijos parodymai už 2 praeitus mėnesius', NULL),
	(700, '3733', 'T4 energijos parodymai už 3 praeitus mėnesius', NULL),
	(700, '3734', 'T4 energijos parodymai už 4 praeitus mėnesius', NULL),
	(700, '3735', 'T4 energijos parodymai už 5 praeitus mėnesius', NULL),
	(700, '3736', 'T4 energijos parodymai už 6 praeitus mėnesius', NULL),
	(700, '3737', 'T4 energijos parodymai už 7 praeitus mėnesius', NULL),
	(700, '3738', 'T4 energijos parodymai už 8 praeitus mėnesius', NULL),
	(700, '3739', 'T4 energijos parodymai už 9 praeitus mėnesius', NULL),
	(700, '38', 'Programos versijos indikacija', NULL),
	(700, '3830', 'T4 energijos parodymai už 10 praeitų mėnesių', NULL),
	(700, '3831', 'T4 energijos parodymai už 11 praeitų mėnesių', NULL),
	(700, '3832', 'T4 energijos parodymai už 12 praeitų mėnesių', NULL),
	(700, '3833', 'T4 energijos parodymai už 13 praeitų mėnesių', NULL),
	(700, '3834', 'Dabartiniai T5 energijos parodymai', NULL),
	(700, '3835', 'T5 energijos parodymai už praeitą mėnesį', NULL),
	(700, '3836', 'T5 energijos parodymai už 2 praeitus mėnesius', NULL),
	(700, '3837', 'T5 energijos parodymai už 3 praeitus mėnesius', NULL),
	(700, '3838', 'T5 energijos parodymai už 4 praeitus mėnesius', NULL),
	(700, '3839', 'T5 energijos parodymai už 5 praeitus mėnesius', NULL),
	(700, '39', 'Sąsajos greitis', NULL),
	(700, '3930', 'T5 energijos parodymai už 6 praeitus mėnesius', NULL),
	(700, '3931', 'T5 energijos parodymai už 7 praeitus mėnesius', NULL),
	(700, '3932', 'T5 energijos parodymai už 8 praeitus mėnesius', NULL),
	(700, '3933', 'T5 energijos parodymai už 9 praeitus mėnesius', NULL),
	(700, '3934', 'T5 energijos parodymai už 10 praeitų mėnesių', NULL),
	(700, '3935', 'T5 energijos parodymai už 11 praeitų mėnesių', NULL),
	(700, '3936', 'T5 energijos parodymai už 12 praeitų mėnesių', NULL),
	(700, '3937', 'T5 energijos parodymai už 13 praeitų mėnesių', NULL),
	(700, '3938', 'Dabartiniai T6 energijos parodymai', NULL),
	(700, '3939', 'T6 energijos parodymai už praeitą mėnesį', NULL),
	(701, '0', 'nenaudoti paskutinio sėkmingo nuskaitymo informacijos', NULL),
	(701, '1', 'panaudoti paskutinio sėkmingo nuskaitymo maršrutą', NULL),
	(701, '2', 'panaudoti paskutinio sėkmingo nuskaitymo kontūrą ir duomenų vietą', NULL),
	(704, '30', 'atrankinis skaitymas be slaptažodžio', NULL),
	(704, '31', 'atrankinis skaitymas su slaptažodžiu', NULL),
	(705, '30', 'bendro skaitymo pagal sąrašą išvesties leidimas, išskyrus apkrovos profilį', NULL),
	(705, '31', 'bendro skaitymo pagal sąrašą LISTI išvestis', NULL),
	(706, '30', 'standartinis duomenų išvesties režimas per sąsają', NULL),
	(706, '31', 'sekančių to paties pavadinimo parametrų be pavadinimo išvestis', NULL),
	(707, '30', 'nerodyti apkrovos profilių papildomą informaciją', NULL),
	(707, '31', 'rodyti apkrovos profilių papildomą informaciją', NULL),
	(708, '30', 'sąsajos atsakymo laikas ne mažiau 200 ms', NULL),
	(708, '31', 'sąsajos atsakymo laikas ne mažiau 20 ms', NULL),
	(709, '30', 'automatinė peržiūra per LCD pagal sąrašą', NULL),
	(709, '31', 'parametrų automatinės peržiūros per LCD draudimas', NULL),
	(710, '30', 'programavimas leidžiamas po mygtuko «DSTP» paspausdimo', NULL),
	(710, '31', 'programavimas leidžiamas be mygtuko «DSTP» paspausdimo', NULL),
	(711, '30', 'augančių dienos ir mėnesio energijų reikšmių, fiksuotų paros ir mėnesio pabaigoje išvestis per LCD', NULL),
	(711, '31', 'sukauptų dienos ir mėnesio energijų išvestis per LCD', NULL),
	(712, '30', 'neperjungti į pradinį kadrą', NULL),
	(712, '31', 'perjungti į pradinį kadrą', NULL),
	(713, '30', 'energijos parametrų numetimo leidimas', NULL),
	(713, '31', 'energijos parametrų numetimo draudimas', NULL),
	(714, '30', 'visų parametrų peržiūra rankiniu režimu per LCD', NULL),
	(714, '31', 'parametrų pagal sąrašą peržiūra rankiniu režimu per LCD', NULL),
	(715, '30', 'sąsajos atsakymo laikas 1,5 s', NULL),
	(715, '31', 'sąsajos atsakymo laikas lygus sąsajos aktyvios veiklos reakcijos laikui', NULL),
	(716, '0', 'visas prietaisas', NULL),
	(716, '1', 'šilumos sistema 1', NULL),
	(716, '2', 'šilumos sistema 2', NULL),
	(716, '3', 'šilumos sistema 3', NULL),
	(717, '0', '0', NULL),
	(717, '1', '1', NULL),
	(717, '2', '2', NULL),
	(717, '3', '3', NULL),
	(717, '4', '4', NULL),
	(717, '5', '5', NULL),
	(717, '6', '6', NULL),
	(717, '7', '7', NULL),
	(717, '8', '8', NULL),
	(717, '9', '9', NULL),
	(718, '1', 'Intervalinis', NULL),
	(718, '2', 'Galutinis', NULL),
	(719, '1', '1', NULL),
	(719, '2', '2', NULL),
	(720, '1', 'A', NULL),
	(720, '2', 'B', NULL),
	(720, '3', 'C', NULL),
	(724, '1', '1', NULL),
	(724, '2', '2', NULL),
	(724, '3', '3', NULL),
	(725, '30', 'normoje', NULL),
	(725, '31', 'viršytas', NULL),
	(726, '30', 'normoje', NULL),
	(726, '31', 'viršytas', NULL),
	(727, '30', 'normoje', NULL),
	(727, '31', 'viršytas', NULL),
	(728, '30', 'normoje', NULL),
	(728, '31', 'viršytas', NULL),
	(729, '30', 'nepažeista', NULL),
	(729, '31', 'pažeista', NULL),
	(730, '30', 'nepažeista', NULL),
	(730, '31', 'pažeista', NULL),
	(731, '30', 'nepažeista', NULL),
	(731, '31', 'pažeista', NULL),
	(732, '30', 'nepažeista', NULL),
	(732, '31', 'pažeista', NULL),
	(733, '30', 'normoje', NULL),
	(733, '31', 'didesnis už atkirtą', NULL),
	(734, '30', 'normoje', NULL),
	(734, '31', 'didesnis už atkirtą', NULL),
	(735, '30', 'normoje', NULL),
	(735, '31', 'didesnis už atkirtą', NULL),
	(736, '30', 'normoje', NULL),
	(736, '31', 'didesnis už atkirtą', NULL),
	(737, '30', 'normoje', NULL),
	(737, '31', 'viršytas', NULL),
	(738, '30', 'nepažeista', NULL),
	(738, '31', 'pažeista', NULL),
	(739, '1', 'šilumos sistema 1', NULL),
	(739, '2', 'šilumos sistema 2', NULL),
	(739, '3', 'šilumos sistema 3', NULL),
	(740, '0', '0', NULL),
	(740, '1', '1', NULL),
	(740, '2', '2', NULL),
	(740, '3', '3', NULL),
	(740, '4', '4', NULL),
	(740, '5', '5', NULL),
	(740, '6', '6', NULL),
	(741, '1', 'šilumos sistema 1', NULL),
	(741, '2', 'šilumos sistema 2', NULL),
	(742, '1', '1', NULL),
	(742, '2', '2', NULL),
	(742, '3', '3', NULL),
	(742, '4', '4', NULL),
	(742, '5', '5', NULL),
	(744, '240', 'MK_N1', NULL),
	(744, '4', 'TMK_N1', NULL),
	(744, '8', 'TMK_N2', NULL),
	(744, '9', 'TMK_N3', NULL),
	(745, '30', 'Grįžimas iš avarinės situacijos: t4 > t4max ', NULL),
	(745, '31', 'Avarinė situacija: t4 > t4max', NULL),
	(746, '30', 'Grįžimas iš avarinės situacijos: t4 < t4min ', NULL),
	(746, '31', 'Avarinė situacija: t4 < t4min', NULL),
	(747, '30', 'Grįžimas iš avarinės situacijos:Gv2 > 1.04*Gv2 ', NULL),
	(747, '31', 'Avarinė situacija:Gv2 > 1.04*Gv2', NULL),
	(748, '30', 'Grįžimas iš avarinės situacijos: tx > tx max ', NULL),
	(748, '31', 'Avarinė situacija: tx > tx max', NULL),
	(749, '30', 'Grįžimas iš avarinės situacijos: tx < tx max ', NULL),
	(749, '31', 'Avarinė situacija: tx < tx max', NULL),
	(750, '30', 'Grįžimas iš avarinės situacijos: t2 > t2max ', NULL),
	(750, '31', 'Avarinė situacija: t2 > t2max', NULL),
	(751, '30', 'Grįžimas iš avarinės situacijos: t2 < t2min ', NULL),
	(751, '31', 'Avarinė situacija: t2 < t2min', NULL),
	(752, '30', 'Grįžimas iš avarinės situacijos: t1 > t1max ', NULL),
	(752, '31', 'Avarinė situacija: t1 > t1max', NULL),
	(753, '30', 'Grįžimas iš avarinės situacijos: t1 < t1min ', NULL),
	(753, '31', 'Avarinė situacija: t1 < t1min', NULL),
	(754, '30', 'Grįžimas iš avarinės situacijos: t1 - t2 > delta_tmax ', NULL),
	(754, '31', 'Avarinė situacija: t1 - t2 > delta_tmax', NULL),
	(755, '30', 'Grįžimas iš avarinės situacijos: W < 0 ', NULL),
	(755, '31', 'Avarinė situacija: W < 0', NULL),
	(756, '30', 'Grįžimas iš avarinės situacijos: P1 > P1max ', NULL),
	(756, '31', 'Avarinė situacija: P1 > P1max', NULL),
	(757, '30', 'Grįžimas iš avarinės situacijos: P1 < P1min ', NULL),
	(757, '31', 'Avarinė situacija: P1 < P1min', NULL),
	(758, '30', 'Grįžimas iš avarinės situacijos: P2 > P2max ', NULL),
	(758, '31', 'Avarinė situacija: P2 > P2max', NULL),
	(759, '30', 'Grįžimas iš avarinės situacijos: P2 < P2min ', NULL),
	(759, '31', 'Avarinė situacija: P2 < P2min', NULL),
	(760, '30', 'Klaidų kiekis per parą normos ribose', NULL),
	(760, '31', 'Klaidų kiekis per parą > maksimumą', NULL),
	(761, '30', 'Apsikeitimo su PPC klaidos nėra', NULL),
	(761, '31', 'Apsikeitimo su PPC klaida', NULL),
	(762, '30', 'PPC termometrų gedimo grandyje nėra', NULL),
	(762, '31', 'PPC termometrų gedimas grandyje', NULL),
	(763, '30', 'KM-5 termometrų gedimo grandyje nėra', NULL),
	(763, '31', 'KM-5 termometrų gedimas grandyje', NULL),
	(764, '30', 'KM-5 vamzdis netuščias', NULL),
	(764, '31', 'KM-5 tuščio vamzdžio daviklio galutinis požymis', NULL),
	(765, '30', 'PPC vamzdis netuščias', NULL),
	(765, '31', 'PPC tuščio vamzdžio daviklio galutinis požymis', NULL),
	(766, '1', 'KM 5 1', NULL),
	(766, '2', 'KM 5 2', NULL),
	(766, '3', 'KM 5 3', NULL),
	(766, '4', 'KM 5 4', NULL),
	(766, '5', 'KM 5 5', NULL),
	(766, '6', 'KM 5 6', NULL),
	(766, '7', 'KM 5 7', NULL),
	(767, '30', ' dingo', NULL),
	(767, '31', ' atsirado', NULL),
	(768, '30', ' - atstatytas', NULL),
	(768, '31', ' - nėra', NULL),
	(769, 'FT.1.1', 'protokolas FT.1.1', NULL),
	(769, 'FT.1.2', 'protokolas FT.1.2', NULL),
	(770, '1', 'Spintos durys', NULL),
	(770, '10', 'Rezervinis2', NULL),
	(770, '11', 'Rezervinis3', NULL),
	(770, '12', 'Rezervinis4', NULL),
	(770, '13', 'UPS', NULL),
	(770, '14', 'Apsauga (signalizacija)', NULL),
	(770, '15', 'Durys', NULL),
	(770, '16', 'Temperatūros daviklio Nr.1 statusas (16)', NULL),
	(770, '17', 'Temperatūros daviklio Nr.2 statusas (17)', NULL),
	(770, '2', 'Lauko durys', NULL),
	(770, '3', 'Stiklo dūžis', NULL),
	(770, '4', 'Gaisras', NULL),
	(770, '5', 'Sirenos darbo tikrinimas „Sirena įjungta“', NULL),
	(770, '6', 'Sirenos sabotažas', NULL),
	(770, '7', 'Spynos darbo tikrinimas „Spyna užsikirto“', NULL),
	(770, '8', 'Mygtukas', NULL),
	(770, '9', 'Rezervinis1', NULL),
	(774, '31', ' ', NULL),
	(774, '3130', 'TM koeficientų nustatymas', NULL),
	(774, '3131', 'Integravimo periodo keitimas', NULL),
	(774, '3132', 'Laiko nustatymas', NULL),
	(774, '3133', 'Transformacijos koeficientų parametravimas', NULL),
	(774, '3134', 'Duomenų numetimas', NULL),
	(774, '3135', 'Pagrindinių parametrų parametravimas', NULL),
	(774, '3136', 'Diskretinių signalų parametravimas', NULL),
	(774, '3137', 'Impulsinių skaitiklių parametravimas', NULL),
	(774, '3138', 'Skaitmeninių skaitiklių parametravimas', NULL),
	(774, '3139', 'GPRS parametravimas', NULL),
	(774, '32', 'Parametravimas', NULL),
	(774, '3230', 'Užduočių parametravimas', NULL),
	(774, '3231', 'Taškų parametravimas', NULL),
	(774, '3232', 'Aliarmų parametravimas', NULL),
	(774, '33', 'Profilio parametravimas', NULL),
	(774, '34', 'Maksimalios galios tarifų diegimas', NULL),
	(774, '35', 'Maksimalios galios tarifų kiekio diegimas', NULL),
	(774, '36', 'Mėnesio duomenų numetimas', NULL),
	(774, '37', 'Konfigūracijos konstantų nustatymas', NULL),
	(774, '38', 'Tarifų nustatymas', NULL),
	(774, '39', 'TM įėjimų koeficientų nustatymas', NULL),
	(775, '30', 'Skaitiklis registruotas', NULL),
	(775, '31', 'Skaitiklis neregistruotas', NULL),
	(779, '30', 'Mygtuko paspaudimas nieko nenumeta', NULL),
	(779, '31', 'Magnetinio lauko poveikio LED gesinimas', NULL),
	(780, '31', 'Mygtuko paspaudimu', NULL),
	(780, '32', 'Pagal sezonų kalentorių', NULL),
	(780, '33', 'Paskutinę mėnesio dieną', NULL),
	(780, '34', 'Išrinkta mėnesio dieną', NULL),
	(781, '17', 'Užimtos EMCOS_IND tablespace vietos procentas', NULL),
	(781, '18', 'Užimtos EMCOS_TAB tablespace vietos procentas', NULL),
	(781, '19', 'Taškų matavimų galiojančių išsaugojimų kiekis per parą', NULL),
	(781, '20', 'Taškų matavimų galiojančių išsaugojimų procentas per parą', NULL),
	(781, '21', 'Turinčių diskretiškumą taškų matavimų išsaugojimų procentas per parą', NULL),
	(781, '22', 'Suvestų apskaitos taškų kiekis', NULL),
	(781, '23', 'Turinčių diskretiškumą taškų matavimų be skylių procentas', NULL),
	(781, '24', 'Ryšio kanalų unikalių sesijų kiekis per parą', NULL),
	(781, '25', 'Ryšio kanalų unikalių sesijų be transporto lygio klaidų procentas per parą', NULL),
	(781, '26', 'Uždarytų taškų procentas per parą', NULL),
	(781, '27', 'Įrašų kiekis taškų matavimų saugotinų nuskaitymų buferyje', NULL),
	(781, '28', 'Įrašų kiekis taškų matavimų nesaugotinų nuskaitymų buferyje', NULL),
	(781, '29', 'Svarbių Oracle pranešimų kiekis įvykių registre per parą', NULL),
	(781, '30', 'Maksimalus eilės dydis per parą', NULL),
	(781, '31', 'Suformuotų automatizuotų ataskaitų kiekis per parą', NULL),
	(781, '32', 'Naudojamų ryšio kanalų kiekis', NULL),
	(781, '33', 'Naudojamų ryšio kanalų, su kuriais yra ryšys, procentas', NULL),
	(781, '34', 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą', NULL),
	(781, '35', 'Turinčių diskretiškumą galiojančių saugotinų nepagerinamų išsaugojimų procentas per parą', NULL),
	(781, '36', 'Neturinčių diskretiškumo galiojančių saugotinų nepagerinamų išsaugojimų procentas per parą', NULL),
	(781, '46', 'Źīėč÷åńņāī ąāņīģąņčēčšīāąķķūõ ņī÷åź ó÷åņą', NULL),
	(781, '51', 'Beviltiškų taškų procentas', NULL),
	(781, '52', 'Beviltiškų taškų skylių užsakymų eilučių procentas nuo bendro kiekio', NULL),
	(781, '53', 'Beviltiškų skylių užsakymų eilučių kiekis', NULL),
	(781, '54', 'Lentelės PL_DATA apimties procentas nuo visų EMCOS_TAB segmentų', NULL),
	(781, '55', 'Taškų su skylėmis procentas', NULL),
	(781, '56', 'Nuskaitymo taškų, su kuriais nėra ryšio, procentas nuo galiojančių', NULL),
	(781, '57', 'Galiojančių ryšio kanalų be ryšio kiekis', NULL),
	(781, '58', 'Sėkmingai išsiųstų eksporto formų procentas', NULL),
	(781, '59', 'Sėkmingų sugrupuotų užklausų procentas', NULL),
	(781, '60', 'Įvykio registro pranešimų kiekis per parą', NULL),
	(781, '61', 'Bendra EMCOS segmentų apimtis (GB)', NULL),
	(781, '62', 'Negaliojančių rodmenų nuskaitymų lentelės PL_DATA_NV apimtis procentais', NULL),
	(781, '63', 'Įrašų kiekis taškų vytelių buferyje', NULL),
	(784, '1', 'Atmesti siuntimą, jei aptikta trūkstamų formoje elementų', NULL),
	(784, '2', 'Priimti sutampančių elementų duomenis, dėl trūkstamų suformuoti įspėjantį pranešimą', NULL),
	(784, '3', 'Priimti sutampančių elementų duomenis', NULL),
	(785, '1', '1 mėnuo', NULL),
	(785, '3', '3 mėnesiai', NULL),
	(786, '19842', '$4D82', NULL),
	(787, '0', 'iš koncentratoriaus archyvo', NULL),
	(787, '1', 'Online rėžimu', NULL),
	(788, '0', 'user', NULL),
	(788, '1', 'operator', NULL),
	(789, '195', 'KM', NULL),
	(789, '216', 'KSPD', NULL),
	(790, '0', 'RS485', NULL),
	(790, '1', 'RS232', NULL),
	(790, '2', 'Ethernet', NULL),
	(791, '115200', '115200', NULL),
	(791, '19200', '19200', NULL),
	(791, '2400', '2400', NULL),
	(791, '38400', '38400', NULL),
	(791, '4800', '4800', NULL),
	(791, '57600', '57600', NULL),
	(791, '9600', '9600', NULL),
	(792, '30', 'Skaitiklio dangčio uždarymas', NULL),
	(792, '31', 'Skaitiklio dangčio atidarymas', NULL),
	(793, '30', 'Išjungti  patikros režimą', NULL),
	(793, '31', 'Įjungti patikros režimą', NULL),
	(794, '31', 'Netinkamas laikas', NULL),
	(795, '30', 'Srovės fazės atstatymas', NULL),
	(795, '31', 'Srovės fazės nutraukimas', NULL),
	(796, '30', 'Įtampos fazės atstatymas', NULL),
	(796, '31', 'Įtampos fazės nutraukimas', NULL),
	(797, '1143', '$477', NULL),
	(798, '30', 'grįžimas', NULL),
	(798, '31', 'peržengimas', NULL),
	(799, '30', 'išjungimas', NULL),
	(799, '31', 'įjungimas', NULL),
	(800, '0', '0', 1),
	(800, '1', '1', 2),
	(800, '10', '10', 11),
	(800, '100', '100', 101),
	(800, '101', '101', 102),
	(800, '102', '102', 103),
	(800, '103', '103', 104),
	(800, '104', '104', 105),
	(800, '105', '105', 106),
	(800, '106', '106', 107),
	(800, '107', '107', 108),
	(800, '108', '108', 109),
	(800, '109', '109', 110),
	(800, '11', '11', 12),
	(800, '110', '110', 111),
	(800, '111', '111', 112),
	(800, '112', '112', 113),
	(800, '113', '113', 114),
	(800, '114', '114', 115),
	(800, '115', '115', 116),
	(800, '116', '116', 117),
	(800, '117', '117', 118),
	(800, '118', '118', 119),
	(800, '119', '119', 120),
	(800, '12', '12', 13),
	(800, '120', '120', 121),
	(800, '121', '121', 122),
	(800, '122', '122', 123),
	(800, '123', '123', 124),
	(800, '124', '124', 125),
	(800, '125', '125', 126),
	(800, '126', '126', 127),
	(800, '127', '127', 128),
	(800, '128', '128', 129),
	(800, '129', '129', 130),
	(800, '13', '13', 14),
	(800, '130', '130', 131),
	(800, '131', '131', 132),
	(800, '132', '132', 133),
	(800, '133', '133', 134),
	(800, '134', '134', 135),
	(800, '135', '135', 136),
	(800, '136', '136', 137),
	(800, '137', '137', 138),
	(800, '138', '138', 139),
	(800, '139', '139', 140),
	(800, '14', '14', 15),
	(800, '140', '140', 141),
	(800, '141', '141', 142),
	(800, '142', '142', 143),
	(800, '143', '143', 144),
	(800, '144', '144', 145),
	(800, '145', '145', 146),
	(800, '146', '146', 147),
	(800, '147', '147', 148),
	(800, '148', '148', 149),
	(800, '149', '149', 150),
	(800, '15', '15', 16),
	(800, '150', '150', 151),
	(800, '151', '151', 152),
	(800, '152', '152', 153),
	(800, '153', '153', 154),
	(800, '154', '154', 155),
	(800, '155', '155', 156),
	(800, '156', '156', 157),
	(800, '157', '157', 158),
	(800, '158', '158', 159),
	(800, '159', '159', 160),
	(800, '16', '16', 17),
	(800, '160', '160', 161),
	(800, '161', '161', 162),
	(800, '162', '162', 163),
	(800, '163', '163', 164),
	(800, '164', '164', 165),
	(800, '165', '165', 166),
	(800, '166', '166', 167),
	(800, '167', '167', 168),
	(800, '168', '168', 169),
	(800, '169', '169', 170),
	(800, '17', '17', 18),
	(800, '170', '170', 171),
	(800, '171', '171', 172),
	(800, '172', '172', 173),
	(800, '173', '173', 174),
	(800, '174', '174', 175),
	(800, '175', '175', 176),
	(800, '176', '176', 177),
	(800, '177', '177', 178),
	(800, '178', '178', 179),
	(800, '179', '179', 180),
	(800, '18', '18', 19),
	(800, '180', '180', 181),
	(800, '181', '181', 182),
	(800, '182', '182', 183),
	(800, '183', '183', 184),
	(800, '184', '184', 185),
	(800, '185', '185', 186),
	(800, '186', '186', 187),
	(800, '187', '187', 188),
	(800, '188', '188', 189),
	(800, '189', '189', 190),
	(800, '19', '19', 20),
	(800, '190', '190', 191),
	(800, '191', '191', 192),
	(800, '192', '192', 193),
	(800, '193', '193', 194),
	(800, '194', '194', 195),
	(800, '195', '195', 196),
	(800, '196', '196', 197),
	(800, '197', '197', 198),
	(800, '198', '198', 199),
	(800, '199', '199', 200),
	(800, '2', '2', 3),
	(800, '20', '20', 21),
	(800, '200', '200', 201),
	(800, '201', '201', 202),
	(800, '202', '202', 203),
	(800, '203', '203', 204),
	(800, '204', '204', 205),
	(800, '205', '205', 206),
	(800, '206', '206', 207),
	(800, '207', '207', 208),
	(800, '208', '208', 209),
	(800, '209', '209', 210),
	(800, '21', '21', 22),
	(800, '210', '210', 211),
	(800, '211', '211', 212),
	(800, '212', '212', 213),
	(800, '213', '213', 214),
	(800, '214', '214', 215),
	(800, '215', '215', 216),
	(800, '216', '216', 217),
	(800, '217', '217', 218),
	(800, '218', '218', 219),
	(800, '219', '219', 220),
	(800, '22', '22', 23),
	(800, '220', '220', 221),
	(800, '221', '221', 222),
	(800, '222', '222', 223),
	(800, '223', '223', 224),
	(800, '224', '224', 225),
	(800, '225', '225', 226),
	(800, '226', '226', 227),
	(800, '227', '227', 228),
	(800, '228', '228', 229),
	(800, '229', '229', 230),
	(800, '23', '23', 24),
	(800, '230', '230', 231),
	(800, '231', '231', 232),
	(800, '232', '232', 233),
	(800, '233', '233', 234),
	(800, '234', '234', 235),
	(800, '235', '235', 236),
	(800, '236', '236', 237),
	(800, '237', '237', 238),
	(800, '238', '238', 239),
	(800, '239', '239', 240),
	(800, '24', '24', 25),
	(800, '240', '240', 241),
	(800, '241', '241', 242),
	(800, '242', '242', 243),
	(800, '243', '243', 244),
	(800, '244', '244', 245),
	(800, '245', '245', 246),
	(800, '246', '246', 247),
	(800, '247', '247', 248),
	(800, '248', '248', 249),
	(800, '249', '249', 250),
	(800, '25', '25', 26),
	(800, '250', '250', 251),
	(800, '251', '251', 252),
	(800, '252', '252', 253),
	(800, '253', '253', 254),
	(800, '254', '254', 255),
	(800, '255', '255', 256),
	(800, '256', '256', 257),
	(800, '257', '257', 258),
	(800, '258', '258', 259),
	(800, '259', '259', 260),
	(800, '26', '26', 27),
	(800, '260', '260', 261),
	(800, '261', '261', 262),
	(800, '262', '262', 263),
	(800, '263', '263', 264),
	(800, '264', '264', 265),
	(800, '265', '265', 266),
	(800, '266', '266', 267),
	(800, '267', '267', 268),
	(800, '268', '268', 269),
	(800, '269', '269', 270),
	(800, '27', '27', 28),
	(800, '270', '270', 271),
	(800, '271', '271', 272),
	(800, '272', '272', 273),
	(800, '273', '273', 274),
	(800, '274', '274', 275),
	(800, '275', '275', 276),
	(800, '276', '276', 277),
	(800, '277', '277', 278),
	(800, '278', '278', 279),
	(800, '279', '279', 280),
	(800, '28', '28', 29),
	(800, '280', '280', 281),
	(800, '281', '281', 282),
	(800, '282', '282', 283),
	(800, '283', '283', 284),
	(800, '284', '284', 285),
	(800, '285', '285', 286),
	(800, '286', '286', 287),
	(800, '287', '287', 288),
	(800, '288', '288', 289),
	(800, '289', '289', 290),
	(800, '29', '29', 30),
	(800, '290', '290', 291),
	(800, '291', '291', 292),
	(800, '292', '292', 293),
	(800, '293', '293', 294),
	(800, '294', '294', 295),
	(800, '295', '295', 296),
	(800, '296', '296', 297),
	(800, '297', '297', 298),
	(800, '298', '298', 299),
	(800, '299', '299', 300),
	(800, '3', '3', 4),
	(800, '30', '30', 31),
	(800, '300', '300', 301),
	(800, '301', '301', 302),
	(800, '302', '302', 303),
	(800, '303', '303', 304),
	(800, '304', '304', 305),
	(800, '305', '305', 306),
	(800, '306', '306', 307),
	(800, '307', '307', 308),
	(800, '308', '308', 309),
	(800, '309', '309', 310),
	(800, '31', '31', 32),
	(800, '310', '310', 311),
	(800, '311', '311', 312),
	(800, '312', '312', 313),
	(800, '313', '313', 314),
	(800, '314', '314', 315),
	(800, '315', '315', 316),
	(800, '316', '316', 317),
	(800, '317', '317', 318),
	(800, '318', '318', 319),
	(800, '319', '319', 320),
	(800, '32', '32', 33),
	(800, '320', '320', 321),
	(800, '321', '321', 322),
	(800, '322', '322', 323),
	(800, '323', '323', 324),
	(800, '324', '324', 325),
	(800, '325', '325', 326),
	(800, '326', '326', 327),
	(800, '327', '327', 328),
	(800, '328', '328', 329),
	(800, '329', '329', 330),
	(800, '33', '33', 34),
	(800, '330', '330', 331),
	(800, '331', '331', 332),
	(800, '332', '332', 333),
	(800, '333', '333', 334),
	(800, '334', '334', 335),
	(800, '335', '335', 336),
	(800, '336', '336', 337),
	(800, '337', '337', 338),
	(800, '338', '338', 339),
	(800, '339', '339', 340),
	(800, '34', '34', 35),
	(800, '340', '340', 341),
	(800, '341', '341', 342),
	(800, '342', '342', 343),
	(800, '343', '343', 344),
	(800, '344', '344', 345),
	(800, '345', '345', 346),
	(800, '346', '346', 347),
	(800, '347', '347', 348),
	(800, '348', '348', 349),
	(800, '349', '349', 350),
	(800, '35', '35', 36),
	(800, '350', '350', 351),
	(800, '351', '351', 352),
	(800, '352', '352', 353),
	(800, '353', '353', 354),
	(800, '354', '354', 355),
	(800, '355', '355', 356),
	(800, '356', '356', 357),
	(800, '357', '357', 358),
	(800, '358', '358', 359),
	(800, '359', '359', 360),
	(800, '36', '36', 37),
	(800, '360', '360', 361),
	(800, '361', '361', 362),
	(800, '362', '362', 363),
	(800, '363', '363', 364),
	(800, '364', '364', 365),
	(800, '365', '365', 366),
	(800, '366', '366', 367),
	(800, '367', '367', 368),
	(800, '368', '368', 369),
	(800, '369', '369', 370),
	(800, '37', '37', 38),
	(800, '370', '370', 371),
	(800, '371', '371', 372),
	(800, '372', '372', 373),
	(800, '373', '373', 374),
	(800, '374', '374', 375),
	(800, '375', '375', 376),
	(800, '376', '376', 377),
	(800, '377', '377', 378),
	(800, '378', '378', 379),
	(800, '379', '379', 380),
	(800, '38', '38', 39),
	(800, '380', '380', 381),
	(800, '381', '381', 382),
	(800, '382', '382', 383),
	(800, '383', '383', 384),
	(800, '384', '384', 385),
	(800, '385', '385', 386),
	(800, '386', '386', 387),
	(800, '387', '387', 388),
	(800, '388', '388', 389),
	(800, '389', '389', 390),
	(800, '39', '39', 40),
	(800, '390', '390', 391),
	(800, '391', '391', 392),
	(800, '392', '392', 393),
	(800, '393', '393', 394),
	(800, '394', '394', 395),
	(800, '395', '395', 396),
	(800, '396', '396', 397),
	(800, '397', '397', 398),
	(800, '398', '398', 399),
	(800, '399', '399', 400),
	(800, '4', '4', 5),
	(800, '40', '40', 41),
	(800, '400', '400', 401),
	(800, '401', '401', 402),
	(800, '402', '402', 403),
	(800, '403', '403', 404),
	(800, '404', '404', 405),
	(800, '405', '405', 406),
	(800, '406', '406', 407),
	(800, '407', '407', 408),
	(800, '408', '408', 409),
	(800, '409', '409', 410),
	(800, '41', '41', 42),
	(800, '410', '410', 411),
	(800, '411', '411', 412),
	(800, '412', '412', 413),
	(800, '413', '413', 414),
	(800, '414', '414', 415),
	(800, '415', '415', 416),
	(800, '416', '416', 417),
	(800, '417', '417', 418),
	(800, '418', '418', 419),
	(800, '419', '419', 420),
	(800, '42', '42', 43),
	(800, '420', '420', 421),
	(800, '421', '421', 422),
	(800, '422', '422', 423),
	(800, '423', '423', 424),
	(800, '424', '424', 425),
	(800, '425', '425', 426),
	(800, '426', '426', 427),
	(800, '427', '427', 428),
	(800, '428', '428', 429),
	(800, '429', '429', 430),
	(800, '43', '43', 44),
	(800, '430', '430', 431),
	(800, '431', '431', 432),
	(800, '432', '432', 433),
	(800, '433', '433', 434),
	(800, '434', '434', 435),
	(800, '435', '435', 436),
	(800, '436', '436', 437),
	(800, '437', '437', 438),
	(800, '438', '438', 439),
	(800, '439', '439', 440),
	(800, '44', '44', 45),
	(800, '440', '440', 441),
	(800, '441', '441', 442),
	(800, '442', '442', 443),
	(800, '443', '443', 444),
	(800, '444', '444', 445),
	(800, '445', '445', 446),
	(800, '446', '446', 447),
	(800, '447', '447', 448),
	(800, '448', '448', 449),
	(800, '449', '449', 450),
	(800, '45', '45', 46),
	(800, '450', '450', 451),
	(800, '451', '451', 452),
	(800, '452', '452', 453),
	(800, '453', '453', 454),
	(800, '454', '454', 455),
	(800, '455', '455', 456),
	(800, '456', '456', 457),
	(800, '457', '457', 458),
	(800, '458', '458', 459),
	(800, '459', '459', 460),
	(800, '46', '46', 47),
	(800, '460', '460', 461),
	(800, '461', '461', 462),
	(800, '462', '462', 463),
	(800, '463', '463', 464),
	(800, '464', '464', 465),
	(800, '465', '465', 466),
	(800, '466', '466', 467),
	(800, '467', '467', 468),
	(800, '468', '468', 469),
	(800, '469', '469', 470),
	(800, '47', '47', 48),
	(800, '470', '470', 471),
	(800, '471', '471', 472),
	(800, '472', '472', 473),
	(800, '473', '473', 474),
	(800, '474', '474', 475),
	(800, '475', '475', 476),
	(800, '476', '476', 477),
	(800, '477', '477', 478),
	(800, '478', '478', 479),
	(800, '479', '479', 480),
	(800, '48', '48', 49),
	(800, '480', '480', 481),
	(800, '481', '481', 482),
	(800, '482', '482', 483),
	(800, '483', '483', 484),
	(800, '484', '484', 485),
	(800, '485', '485', 486),
	(800, '486', '486', 487),
	(800, '487', '487', 488),
	(800, '488', '488', 489),
	(800, '489', '489', 490),
	(800, '49', '49', 50),
	(800, '490', '490', 491),
	(800, '491', '491', 492),
	(800, '492', '492', 493),
	(800, '493', '493', 494),
	(800, '494', '494', 495),
	(800, '495', '495', 496),
	(800, '496', '496', 497),
	(800, '497', '497', 498),
	(800, '498', '498', 499),
	(800, '499', '499', 500),
	(800, '5', '5', 6),
	(800, '50', '50', 51),
	(800, '500', '500', 501),
	(800, '501', '501', 502),
	(800, '502', '502', 503),
	(800, '503', '503', 504),
	(800, '504', '504', 505),
	(800, '505', '505', 506),
	(800, '506', '506', 507),
	(800, '507', '507', 508),
	(800, '508', '508', 509),
	(800, '509', '509', 510),
	(800, '51', '51', 52),
	(800, '510', '510', 511),
	(800, '511', '511', 512),
	(800, '512', '512', 513),
	(800, '52', '52', 53),
	(800, '53', '53', 54),
	(800, '54', '54', 55),
	(800, '55', '55', 56),
	(800, '56', '56', 57),
	(800, '57', '57', 58),
	(800, '58', '58', 59),
	(800, '59', '59', 60),
	(800, '6', '6', 7),
	(800, '60', '60', 61),
	(800, '61', '61', 62),
	(800, '62', '62', 63),
	(800, '63', '63', 64),
	(800, '64', '64', 65),
	(800, '65', '65', 66),
	(800, '66', '66', 67),
	(800, '67', '67', 68),
	(800, '68', '68', 69),
	(800, '69', '69', 70),
	(800, '7', '7', 8),
	(800, '70', '70', 71),
	(800, '71', '71', 72),
	(800, '72', '72', 73),
	(800, '73', '73', 74),
	(800, '74', '74', 75),
	(800, '75', '75', 76),
	(800, '76', '76', 77),
	(800, '77', '77', 78),
	(800, '78', '78', 79),
	(800, '79', '79', 80),
	(800, '8', '8', 9),
	(800, '80', '80', 81),
	(800, '81', '81', 82),
	(800, '82', '82', 83),
	(800, '83', '83', 84),
	(800, '84', '84', 85),
	(800, '85', '85', 86),
	(800, '86', '86', 87),
	(800, '87', '87', 88),
	(800, '88', '88', 89),
	(800, '89', '89', 90),
	(800, '9', '9', 10),
	(800, '90', '90', 91),
	(800, '91', '91', 92),
	(800, '92', '92', 93),
	(800, '93', '93', 94),
	(800, '94', '94', 95),
	(800, '95', '95', 96),
	(800, '96', '96', 97),
	(800, '97', '97', 98),
	(800, '98', '98', 99),
	(800, '99', '99', 100),
	(801, '1', '1', 1),
	(801, '10', '10', 10),
	(801, '11', '11', 11),
	(801, '12', '12', 12),
	(801, '13', '13', 13),
	(801, '14', '14', 14),
	(801, '15', '15', 15),
	(801, '16', '16', 16),
	(801, '17', '17', 17),
	(801, '18', '18', 18),
	(801, '19', '19', 19),
	(801, '2', '2', 2),
	(801, '20', '20', 20),
	(801, '21', '21', 21),
	(801, '22', '22', 22),
	(801, '23', '23', 23),
	(801, '24', '24', 24),
	(801, '25', '25', 25),
	(801, '26', '26', 26),
	(801, '27', '27', 27),
	(801, '28', '28', 28),
	(801, '29', '29', 29),
	(801, '3', '3', 3),
	(801, '30', '30', 30),
	(801, '31', '31', 31),
	(801, '32', '32', 32),
	(801, '33', '33', 33),
	(801, '34', '34', 34),
	(801, '35', '35', 35),
	(801, '36', '36', 36),
	(801, '37', '37', 37),
	(801, '38', '38', 38),
	(801, '39', '39', 39),
	(801, '4', '4', 4),
	(801, '40', '40', 40),
	(801, '41', '41', 41),
	(801, '42', '42', 42),
	(801, '43', '43', 43),
	(801, '44', '44', 44),
	(801, '45', '45', 45),
	(801, '46', '46', 46),
	(801, '47', '47', 47),
	(801, '48', '48', 48),
	(801, '49', '49', 49),
	(801, '5', '5', 5),
	(801, '50', '50', 50),
	(801, '51', '51', 51),
	(801, '52', '52', 52),
	(801, '53', '53', 53),
	(801, '54', '54', 54),
	(801, '55', '55', 55),
	(801, '56', '56', 56),
	(801, '57', '57', 57),
	(801, '58', '58', 58),
	(801, '59', '59', 59),
	(801, '6', '6', 6),
	(801, '60', '60', 60),
	(801, '61', '61', 61),
	(801, '62', '62', 62),
	(801, '63', '63', 63),
	(801, '64', '64', 64),
	(801, '7', '7', 7),
	(801, '8', '8', 8),
	(801, '9', '9', 9),
	(802, '1', '1', 1),
	(802, '10', '10', 10),
	(802, '11', '11', 11),
	(802, '12', '12', 12),
	(802, '13', '13', 13),
	(802, '14', '14', 14),
	(802, '15', '15', 15),
	(802, '16', '16', 16),
	(802, '17', '17', 17),
	(802, '18', '18', 18),
	(802, '19', '19', 19),
	(802, '2', '2', 2),
	(802, '20', '20', 20),
	(802, '21', '21', 21),
	(802, '22', '22', 22),
	(802, '23', '23', 23),
	(802, '24', '24', 24),
	(802, '25', '25', 25),
	(802, '26', '26', 26),
	(802, '27', '27', 27),
	(802, '28', '28', 28),
	(802, '29', '29', 29),
	(802, '3', '3', 3),
	(802, '30', '30', 30),
	(802, '31', '31', 31),
	(802, '32', '32', 32),
	(802, '4', '4', 4),
	(802, '5', '5', 5),
	(802, '6', '6', 6),
	(802, '7', '7', 7),
	(802, '8', '8', 8),
	(802, '9', '9', 9),
	(803, '30', 'Relės valdymo sutrikimo nėra', NULL),
	(803, '31', 'Relės valdymo sutrikimas, einamoji būsena neatitinka išsaugotosios', NULL),
	(804, '30', 'El. energijos grobstymo nėra', NULL),
	(804, '31', 'Užregistruotas el. energijos grobstymas arba atvirkštinė energijos kryptis', NULL),
	(805, '1', '1', 1),
	(805, '10', '10', 10),
	(805, '100', '100', 100),
	(805, '101', '101', 101),
	(805, '102', '102', 102),
	(805, '103', '103', 103),
	(805, '104', '104', 104),
	(805, '105', '105', 105),
	(805, '106', '106', 106),
	(805, '107', '107', 107),
	(805, '108', '108', 108),
	(805, '109', '109', 109),
	(805, '11', '11', 11),
	(805, '110', '110', 110),
	(805, '111', '111', 111),
	(805, '112', '112', 112),
	(805, '113', '113', 113),
	(805, '114', '114', 114),
	(805, '115', '115', 115),
	(805, '116', '116', 116),
	(805, '117', '117', 117),
	(805, '118', '118', 118),
	(805, '119', '119', 119),
	(805, '12', '12', 12),
	(805, '120', '120', 120),
	(805, '121', '121', 121),
	(805, '122', '122', 122),
	(805, '123', '123', 123),
	(805, '124', '124', 124),
	(805, '125', '125', 125),
	(805, '126', '126', 126),
	(805, '127', '127', 127),
	(805, '128', '128', 128),
	(805, '129', '129', 129),
	(805, '13', '13', 13),
	(805, '130', '130', 130),
	(805, '131', '131', 131),
	(805, '132', '132', 132),
	(805, '133', '133', 133),
	(805, '134', '134', 134),
	(805, '135', '135', 135),
	(805, '136', '136', 136),
	(805, '137', '137', 137),
	(805, '138', '138', 138),
	(805, '139', '139', 139),
	(805, '14', '14', 14),
	(805, '140', '140', 140),
	(805, '141', '141', 141),
	(805, '142', '142', 142),
	(805, '143', '143', 143),
	(805, '144', '144', 144),
	(805, '145', '145', 145),
	(805, '146', '146', 146),
	(805, '147', '147', 147),
	(805, '148', '148', 148),
	(805, '149', '149', 149),
	(805, '15', '15', 15),
	(805, '150', '150', 150),
	(805, '151', '151', 151),
	(805, '152', '152', 152),
	(805, '153', '153', 153),
	(805, '154', '154', 154),
	(805, '155', '155', 155),
	(805, '156', '156', 156),
	(805, '157', '157', 157),
	(805, '158', '158', 158),
	(805, '159', '159', 159),
	(805, '16', '16', 16),
	(805, '160', '160', 160),
	(805, '161', '161', 161),
	(805, '162', '162', 162),
	(805, '163', '163', 163),
	(805, '164', '164', 164),
	(805, '165', '165', 165),
	(805, '166', '166', 166),
	(805, '167', '167', 167),
	(805, '168', '168', 168),
	(805, '169', '169', 169),
	(805, '17', '17', 17),
	(805, '170', '170', 170),
	(805, '171', '171', 171),
	(805, '172', '172', 172),
	(805, '173', '173', 173),
	(805, '174', '174', 174),
	(805, '175', '175', 175),
	(805, '176', '176', 176),
	(805, '177', '177', 177),
	(805, '178', '178', 178),
	(805, '179', '179', 179),
	(805, '18', '18', 18),
	(805, '180', '180', 180),
	(805, '181', '181', 181),
	(805, '182', '182', 182),
	(805, '183', '183', 183),
	(805, '184', '184', 184),
	(805, '185', '185', 185),
	(805, '186', '186', 186),
	(805, '187', '187', 187),
	(805, '188', '188', 188),
	(805, '189', '189', 189),
	(805, '19', '19', 19),
	(805, '190', '190', 190),
	(805, '191', '191', 191),
	(805, '192', '192', 192),
	(805, '193', '193', 193),
	(805, '194', '194', 194),
	(805, '195', '195', 195),
	(805, '196', '196', 196),
	(805, '197', '197', 197),
	(805, '198', '198', 198),
	(805, '199', '199', 199),
	(805, '2', '2', 2),
	(805, '20', '20', 20),
	(805, '200', '200', 200),
	(805, '201', '201', 201),
	(805, '202', '202', 202),
	(805, '203', '203', 203),
	(805, '204', '204', 204),
	(805, '205', '205', 205),
	(805, '206', '206', 206),
	(805, '207', '207', 207),
	(805, '208', '208', 208),
	(805, '209', '209', 209),
	(805, '21', '21', 21),
	(805, '210', '210', 210),
	(805, '211', '211', 211),
	(805, '212', '212', 212),
	(805, '213', '213', 213),
	(805, '214', '214', 214),
	(805, '215', '215', 215),
	(805, '216', '216', 216),
	(805, '217', '217', 217),
	(805, '218', '218', 218),
	(805, '219', '219', 219),
	(805, '22', '22', 22),
	(805, '220', '220', 220),
	(805, '221', '221', 221),
	(805, '222', '222', 222),
	(805, '223', '223', 223),
	(805, '224', '224', 224),
	(805, '225', '225', 225),
	(805, '226', '226', 226),
	(805, '227', '227', 227),
	(805, '228', '228', 228),
	(805, '229', '229', 229),
	(805, '23', '23', 23),
	(805, '230', '230', 230),
	(805, '231', '231', 231),
	(805, '232', '232', 232),
	(805, '233', '233', 233),
	(805, '234', '234', 234),
	(805, '235', '235', 235),
	(805, '236', '236', 236),
	(805, '237', '237', 237),
	(805, '238', '238', 238),
	(805, '239', '239', 239),
	(805, '24', '24', 24),
	(805, '240', '240', 240),
	(805, '241', '241', 241),
	(805, '242', '242', 242),
	(805, '243', '243', 243),
	(805, '244', '244', 244),
	(805, '245', '245', 245),
	(805, '246', '246', 246),
	(805, '247', '247', 247),
	(805, '248', '248', 248),
	(805, '249', '249', 249),
	(805, '25', '25', 25),
	(805, '250', '250', 250),
	(805, '251', '251', 251),
	(805, '252', '252', 252),
	(805, '253', '253', 253),
	(805, '254', '254', 254),
	(805, '255', '255', 255),
	(805, '256', '256', 256),
	(805, '257', '257', 257),
	(805, '258', '258', 258),
	(805, '259', '259', 259),
	(805, '26', '26', 26),
	(805, '260', '260', 260),
	(805, '261', '261', 261),
	(805, '262', '262', 262),
	(805, '263', '263', 263),
	(805, '264', '264', 264),
	(805, '265', '265', 265),
	(805, '266', '266', 266),
	(805, '267', '267', 267),
	(805, '268', '268', 268),
	(805, '269', '269', 269),
	(805, '27', '27', 27),
	(805, '270', '270', 270),
	(805, '271', '271', 271),
	(805, '272', '272', 272),
	(805, '273', '273', 273),
	(805, '274', '274', 274),
	(805, '275', '275', 275),
	(805, '276', '276', 276),
	(805, '277', '277', 277),
	(805, '278', '278', 278),
	(805, '279', '279', 279),
	(805, '28', '28', 28),
	(805, '280', '280', 280),
	(805, '281', '281', 281),
	(805, '282', '282', 282),
	(805, '283', '283', 283),
	(805, '284', '284', 284),
	(805, '285', '285', 285),
	(805, '286', '286', 286),
	(805, '287', '287', 287),
	(805, '288', '288', 288),
	(805, '289', '289', 289),
	(805, '29', '29', 29),
	(805, '290', '290', 290),
	(805, '291', '291', 291),
	(805, '292', '292', 292),
	(805, '293', '293', 293),
	(805, '294', '294', 294),
	(805, '295', '295', 295),
	(805, '296', '296', 296),
	(805, '297', '297', 297),
	(805, '298', '298', 298),
	(805, '299', '299', 299),
	(805, '3', '3', 3),
	(805, '30', '30', 30),
	(805, '300', '300', 300),
	(805, '301', '301', 301),
	(805, '302', '302', 302),
	(805, '303', '303', 303),
	(805, '304', '304', 304),
	(805, '305', '305', 305),
	(805, '306', '306', 306),
	(805, '307', '307', 307),
	(805, '308', '308', 308),
	(805, '309', '309', 309),
	(805, '31', '31', 31),
	(805, '310', '310', 310),
	(805, '311', '311', 311),
	(805, '312', '312', 312),
	(805, '313', '313', 313),
	(805, '314', '314', 314),
	(805, '315', '315', 315),
	(805, '316', '316', 316),
	(805, '317', '317', 317),
	(805, '318', '318', 318),
	(805, '319', '319', 319),
	(805, '32', '32', 32),
	(805, '320', '320', 320),
	(805, '321', '321', 321),
	(805, '322', '322', 322),
	(805, '323', '323', 323),
	(805, '324', '324', 324),
	(805, '325', '325', 325),
	(805, '326', '326', 326),
	(805, '327', '327', 327),
	(805, '328', '328', 328),
	(805, '329', '329', 329),
	(805, '33', '33', 33),
	(805, '330', '330', 330),
	(805, '331', '331', 331),
	(805, '332', '332', 332),
	(805, '333', '333', 333),
	(805, '334', '334', 334),
	(805, '335', '335', 335),
	(805, '336', '336', 336),
	(805, '337', '337', 337),
	(805, '338', '338', 338),
	(805, '339', '339', 339),
	(805, '34', '34', 34),
	(805, '340', '340', 340),
	(805, '341', '341', 341),
	(805, '342', '342', 342),
	(805, '343', '343', 343),
	(805, '344', '344', 344),
	(805, '345', '345', 345),
	(805, '346', '346', 346),
	(805, '347', '347', 347),
	(805, '348', '348', 348),
	(805, '349', '349', 349),
	(805, '35', '35', 35),
	(805, '350', '350', 350),
	(805, '351', '351', 351),
	(805, '352', '352', 352),
	(805, '353', '353', 353),
	(805, '354', '354', 354),
	(805, '355', '355', 355),
	(805, '356', '356', 356),
	(805, '357', '357', 357),
	(805, '358', '358', 358),
	(805, '359', '359', 359),
	(805, '36', '36', 36),
	(805, '360', '360', 360),
	(805, '361', '361', 361),
	(805, '362', '362', 362),
	(805, '363', '363', 363),
	(805, '364', '364', 364),
	(805, '365', '365', 365),
	(805, '366', '366', 366),
	(805, '367', '367', 367),
	(805, '368', '368', 368),
	(805, '369', '369', 369),
	(805, '37', '37', 37),
	(805, '370', '370', 370),
	(805, '371', '371', 371),
	(805, '372', '372', 372),
	(805, '373', '373', 373),
	(805, '374', '374', 374),
	(805, '375', '375', 375),
	(805, '376', '376', 376),
	(805, '377', '377', 377),
	(805, '378', '378', 378),
	(805, '379', '379', 379),
	(805, '38', '38', 38),
	(805, '380', '380', 380),
	(805, '381', '381', 381),
	(805, '382', '382', 382),
	(805, '383', '383', 383),
	(805, '384', '384', 384),
	(805, '385', '385', 385),
	(805, '386', '386', 386),
	(805, '387', '387', 387),
	(805, '388', '388', 388),
	(805, '389', '389', 389),
	(805, '39', '39', 39),
	(805, '390', '390', 390),
	(805, '391', '391', 391),
	(805, '392', '392', 392),
	(805, '393', '393', 393),
	(805, '394', '394', 394),
	(805, '395', '395', 395),
	(805, '396', '396', 396),
	(805, '397', '397', 397),
	(805, '398', '398', 398),
	(805, '399', '399', 399),
	(805, '4', '4', 4),
	(805, '40', '40', 40),
	(805, '400', '400', 400),
	(805, '401', '401', 401),
	(805, '402', '402', 402),
	(805, '403', '403', 403),
	(805, '404', '404', 404),
	(805, '405', '405', 405),
	(805, '406', '406', 406),
	(805, '407', '407', 407),
	(805, '408', '408', 408),
	(805, '409', '409', 409),
	(805, '41', '41', 41),
	(805, '410', '410', 410),
	(805, '411', '411', 411),
	(805, '412', '412', 412),
	(805, '413', '413', 413),
	(805, '414', '414', 414),
	(805, '415', '415', 415),
	(805, '416', '416', 416),
	(805, '417', '417', 417),
	(805, '418', '418', 418),
	(805, '419', '419', 419),
	(805, '42', '42', 42),
	(805, '420', '420', 420),
	(805, '421', '421', 421),
	(805, '422', '422', 422),
	(805, '423', '423', 423),
	(805, '424', '424', 424),
	(805, '425', '425', 425),
	(805, '426', '426', 426),
	(805, '427', '427', 427),
	(805, '428', '428', 428),
	(805, '429', '429', 429),
	(805, '43', '43', 43),
	(805, '430', '430', 430),
	(805, '431', '431', 431),
	(805, '432', '432', 432),
	(805, '433', '433', 433),
	(805, '434', '434', 434),
	(805, '435', '435', 435),
	(805, '436', '436', 436),
	(805, '437', '437', 437),
	(805, '438', '438', 438),
	(805, '439', '439', 439),
	(805, '44', '44', 44),
	(805, '440', '440', 440),
	(805, '441', '441', 441),
	(805, '442', '442', 442),
	(805, '443', '443', 443),
	(805, '444', '444', 444),
	(805, '445', '445', 445),
	(805, '446', '446', 446),
	(805, '447', '447', 447),
	(805, '448', '448', 448),
	(805, '449', '449', 449),
	(805, '45', '45', 45),
	(805, '450', '450', 450),
	(805, '451', '451', 451),
	(805, '452', '452', 452),
	(805, '453', '453', 453),
	(805, '454', '454', 454),
	(805, '455', '455', 455),
	(805, '456', '456', 456),
	(805, '457', '457', 457),
	(805, '458', '458', 458),
	(805, '459', '459', 459),
	(805, '46', '46', 46),
	(805, '460', '460', 460),
	(805, '461', '461', 461),
	(805, '462', '462', 462),
	(805, '463', '463', 463),
	(805, '464', '464', 464),
	(805, '465', '465', 465),
	(805, '466', '466', 466),
	(805, '467', '467', 467),
	(805, '468', '468', 468),
	(805, '469', '469', 469),
	(805, '47', '47', 47),
	(805, '470', '470', 470),
	(805, '471', '471', 471),
	(805, '472', '472', 472),
	(805, '473', '473', 473),
	(805, '474', '474', 474),
	(805, '475', '475', 475),
	(805, '476', '476', 476),
	(805, '477', '477', 477),
	(805, '478', '478', 478),
	(805, '479', '479', 479),
	(805, '48', '48', 48),
	(805, '480', '480', 480),
	(805, '481', '481', 481),
	(805, '482', '482', 482),
	(805, '483', '483', 483),
	(805, '484', '484', 484),
	(805, '485', '485', 485),
	(805, '486', '486', 486),
	(805, '487', '487', 487),
	(805, '488', '488', 488),
	(805, '489', '489', 489),
	(805, '49', '49', 49),
	(805, '490', '490', 490),
	(805, '491', '491', 491),
	(805, '492', '492', 492),
	(805, '493', '493', 493),
	(805, '494', '494', 494),
	(805, '495', '495', 495),
	(805, '496', '496', 496),
	(805, '497', '497', 497),
	(805, '498', '498', 498),
	(805, '499', '499', 499),
	(805, '5', '5', 5),
	(805, '50', '50', 50),
	(805, '500', '500', 500),
	(805, '501', '501', 501),
	(805, '502', '502', 502),
	(805, '503', '503', 503),
	(805, '504', '504', 504),
	(805, '505', '505', 505),
	(805, '506', '506', 506),
	(805, '507', '507', 507),
	(805, '508', '508', 508),
	(805, '509', '509', 509),
	(805, '51', '51', 51),
	(805, '510', '510', 510),
	(805, '511', '511', 511),
	(805, '512', '512', 512),
	(805, '52', '52', 52),
	(805, '53', '53', 53),
	(805, '54', '54', 54),
	(805, '55', '55', 55),
	(805, '56', '56', 56),
	(805, '57', '57', 57),
	(805, '58', '58', 58),
	(805, '59', '59', 59),
	(805, '6', '6', 6),
	(805, '60', '60', 60),
	(805, '61', '61', 61),
	(805, '62', '62', 62),
	(805, '63', '63', 63),
	(805, '64', '64', 64),
	(805, '65', '65', 65),
	(805, '66', '66', 66),
	(805, '67', '67', 67),
	(805, '68', '68', 68),
	(805, '69', '69', 69),
	(805, '7', '7', 7),
	(805, '70', '70', 70),
	(805, '71', '71', 71),
	(805, '72', '72', 72),
	(805, '73', '73', 73),
	(805, '74', '74', 74),
	(805, '75', '75', 75),
	(805, '76', '76', 76),
	(805, '77', '77', 77),
	(805, '78', '78', 78),
	(805, '79', '79', 79),
	(805, '8', '8', 8),
	(805, '80', '80', 80),
	(805, '81', '81', 81),
	(805, '82', '82', 82),
	(805, '83', '83', 83),
	(805, '84', '84', 84),
	(805, '85', '85', 85),
	(805, '86', '86', 86),
	(805, '87', '87', 87),
	(805, '88', '88', 88),
	(805, '89', '89', 89),
	(805, '9', '9', 9),
	(805, '90', '90', 90),
	(805, '91', '91', 91),
	(805, '92', '92', 92),
	(805, '93', '93', 93),
	(805, '94', '94', 94),
	(805, '95', '95', 95),
	(805, '96', '96', 96),
	(805, '97', '97', 97),
	(805, '98', '98', 98),
	(805, '99', '99', 99),
	(806, '1', ' komercinis profilis', NULL),
	(806, '2', ' pointervalių profilis', NULL),
	(807, '1', ' pagrindinis', NULL),
	(807, '2', ' pagalbinis Nr.1', NULL),
	(807, '3', ' pagalbinis Nr.2', NULL),
	(808, 'MODBUS', 'MODBUS', 1),
	(808, 'MODBUSTCP', 'MODBUSTCP', 1),
	(809, 'Float', 'Float', 1),
	(809, 'Int', 'Int', 2),
	(809, 'Int16', 'Int16', 4),
	(809, 'Word', 'Word', 3),
	(810, '1', '1', 1),
	(810, '10', '10', 10),
	(810, '11', '11', 11),
	(810, '12', '12', 12),
	(810, '13', '13', 13),
	(810, '14', '14', 14),
	(810, '15', '15', 15),
	(810, '16', '16', 16),
	(810, '17', '17', 17),
	(810, '18', '18', 18),
	(810, '19', '19', 19),
	(810, '2', '2', 2),
	(810, '20', '20', 20),
	(810, '21', '21', 21),
	(810, '22', '22', 22),
	(810, '23', '23', 23),
	(810, '24', '24', 24),
	(810, '25', '25', 25),
	(810, '26', '26', 26),
	(810, '27', '27', 27),
	(810, '28', '28', 28),
	(810, '29', '29', 29),
	(810, '3', '3', 3),
	(810, '30', '30', 30),
	(810, '31', '31', 31),
	(810, '4', '4', 4),
	(810, '5', '5', 5),
	(810, '6', '6', 6),
	(810, '7', '7', 7),
	(810, '8', '8', 8),
	(810, '9', '9', 9),
	(811, '0', 'Ne', NULL),
	(811, '1', 'Taip', NULL),
	(811, '2', 'Taip, aukštesniu prioritetu', NULL),
	(812, '30', '0.2', NULL),
	(812, '31', '0.5', NULL),
	(812, '32', '1.0', NULL),
	(812, '33', '2.0', NULL),
	(812, '34', 'nėra', NULL),
	(813, '30', '5 - 7.5 A', NULL),
	(813, '31', '5 - 60 A', NULL),
	(813, '32', '5 - 100 A', NULL),
	(813, '33', '10 - 100 A', NULL),
	(813, '34', '20 - 200 A', NULL),
	(814, '30', '220(160 - 275) V', NULL),
	(814, '31', '3 x 57.7/100 V', NULL),
	(814, '32', '3 x 100 V', NULL),
	(814, '33', '3 x 220/380 V', NULL),
	(814, '34', '3 x 57.7/100 V, 3 x 220/380 V', NULL),
	(815, '1', 'vartotojo', NULL),
	(815, '2', 'operatoriaus', NULL),
	(815, '3', 'gamintojo', NULL),
	(816, '1', 'Orman CO-E711 vienfazis', NULL),
	(816, '2', 'Dala CA4-E720 trifazis', NULL),
	(817, '0', 'prietaiso būsenos', NULL),
	(817, '1', 'prietaiso konfigūracija', NULL),
	(818, '1', 'Neužpildytos būtinos ryšio savybės', 1),
	(818, '10', 'Nėra nuskaitymo rezultatų daliai nuskaitomų matavimų', 10),
	(818, '11', 'Nepildoma dalis galiojančių matavimų', 11),
	(818, '12', 'Skylės už senus periodus', 12),
	(818, '13', 'Nepavyko uždaryti', 13),
	(818, '14', 'Nuskaitymo taškui buvo ryšio būklės pasikeitimų', 14),
	(818, '15', 'Archyvą turintiems skaitiklių šaltinių elementams nenustatytas atstatymo gylis', 15),
	(818, '16', 'Neužpildytos rekomenduojamos ryšio savybės', 16),
	(818, '17', 'Nuskaitymo taškui buvo ryšio klaidų', 17),
	(818, '18', 'Šaltinis vienas iš blogiausių pagal klaidų kiekį', 18),
	(818, '19', 'Šaltinis vienas iš blogiausių pagal negaliojančių nuskaitymų kiekį', 19),
	(818, '2', 'Niekada nebuvo matavimų duomenų', 2),
	(818, '20', 'Nuskaitymo taškas vienas iš blogiausių pagal labiausiai užimtus ryšių kanalus', 20),
	(818, '21', 'Daug įvykių', 21),
	(818, '3', 'Neatsako nuskaitymo taškas', 3),
	(818, '4', 'Nesinchronizuotas laikas', 4),
	(818, '5', 'Per paskutines paras nėra duomenų visam nuskaitymo taškui', 5),
	(818, '6', 'Beviltiškos skylės', 6),
	(818, '7', 'Nėra jokių nuskaitymo duomenų', 7),
	(818, '8', 'Nėra duomenų už paskutines paras, nors nuskaitymo taškui yra', 8),
	(818, '9', 'Nėra duomenų už paskutines paras', 9),
	(819, '30', 'neužblokuotas', NULL),
	(819, '31', 'užblokuotas', NULL),
	(820, '1', 'viena užklausa', NULL),
	(820, '2', 'dviem užklausom: atskirai data, atskirai laikas', NULL),
	(821, '31', 'Data ir laikas viena užklausa', NULL),
	(821, '32', 'Data ir laikas atskiromis užklausomis', NULL),
	(822, '30', 'Normoje', NULL),
	(822, '31', 'Aukščiau leistinos ribos', NULL),
	(823, '30', 'Īņńóņńņāóåņ', NULL),
	(823, '31', 'Yra', NULL),
	(824, '30', 'Tvarkingas', NULL),
	(824, '31', 'Sugedęs', NULL),
	(825, '30', 'Yra', NULL),
	(825, '31', 'Īņńóņńņāóåņ', NULL),
	(826, '30', 'Leistina', NULL),
	(826, '31', 'Neleistina', NULL),
	(827, '30', 'Neleistina', NULL),
	(827, '31', 'Leistina', NULL),
	(828, '30', 'Išjungta', NULL),
	(828, '31', 'Įjungta', NULL),
	(829, '30', 'išjungimas', NULL),
	(829, '31', 'suveikimas', NULL),
	(830, '30', 'Īņńóņńņāóåņ', NULL),
	(830, '31', 'yra', NULL),
	(831, '30', 'nebuvo', NULL),
	(831, '31', 'Įūėą', NULL),
	(832, '30', 'neaptiktas', NULL),
	(832, '31', 'aptiktas', NULL),
	(833, '30', 'neaptiktas', NULL),
	(833, '31', 'aptiktas', NULL),
	(834, '30', 'Īņńóņńņāóåņ', NULL),
	(834, '31', 'yra', NULL),
	(835, '30', 'nebuvo', NULL),
	(835, '31', 'buvo', NULL),
	(836, '30', 'Īņńóņńņāóåņ', NULL),
	(836, '31', 'yra', NULL),
	(837, '30', 'nebuvo', NULL),
	(837, '31', 'buvo', NULL),
	(838, '30', 'nelyginė', NULL),
	(838, '31', 'lyginė', NULL),
	(839, '30', 'keturlaidė', NULL),
	(839, '31', 'trilaidė', NULL),
	(840, '30', 'Neperžengtos', NULL),
	(840, '31', 'Peržengtos', NULL),
	(841, '30', 'Negalimas', NULL),
	(841, '31', 'Galimas', NULL),
	(842, '30', 'Nepažeistos', NULL),
	(842, '31', 'Pažeistos', NULL),
	(843, '30', 'Nepažeistos', NULL),
	(843, '31', 'Pažeistos', NULL),
	(844, '30', 'Negalimas', NULL),
	(844, '31', 'Galimas', NULL),
	(845, '30', 'Negalimas', NULL),
	(845, '31', 'Galimas', NULL),
	(846, '30', 'Ķåņ', NULL),
	(846, '31', 'Taip', NULL),
	(847, '30', 'Ķåņ', NULL),
	(847, '31', 'Taip', NULL),
	(848, '30', 'Ķåņ', NULL),
	(848, '31', 'Taip', NULL),
	(849, '30', 'Ķåņ', NULL),
	(849, '31', 'Taip', NULL),
	(850, '30', 'Ķåņ', NULL),
	(850, '31', 'Taip', NULL),
	(851, '30', 'Ķåņ', NULL),
	(851, '31', 'Taip', NULL),
	(852, '30', 'Ķåņ', NULL),
	(852, '31', 'Taip', NULL),
	(853, '30', 'Nepažeistos', NULL),
	(853, '31', 'Pažeistos', NULL),
	(854, '30', 'Nepažeistos', NULL),
	(854, '31', 'Pažeistos', NULL),
	(855, '30', 'Nepažeistos', NULL),
	(855, '31', 'Pažeistos', NULL),
	(856, '30', 'Nepažeistos', NULL),
	(856, '31', 'Pažeistos', NULL),
	(857, '30', 'Ķåņ', NULL),
	(857, '31', 'Yra', NULL),
	(858, '30', 'Ne', NULL),
	(858, '31', 'Taip', NULL),
	(859, '30', 'Ķåņ', NULL),
	(859, '31', 'Yra', NULL),
	(860, '30', 'Neviršyta', NULL),
	(860, '31', 'Viršyta', NULL),
	(861, '30', 'Ķåņ', NULL),
	(861, '31', 'Yra', NULL),
	(862, '30', 'Nepasiekta', NULL),
	(862, '31', 'Pasiekta', NULL),
	(863, '30', 'Išjungtas', NULL),
	(863, '31', 'Įjungtas', NULL),
	(864, '30', 'Ķåņ', NULL),
	(864, '31', 'Yra', NULL),
	(865, '30', 'Ķåņ', NULL),
	(865, '31', 'Yra', NULL),
	(866, '30', 'Užrakinta', NULL),
	(866, '31', 'Atrakinta', NULL),
	(867, '30', 'Užrakinta', NULL),
	(867, '31', 'Atrakinta', NULL),
	(868, '30', 'Užrakinta', NULL),
	(868, '31', 'Atrakinta', NULL),
	(869, '30', 'Neaktyvus', NULL),
	(869, '31', 'Aktyvus', NULL),
	(870, '30', 'Neaktyvus', NULL),
	(870, '31', 'Aktyvus', NULL),
	(871, '30', 'Neaktyvus', NULL),
	(871, '31', 'Aktyvus', NULL),
	(872, '30', 'Neaktyvus', NULL),
	(872, '31', 'Aktyvus', NULL),
	(873, '0', 'Išjungtas', NULL),
	(873, '1', 'Įjungtas', NULL),
	(874, '0', 'Ķåņ', NULL),
	(874, '{3051589D-C331-4F10-BCA2-BE31DB1DB661}', 'Taip', NULL),
	(875, '30', ' pabaiga', NULL),
	(875, '31', ' pradžia', NULL),
	(876, '0', 'laiko neskaityti', NULL),
	(876, '1', 'laiką skaityti, klaidos atveju grąžinti rodmenis be laiko', NULL),
	(876, '2', 'laiką skaityti, klaidos atveju negrąžinti rodmenų', NULL),
	(877, 'MODBUS', 'MODBUS', NULL),
	(877, 'MODBUSTCP', 'MODBUSTCP', NULL),
	(879, '1', '1', NULL),
	(879, '10', '10', NULL),
	(879, '15', '15', NULL),
	(879, '3', '3', NULL),
	(879, '30', '30', NULL),
	(879, '5', '5', NULL),
	(879, '60', '60', NULL),
	(880, '0', 'Sveikos reikšmės, suapvalintos pagal reglamentą', NULL),
	(880, '1', 'Trupmenos, suapvalintos iki 1 ženklo', NULL),
	(880, '2', 'Trupmenos, suapvalintos iki 2 ženklų', NULL),
	(880, '3', 'Trupmenos, suapvalintos iki 3 ženklų', NULL),
	(880, '4', 'Trupmenos, suapvalintos iki 4 ženklų', NULL),
	(880, '5', 'Trupmenos, suapvalintos iki 5 ženklų', NULL),
	(880, '6', 'Trupmenos, suapvalintos iki 6 ženklų', NULL),
	(881, '1', 'taškas', NULL),
	(881, '2', 'kablelis', NULL),
	(882, '0', '0', 0),
	(882, '1', '1', 1),
	(882, '10', '10', 10),
	(882, '100', '100', 100),
	(882, '101', '101', 101),
	(882, '102', '102', 102),
	(882, '103', '103', 103),
	(882, '104', '104', 104),
	(882, '105', '105', 105),
	(882, '106', '106', 106),
	(882, '107', '107', 107),
	(882, '108', '108', 108),
	(882, '109', '109', 109),
	(882, '11', '11', 11),
	(882, '110', '110', 110),
	(882, '111', '111', 111),
	(882, '112', '112', 112),
	(882, '113', '113', 113),
	(882, '114', '114', 114),
	(882, '115', '115', 115),
	(882, '116', '116', 116),
	(882, '117', '117', 117),
	(882, '118', '118', 118),
	(882, '119', '119', 119),
	(882, '12', '12', 12),
	(882, '120', '120', 120),
	(882, '121', '121', 121),
	(882, '122', '122', 122),
	(882, '123', '123', 123),
	(882, '124', '124', 124),
	(882, '125', '125', 125),
	(882, '126', '126', 126),
	(882, '127', '127', 127),
	(882, '128', '128', 128),
	(882, '129', '129', 129),
	(882, '13', '13', 13),
	(882, '130', '130', 130),
	(882, '131', '131', 131),
	(882, '132', '132', 132),
	(882, '133', '133', 133),
	(882, '134', '134', 134),
	(882, '135', '135', 135),
	(882, '136', '136', 136),
	(882, '137', '137', 137),
	(882, '138', '138', 138),
	(882, '139', '139', 139),
	(882, '14', '14', 14),
	(882, '140', '140', 140),
	(882, '141', '141', 141),
	(882, '142', '142', 142),
	(882, '143', '143', 143),
	(882, '144', '144', 144),
	(882, '145', '145', 145),
	(882, '146', '146', 146),
	(882, '147', '147', 147),
	(882, '148', '148', 148),
	(882, '149', '149', 149),
	(882, '15', '15', 15),
	(882, '150', '150', 150),
	(882, '151', '151', 151),
	(882, '152', '152', 152),
	(882, '153', '153', 153),
	(882, '154', '154', 154),
	(882, '155', '155', 155),
	(882, '156', '156', 156),
	(882, '157', '157', 157),
	(882, '158', '158', 158),
	(882, '159', '159', 159),
	(882, '16', '16', 16),
	(882, '160', '160', 160),
	(882, '161', '161', 161),
	(882, '162', '162', 162),
	(882, '163', '163', 163),
	(882, '164', '164', 164),
	(882, '165', '165', 165),
	(882, '166', '166', 166),
	(882, '167', '167', 167),
	(882, '168', '168', 168),
	(882, '169', '169', 169),
	(882, '17', '17', 17),
	(882, '170', '170', 170),
	(882, '171', '171', 171),
	(882, '172', '172', 172),
	(882, '173', '173', 173),
	(882, '174', '174', 174),
	(882, '175', '175', 175),
	(882, '176', '176', 176),
	(882, '177', '177', 177),
	(882, '178', '178', 178),
	(882, '179', '179', 179),
	(882, '18', '18', 18),
	(882, '180', '180', 180),
	(882, '181', '181', 181),
	(882, '182', '182', 182),
	(882, '183', '183', 183),
	(882, '184', '184', 184),
	(882, '185', '185', 185),
	(882, '186', '186', 186),
	(882, '187', '187', 187),
	(882, '188', '188', 188),
	(882, '189', '189', 189),
	(882, '19', '19', 19),
	(882, '190', '190', 190),
	(882, '191', '191', 191),
	(882, '192', '192', 192),
	(882, '193', '193', 193),
	(882, '194', '194', 194),
	(882, '195', '195', 195),
	(882, '196', '196', 196),
	(882, '197', '197', 197),
	(882, '198', '198', 198),
	(882, '199', '199', 199),
	(882, '2', '2', 2),
	(882, '20', '20', 20),
	(882, '200', '200', 200),
	(882, '201', '201', 201),
	(882, '202', '202', 202),
	(882, '203', '203', 203),
	(882, '204', '204', 204),
	(882, '205', '205', 205),
	(882, '206', '206', 206),
	(882, '207', '207', 207),
	(882, '208', '208', 208),
	(882, '209', '209', 209),
	(882, '21', '21', 21),
	(882, '210', '210', 210),
	(882, '211', '211', 211),
	(882, '212', '212', 212),
	(882, '213', '213', 213),
	(882, '214', '214', 214),
	(882, '215', '215', 215),
	(882, '216', '216', 216),
	(882, '217', '217', 217),
	(882, '218', '218', 218),
	(882, '219', '219', 219),
	(882, '22', '22', 22),
	(882, '220', '220', 220),
	(882, '221', '221', 221),
	(882, '222', '222', 222),
	(882, '223', '223', 223),
	(882, '224', '224', 224),
	(882, '225', '225', 225),
	(882, '226', '226', 226),
	(882, '227', '227', 227),
	(882, '228', '228', 228),
	(882, '229', '229', 229),
	(882, '23', '23', 23),
	(882, '230', '230', 230),
	(882, '231', '231', 231),
	(882, '232', '232', 232),
	(882, '233', '233', 233),
	(882, '234', '234', 234),
	(882, '235', '235', 235),
	(882, '236', '236', 236),
	(882, '237', '237', 237),
	(882, '238', '238', 238),
	(882, '239', '239', 239),
	(882, '24', '24', 24),
	(882, '240', '240', 240),
	(882, '241', '241', 241),
	(882, '242', '242', 242),
	(882, '243', '243', 243),
	(882, '244', '244', 244),
	(882, '245', '245', 245),
	(882, '246', '246', 246),
	(882, '247', '247', 247),
	(882, '248', '248', 248),
	(882, '249', '249', 249),
	(882, '25', '25', 25),
	(882, '250', '250', 250),
	(882, '251', '251', 251),
	(882, '252', '252', 252),
	(882, '253', '253', 253),
	(882, '254', '254', 254),
	(882, '255', '255', 255),
	(882, '26', '26', 26),
	(882, '27', '27', 27),
	(882, '28', '28', 28),
	(882, '29', '29', 29),
	(882, '3', '3', 3),
	(882, '30', '30', 30),
	(882, '31', '31', 31),
	(882, '32', '32', 32),
	(882, '33', '33', 33),
	(882, '34', '34', 34),
	(882, '35', '35', 35),
	(882, '36', '36', 36),
	(882, '37', '37', 37),
	(882, '38', '38', 38),
	(882, '39', '39', 39),
	(882, '4', '4', 4),
	(882, '40', '40', 40),
	(882, '41', '41', 41),
	(882, '42', '42', 42),
	(882, '43', '43', 43),
	(882, '44', '44', 44),
	(882, '45', '45', 45),
	(882, '46', '46', 46),
	(882, '47', '47', 47),
	(882, '48', '48', 48),
	(882, '49', '49', 49),
	(882, '5', '5', 5),
	(882, '50', '50', 50),
	(882, '51', '51', 51),
	(882, '52', '52', 52),
	(882, '53', '53', 53),
	(882, '54', '54', 54),
	(882, '55', '55', 55),
	(882, '56', '56', 56),
	(882, '57', '57', 57),
	(882, '58', '58', 58),
	(882, '59', '59', 59),
	(882, '6', '6', 6),
	(882, '60', '60', 60),
	(882, '61', '61', 61),
	(882, '62', '62', 62),
	(882, '63', '63', 63),
	(882, '64', '64', 64),
	(882, '65', '65', 65),
	(882, '66', '66', 66),
	(882, '67', '67', 67),
	(882, '68', '68', 68),
	(882, '69', '69', 69),
	(882, '7', '7', 7),
	(882, '70', '70', 70),
	(882, '71', '71', 71),
	(882, '72', '72', 72),
	(882, '73', '73', 73),
	(882, '74', '74', 74),
	(882, '75', '75', 75),
	(882, '76', '76', 76),
	(882, '77', '77', 77),
	(882, '78', '78', 78),
	(882, '79', '79', 79),
	(882, '8', '8', 8),
	(882, '80', '80', 80),
	(882, '81', '81', 81),
	(882, '82', '82', 82),
	(882, '83', '83', 83),
	(882, '84', '84', 84),
	(882, '85', '85', 85),
	(882, '86', '86', 86),
	(882, '87', '87', 87),
	(882, '88', '88', 88),
	(882, '89', '89', 89),
	(882, '9', '9', 9),
	(882, '90', '90', 90),
	(882, '91', '91', 91),
	(882, '92', '92', 92),
	(882, '93', '93', 93),
	(882, '94', '94', 94),
	(882, '95', '95', 95),
	(882, '96', '96', 96),
	(882, '97', '97', 97),
	(882, '98', '98', 98),
	(882, '99', '99', 99),
	(883, '30', 'MPa', NULL),
	(883, '31', 'kgf/cm2', NULL),
	(884, '30', 'GJ', NULL),
	(884, '31', 'Gcal', NULL),
	(884, '32', 'MWh', NULL),
	(885, '30', 'GJ/h', NULL),
	(885, '31', 'Gcal/h', NULL),
	(885, '32', 'MW', NULL),
	(886, '1801', '$709', NULL),
	(887, 'MODBUS', 'MODBUS', NULL),
	(887, 'MODBUSTCP', 'MODBUSTCP', NULL),
	(888, '1', '1', 1),
	(888, '10', '10', 10),
	(888, '100', '100', 100),
	(888, '101', '101', 101),
	(888, '102', '102', 102),
	(888, '103', '103', 103),
	(888, '104', '104', 104),
	(888, '105', '105', 105),
	(888, '106', '106', 106),
	(888, '107', '107', 107),
	(888, '108', '108', 108),
	(888, '109', '109', 109),
	(888, '11', '11', 11),
	(888, '110', '110', 110),
	(888, '111', '111', 111),
	(888, '112', '112', 112),
	(888, '113', '113', 113),
	(888, '114', '114', 114),
	(888, '115', '115', 115),
	(888, '116', '116', 116),
	(888, '117', '117', 117),
	(888, '118', '118', 118),
	(888, '119', '119', 119),
	(888, '12', '12', 12),
	(888, '120', '120', 120),
	(888, '121', '121', 121),
	(888, '122', '122', 122),
	(888, '123', '123', 123),
	(888, '124', '124', 124),
	(888, '125', '125', 125),
	(888, '126', '126', 126),
	(888, '127', '127', 127),
	(888, '128', '128', 128),
	(888, '129', '129', 129),
	(888, '13', '13', 13),
	(888, '130', '130', 130),
	(888, '131', '131', 131),
	(888, '132', '132', 132),
	(888, '133', '133', 133),
	(888, '134', '134', 134),
	(888, '135', '135', 135),
	(888, '136', '136', 136),
	(888, '137', '137', 137),
	(888, '138', '138', 138),
	(888, '139', '139', 139),
	(888, '14', '14', 14),
	(888, '140', '140', 140),
	(888, '141', '141', 141),
	(888, '142', '142', 142),
	(888, '143', '143', 143),
	(888, '144', '144', 144),
	(888, '145', '145', 145),
	(888, '146', '146', 146),
	(888, '147', '147', 147),
	(888, '148', '148', 148),
	(888, '149', '149', 149),
	(888, '15', '15', 15),
	(888, '150', '150', 150),
	(888, '151', '151', 151),
	(888, '152', '152', 152),
	(888, '153', '153', 153),
	(888, '154', '154', 154),
	(888, '155', '155', 155),
	(888, '156', '156', 156),
	(888, '157', '157', 157),
	(888, '158', '158', 158),
	(888, '159', '159', 159),
	(888, '16', '16', 16),
	(888, '160', '160', 160),
	(888, '161', '161', 161),
	(888, '162', '162', 162),
	(888, '163', '163', 163),
	(888, '164', '164', 164),
	(888, '165', '165', 165),
	(888, '166', '166', 166),
	(888, '167', '167', 167),
	(888, '168', '168', 168),
	(888, '169', '169', 169),
	(888, '17', '17', 17),
	(888, '170', '170', 170),
	(888, '171', '171', 171),
	(888, '172', '172', 172),
	(888, '173', '173', 173),
	(888, '174', '174', 174),
	(888, '175', '175', 175),
	(888, '176', '176', 176),
	(888, '177', '177', 177),
	(888, '178', '178', 178),
	(888, '179', '179', 179),
	(888, '18', '18', 18),
	(888, '180', '180', 180),
	(888, '181', '181', 181),
	(888, '182', '182', 182),
	(888, '183', '183', 183),
	(888, '184', '184', 184),
	(888, '185', '185', 185),
	(888, '186', '186', 186),
	(888, '187', '187', 187),
	(888, '188', '188', 188),
	(888, '189', '189', 189),
	(888, '19', '19', 19),
	(888, '190', '190', 190),
	(888, '191', '191', 191),
	(888, '192', '192', 192),
	(888, '193', '193', 193),
	(888, '194', '194', 194),
	(888, '195', '195', 195),
	(888, '196', '196', 196),
	(888, '197', '197', 197),
	(888, '198', '198', 198),
	(888, '199', '199', 199),
	(888, '2', '2', 2),
	(888, '20', '20', 20),
	(888, '200', '200', 200),
	(888, '201', '201', 201),
	(888, '202', '202', 202),
	(888, '203', '203', 203),
	(888, '204', '204', 204),
	(888, '205', '205', 205),
	(888, '206', '206', 206),
	(888, '207', '207', 207),
	(888, '208', '208', 208),
	(888, '209', '209', 209),
	(888, '21', '21', 21),
	(888, '210', '210', 210),
	(888, '211', '211', 211),
	(888, '212', '212', 212),
	(888, '213', '213', 213),
	(888, '214', '214', 214),
	(888, '215', '215', 215),
	(888, '216', '216', 216),
	(888, '217', '217', 217),
	(888, '218', '218', 218),
	(888, '219', '219', 219),
	(888, '22', '22', 22),
	(888, '220', '220', 220),
	(888, '221', '221', 221),
	(888, '222', '222', 222),
	(888, '223', '223', 223),
	(888, '224', '224', 224),
	(888, '225', '225', 225),
	(888, '226', '226', 226),
	(888, '227', '227', 227),
	(888, '228', '228', 228),
	(888, '229', '229', 229),
	(888, '23', '23', 23),
	(888, '230', '230', 230),
	(888, '231', '231', 231),
	(888, '232', '232', 232),
	(888, '233', '233', 233),
	(888, '234', '234', 234),
	(888, '235', '235', 235),
	(888, '236', '236', 236),
	(888, '237', '237', 237),
	(888, '238', '238', 238),
	(888, '239', '239', 239),
	(888, '24', '24', 24),
	(888, '240', '240', 240),
	(888, '241', '241', 241),
	(888, '242', '242', 242),
	(888, '243', '243', 243),
	(888, '244', '244', 244),
	(888, '245', '245', 245),
	(888, '246', '246', 246),
	(888, '247', '247', 247),
	(888, '248', '248', 248),
	(888, '249', '249', 249),
	(888, '25', '25', 25),
	(888, '250', '250', 250),
	(888, '251', '251', 251),
	(888, '252', '252', 252),
	(888, '253', '253', 253),
	(888, '254', '254', 254),
	(888, '255', '255', 255),
	(888, '26', '26', 26),
	(888, '27', '27', 27),
	(888, '28', '28', 28),
	(888, '29', '29', 29),
	(888, '3', '3', 3),
	(888, '30', '30', 30),
	(888, '31', '31', 31),
	(888, '32', '32', 32),
	(888, '33', '33', 33),
	(888, '34', '34', 34),
	(888, '35', '35', 35),
	(888, '36', '36', 36),
	(888, '37', '37', 37),
	(888, '38', '38', 38),
	(888, '39', '39', 39),
	(888, '4', '4', 4),
	(888, '40', '40', 40),
	(888, '41', '41', 41),
	(888, '42', '42', 42),
	(888, '43', '43', 43),
	(888, '44', '44', 44),
	(888, '45', '45', 45),
	(888, '46', '46', 46),
	(888, '47', '47', 47),
	(888, '48', '48', 48),
	(888, '49', '49', 49),
	(888, '5', '5', 5),
	(888, '50', '50', 50),
	(888, '51', '51', 51),
	(888, '52', '52', 52),
	(888, '53', '53', 53),
	(888, '54', '54', 54),
	(888, '55', '55', 55),
	(888, '56', '56', 56),
	(888, '57', '57', 57),
	(888, '58', '58', 58),
	(888, '59', '59', 59),
	(888, '6', '6', 6),
	(888, '60', '60', 60),
	(888, '61', '61', 61),
	(888, '62', '62', 62),
	(888, '63', '63', 63),
	(888, '64', '64', 64),
	(888, '65', '65', 65),
	(888, '66', '66', 66),
	(888, '67', '67', 67),
	(888, '68', '68', 68),
	(888, '69', '69', 69),
	(888, '7', '7', 7),
	(888, '70', '70', 70),
	(888, '71', '71', 71),
	(888, '72', '72', 72),
	(888, '73', '73', 73),
	(888, '74', '74', 74),
	(888, '75', '75', 75),
	(888, '76', '76', 76),
	(888, '77', '77', 77),
	(888, '78', '78', 78),
	(888, '79', '79', 79),
	(888, '8', '8', 8),
	(888, '80', '80', 80),
	(888, '81', '81', 81),
	(888, '82', '82', 82),
	(888, '83', '83', 83),
	(888, '84', '84', 84),
	(888, '85', '85', 85),
	(888, '86', '86', 86),
	(888, '87', '87', 87),
	(888, '88', '88', 88),
	(888, '89', '89', 89),
	(888, '9', '9', 9),
	(888, '90', '90', 90),
	(888, '91', '91', 91),
	(888, '92', '92', 92),
	(888, '93', '93', 93),
	(888, '94', '94', 94),
	(888, '95', '95', 95),
	(888, '96', '96', 96),
	(888, '97', '97', 97),
	(888, '98', '98', 98),
	(888, '99', '99', 99),
	(889, '1', '1', 1),
	(889, '2', '2', 2),
	(890, '1', '1', 1),
	(890, '2', '2', 2),
	(890, '3', '3', 3),
	(891, '0', 'Trupmenos, suapvalintos iki 0 ženklo', NULL),
	(891, '1', 'Trupmenos, suapvalintos iki 1 ženklo', NULL),
	(891, '2', 'Trupmenos, suapvalintos iki 2 ženklų', NULL),
	(891, '3', 'Trupmenos, suapvalintos iki 3 ženklų', NULL),
	(891, '4', 'Trupmenos, suapvalintos iki 4 ženklų', NULL),
	(891, '5', 'Trupmenos, suapvalintos iki 5 ženklų', NULL),
	(891, '6', 'Trupmenos, suapvalintos iki 6 ženklų', NULL),
	(892, '0', 'loginis ir fizinis adresai sutampa', NULL),
	(892, '1', 'gautas adresas sumažinamas 1-etu', NULL),
	(894, '1', 'be autorizacijos', NULL),
	(894, '2', 'su slaptažodžiu', NULL),
	(895, 'ASCII', 'ASCII', NULL),
	(895, 'binary', 'binary', NULL),
	(899, '215', 'MCL', NULL),
	(899, '230', 'Corax', NULL),
	(900, '30', 'normoje', NULL),
	(900, '31', 'klaidinga', NULL),
	(901, '30', 'pabaiga', NULL),
	(901, '31', 'pradžia', NULL),
	(902, '30', 'įvyko', NULL),
	(902, '31', 'neįvyko', NULL),
	(903, '1', 'pagrindinis profilis', NULL),
	(903, '2', 'antras profilis', NULL),
	(903, '3', 'trumpas profilis', NULL),
	(904, '30', 'teisingas', NULL),
	(904, '31', 'neteisingas', NULL),
	(905, '30', 'pakanka', NULL),
	(905, '31', 'nepakanka', NULL),
	(906, '30', 'dingo', NULL),
	(906, '31', 'atsistatė', NULL),
	(907, '30', 'Nenaudojama', NULL),
	(907, '31', 'Naudojamas ir paduodamas', NULL),
	(907, '32', 'Naudojamas ir grįžtamas', NULL),
	(907, '33', 'Naudojamas ir pamaitinimas ar KVT', NULL),
	(908, '30', 'Magistralė su atviru padavimu. Matuojami G1, G2 ', NULL),
	(908, '31', 'Uždara magistralė, Paduodami vamzdynai', NULL),
	(908, '32', 'Uždara magistralė, Grįžtami vamzdynai', NULL),
	(908, '33', 'Magistralė su atviru padavimu. Matuojami G1, G2, G3 ', NULL),
	(908, '34', 'Magistralė su atviru padavimu. Matuojami G1, G3 ', NULL),
	(908, '35', 'Magistralė su atviru padavimu. Matuojami G2, G3 ', NULL),
	(909, '30', 'uždarytas', NULL),
	(909, '31', 'atidarytas', NULL),
	(910, '30', 'pabaiga', NULL),
	(910, '31', 'pradžia', NULL),
	(911, '30', 'pabaiga', NULL),
	(911, '31', 'pradžia', NULL),
	(912, '30', 'pabaiga', NULL),
	(912, '31', 'pradžia', NULL),
	(913, '30', 'pabaiga', NULL),
	(913, '31', 'pradžia', NULL),
	(914, '30', 'gerai', NULL),
	(914, '31', 'blogai', NULL),
	(915, '30', 'gerai', NULL),
	(915, '31', 'blogai', NULL),
	(916, '30', 'nesėkmingai', NULL),
	(916, '31', 'sėkmingai', NULL),
	(917, '30', 'aktivuotas', NULL),
	(917, '31', 'pasibaigė', NULL),
	(918, '30', 'aktivuotas', NULL),
	(918, '31', 'pasibaigė', NULL),
	(919, '30', 'atsijungė', NULL),
	(919, '31', 'prisijungė', NULL),
	(924, '30', 'Ne', NULL),
	(924, '31', 'S (soketas)', NULL),
	(924, '32', 'A (ANSI pajungimo pagrindas)', NULL),
	(924, '33', 'K', NULL),
	(924, '34', 'IEC pajungimo pagrindas', NULL),
	(924, '35', 'Komutatorius', NULL),
	(924, '36', 'Statusis montažas', NULL),
	(924, '37', 'B', NULL),
	(924, '38', 'P (Kanados standartas)', NULL),
	(925, '30', 'Autonuskaitymas ir galios numetimas kontroliuojamas atskirai', NULL),
	(925, '31', 'Autoskaitymas kiekviena kartą numetant galią', NULL),
	(925, '32', 'Galios numetimas autonuskaitant', NULL),
	(925, '33', 'Autonuskaitymas ir galios numetimas vienu metu', NULL),
	(926, '30', 'Aktyvinė energija priėmimas', NULL),
	(926, '31', 'Reaktyvinė energija priėmimas', NULL),
	(926, '3132', 'Suminė aktyvinė energija (priėmimas + atidavimas)', NULL),
	(926, '3133', 'Tinklo aktyvinė energija (priėmimas + atidavimas)', NULL),
	(926, '3134', 'Q1+Q4 reaktyvinė energija', NULL),
	(926, '3135', 'Q2+Q3 reaktyvinė energija', NULL),
	(926, '3136', 'Reaktyvinė suminė energija', NULL),
	(926, '313635', 'Aktyvinė galia', NULL),
	(926, '313636', 'Reaktyvinė galia', NULL),
	(926, '313637', 'A fazės galios koeficientas ', NULL),
	(926, '313638', 'B fazės galios koeficientas', NULL),
	(926, '313639', 'C fazės galios koeficientas', NULL),
	(926, '313730', 'Galios koeficientas', NULL),
	(926, '313731', 'A fazės galios koeficientas laipsniais', NULL),
	(926, '313732', 'B fazės galios koeficientas laipsniais', NULL),
	(926, '313733', 'C fazės galios koeficientas laipsniais', NULL),
	(926, '313735', 'A fazės srovės kampas laipsniais', NULL),
	(926, '313736', 'B fazės srovės kampas laipsniais', NULL),
	(926, '313737', 'C fazės srovės kampas laipsniais', NULL),
	(926, '313738', 'A fazės reaktyvinė galia', NULL),
	(926, '313739', 'B fazės reaktyvinė galia', NULL),
	(926, '313830', 'C fazės reaktyvinė galia', NULL),
	(926, '313831', 'Reaktyvinė galia', NULL),
	(926, '32', 'Aktyvinė energija atidavimas', NULL),
	(926, '3230', 'Reaktyvinė tinklo energija', NULL),
	(926, '3231', 'Pilnoji energija priėmimas', NULL),
	(926, '3235', 'Pilnoji energija atidavimas', NULL),
	(926, '33', 'Reaktyvinė energija atidavimas', NULL),
	(926, '3330', 'Pilnoji suminė energija', NULL),
	(926, '3331', 'Dabartinis vidutinis galios koeficientas priėmimas', NULL),
	(926, '3335', 'Dabartinis vidutinis galios koeficientas atidavimas', NULL),
	(926, '34', 'Q1 reaktyvinė energija', NULL),
	(926, '35', 'Q2 reaktyvinė energija', NULL),
	(926, '3530', 'Dažnis', NULL),
	(926, '3531', 'A fazės srovė', NULL),
	(926, '3532', 'B fazės srovė', NULL),
	(926, '3533', 'C fazės srovė', NULL),
	(926, '3534', 'A fazės įtampa', NULL),
	(926, '3535', 'B fazės įtampa', NULL),
	(926, '3536', 'C fazės įtampa', NULL),
	(926, '3537', 'A fazės galia', NULL),
	(926, '3538', 'B fazės galia', NULL),
	(926, '3539', 'C fazės galia', NULL),
	(926, '36', 'Q3 reaktyvinė energija', NULL),
	(926, '3630', 'A fazės pilnoji galia', NULL),
	(926, '3631', 'B fazės pilnoji galia', NULL),
	(926, '3632', 'C fazės pilnoji galia', NULL),
	(926, '3633', 'Kampas tarp įtampų C ir A fazės', NULL),
	(926, '3634', 'Kampas tarp įtampų A ir B fazės', NULL),
	(926, '3635', 'Kampas tarp įtampų A ir C fazės', NULL),
	(926, '37', 'Q4 reaktyvinė energija', NULL),
	(927, '30', 'Nevykdoma funkcija', NULL),
	(927, '31', 'Perėjimas į vasaros laiką', NULL),
	(927, '3130', '7 sezono pasirinkimas', NULL),
	(927, '3131', '8 sezono pasirinkimas', NULL),
	(927, '3132', '9 sezono pasirinkimas', NULL),
	(927, '3133', '10 sezono pasirinkimas', NULL),
	(927, '3134', '11 sezono pasirinkimas', NULL),
	(927, '3135', '12 sezono pasirinkimas', NULL),
	(927, '3136', '13 sezono pasirinkimas', NULL),
	(927, '3137', '14 sezono pasirinkimas', NULL),
	(927, '3138', '15 sezono pasirinkimas', NULL),
	(927, '3139', '0 specialusis tvarkaraštis', NULL),
	(927, '32', 'Perėjimas į žiemos laiką', NULL),
	(927, '3230', '1 specialusis tvarkaraštis', NULL),
	(927, '3231', '2 specialusis tvarkaraštis', NULL),
	(927, '3232', '3 specialusis tvarkaraštis', NULL),
	(927, '3233', '4 specialusis tvarkaraštis', NULL),
	(927, '3234', '5 specialusis tvarkaraštis', NULL),
	(927, '3235', '6 specialusis tvarkaraštis', NULL),
	(927, '3236', '7 specialusis tvarkaraštis', NULL),
	(927, '3237', '8 specialusis tvarkaraštis', NULL),
	(927, '3238', '9 specialusis tvarkaraštis', NULL),
	(927, '3239', '10 specialusis tvarkaraštis', NULL),
	(927, '33', '0 sezono pasirinkimas', NULL),
	(927, '3330', '11 specialusis tvarkaraštis', NULL),
	(927, '3331', 'Sąrašo pabaiga', NULL),
	(927, '34', '1 sezono pasirinkimas', NULL),
	(927, '35', '2 sezono pasirinkimas', NULL),
	(927, '36', '3 sezono pasirinkimas', NULL),
	(927, '37', '4 sezono pasirinkimas', NULL),
	(927, '38', '5 sezono pasirinkimas', NULL),
	(927, '39', '6 sezono pasirinkimas', NULL),
	(928, '30', '"Periodo" veikimo pakartojimas kiekvieną minutę', NULL),
	(928, '31', 'Sausis', NULL),
	(928, '3130', 'Spalis', NULL),
	(928, '3131', 'Lapkritis', NULL),
	(928, '3132', 'Gruodis', NULL),
	(928, '3133', 'Veikimo pakartojimas kas mėnesį', NULL),
	(928, '3134', 'Veikimo pakartojimas kas savaitę', NULL),
	(928, '3135', 'Pakartojimas kiekvieną "Periodą", nusakantys "pririšimo data + delta"', NULL),
	(928, '32', 'Vasaris', NULL),
	(928, '33', 'Kovas', NULL),
	(928, '34', 'Balandis', NULL),
	(928, '35', 'Gegužė', NULL),
	(928, '36', 'Birželis', NULL),
	(928, '37', 'Liepa', NULL),
	(928, '38', 'Rugjūtis', NULL),
	(928, '39', 'Rugsėjis', NULL),
	(929, '30', 'skaidrus', NULL),
	(929, '31', 'komPaf', NULL),
	(929, '32', 'IEC1107 LESTO', NULL),
	(929, '33', 'kintamo greičio pagal užklausą', NULL),
	(929, '35', 'APATOR skaitikliams', NULL),
	(930, '30', 'išjugta', NULL),
	(930, '31', 'vieną kartą per dieną iš pajungto skaitiklio', NULL),
	(930, '3137', 'vieną kartą per dieną iš NTP serverio', NULL),
	(930, '3138', 'vieną kartą per savaitę iš NTP serverio', NULL),
	(930, '3139', 'vieną kartą per mėnesį iš NTP serverio', NULL),
	(930, '32', 'vieną kartą per savaitę iš pajungto skaitiklio', NULL),
	(930, '33', 'vieną kartą per mėnesį iš pajungto skaitiklio', NULL),
	(930, '3332', 'kiekvieną kartą po restarto iš GSM tinklo', NULL),
	(931, '30', 'išjugta', NULL),
	(931, '31', 'įjungta', NULL),
	(932, '30', 'išjugta', NULL),
	(932, '31', 'įjungta', NULL),
	(933, '215', 'MCL', NULL),
	(933, '247', 'ZE114', NULL),
	(934, '0', 'skaitiklis', NULL),
	(934, '1', 'kontroleris', NULL),
	(935, '30', 'Relė nr.4 išjungta', NULL),
	(935, '31', 'Relė nr.4 įjungta', NULL),
	(936, '30', 'Relė nr.5 išjungta', NULL),
	(936, '31', 'Relė nr.5 įjungta', NULL),
	(937, '30', 'atjungta', NULL),
	(937, '31', 'įjungta', NULL),
	(938, '30', 'atjungta', NULL),
	(938, '31', 'įjungta', NULL),
	(939, '30', 'atjungė', NULL),
	(939, '31', 'įjungė', NULL),
	(940, '30', 'uždarytas', NULL),
	(940, '31', 'atidarytas', NULL),
	(941, '30', 'grįžo į normą', NULL),
	(941, '31', 'viršytas', NULL),
	(942, '30', 'grįžo į normą', NULL),
	(942, '31', 'viršytas', NULL),
	(943, '30', 'grįžo į normą', NULL),
	(943, '31', 'viršytas', NULL),
	(944, '30', 'grįžo į normą', NULL),
	(944, '31', 'viršytas', NULL),
	(945, '30', 'nenustatyta', NULL),
	(945, '31', 'nustatyta', NULL),
	(946, '0', '0', 0),
	(946, '1', '1', 1),
	(946, '2', '2', 2),
	(946, '3', '3', 3),
	(947, '0', 'Sezoninis laiko pervedimas uždraustas', NULL),
	(947, '1', 'Sezoninis laiko pervedimas leistas', NULL),
	(948, '30', 'atblokuota', NULL),
	(948, '31', 'užblokuota iki dienos pabaigos', NULL),
	(949, '3', 'Read Holding Registers', NULL),
	(949, '4', 'Read Input Registers', NULL),
	(950, '30', 'Kitas skaitiklis', NULL),
	(950, '31', 'Skaitiklis 100A', NULL),
	(951, '30', 'Nežinomas', NULL),
	(951, '31', 'Radiomodulis 433', NULL),
	(951, '3130', 'Optinis kabelis', NULL),
	(951, '3131', 'Keičiamas modulis', NULL),
	(951, '32', 'RS-485', NULL),
	(951, '33', 'ZigBee', NULL),
	(951, '34', 'Optinis portas', NULL),
	(951, '35', 'GSM/GPRS', NULL),
	(951, '36', 'Radio modulis TPP', NULL),
	(951, '37', 'Radio modulis 868', NULL),
	(951, '38', 'PLC', NULL),
	(951, '39', 'Ethernet', NULL),
	(952, '30', 'Skaitiklis be gatvės apšvietimo', NULL),
	(952, '31', 'Skaitiklis su gatvės apšvietimu', NULL),
	(953, '30', 'Relės valdymo paros grafikas - išjungtas', NULL),
	(953, '31', 'Relės valdymo paros grafikas - įjungtas', NULL),
	(954, '30', 'LCD pašvietimas', NULL),
	(954, '31', 'Reakcija į pajungtas reles', NULL),
	(954, '32', 'Pranešimo išsiuntimas į EMCOS sistemą', NULL),
	(954, '33', 'Pranešimo paruošimas EMCOS sistemai', NULL),
	(955, '30', 'Nenaudojamas', NULL),
	(955, '31', 'Pagal galios viršijimą per integravimo periodą', NULL),
	(955, '32', 'Pagal galios viršijimą integravimo periodo pabaigoje', NULL),
	(955, '33', 'Pagal momentines įtampos viršijimą', NULL),
	(956, '30', 'Nenaudojamas', NULL),
	(956, '31', 'Pagal integravimo periodo pabaigą', NULL),
	(956, '32', 'Per nustatyta laiką', NULL),
	(957, '0', 'gražina visus esamus duomenis(Dump mode)', NULL),
	(957, '1', 'gražina duomenis kurių dar nėra siuntęs(Normal mode)', NULL),
	(958, '30', 'normoje', NULL),
	(958, '31', 'iškrauta', NULL),
	(959, '30', 'įtampa dingo', NULL),
	(959, '31', 'įtampa liko', NULL),
	(960, '30', 'įtampa fazėje dingo', NULL),
	(960, '31', 'įtampa fazėje liko', NULL),
	(961, '30', 'įtampa fazėje dingo', NULL),
	(961, '31', 'įtampa fazėje liko', NULL),
	(962, '30', 'įtampa fazėje dingo', NULL),
	(962, '31', 'įtampa fazėje liko', NULL),
	(963, '30', 'įjungta', NULL),
	(963, '31', 'atjungta', NULL),
	(964, '30', 'įjungta', NULL),
	(964, '31', 'atjungta', NULL),
	(965, '30', 'įjungta', NULL),
	(965, '31', 'atjungta', NULL),
	(966, '0', 'Nežinomas', NULL),
	(966, '1', 'Radiomodulis 433', NULL),
	(966, '10', 'Optinis kabelis', NULL),
	(966, '11', 'Keičiamas modulis', NULL),
	(966, '2', 'RS-485', NULL),
	(966, '3', 'ZigBee', NULL),
	(966, '4', 'Optinis portas', NULL),
	(966, '5', 'GSM/GPRS', NULL),
	(966, '6', 'Radio modulis TPP', NULL),
	(966, '7', 'Radio modulis 868', NULL),
	(966, '8', 'PLC', NULL),
	(966, '9', 'Ethernet', NULL),
	(967, '0', '0', NULL),
	(967, '1', '1', NULL),
	(968, '1', '1', 1),
	(968, '10', '10', 10),
	(968, '11', '11', 11),
	(968, '12', '12', 12),
	(968, '13', '13', 13),
	(968, '14', '14', 14),
	(968, '15', '15', 15),
	(968, '16', '16', 16),
	(968, '17', '17', 17),
	(968, '18', '18', 18),
	(968, '19', '19', 19),
	(968, '2', '2', 2),
	(968, '20', '20', 20),
	(968, '21', '21', 21),
	(968, '22', '22', 22),
	(968, '23', '23', 23),
	(968, '24', '24', 24),
	(968, '25', '25', 25),
	(968, '26', '26', 26),
	(968, '27', '27', 27),
	(968, '28', '28', 28),
	(968, '29', '29', 29),
	(968, '3', '3', 3),
	(968, '30', '30', 30),
	(968, '31', '31', 31),
	(968, '4', '4', 4),
	(968, '5', '5', 5),
	(968, '6', '6', 6),
	(968, '7', '7', 7),
	(968, '8', '8', 8),
	(968, '9', '9', 9),
	(969, '1200', '1200', 3),
	(969, '19200', '19200', 8),
	(969, '2400', '2400', 4),
	(969, '300', '300', 1),
	(969, '4800', '4800', 5),
	(969, '600', '600', 2),
	(969, '7200', '7200', 6),
	(969, '9600', '9600', 7),
	(970, '1', '1', NULL),
	(970, '2', '2', NULL),
	(971, '0', 'Hascheck išjungtas', NULL),
	(971, '1', 'Hascheck įjungtas', NULL),
	(972, '0', 'Neporinis', NULL),
	(972, '1', 'Porinis', NULL),
	(973, '5', '5', 1),
	(973, '6', '6', 2),
	(973, '7', '7', 3),
	(973, '8', '8', 4),
	(974, '214', 'Tiesioginis ryšis su skaitikliu', NULL),
	(974, '255', 'Ryšis su skaitikliu per MIT 5000 MG', NULL),
	(975, '1', '1', 1),
	(975, '2', '2', 2),
	(975, '3', '3', 3),
	(975, '4', '4', 4),
	(975, '5', '5', 5),
	(975, '6', '6', 6),
	(975, '7', '7', 7),
	(976, '1', 'TSRV-031', 1),
	(976, '2', 'TSRV-032', 1),
	(976, '3', 'TSRV-033', 1),
	(976, '4', 'TSRV-034', 1),
	(977, '0', 'fiziniai adresai', NULL),
	(977, '1', 'loginiai adresai', NULL),
	(978, 'Float', 'Float', NULL),
	(978, 'Int', 'Int', NULL),
	(978, 'Int16', 'Int16', NULL),
	(978, 'Word', 'Word', NULL),
	(982, '1', '1', 1),
	(982, '10', '10', 10),
	(982, '11', '11', 11),
	(982, '12', '12', 12),
	(982, '13', '13', 13),
	(982, '14', '14', 14),
	(982, '15', '15', 15),
	(982, '16', '16', 16),
	(982, '17', '17', 17),
	(982, '18', '18', 18),
	(982, '19', '19', 19),
	(982, '2', '2', 2),
	(982, '20', '20', 20),
	(982, '21', '21', 21),
	(982, '22', '22', 22),
	(982, '23', '23', 23),
	(982, '24', '24', 24),
	(982, '3', '3', 3),
	(982, '4', '4', 4),
	(982, '5', '5', 5),
	(982, '6', '6', 6),
	(982, '7', '7', 7),
	(982, '8', '8', 8),
	(982, '9', '9', 9),
	(983, '1', '1', 1),
	(983, '2', '2', 2),
	(983, '3', '3', 3),
	(983, '4', '4', 4),
	(983, '5', '5', 5),
	(983, '6', '6', 6),
	(987, '0', 'per skaitiklį', NULL),
	(987, '1', 'per terminalą', NULL),
	(988, '30', 'Ok', NULL),
	(988, '31', 'klaida', NULL),
	(989, '30', 'Ok', NULL),
	(989, '31', 'klaida', NULL),
	(990, '30', 'Ok', NULL),
	(990, '31', 'klaida', NULL),
	(991, '30', 'Ok', NULL),
	(991, '31', 'klaida', NULL),
	(992, '30', 'Ok', NULL),
	(992, '31', 'klaida', NULL),
	(993, '30', 'nebuvo', NULL),
	(993, '31', 'buvo', NULL),
	(994, '30', 'negalioja', NULL),
	(994, '31', 'galioja', NULL),
	(995, '30', 'nepažeisti', NULL),
	(995, '31', 'pažeisti', NULL),
	(996, '30', 'nepažeista', NULL),
	(996, '31', 'pažeista', NULL),
	(997, '30', 'nepažeistas', NULL),
	(997, '31', 'pažeistas', NULL),
	(998, '30', 'neatvaizduojama', NULL),
	(998, '31', 'atvaizduojama ', NULL),
	(999, '30', 'neatvaizduojama', NULL),
	(999, '31', 'atvaizduojama ', NULL),
	(1000, '30', 'neatvaizduojama', NULL),
	(1000, '31', 'atvaizduojama ', NULL),
	(1001, '30', 'nėra', NULL),
	(1001, '31', 'yra', NULL),
	(1002, '30', 'nėra', NULL),
	(1002, '31', 'yra', NULL),
	(1003, '30', 'nėra', NULL),
	(1003, '31', 'yra', NULL),
	(1004, '30', 'nėra', NULL),
	(1004, '31', 'yra', NULL),
	(1005, '30', 'nėra', NULL),
	(1005, '31', 'yra', NULL),
	(1006, '30', 'nėra', NULL),
	(1006, '31', 'yra', NULL),
	(1007, '30', 'nėra', NULL),
	(1007, '31', 'yra', NULL),
	(1008, '30', 'nėra', NULL),
	(1008, '31', 'yra', NULL),
	(1009, '30', 'nėra', NULL),
	(1009, '31', 'yra', NULL),
	(1010, '30', 'nėra', NULL),
	(1010, '31', 'yra', NULL),
	(1011, '30', 'nėra', NULL),
	(1011, '31', 'yra', NULL),
	(1012, '30', 'nėra', NULL),
	(1012, '31', 'yra', NULL),
	(1013, '30', 'nėra', NULL),
	(1013, '31', 'yra', NULL),
	(1014, '30', 'nėra', NULL),
	(1014, '31', 'yra', NULL),
	(1015, '30', 'nėra', NULL),
	(1015, '31', 'yra', NULL),
	(1016, '30', 'nėra', NULL),
	(1016, '31', 'yra', NULL),
	(1017, '30', 'nėra', NULL),
	(1017, '31', 'yra', NULL),
	(1018, '30', 'nėra', NULL),
	(1018, '31', 'yra', NULL),
	(1019, '30', 'nėra', NULL),
	(1019, '31', 'yra', NULL),
	(1020, '30', 'nėra', NULL),
	(1020, '31', 'yra', NULL),
	(1021, '30', 'nėra', NULL),
	(1021, '31', 'yra', NULL),
	(1022, '30', 'nėra', NULL),
	(1022, '31', 'yra', NULL),
	(1023, '30', 'nėra', NULL),
	(1023, '31', 'yra', NULL),
	(1024, '30', 'nėra', NULL),
	(1024, '31', 'yra', NULL),
	(1025, '30', 'nėra', NULL),
	(1025, '31', 'yra', NULL),
	(1026, '30', 'pabaiga', NULL),
	(1026, '31', 'pradžia', NULL),
	(1027, '30', 'neatjungta', NULL),
	(1027, '31', 'atjungta', NULL),
	(1028, '46616C7365', 'False', NULL),
	(1028, '54727565', 'True', NULL),
	(1029, '46616C7365', 'False', NULL),
	(1029, '54727565', 'True', NULL),
	(1030, '46616C7365', 'False', NULL),
	(1030, '54727565', 'True', NULL),
	(1031, '46616C7365', 'False', NULL),
	(1031, '54727565', 'True', NULL),
	(1032, '1', '1', 1),
	(1032, '2', '2', 2),
	(1032, '3', '3', 3),
	(1032, '4', '4', 4),
	(1032, '5', '5', 5),
	(1032, '6', '6', 6),
	(1032, '7', '7', 7),
	(1032, '8', '8', 8),
	(1032, '9', '9', 9),
	(1033, '1', '1', NULL),
	(1033, '2', '2', NULL),
	(1033, '3', '3', NULL),
	(1034, 'GazModem', 'GazModem', NULL),
	(1034, 'GazModem2', 'GazModem2', NULL),
	(1034, 'MODBUS', 'MODBUS', NULL),
	(1035, '1', '1', NULL),
	(1035, '2', '2', NULL),
	(1036, '1', '1', 1),
	(1036, '2', '2', 2),
	(1036, '3', '3', 3),
	(1036, '4', '4', 4),
	(1036, '5', '5', 5),
	(1036, '6', '6', 6),
	(1036, '7', '7', 7),
	(1036, '8', '8', 8),
	(1037, '30', 'neperžengė', NULL),
	(1037, '31', 'peržengė', NULL),
	(1038, '30', 'neperžengė', NULL),
	(1038, '31', 'peržengė', NULL),
	(1039, '30', 'neperžengė', NULL),
	(1039, '31', 'peržengė', NULL),
	(1040, '30', 'neperžengė', NULL),
	(1040, '31', 'peržengė', NULL),
	(1041, '30', 'neperžengė', NULL),
	(1041, '31', 'peržengė', NULL),
	(1042, '30', 'neviršija', NULL),
	(1042, '31', 'viršyjo', NULL),
	(1043, '30', 'neviršija', NULL),
	(1043, '31', 'viršyjo', NULL),
	(1044, '30', 'neviršija', NULL),
	(1044, '31', 'viršyjo', NULL),
	(1045, '30', 'neviršija', NULL),
	(1045, '31', 'viršyjo', NULL),
	(1046, '30', 'neviršija', NULL),
	(1046, '31', 'viršyjo', NULL),
	(1047, '30', 'neperžengė', NULL),
	(1047, '31', 'peržengė', NULL),
	(1048, '30', 'neperžengė', NULL),
	(1048, '31', 'peržengė', NULL),
	(1049, '30', 'neperžengė', NULL),
	(1049, '31', 'peržengė', NULL),
	(1050, '30', 'neperžengė', NULL),
	(1050, '31', 'peržengė', NULL),
	(1051, '30', 'neviršyja', NULL),
	(1051, '31', 'viršyjo', NULL),
	(1052, '30', 'baigėsi', NULL),
	(1052, '31', 'prasidėjo', NULL),
	(1053, '30', 'iki', NULL),
	(1053, '31', 'nuo', NULL),
	(1054, '30', 'iki', NULL),
	(1054, '31', 'nuo', NULL),
	(1055, '30', 'iki', NULL),
	(1055, '31', 'nuo', NULL),
	(1056, '30', 'iki', NULL),
	(1056, '31', 'nuo', NULL),
	(1057, '30', 'iki', NULL),
	(1057, '31', 'nuo', NULL),
	(1058, '30', 'iki', NULL),
	(1058, '31', 'nuo', NULL),
	(1059, '30', 'iki', NULL),
	(1059, '31', 'nuo', NULL),
	(1060, '30', 'iki', NULL),
	(1060, '31', 'nuo', NULL),
	(1061, '30', 'iki', NULL),
	(1061, '31', 'nuo', NULL),
	(1062, '30', 'iki', NULL),
	(1062, '31', 'nuo', NULL),
	(1063, '30', 'pabaiga', NULL),
	(1063, '31', 'pradžia', NULL),
	(1064, '30', 'pabaiga', NULL),
	(1064, '31', 'pradžia', NULL),
	(1065, '30', 'pabaiga', NULL),
	(1065, '31', 'pradžia', NULL),
	(1066, '30', 'pabaiga', NULL),
	(1066, '31', 'pradžia', NULL),
	(1067, '30', 'uždaras', NULL),
	(1067, '31', 'atviras', NULL),
	(1068, '30', 'iki', NULL),
	(1068, '31', 'nuo', NULL),
	(1069, '30', 'iki', NULL),
	(1069, '31', 'nuo', NULL),
	(1070, '30', 'iki', NULL),
	(1070, '31', 'nuo', NULL),
	(1071, '30', 'iki', NULL),
	(1071, '31', 'nuo', NULL),
	(1072, '30', 'iki', NULL),
	(1072, '31', 'nuo', NULL),
	(1073, '30', 'iki', NULL),
	(1073, '31', 'nuo', NULL),
	(1074, '30', 'iki', NULL),
	(1074, '31', 'nuo', NULL),
	(1075, '30', 'iki', NULL),
	(1075, '31', 'nuo', NULL),
	(1076, '30', 'iki', NULL),
	(1076, '31', 'nuo', NULL),
	(1077, '30', 'iki', NULL),
	(1077, '31', 'nuo', NULL),
	(1078, '30', 'iki', NULL),
	(1078, '31', 'nuo', NULL),
	(1079, '30', 'iki', NULL),
	(1079, '31', 'nuo', NULL),
	(1080, '30', 'iki', NULL),
	(1080, '31', 'nuo', NULL),
	(1081, '30', 'iki', NULL),
	(1081, '31', 'nuo', NULL),
	(1082, '30', 'iki', NULL),
	(1082, '31', 'nuo', NULL),
	(1083, '30', 'neviršyja', NULL),
	(1083, '31', 'viršyjo', NULL),
	(1084, '30', 'neviršyja', NULL),
	(1084, '31', 'viršyjo', NULL),
	(1085, '30', 'neviršyja', NULL),
	(1085, '31', 'viršyjo', NULL),
	(1086, '30', 'iki', NULL),
	(1086, '31', 'nuo', NULL),
	(1087, '30', 'neviršyja', NULL),
	(1087, '31', 'viršyjo', NULL),
	(1088, '30', 'neviršyja', NULL),
	(1088, '31', 'viršyjo', NULL),
	(1089, '30', 'iki', NULL),
	(1089, '31', 'nuo', NULL),
	(1090, '30', 'iki', NULL),
	(1090, '31', 'nuo', NULL),
	(1091, '30', 'neperžengė', NULL),
	(1091, '31', 'peržengė', NULL),
	(1092, '30', 'neviršyja', NULL),
	(1092, '31', 'viršyjo', NULL),
	(1093, '30', 'neperžengė', NULL),
	(1093, '31', 'peržengė', NULL),
	(1094, '30', 'iki', NULL),
	(1094, '31', 'nuo', NULL),
	(1095, '30', 'iki', NULL),
	(1095, '31', 'nuo', NULL),
	(1096, '30', 'iki', NULL),
	(1096, '31', 'nuo', NULL),
	(1097, '30', 'iki', NULL),
	(1097, '31', 'nuo', NULL),
	(1098, '30', 'neviršyja', NULL),
	(1098, '31', 'viršyjo', NULL),
	(1099, '30', 'neviršyja', NULL),
	(1099, '31', 'viršyjo', NULL),
	(1100, '30', 'neviršyja', NULL),
	(1100, '31', 'viršyjo', NULL),
	(1101, '30', 'neviršyja', NULL),
	(1101, '31', 'viršyjo', NULL),
	(1102, '30', 'neperžengė', NULL),
	(1102, '31', 'peržengė', NULL),
	(1103, '30', 'neviršyja', NULL),
	(1103, '31', 'viršyjo', NULL),
	(1104, '30', 'neviršyja', NULL),
	(1104, '31', 'viršyjo', NULL),
	(1105, '30', 'iki', NULL),
	(1105, '31', 'nuo', NULL),
	(1106, '30', 'išjungta', NULL),
	(1106, '31', 'įjungta', NULL),
	(1107, '30', 'neviršyja', NULL),
	(1107, '31', 'viršyjo', NULL),
	(1108, '30', 'baigėsi', NULL),
	(1108, '31', 'prasidėjo', NULL),
	(1109, '30', 'iki', NULL),
	(1109, '31', 'nuo', NULL),
	(1110, '30', 'iki', NULL),
	(1110, '31', 'nuo', NULL),
	(1111, '30', 'iki', NULL),
	(1111, '31', 'nuo', NULL),
	(1112, '30', 'iki', NULL),
	(1112, '31', 'nuo', NULL),
	(1113, '30', 'atsistatė', NULL),
	(1113, '31', 'nutrūko', NULL),
	(1114, '30', 'iki', NULL),
	(1114, '31', 'nuo', NULL),
	(1115, '30', 'pabaiga', NULL),
	(1115, '31', 'pradžia', NULL),
	(1116, '30', 'pabaiga', NULL),
	(1116, '31', 'pradžia', NULL),
	(1117, '30', 'pabaiga', NULL),
	(1117, '31', 'pradžia', NULL),
	(1118, '30', 'pabaiga', NULL),
	(1118, '31', 'pradžia', NULL),
	(1119, '30', 'pabaiga', NULL),
	(1119, '31', 'pradžia', NULL),
	(1120, '30', 'pabaiga', NULL),
	(1120, '31', 'pradžia', NULL),
	(1121, '30', 'pabaiga', NULL),
	(1121, '31', 'pradžia', NULL),
	(1122, '30', 'pabaiga', NULL),
	(1122, '31', 'pradžia', NULL),
	(1123, '30', 'pabaiga', NULL),
	(1123, '31', 'pradžia', NULL),
	(1124, '30', 'pabaiga', NULL),
	(1124, '31', 'pradžia', NULL),
	(1125, '30', 'pabaiga', NULL),
	(1125, '31', 'pradžia', NULL),
	(1126, '30', 'pabaiga', NULL),
	(1126, '31', 'pradžia', NULL),
	(1127, '30', 'pabaiga', NULL),
	(1127, '31', 'pradžia', NULL),
	(1128, '30', 'pabaiga', NULL),
	(1128, '31', 'pradžia', NULL),
	(1129, '30', 'pabaiga', NULL),
	(1129, '31', 'pradžia', NULL),
	(1130, '30', 'pabaiga', NULL),
	(1130, '31', 'pradžia', NULL),
	(1131, '30', 'pabaiga', NULL),
	(1131, '31', 'pradžia', NULL),
	(1132, '30', 'pabaiga', NULL),
	(1132, '31', 'pradžia', NULL),
	(1133, '30', 'pabaiga', NULL),
	(1133, '31', 'pradžia', NULL),
	(1134, '30', 'pabaiga', NULL),
	(1134, '31', 'pradžia', NULL),
	(1135, '30', 'pabaiga', NULL),
	(1135, '31', 'pradžia', NULL),
	(1136, '30', 'pabaiga', NULL),
	(1136, '31', 'pradžia', NULL),
	(1137, '30', 'pabaiga', NULL),
	(1137, '31', 'pradžia', NULL),
	(1138, '30', 'pabaiga', NULL),
	(1138, '31', 'pradžia', NULL),
	(1139, '30', 'atsistatė', NULL),
	(1139, '31', 'dingo', NULL),
	(1140, '30', 'atsistatė', NULL),
	(1140, '31', 'dingo', NULL),
	(1141, '30', 'atsistatė', NULL),
	(1141, '31', 'dingo', NULL),
	(1142, '30', 'atsistatė', NULL),
	(1142, '31', 'dingo', NULL),
	(1143, '30', 'atsistatė', NULL),
	(1143, '31', 'dingo', NULL),
	(1144, '30', 'neviršyja', NULL),
	(1144, '31', 'viršyjo', NULL),
	(1145, '30', 'baigesi', NULL),
	(1145, '31', 'prasidėjo', NULL),
	(1146, '30', 'iki', NULL),
	(1146, '31', 'nuo', NULL),
	(1147, '30', 'baigėsi', NULL),
	(1147, '31', 'prasidėjo', NULL),
	(1148, '30', 'baigėsi', NULL),
	(1148, '31', 'prasidėjo', NULL),
	(1149, '30', 'baigėsi', NULL),
	(1149, '31', 'prasidėjo', NULL),
	(1150, '30', 'baigėsi', NULL),
	(1150, '31', 'prasidėjo', NULL),
	(1151, '30', 'neperžengė', NULL),
	(1151, '31', 'peržengė', NULL),
	(1152, '30', 'neviršyja', NULL),
	(1152, '31', 'viršyja', NULL),
	(1153, '30', 'neperžengė', NULL),
	(1153, '31', 'peržengė', NULL),
	(1154, '30', 'neviršyja', NULL),
	(1154, '31', 'viršyja', NULL),
	(1155, '30', 'neviršyja', NULL),
	(1155, '31', 'viršyja', NULL),
	(1156, '30', 'iki', NULL),
	(1156, '31', 'nuo', NULL),
	(1157, '30', 'pabaiga', NULL),
	(1157, '31', 'pradžia', NULL),
	(1158, '30', 'atsistatymas', NULL),
	(1158, '31', 'dingimas', NULL);
/*!40000 ALTER TABLE `enum_data` ENABLE KEYS */;

-- Dumping structure for table emcor.enum_type
CREATE TABLE IF NOT EXISTS `enum_type` (
  `enum_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Išvardinimų naudojimo tipo ID',
  `enum_type_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Išvardinimų naudojimo tipo kodas',
  `enum_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Išvardinimų naudojimo tipo pavadinimas',
  PRIMARY KEY (`enum_type_id`),
  UNIQUE KEY `enum_type_code_u` (`enum_type_code`),
  UNIQUE KEY `enum_type_name_u` (`enum_type_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Išvardinimų naudojimo tipai';

-- Dumping data for table emcor.enum_type: ~9 rows (approximately)
/*!40000 ALTER TABLE `enum_type` DISABLE KEYS */;
INSERT INTO `enum_type` (`enum_type_id`, `enum_type_code`, `enum_type_name`) VALUES
	(0, 'UNIVERSAL', 'Universalūs išvardinimai'),
	(1, 'ENUM_LPTY', 'Ryšio konfigūracijos išvardinimai'),
	(2, 'ENUM_RPTY_FPTY_XPTY', 'Ataskaitų ir eksporto konfigūracijos išvardinimai'),
	(3, 'ENUM_JOURNAL', 'Žurnalų reikšmių išvardinimai'),
	(4, 'ENUM_DISCRETE', 'Diskretinių signalų reikšmių išvardinimai'),
	(5, 'ENUM_GPTY', 'Grupių savybių išvardinimai'),
	(6, 'ENUM_PPTY', 'Taškų savybių išvardinimai'),
	(7, 'ENUM_MPTY', 'Skaitiklių savybių išvardinimai'),
	(8, 'ENUM_SPTY', 'Sisteminių savybių išvardinimai');
/*!40000 ALTER TABLE `enum_type` ENABLE KEYS */;

-- Dumping structure for table emcor.epty
CREATE TABLE IF NOT EXISTS `epty` (
  `epty_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Sąryšių savybės identifikatorius',
  `epty_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Sąryšių savybės kodas',
  `epty_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Sąryšių savybės pavadinimas',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  `epty_type_id` mediumint(8) unsigned NOT NULL DEFAULT 1 COMMENT 'Sąryšių savybių tipo identifikatorius',
  `epty_numeric` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Požymis, ar sąryšio savybės reikšmė turi būti skaitmeninė',
  PRIMARY KEY (`epty_id`),
  UNIQUE KEY `epty_code_u` (`epty_code`),
  UNIQUE KEY `epty_name_u` (`epty_name`),
  KEY `epty_enum_i` (`enum_id`),
  KEY `epty_type_id_i` (`epty_type_id`),
  CONSTRAINT `epty_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`),
  CONSTRAINT `epty_type_id_fk` FOREIGN KEY (`epty_type_id`) REFERENCES `epty_type` (`epty_type_id`)
) ENGINE=InnoDB AUTO_INCREMENT=49 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Galimų sąryšių savybių sarašas';

-- Dumping data for table emcor.epty: ~24 rows (approximately)
/*!40000 ALTER TABLE `epty` DISABLE KEYS */;
INSERT INTO `epty` (`epty_id`, `epty_code`, `epty_name`, `enum_id`, `epty_type_id`, `epty_numeric`) VALUES
	(10, 'COR_COEF', 'Korekcijos koeficientas', NULL, 1, 1),
	(26, 'Q[XX]', 'Tuščiosios veikos reagento nuostoliai, kvar', NULL, 26, 1),
	(27, 'Q[KZ]', 'Trumpojo jungimo reagento nuostoliai, kvar', NULL, 26, 1),
	(28, 'P[XX]', 'Tuščiosios veikos nuostoliai, kW', NULL, 26, 1),
	(29, 'P[KZ]', 'Trumpojo jungimo nuostoliai, kW', NULL, 26, 1),
	(30, 'S[NOM]', 'Vardinė galia, kVA', NULL, 26, 1),
	(31, 'U[NOM]', 'Vardinė įtampa, kW', NULL, 27, 1),
	(32, 'r[UD]', 'Linijos varža, Om/km', NULL, 27, 1),
	(33, 'L[KL]', 'Linijos ilgis, km', NULL, 27, 1),
	(34, 'cos[F]', 'cos(f)', NULL, 27, 1),
	(35, 'P[XX]1', '1 įvado tansformatoriaus tuščiosios veikos nuostoliai, kW', NULL, 26, 1),
	(36, 'P[XX]2', '2 įvado tansformatoriaus tuščiosios veikos nuostoliai, kW', NULL, 26, 1),
	(37, 'P[KZ]1', '1 įvado tansformatoriaus trumpojo jungimo nuostoliai, kW', NULL, 26, 1),
	(38, 'P[KZ]2', '2 įvado tansformatoriaus trumpojo jungimo nuostoliai, kW', NULL, 26, 1),
	(39, 'S[NOM]1', '1 įvado tansformatoriaus vardinė galia, kVA', NULL, 26, 1),
	(40, 'S[NOM]2', '2 įvado tansformatoriaus vardinė galia, kVA', NULL, 26, 1),
	(41, 'Q[XX]1', '1 įvado tansformatoriaus tuščiosios veikos reagento nuostoliai, kvar', NULL, 26, 1),
	(42, 'Q[XX]2', '2 įvado tansformatoriaus tuščiosios veikos reagento nuostoliai, kvar', NULL, 26, 1),
	(43, 'Q[KZ]1', '1 įvado tansformatoriaus trumpojo jungimo reagento nuostoliai, kvar', NULL, 26, 1),
	(44, 'Q[KZ]2', '2 įvado tansformatoriaus trumpojo jungimo reagento nuostoliai, kvar', NULL, 26, 1),
	(45, 'r[UD]1', 'Linijos varža iki 1 įvado, Om/km', NULL, 27, 1),
	(46, 'r[UD]2', 'Linijos varža iki 2 įvado, Om/km', NULL, 27, 1),
	(47, 'L[KL]1', 'Linijos ilgis iki 1 įvado, km', NULL, 27, 1),
	(48, 'L[KL]2', 'Linijos ilgis iki 2 įvado, km', NULL, 27, 1);
/*!40000 ALTER TABLE `epty` ENABLE KEYS */;

-- Dumping structure for table emcor.epty_type
CREATE TABLE IF NOT EXISTS `epty_type` (
  `epty_type_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Sąryšių savybių tipo identifikatorius',
  `epty_type_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Sąryšių savybių tipo kodas',
  `epty_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Sąryšių savybių tipo pavadinimas',
  PRIMARY KEY (`epty_type_id`),
  UNIQUE KEY `epty_type_code_u` (`epty_type_code`),
  UNIQUE KEY `epty_type_name_u` (`epty_type_name`)
) ENGINE=InnoDB AUTO_INCREMENT=28 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Sąryšių savybių tipai';

-- Dumping data for table emcor.epty_type: ~3 rows (approximately)
/*!40000 ALTER TABLE `epty_type` DISABLE KEYS */;
INSERT INTO `epty_type` (`epty_type_id`, `epty_type_code`, `epty_type_name`) VALUES
	(1, 'OTHER_PROPS', 'Kitos savybės'),
	(26, 'TRANSFORMER_PROPS', 'Transformatoriaus savybės'),
	(27, 'LINE_PROPS', 'Linijos savybės');
/*!40000 ALTER TABLE `epty_type` ENABLE KEYS */;

-- Dumping structure for table emcor.estatus
CREATE TABLE IF NOT EXISTS `estatus` (
  `estatus_id` tinyint(3) unsigned NOT NULL COMMENT 'Vokų statuso identifikatorius',
  `estatus_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Vokų statuso kodas',
  `estatus_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Vokų statuso pavadinimas',
  PRIMARY KEY (`estatus_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Vokų statusai';

-- Dumping data for table emcor.estatus: ~14 rows (approximately)
/*!40000 ALTER TABLE `estatus` DISABLE KEYS */;
INSERT INTO `estatus` (`estatus_id`, `estatus_code`, `estatus_name`) VALUES
	(1, 'Created', 'Sukurtas'),
	(2, 'New', 'Paruoštas vykdymui'),
	(3, 'Delayed', 'Atidėtas'),
	(4, 'Process', 'Vykdomas'),
	(5, 'Extended', 'Pratęsta'),
	(6, 'Subscription', 'Atėjęs per prenumeratą'),
	(7, 'Outdated', 'Pasenęs'),
	(8, 'Cancel', 'Atšauktas'),
	(9, 'Rejected', 'Atmestas'),
	(10, 'PrepareCancel', 'Pasiruošimas atšaukimui'),
	(11, 'SuccessfulEnd', 'Sėkminga pabaiga'),
	(12, 'AbnormalEnd', 'Nenormali pabaiga'),
	(13, 'UnsuccessfulEnd', 'Nesėkminga pabaiga'),
	(14, 'PartlySuccessfulEnd', 'Dalinai sėkminga pabaiga');
/*!40000 ALTER TABLE `estatus` ENABLE KEYS */;

-- Dumping structure for table emcor.eu
CREATE TABLE IF NOT EXISTS `eu` (
  `eu_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo vienetų identifikatorius',
  `eu_code` varchar(10) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo vieneto kodas',
  `eu_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo vieneto pavadinimas',
  PRIMARY KEY (`eu_id`),
  UNIQUE KEY `eu_code_u` (`eu_code`),
  UNIQUE KEY `eu_name_u` (`eu_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimo vienetai';

-- Dumping data for table emcor.eu: ~86 rows (approximately)
/*!40000 ALTER TABLE `eu` DISABLE KEYS */;
INSERT INTO `eu` (`eu_id`, `eu_code`, `eu_name`) VALUES
	(0, 'N/A', 'Be matavimo vienetų'),
	(1, 'kW', 'Kilovatai'),
	(2, 'kWh', 'Kilovatvalandės'),
	(3, 'kVar', 'Kilovarai'),
	(4, 'kVarh', 'Kilovarvalandės'),
	(5, 'A', 'Amperai'),
	(6, 'V', 'Voltai'),
	(7, 'kVA', 'Kilovoltamperai'),
	(8, 'Hz', 'Hercai'),
	(9, '%', 'Procentai'),
	(10, 's', 'Sekundės'),
	(11, 'min', 'Minutės'),
	(12, 'day', 'Paros'),
	(13, 'week', 'Savaitės'),
	(14, 'kA', 'Kiloamperai'),
	(15, 'MA', 'Megaamperai'),
	(16, 'W', 'Vatai'),
	(17, 'Wh', 'Vatvalandės'),
	(18, 'Var', 'Varai'),
	(19, 'MVar', 'Megavarai'),
	(20, 'Varh', 'Varvalandės'),
	(21, 'MVarh', 'Megavarvalandės'),
	(22, 'kV', 'Kilovoltai'),
	(23, 'MV', 'Megavoltai'),
	(24, 'VA', 'Voltamperai'),
	(25, 'MVA', 'Megavoltamperai'),
	(26, 'kHz', 'Kilohercai'),
	(27, '°C', 'Laipsniai Celsijaus'),
	(28, 'bar', 'Barai'),
	(29, 'h', 'Valandos'),
	(30, 'kPa', 'Kilopaskaliai'),
	(31, 'm3', 'Kubiniai metrai'),
	(32, 'm3/h', 'Kubiniai metrai per valandą'),
	(33, 'MW', 'Megavatai'),
	(34, 'MWh', 'Megavatvalandės'),
	(35, 't', 'Tonos'),
	(36, 't/h', 'Tonos per valandą'),
	(37, 'Mhz', 'Megahercai'),
	(38, 'Mbar', 'Megabarai'),
	(39, 'kbar', 'Kilobarai'),
	(40, 'Pa', 'Paskaliai'),
	(41, 'kVAh', 'Kilovoltampervalandės'),
	(42, 'MPa', 'Megapaskaliai'),
	(43, 'kg', 'Kilogramai'),
	(45, 'MVAh', 'Megavoltampervalandės'),
	(46, 'VAh', 'Voltampervalandės'),
	(47, 'g', 'Gramai'),
	(48, 'kcal', 'Kilokalorijos'),
	(49, 'Mcal', 'Megakalorijos'),
	(50, 'Gcal', 'Gigakalorijos'),
	(51, 'J', 'Džiauliai'),
	(52, 'kJ', 'Kilodžiauliai'),
	(53, 'MJ', 'Megadžiauliai'),
	(54, 'GJ', 'Gigadžiauliai'),
	(55, 'cal', 'Kalorijos'),
	(56, '°', 'Laipsniai'),
	(57, 'kJ/kg', 'Kilodžiauliai per kilogramą'),
	(58, 'dB', 'Decibelai'),
	(59, 'kg/m3', 'Kilogramai per kubinį metrą'),
	(60, 'kgf/cm2', 'Kilogramai į kvadratinį centimetrą'),
	(61, 'cal/h', 'Kalorijos per valandą'),
	(62, 'kcal/h', 'Kilokalorijos per valandą'),
	(63, 'Mcal/h', 'Megakalorijos per valandą'),
	(64, 'Gcal/h', 'Gigakalorijos per valandą'),
	(65, 'Om', 'Omai'),
	(66, 'Om*m', 'Ommetrai'),
	(67, 'S', 'Simensai'),
	(68, 'S/m', 'Simensai į metrą'),
	(69, 'F', 'Faradai'),
	(70, 'H', 'Henriai'),
	(71, 'imp/kWh', 'Impulsai kilovatvalandei'),
	(72, 'imp/min', 'Impulsai per minutę'),
	(73, 'kg/h', 'Kilogramai per valandą'),
	(74, 'g/h', 'Gramai per valandą'),
	(75, 'kcal/kg', 'Kilokalorijos per kilogramą'),
	(76, 'J/h', 'Džiauliai per valandą'),
	(77, 'kJ/h', 'Kilodžiauliai per valandą'),
	(78, 'MJ/h', 'Megadžiauliai per valandą'),
	(79, 'GJ/h', 'Gigadžiauliai per valandą'),
	(80, 'm/s', 'Metrai per sekundę'),
	(81, 'ms', 'Milisekundės'),
	(82, 'MJ/m3', 'Megadžiauliai kubiniam metrui'),
	(83, 'mbar', 'Milibaras'),
	(84, 'm', 'Metras'),
	(85, 'mg/m3', 'Miligramas už kubinį metrą'),
	(86, 'l/h', 'Litrai per valandą');
/*!40000 ALTER TABLE `eu` ENABLE KEYS */;

-- Dumping structure for table emcor.eu_map
CREATE TABLE IF NOT EXISTS `eu_map` (
  `in_eu_id` mediumint(8) unsigned NOT NULL COMMENT 'Laiko vienetų identifikatorius įėjime',
  `out_eu_id` mediumint(8) unsigned NOT NULL COMMENT 'Laiko vienetų identifikatorius išėjime',
  `eu_a` double NOT NULL COMMENT 'Vienetų pervedimo daugiklis',
  `eu_b` double NOT NULL COMMENT 'Vienetų pervedimo dėmuo',
  PRIMARY KEY (`in_eu_id`,`out_eu_id`),
  UNIQUE KEY `eu_map_out_eu_u` (`out_eu_id`,`in_eu_id`),
  CONSTRAINT `eu_map_eu_in_fk` FOREIGN KEY (`in_eu_id`) REFERENCES `eu` (`eu_id`) ON DELETE CASCADE,
  CONSTRAINT `eu_map_eu_out_fk` FOREIGN KEY (`out_eu_id`) REFERENCES `eu` (`eu_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo vienetų konvertavimo lentelė';

-- Dumping data for table emcor.eu_map: ~231 rows (approximately)
/*!40000 ALTER TABLE `eu_map` DISABLE KEYS */;
INSERT INTO `eu_map` (`in_eu_id`, `out_eu_id`, `eu_a`, `eu_b`) VALUES
	(1, 16, 1000, 0),
	(1, 33, 0.001, 0),
	(1, 61, 859845.2278589854, 0),
	(1, 62, 859.8452278589854, 0),
	(1, 63, 0.8598452278589854, 0),
	(1, 64, 0.000859845227858985, 0),
	(1, 76, 3600000, 0),
	(1, 77, 3600, 0),
	(1, 78, 3.6, 0),
	(1, 79, 0.0036, 0),
	(2, 17, 1000, 0),
	(2, 34, 0.001, 0),
	(2, 48, 859.8452278589854, 0),
	(2, 49, 0.8598452278589854, 0),
	(2, 50, 0.000859845227858985, 0),
	(2, 51, 3600000, 0),
	(2, 52, 3600, 0),
	(2, 53, 3.6, 0),
	(2, 54, 0.0036, 0),
	(2, 55, 859845.2278589854, 0),
	(3, 18, 1000, 0),
	(3, 19, 0.001, 0),
	(4, 20, 1000, 0),
	(4, 21, 0.001, 0),
	(5, 14, 0.001, 0),
	(5, 15, 0.000001, 0),
	(6, 22, 0.001, 0),
	(6, 23, 0.000001, 0),
	(7, 24, 1000, 0),
	(7, 25, 0.001, 0),
	(8, 26, 0.001, 0),
	(8, 37, 0.000001, 0),
	(10, 11, 0.016666666666666666, 0),
	(10, 12, 0.000011574074074074, 0),
	(10, 13, 0.000001653439153439, 0),
	(10, 29, 0.000277777777777778, 0),
	(11, 10, 60, 0),
	(11, 12, 0.000694444444444444, 0),
	(11, 13, 0.000099206349206349, 0),
	(11, 29, 0.016666666666666666, 0),
	(12, 10, 86400, 0),
	(12, 11, 1440, 0),
	(12, 13, 0.14285714285714285, 0),
	(12, 29, 24, 0),
	(13, 10, 604800, 0),
	(13, 11, 10080, 0),
	(13, 12, 7, 0),
	(13, 29, 168, 0),
	(14, 5, 1000, 0),
	(14, 15, 0.001, 0),
	(15, 5, 1000000, 0),
	(15, 14, 1000, 0),
	(16, 1, 0.001, 0),
	(16, 33, 0.000001, 0),
	(17, 2, 0.001, 0),
	(17, 34, 0.000001, 0),
	(17, 48, 0.8598452278589854, 0),
	(17, 49, 0.000859845227858985, 0),
	(17, 50, 0.000000859845227859, 0),
	(17, 51, 3600, 0),
	(17, 52, 3.6, 0),
	(17, 53, 0.0036, 0),
	(17, 54, 0.0000036, 0),
	(17, 55, 859.8452278589854, 0),
	(18, 3, 0.001, 0),
	(18, 19, 0.000001, 0),
	(19, 3, 1000, 0),
	(19, 18, 1000000, 0),
	(20, 4, 0.001, 0),
	(20, 21, 0.000001, 0),
	(21, 4, 1000, 0),
	(21, 20, 1000000, 0),
	(22, 6, 1000, 0),
	(22, 23, 0.001, 0),
	(23, 6, 1000000, 0),
	(23, 22, 1000, 0),
	(24, 7, 0.001, 0),
	(24, 25, 0.000001, 0),
	(25, 7, 1000, 0),
	(25, 24, 1000000, 0),
	(26, 8, 1000, 0),
	(26, 37, 0.001, 0),
	(28, 30, 100, 0),
	(28, 38, 0.000001, 0),
	(28, 39, 0.001, 0),
	(28, 40, 100000, 0),
	(28, 42, 0.1, 0),
	(28, 60, 1.0197162129779282, 0),
	(28, 83, 1000, 0),
	(29, 10, 3600, 0),
	(29, 11, 60, 0),
	(29, 12, 0.041666666666666664, 0),
	(29, 13, 0.005952380952380952, 0),
	(30, 28, 0.01, 0),
	(30, 40, 1000, 0),
	(30, 42, 0.001, 0),
	(30, 60, 0.010197162129779282, 0),
	(30, 83, 10, 0),
	(32, 86, 1000, 0),
	(33, 1, 1000, 0),
	(33, 16, 1000000, 0),
	(34, 2, 1000, 0),
	(34, 17, 1000000, 0),
	(34, 48, 859845.2278589854, 0),
	(34, 49, 859.8452278589854, 0),
	(34, 50, 0.8598452278589854, 0),
	(34, 51, 3600000000, 0),
	(34, 52, 3600000, 0),
	(34, 53, 3600, 0),
	(34, 54, 3.6, 0),
	(34, 55, 859845227.8589854, 0),
	(35, 43, 1000, 0),
	(35, 47, 1000000, 0),
	(36, 73, 1000, 0),
	(36, 74, 1000000, 0),
	(37, 8, 1000000, 0),
	(37, 26, 1000, 0),
	(38, 28, 1000000, 0),
	(38, 39, 1000, 0),
	(38, 60, 1019716.213, 0),
	(38, 83, 1000000000, 0),
	(39, 28, 1000, 0),
	(39, 38, 0.001, 0),
	(39, 60, 1019.716213, 0),
	(39, 83, 1000000, 0),
	(40, 28, 0.00001, 0),
	(40, 30, 0.001, 0),
	(40, 42, 0.000001, 0),
	(40, 60, 0.000010197162129779, 0),
	(40, 83, 0.01, 0),
	(41, 45, 0.001, 0),
	(41, 46, 1000, 0),
	(42, 28, 10, 0),
	(42, 30, 1000, 0),
	(42, 40, 1000000, 0),
	(42, 60, 10.197162129779283, 0),
	(42, 83, 10000, 0),
	(43, 35, 0.001, 0),
	(43, 47, 1000, 0),
	(45, 41, 1000, 0),
	(45, 46, 1000000, 0),
	(46, 41, 0.001, 0),
	(46, 45, 0.000001, 0),
	(47, 35, 0.000001, 0),
	(47, 43, 0.001, 0),
	(48, 2, 0.001163, 0),
	(48, 17, 1.163, 0),
	(48, 34, 0.000001163, 0),
	(48, 49, 0.001, 0),
	(48, 50, 0.000001, 0),
	(48, 55, 1000, 0),
	(49, 2, 1.163, 0),
	(49, 17, 1163, 0),
	(49, 34, 0.001163, 0),
	(49, 48, 1000, 0),
	(49, 50, 0.001, 0),
	(49, 55, 1000000, 0),
	(50, 2, 1163, 0),
	(50, 17, 1163000, 0),
	(50, 34, 1.163, 0),
	(50, 48, 1000000, 0),
	(50, 49, 1000, 0),
	(50, 55, 1000000000, 0),
	(51, 2, 0.000000277777777778, 0),
	(51, 17, 0.000277777777777778, 0),
	(51, 34, 0.000000000277777778, 0),
	(51, 52, 0.001, 0),
	(51, 53, 0.000001, 0),
	(51, 54, 0.000000001, 0),
	(52, 2, 0.000277777777777778, 0),
	(52, 17, 0.2777777777777778, 0),
	(52, 34, 0.000000277777777778, 0),
	(52, 51, 1000, 0),
	(52, 53, 0.001, 0),
	(52, 54, 0.000001, 0),
	(53, 2, 0.2777777777777778, 0),
	(53, 17, 277.77777777777777, 0),
	(53, 34, 0.000277777777777778, 0),
	(53, 51, 1000000, 0),
	(53, 52, 1000, 0),
	(53, 54, 0.001, 0),
	(54, 2, 277.77777777777777, 0),
	(54, 17, 277777.77777777775, 0),
	(54, 34, 0.2777777777777778, 0),
	(54, 51, 1000000000, 0),
	(54, 52, 1000000, 0),
	(54, 53, 1000, 0),
	(55, 2, 0.000001163, 0),
	(55, 17, 0.001163, 0),
	(55, 34, 0.000000001163, 0),
	(55, 48, 0.001, 0),
	(55, 49, 0.000001, 0),
	(55, 50, 0.000000001, 0),
	(57, 75, 0.2388458966274959, 0),
	(60, 28, 0.980665, 0),
	(60, 30, 98.0665, 0),
	(60, 38, 0.000000980664999979, 0),
	(60, 39, 0.000980664999978774, 0),
	(60, 40, 98066.5, 0),
	(60, 42, 0.0980665, 0),
	(60, 83, 980.665, 0),
	(61, 1, 0.000001163, 0),
	(61, 16, 0.001163, 0),
	(61, 33, 0.000000001163, 0),
	(62, 1, 0.001163, 0),
	(62, 16, 1.163, 0),
	(62, 33, 0.000001163, 0),
	(63, 1, 1.163, 0),
	(63, 16, 1163, 0),
	(63, 33, 0.001163, 0),
	(64, 1, 1163, 0),
	(64, 16, 1163000, 0),
	(64, 33, 1.163, 0),
	(73, 36, 0.001, 0),
	(73, 74, 1000, 0),
	(74, 36, 0.000001, 0),
	(74, 73, 0.001, 0),
	(75, 57, 4.1868, 0),
	(76, 1, 0.000000277777777778, 0),
	(77, 1, 0.000277777777777778, 0),
	(78, 1, 0.2777777777777778, 0),
	(79, 1, 277.77777777777777, 0),
	(83, 28, 0.001, 0),
	(83, 30, 0.1, 0),
	(83, 38, 0.000000001, 0),
	(83, 39, 0.000001, 0),
	(83, 40, 100, 0),
	(83, 42, 0.0001, 0),
	(83, 60, 0.001019716212977928, 0),
	(83, 83, 1, 0),
	(86, 32, 0.001, 0);
/*!40000 ALTER TABLE `eu_map` ENABLE KEYS */;

-- Dumping structure for table emcor.ev
CREATE TABLE IF NOT EXISTS `ev` (
  `ev_id` mediumint(8) unsigned NOT NULL COMMENT 'Įvykio ID',
  `evc_id` tinyint(3) unsigned NOT NULL COMMENT 'Sistemos įvykių klasės identifikatorius',
  `evt_id` mediumint(8) unsigned NOT NULL COMMENT 'Sistemos įvykių tipo identifikatorius',
  `evd_id` bigint(20) unsigned DEFAULT NULL COMMENT 'Įvykio detalus ID',
  `ev_priority` tinyint(3) unsigned NOT NULL COMMENT 'Įvykio prioritetas',
  `ev_time` datetime NOT NULL COMMENT 'Įvykio laikas',
  `ev_msg` varchar(250) COLLATE utf8_bin NOT NULL COMMENT 'Įvykio pranešimas',
  `mdl_id` smallint(5) unsigned NOT NULL COMMENT 'Modulio identifikatorius',
  `src_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `ph_id` int(10) unsigned DEFAULT NULL COMMENT 'Ryšio kanalo identifikatorius',
  `dp_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `point_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo taško identifikatorius',
  `gr_id` int(10) unsigned DEFAULT NULL COMMENT 'Grupės identifikatorius',
  `ev_link` varchar(2048) COLLATE utf8_bin DEFAULT NULL COMMENT 'Nuoroda',
  `ds_id` int(10) unsigned DEFAULT NULL COMMENT 'Apskaitos būsenos signalo identifikatorius',
  `sch_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Tvarkaraščio identifikatorius',
  `das_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  `ml_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Matavimo linijos identifikatorius',
  `sheaf_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Duomenų pluošto identifikatorius',
  PRIMARY KEY (`ev_time`,`ev_id`),
  KEY `ev_dp_i` (`dp_id`,`ev_time`),
  KEY `ev_ds_i` (`ds_id`,`ev_time`),
  KEY `ev_evc_i` (`evc_id`,`ev_time`),
  KEY `ev_evt_i` (`evc_id`,`evt_id`,`ev_time`),
  KEY `ev_gr_i` (`gr_id`,`ev_time`),
  KEY `ev_mdl_i` (`mdl_id`,`ev_time`),
  KEY `ev_ph_i` (`ph_id`,`ev_time`),
  KEY `ev_point_i` (`point_id`,`ev_time`),
  KEY `ev_sch_i` (`sch_id`,`ev_time`),
  KEY `ev_src_i` (`src_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Sistemos įvykiai'
 PARTITION BY RANGE (
    to_days(ev_time))
(PARTITION par_201708 VALUES LESS THAN (736751) ENGINE = InnoDB,
 PARTITION par_201709 VALUES LESS THAN (736758) ENGINE = InnoDB,
 PARTITION par_201710 VALUES LESS THAN (736765) ENGINE = InnoDB);

-- Dumping data for table emcor.ev: ~3 rows (approximately)
/*!40000 ALTER TABLE `ev` DISABLE KEYS */;
/*!40000 ALTER TABLE `ev` ENABLE KEYS */;

-- Dumping structure for table emcor.eva
CREATE TABLE IF NOT EXISTS `eva` (
  `eva_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Įvykių atvejo identifikatorius',
  `eva_code` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'Įvykių atvejo kodas',
  `eva_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Įvykių atvejo pavadinimas',
  `eva_enabled` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Įvykių atvejo naudojimo požymis',
  `eva_immediate` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Įvykių atvejo požymis, ar siųsti pranešimą tuoj pat',
  `eva_block` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Įvykių atvejo požymis, ar laikinai blokuoti siuntimą po pranešimo išsiuntimo',
  `eva_block_duration` mediumint(8) unsigned NOT NULL DEFAULT 60 COMMENT 'Įvykių atvejo siuntimo blokavimo trukmė, min',
  `rpa_id` int(10) unsigned DEFAULT NULL COMMENT 'Automatizuotos ataskaitos identifikatorius',
  `ch_cnt` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Įvykių atvejų kiekio tikrinimo požymis',
  `si_cnt` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Įvykių atvejų kiekio lyginimo ženklas',
  `oc_cnt` mediumint(8) unsigned NOT NULL DEFAULT 0 COMMENT 'Įvykių atvejų kiekio riba',
  `du_cnt` mediumint(8) unsigned NOT NULL DEFAULT 10 COMMENT 'Intervalo, per kurį skaičiuojamas įvykių atvejų kiekis, trukmė, min',
  `ch_pnt` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Susijusių apskaitos taškų kiekio tikrinimo požymis',
  `si_pnt` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Susijusių apskaitos taškų kiekio lyginimo ženklas',
  `oc_pnt` mediumint(8) unsigned NOT NULL DEFAULT 0 COMMENT 'Susijusių apskaitos taškų kiekio riba',
  `du_pnt` mediumint(8) unsigned NOT NULL DEFAULT 10 COMMENT 'Intervalo, per kurį skaičiuojamas susijusių apskaitos taškų kiekis, trukmė, min',
  `ch_dsc` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Susijusių apskaitos būsenų signalų kiekio tikrinimo požymis',
  `si_dsc` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Susijusių apskaitos būsenų signalų kiekio lyginimo ženklas',
  `oc_dsc` mediumint(8) unsigned NOT NULL DEFAULT 0 COMMENT 'Susijusių apskaitos būsenų signalų kiekio riba',
  `du_dsc` mediumint(8) unsigned NOT NULL DEFAULT 10 COMMENT 'Intervalo, per kurį skaičiuojamas susijusių apskaitos būsenų signalų kiekis, trukmė, min',
  `ch_dpt` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Susijusių nuskaitymo taškų kiekio tikrinimo požymis',
  `si_dpt` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Susijusių nuskaitymo taškų kiekio lyginimo ženklas',
  `oc_dpt` mediumint(8) unsigned NOT NULL DEFAULT 0 COMMENT 'Susijusių nuskaitymo taškų kiekio riba',
  `du_dpt` mediumint(8) unsigned NOT NULL DEFAULT 10 COMMENT 'Intervalo, per kurį skaičiuojamas susijusių nuskaitymo taškų kiekis, trukmė, min',
  `ch_grp` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Susijusių grupių kiekio tikrinimo požymis',
  `si_grp` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Susijusių grupių kiekio lyginimo ženklas',
  `oc_grp` mediumint(8) unsigned NOT NULL DEFAULT 0 COMMENT 'Susijusių grupių kiekio riba',
  `du_grp` mediumint(8) unsigned NOT NULL DEFAULT 10 COMMENT 'Intervalo, per kurį skaičiuojamas susijusių grupių kiekis, trukmė, min',
  `eva_blocked_until` datetime DEFAULT NULL COMMENT 'Laikas, iki kurio blokuojamas įvykių atvejis',
  `eva_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Įvykių atvejų tipo identifikatorius',
  `ch_steady` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Požymis, ar siųsti pranešimą tik nusistovėjus būsenai',
  `du_steady` mediumint(8) unsigned DEFAULT NULL COMMENT 'Būsenos nusistovėjimo trukmė, min',
  `steady_type_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Objekto tipo, kuriam identifikuojama nusistovėjusi būsena, identifikatorius',
  `eva_block_type_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Objektų, kuriems atskirai taikomas blokavimas, tipo identifikatorius',
  `bga_id` int(10) unsigned DEFAULT NULL COMMENT 'DB aplikacijos foninės užduoties ID',
  `bgao_status` tinyint(3) unsigned DEFAULT NULL COMMENT 'DB aplikacijos foninių užduočių vykdymo užsakymo būsena',
  `ignore_steady_val_restore` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Požymis, ar nesiųsti pranešimo, jei nusistovėjusios būsenos reikšmė sutampa su ankstesne',
  PRIMARY KEY (`eva_id`),
  UNIQUE KEY `eva_code_u` (`eva_code`),
  UNIQUE KEY `eva_name_u` (`eva_name`),
  KEY `eva_bga_i` (`bga_id`),
  KEY `eva_evac_type_i` (`steady_type_id`),
  KEY `eva_eva_type_i` (`eva_type_id`),
  KEY `eva_rpa_i` (`rpa_id`),
  CONSTRAINT `eva_bga_fk` FOREIGN KEY (`bga_id`) REFERENCES `bga` (`bga_id`) ON DELETE CASCADE,
  CONSTRAINT `eva_eva_type_fk` FOREIGN KEY (`eva_type_id`) REFERENCES `eva_type` (`eva_type_id`),
  CONSTRAINT `eva_evac_type_fk` FOREIGN KEY (`steady_type_id`) REFERENCES `evac_type` (`evac_type_id`),
  CONSTRAINT `eva_rpa_fk` FOREIGN KEY (`rpa_id`) REFERENCES `rpa` (`rpa_id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Įvykių atvejai';

-- Dumping data for table emcor.eva: ~4 rows (approximately)
/*!40000 ALTER TABLE `eva` DISABLE KEYS */;
INSERT INTO `eva` (`eva_id`, `eva_code`, `eva_name`, `eva_enabled`, `eva_immediate`, `eva_block`, `eva_block_duration`, `rpa_id`, `ch_cnt`, `si_cnt`, `oc_cnt`, `du_cnt`, `ch_pnt`, `si_pnt`, `oc_pnt`, `du_pnt`, `ch_dsc`, `si_dsc`, `oc_dsc`, `du_dsc`, `ch_dpt`, `si_dpt`, `oc_dpt`, `du_dpt`, `ch_grp`, `si_grp`, `oc_grp`, `du_grp`, `eva_blocked_until`, `eva_type_id`, `ch_steady`, `du_steady`, `steady_type_id`, `eva_block_type_id`, `bga_id`, `bgao_status`, `ignore_steady_val_restore`) VALUES
	(1, 'STLINE_READY_TO_WORK', 'STLine paruoštas apdorojimui', 1, 1, 0, 60, NULL, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, NULL, 1, 0, NULL, 3, NULL, 668, 1, 0),
	(2, 'PW_SETTING_FULL', 'Skaitiklio parametrai pilnai nuskaityti', 0, 1, 0, 60, NULL, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, NULL, 1, 0, NULL, 3, NULL, 670, 1, 0),
	(3, 'UNREGISTERED_METER_FOR_KNOWN_POINT', 'Neužregistruotas skaitiklis taškui', 1, 1, 0, 60, NULL, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, NULL, 1, 0, NULL, 3, NULL, 671, 2, 0),
	(6, 'PW_SETTING_RECEIVED', 'Nuskaitytas skaitiklio konfigūracinis parametras', 1, 0, 0, 60, NULL, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, NULL, 1, 1, 1, 1, NULL, 669, 1, 0);
/*!40000 ALTER TABLE `eva` ENABLE KEYS */;

-- Dumping structure for table emcor.evabgaqf
CREATE TABLE IF NOT EXISTS `evabgaqf` (
  `eva_id` int(10) unsigned NOT NULL COMMENT 'Įvykių atvejo identifikatorius',
  `bga_param_nr` smallint(5) unsigned NOT NULL COMMENT 'DB aplikacijos foninės užduoties parametro numeris',
  `bga_param_value` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'DB aplikacijos foninės užduoties parametro reikšmė',
  PRIMARY KEY (`eva_id`,`bga_param_nr`),
  CONSTRAINT `evabgaqf_eva_fk` FOREIGN KEY (`eva_id`) REFERENCES `eva` (`eva_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Užfiksuotų įvykių atvejų foninių užduočių parametrų reikšmės';

-- Dumping data for table emcor.evabgaqf: ~7 rows (approximately)
/*!40000 ALTER TABLE `evabgaqf` DISABLE KEYS */;
INSERT INTO `evabgaqf` (`eva_id`, `bga_param_nr`, `bga_param_value`) VALUES
	(2, 1, '#SRC_ID'),
	(2, 2, '#POINT_ID'),
	(3, 1, '#POINT_ID'),
	(3, 2, '#PH_ID'),
	(3, 3, '#EV_MSG'),
	(6, 1, '#SRC_ID'),
	(6, 2, '#POINT_ID');
/*!40000 ALTER TABLE `evabgaqf` ENABLE KEYS */;

-- Dumping structure for table emcor.evac
CREATE TABLE IF NOT EXISTS `evac` (
  `eva_id` int(10) unsigned NOT NULL COMMENT 'Įvykių atvejo identifikatorius',
  `evac_nr` smallint(5) unsigned NOT NULL COMMENT 'Įvykių atvejo sąlygos tikrinimo eilės numeris',
  `evac_inv` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Įvykių atvejo sąlygos invertavimo požymis',
  `evac_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Įvykių atvejų sąlygų tipo identifikatorius',
  `nval1` int(10) unsigned DEFAULT NULL COMMENT 'Skaitinė reikšmė Nr.1',
  `nval2` tinyint(3) unsigned DEFAULT NULL COMMENT 'Skaitinė reikšmė Nr.2',
  `cval` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Tekstinė reikšmė',
  `dc_id` tinyint(3) unsigned NOT NULL COMMENT 'Sprendimo identifikatorius',
  PRIMARY KEY (`eva_id`,`evac_nr`),
  KEY `evac_dc_i` (`dc_id`),
  KEY `evac_evac_type_i` (`evac_type_id`),
  CONSTRAINT `evac_dc_fk` FOREIGN KEY (`dc_id`) REFERENCES `dc` (`dc_id`),
  CONSTRAINT `evac_eva_fk` FOREIGN KEY (`eva_id`) REFERENCES `eva` (`eva_id`) ON DELETE CASCADE,
  CONSTRAINT `evac_evac_type_fk` FOREIGN KEY (`evac_type_id`) REFERENCES `evac_type` (`evac_type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Įvykių atvejų sąlygos';

-- Dumping data for table emcor.evac: ~7 rows (approximately)
/*!40000 ALTER TABLE `evac` DISABLE KEYS */;
INSERT INTO `evac` (`eva_id`, `evac_nr`, `evac_inv`, `evac_type_id`, `nval1`, `nval2`, `cval`, `dc_id`) VALUES
	(1, 1, 0, 9, 1, NULL, NULL, 3),
	(1, 2, 0, 4, 20, 4, NULL, 3),
	(1, 3, 0, 6, NULL, NULL, 'Ready to work', 1),
	(2, 1, 0, 4, 8, 1, NULL, 1),
	(3, 1, 0, 4, 41, 4, NULL, 3),
	(3, 2, 0, 5, 1, NULL, NULL, 1),
	(6, 1, 0, 4, 6, 1, NULL, 1);
/*!40000 ALTER TABLE `evac` ENABLE KEYS */;

-- Dumping structure for table emcor.evac_type
CREATE TABLE IF NOT EXISTS `evac_type` (
  `evac_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Įvykių atvejų sąlygų tipo identifikatorius',
  `evac_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Įvykių atvejų sąlygų tipo pavadinimas',
  PRIMARY KEY (`evac_type_id`),
  UNIQUE KEY `evac_type_name_u` (`evac_type_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Įvykių atvejų sąlygų tipai';

-- Dumping data for table emcor.evac_type: ~11 rows (approximately)
/*!40000 ALTER TABLE `evac_type` DISABLE KEYS */;
INSERT INTO `evac_type` (`evac_type_id`, `evac_type_name`) VALUES
	(11, 'Apskaitos būsenos signalas'),
	(1, 'Apskaitos taškas'),
	(8, 'Duomenų šaltinis'),
	(3, 'Grupė'),
	(2, 'Nuskaitymo taškas'),
	(6, 'Pranešimo fragmentas'),
	(10, 'Ryšio kanalas'),
	(9, 'Sistemos modulis'),
	(7, 'Visada tiesa'),
	(5, 'Įvykio detalus ID'),
	(4, 'Įvykių tipas');
/*!40000 ALTER TABLE `evac_type` ENABLE KEYS */;

-- Dumping structure for table emcor.evah
CREATE TABLE IF NOT EXISTS `evah` (
  `eva_id` int(10) unsigned NOT NULL COMMENT 'Įvykių atvejo identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `ev_time` datetime NOT NULL COMMENT 'Įvykio laikas',
  `ev_id` mediumint(8) unsigned NOT NULL COMMENT 'Įvykio ID',
  `eva_status` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Užfiksuoto įvykių atvejo išsiuntimo būsena',
  `ack_time` datetime DEFAULT NULL COMMENT 'Vartotojo patvirtinimo laikas',
  `user_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Vartotojo identifikatorius',
  `ses_id` bigint(20) unsigned DEFAULT NULL COMMENT 'Sesijos identifikatorius',
  PRIMARY KEY (`eva_id`,`ev_time`,`ev_id`),
  KEY `evah_db_time_i` (`db_time`),
  KEY `evah_eva_db_time_i` (`eva_id`,`db_time`),
  KEY `evah_eva_status_i` (`eva_status`),
  KEY `evah_ev_time_i` (`ev_time`,`ev_id`),
  KEY `evah_user_i` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Užfiksuotų įvykių atvejų istorija'
 PARTITION BY RANGE (
    to_days(ev_time))
(PARTITION par_201708 VALUES LESS THAN (736751) ENGINE = InnoDB,
 PARTITION par_201709 VALUES LESS THAN (736758) ENGINE = InnoDB,
 PARTITION par_201710 VALUES LESS THAN (736765) ENGINE = InnoDB);

-- Dumping data for table emcor.evah: ~3 rows (approximately)
/*!40000 ALTER TABLE `evah` DISABLE KEYS */;
/*!40000 ALTER TABLE `evah` ENABLE KEYS */;

-- Dumping structure for table emcor.evapv
CREATE TABLE IF NOT EXISTS `evapv` (
  `eva_id` int(10) unsigned NOT NULL COMMENT 'Įvykių atvejo identifikatorius',
  `ev_time` datetime NOT NULL COMMENT 'Įvykio laikas',
  `ev_id` mediumint(8) unsigned NOT NULL COMMENT 'Įvykio ID',
  `rpqf_id` int(10) unsigned NOT NULL COMMENT 'Ataskaitos užklausos sąlygos identifikatorius',
  `rpqf_value` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Užklausos sąlygos reikšmė',
  PRIMARY KEY (`eva_id`,`ev_time`,`ev_id`,`rpqf_id`),
  KEY `evapv_rpqf_i` (`rpqf_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Užfiksuotų įvykių atvejų ataskaitų užklausų parametrų reikšmės'
 PARTITION BY RANGE (
    to_days(ev_time))
(PARTITION par_201708 VALUES LESS THAN (736751) ENGINE = InnoDB,
 PARTITION par_201709 VALUES LESS THAN (736758) ENGINE = InnoDB,
 PARTITION par_201710 VALUES LESS THAN (736765) ENGINE = InnoDB);

-- Dumping data for table emcor.evapv: ~3 rows (approximately)
/*!40000 ALTER TABLE `evapv` DISABLE KEYS */;
/*!40000 ALTER TABLE `evapv` ENABLE KEYS */;

-- Dumping structure for table emcor.evaqf
CREATE TABLE IF NOT EXISTS `evaqf` (
  `eva_id` int(10) unsigned NOT NULL COMMENT 'Įvykių atvejo identifikatorius',
  `rpqf_id` int(10) unsigned NOT NULL COMMENT 'Ataskaitos užklausos sąlygos identifikatorius',
  `rpqf_value` varchar(250) COLLATE utf8_bin NOT NULL COMMENT 'Užklausos sąlygos reikšmė',
  PRIMARY KEY (`eva_id`,`rpqf_id`),
  KEY `evaqf_rpqf_i` (`rpqf_id`),
  CONSTRAINT `evaqf_eva_fk` FOREIGN KEY (`eva_id`) REFERENCES `eva` (`eva_id`) ON DELETE CASCADE,
  CONSTRAINT `evaqf_rpqf_fk` FOREIGN KEY (`rpqf_id`) REFERENCES `rpqf` (`rpqf_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Įvykių atvejų automatizuotų ataskaitų užklausų sąlygų konfigūracija';

-- Dumping data for table emcor.evaqf: ~0 rows (approximately)
/*!40000 ALTER TABLE `evaqf` DISABLE KEYS */;
/*!40000 ALTER TABLE `evaqf` ENABLE KEYS */;

-- Dumping structure for table emcor.eva_ack_ug
CREATE TABLE IF NOT EXISTS `eva_ack_ug` (
  `eva_id` int(10) unsigned NOT NULL COMMENT 'Įvykių atvejo identifikatorius',
  `ug_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojų grupės identifikatorius',
  `al_id` tinyint(3) unsigned NOT NULL DEFAULT 1 COMMENT 'Prieigos lygis (0-peržiūra,1-redagavimas)',
  PRIMARY KEY (`eva_id`,`ug_id`),
  KEY `eva_ack_ug_ug_i` (`ug_id`),
  CONSTRAINT `eva_ack_ug_eva_fk` FOREIGN KEY (`eva_id`) REFERENCES `eva` (`eva_id`) ON DELETE CASCADE,
  CONSTRAINT `eva_ack_ug_ug_fk` FOREIGN KEY (`ug_id`) REFERENCES `ug` (`ug_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Įvykių atvejų patvirtinimo leidimai vartotojų grupėms';

-- Dumping data for table emcor.eva_ack_ug: ~0 rows (approximately)
/*!40000 ALTER TABLE `eva_ack_ug` DISABLE KEYS */;
/*!40000 ALTER TABLE `eva_ack_ug` ENABLE KEYS */;

-- Dumping structure for table emcor.eva_ack_user
CREATE TABLE IF NOT EXISTS `eva_ack_user` (
  `eva_id` int(10) unsigned NOT NULL COMMENT 'Įvykių atvejo identifikatorius',
  `user_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojo identifikatorius',
  `al_id` tinyint(3) unsigned NOT NULL DEFAULT 1 COMMENT 'Prieigos lygis (0-peržiūra,1-redagavimas)',
  PRIMARY KEY (`eva_id`,`user_id`),
  KEY `eva_ack_user_user_i` (`user_id`),
  CONSTRAINT `eva_ack_user_eva_fk` FOREIGN KEY (`eva_id`) REFERENCES `eva` (`eva_id`) ON DELETE CASCADE,
  CONSTRAINT `eva_ack_user_user_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Įvykių atvejų patvirtinimo leidimai vartotojams';

-- Dumping data for table emcor.eva_ack_user: ~0 rows (approximately)
/*!40000 ALTER TABLE `eva_ack_user` DISABLE KEYS */;
/*!40000 ALTER TABLE `eva_ack_user` ENABLE KEYS */;

-- Dumping structure for table emcor.eva_block
CREATE TABLE IF NOT EXISTS `eva_block` (
  `eva_id` int(10) unsigned NOT NULL COMMENT 'Įvykių atvejo identifikatorius',
  `id` int(10) unsigned NOT NULL,
  `eva_blocked_until` datetime NOT NULL COMMENT 'Laikas, iki kurio blokuojamas įvykių atvejis',
  PRIMARY KEY (`eva_id`,`id`),
  CONSTRAINT `eva_block_eva_fk` FOREIGN KEY (`eva_id`) REFERENCES `eva` (`eva_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Įvykių atvejų blokavimo informacija';

-- Dumping data for table emcor.eva_block: ~0 rows (approximately)
/*!40000 ALTER TABLE `eva_block` DISABLE KEYS */;
/*!40000 ALTER TABLE `eva_block` ENABLE KEYS */;

-- Dumping structure for table emcor.eva_type
CREATE TABLE IF NOT EXISTS `eva_type` (
  `eva_type_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Įvykių atvejų tipo identifikatorius',
  `eva_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Įvykių atvejų tipo pavadinimas',
  PRIMARY KEY (`eva_type_id`),
  UNIQUE KEY `eva_type_name_u` (`eva_type_name`)
) ENGINE=InnoDB AUTO_INCREMENT=12 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Įvykių atvejų tipai';

-- Dumping data for table emcor.eva_type: ~2 rows (approximately)
/*!40000 ALTER TABLE `eva_type` DISABLE KEYS */;
INSERT INTO `eva_type` (`eva_type_id`, `eva_type_name`) VALUES
	(1, 'Automatinis skaitiklių registravimas'),
	(11, 'Operatyvūs pranešimai');
/*!40000 ALTER TABLE `eva_type` ENABLE KEYS */;

-- Dumping structure for table emcor.evc
CREATE TABLE IF NOT EXISTS `evc` (
  `evc_id` tinyint(3) unsigned NOT NULL COMMENT 'Sistemos įvykių klasės identifikatorius',
  `evc_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Sistemos įvykių klasės pavadinimas',
  PRIMARY KEY (`evc_id`),
  UNIQUE KEY `evc_name_u` (`evc_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Sistemos įvykių klasės ';

-- Dumping data for table emcor.evc: ~5 rows (approximately)
/*!40000 ALTER TABLE `evc` DISABLE KEYS */;
INSERT INTO `evc` (`evc_id`, `evc_name`) VALUES
	(4, 'Duomenų pranešimai'),
	(1, 'Oracle pranešimai'),
	(2, 'Programų pranešimai'),
	(3, 'Ryšio pranešimai'),
	(5, 'Sistemos veikimo pranešimai');
/*!40000 ALTER TABLE `evc` ENABLE KEYS */;

-- Dumping structure for table emcor.evt
CREATE TABLE IF NOT EXISTS `evt` (
  `evt_id` mediumint(8) unsigned NOT NULL COMMENT 'Sistemos įvykių tipo identifikatorius',
  `evc_id` tinyint(3) unsigned NOT NULL COMMENT 'Sistemos įvykių klasės identifikatorius',
  `evt_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Sistemos įvykių tipo pavadinimas',
  PRIMARY KEY (`evc_id`,`evt_id`),
  UNIQUE KEY `evt_name_u` (`evt_name`),
  CONSTRAINT `event_type_evc_fk` FOREIGN KEY (`evc_id`) REFERENCES `evc` (`evc_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Sistemos įvykių tipai';

-- Dumping data for table emcor.evt: ~103 rows (approximately)
/*!40000 ALTER TABLE `evt` DISABLE KEYS */;
INSERT INTO `evt` (`evt_id`, `evc_id`, `evt_name`) VALUES
	(38, 4, 'Aptikta atvirkštinė fazių seka elektros skaitiklyje'),
	(37, 4, 'Aptikta atvirkštinė srovė elektros skaitiklyje'),
	(13, 4, 'Aptiktas apskaitos būsenos signalo pasikeitimas'),
	(36, 4, 'Aptiktas išorinis poveikis skaitikliui'),
	(5, 4, 'Aptiktas kontrolerio konfigūracijos pakeitimas'),
	(6, 4, 'Aptiktas neatitikimas priskirtai kraštinei'),
	(8, 4, 'Aptiktas skaitiklio fazių pasikeitimas'),
	(4, 4, 'Aptiktas skaitiklio konfigūracijos pakeitimas'),
	(7, 4, 'Aptiktas skaitiklio maitinimo pasikeitimas'),
	(9, 4, 'Aptiktas skaitiklio poveikių magnetiniu lauku skaičiaus pasikeitimas'),
	(15, 5, 'Ataskaitų ruošimo pranešimai'),
	(6, 5, 'Atsijungimas nuo COM serverio'),
	(4, 5, 'Atsijungimas nuo Oracle'),
	(41, 4, 'Automatinė skaitiklio registracija sistemoje'),
	(20, 5, 'Diagnostikos pranešimai'),
	(20, 4, 'Diagnostikos pranešimai'),
	(16, 5, 'Dokumentų siuntimo pranešimai'),
	(3, 1, 'Duomenų bazės rodikliai'),
	(11, 2, 'Duomenų perdavimo protokolo klaidos'),
	(10, 1, 'Duomenų perkėlimo pranešimai'),
	(51, 4, 'Duomenų užkrovimas iš tekstinio failo'),
	(1, 4, 'Duomenų vėlavimas'),
	(32, 4, 'Eksporto formų (ELEMENT) operacijos'),
	(30, 4, 'Eksporto formų (FORM) operacijos'),
	(7, 1, 'Gauta apdorojimui duomenų koncentratoriaus parametrų informacija'),
	(6, 1, 'Gauta apdorojimui skaitiklio parametrų informacija'),
	(42, 4, 'Gautas signalas apie kontrolerio maitinimo dingimą'),
	(8, 5, 'Importo eksporto bylų apdorojimas'),
	(26, 2, 'Importo eksporto klaidos'),
	(24, 5, 'Importo eksporto pranešimai'),
	(24, 4, 'Importo eksporto pranešimai'),
	(33, 4, 'Importo formų (ELEMENT) operacijos'),
	(31, 4, 'Importo formų (FORM) operacijos'),
	(35, 4, 'Išmontuotas skaitiklis'),
	(8, 1, 'Išsaugota pilna skaitiklio parametrų informacija'),
	(5, 2, 'Klaida, atsijungiant nuo COM serverio'),
	(13, 2, 'Klaida, atsijungiant nuo Oracle'),
	(6, 2, 'Klaida, iškviečiant COM serverio funkciją'),
	(4, 2, 'Klaida, pasijungiant prie COM serverio'),
	(12, 2, 'Klaida, pasijungiant prie Oracle'),
	(39, 4, 'Laiko nustatymas skaitiklyje'),
	(9, 1, 'Matavimo taško ryšio konfigūracija užpildyta'),
	(10, 4, 'Momentinių skaitiklio matavimų išėjimas iš ribų'),
	(22, 4, 'Nekorektiška užklausa kontroleriui'),
	(21, 4, 'Nekorektiška užklausa skaitikliui'),
	(9, 2, 'Nenumatytos klaidos'),
	(3, 4, 'Nepalaikomi konfigūracijos duomenys'),
	(25, 4, 'Nepriimtų duomenų statusai'),
	(2, 4, 'Nesėkmingas duomenų sutikrinimas'),
	(12, 4, 'Nesėkmingas kontrolerio parametravimas'),
	(11, 4, 'Nesėkmingas skaitiklio parametravimas'),
	(8, 2, 'Neužregistruotas įvykio tipas'),
	(5, 1, 'OCI iškvietimo klaida'),
	(7, 2, 'Operacinės sistemos klaidos'),
	(5, 5, 'Pasijungimas prie COM serverio'),
	(3, 5, 'Pasijungimas prie Oracle'),
	(16, 3, 'Pranešimai iš ESMON'),
	(17, 3, 'Pranešimai iš nežinomų skaitiklių'),
	(27, 4, 'Prietaiso parametravimas'),
	(26, 4, 'Priimtų duomenų statusai'),
	(15, 3, 'Prisijungimai prie STProxy'),
	(1, 1, 'Procedūros, funkcijos vykdymas'),
	(27, 2, 'Programa apkrauta'),
	(1, 5, 'Programa startavo'),
	(2, 5, 'Programa uždaroma'),
	(14, 5, 'Programos darbo rėžimo pakeitimas'),
	(23, 4, 'Programos konfigūruojamos'),
	(14, 3, 'Ryšio būklė su duomenų šaltiniu'),
	(13, 3, 'Ryšio būklė transporto kanale'),
	(11, 3, 'Ryšio klaida draiverio lygyje'),
	(10, 3, 'Ryšio klaida transporto lygyje'),
	(12, 3, 'Ryšio klaida transporto menedžerio lygyje'),
	(1, 3, 'Ryšio su prietaisu klaida'),
	(2, 3, 'Ryšio su skaitikliu klaida'),
	(2, 1, 'SQL užklausos vykdymas'),
	(24, 2, 'STGate iš STLine iš karto gavo atsakymą su vienu klaidos kodu'),
	(1, 2, 'STLine buferio klaida'),
	(2, 2, 'STLine skaitiklio duomenų paėmimas'),
	(3, 2, 'STLine užduoties priėmimas'),
	(7, 5, 'Serverio laiko korekcija'),
	(40, 4, 'Skaitiklio relių suveikimas'),
	(28, 4, 'Suminio matavimo reikšmės persivertimas'),
	(34, 4, 'Sumontuotas skaitiklis'),
	(10, 5, 'Sąveika su elektroninio pašto serveriu'),
	(9, 5, 'Sąveika su elektroninio pašto serveriu per ChilKat komponentą'),
	(12, 5, 'Sąveika su moduliu STDataSnapServer'),
	(29, 5, 'Sąveika su viršutinio lygio sistemomis'),
	(29, 4, 'Sąveika su viršutinio lygio sistemomis'),
	(29, 2, 'Sąveikos su viršutinio lygio sistemomis klaidos'),
	(13, 5, 'Tarpmodulinių pranešimų persiuntimas'),
	(18, 5, 'Užblokuoti sistemos vartotojai'),
	(48, 4, 'Vartotojo inicijuota kontrolerio laiko korekcija'),
	(45, 4, 'Vartotojo inicijuota skaitiklio laiko korekcija'),
	(47, 4, 'Vartotojo inicijuotas kontrolerio laiko nustatymas'),
	(49, 4, 'Vartotojo inicijuotas kontrolerio parametravimas'),
	(44, 4, 'Vartotojo inicijuotas skaitiklio laiko nustatymas'),
	(46, 4, 'Vartotojo inicijuotas skaitiklio parametravimas'),
	(50, 4, 'Vartotojo inicijuotas skaitiklio relės nustatymas'),
	(52, 4, 'Vartotojo inicijuotas šablono atnaujinimo modelio pakeitimas'),
	(11, 5, 'Vidinės PĮ užduotys'),
	(101, 4, 'Vidinės skaitiklio klaidos'),
	(10, 2, 'Vidinės, konfigūracinės klaidos'),
	(17, 5, 'Įvykių apdorojimo pranešimai');
/*!40000 ALTER TABLE `evt` ENABLE KEYS */;

-- Dumping structure for table emcor.ewt
CREATE TABLE IF NOT EXISTS `ewt` (
  `ewt_id` mediumint(8) unsigned NOT NULL COMMENT 'Prietaisų įvykio ir įvykių tipo sąryšio ID',
  `evc_id` tinyint(3) unsigned NOT NULL COMMENT 'Sistemos įvykių klasės identifikatorius',
  `evt_id` mediumint(8) unsigned NOT NULL COMMENT 'Sistemos įvykių tipo identifikatorius',
  `is_point` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  `withe_type_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų vytelių tipo identifikatorius',
  `withe_id` mediumint(8) DEFAULT NULL COMMENT 'Duomenų vytelės identifikatorius',
  PRIMARY KEY (`ewt_id`),
  UNIQUE KEY `ewt_ak` (`evc_id`,`evt_id`,`is_point`,`withe_type_id`,`withe_id`),
  KEY `ewt_evc_i` (`evc_id`),
  KEY `ewt_evt_i` (`evt_id`),
  KEY `ewt_withe_i` (`withe_id`),
  KEY `ewt_withe_type_i` (`withe_type_id`),
  CONSTRAINT `ewt_evt_fk` FOREIGN KEY (`evc_id`, `evt_id`) REFERENCES `evt` (`evc_id`, `evt_id`) ON DELETE CASCADE,
  CONSTRAINT `ewt_withe_fk` FOREIGN KEY (`withe_id`) REFERENCES `withe` (`withe_id`) ON DELETE CASCADE,
  CONSTRAINT `ewt_withe_type_fk` FOREIGN KEY (`withe_type_id`) REFERENCES `withe_type` (`withe_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Prietaisų įvykių ir įvykių tipų sąryšiai';

-- Dumping data for table emcor.ewt: ~23 rows (approximately)
/*!40000 ALTER TABLE `ewt` DISABLE KEYS */;
INSERT INTO `ewt` (`ewt_id`, `evc_id`, `evt_id`, `is_point`, `withe_type_id`, `withe_id`) VALUES
	(11, 4, 4, 1, 7, NULL),
	(12, 4, 5, 0, 7, NULL),
	(4, 4, 7, 0, 6, NULL),
	(3, 4, 7, 1, 6, NULL),
	(2, 4, 8, 0, 2, NULL),
	(1, 4, 8, 1, 2, NULL),
	(6, 4, 9, 0, 1, 10003),
	(8, 4, 9, 0, 1, 10587),
	(10, 4, 9, 0, 1, 10588),
	(5, 4, 9, 1, 1, 10003),
	(7, 4, 9, 1, 1, 10587),
	(9, 4, 9, 1, 1, 10588),
	(19, 4, 10, 1, 5, 10096),
	(18, 4, 10, 1, 5, 10304),
	(14, 4, 10, 1, 5, 10800),
	(15, 4, 10, 1, 5, 10801),
	(13, 4, 36, 1, 1, NULL),
	(17, 4, 36, 1, 5, 10553),
	(16, 4, 37, 1, 5, 10284),
	(22, 4, 38, 1, 9, 10597),
	(23, 4, 39, 1, 9, 10015),
	(20, 4, 40, 1, 8, 10010),
	(21, 4, 101, 1, 9, 10597);
/*!40000 ALTER TABLE `ewt` ENABLE KEYS */;

-- Dumping structure for table emcor.exc_byp_md
CREATE TABLE IF NOT EXISTS `exc_byp_md` (
  `md_id` smallint(5) unsigned NOT NULL,
  PRIMARY KEY (`md_id`),
  CONSTRAINT `exc_byp_md_md_fk` FOREIGN KEY (`md_id`) REFERENCES `md` (`md_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apeinamųjų taškų išimtys pagal matavimų diskretiškumą';

-- Dumping data for table emcor.exc_byp_md: ~0 rows (approximately)
/*!40000 ALTER TABLE `exc_byp_md` DISABLE KEYS */;
/*!40000 ALTER TABLE `exc_byp_md` ENABLE KEYS */;

-- Dumping structure for table emcor.exc_pl
CREATE TABLE IF NOT EXISTS `exc_pl` (
  `pl_id` int(10) unsigned NOT NULL,
  `ml_id` mediumint(8) unsigned NOT NULL,
  `src_id` int(10) unsigned NOT NULL,
  PRIMARY KEY (`pl_id`),
  KEY `exc_pl_ml_fk` (`ml_id`),
  CONSTRAINT `exc_pl_ml_fk` FOREIGN KEY (`ml_id`) REFERENCES `ml` (`ml_id`) ON DELETE CASCADE,
  CONSTRAINT `exc_pl_pl_fk` FOREIGN KEY (`pl_id`) REFERENCES `pl` (`pl_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.exc_pl: ~0 rows (approximately)
/*!40000 ALTER TABLE `exc_pl` DISABLE KEYS */;
/*!40000 ALTER TABLE `exc_pl` ENABLE KEYS */;

-- Dumping structure for table emcor.exc_pwl
CREATE TABLE IF NOT EXISTS `exc_pwl` (
  `pwl_id` int(10) unsigned NOT NULL COMMENT 'Taškų ryšio savybių užpildymo pagal konfigūracinius parametrus taisyklės identifikatorius',
  PRIMARY KEY (`pwl_id`),
  CONSTRAINT `exc_pwl_pwl_fk` FOREIGN KEY (`pwl_id`) REFERENCES `pwl` (`pwl_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Atjungtos taškų ryšio savybių užpildymo pagal konfigūracinius parametrus taisyklės';

-- Dumping data for table emcor.exc_pwl: ~0 rows (approximately)
/*!40000 ALTER TABLE `exc_pwl` DISABLE KEYS */;
/*!40000 ALTER TABLE `exc_pwl` ENABLE KEYS */;

-- Dumping structure for table emcor.exc_pwm
CREATE TABLE IF NOT EXISTS `exc_pwm` (
  `ml_id` mediumint(8) unsigned NOT NULL,
  `sbst_ml_id` mediumint(8) unsigned NOT NULL,
  PRIMARY KEY (`ml_id`),
  KEY `exc_pwm_sbst_ml_fk` (`sbst_ml_id`),
  CONSTRAINT `exc_pwm_ml_fk` FOREIGN KEY (`ml_id`) REFERENCES `ml` (`ml_id`) ON DELETE CASCADE,
  CONSTRAINT `exc_pwm_sbst_ml_fk` FOREIGN KEY (`sbst_ml_id`) REFERENCES `ml` (`ml_id`) ON DELETE CASCADE,
  CONSTRAINT `EXC_PWM_THE_SAME` CHECK (`ml_id` <> `sbst_ml_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.exc_pwm: ~0 rows (approximately)
/*!40000 ALTER TABLE `exc_pwm` DISABLE KEYS */;
/*!40000 ALTER TABLE `exc_pwm` ENABLE KEYS */;

-- Dumping structure for table emcor.exc_src_tmpl_gr
CREATE TABLE IF NOT EXISTS `exc_src_tmpl_gr` (
  `src_tmpl_id` mediumint(8) unsigned NOT NULL COMMENT 'Duomenų šaltinių šablono ID',
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  `sbst_src_tmpl_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Pakaitos duomenų šaltinių šablono ID ',
  `sbst_src_tmpl_priority` smallint(5) unsigned NOT NULL DEFAULT 5 COMMENT 'Grupės prioritetas pakaitinio šablono pasirinkime',
  PRIMARY KEY (`src_tmpl_id`,`gr_id`),
  KEY `exc_src_tmpl_gr_gr_i` (`gr_id`),
  KEY `exc_src_tmpl_gr_sbst_tmpl_i` (`sbst_src_tmpl_id`),
  CONSTRAINT `exc_src_tmpl_gr_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE,
  CONSTRAINT `exc_src_tmpl_gr_sbst_tmpl_fk` FOREIGN KEY (`sbst_src_tmpl_id`) REFERENCES `src_tmpl` (`src_tmpl_id`) ON DELETE CASCADE,
  CONSTRAINT `exc_src_tmpl_gr_src_tmpl_fk` FOREIGN KEY (`src_tmpl_id`) REFERENCES `src_tmpl` (`src_tmpl_id`) ON DELETE CASCADE,
  CONSTRAINT `EXC_SRC_TMPL_GR_SBST_THE_SAME` CHECK (`sbst_src_tmpl_id` is null or `src_tmpl_id` <> `sbst_src_tmpl_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų šaltinių šablonų išimtys nurodytų grupių taškams';

-- Dumping data for table emcor.exc_src_tmpl_gr: ~0 rows (approximately)
/*!40000 ALTER TABLE `exc_src_tmpl_gr` DISABLE KEYS */;
/*!40000 ALTER TABLE `exc_src_tmpl_gr` ENABLE KEYS */;

-- Dumping structure for table emcor.exc_src_type_md
CREATE TABLE IF NOT EXISTS `exc_src_type_md` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `aggs_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo segmento identifikatorius',
  `md_id` smallint(5) unsigned NOT NULL,
  `sbst_md_id` smallint(5) unsigned NOT NULL,
  PRIMARY KEY (`src_type_id`,`aggs_id`,`md_id`),
  KEY `exc_src_type_md_aggs_i` (`aggs_id`),
  KEY `exc_src_type_md_md_i` (`md_id`),
  KEY `exc_src_type_md_sbst_md_i` (`sbst_md_id`),
  CONSTRAINT `exc_src_type_md_aggs_fk` FOREIGN KEY (`aggs_id`) REFERENCES `aggs` (`aggs_id`) ON DELETE CASCADE,
  CONSTRAINT `exc_src_type_md_md_fk` FOREIGN KEY (`md_id`) REFERENCES `md` (`md_id`) ON DELETE CASCADE,
  CONSTRAINT `exc_src_type_md_sbst_md_fk` FOREIGN KEY (`sbst_md_id`) REFERENCES `md` (`md_id`) ON DELETE CASCADE,
  CONSTRAINT `exc_src_type_md_src_type_fk` FOREIGN KEY (`src_type_id`) REFERENCES `src_type` (`src_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Šaltinių tipų išimtys pagal matavimų diskretiškumą';

-- Dumping data for table emcor.exc_src_type_md: ~31 rows (approximately)
/*!40000 ALTER TABLE `exc_src_type_md` DISABLE KEYS */;
INSERT INTO `exc_src_type_md` (`src_type_id`, `aggs_id`, `md_id`, `sbst_md_id`) VALUES
	(-1, 7, 2, 7),
	(-1, 7, 15, 7),
	(-1, 7, 18, 7),
	(1, 7, 2, 7),
	(1, 7, 15, 7),
	(1, 7, 18, 7),
	(24, 7, 2, 7),
	(24, 7, 15, 7),
	(24, 7, 18, 7),
	(25, 7, 2, 7),
	(25, 7, 15, 7),
	(25, 7, 18, 7),
	(30, 7, 2, 7),
	(30, 7, 15, 7),
	(30, 7, 18, 7),
	(33, 7, 2, 7),
	(33, 7, 15, 7),
	(33, 7, 18, 7),
	(51, 7, 2, 7),
	(51, 7, 15, 7),
	(51, 7, 18, 7),
	(63, 8, 5, 7),
	(77, 8, 5, 7),
	(78, 8, 5, 7),
	(127, 7, 2, 7),
	(127, 7, 15, 7),
	(127, 7, 18, 7),
	(147, 8, 6, 7),
	(148, 8, 6, 7),
	(154, 8, 5, 7),
	(154, 8, 6, 7);
/*!40000 ALTER TABLE `exc_src_type_md` ENABLE KEYS */;

-- Dumping structure for table emcor.exc_src_type_withe
CREATE TABLE IF NOT EXISTS `exc_src_type_withe` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `is_point` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  PRIMARY KEY (`src_type_id`,`withe_id`,`is_point`),
  KEY `exc_src_type_withe_withe_fk` (`withe_id`),
  CONSTRAINT `exc_src_type_withe_src_type_fk` FOREIGN KEY (`src_type_id`) REFERENCES `src_type` (`src_type_id`) ON DELETE CASCADE,
  CONSTRAINT `exc_src_type_withe_withe_fk` FOREIGN KEY (`withe_id`) REFERENCES `withe` (`withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Šaltinio tipui taikomos parametrų vytelių išimtys';

-- Dumping data for table emcor.exc_src_type_withe: ~0 rows (approximately)
/*!40000 ALTER TABLE `exc_src_type_withe` DISABLE KEYS */;
/*!40000 ALTER TABLE `exc_src_type_withe` ENABLE KEYS */;

-- Dumping structure for table emcor.ffp
CREATE TABLE IF NOT EXISTS `ffp` (
  `ffp_id` mediumint(8) NOT NULL AUTO_INCREMENT COMMENT 'Profilio identifikatorius',
  `ffp_code` varchar(250) COLLATE utf8_bin NOT NULL COMMENT 'Profilio kodas',
  `ffp_name` varchar(250) COLLATE utf8_bin NOT NULL COMMENT 'Profilio pavadinimas',
  `ffp_type` varchar(250) COLLATE utf8_bin NOT NULL COMMENT 'Profilio tipas',
  PRIMARY KEY (`ffp_id`),
  UNIQUE KEY `ffp_code_u` (`ffp_code`),
  UNIQUE KEY `ffp_name_u` (`ffp_name`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Profilio lentelė';

-- Dumping data for table emcor.ffp: ~3 rows (approximately)
/*!40000 ALTER TABLE `ffp` DISABLE KEYS */;
INSERT INTO `ffp` (`ffp_id`, `ffp_code`, `ffp_name`, `ffp_type`) VALUES
	(-1, 'WS_POINT_PROFILE', 'Apskaitos taško profilis WEB-servisui', 'POINT'),
	(1, 'DEFAULT_GR_FFP', 'Pradinis apskaitos grupės profilis', 'GROUP'),
	(2, 'DEFAULT_POINT_FFP', 'Pradinis apskaitos taško profilis', 'POINT');
/*!40000 ALTER TABLE `ffp` ENABLE KEYS */;

-- Dumping structure for table emcor.ffp_data
CREATE TABLE IF NOT EXISTS `ffp_data` (
  `ffp_data_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Profilio reikšmių idenfikatorius',
  `ffp_id` mediumint(8) NOT NULL COMMENT 'Profilio identifikatorius',
  `ffp_val_row_num` mediumint(8) unsigned NOT NULL COMMENT 'Atvaizduojamos profilio reikšmių eiliškumo klasifikatorius',
  `ffp_vt_id` mediumint(8) unsigned NOT NULL COMMENT 'Profilio reikšmės tipo identifikatorius',
  `ffp_val_key_1` int(10) unsigned DEFAULT NULL COMMENT 'Profilio reikšmių pirmoji raktinė reikšmė',
  `ffp_val_key_2` int(10) unsigned DEFAULT NULL COMMENT 'Profilio reikšmių antroji raktinė reikšmė',
  `ffp_val_key_3` varchar(2000) COLLATE utf8_bin DEFAULT NULL COMMENT 'Profilio reikšmių trečioji raktinė reikšmė',
  `ffp_data_name` varchar(120) COLLATE utf8_bin NOT NULL,
  `ffp_val_sort_num` int(10) unsigned DEFAULT NULL,
  PRIMARY KEY (`ffp_data_id`),
  KEY `ffp_data_row_num_i` (`ffp_id`,`ffp_val_row_num`),
  KEY `ffp_vt_fk` (`ffp_vt_id`),
  CONSTRAINT `ffp_data_fk` FOREIGN KEY (`ffp_id`) REFERENCES `ffp` (`ffp_id`),
  CONSTRAINT `ffp_vt_fk` FOREIGN KEY (`ffp_vt_id`) REFERENCES `ffp_val_type` (`ffp_vt_id`)
) ENGINE=InnoDB AUTO_INCREMENT=31 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Profilio reikšmių lentelė';

-- Dumping data for table emcor.ffp_data: ~29 rows (approximately)
/*!40000 ALTER TABLE `ffp_data` DISABLE KEYS */;
INSERT INTO `ffp_data` (`ffp_data_id`, `ffp_id`, `ffp_val_row_num`, `ffp_vt_id`, `ffp_val_key_1`, `ffp_val_key_2`, `ffp_val_key_3`, `ffp_data_name`, `ffp_val_sort_num`) VALUES
	(1, 2, 1, 5, 47, NULL, NULL, 'Duomenys perduodami į bilingo sistemą', NULL),
	(2, 2, 2, 5, 72, NULL, NULL, 'Patalpos kodas/indeksas', NULL),
	(3, 2, 3, 5, 73, NULL, NULL, 'Apskaitos taško vietos aprašymas', NULL),
	(4, 2, 4, 5, 74, NULL, NULL, 'Kodas tiekėjo  sistemoje', NULL),
	(5, 2, 5, 5, 85, NULL, NULL, 'Komplekso paklaida', NULL),
	(6, 2, 6, 7, NULL, NULL, 'CODE', 'Apskaitos taško kodas', NULL),
	(7, 2, 7, 7, NULL, NULL, 'TYPE', 'Apskaitos taško tipas', NULL),
	(8, 2, 8, 7, NULL, NULL, 'NAME', 'Apskaitos taško pavadinimas', NULL),
	(9, 2, 9, 8, 126, NULL, 'CODE', 'Regionas. Kodas', NULL),
	(10, 2, 10, 8, 126, NULL, 'TYPE', 'Regionas. Tipas', NULL),
	(11, 2, 11, 8, 126, NULL, 'NAME', 'Regionas. Pavadinimas', NULL),
	(12, 2, 12, 8, 101, NULL, 'CODE', 'Miestas. Kodas', NULL),
	(13, 2, 13, 8, 101, NULL, 'TYPE', 'Miestas. Tipas', NULL),
	(14, 2, 14, 8, 101, NULL, 'NAME', 'Miestas. Pavadinimas', NULL),
	(15, 2, 15, 8, 1, NULL, 'CODE', 'Objektas. Kodas', NULL),
	(16, 2, 16, 8, 1, NULL, 'TYPE', 'Objektas. Tipas', NULL),
	(17, 2, 17, 8, 1, NULL, 'NAME', 'Objektas. Pavadinimas', NULL),
	(18, 2, 18, 10, NULL, NULL, NULL, 'Skaitiklio tipas', NULL),
	(19, 2, 19, 11, NULL, NULL, NULL, 'Skaitiklio numeris', NULL),
	(21, -1, 1, 9, 65, NULL, NULL, 'dstEnabled', NULL),
	(22, -1, 2, 9, 66, NULL, NULL, 'loadControl', NULL),
	(23, -1, 3, 9, 67, NULL, NULL, 'lotNumber', NULL),
	(24, -1, 4, 9, 72, NULL, NULL, 'modelNumber', NULL),
	(25, -1, 5, 9, 73, NULL, NULL, 'modelVersion', NULL),
	(26, -1, 6, 9, 68, NULL, NULL, 'outageReport', NULL),
	(27, -1, 7, 9, 69, NULL, NULL, 'readRequest', NULL),
	(28, -1, 8, 9, 70, NULL, NULL, 'relayCapable', NULL),
	(29, -1, 9, 9, 71, NULL, NULL, 'reverseFlowHandling', NULL),
	(30, 2, 20, 14, 86, NULL, NULL, 'Esminė problema', NULL);
/*!40000 ALTER TABLE `ffp_data` ENABLE KEYS */;

-- Dumping structure for table emcor.ffp_ug
CREATE TABLE IF NOT EXISTS `ffp_ug` (
  `ffp_id` mediumint(8) NOT NULL COMMENT 'Profilio identifikatorius',
  `ug_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojų grupės identifikatorius',
  PRIMARY KEY (`ffp_id`,`ug_id`),
  KEY `ffp_ug_ug_fk` (`ug_id`),
  CONSTRAINT `ffp_ug_ffp_fk` FOREIGN KEY (`ffp_id`) REFERENCES `ffp` (`ffp_id`) ON DELETE CASCADE,
  CONSTRAINT `ffp_ug_ug_fk` FOREIGN KEY (`ug_id`) REFERENCES `ug` (`ug_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Vartotojų grupėms pasiekiami profiliai';

-- Dumping data for table emcor.ffp_ug: ~0 rows (approximately)
/*!40000 ALTER TABLE `ffp_ug` DISABLE KEYS */;
/*!40000 ALTER TABLE `ffp_ug` ENABLE KEYS */;

-- Dumping structure for table emcor.ffp_val_type
CREATE TABLE IF NOT EXISTS `ffp_val_type` (
  `ffp_vt_id` mediumint(8) unsigned NOT NULL COMMENT 'Profilio reikšmės tipo identifikatorius',
  `ffp_vt_code` varchar(250) COLLATE utf8_bin NOT NULL COMMENT 'Profilio reikšmės tipo kodas',
  `ffp_vt_name` varchar(2000) COLLATE utf8_bin NOT NULL COMMENT 'Profilio reikšmės tipo pavadinimas',
  `ffp_vt_type` varchar(250) COLLATE utf8_bin NOT NULL COMMENT 'Profilio tipas',
  PRIMARY KEY (`ffp_vt_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Profilio reikšmių tipų lentelė';

-- Dumping data for table emcor.ffp_val_type: ~44 rows (approximately)
/*!40000 ALTER TABLE `ffp_val_type` DISABLE KEYS */;
INSERT INTO `ffp_val_type` (`ffp_vt_id`, `ffp_vt_code`, `ffp_vt_name`, `ffp_vt_type`) VALUES
	(1, 'GPTY', 'Apskaitos grupės savybė', 'GROUP'),
	(2, 'CONTAINER_GPTY', 'Apskaitos grupės grupės-konteinerio savybė', 'GROUP'),
	(3, 'GR_ATTR', 'Apskaitos grupės atributas', 'GROUP'),
	(4, 'CONTAINER_GR_ATTR', 'Apskaitos grupės grupės-konteinerio atributas', 'GROUP'),
	(5, 'PPTY', 'Apskaitos taško savybė', 'POINT'),
	(6, 'CONTAINER_POINT_GPTY', 'Apskaitos taško grupės-konteinerio savybė', 'POINT'),
	(7, 'POINT_ATTR', 'Apskaitos taško atributas', 'POINT'),
	(8, 'CONTAINER_POINT_GR_ATTR', 'Apskaitos taško grupės-konteinerio atributas', 'POINT'),
	(9, 'POINT_MPTY', 'Apskaitos taško primontuoto skaitiklio savybė', 'POINT'),
	(10, 'POINT_METER_TYPE', 'Apskaitos taško primontuoto skaitiklio tipas', 'POINT'),
	(11, 'POINT_METER_NUMBER', 'Apskaitos taško primontuoto skaitiklio numeris', 'POINT'),
	(12, 'GPTY_DESC', 'Apskaitos grupės savybės reikšmės aprašymas', 'GROUP'),
	(13, 'CONTAINER_GPTY_DESC', 'Apskaitos grupės grupės-konteinerio savybės reikšmės aprašymas', 'GROUP'),
	(14, 'PPTY_DESC', 'Apskaitos taško savybės reikšmės aprašymas', 'POINT'),
	(15, 'CONTAINER_POINT_GPTY_DESC', 'Apskaitos taško grupės-konteinerio savybės reikšmės aprašymas', 'POINT'),
	(16, 'POINT_MPTY_DESC', 'Apskaitos taške sumontuoto skaitiklio savybės reikšmės aprašymas', 'POINT'),
	(17, 'POINT_SETTING', 'Apskaitos taško konfigūracijos parametras', 'POINT'),
	(18, 'POINT_SETTING_DESC', 'Apskaitos taško konfigūracijos parametro reikšmės aprašymas', 'POINT'),
	(19, 'POINT_SETTING_TMST', 'Apskaitos taško konfigūracijos parametro duomenų laikas', 'POINT'),
	(20, 'PW_STATE', 'Apskaitos taško žurnalo įvykis/būsena', 'POINT'),
	(21, 'PW_STATE_DESC', 'Apskaitos taško žurnalo įvykio/būsenos reikšmės aprašymas', 'POINT'),
	(22, 'PW_STATE_TMST', 'Apskaitos taško žurnalo įvykio/būsenos duomenų laikas', 'POINT'),
	(23, 'LATEST_STORABLE_PL', 'Paskutinio apskaitos taško saugotinų rodmenų įrašymo laikas', 'POINT'),
	(24, 'DP_PH_LPTY', 'Nuskaitymo taško ryšio kanalo savybė', 'GROUP'),
	(25, 'DP_SETTING', 'Nuskaitymo taško konfigūracijos parametras', 'GROUP'),
	(26, 'DP_SETTING_DESC', 'Nuskaitymo taško konfigūracijos parametro reikšmės aprašymas', 'GROUP'),
	(27, 'DW_STATE', 'Nuskaitymo taško įvykis/būsena', 'GROUP'),
	(28, 'DW_STATE_DESC', 'Nuskaitymo taško įvykio/būsenos reikšmės aprašymas', 'GROUP'),
	(29, 'DW_STATE_TMST', 'Nuskaitymo taško įvykio/būsenos duomenų laikas', 'GROUP'),
	(30, 'POINT_DP_SETTING', 'Apskaitos taško atitinkamo nuskaitymo taško konfigūracijos parametras', 'POINT'),
	(31, 'POINT_DP_SETTING_DESC', 'Apskaitos taško atitinkamo nuskaitymo taško konfigūracijos parametro reikšmės aprašymas', 'POINT'),
	(32, 'POINT_DW_STATE', 'Apskaitos taško atitinkamo nuskaitymo taško įvykis/būsena', 'POINT'),
	(33, 'POINT_DW_STATE_DESC', 'Apskaitos taško atitinkamo nuskaitymo taško įvykio/būsenos reikšmės aprašymas', 'POINT'),
	(34, 'POINT_DW_STATE_TMST', 'Apskaitos taško atitinkamo nuskaitymo taško įvykio/būsenos duomenų laikas', 'POINT'),
	(35, 'PL', 'Taško matavimo paskutinė reikšmė', 'POINT'),
	(36, 'PL_RANGE_DESC', 'Taško matavimo paskutinės reikšmės diapazono aprašymas', 'POINT'),
	(37, 'POINT_DP_PH_LPTY', 'Apskaitos tašką atitinkančio nuskaitymo taško ryšio kanalo savybė', 'POINT'),
	(38, 'POINT_COEF_U', 'Įtampos transformacijos koeficientas', 'POINT'),
	(39, 'POINT_COEF_I', 'Srovės transformacijos koeficientas', 'POINT'),
	(40, 'POINT_COEF', 'Transformacijos koeficientas', 'POINT'),
	(41, 'CONT_ID_POINT_ATTR', 'Apskaitos taško konkrečios grupės-konteinerio atributas', 'POINT'),
	(42, 'CONT_ID_ATTR', 'Apskaitos grupės konkrečios grupės-konteinerio atributas', 'GROUP'),
	(43, 'DEV_ATTR', 'Grupės kontrolerio informacija', 'GROUP'),
	(44, 'DEV_POINT_ATTR', 'Nuskaitymo taško kontrolerio informacija', 'POINT');
/*!40000 ALTER TABLE `ffp_val_type` ENABLE KEYS */;

-- Dumping structure for table emcor.fib
CREATE TABLE IF NOT EXISTS `fib` (
  `fib_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Maketo identifikatorius',
  `meter_number` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo priemonės numeris',
  `stobis` mediumint(8) NOT NULL COMMENT 'Kodas STOBIS',
  `md_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimo diskretiškumo identifikatorius',
  `pl_t` datetime NOT NULL COMMENT 'Matavimo linijos matavimo taške duomenų laikas',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `pck_t` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Duomenų paketo laiko žymė',
  `pl_v` double DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų reikšmė',
  `dst` tinyint(3) unsigned DEFAULT NULL,
  `pl_rt` datetime DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų nuskaitymo laikas',
  `dstatus` varbinary(20) DEFAULT NULL COMMENT 'Duomenų statuso kodinė išraiška',
  PRIMARY KEY (`fib_id`,`meter_number`,`stobis`,`md_id`,`pl_t`),
  KEY `fib_md_fk` (`md_id`),
  CONSTRAINT `fib_md_fk` FOREIGN KEY (`md_id`) REFERENCES `md` (`md_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų importo iš failų informacija';

-- Dumping data for table emcor.fib: ~0 rows (approximately)
/*!40000 ALTER TABLE `fib` DISABLE KEYS */;
/*!40000 ALTER TABLE `fib` ENABLE KEYS */;

-- Dumping structure for table emcor.fp
CREATE TABLE IF NOT EXISTS `fp` (
  `fp_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Užpildymo profilio identifikatorius',
  `fp_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Užpildymo profilio kodas',
  `fp_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Užpildymo profilio pavadinimas',
  PRIMARY KEY (`fp_id`),
  UNIQUE KEY `fp_code_u` (`fp_code`),
  UNIQUE KEY `fp_name_u` (`fp_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Užpildymo profiliai';

-- Dumping data for table emcor.fp: ~0 rows (approximately)
/*!40000 ALTER TABLE `fp` DISABLE KEYS */;
/*!40000 ALTER TABLE `fp` ENABLE KEYS */;

-- Dumping structure for table emcor.fpty
CREATE TABLE IF NOT EXISTS `fpty` (
  `fpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ataskaitos formato savybės identifikatorius',
  `fpty_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Ataskaitos formato savybės kodas',
  `fpty_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ataskaitos formato savybės pavadinimas',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  `fpty_nr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Ataskaitos formato savybės eilės numeris rušiavimui',
  PRIMARY KEY (`fpty_id`),
  UNIQUE KEY `fpty_code_u` (`fpty_code`),
  UNIQUE KEY `fpty_name_u` (`fpty_name`),
  KEY `fpty_enum_i` (`enum_id`),
  CONSTRAINT `fpty_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ataskaitos formato savybės';

-- Dumping data for table emcor.fpty: ~11 rows (approximately)
/*!40000 ALTER TABLE `fpty` DISABLE KEYS */;
INSERT INTO `fpty` (`fpty_id`, `fpty_code`, `fpty_name`, `enum_id`, `fpty_nr`) VALUES
	(1, 'Disp', 'Duomenų išdėstymas Excel ataskaitose', 88, NULL),
	(2, 'Sname', 'Šablono failo pavadinimas Excel ataskaitose', NULL, NULL),
	(3, 'Macro', 'Po duomenų užpildymo vykdomos makrokomandos vardas Excel ataskaitose', NULL, NULL),
	(4, 'VbProject', 'Ar palikti macro Excel ataskaitose', 82, NULL),
	(5, 'DataSheet', 'Suformuotoje ataskaitoje "data" lapą', 136, NULL),
	(6, 'OUTPUT_FILE_EXTENSION', 'Suformuotos bylos išplėtimas', NULL, NULL),
	(7, 'OUTPUT_FILENAME_PREFIX', 'Suformuotos bylos pavadinimo priešdėlis', NULL, NULL),
	(8, 'FILENAME_FORMAT', 'Bylos pavadinimo formatas', NULL, NULL),
	(9, 'FILENAME_FORMAT_DELIMITER', 'Skyriklis bylos pavadinimo formate', NULL, NULL),
	(10, 'CSV_Delimiter', 'CSV bylos skyriklis', NULL, NULL),
	(11, 'CSV_Include_Fieldname', 'Įrašyti į CSV bylą laukų pavadinimus', 82, NULL);
/*!40000 ALTER TABLE `fpty` ENABLE KEYS */;

-- Dumping structure for table emcor.fp_data
CREATE TABLE IF NOT EXISTS `fp_data` (
  `fp_id` int(10) unsigned NOT NULL COMMENT 'Užpildymo profilio identifikatorius',
  `fp_nr` mediumint(8) unsigned NOT NULL COMMENT 'Užpildymo profilio sąlygos numeris',
  `aggs_type_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  `ms_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Matavimo identifikatorius',
  `dir_id` tinyint(4) DEFAULT NULL COMMENT 'Krypties identifikatorius',
  `aggs_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Agregavimo segmento identifikatorius',
  `aggf_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Agregavimo funkcijos identifikatorius',
  `tff_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Tarifo identifikatorius',
  `md_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Matavimo diskretiškumo identifikatorius',
  PRIMARY KEY (`fp_id`,`fp_nr`),
  KEY `fp_data_aggf_fk` (`aggf_id`),
  KEY `fp_data_aggs_fk` (`aggs_id`),
  KEY `fp_data_aggs_type_fk` (`aggs_type_id`),
  KEY `fp_data_dir_fk` (`dir_id`),
  KEY `fp_data_md_fk` (`md_id`),
  KEY `fp_data_ms_fk` (`ms_id`),
  KEY `fp_data_tff_fk` (`tff_id`),
  CONSTRAINT `fp_data_aggf_fk` FOREIGN KEY (`aggf_id`) REFERENCES `aggf` (`aggf_id`) ON DELETE CASCADE,
  CONSTRAINT `fp_data_aggs_fk` FOREIGN KEY (`aggs_id`) REFERENCES `aggs` (`aggs_id`) ON DELETE CASCADE,
  CONSTRAINT `fp_data_aggs_type_fk` FOREIGN KEY (`aggs_type_id`) REFERENCES `aggs_type` (`aggs_type_id`) ON DELETE CASCADE,
  CONSTRAINT `fp_data_dir_fk` FOREIGN KEY (`dir_id`) REFERENCES `dir` (`dir_id`) ON DELETE CASCADE,
  CONSTRAINT `fp_data_fp_fk` FOREIGN KEY (`fp_id`) REFERENCES `fp` (`fp_id`) ON DELETE CASCADE,
  CONSTRAINT `fp_data_md_fk` FOREIGN KEY (`md_id`) REFERENCES `md` (`md_id`) ON DELETE CASCADE,
  CONSTRAINT `fp_data_ms_fk` FOREIGN KEY (`ms_id`) REFERENCES `ms` (`ms_id`) ON DELETE CASCADE,
  CONSTRAINT `fp_data_tff_fk` FOREIGN KEY (`tff_id`) REFERENCES `tff` (`tff_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Užpildymo profilių duomenys';

-- Dumping data for table emcor.fp_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `fp_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `fp_data` ENABLE KEYS */;

-- Dumping structure for table emcor.fp_sf
CREATE TABLE IF NOT EXISTS `fp_sf` (
  `fp_id` int(10) unsigned NOT NULL COMMENT 'Užpildymo profilio identifikatorius',
  `sf_id` mediumint(8) unsigned NOT NULL COMMENT 'Statuso požymio ID',
  `sf_auto_null_act` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Maskuojančio duomenis akto suvedimo požymis',
  PRIMARY KEY (`fp_id`,`sf_id`),
  KEY `fp_sf_sf_fk` (`sf_id`),
  CONSTRAINT `fp_sf_fp_fk` FOREIGN KEY (`fp_id`) REFERENCES `fp` (`fp_id`) ON DELETE CASCADE,
  CONSTRAINT `fp_sf_sf_fk` FOREIGN KEY (`sf_id`) REFERENCES `sf` (`sf_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Užpildymo profilio išimtinio statusų apdorojimo konfigūracija';

-- Dumping data for table emcor.fp_sf: ~0 rows (approximately)
/*!40000 ALTER TABLE `fp_sf` DISABLE KEYS */;
/*!40000 ALTER TABLE `fp_sf` ENABLE KEYS */;

-- Dumping structure for table emcor.f_ar_g
CREATE TABLE IF NOT EXISTS `f_ar_g` (
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  `ml_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo linijos identifikatorius',
  `bt` datetime NOT NULL COMMENT 'Periodo pradžia',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `val` double DEFAULT NULL COMMENT 'Reikšmė',
  `val_prc` double DEFAULT NULL COMMENT 'Procentinė reikšmė',
  `val_prc_limit` double DEFAULT NULL,
  `has_act` tinyint(1) DEFAULT NULL COMMENT 'Požymis, ar duomenys koreguoti aktais',
  `has_specific_dstatus` tinyint(1) DEFAULT NULL COMMENT 'Požymis, ar duomenų statusas specifinis',
  `dstatus` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Duomenų statuso kodinė išraiška',
  `read_time` datetime DEFAULT NULL COMMENT 'Nuskaitymo laikas',
  `val_input` double DEFAULT NULL COMMENT 'Įvado reikšmė',
  `has_input_act` tinyint(1) DEFAULT NULL COMMENT 'Požymis, ar įvado duomenys koreguoti aktais',
  `has_input_specific_dstatus` tinyint(1) DEFAULT NULL COMMENT 'Požymis, ar įvado duomenų statusas specifinis',
  `dstatus_input` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Įvado duomenų statuso kodinė išraiška',
  `read_time_input` datetime DEFAULT NULL COMMENT 'Įvado duomenų nuskaitymo laikas',
  `val_output` double DEFAULT NULL COMMENT 'Išvado reikšmė',
  `has_output_act` tinyint(1) DEFAULT NULL COMMENT 'Požymis, ar išvado duomenys koreguoti aktais',
  `has_output_specific_dstatus` tinyint(1) DEFAULT NULL COMMENT 'Požymis, ar išvado duomenų statusas specifinis',
  `dstatus_output` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Išvado duomenų statuso kodinė išraiška',
  `read_time_output` datetime DEFAULT NULL COMMENT 'Išvado duomenų nuskaitymo laikas',
  `tff_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Tarifo identifikatorius',
  `extreme_bt` datetime DEFAULT NULL COMMENT 'Pasiektos ekstremalios reikšmės intervalo pradžia',
  `extreme_et` datetime DEFAULT NULL COMMENT 'Pasiektos ekstremalios reikšmės intervalo pabaiga',
  `extreme_input_bt` datetime DEFAULT NULL COMMENT 'Pasiektos ekstremalios įvado reikšmės intervalo pradžia',
  `extreme_input_et` datetime DEFAULT NULL COMMENT 'Pasiektos ekstremalios įvado reikšmės intervalo pabaiga',
  `extreme_output_bt` datetime DEFAULT NULL COMMENT 'Pasiektos ekstremalios išvado reikšmės intervalo pradžia',
  `extreme_output_et` datetime DEFAULT NULL COMMENT 'Pasiektos ekstremalios išvado reikšmės intervalo pabaiga',
  `extreme_prc_bt` datetime DEFAULT NULL COMMENT 'Pasiektos ekstremalios procentinės reikšmės intervalo pradžia',
  `extreme_prc_et` datetime DEFAULT NULL COMMENT 'Pasiektos ekstremalios procentinės reikšmės intervalo pabaiga',
  `extreme_prc_limit_bt` datetime DEFAULT NULL,
  `extreme_prc_limit_et` datetime DEFAULT NULL,
  PRIMARY KEY (`gr_id`,`ml_id`,`bt`),
  KEY `f_ar_g_ml_i` (`ml_id`,`bt`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Užfiksuoti grupių matavimų archyvų duomenys'
 PARTITION BY RANGE (
    to_days(bt))
(PARTITION par_201701 VALUES LESS THAN (736726) ENGINE = InnoDB,
 PARTITION par_201702 VALUES LESS THAN (736754) ENGINE = InnoDB,
 PARTITION par_201703 VALUES LESS THAN (736785) ENGINE = InnoDB,
 PARTITION par_201704 VALUES LESS THAN (736815) ENGINE = InnoDB,
 PARTITION par_201705 VALUES LESS THAN (736846) ENGINE = InnoDB);

-- Dumping data for table emcor.f_ar_g: ~5 rows (approximately)
/*!40000 ALTER TABLE `f_ar_g` DISABLE KEYS */;
/*!40000 ALTER TABLE `f_ar_g` ENABLE KEYS */;

-- Dumping structure for table emcor.gew
CREATE TABLE IF NOT EXISTS `gew` (
  `gew_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Apskaitos taškų įvykių, registruojamų įvykių registre, sąlygos ID',
  `gew_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Apskaitos taškų įvykių, registruojamų įvykių registre, sąlygos pavadinimas',
  `gew_enabled` tinyint(1) NOT NULL COMMENT 'Apskaitos taškų įvykių, registruojamų įvykių registre, sąlygos galiojimo požymis',
  `withe_type_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų vytelių tipo identifikatorius',
  `withe_id` mediumint(8) DEFAULT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `gr_id` int(10) unsigned DEFAULT NULL COMMENT 'Grupės identifikatorius',
  `gew_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Parų kiekis, apibrėžiantis paieškos gylį prietaisų įvykių žurnale',
  PRIMARY KEY (`gew_id`),
  UNIQUE KEY `gew_name_u` (`gew_name`),
  KEY `gew_gr_i` (`gr_id`),
  KEY `gew_withe_i` (`withe_id`),
  KEY `gew_withe_type_i` (`withe_type_id`),
  CONSTRAINT `gew_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE,
  CONSTRAINT `gew_withe_fk` FOREIGN KEY (`withe_id`) REFERENCES `withe` (`withe_id`) ON DELETE CASCADE,
  CONSTRAINT `gew_withe_type_fk` FOREIGN KEY (`withe_type_id`) REFERENCES `withe_type` (`withe_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apskaitos taškų įvykiai, registruojami įvykių registre';

-- Dumping data for table emcor.gew: ~0 rows (approximately)
/*!40000 ALTER TABLE `gew` DISABLE KEYS */;
/*!40000 ALTER TABLE `gew` ENABLE KEYS */;

-- Dumping structure for table emcor.gma_ma_tmpl
CREATE TABLE IF NOT EXISTS `gma_ma_tmpl` (
  `gma_ma_tmpl_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Apskaitos grupės monitoringo šablono elemento ID',
  `gma_tmpl_id` mediumint(8) unsigned NOT NULL COMMENT 'Apskaitos grupės monitoringo šablono ID',
  `verge_id` smallint(5) unsigned NOT NULL COMMENT 'Kraštinės ID',
  `ma_ab` tinyint(1) NOT NULL COMMENT 'Požymis, ar naudoti tiesinę transformaciją išeities rodiklio reikšmei',
  `ma_a_nom` float DEFAULT NULL COMMENT 'Tiesinės transformacijos daugiklio skaitiklis',
  `ma_a_denom` float DEFAULT NULL COMMENT 'Tiesinės transformacijos daugiklio vardiklis',
  `ma_b` double DEFAULT NULL COMMENT 'Tiesinės transformacijos dėmuo',
  `gpty_ma_a_nom` float DEFAULT NULL COMMENT 'Tiesinės transformacijos daugiklio skaitiklis, nurodytas per grupės savybę',
  `gpty_ma_a_denom` float DEFAULT NULL COMMENT 'Tiesinės transformacijos daugiklio vardiklis, nurodytas per grupės savybę',
  `gpty_ma_b` double DEFAULT NULL COMMENT 'Tiesinės transformacijos dėmuo, nurodytas per grupės savybę',
  `ignore_ma_ab` tinyint(1) NOT NULL COMMENT 'Tiesinės transformacijos atributų ignoravimo požymis',
  `ma_show` tinyint(1) NOT NULL COMMENT 'Priskirtos kraštinės atvaizdavimo požymis',
  `ma_auto_check` tinyint(1) NOT NULL COMMENT 'Požymis, ar automatiškai tikrinti rodiklių atitikimą nurodytuose perioduose',
  `ma_auto_null_act` tinyint(3) unsigned NOT NULL COMMENT 'Požymis, ar automatiškai priskirti nulinį aktą neatitikimo atveju',
  `ma_auto_ccs` tinyint(1) NOT NULL COMMENT 'Požymis, ar automatiškai priskirti nekomercinių duomenų statusą neatitikimo atveju',
  `ma_report_exceeding` tinyint(1) DEFAULT NULL COMMENT 'Požymis, ar tikrinama dėl viršijimo (ar dėl nusileidimo)',
  `ma_lag` mediumint(8) unsigned DEFAULT NULL COMMENT 'Monitoringo priskyrimo poslinkis laike',
  `ma_lag_per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Monitoringo priskyrimo poslinkio periodo identifikatorius',
  `gpty_id` int(10) unsigned DEFAULT NULL COMMENT 'Apskaitos grupės savybės ID',
  `ltc_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Tiesinės transformacijos koeficiento ID',
  `target_ml_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Paskirties matavimo linija',
  `target_gmod_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Paskirties sugrupuotų duomenų modifikacijos ',
  `target_gprc` tinyint(3) unsigned DEFAULT NULL COMMENT 'Paskirties grupės procentinės reikšmės naudojimo požymis ',
  `target_ec_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Paskirties ekonominės kategorijos identifikatorius ',
  `target_ec_in` tinyint(1) DEFAULT NULL COMMENT 'Paskirties ekonominės kategorijos pajamų/išlaidų požymis',
  `source_mt_id` int(10) unsigned DEFAULT NULL COMMENT 'Išeities monitoringe naudojamas rodiklis',
  `source_sam_tmpl_id` int(10) unsigned DEFAULT NULL,
  `source_ml_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išeities matavimo linija',
  `source_gmod_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išeities sugrupuotų duomenų modifikacijos ',
  `source_gprc` tinyint(3) unsigned DEFAULT NULL COMMENT 'Išeities grupės procentinės reikšmės naudojimo požymis',
  `source_ec_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išeities ekonominės kategorijos identifikatorius ',
  `source_ec_in` tinyint(1) DEFAULT NULL COMMENT 'Išeities ekonominės kategorijos pajamų/išlaidų požymis',
  `source_ecp_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išeities taško ekonominio profilio identifikatorius',
  PRIMARY KEY (`gma_ma_tmpl_id`),
  UNIQUE KEY `gma_ma_tmpl_u` (`gma_tmpl_id`,`target_ml_id`,`verge_id`,`target_gprc`,`target_gmod_id`,`target_ec_in`,`target_ec_id`),
  KEY `gma_ma_tmpl_gpty_i` (`gpty_id`),
  KEY `gma_ma_tmpl_ma_lag_per_i` (`ma_lag_per_id`),
  KEY `gma_ma_tmpl_sam_tmpl_id_i` (`source_sam_tmpl_id`),
  KEY `gma_ma_tmpl_source_ec_i` (`source_ec_id`),
  KEY `gma_ma_tmpl_source_gmod_i` (`source_gmod_id`),
  KEY `gma_ma_tmpl_source_ml_i` (`source_ml_id`),
  KEY `gma_ma_tmpl_source_mt_i` (`source_mt_id`),
  KEY `gma_ma_tmpl_target_ec_i` (`target_ec_id`),
  KEY `gma_ma_tmpl_target_gmod_i` (`target_gmod_id`),
  KEY `gma_ma_tmpl_target_ml_i` (`target_ml_id`),
  KEY `gma_ma_tmpl_verge_i` (`verge_id`),
  KEY `gma_ma_tmpl_ltc_fk` (`ltc_id`),
  CONSTRAINT `gma_ma_tmpl_fk` FOREIGN KEY (`gma_tmpl_id`) REFERENCES `gma_tmpl` (`gma_tmpl_id`) ON DELETE CASCADE,
  CONSTRAINT `gma_ma_tmpl_ltc_fk` FOREIGN KEY (`ltc_id`) REFERENCES `ltc` (`ltc_id`) ON DELETE SET NULL,
  CONSTRAINT `gma_ma_tmpl_ma_lag_per_fk` FOREIGN KEY (`ma_lag_per_id`) REFERENCES `per` (`per_id`) ON DELETE CASCADE,
  CONSTRAINT `gma_ma_tmpl_ppty_fk` FOREIGN KEY (`gpty_id`) REFERENCES `gpty` (`gpty_id`) ON DELETE SET NULL,
  CONSTRAINT `gma_ma_tmpl_sam_tmpl_fk` FOREIGN KEY (`source_sam_tmpl_id`) REFERENCES `sam_tmpl` (`sam_tmpl_id`) ON DELETE CASCADE,
  CONSTRAINT `gma_ma_tmpl_source_ec_fk` FOREIGN KEY (`source_ec_id`) REFERENCES `ec` (`ec_id`) ON DELETE CASCADE,
  CONSTRAINT `gma_ma_tmpl_source_gmod_fk` FOREIGN KEY (`source_gmod_id`) REFERENCES `gmod` (`gmod_id`) ON DELETE CASCADE,
  CONSTRAINT `gma_ma_tmpl_source_ml_fk` FOREIGN KEY (`source_ml_id`) REFERENCES `ml` (`ml_id`) ON DELETE CASCADE,
  CONSTRAINT `gma_ma_tmpl_source_mt_fk` FOREIGN KEY (`source_mt_id`) REFERENCES `mt` (`mt_id`) ON DELETE CASCADE,
  CONSTRAINT `gma_ma_tmpl_target_ec_fk` FOREIGN KEY (`target_ec_id`) REFERENCES `ec` (`ec_id`) ON DELETE CASCADE,
  CONSTRAINT `gma_ma_tmpl_target_gmod_fk` FOREIGN KEY (`target_gmod_id`) REFERENCES `gmod` (`gmod_id`) ON DELETE CASCADE,
  CONSTRAINT `gma_ma_tmpl_target_ml_fk` FOREIGN KEY (`target_ml_id`) REFERENCES `ml` (`ml_id`) ON DELETE CASCADE,
  CONSTRAINT `gma_ma_tmpl_verge_fk` FOREIGN KEY (`verge_id`) REFERENCES `verge` (`verge_id`) ON DELETE CASCADE,
  CONSTRAINT `GMA_MA_TMPL_NOT_IN_14_T_CHK` CHECK (`target_ml_id` is not null and `target_gmod_id` is null and `target_gprc` is null and `target_ec_id` is null and `target_ec_in` is null or `target_ml_id` is not null and `target_gprc` is not null and `target_gprc` in (0,1,2) and `target_ec_id` is null and `target_ec_in` is null or `target_ml_id` is not null and `target_gprc` is not null and `target_gprc` = 0 and `target_ec_id` is null and `target_ec_in` is not null and `target_ec_in` in (0,1) or `target_ml_id` is not null and `target_gprc` is not null and `target_gprc` = 0 and `target_ec_id` is not null and `target_ec_in` is null),
  CONSTRAINT `GMA_MA_TMPL_NOT_IN_14_S_CHK` CHECK (`source_mt_id` is null and `source_sam_tmpl_id` is null and `source_ml_id` is not null and `source_gmod_id` is null and `source_gprc` is null and `source_ec_id` is null and `source_ec_in` is null and `source_ecp_id` is null or `source_mt_id` is null and `source_sam_tmpl_id` is null and `source_ml_id` is not null and `source_gprc` is not null and `source_gprc` in (0,1,2) and `source_ec_id` is null and `source_ec_in` is null and `source_ecp_id` is null or `source_mt_id` is null and `source_sam_tmpl_id` is null and `source_ml_id` is not null and `source_gprc` is not null and `source_gprc` = 0 and `source_ec_id` is null and `source_ec_in` is not null and `source_ec_in` in (0,1) and `source_ecp_id` is null or `source_mt_id` is null and `source_sam_tmpl_id` is null and `source_ml_id` is not null and `source_gprc` is not null and `source_gprc` = 0 and `source_ec_id` is not null and `source_ec_in` is null and `source_ecp_id` is null or `source_mt_id` is not null and `source_sam_tmpl_id` is null and `source_ml_id` is null and `source_gmod_id` is null and `source_gprc` is null and `source_ec_id` is null and `source_ec_in` is null and `source_ecp_id` is null or `source_mt_id` is null and `source_sam_tmpl_id` is not null and `source_ml_id` is null and `source_gmod_id` is null and `source_gprc` is null and `source_ec_id` is null and `source_ec_in` is null and `source_ecp_id` is null or `source_mt_id` is null and `source_sam_tmpl_id` is null and `source_ml_id` is not null and `source_gprc` is null and `source_ec_id` is null and `source_ec_in` is null and `source_ecp_id` is not null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apskaitos grupės monitoringo šablonų elementai';

-- Dumping data for table emcor.gma_ma_tmpl: ~0 rows (approximately)
/*!40000 ALTER TABLE `gma_ma_tmpl` DISABLE KEYS */;
/*!40000 ALTER TABLE `gma_ma_tmpl` ENABLE KEYS */;

-- Dumping structure for table emcor.gma_tmpl
CREATE TABLE IF NOT EXISTS `gma_tmpl` (
  `gma_tmpl_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Apskaitos grupės monitoringo šablono ID',
  `gma_tmpl_code` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'Apskaitos grupės monitoringo šablono kodas',
  `gma_tmpl_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Apskaitos grupės monitoringo šablono pavadinimas',
  PRIMARY KEY (`gma_tmpl_id`),
  UNIQUE KEY `gma_tmpl_code_u` (`gma_tmpl_code`),
  UNIQUE KEY `gma_tmpl_name_u` (`gma_tmpl_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apskaitos grupės monitoringo šablonai';

-- Dumping data for table emcor.gma_tmpl: ~0 rows (approximately)
/*!40000 ALTER TABLE `gma_tmpl` DISABLE KEYS */;
/*!40000 ALTER TABLE `gma_tmpl` ENABLE KEYS */;

-- Dumping structure for table emcor.gmod
CREATE TABLE IF NOT EXISTS `gmod` (
  `gmod_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Sugrupuotų duomenų modifikacijos ID',
  `gmod_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Sugrupuotų duomenų modifikacijos kodas',
  `gmod_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Sugrupuotų duomenų modifikacijos pavadinimas',
  `ignore_group_value` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Grupės reikšmės ignoravimo požymis',
  `gmod_eu_code` varchar(20) COLLATE utf8_bin DEFAULT NULL COMMENT 'Grupės matavimo matavimo vienetų pakaitalas',
  `gmod_eu_code_usage` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Grupės matavimo matavimo vienetų pakaitalo naudojimo rėžimas',
  PRIMARY KEY (`gmod_id`),
  UNIQUE KEY `gmod_code_u` (`gmod_code`),
  UNIQUE KEY `gmod_name_u` (`gmod_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Galimos sugrupuotų duomenų modifikacijos';

-- Dumping data for table emcor.gmod: ~0 rows (approximately)
/*!40000 ALTER TABLE `gmod` DISABLE KEYS */;
/*!40000 ALTER TABLE `gmod` ENABLE KEYS */;

-- Dumping structure for table emcor.gmod_data
CREATE TABLE IF NOT EXISTS `gmod_data` (
  `gmod_id` mediumint(8) unsigned NOT NULL COMMENT 'Sugrupuotų duomenų modifikacijos ID',
  `gpty_id` int(10) unsigned DEFAULT NULL COMMENT 'Apskaitos grupių savybės identifikatorius',
  `ltc_id` tinyint(3) unsigned NOT NULL COMMENT 'Tiesinės transformacijos koeficiento ID',
  `gmod_const` double DEFAULT NULL COMMENT 'Sugrupuotų duomenų modifikacijos pastovi reikšmė',
  `gmod_data_nr` mediumint(8) unsigned NOT NULL COMMENT 'Sugrupuotų duomenų modifikacijos parametro numeris',
  `ms_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Matavimo identifikatorius',
  `tff_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Tarifo identifikatorius',
  `ec_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Ekonominės kategorijos identifikatorius',
  PRIMARY KEY (`gmod_id`,`gmod_data_nr`),
  KEY `gmod_data_ec_i` (`ec_id`),
  KEY `gmod_data_gpty_i` (`gpty_id`),
  KEY `gmod_data_ltc_i` (`ltc_id`),
  KEY `gmod_data_ms_fk` (`ms_id`),
  KEY `gmod_data_tff_fk` (`tff_id`),
  CONSTRAINT `gmod_data_ec_fk` FOREIGN KEY (`ec_id`) REFERENCES `ec` (`ec_id`) ON DELETE CASCADE,
  CONSTRAINT `gmod_data_gmod_fk` FOREIGN KEY (`gmod_id`) REFERENCES `gmod` (`gmod_id`) ON DELETE CASCADE,
  CONSTRAINT `gmod_data_gpty_fk` FOREIGN KEY (`gpty_id`) REFERENCES `gpty` (`gpty_id`),
  CONSTRAINT `gmod_data_ltc_fk` FOREIGN KEY (`ltc_id`) REFERENCES `ltc` (`ltc_id`),
  CONSTRAINT `gmod_data_ms_fk` FOREIGN KEY (`ms_id`) REFERENCES `ms` (`ms_id`) ON DELETE CASCADE,
  CONSTRAINT `gmod_data_tff_fk` FOREIGN KEY (`tff_id`) REFERENCES `tff` (`tff_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Sugrupuotų duomenų modifikacijų duomenys';

-- Dumping data for table emcor.gmod_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `gmod_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `gmod_data` ENABLE KEYS */;

-- Dumping structure for table emcor.gpty
CREATE TABLE IF NOT EXISTS `gpty` (
  `gpty_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Apskaitos grupių savybės identifikatorius',
  `gpty_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Apskaitos grupių savybės kodas',
  `gpty_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Apskaitos grupių savybės pavadinimas',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  `gpty_numeric` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Požymis, ar grupės savybės reikšmė turi būti skaitmeninė',
  `gpty_type_id` mediumint(8) unsigned NOT NULL DEFAULT 1 COMMENT 'Galimų apskaitos grupių savybių sąrašų tipo identifikatorius',
  `gpty_nr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Apskaitos grupių savybės eilės numeris rušiavimui',
  PRIMARY KEY (`gpty_id`),
  UNIQUE KEY `gpty_code_u` (`gpty_code`),
  UNIQUE KEY `gpty_name_u` (`gpty_name`),
  KEY `gpty_enum_i` (`enum_id`),
  KEY `gpty_type_id_i` (`gpty_type_id`),
  CONSTRAINT `gpty_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`),
  CONSTRAINT `gpty_type_id_fk` FOREIGN KEY (`gpty_type_id`) REFERENCES `gpty_type` (`gpty_type_id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Galimų apskaitos grupių savybių sąrašas';

-- Dumping data for table emcor.gpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `gpty` DISABLE KEYS */;
INSERT INTO `gpty` (`gpty_id`, `gpty_code`, `gpty_name`, `enum_id`, `gpty_numeric`, `gpty_type_id`, `gpty_nr`) VALUES
	(1, 'SUGGESTED_ROOT', 'Siūlyti vartotojams pasirinkti grupę, kaip šakninę', 82, 1, 1, NULL);
/*!40000 ALTER TABLE `gpty` ENABLE KEYS */;

-- Dumping structure for table emcor.gpty_cnt_grc
CREATE TABLE IF NOT EXISTS `gpty_cnt_grc` (
  `cont_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Grupės-konteinerio tipo identifikatorius',
  `gpty_id` int(10) unsigned NOT NULL COMMENT 'Apskaitos grupės savybės ID',
  `comp_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Grupės-komponento tipo identifikatorius',
  PRIMARY KEY (`cont_type_id`,`gpty_id`),
  KEY `gpty_cnt_grc_comp_type_fk` (`comp_type_id`),
  KEY `gpty_cnt_grc_gpty_fk` (`gpty_id`),
  CONSTRAINT `gpty_cnt_grc_comp_type_fk` FOREIGN KEY (`comp_type_id`) REFERENCES `gr_type` (`gr_type_id`) ON DELETE CASCADE,
  CONSTRAINT `gpty_cnt_grc_cont_type_fk` FOREIGN KEY (`cont_type_id`) REFERENCES `gr_type` (`gr_type_id`) ON DELETE CASCADE,
  CONSTRAINT `gpty_cnt_grc_gpty_fk` FOREIGN KEY (`gpty_id`) REFERENCES `gpty` (`gpty_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Dinamiškai suformuojamų grupių savybių pagal komponentų kiekį, konfigūracija';

-- Dumping data for table emcor.gpty_cnt_grc: ~0 rows (approximately)
/*!40000 ALTER TABLE `gpty_cnt_grc` DISABLE KEYS */;
/*!40000 ALTER TABLE `gpty_cnt_grc` ENABLE KEYS */;

-- Dumping structure for table emcor.gpty_cnt_grp
CREATE TABLE IF NOT EXISTS `gpty_cnt_grp` (
  `gr_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Apskaitos grupių tipo identifikatorius',
  `gpty_id` int(10) unsigned NOT NULL COMMENT 'Apskaitos grupės savybės ID',
  `ecp_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Taško ekonominio profilio identifikatorius',
  `point_type_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Matavimo taškų tipo identifikatorius',
  PRIMARY KEY (`gr_type_id`,`gpty_id`),
  KEY `gpty_cnt_grp_ecp_fk` (`ecp_id`),
  KEY `gpty_cnt_grp_gpty_fk` (`gpty_id`),
  KEY `gpty_cnt_grp_point_type_fk` (`point_type_id`),
  CONSTRAINT `gpty_cnt_grp_ecp_fk` FOREIGN KEY (`ecp_id`) REFERENCES `ecp` (`ecp_id`) ON DELETE CASCADE,
  CONSTRAINT `gpty_cnt_grp_gpty_fk` FOREIGN KEY (`gpty_id`) REFERENCES `gpty` (`gpty_id`) ON DELETE CASCADE,
  CONSTRAINT `gpty_cnt_grp_gr_type_fk` FOREIGN KEY (`gr_type_id`) REFERENCES `gr_type` (`gr_type_id`) ON DELETE CASCADE,
  CONSTRAINT `gpty_cnt_grp_point_type_fk` FOREIGN KEY (`point_type_id`) REFERENCES `point_type` (`point_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Dinamiškai suformuojamų grupių savybių pagal taškų kiekį, konfigūracija';

-- Dumping data for table emcor.gpty_cnt_grp: ~0 rows (approximately)
/*!40000 ALTER TABLE `gpty_cnt_grp` DISABLE KEYS */;
/*!40000 ALTER TABLE `gpty_cnt_grp` ENABLE KEYS */;

-- Dumping structure for table emcor.gpty_type
CREATE TABLE IF NOT EXISTS `gpty_type` (
  `gpty_type_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Galimų apskaitos grupių savybių sąrašų tipo identifikatorius',
  `gpty_type_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Galimų apskaitos grupių savybių sąrašų tipo kodas',
  `gpty_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Galimų apskaitos grupių savybių sąrašų tipo pavadinimas',
  PRIMARY KEY (`gpty_type_id`),
  UNIQUE KEY `gpty_type_code_uniq` (`gpty_type_code`),
  UNIQUE KEY `gpty_type_name_uniq` (`gpty_type_name`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Galimų apskaitos grupių savybių sąrašų tipai';

-- Dumping data for table emcor.gpty_type: ~0 rows (approximately)
/*!40000 ALTER TABLE `gpty_type` DISABLE KEYS */;
INSERT INTO `gpty_type` (`gpty_type_id`, `gpty_type_code`, `gpty_type_name`) VALUES
	(1, 'OTHER_PROPS', 'Kitos savybės');
/*!40000 ALTER TABLE `gpty_type` ENABLE KEYS */;

-- Dumping structure for table emcor.gr
CREATE TABLE IF NOT EXISTS `gr` (
  `gr_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Grupės identifikatorius',
  `user_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojo identifikatorius',
  `gr_type_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Apskaitos grupių tipo identifikatorius',
  `gr_code` varchar(80) COLLATE utf8_bin NOT NULL COMMENT 'Grupės kodas',
  `is_public` tinyint(1) NOT NULL COMMENT 'Viešos grupės požymis',
  `gr_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Grupės pavadinimas',
  PRIMARY KEY (`gr_id`),
  UNIQUE KEY `gr_code_u` (`gr_code`),
  KEY `gr_gr_type_i` (`gr_type_id`),
  KEY `gr_user_i` (`user_id`),
  CONSTRAINT `gr_gr_type_fk` FOREIGN KEY (`gr_type_id`) REFERENCES `gr_type` (`gr_type_id`) ON DELETE SET NULL,
  CONSTRAINT `gr_user_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`)
) ENGINE=InnoDB AUTO_INCREMENT=909 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apskaitos grupės';

-- Dumping data for table emcor.gr: ~41 rows (approximately)
/*!40000 ALTER TABLE `gr` DISABLE KEYS */;
INSERT INTO `gr` (`gr_id`, `user_id`, `gr_type_id`, `gr_code`, `is_public`, `gr_name`) VALUES
	(2, 0, 2, 'ALL.ROOT', 1, 'Pradinė šakninė grupė'),
	(549, 0, 2, 'NOT.IN.ALL.ROOT', 1, 'Taškai, nepasiekiami per apskaitos taškų medį'),
	(833, 1, 127, 'EMS', 1, 'EMS'),
	(834, 1, 127, 'EPQM', 1, 'EPQM'),
	(835, 1, 127, 'EPQS', 1, 'EPQS'),
	(838, 1, 127, 'LZKM', 1, 'LZKM'),
	(839, 1, 127, 'LZQM', 1, 'LZQM'),
	(847, 1, 2, 'USER_GROUPS', 1, 'Vartotojų grupės'),
	(850, 0, 2, 'BY_SRC_TYPE', 1, 'Pagal šaltinių tipus'),
	(855, 0, 2, 'BY_DP', 1, 'Pagal nuskaitymo tašką'),
	(860, 0, 127, 'HOPELESS', 1, 'Beviltiškos skylės'),
	(865, 0, 2, 'Generated_by_SQL_Server', 1, 'Generated_by_SQL_Server'),
	(866, 0, 2, 'BY_DP_GENERATED_BY_ORACLE', 1, 'Duomenų bazėje generuojami duomenys '),
	(867, 0, 2, 'BY_DP_GENERATED_BY_ORACLE_1389', 1, 'Sistemos monitoringo duomenų, fiksuojamų kas valandą generavimas'),
	(868, 0, 2, 'BY_DP_GENERATED_BY_ORACLE_1388', 1, 'Sistemos monitoringo duomenų, fiksuojamų kas parą generavimas'),
	(870, 0, 2, 'BOTTOM_10_SRC_BY_ERRORS', 1, 'Blogiausi šaltiniai pagal klaidų kiekį'),
	(871, 0, 2, 'BOTTOM_10_SRC_BY_NV', 1, 'Blogiausi šaltiniai pagal negaliojančių nuskaitymų kiekį'),
	(872, 0, 2, 'BOTTOM_10_DP_BY_SES_DURATION', 1, 'Labiausiai užimtų ryšių kanalų nuskaitymo taškai'),
	(873, 0, 2, 'NOT_SYNCHRONIZED', 1, 'Nesinchronizuoti'),
	(874, 0, 2, 'NO_DATA_FOR_THE_LAST_24_HOURS', 1, 'Nėra duomenų už paskutines paras'),
	(875, 0, 2, 'NO_READING', 1, 'Nėra nuskaitymo rezultatų'),
	(876, 0, 2, 'NO_ANY_READING', 1, 'Nėra jokių nuskaitymo duomenų'),
	(877, 0, 2, 'NEVER_GOT_STORABLE', 1, 'Niekada nebuvo matavimų duomenų'),
	(878, 0, 2, 'PARTIAL_FAILURE', 1, 'Nepildoma dalis galiojančių matavimų'),
	(879, 0, 2, 'DP_CONNECTION_FAILED', 1, 'Neatsakantys nuskaitymo taškai'),
	(880, 0, 2, 'DP_CONNECTION_CHANGED_TO_OK', 1, 'Atsakantys nuskaitymo taškai, kuriems buvo ryšio būklės pasikeitimų'),
	(881, 0, 2, 'DP_CONNECTION_OK_WITH_ERRORS', 1, 'Atsakantys nuskaitymo taškai, kuriems buvo ryšio klaidų'),
	(882, 0, 2, 'NO_RESTORE_DEPTH', 1, 'Taškai, kurių archyvą turintiems skaitiklių šaltiniams nenustatytas atstatymo gylis'),
	(883, 0, 2, 'DP_NO_ANY_STORABLE', 1, 'Nuskaitymo taškai, kuriems nėra duomenų už paskutines paras'),
	(884, 0, 2, 'NO_ANY_STORABLE_BUT_DP_HAS', 1, 'Taškai, kuriems nėra duomenų už paskutines paras, nors nuskaitymo taškams yra'),
	(885, 0, 2, 'MANDATORY_LPTY_MISSING', 1, 'Neužpildytos būtinos ryšio savybės'),
	(886, 0, 2, 'RECOMMENDED_LPTY_MISSING', 1, 'Neužpildytos rekomenduojamos ryšio savybės'),
	(887, 0, 2, 'OLD_HOLES', 1, 'Skylės už senus periodus'),
	(888, 0, 2, 'NOT_CLOSED', 1, 'Neuždaryti'),
	(890, 0, 2, 'BY_METER_TYPE', 1, 'Pagal matavimo prietaisų tipus'),
	(895, 0, 2, 'NO_ANY_RECENT_READING', 1, 'Nėra jokių nesenų nuskaitymo duomenų'),
	(900, 0, 2, 'MANY_EVENTS', 1, 'Daug įvykių'),
	(905, 0, 2, 'BY_POINT_TYPE', 1, 'Pagal matavimo taškų tipą'),
	(906, 0, 2, 'ELECTRICITY', 1, 'Elektros apskaita'),
	(907, 0, 127, 'IMPROPER', 1, 'Nėra galutinių rodmenų'),
	(908, 0, 2, 'BOTTOM_10_NOT_FAILED_DP_BY_SUCCESS', 1, 'Blogiausi atsakantys nuskaitymo taškai pagal užklausų sėkmės procentą');
/*!40000 ALTER TABLE `gr` ENABLE KEYS */;

-- Dumping structure for table emcor.grc
CREATE TABLE IF NOT EXISTS `grc` (
  `cont_id` int(10) unsigned NOT NULL COMMENT 'Grupės-konteinerio identifikatorius',
  `comp_id` int(10) unsigned NOT NULL COMMENT 'Grupės-komponento identifikatorius',
  `grc_bt` datetime NOT NULL DEFAULT '1899-12-30 00:00:00' COMMENT 'Grupės-komponento priklausomybės grupei-konteineriui periodo pradžia',
  `grc_et` datetime DEFAULT NULL COMMENT 'Grupės-komponento priklausomybės grupei-konteineriui periodo pabaiga',
  `grc_nr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Grupės-komponento eilės numeris',
  `grc_desc` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Grupės-komponento priklausomybės grupei-konteineriui periodo aprašymas',
  PRIMARY KEY (`cont_id`,`comp_id`,`grc_bt`),
  KEY `grc_comp_i` (`comp_id`),
  CONSTRAINT `grc_comp_gr_fk` FOREIGN KEY (`comp_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE,
  CONSTRAINT `grc_cont_gr_fk` FOREIGN KEY (`cont_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apskaitos grupių priklausomybė kitoms grupėms';

-- Dumping data for table emcor.grc: ~34 rows (approximately)
/*!40000 ALTER TABLE `grc` DISABLE KEYS */;
INSERT INTO `grc` (`cont_id`, `comp_id`, `grc_bt`, `grc_et`, `grc_nr`, `grc_desc`) VALUES
	(2, 549, '1999-12-30 00:00:00', NULL, 9, NULL),
	(2, 847, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 850, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 855, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 860, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 870, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 871, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 872, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 873, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 874, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 875, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 876, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 877, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 878, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 879, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 880, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 881, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 882, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 883, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 884, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 885, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 886, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 887, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 888, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 890, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 895, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 900, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 905, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(847, 908, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(850, 865, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(855, 866, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(866, 867, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(866, 868, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(905, 906, '1899-12-30 00:00:00', NULL, NULL, NULL);
/*!40000 ALTER TABLE `grc` ENABLE KEYS */;

-- Dumping structure for table emcor.grcj
CREATE TABLE IF NOT EXISTS `grcj` (
  `cont_id` int(10) unsigned NOT NULL COMMENT 'Grupės-konteinerio identifikatorius',
  `comp_id` int(10) unsigned NOT NULL COMMENT 'Grupės-komponento identifikatorius',
  `grc_bt` datetime NOT NULL COMMENT 'Grupės-komponento priklausomybės grupei-konteineriui periodo pradžia',
  `grc_et` datetime DEFAULT NULL COMMENT 'Grupės-komponento priklausomybės grupei-konteineriui periodo pabaiga',
  PRIMARY KEY (`cont_id`,`comp_id`,`grc_bt`),
  KEY `grcj_comp_i` (`comp_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apibendrinta į grupę įeinančių grupių sudėtis';

-- Dumping data for table emcor.grcj: ~73 rows (approximately)
/*!40000 ALTER TABLE `grcj` DISABLE KEYS */;
INSERT INTO `grcj` (`cont_id`, `comp_id`, `grc_bt`, `grc_et`) VALUES
	(2, 549, '1999-12-30 00:00:00', NULL),
	(2, 847, '1899-12-30 00:00:00', NULL),
	(2, 850, '1899-12-30 00:00:00', NULL),
	(2, 855, '1899-12-30 00:00:00', NULL),
	(2, 860, '1899-12-30 00:00:00', NULL),
	(2, 865, '1899-12-30 00:00:00', NULL),
	(2, 866, '1899-12-30 00:00:00', NULL),
	(2, 867, '1899-12-30 00:00:00', NULL),
	(2, 868, '1899-12-30 00:00:00', NULL),
	(2, 870, '1899-12-30 00:00:00', NULL),
	(2, 871, '1899-12-30 00:00:00', NULL),
	(2, 872, '1899-12-30 00:00:00', NULL),
	(2, 873, '1899-12-30 00:00:00', NULL),
	(2, 874, '1899-12-30 00:00:00', NULL),
	(2, 875, '1899-12-30 00:00:00', NULL),
	(2, 876, '1899-12-30 00:00:00', NULL),
	(2, 877, '1899-12-30 00:00:00', NULL),
	(2, 878, '1899-12-30 00:00:00', NULL),
	(2, 879, '1899-12-30 00:00:00', NULL),
	(2, 880, '1899-12-30 00:00:00', NULL),
	(2, 881, '1899-12-30 00:00:00', NULL),
	(2, 882, '1899-12-30 00:00:00', NULL),
	(2, 883, '1899-12-30 00:00:00', NULL),
	(2, 884, '1899-12-30 00:00:00', NULL),
	(2, 885, '1899-12-30 00:00:00', NULL),
	(2, 886, '1899-12-30 00:00:00', NULL),
	(2, 887, '1899-12-30 00:00:00', NULL),
	(2, 888, '1899-12-30 00:00:00', NULL),
	(2, 890, '1899-12-30 00:00:00', NULL),
	(2, 895, '1899-12-30 00:00:00', NULL),
	(2, 900, '1899-12-30 00:00:00', NULL),
	(2, 905, '1899-12-30 00:00:00', NULL),
	(2, 906, '1899-12-30 00:00:00', NULL),
	(2, 908, '1899-12-30 00:00:00', NULL),
	(847, 850, '1899-12-30 00:00:00', NULL),
	(847, 855, '1899-12-30 00:00:00', NULL),
	(847, 860, '1899-12-30 00:00:00', NULL),
	(847, 865, '1899-12-30 00:00:00', NULL),
	(847, 866, '1899-12-30 00:00:00', NULL),
	(847, 867, '1899-12-30 00:00:00', NULL),
	(847, 868, '1899-12-30 00:00:00', NULL),
	(847, 870, '1899-12-30 00:00:00', NULL),
	(847, 871, '1899-12-30 00:00:00', NULL),
	(847, 872, '1899-12-30 00:00:00', NULL),
	(847, 873, '1899-12-30 00:00:00', NULL),
	(847, 874, '1899-12-30 00:00:00', NULL),
	(847, 875, '1899-12-30 00:00:00', NULL),
	(847, 876, '1899-12-30 00:00:00', NULL),
	(847, 877, '1899-12-30 00:00:00', NULL),
	(847, 878, '1899-12-30 00:00:00', NULL),
	(847, 879, '1899-12-30 00:00:00', NULL),
	(847, 880, '1899-12-30 00:00:00', NULL),
	(847, 881, '1899-12-30 00:00:00', NULL),
	(847, 882, '1899-12-30 00:00:00', NULL),
	(847, 883, '1899-12-30 00:00:00', NULL),
	(847, 884, '1899-12-30 00:00:00', NULL),
	(847, 885, '1899-12-30 00:00:00', NULL),
	(847, 886, '1899-12-30 00:00:00', NULL),
	(847, 887, '1899-12-30 00:00:00', NULL),
	(847, 888, '1899-12-30 00:00:00', NULL),
	(847, 890, '1899-12-30 00:00:00', NULL),
	(847, 895, '1899-12-30 00:00:00', NULL),
	(847, 900, '1899-12-30 00:00:00', NULL),
	(847, 905, '1899-12-30 00:00:00', NULL),
	(847, 906, '1899-12-30 00:00:00', NULL),
	(847, 908, '1899-12-30 00:00:00', NULL),
	(850, 865, '1899-12-30 00:00:00', NULL),
	(855, 866, '1899-12-30 00:00:00', NULL),
	(855, 867, '1899-12-30 00:00:00', NULL),
	(855, 868, '1899-12-30 00:00:00', NULL),
	(866, 867, '1899-12-30 00:00:00', NULL),
	(866, 868, '1899-12-30 00:00:00', NULL),
	(905, 906, '1899-12-30 00:00:00', NULL);
/*!40000 ALTER TABLE `grcj` ENABLE KEYS */;

-- Dumping structure for table emcor.grcj_data
CREATE TABLE IF NOT EXISTS `grcj_data` (
  `cont_id` int(10) unsigned NOT NULL COMMENT 'Grupės-konteinerio identifikatorius',
  `cont_ms_id` smallint(5) unsigned NOT NULL COMMENT 'Grupės-konteinerio matavimo identifikatorius',
  `cont_dir_id` tinyint(4) NOT NULL COMMENT 'Grupės-konteinerio matavimo krypties identifikatorius',
  `cont_ec_id` mediumint(8) unsigned NOT NULL COMMENT 'Grupės-konteinerio ekonominės kategorijos identifikatorius',
  `comp_id` int(10) unsigned NOT NULL COMMENT 'Grupės-komponento identifikatorius',
  `comp_ms_id` smallint(5) unsigned NOT NULL COMMENT 'Grupės-komponento matavimo identifikatorius',
  `comp_dir_id` tinyint(4) NOT NULL COMMENT 'Grupės-komponento matavimo krypties identifikatorius',
  `comp_ec_id` mediumint(8) unsigned NOT NULL COMMENT 'Grupės-komponento ekonominės kategorijos identifikatorius',
  `grc_bt` datetime NOT NULL COMMENT 'Grupės-komponento priklausomybės grupei-konteineriui periodo pradžia',
  `coef` double NOT NULL DEFAULT 1 COMMENT 'Koeficientas',
  PRIMARY KEY (`cont_id`,`comp_id`,`grc_bt`,`comp_ms_id`,`comp_dir_id`,`comp_ec_id`,`cont_ms_id`,`cont_dir_id`,`cont_ec_id`),
  KEY `grcj_data_comp_dir_i` (`comp_dir_id`),
  KEY `grcj_data_comp_ec_i` (`comp_ec_id`),
  KEY `grcj_data_comp_ms_i` (`comp_ms_id`),
  KEY `grcj_data_cont_dir_i` (`cont_dir_id`),
  KEY `grcj_data_cont_ec_i` (`cont_ec_id`),
  KEY `grcj_data_cont_ms_i` (`cont_ms_id`,`cont_id`),
  CONSTRAINT `grcj_data_comp_dir_fk` FOREIGN KEY (`comp_dir_id`) REFERENCES `dir` (`dir_id`),
  CONSTRAINT `grcj_data_comp_ec_fk` FOREIGN KEY (`comp_ec_id`) REFERENCES `ec` (`ec_id`),
  CONSTRAINT `grcj_data_comp_ms_fk` FOREIGN KEY (`comp_ms_id`) REFERENCES `ms` (`ms_id`) ON DELETE CASCADE,
  CONSTRAINT `grcj_data_cont_dir_fk` FOREIGN KEY (`cont_dir_id`) REFERENCES `dir` (`dir_id`),
  CONSTRAINT `grcj_data_cont_ec_fk` FOREIGN KEY (`cont_ec_id`) REFERENCES `ec` (`ec_id`),
  CONSTRAINT `grcj_data_cont_ms_fk` FOREIGN KEY (`cont_ms_id`) REFERENCES `ms` (`ms_id`),
  CONSTRAINT `grcj_data_grc_fk` FOREIGN KEY (`cont_id`, `comp_id`, `grc_bt`) REFERENCES `grcj` (`cont_id`, `comp_id`, `grc_bt`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Grupės matavimų, sudaromų iš į grupę įeinančių apibendrintų grupių matavimų, duomenys';

-- Dumping data for table emcor.grcj_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `grcj_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `grcj_data` ENABLE KEYS */;

-- Dumping structure for table emcor.grc_data
CREATE TABLE IF NOT EXISTS `grc_data` (
  `cont_id` int(10) unsigned NOT NULL COMMENT 'Grupės-konteinerio identifikatorius',
  `cont_ms_id` smallint(5) unsigned NOT NULL COMMENT 'Grupės-konteinerio matavimo identifikatorius',
  `cont_dir_id` tinyint(4) NOT NULL COMMENT 'Grupės-konteinerio matavimo krypties identifikatorius',
  `cont_ec_id` mediumint(8) unsigned NOT NULL COMMENT 'Grupės-konteinerio ekonominės kategorijos identifikatorius',
  `comp_id` int(10) unsigned NOT NULL COMMENT 'Grupės-komponento identifikatorius',
  `comp_ms_id` smallint(5) unsigned NOT NULL COMMENT 'Grupės-komponento matavimo identifikatorius',
  `comp_dir_id` tinyint(4) NOT NULL COMMENT 'Grupės-komponento matavimo krypties identifikatorius',
  `comp_ec_id` mediumint(8) unsigned NOT NULL COMMENT 'Grupės-komponento ekonominės kategorijos identifikatorius',
  `grc_bt` datetime NOT NULL DEFAULT '1899-12-30 00:00:00' COMMENT 'Grupės-komponento priklausomybės grupei-konteineriui periodo pradžia',
  `coef` double NOT NULL DEFAULT 1 COMMENT 'Koeficientas',
  PRIMARY KEY (`cont_id`,`comp_id`,`grc_bt`,`comp_ms_id`,`comp_dir_id`,`comp_ec_id`,`cont_ms_id`,`cont_dir_id`,`cont_ec_id`),
  KEY `grc_data_comp_dir_i` (`comp_dir_id`),
  KEY `grc_data_comp_ec_i` (`comp_ec_id`),
  KEY `grc_data_comp_ms_i` (`comp_ms_id`),
  KEY `grc_data_cont_dir_i` (`cont_dir_id`),
  KEY `grc_data_cont_ec_i` (`cont_ec_id`),
  KEY `grc_data_cont_ms_i` (`cont_ms_id`,`cont_id`),
  CONSTRAINT `grc_data_comp_dir_fk` FOREIGN KEY (`comp_dir_id`) REFERENCES `dir` (`dir_id`),
  CONSTRAINT `grc_data_comp_ec_fk` FOREIGN KEY (`comp_ec_id`) REFERENCES `ec` (`ec_id`),
  CONSTRAINT `grc_data_comp_ms_fk` FOREIGN KEY (`comp_ms_id`) REFERENCES `ms` (`ms_id`) ON DELETE CASCADE,
  CONSTRAINT `grc_data_cont_dir_fk` FOREIGN KEY (`cont_dir_id`) REFERENCES `dir` (`dir_id`),
  CONSTRAINT `grc_data_cont_ec_fk` FOREIGN KEY (`cont_ec_id`) REFERENCES `ec` (`ec_id`),
  CONSTRAINT `grc_data_cont_ms_fk` FOREIGN KEY (`cont_ms_id`) REFERENCES `ms` (`ms_id`),
  CONSTRAINT `grc_data_grc_fk` FOREIGN KEY (`cont_id`, `comp_id`, `grc_bt`) REFERENCES `grc` (`cont_id`, `comp_id`, `grc_bt`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apskaitos grupių priklausomybės kitoms grupėms duomenys';

-- Dumping data for table emcor.grc_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `grc_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `grc_data` ENABLE KEYS */;

-- Dumping structure for table emcor.grc_rule
CREATE TABLE IF NOT EXISTS `grc_rule` (
  `cont_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Grupės-konteinerio tipo identifikatorius',
  `cont_ms_id` smallint(5) unsigned NOT NULL COMMENT 'Grupės-konteinerio matavimo identifikatorius',
  `cont_dir_id` tinyint(4) NOT NULL COMMENT 'Grupės-konteinerio matavimo krypties identifikatorius',
  `cont_ec_id` mediumint(8) unsigned NOT NULL COMMENT 'Grupės-konteinerio ekonominės kategorijos identifikatorius',
  `comp_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Grupės-komponento tipo identifikatorius',
  `comp_ms_id` smallint(5) unsigned NOT NULL COMMENT 'Grupės-komponento matavimo identifikatorius',
  `comp_dir_id` tinyint(4) NOT NULL COMMENT 'Grupės-komponento matavimo krypties identifikatorius',
  `comp_ec_id` mediumint(8) unsigned NOT NULL COMMENT 'Grupės-komponento ekonominės kategorijos identifikatorius',
  `rule_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Taisyklės galiojimo požymis',
  `coef` double NOT NULL DEFAULT 1 COMMENT 'Koeficientas',
  PRIMARY KEY (`cont_type_id`,`comp_type_id`,`cont_ms_id`,`comp_ms_id`,`cont_dir_id`,`comp_dir_id`,`cont_ec_id`,`comp_ec_id`),
  KEY `grc_rule_comp_ec_i` (`comp_ec_id`),
  KEY `grc_rule_comp_type_i` (`comp_type_id`),
  KEY `grc_rule_cont_ec_i` (`cont_ec_id`),
  KEY `grc_rule_comp_dir_fk` (`comp_dir_id`),
  KEY `grc_rule_comp_ms_fk` (`comp_ms_id`),
  KEY `grc_rule_cont_dir_fk` (`cont_dir_id`),
  KEY `grc_rule_cont_ms_fk` (`cont_ms_id`),
  CONSTRAINT `grc_rule_comp_dir_fk` FOREIGN KEY (`comp_dir_id`) REFERENCES `dir` (`dir_id`),
  CONSTRAINT `grc_rule_comp_ec_fk` FOREIGN KEY (`comp_ec_id`) REFERENCES `ec` (`ec_id`),
  CONSTRAINT `grc_rule_comp_ms_fk` FOREIGN KEY (`comp_ms_id`) REFERENCES `ms` (`ms_id`),
  CONSTRAINT `grc_rule_comp_type_fk` FOREIGN KEY (`comp_type_id`) REFERENCES `gr_type` (`gr_type_id`) ON DELETE CASCADE,
  CONSTRAINT `grc_rule_cont_dir_fk` FOREIGN KEY (`cont_dir_id`) REFERENCES `dir` (`dir_id`),
  CONSTRAINT `grc_rule_cont_ec_fk` FOREIGN KEY (`cont_ec_id`) REFERENCES `ec` (`ec_id`),
  CONSTRAINT `grc_rule_cont_ms_fk` FOREIGN KEY (`cont_ms_id`) REFERENCES `ms` (`ms_id`),
  CONSTRAINT `grc_rule_cont_type_fk` FOREIGN KEY (`cont_type_id`) REFERENCES `gr_type` (`gr_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Automatinio apskaitos grupių priklausomybės kitoms grupėms duomenų pildymo taisyklės';

-- Dumping data for table emcor.grc_rule: ~0 rows (approximately)
/*!40000 ALTER TABLE `grc_rule` DISABLE KEYS */;
/*!40000 ALTER TABLE `grc_rule` ENABLE KEYS */;

-- Dumping structure for table emcor.grp
CREATE TABLE IF NOT EXISTS `grp` (
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `grp_bt` datetime NOT NULL DEFAULT '1899-12-30 00:00:00' COMMENT 'Taško priklausomybės grupei periodo pradžia',
  `grp_et` datetime DEFAULT NULL COMMENT 'Taško priklausomybės grupei periodo pabaiga',
  `grp_nr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Taško eilės numeris',
  `grp_desc` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Taško priklausomybės grupei periodo aprašymas',
  PRIMARY KEY (`gr_id`,`point_id`,`grp_bt`),
  KEY `grp_point_i` (`point_id`),
  CONSTRAINT `grp_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`),
  CONSTRAINT `grp_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apskaitos taškų priklausomybė apskaitos grupėms';

-- Dumping data for table emcor.grp: ~5 rows (approximately)
/*!40000 ALTER TABLE `grp` DISABLE KEYS */;
INSERT INTO `grp` (`gr_id`, `point_id`, `grp_bt`, `grp_et`, `grp_nr`, `grp_desc`) VALUES
	(865, 1, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(867, 1, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(868, 1, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(878, 1, '1899-12-30 00:00:00', NULL, NULL, NULL),
	(906, 1, '1899-12-30 00:00:00', NULL, NULL, NULL);
/*!40000 ALTER TABLE `grp` ENABLE KEYS */;

-- Dumping structure for table emcor.grpj
CREATE TABLE IF NOT EXISTS `grpj` (
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `grp_bt` datetime NOT NULL COMMENT 'Taško priklausomybės grupei periodo pradžia',
  `grp_et` datetime DEFAULT NULL COMMENT 'Taško priklausomybės grupei periodo pabaiga',
  PRIMARY KEY (`gr_id`,`point_id`,`grp_bt`),
  KEY `grpj_point_i` (`point_id`),
  CONSTRAINT `grpj_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`),
  CONSTRAINT `grpj_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apibendrinta į grupę įeinančių apskaitos taškų sudėtis';

-- Dumping data for table emcor.grpj: ~11 rows (approximately)
/*!40000 ALTER TABLE `grpj` DISABLE KEYS */;
INSERT INTO `grpj` (`gr_id`, `point_id`, `grp_bt`, `grp_et`) VALUES
	(2, 1, '1899-12-30 00:00:00', NULL),
	(847, 1, '1899-12-30 00:00:00', NULL),
	(850, 1, '1899-12-30 00:00:00', NULL),
	(855, 1, '1899-12-30 00:00:00', NULL),
	(865, 1, '1899-12-30 00:00:00', NULL),
	(866, 1, '1899-12-30 00:00:00', NULL),
	(867, 1, '1899-12-30 00:00:00', NULL),
	(868, 1, '1899-12-30 00:00:00', NULL),
	(878, 1, '1899-12-30 00:00:00', NULL),
	(905, 1, '1899-12-30 00:00:00', NULL),
	(906, 1, '1899-12-30 00:00:00', NULL);
/*!40000 ALTER TABLE `grpj` ENABLE KEYS */;

-- Dumping structure for table emcor.grpj_data
CREATE TABLE IF NOT EXISTS `grpj_data` (
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  `gr_ms_id` smallint(5) unsigned NOT NULL COMMENT 'Apskaitos grupės matavimo identifikatorius',
  `gr_dir_id` tinyint(4) NOT NULL COMMENT 'Grupės matavimo krypties identifikatorius',
  `gr_ec_id` mediumint(8) unsigned NOT NULL COMMENT 'Apskaitos grupės ekonominės kategorijos identifikatorius',
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `point_ms_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimo taško matavimo identifikatorius',
  `point_dir_id` tinyint(4) NOT NULL COMMENT 'Matavimo taško matavimo krypties identifikatorius',
  `grp_bt` datetime NOT NULL COMMENT 'Taško priklausomybės grupei periodo pradžia',
  `coef` double NOT NULL DEFAULT 1 COMMENT 'Koeficientas',
  PRIMARY KEY (`gr_id`,`point_id`,`grp_bt`,`point_ms_id`,`point_dir_id`,`gr_ms_id`,`gr_dir_id`,`gr_ec_id`),
  KEY `grpj_data_gr_dir_i` (`gr_dir_id`),
  KEY `grpj_data_gr_ec_i` (`gr_ec_id`),
  KEY `grpj_data_gr_ms_i` (`gr_ms_id`),
  KEY `grpj_data_point_dir_i` (`point_dir_id`),
  KEY `grpj_data_point_ms_i` (`point_ms_id`),
  CONSTRAINT `grpj_data_ec_fk` FOREIGN KEY (`gr_ec_id`) REFERENCES `ec` (`ec_id`),
  CONSTRAINT `grpj_data_gr_dir_fk` FOREIGN KEY (`gr_dir_id`) REFERENCES `dir` (`dir_id`),
  CONSTRAINT `grpj_data_gr_ms_fk` FOREIGN KEY (`gr_ms_id`) REFERENCES `ms` (`ms_id`),
  CONSTRAINT `grpj_data_grp_fk` FOREIGN KEY (`gr_id`, `point_id`, `grp_bt`) REFERENCES `grpj` (`gr_id`, `point_id`, `grp_bt`) ON DELETE CASCADE,
  CONSTRAINT `grpj_data_point_dir_fk` FOREIGN KEY (`point_dir_id`) REFERENCES `dir` (`dir_id`),
  CONSTRAINT `grpj_data_point_ms_fk` FOREIGN KEY (`point_ms_id`) REFERENCES `ms` (`ms_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Grupės matavimų, sudaromų iš į grupę įeinančių apibendrintų apskaitos taškų matavimų, duomenys';

-- Dumping data for table emcor.grpj_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `grpj_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `grpj_data` ENABLE KEYS */;

-- Dumping structure for table emcor.grp_data
CREATE TABLE IF NOT EXISTS `grp_data` (
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  `gr_ms_id` smallint(5) unsigned NOT NULL COMMENT 'Apskaitos grupės matavimo identifikatorius',
  `gr_dir_id` tinyint(4) NOT NULL COMMENT 'Grupės matavimo krypties identifikatorius',
  `gr_ec_id` mediumint(8) unsigned NOT NULL COMMENT 'Apskaitos grupės ekonominės kategorijos identifikatorius',
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `point_ms_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimo taško matavimo identifikatorius',
  `point_dir_id` tinyint(4) NOT NULL COMMENT 'Matavimo taško matavimo krypties identifikatorius',
  `grp_bt` datetime NOT NULL DEFAULT '1899-12-30 00:00:00' COMMENT 'Taško priklausomybės grupei periodo pradžia',
  `coef` double NOT NULL DEFAULT 1 COMMENT 'Koeficientas',
  PRIMARY KEY (`gr_id`,`point_id`,`grp_bt`,`point_ms_id`,`point_dir_id`,`gr_ms_id`,`gr_dir_id`,`gr_ec_id`),
  KEY `grp_data_gr_dir_i` (`gr_dir_id`),
  KEY `grp_data_gr_ec_i` (`gr_ec_id`),
  KEY `grp_data_gr_ms_i` (`gr_ms_id`),
  KEY `grp_data_point_dir_i` (`point_dir_id`),
  KEY `grp_data_point_ms_i` (`point_ms_id`),
  CONSTRAINT `grp_data_ec_fk` FOREIGN KEY (`gr_ec_id`) REFERENCES `ec` (`ec_id`),
  CONSTRAINT `grp_data_gr_dir_fk` FOREIGN KEY (`gr_dir_id`) REFERENCES `dir` (`dir_id`),
  CONSTRAINT `grp_data_gr_ms_fk` FOREIGN KEY (`gr_ms_id`) REFERENCES `ms` (`ms_id`),
  CONSTRAINT `grp_data_grp_fk` FOREIGN KEY (`gr_id`, `point_id`, `grp_bt`) REFERENCES `grp` (`gr_id`, `point_id`, `grp_bt`) ON DELETE CASCADE,
  CONSTRAINT `grp_data_point_dir_fk` FOREIGN KEY (`point_dir_id`) REFERENCES `dir` (`dir_id`),
  CONSTRAINT `grp_data_point_ms_fk` FOREIGN KEY (`point_ms_id`) REFERENCES `ms` (`ms_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apskaitos taškų priklausomybės apskaitos grupėms duomenys';

-- Dumping data for table emcor.grp_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `grp_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `grp_data` ENABLE KEYS */;

-- Dumping structure for table emcor.grq_otype
CREATE TABLE IF NOT EXISTS `grq_otype` (
  `grq_otype_id` smallint(5) unsigned NOT NULL COMMENT 'Sugrupuotos užklausos draiveriui operacijos tipas',
  `grq_otype_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Sugrupuotos užklausos draiveriui operacijos kodas',
  `grq_otype_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Sugrupuotos užklausos draiveriui operacijos pavadinimas',
  PRIMARY KEY (`grq_otype_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Operacijų su sugrupuotomis užklausomis tipai';

-- Dumping data for table emcor.grq_otype: ~10 rows (approximately)
/*!40000 ALTER TABLE `grq_otype` DISABLE KEYS */;
INSERT INTO `grq_otype` (`grq_otype_id`, `grq_otype_code`, `grq_otype_name`) VALUES
	(1, 'Creation', 'Sukūrimas ir pastatymas į eilę'),
	(2, 'SentTo_TM', 'Persiuntimas į transporto menedžerį'),
	(3, 'RejectFrom_TM', 'Atmetimas iš transporto menedžerio'),
	(4, 'DeleteByProgrammShutDown', 'Išmetimas dėl programos uždarymo'),
	(5, 'DeleteByUser', 'Išmetimas dėl vartotojo nurodymo'),
	(6, 'DeleteByRemoteControl', 'Išmetimas dėl valdymo programos nurodymo'),
	(7, 'DeleteBecauseOldAge', 'Išmetimas dėl senumo'),
	(8, 'LinkError', 'Transporto menedžerio klaida'),
	(9, 'Destroy', 'Normalus užbaigimas'),
	(10, 'LinkDown', 'Transporto menedžeris iškrautas');
/*!40000 ALTER TABLE `grq_otype` ENABLE KEYS */;

-- Dumping structure for table emcor.gr_gma_tmpl
CREATE TABLE IF NOT EXISTS `gr_gma_tmpl` (
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Apskaitos grupės identifikatorius',
  `gma_tmpl_id` mediumint(8) unsigned NOT NULL COMMENT 'Apskaitos grupės monitoringo šablono ID',
  PRIMARY KEY (`gr_id`),
  KEY `gr_gma_tmpl_gma_tmpl_i` (`gma_tmpl_id`),
  CONSTRAINT `gr_gma_tmpl_gma_tmpl_fk` FOREIGN KEY (`gma_tmpl_id`) REFERENCES `gma_tmpl` (`gma_tmpl_id`) ON DELETE CASCADE,
  CONSTRAINT `gr_gma_tmpl_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apskaitos grupės monitoringo šablonų priskyrimai';

-- Dumping data for table emcor.gr_gma_tmpl: ~0 rows (approximately)
/*!40000 ALTER TABLE `gr_gma_tmpl` DISABLE KEYS */;
/*!40000 ALTER TABLE `gr_gma_tmpl` ENABLE KEYS */;

-- Dumping structure for table emcor.gr_gpty
CREATE TABLE IF NOT EXISTS `gr_gpty` (
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  `gpty_id` int(10) unsigned NOT NULL COMMENT 'Apskaitos grupių savybės identifikatorius',
  `gpty_value` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Apskaitos grupės savybės reikšmė',
  `sam_id` int(10) unsigned DEFAULT NULL COMMENT 'Šablono identifikatorius',
  PRIMARY KEY (`gr_id`,`gpty_id`),
  KEY `gr_gpty_gpty_i` (`gpty_id`),
  KEY `gr_gpty_sam_i` (`sam_id`),
  CONSTRAINT `gr_gpty_gpty_fk` FOREIGN KEY (`gpty_id`) REFERENCES `gpty` (`gpty_id`),
  CONSTRAINT `gr_gpty_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE,
  CONSTRAINT `gr_gpty_sam_fk` FOREIGN KEY (`sam_id`) REFERENCES `sam` (`sam_id`),
  CONSTRAINT `GR_GPTY_NOT_IN_2_CHK` CHECK (`gpty_value` is not null and `sam_id` is null or `gpty_value` is null and `sam_id` is not null),
  CONSTRAINT `GR_GPTY_SYMBOL_CHECK` CHECK (nullif(regexp_replace(`gpty_value`,'([[:print:]])+',''),'') is null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apskaitos grupių savybės';

-- Dumping data for table emcor.gr_gpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `gr_gpty` DISABLE KEYS */;
/*!40000 ALTER TABLE `gr_gpty` ENABLE KEYS */;

-- Dumping structure for table emcor.gr_mau
CREATE TABLE IF NOT EXISTS `gr_mau` (
  `gr_id` int(10) unsigned NOT NULL,
  PRIMARY KEY (`gr_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.gr_mau: ~0 rows (approximately)
/*!40000 ALTER TABLE `gr_mau` DISABLE KEYS */;
/*!40000 ALTER TABLE `gr_mau` ENABLE KEYS */;

-- Dumping structure for table emcor.gr_type
CREATE TABLE IF NOT EXISTS `gr_type` (
  `gr_type_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Apskaitos grupių tipo identifikatorius',
  `gr_type_code` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Apskaitos grupių tipo kodas',
  `gr_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Apskaitos grupių tipo pavadinimas',
  PRIMARY KEY (`gr_type_id`),
  UNIQUE KEY `gr_type_code_u` (`gr_type_code`),
  UNIQUE KEY `gr_type_name_u` (`gr_type_name`)
) ENGINE=InnoDB AUTO_INCREMENT=129 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apskaitos grupių tipai';

-- Dumping data for table emcor.gr_type: ~7 rows (approximately)
/*!40000 ALTER TABLE `gr_type` DISABLE KEYS */;
INSERT INTO `gr_type` (`gr_type_id`, `gr_type_code`, `gr_type_name`) VALUES
	(1, 'OBJ', 'Objektas'),
	(2, 'SYSTEM', 'Sisteminė'),
	(21, 'UNIT', 'Padalinys'),
	(101, 'TOWN', 'Miestas'),
	(126, 'REGION', 'Regionas'),
	(127, 'UD', 'Vartotojo grupė'),
	(128, 'DP', 'Nuskaitymo taškas');
/*!40000 ALTER TABLE `gr_type` ENABLE KEYS */;

-- Dumping structure for table emcor.gr_type_gpty
CREATE TABLE IF NOT EXISTS `gr_type_gpty` (
  `gr_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Apskaitos grupių tipo identifikatorius',
  `gpty_id` int(10) unsigned NOT NULL COMMENT 'Apskaitos grupių savybės identifikatorius',
  PRIMARY KEY (`gr_type_id`,`gpty_id`),
  KEY `gr_type_gpty_gpty_i` (`gpty_id`),
  CONSTRAINT `gr_type_gpty_gpty_fk` FOREIGN KEY (`gpty_id`) REFERENCES `gpty` (`gpty_id`) ON DELETE CASCADE,
  CONSTRAINT `gr_type_gpty_gr_type_fk` FOREIGN KEY (`gr_type_id`) REFERENCES `gr_type` (`gr_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Grupių savybės pagal grupių tipus';

-- Dumping data for table emcor.gr_type_gpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `gr_type_gpty` DISABLE KEYS */;
/*!40000 ALTER TABLE `gr_type_gpty` ENABLE KEYS */;

-- Dumping structure for table emcor.gtp
CREATE TABLE IF NOT EXISTS `gtp` (
  `gtp_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Apskaitos grupei priskirto tarifų plano identifikatorius',
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  `ms_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimo identifikatorius',
  `tp_id` mediumint(8) unsigned NOT NULL COMMENT 'Tarifų plano identifikatorius',
  `gtp_bt` datetime DEFAULT NULL COMMENT 'Apskaitos grupei priskirto tarifų plano periodo pradžia',
  `gtp_et` datetime DEFAULT NULL COMMENT 'Apskaitos grupei priskirto tarifų plano periodo pabaiga',
  `aggf_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Agregavimo funkcijos identifikatorius',
  PRIMARY KEY (`gtp_id`),
  UNIQUE KEY `gtp_ak` (`gr_id`,`ms_id`,`aggf_id`,`gtp_bt`,`gtp_et`),
  KEY `gtp_ms_i` (`ms_id`),
  KEY `gtp_tp_i` (`tp_id`),
  KEY `gtp_aggf_fk` (`aggf_id`),
  CONSTRAINT `gtp_aggf_fk` FOREIGN KEY (`aggf_id`) REFERENCES `aggf` (`aggf_id`),
  CONSTRAINT `gtp_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE,
  CONSTRAINT `gtp_ms_fk` FOREIGN KEY (`ms_id`) REFERENCES `ms` (`ms_id`),
  CONSTRAINT `gtp_tp_fk` FOREIGN KEY (`tp_id`) REFERENCES `tp` (`tp_id`),
  CONSTRAINT `GTP_AGGF_CHK` CHECK (`aggf_id` is null or `aggf_id` is not null and `aggf_id` in (2,3))
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apskaitos grupėms priskirti tarifų planai';

-- Dumping data for table emcor.gtp: ~0 rows (approximately)
/*!40000 ALTER TABLE `gtp` DISABLE KEYS */;
/*!40000 ALTER TABLE `gtp` ENABLE KEYS */;

-- Dumping structure for table emcor.hld
CREATE TABLE IF NOT EXISTS `hld` (
  `hld_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Šventinių dienų rinkinio identifikatorius',
  `hld_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Šventinių dienų rinkinio pavadinimas',
  PRIMARY KEY (`hld_id`),
  UNIQUE KEY `hld_name_u` (`hld_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Šventinių dienų rinkiniai';

-- Dumping data for table emcor.hld: ~0 rows (approximately)
/*!40000 ALTER TABLE `hld` DISABLE KEYS */;
/*!40000 ALTER TABLE `hld` ENABLE KEYS */;

-- Dumping structure for table emcor.hld_data
CREATE TABLE IF NOT EXISTS `hld_data` (
  `hld_id` mediumint(8) unsigned NOT NULL COMMENT 'Šventinių dienų rinkinio identifikatorius',
  `mm` tinyint(3) unsigned NOT NULL COMMENT 'Mėnesio numeris',
  `dd` tinyint(3) unsigned NOT NULL COMMENT 'Dienos numeris',
  PRIMARY KEY (`hld_id`,`mm`,`dd`),
  CONSTRAINT `hld_data_hld_fk` FOREIGN KEY (`hld_id`) REFERENCES `hld` (`hld_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Šventinių dienų rinkinių šventinės dienos';

-- Dumping data for table emcor.hld_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `hld_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `hld_data` ENABLE KEYS */;

-- Dumping structure for table emcor.hld_sp_data
CREATE TABLE IF NOT EXISTS `hld_sp_data` (
  `hld_id` mediumint(8) unsigned NOT NULL COMMENT 'Šventinių dienų rinkinio identifikatorius',
  `hday` date NOT NULL COMMENT 'Data',
  `wd` tinyint(3) unsigned NOT NULL DEFAULT 8 COMMENT 'Savaitės dienos numeris',
  `da_desc` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Dienos komentaras',
  PRIMARY KEY (`hld_id`,`hday`),
  CONSTRAINT `hld_sp_data_hld_fk` FOREIGN KEY (`hld_id`) REFERENCES `hld` (`hld_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Šventinių dienų rinkinių specialios dienos';

-- Dumping data for table emcor.hld_sp_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `hld_sp_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `hld_sp_data` ENABLE KEYS */;

-- Dumping structure for table emcor.hmp
CREATE TABLE IF NOT EXISTS `hmp` (
  `table_name` varchar(30) COLLATE utf8_bin NOT NULL COMMENT 'Lentelės vardas',
  `part` tinyint(3) unsigned NOT NULL COMMENT 'Particijos numeris',
  `amp` datetime NOT NULL COMMENT 'Laiko žymė',
  PRIMARY KEY (`table_name`,`part`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Hand-made partitioning lentelių laiko žymių duomenys';

-- Dumping data for table emcor.hmp: ~0 rows (approximately)
/*!40000 ALTER TABLE `hmp` DISABLE KEYS */;
/*!40000 ALTER TABLE `hmp` ENABLE KEYS */;

-- Dumping structure for table emcor.icc
CREATE TABLE IF NOT EXISTS `icc` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `icc_t` datetime NOT NULL COMMENT 'Matavimo taške sumontuoto matavimo prietaiso neesminio konfigūracijos pakeitimo laikas',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Matavimo taške sumontuoto matavimo prietaiso neesminio konfiguracijos pakeitimo įrašymo data',
  PRIMARY KEY (`point_id`,`icc_t`),
  CONSTRAINT `icc_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškuose sumontuotų matavimo prietaisų neesminiai konfigūracijos pakeitimai';

-- Dumping data for table emcor.icc: ~0 rows (approximately)
/*!40000 ALTER TABLE `icc` DISABLE KEYS */;
/*!40000 ALTER TABLE `icc` ENABLE KEYS */;

-- Dumping structure for table emcor.iger
CREATE TABLE IF NOT EXISTS `iger` (
  `nr` mediumint(8) unsigned NOT NULL COMMENT 'Numeris',
  PRIMARY KEY (`nr`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Sveikieji skaičiai ';

-- Dumping data for table emcor.iger: ~86 961 rows (approximately)
/*!40000 ALTER TABLE `iger` DISABLE KEYS */;
INSERT INTO `iger` (`nr`) VALUES
	(1),
	(2),
	(3),
	(4),
	(5),
	(6),
	(7),
	(8),
	(9),
	(10),
	(11),
	(12),
	(13),
	(14),
	(15),
	(16),
	(17),
	(18),
	(19),
	(20),
	(21),
	(22),
	(23),
	(24),
	(25),
	(26),
	(27),
	(28),
	(29),
	(30),
	(31),
	(32),
	(33),
	(34),
	(35),
	(36),
	(37),
	(38),
	(39),
	(40),
	(41),
	(42),
	(43),
	(44),
	(45),
	(46),
	(47),
	(48),
	(49),
	(50),
	(51),
	(52),
	(53),
	(54),
	(55),
	(56),
	(57),
	(58),
	(59),
	(60),
	(61),
	(62),
	(63),
	(64),
	(65),
	(66),
	(67),
	(68),
	(69),
	(70),
	(71),
	(72),
	(73),
	(74),
	(75),
	(76),
	(77),
	(78),
	(79),
	(80),
	(81),
	(82),
	(83),
	(84),
	(85),
	(86),
	(87),
	(88),
	(89),
	(90),
	(91),
	(92),
	(93),
	(94),
	(95),
	(96),
	(97),
	(98),
	(99),
	(100),
	(101),
	(102),
	(103),
	(104),
	(105),
	(106),
	(107),
	(108),
	(109),
	(110),
	(111),
	(112),
	(113),
	(114),
	(115),
	(116),
	(117),
	(118),
	(119),
	(120),
	(121),
	(122),
	(123),
	(124),
	(125),
	(126),
	(127),
	(128),
	(129),
	(130),
	(131),
	(132),
	(133),
	(134),
	(135),
	(136),
	(137),
	(138),
	(139),
	(140),
	(141),
	(142),
	(143),
	(144),
	(145),
	(146),
	(147),
	(148),
	(149),
	(150),
	(151),
	(152),
	(153),
	(154),
	(155),
	(156),
	(157),
	(158),
	(159),
	(160),
	(161),
	(162),
	(163),
	(164),
	(165),
	(166),
	(167),
	(168),
	(169),
	(170),
	(171),
	(172),
	(173),
	(174),
	(175),
	(176),
	(177),
	(178),
	(179),
	(180),
	(181),
	(182),
	(183),
	(184),
	(185),
	(186),
	(187),
	(188),
	(189),
	(190),
	(191),
	(192),
	(193),
	(194),
	(195),
	(196),
	(197),
	(198),
	(199),
	(200),
	(201),
	(202),
	(203),
	(204),
	(205),
	(206),
	(207),
	(208),
	(209),
	(210),
	(211),
	(212),
	(213),
	(214),
	(215),
	(216),
	(217),
	(218),
	(219),
	(220),
	(221),
	(222),
	(223),
	(224),
	(225),
	(226),
	(227),
	(228),
	(229),
	(230),
	(231),
	(232),
	(233),
	(234),
	(235),
	(236),
	(237),
	(238),
	(239),
	(240),
	(241),
	(242),
	(243),
	(244),
	(245),
	(246),
	(247),
	(248),
	(249),
	(250),
	(251),
	(252),
	(253),
	(254),
	(255),
	(256),
	(257),
	(258),
	(259),
	(260),
	(261),
	(262),
	(263),
	(264),
	(265),
	(266),
	(267),
	(268),
	(269),
	(270),
	(271),
	(272),
	(273),
	(274),
	(275),
	(276),
	(277),
	(278),
	(279),
	(280),
	(281),
	(282),
	(283),
	(284),
	(285),
	(286),
	(287),
	(288),
	(289),
	(290),
	(291),
	(292),
	(293),
	(294),
	(295),
	(296),
	(297),
	(298),
	(299),
	(300),
	(301),
	(302),
	(303),
	(304),
	(305),
	(306),
	(307),
	(308),
	(309),
	(310),
	(311),
	(312),
	(313),
	(314),
	(315),
	(316),
	(317),
	(318),
	(319),
	(320),
	(321),
	(322),
	(323),
	(324),
	(325),
	(326),
	(327),
	(328),
	(329),
	(330),
	(331),
	(332),
	(333),
	(334),
	(335),
	(336),
	(337),
	(338),
	(339),
	(340),
	(341),
	(342),
	(343),
	(344),
	(345),
	(346),
	(347),
	(348),
	(349),
	(350),
	(351),
	(352),
	(353),
	(354),
	(355),
	(356),
	(357),
	(358),
	(359),
	(360),
	(361),
	(362),
	(363),
	(364),
	(365),
	(366),
	(367),
	(368),
	(369),
	(370),
	(371),
	(372),
	(373),
	(374),
	(375),
	(376),
	(377),
	(378),
	(379),
	(380),
	(381),
	(382),
	(383),
	(384),
	(385),
	(386),
	(387),
	(388),
	(389),
	(390),
	(391),
	(392),
	(393),
	(394),
	(395),
	(396),
	(397),
	(398),
	(399),
	(400),
	(401),
	(402),
	(403),
	(404),
	(405),
	(406),
	(407),
	(408),
	(409),
	(410),
	(411),
	(412),
	(413),
	(414),
	(415),
	(416),
	(417),
	(418),
	(419),
	(420),
	(421),
	(422),
	(423),
	(424),
	(425),
	(426),
	(427),
	(428),
	(429),
	(430),
	(431),
	(432),
	(433),
	(434),
	(435),
	(436),
	(437),
	(438),
	(439),
	(440),
	(441),
	(442),
	(443),
	(444),
	(445),
	(446),
	(447),
	(448),
	(449),
	(450),
	(451),
	(452),
	(453),
	(454),
	(455),
	(456),
	(457),
	(458),
	(459),
	(460),
	(461),
	(462),
	(463),
	(464),
	(465),
	(466),
	(467),
	(468),
	(469),
	(470),
	(471),
	(472),
	(473),
	(474),
	(475),
	(476),
	(477),
	(478),
	(479),
	(480),
	(481),
	(482),
	(483),
	(484),
	(485),
	(486),
	(487),
	(488),
	(489),
	(490),
	(491),
	(492),
	(493),
	(494),
	(495),
	(496),
	(497),
	(498),
	(499),
	(500),
	(501),
	(502),
	(503),
	(504),
	(505),
	(506),
	(507),
	(508),
	(509),
	(510),
	(511),
	(512),
	(513),
	(514),
	(515),
	(516),
	(517),
	(518),
	(519),
	(520),
	(521),
	(522),
	(523),
	(524),
	(525),
	(526),
	(527),
	(528),
	(529),
	(530),
	(531),
	(532),
	(533),
	(534),
	(535),
	(536),
	(537),
	(538),
	(539),
	(540),
	(541),
	(542),
	(543),
	(544),
	(545),
	(546),
	(547),
	(548),
	(549),
	(550),
	(551),
	(552),
	(553),
	(554),
	(555),
	(556),
	(557),
	(558),
	(559),
	(560),
	(561),
	(562),
	(563),
	(564),
	(565),
	(566),
	(567),
	(568),
	(569),
	(570),
	(571),
	(572),
	(573),
	(574),
	(575),
	(576),
	(577),
	(578),
	(579),
	(580),
	(581),
	(582),
	(583),
	(584),
	(585),
	(586),
	(587),
	(588),
	(589),
	(590),
	(591),
	(592),
	(593),
	(594),
	(595),
	(596),
	(597),
	(598),
	(599),
	(600),
	(601),
	(602),
	(603),
	(604),
	(605),
	(606),
	(607),
	(608),
	(609),
	(610),
	(611),
	(612),
	(613),
	(614),
	(615),
	(616),
	(617),
	(618),
	(619),
	(620),
	(621),
	(622),
	(623),
	(624),
	(625),
	(626),
	(627),
	(628),
	(629),
	(630),
	(631),
	(632),
	(633),
	(634),
	(635),
	(636),
	(637),
	(638),
	(639),
	(640),
	(641),
	(642),
	(643),
	(644),
	(645),
	(646),
	(647),
	(648),
	(649),
	(650),
	(651),
	(652),
	(653),
	(654),
	(655),
	(656),
	(657),
	(658),
	(659),
	(660),
	(661),
	(662),
	(663),
	(664),
	(665),
	(666),
	(667),
	(668),
	(669),
	(670),
	(671),
	(672),
	(673),
	(674),
	(675),
	(676),
	(677),
	(678),
	(679),
	(680),
	(681),
	(682),
	(683),
	(684),
	(685),
	(686),
	(687),
	(688),
	(689),
	(690),
	(691),
	(692),
	(693),
	(694),
	(695),
	(696),
	(697),
	(698),
	(699),
	(700),
	(701),
	(702),
	(703),
	(704),
	(705),
	(706),
	(707),
	(708),
	(709),
	(710),
	(711),
	(712),
	(713),
	(714),
	(715),
	(716),
	(717),
	(718),
	(719),
	(720),
	(721),
	(722),
	(723),
	(724),
	(725),
	(726),
	(727),
	(728),
	(729),
	(730),
	(731),
	(732),
	(733),
	(734),
	(735),
	(736),
	(737),
	(738),
	(739),
	(740),
	(741),
	(742),
	(743),
	(744),
	(745),
	(746),
	(747),
	(748),
	(749),
	(750),
	(751),
	(752),
	(753),
	(754),
	(755),
	(756),
	(757),
	(758),
	(759),
	(760),
	(761),
	(762),
	(763),
	(764),
	(765),
	(766),
	(767),
	(768),
	(769),
	(770),
	(771),
	(772),
	(773),
	(774),
	(775),
	(776),
	(777),
	(778),
	(779),
	(780),
	(781),
	(782),
	(783),
	(784),
	(785),
	(786),
	(787),
	(788),
	(789),
	(790),
	(791),
	(792),
	(793),
	(794),
	(795),
	(796),
	(797),
	(798),
	(799),
	(800),
	(801),
	(802),
	(803),
	(804),
	(805),
	(806),
	(807),
	(808),
	(809),
	(810),
	(811),
	(812),
	(813),
	(814),
	(815),
	(816),
	(817),
	(818),
	(819),
	(820),
	(821),
	(822),
	(823),
	(824),
	(825),
	(826),
	(827),
	(828),
	(829),
	(830),
	(831),
	(832),
	(833),
	(834),
	(835),
	(836),
	(837),
	(838),
	(839),
	(840),
	(841),
	(842),
	(843),
	(844),
	(845),
	(846),
	(847),
	(848),
	(849),
	(850),
	(851),
	(852),
	(853),
	(854),
	(855),
	(856),
	(857),
	(858),
	(859),
	(860),
	(861),
	(862),
	(863),
	(864),
	(865),
	(866),
	(867),
	(868),
	(869),
	(870),
	(871),
	(872),
	(873),
	(874),
	(875),
	(876),
	(877),
	(878),
	(879),
	(880),
	(881),
	(882),
	(883),
	(884),
	(885),
	(886),
	(887),
	(888),
	(889),
	(890),
	(891),
	(892),
	(893),
	(894),
	(895),
	(896),
	(897),
	(898),
	(899),
	(900),
	(901),
	(902),
	(903),
	(904),
	(905),
	(906),
	(907),
	(908),
	(909),
	(910),
	(911),
	(912),
	(913),
	(914),
	(915),
	(916),
	(917),
	(918),
	(919),
	(920),
	(921),
	(922),
	(923),
	(924),
	(925),
	(926),
	(927),
	(928),
	(929),
	(930),
	(931),
	(932),
	(933),
	(934),
	(935),
	(936),
	(937),
	(938),
	(939),
	(940),
	(941),
	(942),
	(943),
	(944),
	(945),
	(946),
	(947),
	(948),
	(949),
	(950),
	(951),
	(952),
	(953),
	(954),
	(955),
	(956),
	(957),
	(958),
	(959),
	(960),
	(961),
	(962),
	(963),
	(964),
	(965),
	(966),
	(967),
	(968),
	(969),
	(970),
	(971),
	(972),
	(973),
	(974),
	(975),
	(976),
	(977),
	(978),
	(979),
	(980),
	(981),
	(982),
	(983),
	(984),
	(985),
	(986),
	(987),
	(988),
	(989),
	(990),
	(991),
	(992),
	(993),
	(994),
	(995),
	(996),
	(997),
	(998),
	(999),
	(1000),
	(1001),
	(1002),
	(1003),
	(1004),
	(1005),
	(1006),
	(1007),
	(1008),
	(1009),
	(1010),
	(1011),
	(1012),
	(1013),
	(1014),
	(1015),
	(1016),
	(1017),
	(1018),
	(1019),
	(1020),
	(1021),
	(1022),
	(1023),
	(1024),
	(1025),
	(1026),
	(1027),
	(1028),
	(1029),
	(1030),
	(1031),
	(1032),
	(1033),
	(1034),
	(1035),
	(1036),
	(1037),
	(1038),
	(1039),
	(1040),
	(1041),
	(1042),
	(1043),
	(1044),
	(1045),
	(1046),
	(1047),
	(1048),
	(1049),
	(1050),
	(1051),
	(1052),
	(1053),
	(1054),
	(1055),
	(1056),
	(1057),
	(1058),
	(1059),
	(1060),
	(1061),
	(1062),
	(1063),
	(1064),
	(1065),
	(1066),
	(1067),
	(1068),
	(1069),
	(1070),
	(1071),
	(1072),
	(1073),
	(1074),
	(1075),
	(1076),
	(1077),
	(1078),
	(1079),
	(1080),
	(1081),
	(1082),
	(1083),
	(1084),
	(1085),
	(1086),
	(1087),
	(1088),
	(1089),
	(1090),
	(1091),
	(1092),
	(1093),
	(1094),
	(1095),
	(1096),
	(1097),
	(1098),
	(1099),
	(1100),
	(1101),
	(1102),
	(1103),
	(1104),
	(1105),
	(1106),
	(1107),
	(1108),
	(1109),
	(1110),
	(1111),
	(1112),
	(1113),
	(1114),
	(1115),
	(1116),
	(1117),
	(1118),
	(1119),
	(1120),
	(1121),
	(1122),
	(1123),
	(1124),
	(1125),
	(1126),
	(1127),
	(1128),
	(1129),
	(1130),
	(1131),
	(1132),
	(1133),
	(1134),
	(1135),
	(1136),
	(1137),
	(1138),
	(1139),
	(1140),
	(1141),
	(1142),
	(1143),
	(1144),
	(1145),
	(1146),
	(1147),
	(1148),
	(1149),
	(1150),
	(1151),
	(1152),
	(1153),
	(1154),
	(1155),
	(1156),
	(1157),
	(1158),
	(1159),
	(1160),
	(1161),
	(1162),
	(1163),
	(1164),
	(1165),
	(1166),
	(1167),
	(1168),
	(1169),
	(1170),
	(1171),
	(1172),
	(1173),
	(1174),
	(1175),
	(1176),
	(1177),
	(1178),
	(1179),
	(1180),
	(1181),
	(1182),
	(1183),
	(1184),
	(1185),
	(1186),
	(1187),
	(1188),
	(1189),
	(1190),
	(1191),
	(1192),
	(1193),
	(1194),
	(1195),
	(1196),
	(1197),
	(1198),
	(1199),
	(1200),
	(1201),
	(1202),
	(1203),
	(1204),
	(1205),
	(1206),
	(1207),
	(1208),
	(1209),
	(1210),
	(1211),
	(1212),
	(1213),
	(1214),
	(1215),
	(1216),
	(1217),
	(1218),
	(1219),
	(1220),
	(1221),
	(1222),
	(1223),
	(1224),
	(1225),
	(1226),
	(1227),
	(1228),
	(1229),
	(1230),
	(1231),
	(1232),
	(1233),
	(1234),
	(1235),
	(1236),
	(1237),
	(1238),
	(1239),
	(1240),
	(1241),
	(1242),
	(1243),
	(1244),
	(1245),
	(1246),
	(1247),
	(1248),
	(1249),
	(1250),
	(1251),
	(1252),
	(1253),
	(1254),
	(1255),
	(1256),
	(1257),
	(1258),
	(1259),
	(1260),
	(1261),
	(1262),
	(1263),
	(1264),
	(1265),
	(1266),
	(1267),
	(1268),
	(1269),
	(1270),
	(1271),
	(1272),
	(1273),
	(1274),
	(1275),
	(1276),
	(1277),
	(1278),
	(1279),
	(1280),
	(1281),
	(1282),
	(1283),
	(1284),
	(1285),
	(1286),
	(1287),
	(1288),
	(1289),
	(1290),
	(1291),
	(1292),
	(1293),
	(1294),
	(1295),
	(1296),
	(1297),
	(1298),
	(1299),
	(1300),
	(1301),
	(1302),
	(1303),
	(1304),
	(1305),
	(1306),
	(1307),
	(1308),
	(1309),
	(1310),
	(1311),
	(1312),
	(1313),
	(1314),
	(1315),
	(1316),
	(1317),
	(1318),
	(1319),
	(1320),
	(1321),
	(1322),
	(1323),
	(1324),
	(1325),
	(1326),
	(1327),
	(1328),
	(1329),
	(1330),
	(1331),
	(1332),
	(1333),
	(1334),
	(1335),
	(1336),
	(1337),
	(1338),
	(1339),
	(1340),
	(1341),
	(1342),
	(1343),
	(1344),
	(1345),
	(1346),
	(1347),
	(1348),
	(1349),
	(1350),
	(1351),
	(1352),
	(1353),
	(1354),
	(1355),
	(1356),
	(1357),
	(1358),
	(1359),
	(1360),
	(1361),
	(1362),
	(1363),
	(1364),
	(1365),
	(1366),
	(1367),
	(1368),
	(1369),
	(1370),
	(1371),
	(1372),
	(1373),
	(1374),
	(1375),
	(1376),
	(1377),
	(1378),
	(1379),
	(1380),
	(1381),
	(1382),
	(1383),
	(1384),
	(1385),
	(1386),
	(1387),
	(1388),
	(1389),
	(1390),
	(1391),
	(1392),
	(1393),
	(1394),
	(1395),
	(1396),
	(1397),
	(1398),
	(1399),
	(1400),
	(1401),
	(1402),
	(1403),
	(1404),
	(1405),
	(1406),
	(1407),
	(1408),
	(1409),
	(1410),
	(1411),
	(1412),
	(1413),
	(1414),
	(1415),
	(1416),
	(1417),
	(1418),
	(1419),
	(1420),
	(1421),
	(1422),
	(1423),
	(1424),
	(1425),
	(1426),
	(1427),
	(1428),
	(1429),
	(1430),
	(1431),
	(1432),
	(1433),
	(1434),
	(1435),
	(1436),
	(1437),
	(1438),
	(1439),
	(1440),
	(1441),
	(1442),
	(1443),
	(1444),
	(1445),
	(1446),
	(1447),
	(1448),
	(1449),
	(1450),
	(1451),
	(1452),
	(1453),
	(1454),
	(1455),
	(1456),
	(1457),
	(1458),
	(1459),
	(1460),
	(1461),
	(1462),
	(1463),
	(1464),
	(1465),
	(1466),
	(1467),
	(1468),
	(1469),
	(1470),
	(1471),
	(1472),
	(1473),
	(1474),
	(1475),
	(1476),
	(1477),
	(1478),
	(1479),
	(1480),
	(1481),
	(1482),
	(1483),
	(1484),
	(1485),
	(1486),
	(1487),
	(1488),
	(1489),
	(1490),
	(1491),
	(1492),
	(1493),
	(1494),
	(1495),
	(1496),
	(1497),
	(1498),
	(1499),
	(1500),
	(1501),
	(1502),
	(1503),
	(1504),
	(1505),
	(1506),
	(1507),
	(1508),
	(1509),
	(1510),
	(1511),
	(1512),
	(1513),
	(1514),
	(1515),
	(1516),
	(1517),
	(1518),
	(1519),
	(1520),
	(1521),
	(1522),
	(1523),
	(1524),
	(1525),
	(1526),
	(1527),
	(1528),
	(1529),
	(1530),
	(1531),
	(1532),
	(1533),
	(1534),
	(1535),
	(1536),
	(1537),
	(1538),
	(1539),
	(1540),
	(1541),
	(1542),
	(1543),
	(1544),
	(1545),
	(1546),
	(1547),
	(1548),
	(1549),
	(1550),
	(1551),
	(1552),
	(1553),
	(1554),
	(1555),
	(1556),
	(1557),
	(1558),
	(1559),
	(1560),
	(1561),
	(1562),
	(1563),
	(1564),
	(1565),
	(1566),
	(1567),
	(1568),
	(1569),
	(1570),
	(1571),
	(1572),
	(1573),
	(1574),
	(1575),
	(1576),
	(1577),
	(1578),
	(1579),
	(1580),
	(1581),
	(1582),
	(1583),
	(1584),
	(1585),
	(1586),
	(1587),
	(1588),
	(1589),
	(1590),
	(1591),
	(1592),
	(1593),
	(1594),
	(1595),
	(1596),
	(1597),
	(1598),
	(1599),
	(1600),
	(1601),
	(1602),
	(1603),
	(1604),
	(1605),
	(1606),
	(1607),
	(1608),
	(1609),
	(1610),
	(1611),
	(1612),
	(1613),
	(1614),
	(1615),
	(1616),
	(1617),
	(1618),
	(1619),
	(1620),
	(1621),
	(1622),
	(1623),
	(1624),
	(1625),
	(1626),
	(1627),
	(1628),
	(1629),
	(1630),
	(1631),
	(1632),
	(1633),
	(1634),
	(1635),
	(1636),
	(1637),
	(1638),
	(1639),
	(1640),
	(1641),
	(1642),
	(1643),
	(1644),
	(1645),
	(1646),
	(1647),
	(1648),
	(1649),
	(1650),
	(1651),
	(1652),
	(1653),
	(1654),
	(1655),
	(1656),
	(1657),
	(1658),
	(1659),
	(1660),
	(1661),
	(1662),
	(1663),
	(1664),
	(1665),
	(1666),
	(1667),
	(1668),
	(1669),
	(1670),
	(1671),
	(1672),
	(1673),
	(1674),
	(1675),
	(1676),
	(1677),
	(1678),
	(1679),
	(1680),
	(1681),
	(1682),
	(1683),
	(1684),
	(1685),
	(1686),
	(1687),
	(1688),
	(1689),
	(1690),
	(1691),
	(1692),
	(1693),
	(1694),
	(1695),
	(1696),
	(1697),
	(1698),
	(1699),
	(1700),
	(1701),
	(1702),
	(1703),
	(1704),
	(1705),
	(1706),
	(1707),
	(1708),
	(1709),
	(1710),
	(1711),
	(1712),
	(1713),
	(1714),
	(1715),
	(1716),
	(1717),
	(1718),
	(1719),
	(1720),
	(1721),
	(1722),
	(1723),
	(1724),
	(1725),
	(1726),
	(1727),
	(1728),
	(1729),
	(1730),
	(1731),
	(1732),
	(1733),
	(1734),
	(1735),
	(1736),
	(1737),
	(1738),
	(1739),
	(1740),
	(1741),
	(1742),
	(1743),
	(1744),
	(1745),
	(1746),
	(1747),
	(1748),
	(1749),
	(1750),
	(1751),
	(1752),
	(1753),
	(1754),
	(1755),
	(1756),
	(1757),
	(1758),
	(1759),
	(1760),
	(1761),
	(1762),
	(1763),
	(1764),
	(1765),
	(1766),
	(1767),
	(1768),
	(1769),
	(1770),
	(1771),
	(1772),
	(1773),
	(1774),
	(1775),
	(1776),
	(1777),
	(1778),
	(1779),
	(1780),
	(1781),
	(1782),
	(1783),
	(1784),
	(1785),
	(1786),
	(1787),
	(1788),
	(1789),
	(1790),
	(1791),
	(1792),
	(1793),
	(1794),
	(1795),
	(1796),
	(1797),
	(1798),
	(1799),
	(1800),
	(1801),
	(1802),
	(1803),
	(1804),
	(1805),
	(1806),
	(1807),
	(1808),
	(1809),
	(1810),
	(1811),
	(1812),
	(1813),
	(1814),
	(1815),
	(1816),
	(1817),
	(1818),
	(1819),
	(1820),
	(1821),
	(1822),
	(1823),
	(1824),
	(1825),
	(1826),
	(1827),
	(1828),
	(1829),
	(1830),
	(1831),
	(1832),
	(1833),
	(1834),
	(1835),
	(1836),
	(1837),
	(1838),
	(1839),
	(1840),
	(1841),
	(1842),
	(1843),
	(1844),
	(1845),
	(1846),
	(1847),
	(1848),
	(1849),
	(1850),
	(1851),
	(1852),
	(1853),
	(1854),
	(1855),
	(1856),
	(1857),
	(1858),
	(1859),
	(1860),
	(1861),
	(1862),
	(1863),
	(1864),
	(1865),
	(1866),
	(1867),
	(1868),
	(1869),
	(1870),
	(1871),
	(1872),
	(1873),
	(1874),
	(1875),
	(1876),
	(1877),
	(1878),
	(1879),
	(1880),
	(1881),
	(1882),
	(1883),
	(1884),
	(1885),
	(1886),
	(1887),
	(1888),
	(1889),
	(1890),
	(1891),
	(1892),
	(1893),
	(1894),
	(1895),
	(1896),
	(1897),
	(1898),
	(1899),
	(1900),
	(1901),
	(1902),
	(1903),
	(1904),
	(1905),
	(1906),
	(1907),
	(1908),
	(1909),
	(1910),
	(1911),
	(1912),
	(1913),
	(1914),
	(1915),
	(1916),
	(1917),
	(1918),
	(1919),
	(1920),
	(1921),
	(1922),
	(1923),
	(1924),
	(1925),
	(1926),
	(1927),
	(1928),
	(1929),
	(1930),
	(1931),
	(1932),
	(1933),
	(1934),
	(1935),
	(1936),
	(1937),
	(1938),
	(1939),
	(1940),
	(1941),
	(1942),
	(1943),
	(1944),
	(1945),
	(1946),
	(1947),
	(1948),
	(1949),
	(1950),
	(1951),
	(1952),
	(1953),
	(1954),
	(1955),
	(1956),
	(1957),
	(1958),
	(1959),
	(1960),
	(1961),
	(1962),
	(1963),
	(1964),
	(1965),
	(1966),
	(1967),
	(1968),
	(1969),
	(1970),
	(1971),
	(1972),
	(1973),
	(1974),
	(1975),
	(1976),
	(1977),
	(1978),
	(1979),
	(1980),
	(1981),
	(1982),
	(1983),
	(1984),
	(1985),
	(1986),
	(1987),
	(1988),
	(1989),
	(1990),
	(1991),
	(1992),
	(1993),
	(1994),
	(1995),
	(1996),
	(1997),
	(1998),
	(1999),
	(2000),
	(2001),
	(2002),
	(2003),
	(2004),
	(2005),
	(2006),
	(2007),
	(2008),
	(2009),
	(2010),
	(2011),
	(2012),
	(2013),
	(2014),
	(2015),
	(2016),
	(2017),
	(2018),
	(2019),
	(2020),
	(2021),
	(2022),
	(2023),
	(2024),
	(2025),
	(2026),
	(2027),
	(2028),
	(2029),
	(2030),
	(2031),
	(2032),
	(2033),
	(2034),
	(2035),
	(2036),
	(2037),
	(2038),
	(2039),
	(2040),
	(2041),
	(2042),
	(2043),
	(2044),
	(2045),
	(2046),
	(2047),
	(2048),
	(2049),
	(2050),
	(2051),
	(2052),
	(2053),
	(2054),
	(2055),
	(2056),
	(2057),
	(2058),
	(2059),
	(2060),
	(2061),
	(2062),
	(2063),
	(2064),
	(2065),
	(2066),
	(2067),
	(2068),
	(2069),
	(2070),
	(2071),
	(2072),
	(2073),
	(2074),
	(2075),
	(2076),
	(2077),
	(2078),
	(2079),
	(2080),
	(2081),
	(2082),
	(2083),
	(2084),
	(2085),
	(2086),
	(2087),
	(2088),
	(2089),
	(2090),
	(2091),
	(2092),
	(2093),
	(2094),
	(2095),
	(2096),
	(2097),
	(2098),
	(2099),
	(2100),
	(2101),
	(2102),
	(2103),
	(2104),
	(2105),
	(2106),
	(2107),
	(2108),
	(2109),
	(2110),
	(2111),
	(2112),
	(2113),
	(2114),
	(2115),
	(2116),
	(2117),
	(2118),
	(2119),
	(2120),
	(2121),
	(2122),
	(2123),
	(2124),
	(2125),
	(2126),
	(2127),
	(2128),
	(2129),
	(2130),
	(2131),
	(2132),
	(2133),
	(2134),
	(2135),
	(2136),
	(2137),
	(2138),
	(2139),
	(2140),
	(2141),
	(2142),
	(2143),
	(2144),
	(2145),
	(2146),
	(2147),
	(2148),
	(2149),
	(2150),
	(2151),
	(2152),
	(2153),
	(2154),
	(2155),
	(2156),
	(2157),
	(2158),
	(2159),
	(2160),
	(2161),
	(2162),
	(2163),
	(2164),
	(2165),
	(2166),
	(2167),
	(2168),
	(2169),
	(2170),
	(2171),
	(2172),
	(2173),
	(2174),
	(2175),
	(2176),
	(2177),
	(2178),
	(2179),
	(2180),
	(2181),
	(2182),
	(2183),
	(2184),
	(2185),
	(2186),
	(2187),
	(2188),
	(2189),
	(2190),
	(2191),
	(2192),
	(2193),
	(2194),
	(2195),
	(2196),
	(2197),
	(2198),
	(2199),
	(2200),
	(2201),
	(2202),
	(2203),
	(2204),
	(2205),
	(2206),
	(2207),
	(2208),
	(2209),
	(2210),
	(2211),
	(2212),
	(2213),
	(2214),
	(2215),
	(2216),
	(2217),
	(2218),
	(2219),
	(2220),
	(2221),
	(2222),
	(2223),
	(2224),
	(2225),
	(2226),
	(2227),
	(2228),
	(2229),
	(2230),
	(2231),
	(2232),
	(2233),
	(2234),
	(2235),
	(2236),
	(2237),
	(2238),
	(2239),
	(2240),
	(2241),
	(2242),
	(2243),
	(2244),
	(2245),
	(2246),
	(2247),
	(2248),
	(2249),
	(2250),
	(2251),
	(2252),
	(2253),
	(2254),
	(2255),
	(2256),
	(2257),
	(2258),
	(2259),
	(2260),
	(2261),
	(2262),
	(2263),
	(2264),
	(2265),
	(2266),
	(2267),
	(2268),
	(2269),
	(2270),
	(2271),
	(2272),
	(2273),
	(2274),
	(2275),
	(2276),
	(2277),
	(2278),
	(2279),
	(2280),
	(2281),
	(2282),
	(2283),
	(2284),
	(2285),
	(2286),
	(2287),
	(2288),
	(2289),
	(2290),
	(2291),
	(2292),
	(2293),
	(2294),
	(2295),
	(2296),
	(2297),
	(2298),
	(2299),
	(2300),
	(2301),
	(2302),
	(2303),
	(2304),
	(2305),
	(2306),
	(2307),
	(2308),
	(2309),
	(2310),
	(2311),
	(2312),
	(2313),
	(2314),
	(2315),
	(2316),
	(2317),
	(2318),
	(2319),
	(2320),
	(2321),
	(2322),
	(2323),
	(2324),
	(2325),
	(2326),
	(2327),
	(2328),
	(2329),
	(2330),
	(2331),
	(2332),
	(2333),
	(2334),
	(2335),
	(2336),
	(2337),
	(2338),
	(2339),
	(2340),
	(2341),
	(2342),
	(2343),
	(2344),
	(2345),
	(2346),
	(2347),
	(2348),
	(2349),
	(2350),
	(2351),
	(2352),
	(2353),
	(2354),
	(2355),
	(2356),
	(2357),
	(2358),
	(2359),
	(2360),
	(2361),
	(2362),
	(2363),
	(2364),
	(2365),
	(2366),
	(2367),
	(2368),
	(2369),
	(2370),
	(2371),
	(2372),
	(2373),
	(2374),
	(2375),
	(2376),
	(2377),
	(2378),
	(2379),
	(2380),
	(2381),
	(2382),
	(2383),
	(2384),
	(2385),
	(2386),
	(2387),
	(2388),
	(2389),
	(2390),
	(2391),
	(2392),
	(2393),
	(2394),
	(2395),
	(2396),
	(2397),
	(2398),
	(2399),
	(2400),
	(2401),
	(2402),
	(2403),
	(2404),
	(2405),
	(2406),
	(2407),
	(2408),
	(2409),
	(2410),
	(2411),
	(2412),
	(2413),
	(2414),
	(2415),
	(2416),
	(2417),
	(2418),
	(2419),
	(2420),
	(2421),
	(2422),
	(2423),
	(2424),
	(2425),
	(2426),
	(2427),
	(2428),
	(2429),
	(2430),
	(2431),
	(2432),
	(2433),
	(2434),
	(2435),
	(2436),
	(2437),
	(2438),
	(2439),
	(2440),
	(2441),
	(2442),
	(2443),
	(2444),
	(2445),
	(2446),
	(2447),
	(2448),
	(2449),
	(2450),
	(2451),
	(2452),
	(2453),
	(2454),
	(2455),
	(2456),
	(2457),
	(2458),
	(2459),
	(2460),
	(2461),
	(2462),
	(2463),
	(2464),
	(2465),
	(2466),
	(2467),
	(2468),
	(2469),
	(2470),
	(2471),
	(2472),
	(2473),
	(2474),
	(2475),
	(2476),
	(2477),
	(2478),
	(2479),
	(2480),
	(2481),
	(2482),
	(2483),
	(2484),
	(2485),
	(2486),
	(2487),
	(2488),
	(2489),
	(2490),
	(2491),
	(2492),
	(2493),
	(2494),
	(2495),
	(2496),
	(2497),
	(2498),
	(2499),
	(2500),
	(2501),
	(2502),
	(2503),
	(2504),
	(2505),
	(2506),
	(2507),
	(2508),
	(2509),
	(2510),
	(2511),
	(2512),
	(2513),
	(2514),
	(2515),
	(2516),
	(2517),
	(2518),
	(2519),
	(2520),
	(2521),
	(2522),
	(2523),
	(2524),
	(2525),
	(2526),
	(2527),
	(2528),
	(2529),
	(2530),
	(2531),
	(2532),
	(2533),
	(2534),
	(2535),
	(2536),
	(2537),
	(2538),
	(2539),
	(2540),
	(2541),
	(2542),
	(2543),
	(2544),
	(2545),
	(2546),
	(2547),
	(2548),
	(2549),
	(2550),
	(2551),
	(2552),
	(2553),
	(2554),
	(2555),
	(2556),
	(2557),
	(2558),
	(2559),
	(2560),
	(2561),
	(2562),
	(2563),
	(2564),
	(2565),
	(2566),
	(2567),
	(2568),
	(2569),
	(2570),
	(2571),
	(2572),
	(2573),
	(2574),
	(2575),
	(2576),
	(2577),
	(2578),
	(2579),
	(2580),
	(2581),
	(2582),
	(2583),
	(2584),
	(2585),
	(2586),
	(2587),
	(2588),
	(2589),
	(2590),
	(2591),
	(2592),
	(2593),
	(2594),
	(2595),
	(2596),
	(2597),
	(2598),
	(2599),
	(2600),
	(2601),
	(2602),
	(2603),
	(2604),
	(2605),
	(2606),
	(2607),
	(2608),
	(2609),
	(2610),
	(2611),
	(2612),
	(2613),
	(2614),
	(2615),
	(2616),
	(2617),
	(2618),
	(2619),
	(2620),
	(2621),
	(2622),
	(2623),
	(2624),
	(2625),
	(2626),
	(2627),
	(2628),
	(2629),
	(2630),
	(2631),
	(2632),
	(2633),
	(2634),
	(2635),
	(2636),
	(2637),
	(2638),
	(2639),
	(2640),
	(2641),
	(2642),
	(2643),
	(2644),
	(2645),
	(2646),
	(2647),
	(2648),
	(2649),
	(2650),
	(2651),
	(2652),
	(2653),
	(2654),
	(2655),
	(2656),
	(2657),
	(2658),
	(2659),
	(2660),
	(2661),
	(2662),
	(2663),
	(2664),
	(2665),
	(2666),
	(2667),
	(2668),
	(2669),
	(2670),
	(2671),
	(2672),
	(2673),
	(2674),
	(2675),
	(2676),
	(2677),
	(2678),
	(2679),
	(2680),
	(2681),
	(2682),
	(2683),
	(2684),
	(2685),
	(2686),
	(2687),
	(2688),
	(2689),
	(2690),
	(2691),
	(2692),
	(2693),
	(2694),
	(2695),
	(2696),
	(2697),
	(2698),
	(2699),
	(2700),
	(2701),
	(2702),
	(2703),
	(2704),
	(2705),
	(2706),
	(2707),
	(2708),
	(2709),
	(2710),
	(2711),
	(2712),
	(2713),
	(2714),
	(2715),
	(2716),
	(2717),
	(2718),
	(2719),
	(2720),
	(2721),
	(2722),
	(2723),
	(2724),
	(2725),
	(2726),
	(2727),
	(2728),
	(2729),
	(2730),
	(2731),
	(2732),
	(2733),
	(2734),
	(2735),
	(2736),
	(2737),
	(2738),
	(2739),
	(2740),
	(2741),
	(2742),
	(2743),
	(2744),
	(2745),
	(2746),
	(2747),
	(2748),
	(2749),
	(2750),
	(2751),
	(2752),
	(2753),
	(2754),
	(2755),
	(2756),
	(2757),
	(2758),
	(2759),
	(2760),
	(2761),
	(2762),
	(2763),
	(2764),
	(2765),
	(2766),
	(2767),
	(2768),
	(2769),
	(2770),
	(2771),
	(2772),
	(2773),
	(2774),
	(2775),
	(2776),
	(2777),
	(2778),
	(2779),
	(2780),
	(2781),
	(2782),
	(2783),
	(2784),
	(2785),
	(2786),
	(2787),
	(2788),
	(2789),
	(2790),
	(2791),
	(2792),
	(2793),
	(2794),
	(2795),
	(2796),
	(2797),
	(2798),
	(2799),
	(2800),
	(2801),
	(2802),
	(2803),
	(2804),
	(2805),
	(2806),
	(2807),
	(2808),
	(2809),
	(2810),
	(2811),
	(2812),
	(2813),
	(2814),
	(2815),
	(2816),
	(2817),
	(2818),
	(2819),
	(2820),
	(2821),
	(2822),
	(2823),
	(2824),
	(2825),
	(2826),
	(2827),
	(2828),
	(2829),
	(2830),
	(2831),
	(2832),
	(2833),
	(2834),
	(2835),
	(2836),
	(2837),
	(2838),
	(2839),
	(2840),
	(2841),
	(2842),
	(2843),
	(2844),
	(2845),
	(2846),
	(2847),
	(2848),
	(2849),
	(2850),
	(2851),
	(2852),
	(2853),
	(2854),
	(2855),
	(2856),
	(2857),
	(2858),
	(2859),
	(2860),
	(2861),
	(2862),
	(2863),
	(2864),
	(2865),
	(2866),
	(2867),
	(2868),
	(2869),
	(2870),
	(2871),
	(2872),
	(2873),
	(2874),
	(2875),
	(2876),
	(2877),
	(2878),
	(2879),
	(2880),
	(2881),
	(2882),
	(2883),
	(2884),
	(2885),
	(2886),
	(2887),
	(2888),
	(2889),
	(2890),
	(2891),
	(2892),
	(2893),
	(2894),
	(2895),
	(2896),
	(2897),
	(2898),
	(2899),
	(2900),
	(2901),
	(2902),
	(2903),
	(2904),
	(2905),
	(2906),
	(2907),
	(2908),
	(2909),
	(2910),
	(2911),
	(2912),
	(2913),
	(2914),
	(2915),
	(2916),
	(2917),
	(2918),
	(2919),
	(2920),
	(2921),
	(2922),
	(2923),
	(2924),
	(2925),
	(2926),
	(2927),
	(2928),
	(2929),
	(2930),
	(2931),
	(2932),
	(2933),
	(2934),
	(2935),
	(2936),
	(2937),
	(2938),
	(2939),
	(2940),
	(2941),
	(2942),
	(2943),
	(2944),
	(2945),
	(2946),
	(2947),
	(2948),
	(2949),
	(2950),
	(2951),
	(2952),
	(2953),
	(2954),
	(2955),
	(2956),
	(2957),
	(2958),
	(2959),
	(2960),
	(2961),
	(2962),
	(2963),
	(2964),
	(2965),
	(2966),
	(2967),
	(2968),
	(2969),
	(2970),
	(2971),
	(2972),
	(2973),
	(2974),
	(2975),
	(2976),
	(2977),
	(2978),
	(2979),
	(2980),
	(2981),
	(2982),
	(2983),
	(2984),
	(2985),
	(2986),
	(2987),
	(2988),
	(2989),
	(2990),
	(2991),
	(2992),
	(2993),
	(2994),
	(2995),
	(2996),
	(2997),
	(2998),
	(2999),
	(3000),
	(3001),
	(3002),
	(3003),
	(3004),
	(3005),
	(3006),
	(3007),
	(3008),
	(3009),
	(3010),
	(3011),
	(3012),
	(3013),
	(3014),
	(3015),
	(3016),
	(3017),
	(3018),
	(3019),
	(3020),
	(3021),
	(3022),
	(3023),
	(3024),
	(3025),
	(3026),
	(3027),
	(3028),
	(3029),
	(3030),
	(3031),
	(3032),
	(3033),
	(3034),
	(3035),
	(3036),
	(3037),
	(3038),
	(3039),
	(3040),
	(3041),
	(3042),
	(3043),
	(3044),
	(3045),
	(3046),
	(3047),
	(3048),
	(3049),
	(3050),
	(3051),
	(3052),
	(3053),
	(3054),
	(3055),
	(3056),
	(3057),
	(3058),
	(3059),
	(3060),
	(3061),
	(3062),
	(3063),
	(3064),
	(3065),
	(3066),
	(3067),
	(3068),
	(3069),
	(3070),
	(3071),
	(3072),
	(3073),
	(3074),
	(3075),
	(3076),
	(3077),
	(3078),
	(3079),
	(3080),
	(3081),
	(3082),
	(3083),
	(3084),
	(3085),
	(3086),
	(3087),
	(3088),
	(3089),
	(3090),
	(3091),
	(3092),
	(3093),
	(3094),
	(3095),
	(3096),
	(3097),
	(3098),
	(3099),
	(3100),
	(3101),
	(3102),
	(3103),
	(3104),
	(3105),
	(3106),
	(3107),
	(3108),
	(3109),
	(3110),
	(3111),
	(3112),
	(3113),
	(3114),
	(3115),
	(3116),
	(3117),
	(3118),
	(3119),
	(3120),
	(3121),
	(3122),
	(3123),
	(3124),
	(3125),
	(3126),
	(3127),
	(3128),
	(3129),
	(3130),
	(3131),
	(3132),
	(3133),
	(3134),
	(3135),
	(3136),
	(3137),
	(3138),
	(3139),
	(3140),
	(3141),
	(3142),
	(3143),
	(3144),
	(3145),
	(3146),
	(3147),
	(3148),
	(3149),
	(3150),
	(3151),
	(3152),
	(3153),
	(3154),
	(3155),
	(3156),
	(3157),
	(3158),
	(3159),
	(3160),
	(3161),
	(3162),
	(3163),
	(3164),
	(3165),
	(3166),
	(3167),
	(3168),
	(3169),
	(3170),
	(3171),
	(3172),
	(3173),
	(3174),
	(3175),
	(3176),
	(3177),
	(3178),
	(3179),
	(3180),
	(3181),
	(3182),
	(3183),
	(3184),
	(3185),
	(3186),
	(3187),
	(3188),
	(3189),
	(3190),
	(3191),
	(3192),
	(3193),
	(3194),
	(3195),
	(3196),
	(3197),
	(3198),
	(3199),
	(3200),
	(3201),
	(3202),
	(3203),
	(3204),
	(3205),
	(3206),
	(3207),
	(3208),
	(3209),
	(3210),
	(3211),
	(3212),
	(3213),
	(3214),
	(3215),
	(3216),
	(3217),
	(3218),
	(3219),
	(3220),
	(3221),
	(3222),
	(3223),
	(3224),
	(3225),
	(3226),
	(3227),
	(3228),
	(3229),
	(3230),
	(3231),
	(3232),
	(3233),
	(3234),
	(3235),
	(3236),
	(3237),
	(3238),
	(3239),
	(3240),
	(3241),
	(3242),
	(3243),
	(3244),
	(3245),
	(3246),
	(3247),
	(3248),
	(3249),
	(3250),
	(3251),
	(3252),
	(3253),
	(3254),
	(3255),
	(3256),
	(3257),
	(3258),
	(3259),
	(3260),
	(3261),
	(3262),
	(3263),
	(3264),
	(3265),
	(3266),
	(3267),
	(3268),
	(3269),
	(3270),
	(3271),
	(3272),
	(3273),
	(3274),
	(3275),
	(3276),
	(3277),
	(3278),
	(3279),
	(3280),
	(3281),
	(3282),
	(3283),
	(3284),
	(3285),
	(3286),
	(3287),
	(3288),
	(3289),
	(3290),
	(3291),
	(3292),
	(3293),
	(3294),
	(3295),
	(3296),
	(3297),
	(3298),
	(3299),
	(3300),
	(3301),
	(3302),
	(3303),
	(3304),
	(3305),
	(3306),
	(3307),
	(3308),
	(3309),
	(3310),
	(3311),
	(3312),
	(3313),
	(3314),
	(3315),
	(3316),
	(3317),
	(3318),
	(3319),
	(3320),
	(3321),
	(3322),
	(3323),
	(3324),
	(3325),
	(3326),
	(3327),
	(3328),
	(3329),
	(3330),
	(3331),
	(3332),
	(3333),
	(3334),
	(3335),
	(3336),
	(3337),
	(3338),
	(3339),
	(3340),
	(3341),
	(3342),
	(3343),
	(3344),
	(3345),
	(3346),
	(3347),
	(3348),
	(3349),
	(3350),
	(3351),
	(3352),
	(3353),
	(3354),
	(3355),
	(3356),
	(3357),
	(3358),
	(3359),
	(3360),
	(3361),
	(3362),
	(3363),
	(3364),
	(3365),
	(3366),
	(3367),
	(3368),
	(3369),
	(3370),
	(3371),
	(3372),
	(3373),
	(3374),
	(3375),
	(3376),
	(3377),
	(3378),
	(3379),
	(3380),
	(3381),
	(3382),
	(3383),
	(3384),
	(3385),
	(3386),
	(3387),
	(3388),
	(3389),
	(3390),
	(3391),
	(3392),
	(3393),
	(3394),
	(3395),
	(3396),
	(3397),
	(3398),
	(3399),
	(3400),
	(3401),
	(3402),
	(3403),
	(3404),
	(3405),
	(3406),
	(3407),
	(3408),
	(3409),
	(3410),
	(3411),
	(3412),
	(3413),
	(3414),
	(3415),
	(3416),
	(3417),
	(3418),
	(3419),
	(3420),
	(3421),
	(3422),
	(3423),
	(3424),
	(3425),
	(3426),
	(3427),
	(3428),
	(3429),
	(3430),
	(3431),
	(3432),
	(3433),
	(3434),
	(3435),
	(3436),
	(3437),
	(3438),
	(3439),
	(3440),
	(3441),
	(3442),
	(3443),
	(3444),
	(3445),
	(3446),
	(3447),
	(3448),
	(3449),
	(3450),
	(3451),
	(3452),
	(3453),
	(3454),
	(3455),
	(3456),
	(3457),
	(3458),
	(3459),
	(3460),
	(3461),
	(3462),
	(3463),
	(3464),
	(3465),
	(3466),
	(3467),
	(3468),
	(3469),
	(3470),
	(3471),
	(3472),
	(3473),
	(3474),
	(3475),
	(3476),
	(3477),
	(3478),
	(3479),
	(3480),
	(3481),
	(3482),
	(3483),
	(3484),
	(3485),
	(3486),
	(3487),
	(3488),
	(3489),
	(3490),
	(3491),
	(3492),
	(3493),
	(3494),
	(3495),
	(3496),
	(3497),
	(3498),
	(3499),
	(3500),
	(3501),
	(3502),
	(3503),
	(3504),
	(3505),
	(3506),
	(3507),
	(3508),
	(3509),
	(3510),
	(3511),
	(3512),
	(3513),
	(3514),
	(3515),
	(3516),
	(3517),
	(3518),
	(3519),
	(3520),
	(3521),
	(3522),
	(3523),
	(3524),
	(3525),
	(3526),
	(3527),
	(3528),
	(3529),
	(3530),
	(3531),
	(3532),
	(3533),
	(3534),
	(3535),
	(3536),
	(3537),
	(3538),
	(3539),
	(3540),
	(3541),
	(3542),
	(3543),
	(3544),
	(3545),
	(3546),
	(3547),
	(3548),
	(3549),
	(3550),
	(3551),
	(3552),
	(3553),
	(3554),
	(3555),
	(3556),
	(3557),
	(3558),
	(3559),
	(3560),
	(3561),
	(3562),
	(3563),
	(3564),
	(3565),
	(3566),
	(3567),
	(3568),
	(3569),
	(3570),
	(3571),
	(3572),
	(3573),
	(3574),
	(3575),
	(3576),
	(3577),
	(3578),
	(3579),
	(3580),
	(3581),
	(3582),
	(3583),
	(3584),
	(3585),
	(3586),
	(3587),
	(3588),
	(3589),
	(3590),
	(3591),
	(3592),
	(3593),
	(3594),
	(3595),
	(3596),
	(3597),
	(3598),
	(3599),
	(3600),
	(3601),
	(3602),
	(3603),
	(3604),
	(3605),
	(3606),
	(3607),
	(3608),
	(3609),
	(3610),
	(3611),
	(3612),
	(3613),
	(3614),
	(3615),
	(3616),
	(3617),
	(3618),
	(3619),
	(3620),
	(3621),
	(3622),
	(3623),
	(3624),
	(3625),
	(3626),
	(3627),
	(3628),
	(3629),
	(3630),
	(3631),
	(3632),
	(3633),
	(3634),
	(3635),
	(3636),
	(3637),
	(3638),
	(3639),
	(3640),
	(3641),
	(3642),
	(3643),
	(3644),
	(3645),
	(3646),
	(3647),
	(3648),
	(3649),
	(3650),
	(3651),
	(3652),
	(3653),
	(3654),
	(3655),
	(3656),
	(3657),
	(3658),
	(3659),
	(3660),
	(3661),
	(3662),
	(3663),
	(3664),
	(3665),
	(3666),
	(3667),
	(3668),
	(3669),
	(3670),
	(3671),
	(3672),
	(3673),
	(3674),
	(3675),
	(3676),
	(3677),
	(3678),
	(3679),
	(3680),
	(3681),
	(3682),
	(3683),
	(3684),
	(3685),
	(3686),
	(3687),
	(3688),
	(3689),
	(3690),
	(3691),
	(3692),
	(3693),
	(3694),
	(3695),
	(3696),
	(3697),
	(3698),
	(3699),
	(3700),
	(3701),
	(3702),
	(3703),
	(3704),
	(3705),
	(3706),
	(3707),
	(3708),
	(3709),
	(3710),
	(3711),
	(3712),
	(3713),
	(3714),
	(3715),
	(3716),
	(3717),
	(3718),
	(3719),
	(3720),
	(3721),
	(3722),
	(3723),
	(3724),
	(3725),
	(3726),
	(3727),
	(3728),
	(3729),
	(3730),
	(3731),
	(3732),
	(3733),
	(3734),
	(3735),
	(3736),
	(3737),
	(3738),
	(3739),
	(3740),
	(3741),
	(3742),
	(3743),
	(3744),
	(3745),
	(3746),
	(3747),
	(3748),
	(3749),
	(3750),
	(3751),
	(3752),
	(3753),
	(3754),
	(3755),
	(3756),
	(3757),
	(3758),
	(3759),
	(3760),
	(3761),
	(3762),
	(3763),
	(3764),
	(3765),
	(3766),
	(3767),
	(3768),
	(3769),
	(3770),
	(3771),
	(3772),
	(3773),
	(3774),
	(3775),
	(3776),
	(3777),
	(3778),
	(3779),
	(3780),
	(3781),
	(3782),
	(3783),
	(3784),
	(3785),
	(3786),
	(3787),
	(3788),
	(3789),
	(3790),
	(3791),
	(3792),
	(3793),
	(3794),
	(3795),
	(3796),
	(3797),
	(3798),
	(3799),
	(3800),
	(3801),
	(3802),
	(3803),
	(3804),
	(3805),
	(3806),
	(3807),
	(3808),
	(3809),
	(3810),
	(3811),
	(3812),
	(3813),
	(3814),
	(3815),
	(3816),
	(3817),
	(3818),
	(3819),
	(3820),
	(3821),
	(3822),
	(3823),
	(3824),
	(3825),
	(3826),
	(3827),
	(3828),
	(3829),
	(3830),
	(3831),
	(3832),
	(3833),
	(3834),
	(3835),
	(3836),
	(3837),
	(3838),
	(3839),
	(3840),
	(3841),
	(3842),
	(3843),
	(3844),
	(3845),
	(3846),
	(3847),
	(3848),
	(3849),
	(3850),
	(3851),
	(3852),
	(3853),
	(3854),
	(3855),
	(3856),
	(3857),
	(3858),
	(3859),
	(3860),
	(3861),
	(3862),
	(3863),
	(3864),
	(3865),
	(3866),
	(3867),
	(3868),
	(3869),
	(3870),
	(3871),
	(3872),
	(3873),
	(3874),
	(3875),
	(3876),
	(3877),
	(3878),
	(3879),
	(3880),
	(3881),
	(3882),
	(3883),
	(3884),
	(3885),
	(3886),
	(3887),
	(3888),
	(3889),
	(3890),
	(3891),
	(3892),
	(3893),
	(3894),
	(3895),
	(3896),
	(3897),
	(3898),
	(3899),
	(3900),
	(3901),
	(3902),
	(3903),
	(3904),
	(3905),
	(3906),
	(3907),
	(3908),
	(3909),
	(3910),
	(3911),
	(3912),
	(3913),
	(3914),
	(3915),
	(3916),
	(3917),
	(3918),
	(3919),
	(3920),
	(3921),
	(3922),
	(3923),
	(3924),
	(3925),
	(3926),
	(3927),
	(3928),
	(3929),
	(3930),
	(3931),
	(3932),
	(3933),
	(3934),
	(3935),
	(3936),
	(3937),
	(3938),
	(3939),
	(3940),
	(3941),
	(3942),
	(3943),
	(3944),
	(3945),
	(3946),
	(3947),
	(3948),
	(3949),
	(3950),
	(3951),
	(3952),
	(3953),
	(3954),
	(3955),
	(3956),
	(3957),
	(3958),
	(3959),
	(3960),
	(3961),
	(3962),
	(3963),
	(3964),
	(3965),
	(3966),
	(3967),
	(3968),
	(3969),
	(3970),
	(3971),
	(3972),
	(3973),
	(3974),
	(3975),
	(3976),
	(3977),
	(3978),
	(3979),
	(3980),
	(3981),
	(3982),
	(3983),
	(3984),
	(3985),
	(3986),
	(3987),
	(3988),
	(3989),
	(3990),
	(3991),
	(3992),
	(3993),
	(3994),
	(3995),
	(3996),
	(3997),
	(3998),
	(3999),
	(4000),
	(4001),
	(4002),
	(4003),
	(4004),
	(4005),
	(4006),
	(4007),
	(4008),
	(4009),
	(4010),
	(4011),
	(4012),
	(4013),
	(4014),
	(4015),
	(4016),
	(4017),
	(4018),
	(4019),
	(4020),
	(4021),
	(4022),
	(4023),
	(4024),
	(4025),
	(4026),
	(4027),
	(4028),
	(4029),
	(4030),
	(4031),
	(4032),
	(4033),
	(4034),
	(4035),
	(4036),
	(4037),
	(4038),
	(4039),
	(4040),
	(4041),
	(4042),
	(4043),
	(4044),
	(4045),
	(4046),
	(4047),
	(4048),
	(4049),
	(4050),
	(4051),
	(4052),
	(4053),
	(4054),
	(4055),
	(4056),
	(4057),
	(4058),
	(4059),
	(4060),
	(4061),
	(4062),
	(4063),
	(4064),
	(4065),
	(4066),
	(4067),
	(4068),
	(4069),
	(4070),
	(4071),
	(4072),
	(4073),
	(4074),
	(4075),
	(4076),
	(4077),
	(4078),
	(4079),
	(4080),
	(4081),
	(4082),
	(4083),
	(4084),
	(4085),
	(4086),
	(4087),
	(4088),
	(4089),
	(4090),
	(4091),
	(4092),
	(4093),
	(4094),
	(4095),
	(4096),
	(4097),
	(4098),
	(4099),
	(4100),
	(4101),
	(4102),
	(4103),
	(4104),
	(4105),
	(4106),
	(4107),
	(4108),
	(4109),
	(4110),
	(4111),
	(4112),
	(4113),
	(4114),
	(4115),
	(4116),
	(4117),
	(4118),
	(4119),
	(4120),
	(4121),
	(4122),
	(4123),
	(4124),
	(4125),
	(4126),
	(4127),
	(4128),
	(4129),
	(4130),
	(4131),
	(4132),
	(4133),
	(4134),
	(4135),
	(4136),
	(4137),
	(4138),
	(4139),
	(4140),
	(4141),
	(4142),
	(4143),
	(4144),
	(4145),
	(4146),
	(4147),
	(4148),
	(4149),
	(4150),
	(4151),
	(4152),
	(4153),
	(4154),
	(4155),
	(4156),
	(4157),
	(4158),
	(4159),
	(4160),
	(4161),
	(4162),
	(4163),
	(4164),
	(4165),
	(4166),
	(4167),
	(4168),
	(4169),
	(4170),
	(4171),
	(4172),
	(4173),
	(4174),
	(4175),
	(4176),
	(4177),
	(4178),
	(4179),
	(4180),
	(4181),
	(4182),
	(4183),
	(4184),
	(4185),
	(4186),
	(4187),
	(4188),
	(4189),
	(4190),
	(4191),
	(4192),
	(4193),
	(4194),
	(4195),
	(4196),
	(4197),
	(4198),
	(4199),
	(4200),
	(4201),
	(4202),
	(4203),
	(4204),
	(4205),
	(4206),
	(4207),
	(4208),
	(4209),
	(4210),
	(4211),
	(4212),
	(4213),
	(4214),
	(4215),
	(4216),
	(4217),
	(4218),
	(4219),
	(4220),
	(4221),
	(4222),
	(4223),
	(4224),
	(4225),
	(4226),
	(4227),
	(4228),
	(4229),
	(4230),
	(4231),
	(4232),
	(4233),
	(4234),
	(4235),
	(4236),
	(4237),
	(4238),
	(4239),
	(4240),
	(4241),
	(4242),
	(4243),
	(4244),
	(4245),
	(4246),
	(4247),
	(4248),
	(4249),
	(4250),
	(4251),
	(4252),
	(4253),
	(4254),
	(4255),
	(4256),
	(4257),
	(4258),
	(4259),
	(4260),
	(4261),
	(4262),
	(4263),
	(4264),
	(4265),
	(4266),
	(4267),
	(4268),
	(4269),
	(4270),
	(4271),
	(4272),
	(4273),
	(4274),
	(4275),
	(4276),
	(4277),
	(4278),
	(4279),
	(4280),
	(4281),
	(4282),
	(4283),
	(4284),
	(4285),
	(4286),
	(4287),
	(4288),
	(4289),
	(4290),
	(4291),
	(4292),
	(4293),
	(4294),
	(4295),
	(4296),
	(4297),
	(4298),
	(4299),
	(4300),
	(4301),
	(4302),
	(4303),
	(4304),
	(4305),
	(4306),
	(4307),
	(4308),
	(4309),
	(4310),
	(4311),
	(4312),
	(4313),
	(4314),
	(4315),
	(4316),
	(4317),
	(4318),
	(4319),
	(4320),
	(4321),
	(4322),
	(4323),
	(4324),
	(4325),
	(4326),
	(4327),
	(4328),
	(4329),
	(4330),
	(4331),
	(4332),
	(4333),
	(4334),
	(4335),
	(4336),
	(4337),
	(4338),
	(4339),
	(4340),
	(4341),
	(4342),
	(4343),
	(4344),
	(4345),
	(4346),
	(4347),
	(4348),
	(4349),
	(4350),
	(4351),
	(4352),
	(4353),
	(4354),
	(4355),
	(4356),
	(4357),
	(4358),
	(4359),
	(4360),
	(4361),
	(4362),
	(4363),
	(4364),
	(4365),
	(4366),
	(4367),
	(4368),
	(4369),
	(4370),
	(4371),
	(4372),
	(4373),
	(4374),
	(4375),
	(4376),
	(4377),
	(4378),
	(4379),
	(4380),
	(4381),
	(4382),
	(4383),
	(4384),
	(4385),
	(4386),
	(4387),
	(4388),
	(4389),
	(4390),
	(4391),
	(4392),
	(4393),
	(4394),
	(4395),
	(4396),
	(4397),
	(4398),
	(4399),
	(4400),
	(4401),
	(4402),
	(4403),
	(4404),
	(4405),
	(4406),
	(4407),
	(4408),
	(4409),
	(4410),
	(4411),
	(4412),
	(4413),
	(4414),
	(4415),
	(4416),
	(4417),
	(4418),
	(4419),
	(4420),
	(4421),
	(4422),
	(4423),
	(4424),
	(4425),
	(4426),
	(4427),
	(4428),
	(4429),
	(4430),
	(4431),
	(4432),
	(4433),
	(4434),
	(4435),
	(4436),
	(4437),
	(4438),
	(4439),
	(4440),
	(4441),
	(4442),
	(4443),
	(4444),
	(4445),
	(4446),
	(4447),
	(4448),
	(4449),
	(4450),
	(4451),
	(4452),
	(4453),
	(4454),
	(4455),
	(4456),
	(4457),
	(4458),
	(4459),
	(4460),
	(4461),
	(4462),
	(4463),
	(4464),
	(4465),
	(4466),
	(4467),
	(4468),
	(4469),
	(4470),
	(4471),
	(4472),
	(4473),
	(4474),
	(4475),
	(4476),
	(4477),
	(4478),
	(4479),
	(4480),
	(4481),
	(4482),
	(4483),
	(4484),
	(4485),
	(4486),
	(4487),
	(4488),
	(4489),
	(4490),
	(4491),
	(4492),
	(4493),
	(4494),
	(4495),
	(4496),
	(4497),
	(4498),
	(4499),
	(4500),
	(4501),
	(4502),
	(4503),
	(4504),
	(4505),
	(4506),
	(4507),
	(4508),
	(4509),
	(4510),
	(4511),
	(4512),
	(4513),
	(4514),
	(4515),
	(4516),
	(4517),
	(4518),
	(4519),
	(4520),
	(4521),
	(4522),
	(4523),
	(4524),
	(4525),
	(4526),
	(4527),
	(4528),
	(4529),
	(4530),
	(4531),
	(4532),
	(4533),
	(4534),
	(4535),
	(4536),
	(4537),
	(4538),
	(4539),
	(4540),
	(4541),
	(4542),
	(4543),
	(4544),
	(4545),
	(4546),
	(4547),
	(4548),
	(4549),
	(4550),
	(4551),
	(4552),
	(4553),
	(4554),
	(4555),
	(4556),
	(4557),
	(4558),
	(4559),
	(4560),
	(4561),
	(4562),
	(4563),
	(4564),
	(4565),
	(4566),
	(4567),
	(4568),
	(4569),
	(4570),
	(4571),
	(4572),
	(4573),
	(4574),
	(4575),
	(4576),
	(4577),
	(4578),
	(4579),
	(4580),
	(4581),
	(4582),
	(4583),
	(4584),
	(4585),
	(4586),
	(4587),
	(4588),
	(4589),
	(4590),
	(4591),
	(4592),
	(4593),
	(4594),
	(4595),
	(4596),
	(4597),
	(4598),
	(4599),
	(4600),
	(4601),
	(4602),
	(4603),
	(4604),
	(4605),
	(4606),
	(4607),
	(4608),
	(4609),
	(4610),
	(4611),
	(4612),
	(4613),
	(4614),
	(4615),
	(4616),
	(4617),
	(4618),
	(4619),
	(4620),
	(4621),
	(4622),
	(4623),
	(4624),
	(4625),
	(4626),
	(4627),
	(4628),
	(4629),
	(4630),
	(4631),
	(4632),
	(4633),
	(4634),
	(4635),
	(4636),
	(4637),
	(4638),
	(4639),
	(4640),
	(4641),
	(4642),
	(4643),
	(4644),
	(4645),
	(4646),
	(4647),
	(4648),
	(4649),
	(4650),
	(4651),
	(4652),
	(4653),
	(4654),
	(4655),
	(4656),
	(4657),
	(4658),
	(4659),
	(4660),
	(4661),
	(4662),
	(4663),
	(4664),
	(4665),
	(4666),
	(4667),
	(4668),
	(4669),
	(4670),
	(4671),
	(4672),
	(4673),
	(4674),
	(4675),
	(4676),
	(4677),
	(4678),
	(4679),
	(4680),
	(4681),
	(4682),
	(4683),
	(4684),
	(4685),
	(4686),
	(4687),
	(4688),
	(4689),
	(4690),
	(4691),
	(4692),
	(4693),
	(4694),
	(4695),
	(4696),
	(4697),
	(4698),
	(4699),
	(4700),
	(4701),
	(4702),
	(4703),
	(4704),
	(4705),
	(4706),
	(4707),
	(4708),
	(4709),
	(4710),
	(4711),
	(4712),
	(4713),
	(4714),
	(4715),
	(4716),
	(4717),
	(4718),
	(4719),
	(4720),
	(4721),
	(4722),
	(4723),
	(4724),
	(4725),
	(4726),
	(4727),
	(4728),
	(4729),
	(4730),
	(4731),
	(4732),
	(4733),
	(4734),
	(4735),
	(4736),
	(4737),
	(4738),
	(4739),
	(4740),
	(4741),
	(4742),
	(4743),
	(4744),
	(4745),
	(4746),
	(4747),
	(4748),
	(4749),
	(4750),
	(4751),
	(4752),
	(4753),
	(4754),
	(4755),
	(4756),
	(4757),
	(4758),
	(4759),
	(4760),
	(4761),
	(4762),
	(4763),
	(4764),
	(4765),
	(4766),
	(4767),
	(4768),
	(4769),
	(4770),
	(4771),
	(4772),
	(4773),
	(4774),
	(4775),
	(4776),
	(4777),
	(4778),
	(4779),
	(4780),
	(4781),
	(4782),
	(4783),
	(4784),
	(4785),
	(4786),
	(4787),
	(4788),
	(4789),
	(4790),
	(4791),
	(4792),
	(4793),
	(4794),
	(4795),
	(4796),
	(4797),
	(4798),
	(4799),
	(4800),
	(4801),
	(4802),
	(4803),
	(4804),
	(4805),
	(4806),
	(4807),
	(4808),
	(4809),
	(4810),
	(4811),
	(4812),
	(4813),
	(4814),
	(4815),
	(4816),
	(4817),
	(4818),
	(4819),
	(4820),
	(4821),
	(4822),
	(4823),
	(4824),
	(4825),
	(4826),
	(4827),
	(4828),
	(4829),
	(4830),
	(4831),
	(4832),
	(4833),
	(4834),
	(4835),
	(4836),
	(4837),
	(4838),
	(4839),
	(4840),
	(4841),
	(4842),
	(4843),
	(4844),
	(4845),
	(4846),
	(4847),
	(4848),
	(4849),
	(4850),
	(4851),
	(4852),
	(4853),
	(4854),
	(4855),
	(4856),
	(4857),
	(4858),
	(4859),
	(4860),
	(4861),
	(4862),
	(4863),
	(4864),
	(4865),
	(4866),
	(4867),
	(4868),
	(4869),
	(4870),
	(4871),
	(4872),
	(4873),
	(4874),
	(4875),
	(4876),
	(4877),
	(4878),
	(4879),
	(4880),
	(4881),
	(4882),
	(4883),
	(4884),
	(4885),
	(4886),
	(4887),
	(4888),
	(4889),
	(4890),
	(4891),
	(4892),
	(4893),
	(4894),
	(4895),
	(4896),
	(4897),
	(4898),
	(4899),
	(4900),
	(4901),
	(4902),
	(4903),
	(4904),
	(4905),
	(4906),
	(4907),
	(4908),
	(4909),
	(4910),
	(4911),
	(4912),
	(4913),
	(4914),
	(4915),
	(4916),
	(4917),
	(4918),
	(4919),
	(4920),
	(4921),
	(4922),
	(4923),
	(4924),
	(4925),
	(4926),
	(4927),
	(4928),
	(4929),
	(4930),
	(4931),
	(4932),
	(4933),
	(4934),
	(4935),
	(4936),
	(4937),
	(4938),
	(4939),
	(4940),
	(4941),
	(4942),
	(4943),
	(4944),
	(4945),
	(4946),
	(4947),
	(4948),
	(4949),
	(4950),
	(4951),
	(4952),
	(4953),
	(4954),
	(4955),
	(4956),
	(4957),
	(4958),
	(4959),
	(4960),
	(4961),
	(4962),
	(4963),
	(4964),
	(4965),
	(4966),
	(4967),
	(4968),
	(4969),
	(4970),
	(4971),
	(4972),
	(4973),
	(4974),
	(4975),
	(4976),
	(4977),
	(4978),
	(4979),
	(4980),
	(4981),
	(4982),
	(4983),
	(4984),
	(4985),
	(4986),
	(4987),
	(4988),
	(4989),
	(4990),
	(4991),
	(4992),
	(4993),
	(4994),
	(4995),
	(4996),
	(4997),
	(4998),
	(4999),
	(5000),
	(5001),
	(5002),
	(5003),
	(5004),
	(5005),
	(5006),
	(5007),
	(5008),
	(5009),
	(5010),
	(5011),
	(5012),
	(5013),
	(5014),
	(5015),
	(5016),
	(5017),
	(5018),
	(5019),
	(5020),
	(5021),
	(5022),
	(5023),
	(5024),
	(5025),
	(5026),
	(5027),
	(5028),
	(5029),
	(5030),
	(5031),
	(5032),
	(5033),
	(5034),
	(5035),
	(5036),
	(5037),
	(5038),
	(5039),
	(5040),
	(5041),
	(5042),
	(5043),
	(5044),
	(5045),
	(5046),
	(5047),
	(5048),
	(5049),
	(5050),
	(5051),
	(5052),
	(5053),
	(5054),
	(5055),
	(5056),
	(5057),
	(5058),
	(5059),
	(5060),
	(5061),
	(5062),
	(5063),
	(5064),
	(5065),
	(5066),
	(5067),
	(5068),
	(5069),
	(5070),
	(5071),
	(5072),
	(5073),
	(5074),
	(5075),
	(5076),
	(5077),
	(5078),
	(5079),
	(5080),
	(5081),
	(5082),
	(5083),
	(5084),
	(5085),
	(5086),
	(5087),
	(5088),
	(5089),
	(5090),
	(5091),
	(5092),
	(5093),
	(5094),
	(5095),
	(5096),
	(5097),
	(5098),
	(5099),
	(5100),
	(5101),
	(5102),
	(5103),
	(5104),
	(5105),
	(5106),
	(5107),
	(5108),
	(5109),
	(5110),
	(5111),
	(5112),
	(5113),
	(5114),
	(5115),
	(5116),
	(5117),
	(5118),
	(5119),
	(5120),
	(5121),
	(5122),
	(5123),
	(5124),
	(5125),
	(5126),
	(5127),
	(5128),
	(5129),
	(5130),
	(5131),
	(5132),
	(5133),
	(5134),
	(5135),
	(5136),
	(5137),
	(5138),
	(5139),
	(5140),
	(5141),
	(5142),
	(5143),
	(5144),
	(5145),
	(5146),
	(5147),
	(5148),
	(5149),
	(5150),
	(5151),
	(5152),
	(5153),
	(5154),
	(5155),
	(5156),
	(5157),
	(5158),
	(5159),
	(5160),
	(5161),
	(5162),
	(5163),
	(5164),
	(5165),
	(5166),
	(5167),
	(5168),
	(5169),
	(5170),
	(5171),
	(5172),
	(5173),
	(5174),
	(5175),
	(5176),
	(5177),
	(5178),
	(5179),
	(5180),
	(5181),
	(5182),
	(5183),
	(5184),
	(5185),
	(5186),
	(5187),
	(5188),
	(5189),
	(5190),
	(5191),
	(5192),
	(5193),
	(5194),
	(5195),
	(5196),
	(5197),
	(5198),
	(5199),
	(5200),
	(5201),
	(5202),
	(5203),
	(5204),
	(5205),
	(5206),
	(5207),
	(5208),
	(5209),
	(5210),
	(5211),
	(5212),
	(5213),
	(5214),
	(5215),
	(5216),
	(5217),
	(5218),
	(5219),
	(5220),
	(5221),
	(5222),
	(5223),
	(5224),
	(5225),
	(5226),
	(5227),
	(5228),
	(5229),
	(5230),
	(5231),
	(5232),
	(5233),
	(5234),
	(5235),
	(5236),
	(5237),
	(5238),
	(5239),
	(5240),
	(5241),
	(5242),
	(5243),
	(5244),
	(5245),
	(5246),
	(5247),
	(5248),
	(5249),
	(5250),
	(5251),
	(5252),
	(5253),
	(5254),
	(5255),
	(5256),
	(5257),
	(5258),
	(5259),
	(5260),
	(5261),
	(5262),
	(5263),
	(5264),
	(5265),
	(5266),
	(5267),
	(5268),
	(5269),
	(5270),
	(5271),
	(5272),
	(5273),
	(5274),
	(5275),
	(5276),
	(5277),
	(5278),
	(5279),
	(5280),
	(5281),
	(5282),
	(5283),
	(5284),
	(5285),
	(5286),
	(5287),
	(5288),
	(5289),
	(5290),
	(5291),
	(5292),
	(5293),
	(5294),
	(5295),
	(5296),
	(5297),
	(5298),
	(5299),
	(5300),
	(5301),
	(5302),
	(5303),
	(5304),
	(5305),
	(5306),
	(5307),
	(5308),
	(5309),
	(5310),
	(5311),
	(5312),
	(5313),
	(5314),
	(5315),
	(5316),
	(5317),
	(5318),
	(5319),
	(5320),
	(5321),
	(5322),
	(5323),
	(5324),
	(5325),
	(5326),
	(5327),
	(5328),
	(5329),
	(5330),
	(5331),
	(5332),
	(5333),
	(5334),
	(5335),
	(5336),
	(5337),
	(5338),
	(5339),
	(5340),
	(5341),
	(5342),
	(5343),
	(5344),
	(5345),
	(5346),
	(5347),
	(5348),
	(5349),
	(5350),
	(5351),
	(5352),
	(5353),
	(5354),
	(5355),
	(5356),
	(5357),
	(5358),
	(5359),
	(5360),
	(5361),
	(5362),
	(5363),
	(5364),
	(5365),
	(5366),
	(5367),
	(5368),
	(5369),
	(5370),
	(5371),
	(5372),
	(5373),
	(5374),
	(5375),
	(5376),
	(5377),
	(5378),
	(5379),
	(5380),
	(5381),
	(5382),
	(5383),
	(5384),
	(5385),
	(5386),
	(5387),
	(5388),
	(5389),
	(5390),
	(5391),
	(5392),
	(5393),
	(5394),
	(5395),
	(5396),
	(5397),
	(5398),
	(5399),
	(5400),
	(5401),
	(5402),
	(5403),
	(5404),
	(5405),
	(5406),
	(5407),
	(5408),
	(5409),
	(5410),
	(5411),
	(5412),
	(5413),
	(5414),
	(5415),
	(5416),
	(5417),
	(5418),
	(5419),
	(5420),
	(5421),
	(5422),
	(5423),
	(5424),
	(5425),
	(5426),
	(5427),
	(5428),
	(5429),
	(5430),
	(5431),
	(5432),
	(5433),
	(5434),
	(5435),
	(5436),
	(5437),
	(5438),
	(5439),
	(5440),
	(5441),
	(5442),
	(5443),
	(5444),
	(5445),
	(5446),
	(5447),
	(5448),
	(5449),
	(5450),
	(5451),
	(5452),
	(5453),
	(5454),
	(5455),
	(5456),
	(5457),
	(5458),
	(5459),
	(5460),
	(5461),
	(5462),
	(5463),
	(5464),
	(5465),
	(5466),
	(5467),
	(5468),
	(5469),
	(5470),
	(5471),
	(5472),
	(5473),
	(5474),
	(5475),
	(5476),
	(5477),
	(5478),
	(5479),
	(5480),
	(5481),
	(5482),
	(5483),
	(5484),
	(5485),
	(5486),
	(5487),
	(5488),
	(5489),
	(5490),
	(5491),
	(5492),
	(5493),
	(5494),
	(5495),
	(5496),
	(5497),
	(5498),
	(5499),
	(5500),
	(5501),
	(5502),
	(5503),
	(5504),
	(5505),
	(5506),
	(5507),
	(5508),
	(5509),
	(5510),
	(5511),
	(5512),
	(5513),
	(5514),
	(5515),
	(5516),
	(5517),
	(5518),
	(5519),
	(5520),
	(5521),
	(5522),
	(5523),
	(5524),
	(5525),
	(5526),
	(5527),
	(5528),
	(5529),
	(5530),
	(5531),
	(5532),
	(5533),
	(5534),
	(5535),
	(5536),
	(5537),
	(5538),
	(5539),
	(5540),
	(5541),
	(5542),
	(5543),
	(5544),
	(5545),
	(5546),
	(5547),
	(5548),
	(5549),
	(5550),
	(5551),
	(5552),
	(5553),
	(5554),
	(5555),
	(5556),
	(5557),
	(5558),
	(5559),
	(5560),
	(5561),
	(5562),
	(5563),
	(5564),
	(5565),
	(5566),
	(5567),
	(5568),
	(5569),
	(5570),
	(5571),
	(5572),
	(5573),
	(5574),
	(5575),
	(5576),
	(5577),
	(5578),
	(5579),
	(5580),
	(5581),
	(5582),
	(5583),
	(5584),
	(5585),
	(5586),
	(5587),
	(5588),
	(5589),
	(5590),
	(5591),
	(5592),
	(5593),
	(5594),
	(5595),
	(5596),
	(5597),
	(5598),
	(5599),
	(5600),
	(5601),
	(5602),
	(5603),
	(5604),
	(5605),
	(5606),
	(5607),
	(5608),
	(5609),
	(5610),
	(5611),
	(5612),
	(5613),
	(5614),
	(5615),
	(5616),
	(5617),
	(5618),
	(5619),
	(5620),
	(5621),
	(5622),
	(5623),
	(5624),
	(5625),
	(5626),
	(5627),
	(5628),
	(5629),
	(5630),
	(5631),
	(5632),
	(5633),
	(5634),
	(5635),
	(5636),
	(5637),
	(5638),
	(5639),
	(5640),
	(5641),
	(5642),
	(5643),
	(5644),
	(5645),
	(5646),
	(5647),
	(5648),
	(5649),
	(5650),
	(5651),
	(5652),
	(5653),
	(5654),
	(5655),
	(5656),
	(5657),
	(5658),
	(5659),
	(5660),
	(5661),
	(5662),
	(5663),
	(5664),
	(5665),
	(5666),
	(5667),
	(5668),
	(5669),
	(5670),
	(5671),
	(5672),
	(5673),
	(5674),
	(5675),
	(5676),
	(5677),
	(5678),
	(5679),
	(5680),
	(5681),
	(5682),
	(5683),
	(5684),
	(5685),
	(5686),
	(5687),
	(5688),
	(5689),
	(5690),
	(5691),
	(5692),
	(5693),
	(5694),
	(5695),
	(5696),
	(5697),
	(5698),
	(5699),
	(5700),
	(5701),
	(5702),
	(5703),
	(5704),
	(5705),
	(5706),
	(5707),
	(5708),
	(5709),
	(5710),
	(5711),
	(5712),
	(5713),
	(5714),
	(5715),
	(5716),
	(5717),
	(5718),
	(5719),
	(5720),
	(5721),
	(5722),
	(5723),
	(5724),
	(5725),
	(5726),
	(5727),
	(5728),
	(5729),
	(5730),
	(5731),
	(5732),
	(5733),
	(5734),
	(5735),
	(5736),
	(5737),
	(5738),
	(5739),
	(5740),
	(5741),
	(5742),
	(5743),
	(5744),
	(5745),
	(5746),
	(5747),
	(5748),
	(5749),
	(5750),
	(5751),
	(5752),
	(5753),
	(5754),
	(5755),
	(5756),
	(5757),
	(5758),
	(5759),
	(5760),
	(5761),
	(5762),
	(5763),
	(5764),
	(5765),
	(5766),
	(5767),
	(5768),
	(5769),
	(5770),
	(5771),
	(5772),
	(5773),
	(5774),
	(5775),
	(5776),
	(5777),
	(5778),
	(5779),
	(5780),
	(5781),
	(5782),
	(5783),
	(5784),
	(5785),
	(5786),
	(5787),
	(5788),
	(5789),
	(5790),
	(5791),
	(5792),
	(5793),
	(5794),
	(5795),
	(5796),
	(5797),
	(5798),
	(5799),
	(5800),
	(5801),
	(5802),
	(5803),
	(5804),
	(5805),
	(5806),
	(5807),
	(5808),
	(5809),
	(5810),
	(5811),
	(5812),
	(5813),
	(5814),
	(5815),
	(5816),
	(5817),
	(5818),
	(5819),
	(5820),
	(5821),
	(5822),
	(5823),
	(5824),
	(5825),
	(5826),
	(5827),
	(5828),
	(5829),
	(5830),
	(5831),
	(5832),
	(5833),
	(5834),
	(5835),
	(5836),
	(5837),
	(5838),
	(5839),
	(5840),
	(5841),
	(5842),
	(5843),
	(5844),
	(5845),
	(5846),
	(5847),
	(5848),
	(5849),
	(5850),
	(5851),
	(5852),
	(5853),
	(5854),
	(5855),
	(5856),
	(5857),
	(5858),
	(5859),
	(5860),
	(5861),
	(5862),
	(5863),
	(5864),
	(5865),
	(5866),
	(5867),
	(5868),
	(5869),
	(5870),
	(5871),
	(5872),
	(5873),
	(5874),
	(5875),
	(5876),
	(5877),
	(5878),
	(5879),
	(5880),
	(5881),
	(5882),
	(5883),
	(5884),
	(5885),
	(5886),
	(5887),
	(5888),
	(5889),
	(5890),
	(5891),
	(5892),
	(5893),
	(5894),
	(5895),
	(5896),
	(5897),
	(5898),
	(5899),
	(5900),
	(5901),
	(5902),
	(5903),
	(5904),
	(5905),
	(5906),
	(5907),
	(5908),
	(5909),
	(5910),
	(5911),
	(5912),
	(5913),
	(5914),
	(5915),
	(5916),
	(5917),
	(5918),
	(5919),
	(5920),
	(5921),
	(5922),
	(5923),
	(5924),
	(5925),
	(5926),
	(5927),
	(5928),
	(5929),
	(5930),
	(5931),
	(5932),
	(5933),
	(5934),
	(5935),
	(5936),
	(5937),
	(5938),
	(5939),
	(5940),
	(5941),
	(5942),
	(5943),
	(5944),
	(5945),
	(5946),
	(5947),
	(5948),
	(5949),
	(5950),
	(5951),
	(5952),
	(5953),
	(5954),
	(5955),
	(5956),
	(5957),
	(5958),
	(5959),
	(5960),
	(5961),
	(5962),
	(5963),
	(5964),
	(5965),
	(5966),
	(5967),
	(5968),
	(5969),
	(5970),
	(5971),
	(5972),
	(5973),
	(5974),
	(5975),
	(5976),
	(5977),
	(5978),
	(5979),
	(5980),
	(5981),
	(5982),
	(5983),
	(5984),
	(5985),
	(5986),
	(5987),
	(5988),
	(5989),
	(5990),
	(5991),
	(5992),
	(5993),
	(5994),
	(5995),
	(5996),
	(5997),
	(5998),
	(5999),
	(6000),
	(6001),
	(6002),
	(6003),
	(6004),
	(6005),
	(6006),
	(6007),
	(6008),
	(6009),
	(6010),
	(6011),
	(6012),
	(6013),
	(6014),
	(6015),
	(6016),
	(6017),
	(6018),
	(6019),
	(6020),
	(6021),
	(6022),
	(6023),
	(6024),
	(6025),
	(6026),
	(6027),
	(6028),
	(6029),
	(6030),
	(6031),
	(6032),
	(6033),
	(6034),
	(6035),
	(6036),
	(6037),
	(6038),
	(6039),
	(6040),
	(6041),
	(6042),
	(6043),
	(6044),
	(6045),
	(6046),
	(6047),
	(6048),
	(6049),
	(6050),
	(6051),
	(6052),
	(6053),
	(6054),
	(6055),
	(6056),
	(6057),
	(6058),
	(6059),
	(6060),
	(6061),
	(6062),
	(6063),
	(6064),
	(6065),
	(6066),
	(6067),
	(6068),
	(6069),
	(6070),
	(6071),
	(6072),
	(6073),
	(6074),
	(6075),
	(6076),
	(6077),
	(6078),
	(6079),
	(6080),
	(6081),
	(6082),
	(6083),
	(6084),
	(6085),
	(6086),
	(6087),
	(6088),
	(6089),
	(6090),
	(6091),
	(6092),
	(6093),
	(6094),
	(6095),
	(6096),
	(6097),
	(6098),
	(6099),
	(6100),
	(6101),
	(6102),
	(6103),
	(6104),
	(6105),
	(6106),
	(6107),
	(6108),
	(6109),
	(6110),
	(6111),
	(6112),
	(6113),
	(6114),
	(6115),
	(6116),
	(6117),
	(6118),
	(6119),
	(6120),
	(6121),
	(6122),
	(6123),
	(6124),
	(6125),
	(6126),
	(6127),
	(6128),
	(6129),
	(6130),
	(6131),
	(6132),
	(6133),
	(6134),
	(6135),
	(6136),
	(6137),
	(6138),
	(6139),
	(6140),
	(6141),
	(6142),
	(6143),
	(6144),
	(6145),
	(6146),
	(6147),
	(6148),
	(6149),
	(6150),
	(6151),
	(6152),
	(6153),
	(6154),
	(6155),
	(6156),
	(6157),
	(6158),
	(6159),
	(6160),
	(6161),
	(6162),
	(6163),
	(6164),
	(6165),
	(6166),
	(6167),
	(6168),
	(6169),
	(6170),
	(6171),
	(6172),
	(6173),
	(6174),
	(6175),
	(6176),
	(6177),
	(6178),
	(6179),
	(6180),
	(6181),
	(6182),
	(6183),
	(6184),
	(6185),
	(6186),
	(6187),
	(6188),
	(6189),
	(6190),
	(6191),
	(6192),
	(6193),
	(6194),
	(6195),
	(6196),
	(6197),
	(6198),
	(6199),
	(6200),
	(6201),
	(6202),
	(6203),
	(6204),
	(6205),
	(6206),
	(6207),
	(6208),
	(6209),
	(6210),
	(6211),
	(6212),
	(6213),
	(6214),
	(6215),
	(6216),
	(6217),
	(6218),
	(6219),
	(6220),
	(6221),
	(6222),
	(6223),
	(6224),
	(6225),
	(6226),
	(6227),
	(6228),
	(6229),
	(6230),
	(6231),
	(6232),
	(6233),
	(6234),
	(6235),
	(6236),
	(6237),
	(6238),
	(6239),
	(6240),
	(6241),
	(6242),
	(6243),
	(6244),
	(6245),
	(6246),
	(6247),
	(6248),
	(6249),
	(6250),
	(6251),
	(6252),
	(6253),
	(6254),
	(6255),
	(6256),
	(6257),
	(6258),
	(6259),
	(6260),
	(6261),
	(6262),
	(6263),
	(6264),
	(6265),
	(6266),
	(6267),
	(6268),
	(6269),
	(6270),
	(6271),
	(6272),
	(6273),
	(6274),
	(6275),
	(6276),
	(6277),
	(6278),
	(6279),
	(6280),
	(6281),
	(6282),
	(6283),
	(6284),
	(6285),
	(6286),
	(6287),
	(6288),
	(6289),
	(6290),
	(6291),
	(6292),
	(6293),
	(6294),
	(6295),
	(6296),
	(6297),
	(6298),
	(6299),
	(6300),
	(6301),
	(6302),
	(6303),
	(6304),
	(6305),
	(6306),
	(6307),
	(6308),
	(6309),
	(6310),
	(6311),
	(6312),
	(6313),
	(6314),
	(6315),
	(6316),
	(6317),
	(6318),
	(6319),
	(6320),
	(6321),
	(6322),
	(6323),
	(6324),
	(6325),
	(6326),
	(6327),
	(6328),
	(6329),
	(6330),
	(6331),
	(6332),
	(6333),
	(6334),
	(6335),
	(6336),
	(6337),
	(6338),
	(6339),
	(6340),
	(6341),
	(6342),
	(6343),
	(6344),
	(6345),
	(6346),
	(6347),
	(6348),
	(6349),
	(6350),
	(6351),
	(6352),
	(6353),
	(6354),
	(6355),
	(6356),
	(6357),
	(6358),
	(6359),
	(6360),
	(6361),
	(6362),
	(6363),
	(6364),
	(6365),
	(6366),
	(6367),
	(6368),
	(6369),
	(6370),
	(6371),
	(6372),
	(6373),
	(6374),
	(6375),
	(6376),
	(6377),
	(6378),
	(6379),
	(6380),
	(6381),
	(6382),
	(6383),
	(6384),
	(6385),
	(6386),
	(6387),
	(6388),
	(6389),
	(6390),
	(6391),
	(6392),
	(6393),
	(6394),
	(6395),
	(6396),
	(6397),
	(6398),
	(6399),
	(6400),
	(6401),
	(6402),
	(6403),
	(6404),
	(6405),
	(6406),
	(6407),
	(6408),
	(6409),
	(6410),
	(6411),
	(6412),
	(6413),
	(6414),
	(6415),
	(6416),
	(6417),
	(6418),
	(6419),
	(6420),
	(6421),
	(6422),
	(6423),
	(6424),
	(6425),
	(6426),
	(6427),
	(6428),
	(6429),
	(6430),
	(6431),
	(6432),
	(6433),
	(6434),
	(6435),
	(6436),
	(6437),
	(6438),
	(6439),
	(6440),
	(6441),
	(6442),
	(6443),
	(6444),
	(6445),
	(6446),
	(6447),
	(6448),
	(6449),
	(6450),
	(6451),
	(6452),
	(6453),
	(6454),
	(6455),
	(6456),
	(6457),
	(6458),
	(6459),
	(6460),
	(6461),
	(6462),
	(6463),
	(6464),
	(6465),
	(6466),
	(6467),
	(6468),
	(6469),
	(6470),
	(6471),
	(6472),
	(6473),
	(6474),
	(6475),
	(6476),
	(6477),
	(6478),
	(6479),
	(6480),
	(6481),
	(6482),
	(6483),
	(6484),
	(6485),
	(6486),
	(6487),
	(6488),
	(6489),
	(6490),
	(6491),
	(6492),
	(6493),
	(6494),
	(6495),
	(6496),
	(6497),
	(6498),
	(6499),
	(6500),
	(6501),
	(6502),
	(6503),
	(6504),
	(6505),
	(6506),
	(6507),
	(6508),
	(6509),
	(6510),
	(6511),
	(6512),
	(6513),
	(6514),
	(6515),
	(6516),
	(6517),
	(6518),
	(6519),
	(6520),
	(6521),
	(6522),
	(6523),
	(6524),
	(6525),
	(6526),
	(6527),
	(6528),
	(6529),
	(6530),
	(6531),
	(6532),
	(6533),
	(6534),
	(6535),
	(6536),
	(6537),
	(6538),
	(6539),
	(6540),
	(6541),
	(6542),
	(6543),
	(6544),
	(6545),
	(6546),
	(6547),
	(6548),
	(6549),
	(6550),
	(6551),
	(6552),
	(6553),
	(6554),
	(6555),
	(6556),
	(6557),
	(6558),
	(6559),
	(6560),
	(6561),
	(6562),
	(6563),
	(6564),
	(6565),
	(6566),
	(6567),
	(6568),
	(6569),
	(6570),
	(6571),
	(6572),
	(6573),
	(6574),
	(6575),
	(6576),
	(6577),
	(6578),
	(6579),
	(6580),
	(6581),
	(6582),
	(6583),
	(6584),
	(6585),
	(6586),
	(6587),
	(6588),
	(6589),
	(6590),
	(6591),
	(6592),
	(6593),
	(6594),
	(6595),
	(6596),
	(6597),
	(6598),
	(6599),
	(6600),
	(6601),
	(6602),
	(6603),
	(6604),
	(6605),
	(6606),
	(6607),
	(6608),
	(6609),
	(6610),
	(6611),
	(6612),
	(6613),
	(6614),
	(6615),
	(6616),
	(6617),
	(6618),
	(6619),
	(6620),
	(6621),
	(6622),
	(6623),
	(6624),
	(6625),
	(6626),
	(6627),
	(6628),
	(6629),
	(6630),
	(6631),
	(6632),
	(6633),
	(6634),
	(6635),
	(6636),
	(6637),
	(6638),
	(6639),
	(6640),
	(6641),
	(6642),
	(6643),
	(6644),
	(6645),
	(6646),
	(6647),
	(6648),
	(6649),
	(6650),
	(6651),
	(6652),
	(6653),
	(6654),
	(6655),
	(6656),
	(6657),
	(6658),
	(6659),
	(6660),
	(6661),
	(6662),
	(6663),
	(6664),
	(6665),
	(6666),
	(6667),
	(6668),
	(6669),
	(6670),
	(6671),
	(6672),
	(6673),
	(6674),
	(6675),
	(6676),
	(6677),
	(6678),
	(6679),
	(6680),
	(6681),
	(6682),
	(6683),
	(6684),
	(6685),
	(6686),
	(6687),
	(6688),
	(6689),
	(6690),
	(6691),
	(6692),
	(6693),
	(6694),
	(6695),
	(6696),
	(6697),
	(6698),
	(6699),
	(6700),
	(6701),
	(6702),
	(6703),
	(6704),
	(6705),
	(6706),
	(6707),
	(6708),
	(6709),
	(6710),
	(6711),
	(6712),
	(6713),
	(6714),
	(6715),
	(6716),
	(6717),
	(6718),
	(6719),
	(6720),
	(6721),
	(6722),
	(6723),
	(6724),
	(6725),
	(6726),
	(6727),
	(6728),
	(6729),
	(6730),
	(6731),
	(6732),
	(6733),
	(6734),
	(6735),
	(6736),
	(6737),
	(6738),
	(6739),
	(6740),
	(6741),
	(6742),
	(6743),
	(6744),
	(6745),
	(6746),
	(6747),
	(6748),
	(6749),
	(6750),
	(6751),
	(6752),
	(6753),
	(6754),
	(6755),
	(6756),
	(6757),
	(6758),
	(6759),
	(6760),
	(6761),
	(6762),
	(6763),
	(6764),
	(6765),
	(6766),
	(6767),
	(6768),
	(6769),
	(6770),
	(6771),
	(6772),
	(6773),
	(6774),
	(6775),
	(6776),
	(6777),
	(6778),
	(6779),
	(6780),
	(6781),
	(6782),
	(6783),
	(6784),
	(6785),
	(6786),
	(6787),
	(6788),
	(6789),
	(6790),
	(6791),
	(6792),
	(6793),
	(6794),
	(6795),
	(6796),
	(6797),
	(6798),
	(6799),
	(6800),
	(6801),
	(6802),
	(6803),
	(6804),
	(6805),
	(6806),
	(6807),
	(6808),
	(6809),
	(6810),
	(6811),
	(6812),
	(6813),
	(6814),
	(6815),
	(6816),
	(6817),
	(6818),
	(6819),
	(6820),
	(6821),
	(6822),
	(6823),
	(6824),
	(6825),
	(6826),
	(6827),
	(6828),
	(6829),
	(6830),
	(6831),
	(6832),
	(6833),
	(6834),
	(6835),
	(6836),
	(6837),
	(6838),
	(6839),
	(6840),
	(6841),
	(6842),
	(6843),
	(6844),
	(6845),
	(6846),
	(6847),
	(6848),
	(6849),
	(6850),
	(6851),
	(6852),
	(6853),
	(6854),
	(6855),
	(6856),
	(6857),
	(6858),
	(6859),
	(6860),
	(6861),
	(6862),
	(6863),
	(6864),
	(6865),
	(6866),
	(6867),
	(6868),
	(6869),
	(6870),
	(6871),
	(6872),
	(6873),
	(6874),
	(6875),
	(6876),
	(6877),
	(6878),
	(6879),
	(6880),
	(6881),
	(6882),
	(6883),
	(6884),
	(6885),
	(6886),
	(6887),
	(6888),
	(6889),
	(6890),
	(6891),
	(6892),
	(6893),
	(6894),
	(6895),
	(6896),
	(6897),
	(6898),
	(6899),
	(6900),
	(6901),
	(6902),
	(6903),
	(6904),
	(6905),
	(6906),
	(6907),
	(6908),
	(6909),
	(6910),
	(6911),
	(6912),
	(6913),
	(6914),
	(6915),
	(6916),
	(6917),
	(6918),
	(6919),
	(6920),
	(6921),
	(6922),
	(6923),
	(6924),
	(6925),
	(6926),
	(6927),
	(6928),
	(6929),
	(6930),
	(6931),
	(6932),
	(6933),
	(6934),
	(6935),
	(6936),
	(6937),
	(6938),
	(6939),
	(6940),
	(6941),
	(6942),
	(6943),
	(6944),
	(6945),
	(6946),
	(6947),
	(6948),
	(6949),
	(6950),
	(6951),
	(6952),
	(6953),
	(6954),
	(6955),
	(6956),
	(6957),
	(6958),
	(6959),
	(6960),
	(6961),
	(6962),
	(6963),
	(6964),
	(6965),
	(6966),
	(6967),
	(6968),
	(6969),
	(6970),
	(6971),
	(6972),
	(6973),
	(6974),
	(6975),
	(6976),
	(6977),
	(6978),
	(6979),
	(6980),
	(6981),
	(6982),
	(6983),
	(6984),
	(6985),
	(6986),
	(6987),
	(6988),
	(6989),
	(6990),
	(6991),
	(6992),
	(6993),
	(6994),
	(6995),
	(6996),
	(6997),
	(6998),
	(6999),
	(7000),
	(7001),
	(7002),
	(7003),
	(7004),
	(7005),
	(7006),
	(7007),
	(7008),
	(7009),
	(7010),
	(7011),
	(7012),
	(7013),
	(7014),
	(7015),
	(7016),
	(7017),
	(7018),
	(7019),
	(7020),
	(7021),
	(7022),
	(7023),
	(7024),
	(7025),
	(7026),
	(7027),
	(7028),
	(7029),
	(7030),
	(7031),
	(7032),
	(7033),
	(7034),
	(7035),
	(7036),
	(7037),
	(7038),
	(7039),
	(7040),
	(7041),
	(7042),
	(7043),
	(7044),
	(7045),
	(7046),
	(7047),
	(7048),
	(7049),
	(7050),
	(7051),
	(7052),
	(7053),
	(7054),
	(7055),
	(7056),
	(7057),
	(7058),
	(7059),
	(7060),
	(7061),
	(7062),
	(7063),
	(7064),
	(7065),
	(7066),
	(7067),
	(7068),
	(7069),
	(7070),
	(7071),
	(7072),
	(7073),
	(7074),
	(7075),
	(7076),
	(7077),
	(7078),
	(7079),
	(7080),
	(7081),
	(7082),
	(7083),
	(7084),
	(7085),
	(7086),
	(7087),
	(7088),
	(7089),
	(7090),
	(7091),
	(7092),
	(7093),
	(7094),
	(7095),
	(7096),
	(7097),
	(7098),
	(7099),
	(7100),
	(7101),
	(7102),
	(7103),
	(7104),
	(7105),
	(7106),
	(7107),
	(7108),
	(7109),
	(7110),
	(7111),
	(7112),
	(7113),
	(7114),
	(7115),
	(7116),
	(7117),
	(7118),
	(7119),
	(7120),
	(7121),
	(7122),
	(7123),
	(7124),
	(7125),
	(7126),
	(7127),
	(7128),
	(7129),
	(7130),
	(7131),
	(7132),
	(7133),
	(7134),
	(7135),
	(7136),
	(7137),
	(7138),
	(7139),
	(7140),
	(7141),
	(7142),
	(7143),
	(7144),
	(7145),
	(7146),
	(7147),
	(7148),
	(7149),
	(7150),
	(7151),
	(7152),
	(7153),
	(7154),
	(7155),
	(7156),
	(7157),
	(7158),
	(7159),
	(7160),
	(7161),
	(7162),
	(7163),
	(7164),
	(7165),
	(7166),
	(7167),
	(7168),
	(7169),
	(7170),
	(7171),
	(7172),
	(7173),
	(7174),
	(7175),
	(7176),
	(7177),
	(7178),
	(7179),
	(7180),
	(7181),
	(7182),
	(7183),
	(7184),
	(7185),
	(7186),
	(7187),
	(7188),
	(7189),
	(7190),
	(7191),
	(7192),
	(7193),
	(7194),
	(7195),
	(7196),
	(7197),
	(7198),
	(7199),
	(7200),
	(7201),
	(7202),
	(7203),
	(7204),
	(7205),
	(7206),
	(7207),
	(7208),
	(7209),
	(7210),
	(7211),
	(7212),
	(7213),
	(7214),
	(7215),
	(7216),
	(7217),
	(7218),
	(7219),
	(7220),
	(7221),
	(7222),
	(7223),
	(7224),
	(7225),
	(7226),
	(7227),
	(7228),
	(7229),
	(7230),
	(7231),
	(7232),
	(7233),
	(7234),
	(7235),
	(7236),
	(7237),
	(7238),
	(7239),
	(7240),
	(7241),
	(7242),
	(7243),
	(7244),
	(7245),
	(7246),
	(7247),
	(7248),
	(7249),
	(7250),
	(7251),
	(7252),
	(7253),
	(7254),
	(7255),
	(7256),
	(7257),
	(7258),
	(7259),
	(7260),
	(7261),
	(7262),
	(7263),
	(7264),
	(7265),
	(7266),
	(7267),
	(7268),
	(7269),
	(7270),
	(7271),
	(7272),
	(7273),
	(7274),
	(7275),
	(7276),
	(7277),
	(7278),
	(7279),
	(7280),
	(7281),
	(7282),
	(7283),
	(7284),
	(7285),
	(7286),
	(7287),
	(7288),
	(7289),
	(7290),
	(7291),
	(7292),
	(7293),
	(7294),
	(7295),
	(7296),
	(7297),
	(7298),
	(7299),
	(7300),
	(7301),
	(7302),
	(7303),
	(7304),
	(7305),
	(7306),
	(7307),
	(7308),
	(7309),
	(7310),
	(7311),
	(7312),
	(7313),
	(7314),
	(7315),
	(7316),
	(7317),
	(7318),
	(7319),
	(7320),
	(7321),
	(7322),
	(7323),
	(7324),
	(7325),
	(7326),
	(7327),
	(7328),
	(7329),
	(7330),
	(7331),
	(7332),
	(7333),
	(7334),
	(7335),
	(7336),
	(7337),
	(7338),
	(7339),
	(7340),
	(7341),
	(7342),
	(7343),
	(7344),
	(7345),
	(7346),
	(7347),
	(7348),
	(7349),
	(7350),
	(7351),
	(7352),
	(7353),
	(7354),
	(7355),
	(7356),
	(7357),
	(7358),
	(7359),
	(7360),
	(7361),
	(7362),
	(7363),
	(7364),
	(7365),
	(7366),
	(7367),
	(7368),
	(7369),
	(7370),
	(7371),
	(7372),
	(7373),
	(7374),
	(7375),
	(7376),
	(7377),
	(7378),
	(7379),
	(7380),
	(7381),
	(7382),
	(7383),
	(7384),
	(7385),
	(7386),
	(7387),
	(7388),
	(7389),
	(7390),
	(7391),
	(7392),
	(7393),
	(7394),
	(7395),
	(7396),
	(7397),
	(7398),
	(7399),
	(7400),
	(7401),
	(7402),
	(7403),
	(7404),
	(7405),
	(7406),
	(7407),
	(7408),
	(7409),
	(7410),
	(7411),
	(7412),
	(7413),
	(7414),
	(7415),
	(7416),
	(7417),
	(7418),
	(7419),
	(7420),
	(7421),
	(7422),
	(7423),
	(7424),
	(7425),
	(7426),
	(7427),
	(7428),
	(7429),
	(7430),
	(7431),
	(7432),
	(7433),
	(7434),
	(7435),
	(7436),
	(7437),
	(7438),
	(7439),
	(7440),
	(7441),
	(7442),
	(7443),
	(7444),
	(7445),
	(7446),
	(7447),
	(7448),
	(7449),
	(7450),
	(7451),
	(7452),
	(7453),
	(7454),
	(7455),
	(7456),
	(7457),
	(7458),
	(7459),
	(7460),
	(7461),
	(7462),
	(7463),
	(7464),
	(7465),
	(7466),
	(7467),
	(7468),
	(7469),
	(7470),
	(7471),
	(7472),
	(7473),
	(7474),
	(7475),
	(7476),
	(7477),
	(7478),
	(7479),
	(7480),
	(7481),
	(7482),
	(7483),
	(7484),
	(7485),
	(7486),
	(7487),
	(7488),
	(7489),
	(7490),
	(7491),
	(7492),
	(7493),
	(7494),
	(7495),
	(7496),
	(7497),
	(7498),
	(7499),
	(7500),
	(7501),
	(7502),
	(7503),
	(7504),
	(7505),
	(7506),
	(7507),
	(7508),
	(7509),
	(7510),
	(7511),
	(7512),
	(7513),
	(7514),
	(7515),
	(7516),
	(7517),
	(7518),
	(7519),
	(7520),
	(7521),
	(7522),
	(7523),
	(7524),
	(7525),
	(7526),
	(7527),
	(7528),
	(7529),
	(7530),
	(7531),
	(7532),
	(7533),
	(7534),
	(7535),
	(7536),
	(7537),
	(7538),
	(7539),
	(7540),
	(7541),
	(7542),
	(7543),
	(7544),
	(7545),
	(7546),
	(7547),
	(7548),
	(7549),
	(7550),
	(7551),
	(7552),
	(7553),
	(7554),
	(7555),
	(7556),
	(7557),
	(7558),
	(7559),
	(7560),
	(7561),
	(7562),
	(7563),
	(7564),
	(7565),
	(7566),
	(7567),
	(7568),
	(7569),
	(7570),
	(7571),
	(7572),
	(7573),
	(7574),
	(7575),
	(7576),
	(7577),
	(7578),
	(7579),
	(7580),
	(7581),
	(7582),
	(7583),
	(7584),
	(7585),
	(7586),
	(7587),
	(7588),
	(7589),
	(7590),
	(7591),
	(7592),
	(7593),
	(7594),
	(7595),
	(7596),
	(7597),
	(7598),
	(7599),
	(7600),
	(7601),
	(7602),
	(7603),
	(7604),
	(7605),
	(7606),
	(7607),
	(7608),
	(7609),
	(7610),
	(7611),
	(7612),
	(7613),
	(7614),
	(7615),
	(7616),
	(7617),
	(7618),
	(7619),
	(7620),
	(7621),
	(7622),
	(7623),
	(7624),
	(7625),
	(7626),
	(7627),
	(7628),
	(7629),
	(7630),
	(7631),
	(7632),
	(7633),
	(7634),
	(7635),
	(7636),
	(7637),
	(7638),
	(7639),
	(7640),
	(7641),
	(7642),
	(7643),
	(7644),
	(7645),
	(7646),
	(7647),
	(7648),
	(7649),
	(7650),
	(7651),
	(7652),
	(7653),
	(7654),
	(7655),
	(7656),
	(7657),
	(7658),
	(7659),
	(7660),
	(7661),
	(7662),
	(7663),
	(7664),
	(7665),
	(7666),
	(7667),
	(7668),
	(7669),
	(7670),
	(7671),
	(7672),
	(7673),
	(7674),
	(7675),
	(7676),
	(7677),
	(7678),
	(7679),
	(7680),
	(7681),
	(7682),
	(7683),
	(7684),
	(7685),
	(7686),
	(7687),
	(7688),
	(7689),
	(7690),
	(7691),
	(7692),
	(7693),
	(7694),
	(7695),
	(7696),
	(7697),
	(7698),
	(7699),
	(7700),
	(7701),
	(7702),
	(7703),
	(7704),
	(7705),
	(7706),
	(7707),
	(7708),
	(7709),
	(7710),
	(7711),
	(7712),
	(7713),
	(7714),
	(7715),
	(7716),
	(7717),
	(7718),
	(7719),
	(7720),
	(7721),
	(7722),
	(7723),
	(7724),
	(7725),
	(7726),
	(7727),
	(7728),
	(7729),
	(7730),
	(7731),
	(7732),
	(7733),
	(7734),
	(7735),
	(7736),
	(7737),
	(7738),
	(7739),
	(7740),
	(7741),
	(7742),
	(7743),
	(7744),
	(7745),
	(7746),
	(7747),
	(7748),
	(7749),
	(7750),
	(7751),
	(7752),
	(7753),
	(7754),
	(7755),
	(7756),
	(7757),
	(7758),
	(7759),
	(7760),
	(7761),
	(7762),
	(7763),
	(7764),
	(7765),
	(7766),
	(7767),
	(7768),
	(7769),
	(7770),
	(7771),
	(7772),
	(7773),
	(7774),
	(7775),
	(7776),
	(7777),
	(7778),
	(7779),
	(7780),
	(7781),
	(7782),
	(7783),
	(7784),
	(7785),
	(7786),
	(7787),
	(7788),
	(7789),
	(7790),
	(7791),
	(7792),
	(7793),
	(7794),
	(7795),
	(7796),
	(7797),
	(7798),
	(7799),
	(7800),
	(7801),
	(7802),
	(7803),
	(7804),
	(7805),
	(7806),
	(7807),
	(7808),
	(7809),
	(7810),
	(7811),
	(7812),
	(7813),
	(7814),
	(7815),
	(7816),
	(7817),
	(7818),
	(7819),
	(7820),
	(7821),
	(7822),
	(7823),
	(7824),
	(7825),
	(7826),
	(7827),
	(7828),
	(7829),
	(7830),
	(7831),
	(7832),
	(7833),
	(7834),
	(7835),
	(7836),
	(7837),
	(7838),
	(7839),
	(7840),
	(7841),
	(7842),
	(7843),
	(7844),
	(7845),
	(7846),
	(7847),
	(7848),
	(7849),
	(7850),
	(7851),
	(7852),
	(7853),
	(7854),
	(7855),
	(7856),
	(7857),
	(7858),
	(7859),
	(7860),
	(7861),
	(7862),
	(7863),
	(7864),
	(7865),
	(7866),
	(7867),
	(7868),
	(7869),
	(7870),
	(7871),
	(7872),
	(7873),
	(7874),
	(7875),
	(7876),
	(7877),
	(7878),
	(7879),
	(7880),
	(7881),
	(7882),
	(7883),
	(7884),
	(7885),
	(7886),
	(7887),
	(7888),
	(7889),
	(7890),
	(7891),
	(7892),
	(7893),
	(7894),
	(7895),
	(7896),
	(7897),
	(7898),
	(7899),
	(7900),
	(7901),
	(7902),
	(7903),
	(7904),
	(7905),
	(7906),
	(7907),
	(7908),
	(7909),
	(7910),
	(7911),
	(7912),
	(7913),
	(7914),
	(7915),
	(7916),
	(7917),
	(7918),
	(7919),
	(7920),
	(7921),
	(7922),
	(7923),
	(7924),
	(7925),
	(7926),
	(7927),
	(7928),
	(7929),
	(7930),
	(7931),
	(7932),
	(7933),
	(7934),
	(7935),
	(7936),
	(7937),
	(7938),
	(7939),
	(7940),
	(7941),
	(7942),
	(7943),
	(7944),
	(7945),
	(7946),
	(7947),
	(7948),
	(7949),
	(7950),
	(7951),
	(7952),
	(7953),
	(7954),
	(7955),
	(7956),
	(7957),
	(7958),
	(7959),
	(7960),
	(7961),
	(7962),
	(7963),
	(7964),
	(7965),
	(7966),
	(7967),
	(7968),
	(7969),
	(7970),
	(7971),
	(7972),
	(7973),
	(7974),
	(7975),
	(7976),
	(7977),
	(7978),
	(7979),
	(7980),
	(7981),
	(7982),
	(7983),
	(7984),
	(7985),
	(7986),
	(7987),
	(7988),
	(7989),
	(7990),
	(7991),
	(7992),
	(7993),
	(7994),
	(7995),
	(7996),
	(7997),
	(7998),
	(7999),
	(8000),
	(8001),
	(8002),
	(8003),
	(8004),
	(8005),
	(8006),
	(8007),
	(8008),
	(8009),
	(8010),
	(8011),
	(8012),
	(8013),
	(8014),
	(8015),
	(8016),
	(8017),
	(8018),
	(8019),
	(8020),
	(8021),
	(8022),
	(8023),
	(8024),
	(8025),
	(8026),
	(8027),
	(8028),
	(8029),
	(8030),
	(8031),
	(8032),
	(8033),
	(8034),
	(8035),
	(8036),
	(8037),
	(8038),
	(8039),
	(8040),
	(8041),
	(8042),
	(8043),
	(8044),
	(8045),
	(8046),
	(8047),
	(8048),
	(8049),
	(8050),
	(8051),
	(8052),
	(8053),
	(8054),
	(8055),
	(8056),
	(8057),
	(8058),
	(8059),
	(8060),
	(8061),
	(8062),
	(8063),
	(8064),
	(8065),
	(8066),
	(8067),
	(8068),
	(8069),
	(8070),
	(8071),
	(8072),
	(8073),
	(8074),
	(8075),
	(8076),
	(8077),
	(8078),
	(8079),
	(8080),
	(8081),
	(8082),
	(8083),
	(8084),
	(8085),
	(8086),
	(8087),
	(8088),
	(8089),
	(8090),
	(8091),
	(8092),
	(8093),
	(8094),
	(8095),
	(8096),
	(8097),
	(8098),
	(8099),
	(8100),
	(8101),
	(8102),
	(8103),
	(8104),
	(8105),
	(8106),
	(8107),
	(8108),
	(8109),
	(8110),
	(8111),
	(8112),
	(8113),
	(8114),
	(8115),
	(8116),
	(8117),
	(8118),
	(8119),
	(8120),
	(8121),
	(8122),
	(8123),
	(8124),
	(8125),
	(8126),
	(8127),
	(8128),
	(8129),
	(8130),
	(8131),
	(8132),
	(8133),
	(8134),
	(8135),
	(8136),
	(8137),
	(8138),
	(8139),
	(8140),
	(8141),
	(8142),
	(8143),
	(8144),
	(8145),
	(8146),
	(8147),
	(8148),
	(8149),
	(8150),
	(8151),
	(8152),
	(8153),
	(8154),
	(8155),
	(8156),
	(8157),
	(8158),
	(8159),
	(8160),
	(8161),
	(8162),
	(8163),
	(8164),
	(8165),
	(8166),
	(8167),
	(8168),
	(8169),
	(8170),
	(8171),
	(8172),
	(8173),
	(8174),
	(8175),
	(8176),
	(8177),
	(8178),
	(8179),
	(8180),
	(8181),
	(8182),
	(8183),
	(8184),
	(8185),
	(8186),
	(8187),
	(8188),
	(8189),
	(8190),
	(8191),
	(8192),
	(8193),
	(8194),
	(8195),
	(8196),
	(8197),
	(8198),
	(8199),
	(8200),
	(8201),
	(8202),
	(8203),
	(8204),
	(8205),
	(8206),
	(8207),
	(8208),
	(8209),
	(8210),
	(8211),
	(8212),
	(8213),
	(8214),
	(8215),
	(8216),
	(8217),
	(8218),
	(8219),
	(8220),
	(8221),
	(8222),
	(8223),
	(8224),
	(8225),
	(8226),
	(8227),
	(8228),
	(8229),
	(8230),
	(8231),
	(8232),
	(8233),
	(8234),
	(8235),
	(8236),
	(8237),
	(8238),
	(8239),
	(8240),
	(8241),
	(8242),
	(8243),
	(8244),
	(8245),
	(8246),
	(8247),
	(8248),
	(8249),
	(8250),
	(8251),
	(8252),
	(8253),
	(8254),
	(8255),
	(8256),
	(8257),
	(8258),
	(8259),
	(8260),
	(8261),
	(8262),
	(8263),
	(8264),
	(8265),
	(8266),
	(8267),
	(8268),
	(8269),
	(8270),
	(8271),
	(8272),
	(8273),
	(8274),
	(8275),
	(8276),
	(8277),
	(8278),
	(8279),
	(8280),
	(8281),
	(8282),
	(8283),
	(8284),
	(8285),
	(8286),
	(8287),
	(8288),
	(8289),
	(8290),
	(8291),
	(8292),
	(8293),
	(8294),
	(8295),
	(8296),
	(8297),
	(8298),
	(8299),
	(8300),
	(8301),
	(8302),
	(8303),
	(8304),
	(8305),
	(8306),
	(8307),
	(8308),
	(8309),
	(8310),
	(8311),
	(8312),
	(8313),
	(8314),
	(8315),
	(8316),
	(8317),
	(8318),
	(8319),
	(8320),
	(8321),
	(8322),
	(8323),
	(8324),
	(8325),
	(8326),
	(8327),
	(8328),
	(8329),
	(8330),
	(8331),
	(8332),
	(8333),
	(8334),
	(8335),
	(8336),
	(8337),
	(8338),
	(8339),
	(8340),
	(8341),
	(8342),
	(8343),
	(8344),
	(8345),
	(8346),
	(8347),
	(8348),
	(8349),
	(8350),
	(8351),
	(8352),
	(8353),
	(8354),
	(8355),
	(8356),
	(8357),
	(8358),
	(8359),
	(8360),
	(8361),
	(8362),
	(8363),
	(8364),
	(8365),
	(8366),
	(8367),
	(8368),
	(8369),
	(8370),
	(8371),
	(8372),
	(8373),
	(8374),
	(8375),
	(8376),
	(8377),
	(8378),
	(8379),
	(8380),
	(8381),
	(8382),
	(8383),
	(8384),
	(8385),
	(8386),
	(8387),
	(8388),
	(8389),
	(8390),
	(8391),
	(8392),
	(8393),
	(8394),
	(8395),
	(8396),
	(8397),
	(8398),
	(8399),
	(8400),
	(8401),
	(8402),
	(8403),
	(8404),
	(8405),
	(8406),
	(8407),
	(8408),
	(8409),
	(8410),
	(8411),
	(8412),
	(8413),
	(8414),
	(8415),
	(8416),
	(8417),
	(8418),
	(8419),
	(8420),
	(8421),
	(8422),
	(8423),
	(8424),
	(8425),
	(8426),
	(8427),
	(8428),
	(8429),
	(8430),
	(8431),
	(8432),
	(8433),
	(8434),
	(8435),
	(8436),
	(8437),
	(8438),
	(8439),
	(8440),
	(8441),
	(8442),
	(8443),
	(8444),
	(8445),
	(8446),
	(8447),
	(8448),
	(8449),
	(8450),
	(8451),
	(8452),
	(8453),
	(8454),
	(8455),
	(8456),
	(8457),
	(8458),
	(8459),
	(8460),
	(8461),
	(8462),
	(8463),
	(8464),
	(8465),
	(8466),
	(8467),
	(8468),
	(8469),
	(8470),
	(8471),
	(8472),
	(8473),
	(8474),
	(8475),
	(8476),
	(8477),
	(8478),
	(8479),
	(8480),
	(8481),
	(8482),
	(8483),
	(8484),
	(8485),
	(8486),
	(8487),
	(8488),
	(8489),
	(8490),
	(8491),
	(8492),
	(8493),
	(8494),
	(8495),
	(8496),
	(8497),
	(8498),
	(8499),
	(8500),
	(8501),
	(8502),
	(8503),
	(8504),
	(8505),
	(8506),
	(8507),
	(8508),
	(8509),
	(8510),
	(8511),
	(8512),
	(8513),
	(8514),
	(8515),
	(8516),
	(8517),
	(8518),
	(8519),
	(8520),
	(8521),
	(8522),
	(8523),
	(8524),
	(8525),
	(8526),
	(8527),
	(8528),
	(8529),
	(8530),
	(8531),
	(8532),
	(8533),
	(8534),
	(8535),
	(8536),
	(8537),
	(8538),
	(8539),
	(8540),
	(8541),
	(8542),
	(8543),
	(8544),
	(8545),
	(8546),
	(8547),
	(8548),
	(8549),
	(8550),
	(8551),
	(8552),
	(8553),
	(8554),
	(8555),
	(8556),
	(8557),
	(8558),
	(8559),
	(8560),
	(8561),
	(8562),
	(8563),
	(8564),
	(8565),
	(8566),
	(8567),
	(8568),
	(8569),
	(8570),
	(8571),
	(8572),
	(8573),
	(8574),
	(8575),
	(8576),
	(8577),
	(8578),
	(8579),
	(8580),
	(8581),
	(8582),
	(8583),
	(8584),
	(8585),
	(8586),
	(8587),
	(8588),
	(8589),
	(8590),
	(8591),
	(8592),
	(8593),
	(8594),
	(8595),
	(8596),
	(8597),
	(8598),
	(8599),
	(8600),
	(8601),
	(8602),
	(8603),
	(8604),
	(8605),
	(8606),
	(8607),
	(8608),
	(8609),
	(8610),
	(8611),
	(8612),
	(8613),
	(8614),
	(8615),
	(8616),
	(8617),
	(8618),
	(8619),
	(8620),
	(8621),
	(8622),
	(8623),
	(8624),
	(8625),
	(8626),
	(8627),
	(8628),
	(8629),
	(8630),
	(8631),
	(8632),
	(8633),
	(8634),
	(8635),
	(8636),
	(8637),
	(8638),
	(8639),
	(8640),
	(8641),
	(8642),
	(8643),
	(8644),
	(8645),
	(8646),
	(8647),
	(8648),
	(8649),
	(8650),
	(8651),
	(8652),
	(8653),
	(8654),
	(8655),
	(8656),
	(8657),
	(8658),
	(8659),
	(8660),
	(8661),
	(8662),
	(8663),
	(8664),
	(8665),
	(8666),
	(8667),
	(8668),
	(8669),
	(8670),
	(8671),
	(8672),
	(8673),
	(8674),
	(8675),
	(8676),
	(8677),
	(8678),
	(8679),
	(8680),
	(8681),
	(8682),
	(8683),
	(8684),
	(8685),
	(8686),
	(8687),
	(8688),
	(8689),
	(8690),
	(8691),
	(8692),
	(8693),
	(8694),
	(8695),
	(8696),
	(8697),
	(8698),
	(8699),
	(8700),
	(8701),
	(8702),
	(8703),
	(8704),
	(8705),
	(8706),
	(8707),
	(8708),
	(8709),
	(8710),
	(8711),
	(8712),
	(8713),
	(8714),
	(8715),
	(8716),
	(8717),
	(8718),
	(8719),
	(8720),
	(8721),
	(8722),
	(8723),
	(8724),
	(8725),
	(8726),
	(8727),
	(8728),
	(8729),
	(8730),
	(8731),
	(8732),
	(8733),
	(8734),
	(8735),
	(8736),
	(8737),
	(8738),
	(8739),
	(8740),
	(8741),
	(8742),
	(8743),
	(8744),
	(8745),
	(8746),
	(8747),
	(8748),
	(8749),
	(8750),
	(8751),
	(8752),
	(8753),
	(8754),
	(8755),
	(8756),
	(8757),
	(8758),
	(8759),
	(8760),
	(8761),
	(8762),
	(8763),
	(8764),
	(8765),
	(8766),
	(8767),
	(8768),
	(8769),
	(8770),
	(8771),
	(8772),
	(8773),
	(8774),
	(8775),
	(8776),
	(8777),
	(8778),
	(8779),
	(8780),
	(8781),
	(8782),
	(8783),
	(8784),
	(8785),
	(8786),
	(8787),
	(8788),
	(8789),
	(8790),
	(8791),
	(8792),
	(8793),
	(8794),
	(8795),
	(8796),
	(8797),
	(8798),
	(8799),
	(8800),
	(8801),
	(8802),
	(8803),
	(8804),
	(8805),
	(8806),
	(8807),
	(8808),
	(8809),
	(8810),
	(8811),
	(8812),
	(8813),
	(8814),
	(8815),
	(8816),
	(8817),
	(8818),
	(8819),
	(8820),
	(8821),
	(8822),
	(8823),
	(8824),
	(8825),
	(8826),
	(8827),
	(8828),
	(8829),
	(8830),
	(8831),
	(8832),
	(8833),
	(8834),
	(8835),
	(8836),
	(8837),
	(8838),
	(8839),
	(8840),
	(8841),
	(8842),
	(8843),
	(8844),
	(8845),
	(8846),
	(8847),
	(8848),
	(8849),
	(8850),
	(8851),
	(8852),
	(8853),
	(8854),
	(8855),
	(8856),
	(8857),
	(8858),
	(8859),
	(8860),
	(8861),
	(8862),
	(8863),
	(8864),
	(8865),
	(8866),
	(8867),
	(8868),
	(8869),
	(8870),
	(8871),
	(8872),
	(8873),
	(8874),
	(8875),
	(8876),
	(8877),
	(8878),
	(8879),
	(8880),
	(8881),
	(8882),
	(8883),
	(8884),
	(8885),
	(8886),
	(8887),
	(8888),
	(8889),
	(8890),
	(8891),
	(8892),
	(8893),
	(8894),
	(8895),
	(8896),
	(8897),
	(8898),
	(8899),
	(8900),
	(8901),
	(8902),
	(8903),
	(8904),
	(8905),
	(8906),
	(8907),
	(8908),
	(8909),
	(8910),
	(8911),
	(8912),
	(8913),
	(8914),
	(8915),
	(8916),
	(8917),
	(8918),
	(8919),
	(8920),
	(8921),
	(8922),
	(8923),
	(8924),
	(8925),
	(8926),
	(8927),
	(8928),
	(8929),
	(8930),
	(8931),
	(8932),
	(8933),
	(8934),
	(8935),
	(8936),
	(8937),
	(8938),
	(8939),
	(8940),
	(8941),
	(8942),
	(8943),
	(8944),
	(8945),
	(8946),
	(8947),
	(8948),
	(8949),
	(8950),
	(8951),
	(8952),
	(8953),
	(8954),
	(8955),
	(8956),
	(8957),
	(8958),
	(8959),
	(8960),
	(8961),
	(8962),
	(8963),
	(8964),
	(8965),
	(8966),
	(8967),
	(8968),
	(8969),
	(8970),
	(8971),
	(8972),
	(8973),
	(8974),
	(8975),
	(8976),
	(8977),
	(8978),
	(8979),
	(8980),
	(8981),
	(8982),
	(8983),
	(8984),
	(8985),
	(8986),
	(8987),
	(8988),
	(8989),
	(8990),
	(8991),
	(8992),
	(8993),
	(8994),
	(8995),
	(8996),
	(8997),
	(8998),
	(8999),
	(9000),
	(9001),
	(9002),
	(9003),
	(9004),
	(9005),
	(9006),
	(9007),
	(9008),
	(9009),
	(9010),
	(9011),
	(9012),
	(9013),
	(9014),
	(9015),
	(9016),
	(9017),
	(9018),
	(9019),
	(9020),
	(9021),
	(9022),
	(9023),
	(9024),
	(9025),
	(9026),
	(9027),
	(9028),
	(9029),
	(9030),
	(9031),
	(9032),
	(9033),
	(9034),
	(9035),
	(9036),
	(9037),
	(9038),
	(9039),
	(9040),
	(9041),
	(9042),
	(9043),
	(9044),
	(9045),
	(9046),
	(9047),
	(9048),
	(9049),
	(9050),
	(9051),
	(9052),
	(9053),
	(9054),
	(9055),
	(9056),
	(9057),
	(9058),
	(9059),
	(9060),
	(9061),
	(9062),
	(9063),
	(9064),
	(9065),
	(9066),
	(9067),
	(9068),
	(9069),
	(9070),
	(9071),
	(9072),
	(9073),
	(9074),
	(9075),
	(9076),
	(9077),
	(9078),
	(9079),
	(9080),
	(9081),
	(9082),
	(9083),
	(9084),
	(9085),
	(9086),
	(9087),
	(9088),
	(9089),
	(9090),
	(9091),
	(9092),
	(9093),
	(9094),
	(9095),
	(9096),
	(9097),
	(9098),
	(9099),
	(9100),
	(9101),
	(9102),
	(9103),
	(9104),
	(9105),
	(9106),
	(9107),
	(9108),
	(9109),
	(9110),
	(9111),
	(9112),
	(9113),
	(9114),
	(9115),
	(9116),
	(9117),
	(9118),
	(9119),
	(9120),
	(9121),
	(9122),
	(9123),
	(9124),
	(9125),
	(9126),
	(9127),
	(9128),
	(9129),
	(9130),
	(9131),
	(9132),
	(9133),
	(9134),
	(9135),
	(9136),
	(9137),
	(9138),
	(9139),
	(9140),
	(9141),
	(9142),
	(9143),
	(9144),
	(9145),
	(9146),
	(9147),
	(9148),
	(9149),
	(9150),
	(9151),
	(9152),
	(9153),
	(9154),
	(9155),
	(9156),
	(9157),
	(9158),
	(9159),
	(9160),
	(9161),
	(9162),
	(9163),
	(9164),
	(9165),
	(9166),
	(9167),
	(9168),
	(9169),
	(9170),
	(9171),
	(9172),
	(9173),
	(9174),
	(9175),
	(9176),
	(9177),
	(9178),
	(9179),
	(9180),
	(9181),
	(9182),
	(9183),
	(9184),
	(9185),
	(9186),
	(9187),
	(9188),
	(9189),
	(9190),
	(9191),
	(9192),
	(9193),
	(9194),
	(9195),
	(9196),
	(9197),
	(9198),
	(9199),
	(9200),
	(9201),
	(9202),
	(9203),
	(9204),
	(9205),
	(9206),
	(9207),
	(9208),
	(9209),
	(9210),
	(9211),
	(9212),
	(9213),
	(9214),
	(9215),
	(9216),
	(9217),
	(9218),
	(9219),
	(9220),
	(9221),
	(9222),
	(9223),
	(9224),
	(9225),
	(9226),
	(9227),
	(9228),
	(9229),
	(9230),
	(9231),
	(9232),
	(9233),
	(9234),
	(9235),
	(9236),
	(9237),
	(9238),
	(9239),
	(9240),
	(9241),
	(9242),
	(9243),
	(9244),
	(9245),
	(9246),
	(9247),
	(9248),
	(9249),
	(9250),
	(9251),
	(9252),
	(9253),
	(9254),
	(9255),
	(9256),
	(9257),
	(9258),
	(9259),
	(9260),
	(9261),
	(9262),
	(9263),
	(9264),
	(9265),
	(9266),
	(9267),
	(9268),
	(9269),
	(9270),
	(9271),
	(9272),
	(9273),
	(9274),
	(9275),
	(9276),
	(9277),
	(9278),
	(9279),
	(9280),
	(9281),
	(9282),
	(9283),
	(9284),
	(9285),
	(9286),
	(9287),
	(9288),
	(9289),
	(9290),
	(9291),
	(9292),
	(9293),
	(9294),
	(9295),
	(9296),
	(9297),
	(9298),
	(9299),
	(9300),
	(9301),
	(9302),
	(9303),
	(9304),
	(9305),
	(9306),
	(9307),
	(9308),
	(9309),
	(9310),
	(9311),
	(9312),
	(9313),
	(9314),
	(9315),
	(9316),
	(9317),
	(9318),
	(9319),
	(9320),
	(9321),
	(9322),
	(9323),
	(9324),
	(9325),
	(9326),
	(9327),
	(9328),
	(9329),
	(9330),
	(9331),
	(9332),
	(9333),
	(9334),
	(9335),
	(9336),
	(9337),
	(9338),
	(9339),
	(9340),
	(9341),
	(9342),
	(9343),
	(9344),
	(9345),
	(9346),
	(9347),
	(9348),
	(9349),
	(9350),
	(9351),
	(9352),
	(9353),
	(9354),
	(9355),
	(9356),
	(9357),
	(9358),
	(9359),
	(9360),
	(9361),
	(9362),
	(9363),
	(9364),
	(9365),
	(9366),
	(9367),
	(9368),
	(9369),
	(9370),
	(9371),
	(9372),
	(9373),
	(9374),
	(9375),
	(9376),
	(9377),
	(9378),
	(9379),
	(9380),
	(9381),
	(9382),
	(9383),
	(9384),
	(9385),
	(9386),
	(9387),
	(9388),
	(9389),
	(9390),
	(9391),
	(9392),
	(9393),
	(9394),
	(9395),
	(9396),
	(9397),
	(9398),
	(9399),
	(9400),
	(9401),
	(9402),
	(9403),
	(9404),
	(9405),
	(9406),
	(9407),
	(9408),
	(9409),
	(9410),
	(9411),
	(9412),
	(9413),
	(9414),
	(9415),
	(9416),
	(9417),
	(9418),
	(9419),
	(9420),
	(9421),
	(9422),
	(9423),
	(9424),
	(9425),
	(9426),
	(9427),
	(9428),
	(9429),
	(9430),
	(9431),
	(9432),
	(9433),
	(9434),
	(9435),
	(9436),
	(9437),
	(9438),
	(9439),
	(9440),
	(9441),
	(9442),
	(9443),
	(9444),
	(9445),
	(9446),
	(9447),
	(9448),
	(9449),
	(9450),
	(9451),
	(9452),
	(9453),
	(9454),
	(9455),
	(9456),
	(9457),
	(9458),
	(9459),
	(9460),
	(9461),
	(9462),
	(9463),
	(9464),
	(9465),
	(9466),
	(9467),
	(9468),
	(9469),
	(9470),
	(9471),
	(9472),
	(9473),
	(9474),
	(9475),
	(9476),
	(9477),
	(9478),
	(9479),
	(9480),
	(9481),
	(9482),
	(9483),
	(9484),
	(9485),
	(9486),
	(9487),
	(9488),
	(9489),
	(9490),
	(9491),
	(9492),
	(9493),
	(9494),
	(9495),
	(9496),
	(9497),
	(9498),
	(9499),
	(9500),
	(9501),
	(9502),
	(9503),
	(9504),
	(9505),
	(9506),
	(9507),
	(9508),
	(9509),
	(9510),
	(9511),
	(9512),
	(9513),
	(9514),
	(9515),
	(9516),
	(9517),
	(9518),
	(9519),
	(9520),
	(9521),
	(9522),
	(9523),
	(9524),
	(9525),
	(9526),
	(9527),
	(9528),
	(9529),
	(9530),
	(9531),
	(9532),
	(9533),
	(9534),
	(9535),
	(9536),
	(9537),
	(9538),
	(9539),
	(9540),
	(9541),
	(9542),
	(9543),
	(9544),
	(9545),
	(9546),
	(9547),
	(9548),
	(9549),
	(9550),
	(9551),
	(9552),
	(9553),
	(9554),
	(9555),
	(9556),
	(9557),
	(9558),
	(9559),
	(9560),
	(9561),
	(9562),
	(9563),
	(9564),
	(9565),
	(9566),
	(9567),
	(9568),
	(9569),
	(9570),
	(9571),
	(9572),
	(9573),
	(9574),
	(9575),
	(9576),
	(9577),
	(9578),
	(9579),
	(9580),
	(9581),
	(9582),
	(9583),
	(9584),
	(9585),
	(9586),
	(9587),
	(9588),
	(9589),
	(9590),
	(9591),
	(9592),
	(9593),
	(9594),
	(9595),
	(9596),
	(9597),
	(9598),
	(9599),
	(9600),
	(9601),
	(9602),
	(9603),
	(9604),
	(9605),
	(9606),
	(9607),
	(9608),
	(9609),
	(9610),
	(9611),
	(9612),
	(9613),
	(9614),
	(9615),
	(9616),
	(9617),
	(9618),
	(9619),
	(9620),
	(9621),
	(9622),
	(9623),
	(9624),
	(9625),
	(9626),
	(9627),
	(9628),
	(9629),
	(9630),
	(9631),
	(9632),
	(9633),
	(9634),
	(9635),
	(9636),
	(9637),
	(9638),
	(9639),
	(9640),
	(9641),
	(9642),
	(9643),
	(9644),
	(9645),
	(9646),
	(9647),
	(9648),
	(9649),
	(9650),
	(9651),
	(9652),
	(9653),
	(9654),
	(9655),
	(9656),
	(9657),
	(9658),
	(9659),
	(9660),
	(9661),
	(9662),
	(9663),
	(9664),
	(9665),
	(9666),
	(9667),
	(9668),
	(9669),
	(9670),
	(9671),
	(9672),
	(9673),
	(9674),
	(9675),
	(9676),
	(9677),
	(9678),
	(9679),
	(9680),
	(9681),
	(9682),
	(9683),
	(9684),
	(9685),
	(9686),
	(9687),
	(9688),
	(9689),
	(9690),
	(9691),
	(9692),
	(9693),
	(9694),
	(9695),
	(9696),
	(9697),
	(9698),
	(9699),
	(9700),
	(9701),
	(9702),
	(9703),
	(9704),
	(9705),
	(9706),
	(9707),
	(9708),
	(9709),
	(9710),
	(9711),
	(9712),
	(9713),
	(9714),
	(9715),
	(9716),
	(9717),
	(9718),
	(9719),
	(9720),
	(9721),
	(9722),
	(9723),
	(9724),
	(9725),
	(9726),
	(9727),
	(9728),
	(9729),
	(9730),
	(9731),
	(9732),
	(9733),
	(9734),
	(9735),
	(9736),
	(9737),
	(9738),
	(9739),
	(9740),
	(9741),
	(9742),
	(9743),
	(9744),
	(9745),
	(9746),
	(9747),
	(9748),
	(9749),
	(9750),
	(9751),
	(9752),
	(9753),
	(9754),
	(9755),
	(9756),
	(9757),
	(9758),
	(9759),
	(9760),
	(9761),
	(9762),
	(9763),
	(9764),
	(9765),
	(9766),
	(9767),
	(9768),
	(9769),
	(9770),
	(9771),
	(9772),
	(9773),
	(9774),
	(9775),
	(9776),
	(9777),
	(9778),
	(9779),
	(9780),
	(9781),
	(9782),
	(9783),
	(9784),
	(9785),
	(9786),
	(9787),
	(9788),
	(9789),
	(9790),
	(9791),
	(9792),
	(9793),
	(9794),
	(9795),
	(9796),
	(9797),
	(9798),
	(9799),
	(9800),
	(9801),
	(9802),
	(9803),
	(9804),
	(9805),
	(9806),
	(9807),
	(9808),
	(9809),
	(9810),
	(9811),
	(9812),
	(9813),
	(9814),
	(9815),
	(9816),
	(9817),
	(9818),
	(9819),
	(9820),
	(9821),
	(9822),
	(9823),
	(9824),
	(9825),
	(9826),
	(9827),
	(9828),
	(9829),
	(9830),
	(9831),
	(9832),
	(9833),
	(9834),
	(9835),
	(9836),
	(9837),
	(9838),
	(9839),
	(9840),
	(9841),
	(9842),
	(9843),
	(9844),
	(9845),
	(9846),
	(9847),
	(9848),
	(9849),
	(9850),
	(9851),
	(9852),
	(9853),
	(9854),
	(9855),
	(9856),
	(9857),
	(9858),
	(9859),
	(9860),
	(9861),
	(9862),
	(9863),
	(9864),
	(9865),
	(9866),
	(9867),
	(9868),
	(9869),
	(9870),
	(9871),
	(9872),
	(9873),
	(9874),
	(9875),
	(9876),
	(9877),
	(9878),
	(9879),
	(9880),
	(9881),
	(9882),
	(9883),
	(9884),
	(9885),
	(9886),
	(9887),
	(9888),
	(9889),
	(9890),
	(9891),
	(9892),
	(9893),
	(9894),
	(9895),
	(9896),
	(9897),
	(9898),
	(9899),
	(9900),
	(9901),
	(9902),
	(9903),
	(9904),
	(9905),
	(9906),
	(9907),
	(9908),
	(9909),
	(9910),
	(9911),
	(9912),
	(9913),
	(9914),
	(9915),
	(9916),
	(9917),
	(9918),
	(9919),
	(9920),
	(9921),
	(9922),
	(9923),
	(9924),
	(9925),
	(9926),
	(9927),
	(9928),
	(9929),
	(9930),
	(9931),
	(9932),
	(9933),
	(9934),
	(9935),
	(9936),
	(9937),
	(9938),
	(9939),
	(9940),
	(9941),
	(9942),
	(9943),
	(9944),
	(9945),
	(9946),
	(9947),
	(9948),
	(9949),
	(9950),
	(9951),
	(9952),
	(9953),
	(9954),
	(9955),
	(9956),
	(9957),
	(9958),
	(9959),
	(9960),
	(9961),
	(9962),
	(9963),
	(9964),
	(9965),
	(9966),
	(9967),
	(9968),
	(9969),
	(9970),
	(9971),
	(9972),
	(9973),
	(9974),
	(9975),
	(9976),
	(9977),
	(9978),
	(9979),
	(9980),
	(9981),
	(9982),
	(9983),
	(9984),
	(9985),
	(9986),
	(9987),
	(9988),
	(9989),
	(9990),
	(9991),
	(9992),
	(9993),
	(9994),
	(9995),
	(9996),
	(9997),
	(9998),
	(9999),
	(10000),
	(10001),
	(10002),
	(10003),
	(10004),
	(10005),
	(10006),
	(10007),
	(10008),
	(10009),
	(10010),
	(10011),
	(10012),
	(10013),
	(10014),
	(10015),
	(10016),
	(10017),
	(10018),
	(10019),
	(10020),
	(10021),
	(10022),
	(10023),
	(10024),
	(10025),
	(10026),
	(10027),
	(10028),
	(10029),
	(10030),
	(10031),
	(10032),
	(10033),
	(10034),
	(10035),
	(10036),
	(10037),
	(10038),
	(10039),
	(10040),
	(10041),
	(10042),
	(10043),
	(10044),
	(10045),
	(10046),
	(10047),
	(10048),
	(10049),
	(10050),
	(10051),
	(10052),
	(10053),
	(10054),
	(10055),
	(10056),
	(10057),
	(10058),
	(10059),
	(10060),
	(10061),
	(10062),
	(10063),
	(10064),
	(10065),
	(10066),
	(10067),
	(10068),
	(10069),
	(10070),
	(10071),
	(10072),
	(10073),
	(10074),
	(10075),
	(10076),
	(10077),
	(10078),
	(10079),
	(10080),
	(10081),
	(10082),
	(10083),
	(10084),
	(10085),
	(10086),
	(10087),
	(10088),
	(10089),
	(10090),
	(10091),
	(10092),
	(10093),
	(10094),
	(10095),
	(10096),
	(10097),
	(10098),
	(10099),
	(10100),
	(10101),
	(10102),
	(10103),
	(10104),
	(10105),
	(10106),
	(10107),
	(10108),
	(10109),
	(10110),
	(10111),
	(10112),
	(10113),
	(10114),
	(10115),
	(10116),
	(10117),
	(10118),
	(10119),
	(10120),
	(10121),
	(10122),
	(10123),
	(10124),
	(10125),
	(10126),
	(10127),
	(10128),
	(10129),
	(10130),
	(10131),
	(10132),
	(10133),
	(10134),
	(10135),
	(10136),
	(10137),
	(10138),
	(10139),
	(10140),
	(10141),
	(10142),
	(10143),
	(10144),
	(10145),
	(10146),
	(10147),
	(10148),
	(10149),
	(10150),
	(10151),
	(10152),
	(10153),
	(10154),
	(10155),
	(10156),
	(10157),
	(10158),
	(10159),
	(10160),
	(10161),
	(10162),
	(10163),
	(10164),
	(10165),
	(10166),
	(10167),
	(10168),
	(10169),
	(10170),
	(10171),
	(10172),
	(10173),
	(10174),
	(10175),
	(10176),
	(10177),
	(10178),
	(10179),
	(10180),
	(10181),
	(10182),
	(10183),
	(10184),
	(10185),
	(10186),
	(10187),
	(10188),
	(10189),
	(10190),
	(10191),
	(10192),
	(10193),
	(10194),
	(10195),
	(10196),
	(10197),
	(10198),
	(10199),
	(10200),
	(10201),
	(10202),
	(10203),
	(10204),
	(10205),
	(10206),
	(10207),
	(10208),
	(10209),
	(10210),
	(10211),
	(10212),
	(10213),
	(10214),
	(10215),
	(10216),
	(10217),
	(10218),
	(10219),
	(10220),
	(10221),
	(10222),
	(10223),
	(10224),
	(10225),
	(10226),
	(10227),
	(10228),
	(10229),
	(10230),
	(10231),
	(10232),
	(10233),
	(10234),
	(10235),
	(10236),
	(10237),
	(10238),
	(10239),
	(10240),
	(10241),
	(10242),
	(10243),
	(10244),
	(10245),
	(10246),
	(10247),
	(10248),
	(10249),
	(10250),
	(10251),
	(10252),
	(10253),
	(10254),
	(10255),
	(10256),
	(10257),
	(10258),
	(10259),
	(10260),
	(10261),
	(10262),
	(10263),
	(10264),
	(10265),
	(10266),
	(10267),
	(10268),
	(10269),
	(10270),
	(10271),
	(10272),
	(10273),
	(10274),
	(10275),
	(10276),
	(10277),
	(10278),
	(10279),
	(10280),
	(10281),
	(10282),
	(10283),
	(10284),
	(10285),
	(10286),
	(10287),
	(10288),
	(10289),
	(10290),
	(10291),
	(10292),
	(10293),
	(10294),
	(10295),
	(10296),
	(10297),
	(10298),
	(10299),
	(10300),
	(10301),
	(10302),
	(10303),
	(10304),
	(10305),
	(10306),
	(10307),
	(10308),
	(10309),
	(10310),
	(10311),
	(10312),
	(10313),
	(10314),
	(10315),
	(10316),
	(10317),
	(10318),
	(10319),
	(10320),
	(10321),
	(10322),
	(10323),
	(10324),
	(10325),
	(10326),
	(10327),
	(10328),
	(10329),
	(10330),
	(10331),
	(10332),
	(10333),
	(10334),
	(10335),
	(10336),
	(10337),
	(10338),
	(10339),
	(10340),
	(10341),
	(10342),
	(10343),
	(10344),
	(10345),
	(10346),
	(10347),
	(10348),
	(10349),
	(10350),
	(10351),
	(10352),
	(10353),
	(10354),
	(10355),
	(10356),
	(10357),
	(10358),
	(10359),
	(10360),
	(10361),
	(10362),
	(10363),
	(10364),
	(10365),
	(10366),
	(10367),
	(10368),
	(10369),
	(10370),
	(10371),
	(10372),
	(10373),
	(10374),
	(10375),
	(10376),
	(10377),
	(10378),
	(10379),
	(10380),
	(10381),
	(10382),
	(10383),
	(10384),
	(10385),
	(10386),
	(10387),
	(10388),
	(10389),
	(10390),
	(10391),
	(10392),
	(10393),
	(10394),
	(10395),
	(10396),
	(10397),
	(10398),
	(10399),
	(10400),
	(10401),
	(10402),
	(10403),
	(10404),
	(10405),
	(10406),
	(10407),
	(10408),
	(10409),
	(10410),
	(10411),
	(10412),
	(10413),
	(10414),
	(10415),
	(10416),
	(10417),
	(10418),
	(10419),
	(10420),
	(10421),
	(10422),
	(10423),
	(10424),
	(10425),
	(10426),
	(10427),
	(10428),
	(10429),
	(10430),
	(10431),
	(10432),
	(10433),
	(10434),
	(10435),
	(10436),
	(10437),
	(10438),
	(10439),
	(10440),
	(10441),
	(10442),
	(10443),
	(10444),
	(10445),
	(10446),
	(10447),
	(10448),
	(10449),
	(10450),
	(10451),
	(10452),
	(10453),
	(10454),
	(10455),
	(10456),
	(10457),
	(10458),
	(10459),
	(10460),
	(10461),
	(10462),
	(10463),
	(10464),
	(10465),
	(10466),
	(10467),
	(10468),
	(10469),
	(10470),
	(10471),
	(10472),
	(10473),
	(10474),
	(10475),
	(10476),
	(10477),
	(10478),
	(10479),
	(10480),
	(10481),
	(10482),
	(10483),
	(10484),
	(10485),
	(10486),
	(10487),
	(10488),
	(10489),
	(10490),
	(10491),
	(10492),
	(10493),
	(10494),
	(10495),
	(10496),
	(10497),
	(10498),
	(10499),
	(10500),
	(10501),
	(10502),
	(10503),
	(10504),
	(10505),
	(10506),
	(10507),
	(10508),
	(10509),
	(10510),
	(10511),
	(10512),
	(10513),
	(10514),
	(10515),
	(10516),
	(10517),
	(10518),
	(10519),
	(10520),
	(10521),
	(10522),
	(10523),
	(10524),
	(10525),
	(10526),
	(10527),
	(10528),
	(10529),
	(10530),
	(10531),
	(10532),
	(10533),
	(10534),
	(10535),
	(10536),
	(10537),
	(10538),
	(10539),
	(10540),
	(10541),
	(10542),
	(10543),
	(10544),
	(10545),
	(10546),
	(10547),
	(10548),
	(10549),
	(10550),
	(10551),
	(10552),
	(10553),
	(10554),
	(10555),
	(10556),
	(10557),
	(10558),
	(10559),
	(10560),
	(10561),
	(10562),
	(10563),
	(10564),
	(10565),
	(10566),
	(10567),
	(10568),
	(10569),
	(10570),
	(10571),
	(10572),
	(10573),
	(10574),
	(10575),
	(10576),
	(10577),
	(10578),
	(10579),
	(10580),
	(10581),
	(10582),
	(10583),
	(10584),
	(10585),
	(10586),
	(10587),
	(10588),
	(10589),
	(10590),
	(10591),
	(10592),
	(10593),
	(10594),
	(10595),
	(10596),
	(10597),
	(10598),
	(10599),
	(10600),
	(10601),
	(10602),
	(10603),
	(10604),
	(10605),
	(10606),
	(10607),
	(10608),
	(10609),
	(10610),
	(10611),
	(10612),
	(10613),
	(10614),
	(10615),
	(10616),
	(10617),
	(10618),
	(10619),
	(10620),
	(10621),
	(10622),
	(10623),
	(10624),
	(10625),
	(10626),
	(10627),
	(10628),
	(10629),
	(10630),
	(10631),
	(10632),
	(10633),
	(10634),
	(10635),
	(10636),
	(10637),
	(10638),
	(10639),
	(10640),
	(10641),
	(10642),
	(10643),
	(10644),
	(10645),
	(10646),
	(10647),
	(10648),
	(10649),
	(10650),
	(10651),
	(10652),
	(10653),
	(10654),
	(10655),
	(10656),
	(10657),
	(10658),
	(10659),
	(10660),
	(10661),
	(10662),
	(10663),
	(10664),
	(10665),
	(10666),
	(10667),
	(10668),
	(10669),
	(10670),
	(10671),
	(10672),
	(10673),
	(10674),
	(10675),
	(10676),
	(10677),
	(10678),
	(10679),
	(10680),
	(10681),
	(10682),
	(10683),
	(10684),
	(10685),
	(10686),
	(10687),
	(10688),
	(10689),
	(10690),
	(10691),
	(10692),
	(10693),
	(10694),
	(10695),
	(10696),
	(10697),
	(10698),
	(10699),
	(10700),
	(10701),
	(10702),
	(10703),
	(10704),
	(10705),
	(10706),
	(10707),
	(10708),
	(10709),
	(10710),
	(10711),
	(10712),
	(10713),
	(10714),
	(10715),
	(10716),
	(10717),
	(10718),
	(10719),
	(10720),
	(10721),
	(10722),
	(10723),
	(10724),
	(10725),
	(10726),
	(10727),
	(10728),
	(10729),
	(10730),
	(10731),
	(10732),
	(10733),
	(10734),
	(10735),
	(10736),
	(10737),
	(10738),
	(10739),
	(10740),
	(10741),
	(10742),
	(10743),
	(10744),
	(10745),
	(10746),
	(10747),
	(10748),
	(10749),
	(10750),
	(10751),
	(10752),
	(10753),
	(10754),
	(10755),
	(10756),
	(10757),
	(10758),
	(10759),
	(10760),
	(10761),
	(10762),
	(10763),
	(10764),
	(10765),
	(10766),
	(10767),
	(10768),
	(10769),
	(10770),
	(10771),
	(10772),
	(10773),
	(10774),
	(10775),
	(10776),
	(10777),
	(10778),
	(10779),
	(10780),
	(10781),
	(10782),
	(10783),
	(10784),
	(10785),
	(10786),
	(10787),
	(10788),
	(10789),
	(10790),
	(10791),
	(10792),
	(10793),
	(10794),
	(10795),
	(10796),
	(10797),
	(10798),
	(10799),
	(10800),
	(10801),
	(10802),
	(10803),
	(10804),
	(10805),
	(10806),
	(10807),
	(10808),
	(10809),
	(10810),
	(10811),
	(10812),
	(10813),
	(10814),
	(10815),
	(10816),
	(10817),
	(10818),
	(10819),
	(10820),
	(10821),
	(10822),
	(10823),
	(10824),
	(10825),
	(10826),
	(10827),
	(10828),
	(10829),
	(10830),
	(10831),
	(10832),
	(10833),
	(10834),
	(10835),
	(10836),
	(10837),
	(10838),
	(10839),
	(10840),
	(10841),
	(10842),
	(10843),
	(10844),
	(10845),
	(10846),
	(10847),
	(10848),
	(10849),
	(10850),
	(10851),
	(10852),
	(10853),
	(10854),
	(10855),
	(10856),
	(10857),
	(10858),
	(10859),
	(10860),
	(10861),
	(10862),
	(10863),
	(10864),
	(10865),
	(10866),
	(10867),
	(10868),
	(10869),
	(10870),
	(10871),
	(10872),
	(10873),
	(10874),
	(10875),
	(10876),
	(10877),
	(10878),
	(10879),
	(10880),
	(10881),
	(10882),
	(10883),
	(10884),
	(10885),
	(10886),
	(10887),
	(10888),
	(10889),
	(10890),
	(10891),
	(10892),
	(10893),
	(10894),
	(10895),
	(10896),
	(10897),
	(10898),
	(10899),
	(10900),
	(10901),
	(10902),
	(10903),
	(10904),
	(10905),
	(10906),
	(10907),
	(10908),
	(10909),
	(10910),
	(10911),
	(10912),
	(10913),
	(10914),
	(10915),
	(10916),
	(10917),
	(10918),
	(10919),
	(10920),
	(10921),
	(10922),
	(10923),
	(10924),
	(10925),
	(10926),
	(10927),
	(10928),
	(10929),
	(10930),
	(10931),
	(10932),
	(10933),
	(10934),
	(10935),
	(10936),
	(10937),
	(10938),
	(10939),
	(10940),
	(10941),
	(10942),
	(10943),
	(10944),
	(10945),
	(10946),
	(10947),
	(10948),
	(10949),
	(10950),
	(10951),
	(10952),
	(10953),
	(10954),
	(10955),
	(10956),
	(10957),
	(10958),
	(10959),
	(10960),
	(10961),
	(10962),
	(10963),
	(10964),
	(10965),
	(10966),
	(10967),
	(10968),
	(10969),
	(10970),
	(10971),
	(10972),
	(10973),
	(10974),
	(10975),
	(10976),
	(10977),
	(10978),
	(10979),
	(10980),
	(10981),
	(10982),
	(10983),
	(10984),
	(10985),
	(10986),
	(10987),
	(10988),
	(10989),
	(10990),
	(10991),
	(10992),
	(10993),
	(10994),
	(10995),
	(10996),
	(10997),
	(10998),
	(10999),
	(11000),
	(11001),
	(11002),
	(11003),
	(11004),
	(11005),
	(11006),
	(11007),
	(11008),
	(11009),
	(11010),
	(11011),
	(11012),
	(11013),
	(11014),
	(11015),
	(11016),
	(11017),
	(11018),
	(11019),
	(11020),
	(11021),
	(11022),
	(11023),
	(11024),
	(11025),
	(11026),
	(11027),
	(11028),
	(11029),
	(11030),
	(11031),
	(11032),
	(11033),
	(11034),
	(11035),
	(11036),
	(11037),
	(11038),
	(11039),
	(11040),
	(11041),
	(11042),
	(11043),
	(11044),
	(11045),
	(11046),
	(11047),
	(11048),
	(11049),
	(11050),
	(11051),
	(11052),
	(11053),
	(11054),
	(11055),
	(11056),
	(11057),
	(11058),
	(11059),
	(11060),
	(11061),
	(11062),
	(11063),
	(11064),
	(11065),
	(11066),
	(11067),
	(11068),
	(11069),
	(11070),
	(11071),
	(11072),
	(11073),
	(11074),
	(11075),
	(11076),
	(11077),
	(11078),
	(11079),
	(11080),
	(11081),
	(11082),
	(11083),
	(11084),
	(11085),
	(11086),
	(11087),
	(11088),
	(11089),
	(11090),
	(11091),
	(11092),
	(11093),
	(11094),
	(11095),
	(11096),
	(11097),
	(11098),
	(11099),
	(11100),
	(11101),
	(11102),
	(11103),
	(11104),
	(11105),
	(11106),
	(11107),
	(11108),
	(11109),
	(11110),
	(11111),
	(11112),
	(11113),
	(11114),
	(11115),
	(11116),
	(11117),
	(11118),
	(11119),
	(11120),
	(11121),
	(11122),
	(11123),
	(11124),
	(11125),
	(11126),
	(11127),
	(11128),
	(11129),
	(11130),
	(11131),
	(11132),
	(11133),
	(11134),
	(11135),
	(11136),
	(11137),
	(11138),
	(11139),
	(11140),
	(11141),
	(11142),
	(11143),
	(11144),
	(11145),
	(11146),
	(11147),
	(11148),
	(11149),
	(11150),
	(11151),
	(11152),
	(11153),
	(11154),
	(11155),
	(11156),
	(11157),
	(11158),
	(11159),
	(11160),
	(11161),
	(11162),
	(11163),
	(11164),
	(11165),
	(11166),
	(11167),
	(11168),
	(11169),
	(11170),
	(11171),
	(11172),
	(11173),
	(11174),
	(11175),
	(11176),
	(11177),
	(11178),
	(11179),
	(11180),
	(11181),
	(11182),
	(11183),
	(11184),
	(11185),
	(11186),
	(11187),
	(11188),
	(11189),
	(11190),
	(11191),
	(11192),
	(11193),
	(11194),
	(11195),
	(11196),
	(11197),
	(11198),
	(11199),
	(11200),
	(11201),
	(11202),
	(11203),
	(11204),
	(11205),
	(11206),
	(11207),
	(11208),
	(11209),
	(11210),
	(11211),
	(11212),
	(11213),
	(11214),
	(11215),
	(11216),
	(11217),
	(11218),
	(11219),
	(11220),
	(11221),
	(11222),
	(11223),
	(11224),
	(11225),
	(11226),
	(11227),
	(11228),
	(11229),
	(11230),
	(11231),
	(11232),
	(11233),
	(11234),
	(11235),
	(11236),
	(11237),
	(11238),
	(11239),
	(11240),
	(11241),
	(11242),
	(11243),
	(11244),
	(11245),
	(11246),
	(11247),
	(11248),
	(11249),
	(11250),
	(11251),
	(11252),
	(11253),
	(11254),
	(11255),
	(11256),
	(11257),
	(11258),
	(11259),
	(11260),
	(11261),
	(11262),
	(11263),
	(11264),
	(11265),
	(11266),
	(11267),
	(11268),
	(11269),
	(11270),
	(11271),
	(11272),
	(11273),
	(11274),
	(11275),
	(11276),
	(11277),
	(11278),
	(11279),
	(11280),
	(11281),
	(11282),
	(11283),
	(11284),
	(11285),
	(11286),
	(11287),
	(11288),
	(11289),
	(11290),
	(11291),
	(11292),
	(11293),
	(11294),
	(11295),
	(11296),
	(11297),
	(11298),
	(11299),
	(11300),
	(11301),
	(11302),
	(11303),
	(11304),
	(11305),
	(11306),
	(11307),
	(11308),
	(11309),
	(11310),
	(11311),
	(11312),
	(11313),
	(11314),
	(11315),
	(11316),
	(11317),
	(11318),
	(11319),
	(11320),
	(11321),
	(11322),
	(11323),
	(11324),
	(11325),
	(11326),
	(11327),
	(11328),
	(11329),
	(11330),
	(11331),
	(11332),
	(11333),
	(11334),
	(11335),
	(11336),
	(11337),
	(11338),
	(11339),
	(11340),
	(11341),
	(11342),
	(11343),
	(11344),
	(11345),
	(11346),
	(11347),
	(11348),
	(11349),
	(11350),
	(11351),
	(11352),
	(11353),
	(11354),
	(11355),
	(11356),
	(11357),
	(11358),
	(11359),
	(11360),
	(11361),
	(11362),
	(11363),
	(11364),
	(11365),
	(11366),
	(11367),
	(11368),
	(11369),
	(11370),
	(11371),
	(11372),
	(11373),
	(11374),
	(11375),
	(11376),
	(11377),
	(11378),
	(11379),
	(11380),
	(11381),
	(11382),
	(11383),
	(11384),
	(11385),
	(11386),
	(11387),
	(11388),
	(11389),
	(11390),
	(11391),
	(11392),
	(11393),
	(11394),
	(11395),
	(11396),
	(11397),
	(11398),
	(11399),
	(11400),
	(11401),
	(11402),
	(11403),
	(11404),
	(11405),
	(11406),
	(11407),
	(11408),
	(11409),
	(11410),
	(11411),
	(11412),
	(11413),
	(11414),
	(11415),
	(11416),
	(11417),
	(11418),
	(11419),
	(11420),
	(11421),
	(11422),
	(11423),
	(11424),
	(11425),
	(11426),
	(11427),
	(11428),
	(11429),
	(11430),
	(11431),
	(11432),
	(11433),
	(11434),
	(11435),
	(11436),
	(11437),
	(11438),
	(11439),
	(11440),
	(11441),
	(11442),
	(11443),
	(11444),
	(11445),
	(11446),
	(11447),
	(11448),
	(11449),
	(11450),
	(11451),
	(11452),
	(11453),
	(11454),
	(11455),
	(11456),
	(11457),
	(11458),
	(11459),
	(11460),
	(11461),
	(11462),
	(11463),
	(11464),
	(11465),
	(11466),
	(11467),
	(11468),
	(11469),
	(11470),
	(11471),
	(11472),
	(11473),
	(11474),
	(11475),
	(11476),
	(11477),
	(11478),
	(11479),
	(11480),
	(11481),
	(11482),
	(11483),
	(11484),
	(11485),
	(11486),
	(11487),
	(11488),
	(11489),
	(11490),
	(11491),
	(11492),
	(11493),
	(11494),
	(11495),
	(11496),
	(11497),
	(11498),
	(11499),
	(11500),
	(11501),
	(11502),
	(11503),
	(11504),
	(11505),
	(11506),
	(11507),
	(11508),
	(11509),
	(11510),
	(11511),
	(11512),
	(11513),
	(11514),
	(11515),
	(11516),
	(11517),
	(11518),
	(11519),
	(11520),
	(11521),
	(11522),
	(11523),
	(11524),
	(11525),
	(11526),
	(11527),
	(11528),
	(11529),
	(11530),
	(11531),
	(11532),
	(11533),
	(11534),
	(11535),
	(11536),
	(11537),
	(11538),
	(11539),
	(11540),
	(11541),
	(11542),
	(11543),
	(11544),
	(11545),
	(11546),
	(11547),
	(11548),
	(11549),
	(11550),
	(11551),
	(11552),
	(11553),
	(11554),
	(11555),
	(11556),
	(11557),
	(11558),
	(11559),
	(11560),
	(11561),
	(11562),
	(11563),
	(11564),
	(11565),
	(11566),
	(11567),
	(11568),
	(11569),
	(11570),
	(11571),
	(11572),
	(11573),
	(11574),
	(11575),
	(11576),
	(11577),
	(11578),
	(11579),
	(11580),
	(11581),
	(11582),
	(11583),
	(11584),
	(11585),
	(11586),
	(11587),
	(11588),
	(11589),
	(11590),
	(11591),
	(11592),
	(11593),
	(11594),
	(11595),
	(11596),
	(11597),
	(11598),
	(11599),
	(11600),
	(11601),
	(11602),
	(11603),
	(11604),
	(11605),
	(11606),
	(11607),
	(11608),
	(11609),
	(11610),
	(11611),
	(11612),
	(11613),
	(11614),
	(11615),
	(11616),
	(11617),
	(11618),
	(11619),
	(11620),
	(11621),
	(11622),
	(11623),
	(11624),
	(11625),
	(11626),
	(11627),
	(11628),
	(11629),
	(11630),
	(11631),
	(11632),
	(11633),
	(11634),
	(11635),
	(11636),
	(11637),
	(11638),
	(11639),
	(11640),
	(11641),
	(11642),
	(11643),
	(11644),
	(11645),
	(11646),
	(11647),
	(11648),
	(11649),
	(11650),
	(11651),
	(11652),
	(11653),
	(11654),
	(11655),
	(11656),
	(11657),
	(11658),
	(11659),
	(11660),
	(11661),
	(11662),
	(11663),
	(11664),
	(11665),
	(11666),
	(11667),
	(11668),
	(11669),
	(11670),
	(11671),
	(11672),
	(11673),
	(11674),
	(11675),
	(11676),
	(11677),
	(11678),
	(11679),
	(11680),
	(11681),
	(11682),
	(11683),
	(11684),
	(11685),
	(11686),
	(11687),
	(11688),
	(11689),
	(11690),
	(11691),
	(11692),
	(11693),
	(11694),
	(11695),
	(11696),
	(11697),
	(11698),
	(11699),
	(11700),
	(11701),
	(11702),
	(11703),
	(11704),
	(11705),
	(11706),
	(11707),
	(11708),
	(11709),
	(11710),
	(11711),
	(11712),
	(11713),
	(11714),
	(11715),
	(11716),
	(11717),
	(11718),
	(11719),
	(11720),
	(11721),
	(11722),
	(11723),
	(11724),
	(11725),
	(11726),
	(11727),
	(11728),
	(11729),
	(11730),
	(11731),
	(11732),
	(11733),
	(11734),
	(11735),
	(11736),
	(11737),
	(11738),
	(11739),
	(11740),
	(11741),
	(11742),
	(11743),
	(11744),
	(11745),
	(11746),
	(11747),
	(11748),
	(11749),
	(11750),
	(11751),
	(11752),
	(11753),
	(11754),
	(11755),
	(11756),
	(11757),
	(11758),
	(11759),
	(11760),
	(11761),
	(11762),
	(11763),
	(11764),
	(11765),
	(11766),
	(11767),
	(11768),
	(11769),
	(11770),
	(11771),
	(11772),
	(11773),
	(11774),
	(11775),
	(11776),
	(11777),
	(11778),
	(11779),
	(11780),
	(11781),
	(11782),
	(11783),
	(11784),
	(11785),
	(11786),
	(11787),
	(11788),
	(11789),
	(11790),
	(11791),
	(11792),
	(11793),
	(11794),
	(11795),
	(11796),
	(11797),
	(11798),
	(11799),
	(11800),
	(11801),
	(11802),
	(11803),
	(11804),
	(11805),
	(11806),
	(11807),
	(11808),
	(11809),
	(11810),
	(11811),
	(11812),
	(11813),
	(11814),
	(11815),
	(11816),
	(11817),
	(11818),
	(11819),
	(11820),
	(11821),
	(11822),
	(11823),
	(11824),
	(11825),
	(11826),
	(11827),
	(11828),
	(11829),
	(11830),
	(11831),
	(11832),
	(11833),
	(11834),
	(11835),
	(11836),
	(11837),
	(11838),
	(11839),
	(11840),
	(11841),
	(11842),
	(11843),
	(11844),
	(11845),
	(11846),
	(11847),
	(11848),
	(11849),
	(11850),
	(11851),
	(11852),
	(11853),
	(11854),
	(11855),
	(11856),
	(11857),
	(11858),
	(11859),
	(11860),
	(11861),
	(11862),
	(11863),
	(11864),
	(11865),
	(11866),
	(11867),
	(11868),
	(11869),
	(11870),
	(11871),
	(11872),
	(11873),
	(11874),
	(11875),
	(11876),
	(11877),
	(11878),
	(11879),
	(11880),
	(11881),
	(11882),
	(11883),
	(11884),
	(11885),
	(11886),
	(11887),
	(11888),
	(11889),
	(11890),
	(11891),
	(11892),
	(11893),
	(11894),
	(11895),
	(11896),
	(11897),
	(11898),
	(11899),
	(11900),
	(11901),
	(11902),
	(11903),
	(11904),
	(11905),
	(11906),
	(11907),
	(11908),
	(11909),
	(11910),
	(11911),
	(11912),
	(11913),
	(11914),
	(11915),
	(11916),
	(11917),
	(11918),
	(11919),
	(11920),
	(11921),
	(11922),
	(11923),
	(11924),
	(11925),
	(11926),
	(11927),
	(11928),
	(11929),
	(11930),
	(11931),
	(11932),
	(11933),
	(11934),
	(11935),
	(11936),
	(11937),
	(11938),
	(11939),
	(11940),
	(11941),
	(11942),
	(11943),
	(11944),
	(11945),
	(11946),
	(11947),
	(11948),
	(11949),
	(11950),
	(11951),
	(11952),
	(11953),
	(11954),
	(11955),
	(11956),
	(11957),
	(11958),
	(11959),
	(11960),
	(11961),
	(11962),
	(11963),
	(11964),
	(11965),
	(11966),
	(11967),
	(11968),
	(11969),
	(11970),
	(11971),
	(11972),
	(11973),
	(11974),
	(11975),
	(11976),
	(11977),
	(11978),
	(11979),
	(11980),
	(11981),
	(11982),
	(11983),
	(11984),
	(11985),
	(11986),
	(11987),
	(11988),
	(11989),
	(11990),
	(11991),
	(11992),
	(11993),
	(11994),
	(11995),
	(11996),
	(11997),
	(11998),
	(11999),
	(12000),
	(12001),
	(12002),
	(12003),
	(12004),
	(12005),
	(12006),
	(12007),
	(12008),
	(12009),
	(12010),
	(12011),
	(12012),
	(12013),
	(12014),
	(12015),
	(12016),
	(12017),
	(12018),
	(12019),
	(12020),
	(12021),
	(12022),
	(12023),
	(12024),
	(12025),
	(12026),
	(12027),
	(12028),
	(12029),
	(12030),
	(12031),
	(12032),
	(12033),
	(12034),
	(12035),
	(12036),
	(12037),
	(12038),
	(12039),
	(12040),
	(12041),
	(12042),
	(12043),
	(12044),
	(12045),
	(12046),
	(12047),
	(12048),
	(12049),
	(12050),
	(12051),
	(12052),
	(12053),
	(12054),
	(12055),
	(12056),
	(12057),
	(12058),
	(12059),
	(12060),
	(12061),
	(12062),
	(12063),
	(12064),
	(12065),
	(12066),
	(12067),
	(12068),
	(12069),
	(12070),
	(12071),
	(12072),
	(12073),
	(12074),
	(12075),
	(12076),
	(12077),
	(12078),
	(12079),
	(12080),
	(12081),
	(12082),
	(12083),
	(12084),
	(12085),
	(12086),
	(12087),
	(12088),
	(12089),
	(12090),
	(12091),
	(12092),
	(12093),
	(12094),
	(12095),
	(12096),
	(12097),
	(12098),
	(12099),
	(12100),
	(12101),
	(12102),
	(12103),
	(12104),
	(12105),
	(12106),
	(12107),
	(12108),
	(12109),
	(12110),
	(12111),
	(12112),
	(12113),
	(12114),
	(12115),
	(12116),
	(12117),
	(12118),
	(12119),
	(12120),
	(12121),
	(12122),
	(12123),
	(12124),
	(12125),
	(12126),
	(12127),
	(12128),
	(12129),
	(12130),
	(12131),
	(12132),
	(12133),
	(12134),
	(12135),
	(12136),
	(12137),
	(12138),
	(12139),
	(12140),
	(12141),
	(12142),
	(12143),
	(12144),
	(12145),
	(12146),
	(12147),
	(12148),
	(12149),
	(12150),
	(12151),
	(12152),
	(12153),
	(12154),
	(12155),
	(12156),
	(12157),
	(12158),
	(12159),
	(12160),
	(12161),
	(12162),
	(12163),
	(12164),
	(12165),
	(12166),
	(12167),
	(12168),
	(12169),
	(12170),
	(12171),
	(12172),
	(12173),
	(12174),
	(12175),
	(12176),
	(12177),
	(12178),
	(12179),
	(12180),
	(12181),
	(12182),
	(12183),
	(12184),
	(12185),
	(12186),
	(12187),
	(12188),
	(12189),
	(12190),
	(12191),
	(12192),
	(12193),
	(12194),
	(12195),
	(12196),
	(12197),
	(12198),
	(12199),
	(12200),
	(12201),
	(12202),
	(12203),
	(12204),
	(12205),
	(12206),
	(12207),
	(12208),
	(12209),
	(12210),
	(12211),
	(12212),
	(12213),
	(12214),
	(12215),
	(12216),
	(12217),
	(12218),
	(12219),
	(12220),
	(12221),
	(12222),
	(12223),
	(12224),
	(12225),
	(12226),
	(12227),
	(12228),
	(12229),
	(12230),
	(12231),
	(12232),
	(12233),
	(12234),
	(12235),
	(12236),
	(12237),
	(12238),
	(12239),
	(12240),
	(12241),
	(12242),
	(12243),
	(12244),
	(12245),
	(12246),
	(12247),
	(12248),
	(12249),
	(12250),
	(12251),
	(12252),
	(12253),
	(12254),
	(12255),
	(12256),
	(12257),
	(12258),
	(12259),
	(12260),
	(12261),
	(12262),
	(12263),
	(12264),
	(12265),
	(12266),
	(12267),
	(12268),
	(12269),
	(12270),
	(12271),
	(12272),
	(12273),
	(12274),
	(12275),
	(12276),
	(12277),
	(12278),
	(12279),
	(12280),
	(12281),
	(12282),
	(12283),
	(12284),
	(12285),
	(12286),
	(12287),
	(12288),
	(12289),
	(12290),
	(12291),
	(12292),
	(12293),
	(12294),
	(12295),
	(12296),
	(12297),
	(12298),
	(12299),
	(12300),
	(12301),
	(12302),
	(12303),
	(12304),
	(12305),
	(12306),
	(12307),
	(12308),
	(12309),
	(12310),
	(12311),
	(12312),
	(12313),
	(12314),
	(12315),
	(12316),
	(12317),
	(12318),
	(12319),
	(12320),
	(12321),
	(12322),
	(12323),
	(12324),
	(12325),
	(12326),
	(12327),
	(12328),
	(12329),
	(12330),
	(12331),
	(12332),
	(12333),
	(12334),
	(12335),
	(12336),
	(12337),
	(12338),
	(12339),
	(12340),
	(12341),
	(12342),
	(12343),
	(12344),
	(12345),
	(12346),
	(12347),
	(12348),
	(12349),
	(12350),
	(12351),
	(12352),
	(12353),
	(12354),
	(12355),
	(12356),
	(12357),
	(12358),
	(12359),
	(12360),
	(12361),
	(12362),
	(12363),
	(12364),
	(12365),
	(12366),
	(12367),
	(12368),
	(12369),
	(12370),
	(12371),
	(12372),
	(12373),
	(12374),
	(12375),
	(12376),
	(12377),
	(12378),
	(12379),
	(12380),
	(12381),
	(12382),
	(12383),
	(12384),
	(12385),
	(12386),
	(12387),
	(12388),
	(12389),
	(12390),
	(12391),
	(12392),
	(12393),
	(12394),
	(12395),
	(12396),
	(12397),
	(12398),
	(12399),
	(12400),
	(12401),
	(12402),
	(12403),
	(12404),
	(12405),
	(12406),
	(12407),
	(12408),
	(12409),
	(12410),
	(12411),
	(12412),
	(12413),
	(12414),
	(12415),
	(12416),
	(12417),
	(12418),
	(12419),
	(12420),
	(12421),
	(12422),
	(12423),
	(12424),
	(12425),
	(12426),
	(12427),
	(12428),
	(12429),
	(12430),
	(12431),
	(12432),
	(12433),
	(12434),
	(12435),
	(12436),
	(12437),
	(12438),
	(12439),
	(12440),
	(12441),
	(12442),
	(12443),
	(12444),
	(12445),
	(12446),
	(12447),
	(12448),
	(12449),
	(12450),
	(12451),
	(12452),
	(12453),
	(12454),
	(12455),
	(12456),
	(12457),
	(12458),
	(12459),
	(12460),
	(12461),
	(12462),
	(12463),
	(12464),
	(12465),
	(12466),
	(12467),
	(12468),
	(12469),
	(12470),
	(12471),
	(12472),
	(12473),
	(12474),
	(12475),
	(12476),
	(12477),
	(12478),
	(12479),
	(12480),
	(12481),
	(12482),
	(12483),
	(12484),
	(12485),
	(12486),
	(12487),
	(12488),
	(12489),
	(12490),
	(12491),
	(12492),
	(12493),
	(12494),
	(12495),
	(12496),
	(12497),
	(12498),
	(12499),
	(12500),
	(12501),
	(12502),
	(12503),
	(12504),
	(12505),
	(12506),
	(12507),
	(12508),
	(12509),
	(12510),
	(12511),
	(12512),
	(12513),
	(12514),
	(12515),
	(12516),
	(12517),
	(12518),
	(12519),
	(12520),
	(12521),
	(12522),
	(12523),
	(12524),
	(12525),
	(12526),
	(12527),
	(12528),
	(12529),
	(12530),
	(12531),
	(12532),
	(12533),
	(12534),
	(12535),
	(12536),
	(12537),
	(12538),
	(12539),
	(12540),
	(12541),
	(12542),
	(12543),
	(12544),
	(12545),
	(12546),
	(12547),
	(12548),
	(12549),
	(12550),
	(12551),
	(12552),
	(12553),
	(12554),
	(12555),
	(12556),
	(12557),
	(12558),
	(12559),
	(12560),
	(12561),
	(12562),
	(12563),
	(12564),
	(12565),
	(12566),
	(12567),
	(12568),
	(12569),
	(12570),
	(12571),
	(12572),
	(12573),
	(12574),
	(12575),
	(12576),
	(12577),
	(12578),
	(12579),
	(12580),
	(12581),
	(12582),
	(12583),
	(12584),
	(12585),
	(12586),
	(12587),
	(12588),
	(12589),
	(12590),
	(12591),
	(12592),
	(12593),
	(12594),
	(12595),
	(12596),
	(12597),
	(12598),
	(12599),
	(12600),
	(12601),
	(12602),
	(12603),
	(12604),
	(12605),
	(12606),
	(12607),
	(12608),
	(12609),
	(12610),
	(12611),
	(12612),
	(12613),
	(12614),
	(12615),
	(12616),
	(12617),
	(12618),
	(12619),
	(12620),
	(12621),
	(12622),
	(12623),
	(12624),
	(12625),
	(12626),
	(12627),
	(12628),
	(12629),
	(12630),
	(12631),
	(12632),
	(12633),
	(12634),
	(12635),
	(12636),
	(12637),
	(12638),
	(12639),
	(12640),
	(12641),
	(12642),
	(12643),
	(12644),
	(12645),
	(12646),
	(12647),
	(12648),
	(12649),
	(12650),
	(12651),
	(12652),
	(12653),
	(12654),
	(12655),
	(12656),
	(12657),
	(12658),
	(12659),
	(12660),
	(12661),
	(12662),
	(12663),
	(12664),
	(12665),
	(12666),
	(12667),
	(12668),
	(12669),
	(12670),
	(12671),
	(12672),
	(12673),
	(12674),
	(12675),
	(12676),
	(12677),
	(12678),
	(12679),
	(12680),
	(12681),
	(12682),
	(12683),
	(12684),
	(12685),
	(12686),
	(12687),
	(12688),
	(12689),
	(12690),
	(12691),
	(12692),
	(12693),
	(12694),
	(12695),
	(12696),
	(12697),
	(12698),
	(12699),
	(12700),
	(12701),
	(12702),
	(12703),
	(12704),
	(12705),
	(12706),
	(12707),
	(12708),
	(12709),
	(12710),
	(12711),
	(12712),
	(12713),
	(12714),
	(12715),
	(12716),
	(12717),
	(12718),
	(12719),
	(12720),
	(12721),
	(12722),
	(12723),
	(12724),
	(12725),
	(12726),
	(12727),
	(12728),
	(12729),
	(12730),
	(12731),
	(12732),
	(12733),
	(12734),
	(12735),
	(12736),
	(12737),
	(12738),
	(12739),
	(12740),
	(12741),
	(12742),
	(12743),
	(12744),
	(12745),
	(12746),
	(12747),
	(12748),
	(12749),
	(12750),
	(12751),
	(12752),
	(12753),
	(12754),
	(12755),
	(12756),
	(12757),
	(12758),
	(12759),
	(12760),
	(12761),
	(12762),
	(12763),
	(12764),
	(12765),
	(12766),
	(12767),
	(12768),
	(12769),
	(12770),
	(12771),
	(12772),
	(12773),
	(12774),
	(12775),
	(12776),
	(12777),
	(12778),
	(12779),
	(12780),
	(12781),
	(12782),
	(12783),
	(12784),
	(12785),
	(12786),
	(12787),
	(12788),
	(12789),
	(12790),
	(12791),
	(12792),
	(12793),
	(12794),
	(12795),
	(12796),
	(12797),
	(12798),
	(12799),
	(12800),
	(12801),
	(12802),
	(12803),
	(12804),
	(12805),
	(12806),
	(12807),
	(12808),
	(12809),
	(12810),
	(12811),
	(12812),
	(12813),
	(12814),
	(12815),
	(12816),
	(12817),
	(12818),
	(12819),
	(12820),
	(12821),
	(12822),
	(12823),
	(12824),
	(12825),
	(12826),
	(12827),
	(12828),
	(12829),
	(12830),
	(12831),
	(12832),
	(12833),
	(12834),
	(12835),
	(12836),
	(12837),
	(12838),
	(12839),
	(12840),
	(12841),
	(12842),
	(12843),
	(12844),
	(12845),
	(12846),
	(12847),
	(12848),
	(12849),
	(12850),
	(12851),
	(12852),
	(12853),
	(12854),
	(12855),
	(12856),
	(12857),
	(12858),
	(12859),
	(12860),
	(12861),
	(12862),
	(12863),
	(12864),
	(12865),
	(12866),
	(12867),
	(12868),
	(12869),
	(12870),
	(12871),
	(12872),
	(12873),
	(12874),
	(12875),
	(12876),
	(12877),
	(12878),
	(12879),
	(12880),
	(12881),
	(12882),
	(12883),
	(12884),
	(12885),
	(12886),
	(12887),
	(12888),
	(12889),
	(12890),
	(12891),
	(12892),
	(12893),
	(12894),
	(12895),
	(12896),
	(12897),
	(12898),
	(12899),
	(12900),
	(12901),
	(12902),
	(12903),
	(12904),
	(12905),
	(12906),
	(12907),
	(12908),
	(12909),
	(12910),
	(12911),
	(12912),
	(12913),
	(12914),
	(12915),
	(12916),
	(12917),
	(12918),
	(12919),
	(12920),
	(12921),
	(12922),
	(12923),
	(12924),
	(12925),
	(12926),
	(12927),
	(12928),
	(12929),
	(12930),
	(12931),
	(12932),
	(12933),
	(12934),
	(12935),
	(12936),
	(12937),
	(12938),
	(12939),
	(12940),
	(12941),
	(12942),
	(12943),
	(12944),
	(12945),
	(12946),
	(12947),
	(12948),
	(12949),
	(12950),
	(12951),
	(12952),
	(12953),
	(12954),
	(12955),
	(12956),
	(12957),
	(12958),
	(12959),
	(12960),
	(12961),
	(12962),
	(12963),
	(12964),
	(12965),
	(12966),
	(12967),
	(12968),
	(12969),
	(12970),
	(12971),
	(12972),
	(12973),
	(12974),
	(12975),
	(12976),
	(12977),
	(12978),
	(12979),
	(12980),
	(12981),
	(12982),
	(12983),
	(12984),
	(12985),
	(12986),
	(12987),
	(12988),
	(12989),
	(12990),
	(12991),
	(12992),
	(12993),
	(12994),
	(12995),
	(12996),
	(12997),
	(12998),
	(12999),
	(13000),
	(13001),
	(13002),
	(13003),
	(13004),
	(13005),
	(13006),
	(13007),
	(13008),
	(13009),
	(13010),
	(13011),
	(13012),
	(13013),
	(13014),
	(13015),
	(13016),
	(13017),
	(13018),
	(13019),
	(13020),
	(13021),
	(13022),
	(13023),
	(13024),
	(13025),
	(13026),
	(13027),
	(13028),
	(13029),
	(13030),
	(13031),
	(13032),
	(13033),
	(13034),
	(13035),
	(13036),
	(13037),
	(13038),
	(13039),
	(13040),
	(13041),
	(13042),
	(13043),
	(13044),
	(13045),
	(13046),
	(13047),
	(13048),
	(13049),
	(13050),
	(13051),
	(13052),
	(13053),
	(13054),
	(13055),
	(13056),
	(13057),
	(13058),
	(13059),
	(13060),
	(13061),
	(13062),
	(13063),
	(13064),
	(13065),
	(13066),
	(13067),
	(13068),
	(13069),
	(13070),
	(13071),
	(13072),
	(13073),
	(13074),
	(13075),
	(13076),
	(13077),
	(13078),
	(13079),
	(13080),
	(13081),
	(13082),
	(13083),
	(13084),
	(13085),
	(13086),
	(13087),
	(13088),
	(13089),
	(13090),
	(13091),
	(13092),
	(13093),
	(13094),
	(13095),
	(13096),
	(13097),
	(13098),
	(13099),
	(13100),
	(13101),
	(13102),
	(13103),
	(13104),
	(13105),
	(13106),
	(13107),
	(13108),
	(13109),
	(13110),
	(13111),
	(13112),
	(13113),
	(13114),
	(13115),
	(13116),
	(13117),
	(13118),
	(13119),
	(13120),
	(13121),
	(13122),
	(13123),
	(13124),
	(13125),
	(13126),
	(13127),
	(13128),
	(13129),
	(13130),
	(13131),
	(13132),
	(13133),
	(13134),
	(13135),
	(13136),
	(13137),
	(13138),
	(13139),
	(13140),
	(13141),
	(13142),
	(13143),
	(13144),
	(13145),
	(13146),
	(13147),
	(13148),
	(13149),
	(13150),
	(13151),
	(13152),
	(13153),
	(13154),
	(13155),
	(13156),
	(13157),
	(13158),
	(13159),
	(13160),
	(13161),
	(13162),
	(13163),
	(13164),
	(13165),
	(13166),
	(13167),
	(13168),
	(13169),
	(13170),
	(13171),
	(13172),
	(13173),
	(13174),
	(13175),
	(13176),
	(13177),
	(13178),
	(13179),
	(13180),
	(13181),
	(13182),
	(13183),
	(13184),
	(13185),
	(13186),
	(13187),
	(13188),
	(13189),
	(13190),
	(13191),
	(13192),
	(13193),
	(13194),
	(13195),
	(13196),
	(13197),
	(13198),
	(13199),
	(13200),
	(13201),
	(13202),
	(13203),
	(13204),
	(13205),
	(13206),
	(13207),
	(13208),
	(13209),
	(13210),
	(13211),
	(13212),
	(13213),
	(13214),
	(13215),
	(13216),
	(13217),
	(13218),
	(13219),
	(13220),
	(13221),
	(13222),
	(13223),
	(13224),
	(13225),
	(13226),
	(13227),
	(13228),
	(13229),
	(13230),
	(13231),
	(13232),
	(13233),
	(13234),
	(13235),
	(13236),
	(13237),
	(13238),
	(13239),
	(13240),
	(13241),
	(13242),
	(13243),
	(13244),
	(13245),
	(13246),
	(13247),
	(13248),
	(13249),
	(13250),
	(13251),
	(13252),
	(13253),
	(13254),
	(13255),
	(13256),
	(13257),
	(13258),
	(13259),
	(13260),
	(13261),
	(13262),
	(13263),
	(13264),
	(13265),
	(13266),
	(13267),
	(13268),
	(13269),
	(13270),
	(13271),
	(13272),
	(13273),
	(13274),
	(13275),
	(13276),
	(13277),
	(13278),
	(13279),
	(13280),
	(13281),
	(13282),
	(13283),
	(13284),
	(13285),
	(13286),
	(13287),
	(13288),
	(13289),
	(13290),
	(13291),
	(13292),
	(13293),
	(13294),
	(13295),
	(13296),
	(13297),
	(13298),
	(13299),
	(13300),
	(13301),
	(13302),
	(13303),
	(13304),
	(13305),
	(13306),
	(13307),
	(13308),
	(13309),
	(13310),
	(13311),
	(13312),
	(13313),
	(13314),
	(13315),
	(13316),
	(13317),
	(13318),
	(13319),
	(13320),
	(13321),
	(13322),
	(13323),
	(13324),
	(13325),
	(13326),
	(13327),
	(13328),
	(13329),
	(13330),
	(13331),
	(13332),
	(13333),
	(13334),
	(13335),
	(13336),
	(13337),
	(13338),
	(13339),
	(13340),
	(13341),
	(13342),
	(13343),
	(13344),
	(13345),
	(13346),
	(13347),
	(13348),
	(13349),
	(13350),
	(13351),
	(13352),
	(13353),
	(13354),
	(13355),
	(13356),
	(13357),
	(13358),
	(13359),
	(13360),
	(13361),
	(13362),
	(13363),
	(13364),
	(13365),
	(13366),
	(13367),
	(13368),
	(13369),
	(13370),
	(13371),
	(13372),
	(13373),
	(13374),
	(13375),
	(13376),
	(13377),
	(13378),
	(13379),
	(13380),
	(13381),
	(13382),
	(13383),
	(13384),
	(13385),
	(13386),
	(13387),
	(13388),
	(13389),
	(13390),
	(13391),
	(13392),
	(13393),
	(13394),
	(13395),
	(13396),
	(13397),
	(13398),
	(13399),
	(13400),
	(13401),
	(13402),
	(13403),
	(13404),
	(13405),
	(13406),
	(13407),
	(13408),
	(13409),
	(13410),
	(13411),
	(13412),
	(13413),
	(13414),
	(13415),
	(13416),
	(13417),
	(13418),
	(13419),
	(13420),
	(13421),
	(13422),
	(13423),
	(13424),
	(13425),
	(13426),
	(13427),
	(13428),
	(13429),
	(13430),
	(13431),
	(13432),
	(13433),
	(13434),
	(13435),
	(13436),
	(13437),
	(13438),
	(13439),
	(13440),
	(13441),
	(13442),
	(13443),
	(13444),
	(13445),
	(13446),
	(13447),
	(13448),
	(13449),
	(13450),
	(13451),
	(13452),
	(13453),
	(13454),
	(13455),
	(13456),
	(13457),
	(13458),
	(13459),
	(13460),
	(13461),
	(13462),
	(13463),
	(13464),
	(13465),
	(13466),
	(13467),
	(13468),
	(13469),
	(13470),
	(13471),
	(13472),
	(13473),
	(13474),
	(13475),
	(13476),
	(13477),
	(13478),
	(13479),
	(13480),
	(13481),
	(13482),
	(13483),
	(13484),
	(13485),
	(13486),
	(13487),
	(13488),
	(13489),
	(13490),
	(13491),
	(13492),
	(13493),
	(13494),
	(13495),
	(13496),
	(13497),
	(13498),
	(13499),
	(13500),
	(13501),
	(13502),
	(13503),
	(13504),
	(13505),
	(13506),
	(13507),
	(13508),
	(13509),
	(13510),
	(13511),
	(13512),
	(13513),
	(13514),
	(13515),
	(13516),
	(13517),
	(13518),
	(13519),
	(13520),
	(13521),
	(13522),
	(13523),
	(13524),
	(13525),
	(13526),
	(13527),
	(13528),
	(13529),
	(13530),
	(13531),
	(13532),
	(13533),
	(13534),
	(13535),
	(13536),
	(13537),
	(13538),
	(13539),
	(13540),
	(13541),
	(13542),
	(13543),
	(13544),
	(13545),
	(13546),
	(13547),
	(13548),
	(13549),
	(13550),
	(13551),
	(13552),
	(13553),
	(13554),
	(13555),
	(13556),
	(13557),
	(13558),
	(13559),
	(13560),
	(13561),
	(13562),
	(13563),
	(13564),
	(13565),
	(13566),
	(13567),
	(13568),
	(13569),
	(13570),
	(13571),
	(13572),
	(13573),
	(13574),
	(13575),
	(13576),
	(13577),
	(13578),
	(13579),
	(13580),
	(13581),
	(13582),
	(13583),
	(13584),
	(13585),
	(13586),
	(13587),
	(13588),
	(13589),
	(13590),
	(13591),
	(13592),
	(13593),
	(13594),
	(13595),
	(13596),
	(13597),
	(13598),
	(13599),
	(13600),
	(13601),
	(13602),
	(13603),
	(13604),
	(13605),
	(13606),
	(13607),
	(13608),
	(13609),
	(13610),
	(13611),
	(13612),
	(13613),
	(13614),
	(13615),
	(13616),
	(13617),
	(13618),
	(13619),
	(13620),
	(13621),
	(13622),
	(13623),
	(13624),
	(13625),
	(13626),
	(13627),
	(13628),
	(13629),
	(13630),
	(13631),
	(13632),
	(13633),
	(13634),
	(13635),
	(13636),
	(13637),
	(13638),
	(13639),
	(13640),
	(13641),
	(13642),
	(13643),
	(13644),
	(13645),
	(13646),
	(13647),
	(13648),
	(13649),
	(13650),
	(13651),
	(13652),
	(13653),
	(13654),
	(13655),
	(13656),
	(13657),
	(13658),
	(13659),
	(13660),
	(13661),
	(13662),
	(13663),
	(13664),
	(13665),
	(13666),
	(13667),
	(13668),
	(13669),
	(13670),
	(13671),
	(13672),
	(13673),
	(13674),
	(13675),
	(13676),
	(13677),
	(13678),
	(13679),
	(13680),
	(13681),
	(13682),
	(13683),
	(13684),
	(13685),
	(13686),
	(13687),
	(13688),
	(13689),
	(13690),
	(13691),
	(13692),
	(13693),
	(13694),
	(13695),
	(13696),
	(13697),
	(13698),
	(13699),
	(13700),
	(13701),
	(13702),
	(13703),
	(13704),
	(13705),
	(13706),
	(13707),
	(13708),
	(13709),
	(13710),
	(13711),
	(13712),
	(13713),
	(13714),
	(13715),
	(13716),
	(13717),
	(13718),
	(13719),
	(13720),
	(13721),
	(13722),
	(13723),
	(13724),
	(13725),
	(13726),
	(13727),
	(13728),
	(13729),
	(13730),
	(13731),
	(13732),
	(13733),
	(13734),
	(13735),
	(13736),
	(13737),
	(13738),
	(13739),
	(13740),
	(13741),
	(13742),
	(13743),
	(13744),
	(13745),
	(13746),
	(13747),
	(13748),
	(13749),
	(13750),
	(13751),
	(13752),
	(13753),
	(13754),
	(13755),
	(13756),
	(13757),
	(13758),
	(13759),
	(13760),
	(13761),
	(13762),
	(13763),
	(13764),
	(13765),
	(13766),
	(13767),
	(13768),
	(13769),
	(13770),
	(13771),
	(13772),
	(13773),
	(13774),
	(13775),
	(13776),
	(13777),
	(13778),
	(13779),
	(13780),
	(13781),
	(13782),
	(13783),
	(13784),
	(13785),
	(13786),
	(13787),
	(13788),
	(13789),
	(13790),
	(13791),
	(13792),
	(13793),
	(13794),
	(13795),
	(13796),
	(13797),
	(13798),
	(13799),
	(13800),
	(13801),
	(13802),
	(13803),
	(13804),
	(13805),
	(13806),
	(13807),
	(13808),
	(13809),
	(13810),
	(13811),
	(13812),
	(13813),
	(13814),
	(13815),
	(13816),
	(13817),
	(13818),
	(13819),
	(13820),
	(13821),
	(13822),
	(13823),
	(13824),
	(13825),
	(13826),
	(13827),
	(13828),
	(13829),
	(13830),
	(13831),
	(13832),
	(13833),
	(13834),
	(13835),
	(13836),
	(13837),
	(13838),
	(13839),
	(13840),
	(13841),
	(13842),
	(13843),
	(13844),
	(13845),
	(13846),
	(13847),
	(13848),
	(13849),
	(13850),
	(13851),
	(13852),
	(13853),
	(13854),
	(13855),
	(13856),
	(13857),
	(13858),
	(13859),
	(13860),
	(13861),
	(13862),
	(13863),
	(13864),
	(13865),
	(13866),
	(13867),
	(13868),
	(13869),
	(13870),
	(13871),
	(13872),
	(13873),
	(13874),
	(13875),
	(13876),
	(13877),
	(13878),
	(13879),
	(13880),
	(13881),
	(13882),
	(13883),
	(13884),
	(13885),
	(13886),
	(13887),
	(13888),
	(13889),
	(13890),
	(13891),
	(13892),
	(13893),
	(13894),
	(13895),
	(13896),
	(13897),
	(13898),
	(13899),
	(13900),
	(13901),
	(13902),
	(13903),
	(13904),
	(13905),
	(13906),
	(13907),
	(13908),
	(13909),
	(13910),
	(13911),
	(13912),
	(13913),
	(13914),
	(13915),
	(13916),
	(13917),
	(13918),
	(13919),
	(13920),
	(13921),
	(13922),
	(13923),
	(13924),
	(13925),
	(13926),
	(13927),
	(13928),
	(13929),
	(13930),
	(13931),
	(13932),
	(13933),
	(13934),
	(13935),
	(13936),
	(13937),
	(13938),
	(13939),
	(13940),
	(13941),
	(13942),
	(13943),
	(13944),
	(13945),
	(13946),
	(13947),
	(13948),
	(13949),
	(13950),
	(13951),
	(13952),
	(13953),
	(13954),
	(13955),
	(13956),
	(13957),
	(13958),
	(13959),
	(13960),
	(13961),
	(13962),
	(13963),
	(13964),
	(13965),
	(13966),
	(13967),
	(13968),
	(13969),
	(13970),
	(13971),
	(13972),
	(13973),
	(13974),
	(13975),
	(13976),
	(13977),
	(13978),
	(13979),
	(13980),
	(13981),
	(13982),
	(13983),
	(13984),
	(13985),
	(13986),
	(13987),
	(13988),
	(13989),
	(13990),
	(13991),
	(13992),
	(13993),
	(13994),
	(13995),
	(13996),
	(13997),
	(13998),
	(13999),
	(14000),
	(14001),
	(14002),
	(14003),
	(14004),
	(14005),
	(14006),
	(14007),
	(14008),
	(14009),
	(14010),
	(14011),
	(14012),
	(14013),
	(14014),
	(14015),
	(14016),
	(14017),
	(14018),
	(14019),
	(14020),
	(14021),
	(14022),
	(14023),
	(14024),
	(14025),
	(14026),
	(14027),
	(14028),
	(14029),
	(14030),
	(14031),
	(14032),
	(14033),
	(14034),
	(14035),
	(14036),
	(14037),
	(14038),
	(14039),
	(14040),
	(14041),
	(14042),
	(14043),
	(14044),
	(14045),
	(14046),
	(14047),
	(14048),
	(14049),
	(14050),
	(14051),
	(14052),
	(14053),
	(14054),
	(14055),
	(14056),
	(14057),
	(14058),
	(14059),
	(14060),
	(14061),
	(14062),
	(14063),
	(14064),
	(14065),
	(14066),
	(14067),
	(14068),
	(14069),
	(14070),
	(14071),
	(14072),
	(14073),
	(14074),
	(14075),
	(14076),
	(14077),
	(14078),
	(14079),
	(14080),
	(14081),
	(14082),
	(14083),
	(14084),
	(14085),
	(14086),
	(14087),
	(14088),
	(14089),
	(14090),
	(14091),
	(14092),
	(14093),
	(14094),
	(14095),
	(14096),
	(14097),
	(14098),
	(14099),
	(14100),
	(14101),
	(14102),
	(14103),
	(14104),
	(14105),
	(14106),
	(14107),
	(14108),
	(14109),
	(14110),
	(14111),
	(14112),
	(14113),
	(14114),
	(14115),
	(14116),
	(14117),
	(14118),
	(14119),
	(14120),
	(14121),
	(14122),
	(14123),
	(14124),
	(14125),
	(14126),
	(14127),
	(14128),
	(14129),
	(14130),
	(14131),
	(14132),
	(14133),
	(14134),
	(14135),
	(14136),
	(14137),
	(14138),
	(14139),
	(14140),
	(14141),
	(14142),
	(14143),
	(14144),
	(14145),
	(14146),
	(14147),
	(14148),
	(14149),
	(14150),
	(14151),
	(14152),
	(14153),
	(14154),
	(14155),
	(14156),
	(14157),
	(14158),
	(14159),
	(14160),
	(14161),
	(14162),
	(14163),
	(14164),
	(14165),
	(14166),
	(14167),
	(14168),
	(14169),
	(14170),
	(14171),
	(14172),
	(14173),
	(14174),
	(14175),
	(14176),
	(14177),
	(14178),
	(14179),
	(14180),
	(14181),
	(14182),
	(14183),
	(14184),
	(14185),
	(14186),
	(14187),
	(14188),
	(14189),
	(14190),
	(14191),
	(14192),
	(14193),
	(14194),
	(14195),
	(14196),
	(14197),
	(14198),
	(14199),
	(14200),
	(14201),
	(14202),
	(14203),
	(14204),
	(14205),
	(14206),
	(14207),
	(14208),
	(14209),
	(14210),
	(14211),
	(14212),
	(14213),
	(14214),
	(14215),
	(14216),
	(14217),
	(14218),
	(14219),
	(14220),
	(14221),
	(14222),
	(14223),
	(14224),
	(14225),
	(14226),
	(14227),
	(14228),
	(14229),
	(14230),
	(14231),
	(14232),
	(14233),
	(14234),
	(14235),
	(14236),
	(14237),
	(14238),
	(14239),
	(14240),
	(14241),
	(14242),
	(14243),
	(14244),
	(14245),
	(14246),
	(14247),
	(14248),
	(14249),
	(14250),
	(14251),
	(14252),
	(14253),
	(14254),
	(14255),
	(14256),
	(14257),
	(14258),
	(14259),
	(14260),
	(14261),
	(14262),
	(14263),
	(14264),
	(14265),
	(14266),
	(14267),
	(14268),
	(14269),
	(14270),
	(14271),
	(14272),
	(14273),
	(14274),
	(14275),
	(14276),
	(14277),
	(14278),
	(14279),
	(14280),
	(14281),
	(14282),
	(14283),
	(14284),
	(14285),
	(14286),
	(14287),
	(14288),
	(14289),
	(14290),
	(14291),
	(14292),
	(14293),
	(14294),
	(14295),
	(14296),
	(14297),
	(14298),
	(14299),
	(14300),
	(14301),
	(14302),
	(14303),
	(14304),
	(14305),
	(14306),
	(14307),
	(14308),
	(14309),
	(14310),
	(14311),
	(14312),
	(14313),
	(14314),
	(14315),
	(14316),
	(14317),
	(14318),
	(14319),
	(14320),
	(14321),
	(14322),
	(14323),
	(14324),
	(14325),
	(14326),
	(14327),
	(14328),
	(14329),
	(14330),
	(14331),
	(14332),
	(14333),
	(14334),
	(14335),
	(14336),
	(14337),
	(14338),
	(14339),
	(14340),
	(14341),
	(14342),
	(14343),
	(14344),
	(14345),
	(14346),
	(14347),
	(14348),
	(14349),
	(14350),
	(14351),
	(14352),
	(14353),
	(14354),
	(14355),
	(14356),
	(14357),
	(14358),
	(14359),
	(14360),
	(14361),
	(14362),
	(14363),
	(14364),
	(14365),
	(14366),
	(14367),
	(14368),
	(14369),
	(14370),
	(14371),
	(14372),
	(14373),
	(14374),
	(14375),
	(14376),
	(14377),
	(14378),
	(14379),
	(14380),
	(14381),
	(14382),
	(14383),
	(14384),
	(14385),
	(14386),
	(14387),
	(14388),
	(14389),
	(14390),
	(14391),
	(14392),
	(14393),
	(14394),
	(14395),
	(14396),
	(14397),
	(14398),
	(14399),
	(14400),
	(14401),
	(14402),
	(14403),
	(14404),
	(14405),
	(14406),
	(14407),
	(14408),
	(14409),
	(14410),
	(14411),
	(14412),
	(14413),
	(14414),
	(14415),
	(14416),
	(14417),
	(14418),
	(14419),
	(14420),
	(14421),
	(14422),
	(14423),
	(14424),
	(14425),
	(14426),
	(14427),
	(14428),
	(14429),
	(14430),
	(14431),
	(14432),
	(14433),
	(14434),
	(14435),
	(14436),
	(14437),
	(14438),
	(14439),
	(14440),
	(14441),
	(14442),
	(14443),
	(14444),
	(14445),
	(14446),
	(14447),
	(14448),
	(14449),
	(14450),
	(14451),
	(14452),
	(14453),
	(14454),
	(14455),
	(14456),
	(14457),
	(14458),
	(14459),
	(14460),
	(14461),
	(14462),
	(14463),
	(14464),
	(14465),
	(14466),
	(14467),
	(14468),
	(14469),
	(14470),
	(14471),
	(14472),
	(14473),
	(14474),
	(14475),
	(14476),
	(14477),
	(14478),
	(14479),
	(14480),
	(14481),
	(14482),
	(14483),
	(14484),
	(14485),
	(14486),
	(14487),
	(14488),
	(14489),
	(14490),
	(14491),
	(14492),
	(14493),
	(14494),
	(14495),
	(14496),
	(14497),
	(14498),
	(14499),
	(14500),
	(14501),
	(14502),
	(14503),
	(14504),
	(14505),
	(14506),
	(14507),
	(14508),
	(14509),
	(14510),
	(14511),
	(14512),
	(14513),
	(14514),
	(14515),
	(14516),
	(14517),
	(14518),
	(14519),
	(14520),
	(14521),
	(14522),
	(14523),
	(14524),
	(14525),
	(14526),
	(14527),
	(14528),
	(14529),
	(14530),
	(14531),
	(14532),
	(14533),
	(14534),
	(14535),
	(14536),
	(14537),
	(14538),
	(14539),
	(14540),
	(14541),
	(14542),
	(14543),
	(14544),
	(14545),
	(14546),
	(14547),
	(14548),
	(14549),
	(14550),
	(14551),
	(14552),
	(14553),
	(14554),
	(14555),
	(14556),
	(14557),
	(14558),
	(14559),
	(14560),
	(14561),
	(14562),
	(14563),
	(14564),
	(14565),
	(14566),
	(14567),
	(14568),
	(14569),
	(14570),
	(14571),
	(14572),
	(14573),
	(14574),
	(14575),
	(14576),
	(14577),
	(14578),
	(14579),
	(14580),
	(14581),
	(14582),
	(14583),
	(14584),
	(14585),
	(14586),
	(14587),
	(14588),
	(14589),
	(14590),
	(14591),
	(14592),
	(14593),
	(14594),
	(14595),
	(14596),
	(14597),
	(14598),
	(14599),
	(14600),
	(14601),
	(14602),
	(14603),
	(14604),
	(14605),
	(14606),
	(14607),
	(14608),
	(14609),
	(14610),
	(14611),
	(14612),
	(14613),
	(14614),
	(14615),
	(14616),
	(14617),
	(14618),
	(14619),
	(14620),
	(14621),
	(14622),
	(14623),
	(14624),
	(14625),
	(14626),
	(14627),
	(14628),
	(14629),
	(14630),
	(14631),
	(14632),
	(14633),
	(14634),
	(14635),
	(14636),
	(14637),
	(14638),
	(14639),
	(14640),
	(14641),
	(14642),
	(14643),
	(14644),
	(14645),
	(14646),
	(14647),
	(14648),
	(14649),
	(14650),
	(14651),
	(14652),
	(14653),
	(14654),
	(14655),
	(14656),
	(14657),
	(14658),
	(14659),
	(14660),
	(14661),
	(14662),
	(14663),
	(14664),
	(14665),
	(14666),
	(14667),
	(14668),
	(14669),
	(14670),
	(14671),
	(14672),
	(14673),
	(14674),
	(14675),
	(14676),
	(14677),
	(14678),
	(14679),
	(14680),
	(14681),
	(14682),
	(14683),
	(14684),
	(14685),
	(14686),
	(14687),
	(14688),
	(14689),
	(14690),
	(14691),
	(14692),
	(14693),
	(14694),
	(14695),
	(14696),
	(14697),
	(14698),
	(14699),
	(14700),
	(14701),
	(14702),
	(14703),
	(14704),
	(14705),
	(14706),
	(14707),
	(14708),
	(14709),
	(14710),
	(14711),
	(14712),
	(14713),
	(14714),
	(14715),
	(14716),
	(14717),
	(14718),
	(14719),
	(14720),
	(14721),
	(14722),
	(14723),
	(14724),
	(14725),
	(14726),
	(14727),
	(14728),
	(14729),
	(14730),
	(14731),
	(14732),
	(14733),
	(14734),
	(14735),
	(14736),
	(14737),
	(14738),
	(14739),
	(14740),
	(14741),
	(14742),
	(14743),
	(14744),
	(14745),
	(14746),
	(14747),
	(14748),
	(14749),
	(14750),
	(14751),
	(14752),
	(14753),
	(14754),
	(14755),
	(14756),
	(14757),
	(14758),
	(14759),
	(14760),
	(14761),
	(14762),
	(14763),
	(14764),
	(14765),
	(14766),
	(14767),
	(14768),
	(14769),
	(14770),
	(14771),
	(14772),
	(14773),
	(14774),
	(14775),
	(14776),
	(14777),
	(14778),
	(14779),
	(14780),
	(14781),
	(14782),
	(14783),
	(14784),
	(14785),
	(14786),
	(14787),
	(14788),
	(14789),
	(14790),
	(14791),
	(14792),
	(14793),
	(14794),
	(14795),
	(14796),
	(14797),
	(14798),
	(14799),
	(14800),
	(14801),
	(14802),
	(14803),
	(14804),
	(14805),
	(14806),
	(14807),
	(14808),
	(14809),
	(14810),
	(14811),
	(14812),
	(14813),
	(14814),
	(14815),
	(14816),
	(14817),
	(14818),
	(14819),
	(14820),
	(14821),
	(14822),
	(14823),
	(14824),
	(14825),
	(14826),
	(14827),
	(14828),
	(14829),
	(14830),
	(14831),
	(14832),
	(14833),
	(14834),
	(14835),
	(14836),
	(14837),
	(14838),
	(14839),
	(14840),
	(14841),
	(14842),
	(14843),
	(14844),
	(14845),
	(14846),
	(14847),
	(14848),
	(14849),
	(14850),
	(14851),
	(14852),
	(14853),
	(14854),
	(14855),
	(14856),
	(14857),
	(14858),
	(14859),
	(14860),
	(14861),
	(14862),
	(14863),
	(14864),
	(14865),
	(14866),
	(14867),
	(14868),
	(14869),
	(14870),
	(14871),
	(14872),
	(14873),
	(14874),
	(14875),
	(14876),
	(14877),
	(14878),
	(14879),
	(14880),
	(14881),
	(14882),
	(14883),
	(14884),
	(14885),
	(14886),
	(14887),
	(14888),
	(14889),
	(14890),
	(14891),
	(14892),
	(14893),
	(14894),
	(14895),
	(14896),
	(14897),
	(14898),
	(14899),
	(14900),
	(14901),
	(14902),
	(14903),
	(14904),
	(14905),
	(14906),
	(14907),
	(14908),
	(14909),
	(14910),
	(14911),
	(14912),
	(14913),
	(14914),
	(14915),
	(14916),
	(14917),
	(14918),
	(14919),
	(14920),
	(14921),
	(14922),
	(14923),
	(14924),
	(14925),
	(14926),
	(14927),
	(14928),
	(14929),
	(14930),
	(14931),
	(14932),
	(14933),
	(14934),
	(14935),
	(14936),
	(14937),
	(14938),
	(14939),
	(14940),
	(14941),
	(14942),
	(14943),
	(14944),
	(14945),
	(14946),
	(14947),
	(14948),
	(14949),
	(14950),
	(14951),
	(14952),
	(14953),
	(14954),
	(14955),
	(14956),
	(14957),
	(14958),
	(14959),
	(14960),
	(14961),
	(14962),
	(14963),
	(14964),
	(14965),
	(14966),
	(14967),
	(14968),
	(14969),
	(14970),
	(14971),
	(14972),
	(14973),
	(14974),
	(14975),
	(14976),
	(14977),
	(14978),
	(14979),
	(14980),
	(14981),
	(14982),
	(14983),
	(14984),
	(14985),
	(14986),
	(14987),
	(14988),
	(14989),
	(14990),
	(14991),
	(14992),
	(14993),
	(14994),
	(14995),
	(14996),
	(14997),
	(14998),
	(14999),
	(15000),
	(15001),
	(15002),
	(15003),
	(15004),
	(15005),
	(15006),
	(15007),
	(15008),
	(15009),
	(15010),
	(15011),
	(15012),
	(15013),
	(15014),
	(15015),
	(15016),
	(15017),
	(15018),
	(15019),
	(15020),
	(15021),
	(15022),
	(15023),
	(15024),
	(15025),
	(15026),
	(15027),
	(15028),
	(15029),
	(15030),
	(15031),
	(15032),
	(15033),
	(15034),
	(15035),
	(15036),
	(15037),
	(15038),
	(15039),
	(15040),
	(15041),
	(15042),
	(15043),
	(15044),
	(15045),
	(15046),
	(15047),
	(15048),
	(15049),
	(15050),
	(15051),
	(15052),
	(15053),
	(15054),
	(15055),
	(15056),
	(15057),
	(15058),
	(15059),
	(15060),
	(15061),
	(15062),
	(15063),
	(15064),
	(15065),
	(15066),
	(15067),
	(15068),
	(15069),
	(15070),
	(15071),
	(15072),
	(15073),
	(15074),
	(15075),
	(15076),
	(15077),
	(15078),
	(15079),
	(15080),
	(15081),
	(15082),
	(15083),
	(15084),
	(15085),
	(15086),
	(15087),
	(15088),
	(15089),
	(15090),
	(15091),
	(15092),
	(15093),
	(15094),
	(15095),
	(15096),
	(15097),
	(15098),
	(15099),
	(15100),
	(15101),
	(15102),
	(15103),
	(15104),
	(15105),
	(15106),
	(15107),
	(15108),
	(15109),
	(15110),
	(15111),
	(15112),
	(15113),
	(15114),
	(15115),
	(15116),
	(15117),
	(15118),
	(15119),
	(15120),
	(15121),
	(15122),
	(15123),
	(15124),
	(15125),
	(15126),
	(15127),
	(15128),
	(15129),
	(15130),
	(15131),
	(15132),
	(15133),
	(15134),
	(15135),
	(15136),
	(15137),
	(15138),
	(15139),
	(15140),
	(15141),
	(15142),
	(15143),
	(15144),
	(15145),
	(15146),
	(15147),
	(15148),
	(15149),
	(15150),
	(15151),
	(15152),
	(15153),
	(15154),
	(15155),
	(15156),
	(15157),
	(15158),
	(15159),
	(15160),
	(15161),
	(15162),
	(15163),
	(15164),
	(15165),
	(15166),
	(15167),
	(15168),
	(15169),
	(15170),
	(15171),
	(15172),
	(15173),
	(15174),
	(15175),
	(15176),
	(15177),
	(15178),
	(15179),
	(15180),
	(15181),
	(15182),
	(15183),
	(15184),
	(15185),
	(15186),
	(15187),
	(15188),
	(15189),
	(15190),
	(15191),
	(15192),
	(15193),
	(15194),
	(15195),
	(15196),
	(15197),
	(15198),
	(15199),
	(15200),
	(15201),
	(15202),
	(15203),
	(15204),
	(15205),
	(15206),
	(15207),
	(15208),
	(15209),
	(15210),
	(15211),
	(15212),
	(15213),
	(15214),
	(15215),
	(15216),
	(15217),
	(15218),
	(15219),
	(15220),
	(15221),
	(15222),
	(15223),
	(15224),
	(15225),
	(15226),
	(15227),
	(15228),
	(15229),
	(15230),
	(15231),
	(15232),
	(15233),
	(15234),
	(15235),
	(15236),
	(15237),
	(15238),
	(15239),
	(15240),
	(15241),
	(15242),
	(15243),
	(15244),
	(15245),
	(15246),
	(15247),
	(15248),
	(15249),
	(15250),
	(15251),
	(15252),
	(15253),
	(15254),
	(15255),
	(15256),
	(15257),
	(15258),
	(15259),
	(15260),
	(15261),
	(15262),
	(15263),
	(15264),
	(15265),
	(15266),
	(15267),
	(15268),
	(15269),
	(15270),
	(15271),
	(15272),
	(15273),
	(15274),
	(15275),
	(15276),
	(15277),
	(15278),
	(15279),
	(15280),
	(15281),
	(15282),
	(15283),
	(15284),
	(15285),
	(15286),
	(15287),
	(15288),
	(15289),
	(15290),
	(15291),
	(15292),
	(15293),
	(15294),
	(15295),
	(15296),
	(15297),
	(15298),
	(15299),
	(15300),
	(15301),
	(15302),
	(15303),
	(15304),
	(15305),
	(15306),
	(15307),
	(15308),
	(15309),
	(15310),
	(15311),
	(15312),
	(15313),
	(15314),
	(15315),
	(15316),
	(15317),
	(15318),
	(15319),
	(15320),
	(15321),
	(15322),
	(15323),
	(15324),
	(15325),
	(15326),
	(15327),
	(15328),
	(15329),
	(15330),
	(15331),
	(15332),
	(15333),
	(15334),
	(15335),
	(15336),
	(15337),
	(15338),
	(15339),
	(15340),
	(15341),
	(15342),
	(15343),
	(15344),
	(15345),
	(15346),
	(15347),
	(15348),
	(15349),
	(15350),
	(15351),
	(15352),
	(15353),
	(15354),
	(15355),
	(15356),
	(15357),
	(15358),
	(15359),
	(15360),
	(15361),
	(15362),
	(15363),
	(15364),
	(15365),
	(15366),
	(15367),
	(15368),
	(15369),
	(15370),
	(15371),
	(15372),
	(15373),
	(15374),
	(15375),
	(15376),
	(15377),
	(15378),
	(15379),
	(15380),
	(15381),
	(15382),
	(15383),
	(15384),
	(15385),
	(15386),
	(15387),
	(15388),
	(15389),
	(15390),
	(15391),
	(15392),
	(15393),
	(15394),
	(15395),
	(15396),
	(15397),
	(15398),
	(15399),
	(15400),
	(15401),
	(15402),
	(15403),
	(15404),
	(15405),
	(15406),
	(15407),
	(15408),
	(15409),
	(15410),
	(15411),
	(15412),
	(15413),
	(15414),
	(15415),
	(15416),
	(15417),
	(15418),
	(15419),
	(15420),
	(15421),
	(15422),
	(15423),
	(15424),
	(15425),
	(15426),
	(15427),
	(15428),
	(15429),
	(15430),
	(15431),
	(15432),
	(15433),
	(15434),
	(15435),
	(15436),
	(15437),
	(15438),
	(15439),
	(15440),
	(15441),
	(15442),
	(15443),
	(15444),
	(15445),
	(15446),
	(15447),
	(15448),
	(15449),
	(15450),
	(15451),
	(15452),
	(15453),
	(15454),
	(15455),
	(15456),
	(15457),
	(15458),
	(15459),
	(15460),
	(15461),
	(15462),
	(15463),
	(15464),
	(15465),
	(15466),
	(15467),
	(15468),
	(15469),
	(15470),
	(15471),
	(15472),
	(15473),
	(15474),
	(15475),
	(15476),
	(15477),
	(15478),
	(15479),
	(15480),
	(15481),
	(15482),
	(15483),
	(15484),
	(15485),
	(15486),
	(15487),
	(15488),
	(15489),
	(15490),
	(15491),
	(15492),
	(15493),
	(15494),
	(15495),
	(15496),
	(15497),
	(15498),
	(15499),
	(15500),
	(15501),
	(15502),
	(15503),
	(15504),
	(15505),
	(15506),
	(15507),
	(15508),
	(15509),
	(15510),
	(15511),
	(15512),
	(15513),
	(15514),
	(15515),
	(15516),
	(15517),
	(15518),
	(15519),
	(15520),
	(15521),
	(15522),
	(15523),
	(15524),
	(15525),
	(15526),
	(15527),
	(15528),
	(15529),
	(15530),
	(15531),
	(15532),
	(15533),
	(15534),
	(15535),
	(15536),
	(15537),
	(15538),
	(15539),
	(15540),
	(15541),
	(15542),
	(15543),
	(15544),
	(15545),
	(15546),
	(15547),
	(15548),
	(15549),
	(15550),
	(15551),
	(15552),
	(15553),
	(15554),
	(15555),
	(15556),
	(15557),
	(15558),
	(15559),
	(15560),
	(15561),
	(15562),
	(15563),
	(15564),
	(15565),
	(15566),
	(15567),
	(15568),
	(15569),
	(15570),
	(15571),
	(15572),
	(15573),
	(15574),
	(15575),
	(15576),
	(15577),
	(15578),
	(15579),
	(15580),
	(15581),
	(15582),
	(15583),
	(15584),
	(15585),
	(15586),
	(15587),
	(15588),
	(15589),
	(15590),
	(15591),
	(15592),
	(15593),
	(15594),
	(15595),
	(15596),
	(15597),
	(15598),
	(15599),
	(15600),
	(15601),
	(15602),
	(15603),
	(15604),
	(15605),
	(15606),
	(15607),
	(15608),
	(15609),
	(15610),
	(15611),
	(15612),
	(15613),
	(15614),
	(15615),
	(15616),
	(15617),
	(15618),
	(15619),
	(15620),
	(15621),
	(15622),
	(15623),
	(15624),
	(15625),
	(15626),
	(15627),
	(15628),
	(15629),
	(15630),
	(15631),
	(15632),
	(15633),
	(15634),
	(15635),
	(15636),
	(15637),
	(15638),
	(15639),
	(15640),
	(15641),
	(15642),
	(15643),
	(15644),
	(15645),
	(15646),
	(15647),
	(15648),
	(15649),
	(15650),
	(15651),
	(15652),
	(15653),
	(15654),
	(15655),
	(15656),
	(15657),
	(15658),
	(15659),
	(15660),
	(15661),
	(15662),
	(15663),
	(15664),
	(15665),
	(15666),
	(15667),
	(15668),
	(15669),
	(15670),
	(15671),
	(15672),
	(15673),
	(15674),
	(15675),
	(15676),
	(15677),
	(15678),
	(15679),
	(15680),
	(15681),
	(15682),
	(15683),
	(15684),
	(15685),
	(15686),
	(15687),
	(15688),
	(15689),
	(15690),
	(15691),
	(15692),
	(15693),
	(15694),
	(15695),
	(15696),
	(15697),
	(15698),
	(15699),
	(15700),
	(15701),
	(15702),
	(15703),
	(15704),
	(15705),
	(15706),
	(15707),
	(15708),
	(15709),
	(15710),
	(15711),
	(15712),
	(15713),
	(15714),
	(15715),
	(15716),
	(15717),
	(15718),
	(15719),
	(15720),
	(15721),
	(15722),
	(15723),
	(15724),
	(15725),
	(15726),
	(15727),
	(15728),
	(15729),
	(15730),
	(15731),
	(15732),
	(15733),
	(15734),
	(15735),
	(15736),
	(15737),
	(15738),
	(15739),
	(15740),
	(15741),
	(15742),
	(15743),
	(15744),
	(15745),
	(15746),
	(15747),
	(15748),
	(15749),
	(15750),
	(15751),
	(15752),
	(15753),
	(15754),
	(15755),
	(15756),
	(15757),
	(15758),
	(15759),
	(15760),
	(15761),
	(15762),
	(15763),
	(15764),
	(15765),
	(15766),
	(15767),
	(15768),
	(15769),
	(15770),
	(15771),
	(15772),
	(15773),
	(15774),
	(15775),
	(15776),
	(15777),
	(15778),
	(15779),
	(15780),
	(15781),
	(15782),
	(15783),
	(15784),
	(15785),
	(15786),
	(15787),
	(15788),
	(15789),
	(15790),
	(15791),
	(15792),
	(15793),
	(15794),
	(15795),
	(15796),
	(15797),
	(15798),
	(15799),
	(15800),
	(15801),
	(15802),
	(15803),
	(15804),
	(15805),
	(15806),
	(15807),
	(15808),
	(15809),
	(15810),
	(15811),
	(15812),
	(15813),
	(15814),
	(15815),
	(15816),
	(15817),
	(15818),
	(15819),
	(15820),
	(15821),
	(15822),
	(15823),
	(15824),
	(15825),
	(15826),
	(15827),
	(15828),
	(15829),
	(15830),
	(15831),
	(15832),
	(15833),
	(15834),
	(15835),
	(15836),
	(15837),
	(15838),
	(15839),
	(15840),
	(15841),
	(15842),
	(15843),
	(15844),
	(15845),
	(15846),
	(15847),
	(15848),
	(15849),
	(15850),
	(15851),
	(15852),
	(15853),
	(15854),
	(15855),
	(15856),
	(15857),
	(15858),
	(15859),
	(15860),
	(15861),
	(15862),
	(15863),
	(15864),
	(15865),
	(15866),
	(15867),
	(15868),
	(15869),
	(15870),
	(15871),
	(15872),
	(15873),
	(15874),
	(15875),
	(15876),
	(15877),
	(15878),
	(15879),
	(15880),
	(15881),
	(15882),
	(15883),
	(15884),
	(15885),
	(15886),
	(15887),
	(15888),
	(15889),
	(15890),
	(15891),
	(15892),
	(15893),
	(15894),
	(15895),
	(15896),
	(15897),
	(15898),
	(15899),
	(15900),
	(15901),
	(15902),
	(15903),
	(15904),
	(15905),
	(15906),
	(15907),
	(15908),
	(15909),
	(15910),
	(15911),
	(15912),
	(15913),
	(15914),
	(15915),
	(15916),
	(15917),
	(15918),
	(15919),
	(15920),
	(15921),
	(15922),
	(15923),
	(15924),
	(15925),
	(15926),
	(15927),
	(15928),
	(15929),
	(15930),
	(15931),
	(15932),
	(15933),
	(15934),
	(15935),
	(15936),
	(15937),
	(15938),
	(15939),
	(15940),
	(15941),
	(15942),
	(15943),
	(15944),
	(15945),
	(15946),
	(15947),
	(15948),
	(15949),
	(15950),
	(15951),
	(15952),
	(15953),
	(15954),
	(15955),
	(15956),
	(15957),
	(15958),
	(15959),
	(15960),
	(15961),
	(15962),
	(15963),
	(15964),
	(15965),
	(15966),
	(15967),
	(15968),
	(15969),
	(15970),
	(15971),
	(15972),
	(15973),
	(15974),
	(15975),
	(15976),
	(15977),
	(15978),
	(15979),
	(15980),
	(15981),
	(15982),
	(15983),
	(15984),
	(15985),
	(15986),
	(15987),
	(15988),
	(15989),
	(15990),
	(15991),
	(15992),
	(15993),
	(15994),
	(15995),
	(15996),
	(15997),
	(15998),
	(15999),
	(16000),
	(16001),
	(16002),
	(16003),
	(16004),
	(16005),
	(16006),
	(16007),
	(16008),
	(16009),
	(16010),
	(16011),
	(16012),
	(16013),
	(16014),
	(16015),
	(16016),
	(16017),
	(16018),
	(16019),
	(16020),
	(16021),
	(16022),
	(16023),
	(16024),
	(16025),
	(16026),
	(16027),
	(16028),
	(16029),
	(16030),
	(16031),
	(16032),
	(16033),
	(16034),
	(16035),
	(16036),
	(16037),
	(16038),
	(16039),
	(16040),
	(16041),
	(16042),
	(16043),
	(16044),
	(16045),
	(16046),
	(16047),
	(16048),
	(16049),
	(16050),
	(16051),
	(16052),
	(16053),
	(16054),
	(16055),
	(16056),
	(16057),
	(16058),
	(16059),
	(16060),
	(16061),
	(16062),
	(16063),
	(16064),
	(16065),
	(16066),
	(16067),
	(16068),
	(16069),
	(16070),
	(16071),
	(16072),
	(16073),
	(16074),
	(16075),
	(16076),
	(16077),
	(16078),
	(16079),
	(16080),
	(16081),
	(16082),
	(16083),
	(16084),
	(16085),
	(16086),
	(16087),
	(16088),
	(16089),
	(16090),
	(16091),
	(16092),
	(16093),
	(16094),
	(16095),
	(16096),
	(16097),
	(16098),
	(16099),
	(16100),
	(16101),
	(16102),
	(16103),
	(16104),
	(16105),
	(16106),
	(16107),
	(16108),
	(16109),
	(16110),
	(16111),
	(16112),
	(16113),
	(16114),
	(16115),
	(16116),
	(16117),
	(16118),
	(16119),
	(16120),
	(16121),
	(16122),
	(16123),
	(16124),
	(16125),
	(16126),
	(16127),
	(16128),
	(16129),
	(16130),
	(16131),
	(16132),
	(16133),
	(16134),
	(16135),
	(16136),
	(16137),
	(16138),
	(16139),
	(16140),
	(16141),
	(16142),
	(16143),
	(16144),
	(16145),
	(16146),
	(16147),
	(16148),
	(16149),
	(16150),
	(16151),
	(16152),
	(16153),
	(16154),
	(16155),
	(16156),
	(16157),
	(16158),
	(16159),
	(16160),
	(16161),
	(16162),
	(16163),
	(16164),
	(16165),
	(16166),
	(16167),
	(16168),
	(16169),
	(16170),
	(16171),
	(16172),
	(16173),
	(16174),
	(16175),
	(16176),
	(16177),
	(16178),
	(16179),
	(16180),
	(16181),
	(16182),
	(16183),
	(16184),
	(16185),
	(16186),
	(16187),
	(16188),
	(16189),
	(16190),
	(16191),
	(16192),
	(16193),
	(16194),
	(16195),
	(16196),
	(16197),
	(16198),
	(16199),
	(16200),
	(16201),
	(16202),
	(16203),
	(16204),
	(16205),
	(16206),
	(16207),
	(16208),
	(16209),
	(16210),
	(16211),
	(16212),
	(16213),
	(16214),
	(16215),
	(16216),
	(16217),
	(16218),
	(16219),
	(16220),
	(16221),
	(16222),
	(16223),
	(16224),
	(16225),
	(16226),
	(16227),
	(16228),
	(16229),
	(16230),
	(16231),
	(16232),
	(16233),
	(16234),
	(16235),
	(16236),
	(16237),
	(16238),
	(16239),
	(16240),
	(16241),
	(16242),
	(16243),
	(16244),
	(16245),
	(16246),
	(16247),
	(16248),
	(16249),
	(16250),
	(16251),
	(16252),
	(16253),
	(16254),
	(16255),
	(16256),
	(16257),
	(16258),
	(16259),
	(16260),
	(16261),
	(16262),
	(16263),
	(16264),
	(16265),
	(16266),
	(16267),
	(16268),
	(16269),
	(16270),
	(16271),
	(16272),
	(16273),
	(16274),
	(16275),
	(16276),
	(16277),
	(16278),
	(16279),
	(16280),
	(16281),
	(16282),
	(16283),
	(16284),
	(16285),
	(16286),
	(16287),
	(16288),
	(16289),
	(16290),
	(16291),
	(16292),
	(16293),
	(16294),
	(16295),
	(16296),
	(16297),
	(16298),
	(16299),
	(16300),
	(16301),
	(16302),
	(16303),
	(16304),
	(16305),
	(16306),
	(16307),
	(16308),
	(16309),
	(16310),
	(16311),
	(16312),
	(16313),
	(16314),
	(16315),
	(16316),
	(16317),
	(16318),
	(16319),
	(16320),
	(16321),
	(16322),
	(16323),
	(16324),
	(16325),
	(16326),
	(16327),
	(16328),
	(16329),
	(16330),
	(16331),
	(16332),
	(16333),
	(16334),
	(16335),
	(16336),
	(16337),
	(16338),
	(16339),
	(16340),
	(16341),
	(16342),
	(16343),
	(16344),
	(16345),
	(16346),
	(16347),
	(16348),
	(16349),
	(16350),
	(16351),
	(16352),
	(16353),
	(16354),
	(16355),
	(16356),
	(16357),
	(16358),
	(16359),
	(16360),
	(16361),
	(16362),
	(16363),
	(16364),
	(16365),
	(16366),
	(16367),
	(16368),
	(16369),
	(16370),
	(16371),
	(16372),
	(16373),
	(16374),
	(16375),
	(16376),
	(16377),
	(16378),
	(16379),
	(16380),
	(16381),
	(16382),
	(16383),
	(16384),
	(16385),
	(16386),
	(16387),
	(16388),
	(16389),
	(16390),
	(16391),
	(16392),
	(16393),
	(16394),
	(16395),
	(16396),
	(16397),
	(16398),
	(16399),
	(16400),
	(16401),
	(16402),
	(16403),
	(16404),
	(16405),
	(16406),
	(16407),
	(16408),
	(16409),
	(16410),
	(16411),
	(16412),
	(16413),
	(16414),
	(16415),
	(16416),
	(16417),
	(16418),
	(16419),
	(16420),
	(16421),
	(16422),
	(16423),
	(16424),
	(16425),
	(16426),
	(16427),
	(16428),
	(16429),
	(16430),
	(16431),
	(16432),
	(16433),
	(16434),
	(16435),
	(16436),
	(16437),
	(16438),
	(16439),
	(16440),
	(16441),
	(16442),
	(16443),
	(16444),
	(16445),
	(16446),
	(16447),
	(16448),
	(16449),
	(16450),
	(16451),
	(16452),
	(16453),
	(16454),
	(16455),
	(16456),
	(16457),
	(16458),
	(16459),
	(16460),
	(16461),
	(16462),
	(16463),
	(16464),
	(16465),
	(16466),
	(16467),
	(16468),
	(16469),
	(16470),
	(16471),
	(16472),
	(16473),
	(16474),
	(16475),
	(16476),
	(16477),
	(16478),
	(16479),
	(16480),
	(16481),
	(16482),
	(16483),
	(16484),
	(16485),
	(16486),
	(16487),
	(16488),
	(16489),
	(16490),
	(16491),
	(16492),
	(16493),
	(16494),
	(16495),
	(16496),
	(16497),
	(16498),
	(16499),
	(16500),
	(16501),
	(16502),
	(16503),
	(16504),
	(16505),
	(16506),
	(16507),
	(16508),
	(16509),
	(16510),
	(16511),
	(16512),
	(16513),
	(16514),
	(16515),
	(16516),
	(16517),
	(16518),
	(16519),
	(16520),
	(16521),
	(16522),
	(16523),
	(16524),
	(16525),
	(16526),
	(16527),
	(16528),
	(16529),
	(16530),
	(16531),
	(16532),
	(16533),
	(16534),
	(16535),
	(16536),
	(16537),
	(16538),
	(16539),
	(16540),
	(16541),
	(16542),
	(16543),
	(16544),
	(16545),
	(16546),
	(16547),
	(16548),
	(16549),
	(16550),
	(16551),
	(16552),
	(16553),
	(16554),
	(16555),
	(16556),
	(16557),
	(16558),
	(16559),
	(16560),
	(16561),
	(16562),
	(16563),
	(16564),
	(16565),
	(16566),
	(16567),
	(16568),
	(16569),
	(16570),
	(16571),
	(16572),
	(16573),
	(16574),
	(16575),
	(16576),
	(16577),
	(16578),
	(16579),
	(16580),
	(16581),
	(16582),
	(16583),
	(16584),
	(16585),
	(16586),
	(16587),
	(16588),
	(16589),
	(16590),
	(16591),
	(16592),
	(16593),
	(16594),
	(16595),
	(16596),
	(16597),
	(16598),
	(16599),
	(16600),
	(16601),
	(16602),
	(16603),
	(16604),
	(16605),
	(16606),
	(16607),
	(16608),
	(16609),
	(16610),
	(16611),
	(16612),
	(16613),
	(16614),
	(16615),
	(16616),
	(16617),
	(16618),
	(16619),
	(16620),
	(16621),
	(16622),
	(16623),
	(16624),
	(16625),
	(16626),
	(16627),
	(16628),
	(16629),
	(16630),
	(16631),
	(16632),
	(16633),
	(16634),
	(16635),
	(16636),
	(16637),
	(16638),
	(16639),
	(16640),
	(16641),
	(16642),
	(16643),
	(16644),
	(16645),
	(16646),
	(16647),
	(16648),
	(16649),
	(16650),
	(16651),
	(16652),
	(16653),
	(16654),
	(16655),
	(16656),
	(16657),
	(16658),
	(16659),
	(16660),
	(16661),
	(16662),
	(16663),
	(16664),
	(16665),
	(16666),
	(16667),
	(16668),
	(16669),
	(16670),
	(16671),
	(16672),
	(16673),
	(16674),
	(16675),
	(16676),
	(16677),
	(16678),
	(16679),
	(16680),
	(16681),
	(16682),
	(16683),
	(16684),
	(16685),
	(16686),
	(16687),
	(16688),
	(16689),
	(16690),
	(16691),
	(16692),
	(16693),
	(16694),
	(16695),
	(16696),
	(16697),
	(16698),
	(16699),
	(16700),
	(16701),
	(16702),
	(16703),
	(16704),
	(16705),
	(16706),
	(16707),
	(16708),
	(16709),
	(16710),
	(16711),
	(16712),
	(16713),
	(16714),
	(16715),
	(16716),
	(16717),
	(16718),
	(16719),
	(16720),
	(16721),
	(16722),
	(16723),
	(16724),
	(16725),
	(16726),
	(16727),
	(16728),
	(16729),
	(16730),
	(16731),
	(16732),
	(16733),
	(16734),
	(16735),
	(16736),
	(16737),
	(16738),
	(16739),
	(16740),
	(16741),
	(16742),
	(16743),
	(16744),
	(16745),
	(16746),
	(16747),
	(16748),
	(16749),
	(16750),
	(16751),
	(16752),
	(16753),
	(16754),
	(16755),
	(16756),
	(16757),
	(16758),
	(16759),
	(16760),
	(16761),
	(16762),
	(16763),
	(16764),
	(16765),
	(16766),
	(16767),
	(16768),
	(16769),
	(16770),
	(16771),
	(16772),
	(16773),
	(16774),
	(16775),
	(16776),
	(16777),
	(16778),
	(16779),
	(16780),
	(16781),
	(16782),
	(16783),
	(16784),
	(16785),
	(16786),
	(16787),
	(16788),
	(16789),
	(16790),
	(16791),
	(16792),
	(16793),
	(16794),
	(16795),
	(16796),
	(16797),
	(16798),
	(16799),
	(16800),
	(16801),
	(16802),
	(16803),
	(16804),
	(16805),
	(16806),
	(16807),
	(16808),
	(16809),
	(16810),
	(16811),
	(16812),
	(16813),
	(16814),
	(16815),
	(16816),
	(16817),
	(16818),
	(16819),
	(16820),
	(16821),
	(16822),
	(16823),
	(16824),
	(16825),
	(16826),
	(16827),
	(16828),
	(16829),
	(16830),
	(16831),
	(16832),
	(16833),
	(16834),
	(16835),
	(16836),
	(16837),
	(16838),
	(16839),
	(16840),
	(16841),
	(16842),
	(16843),
	(16844),
	(16845),
	(16846),
	(16847),
	(16848),
	(16849),
	(16850),
	(16851),
	(16852),
	(16853),
	(16854),
	(16855),
	(16856),
	(16857),
	(16858),
	(16859),
	(16860),
	(16861),
	(16862),
	(16863),
	(16864),
	(16865),
	(16866),
	(16867),
	(16868),
	(16869),
	(16870),
	(16871),
	(16872),
	(16873),
	(16874),
	(16875),
	(16876),
	(16877),
	(16878),
	(16879),
	(16880),
	(16881),
	(16882),
	(16883),
	(16884),
	(16885),
	(16886),
	(16887),
	(16888),
	(16889),
	(16890),
	(16891),
	(16892),
	(16893),
	(16894),
	(16895),
	(16896),
	(16897),
	(16898),
	(16899),
	(16900),
	(16901),
	(16902),
	(16903),
	(16904),
	(16905),
	(16906),
	(16907),
	(16908),
	(16909),
	(16910),
	(16911),
	(16912),
	(16913),
	(16914),
	(16915),
	(16916),
	(16917),
	(16918),
	(16919),
	(16920),
	(16921),
	(16922),
	(16923),
	(16924),
	(16925),
	(16926),
	(16927),
	(16928),
	(16929),
	(16930),
	(16931),
	(16932),
	(16933),
	(16934),
	(16935),
	(16936),
	(16937),
	(16938),
	(16939),
	(16940),
	(16941),
	(16942),
	(16943),
	(16944),
	(16945),
	(16946),
	(16947),
	(16948),
	(16949),
	(16950),
	(16951),
	(16952),
	(16953),
	(16954),
	(16955),
	(16956),
	(16957),
	(16958),
	(16959),
	(16960),
	(16961),
	(16962),
	(16963),
	(16964),
	(16965),
	(16966),
	(16967),
	(16968),
	(16969),
	(16970),
	(16971),
	(16972),
	(16973),
	(16974),
	(16975),
	(16976),
	(16977),
	(16978),
	(16979),
	(16980),
	(16981),
	(16982),
	(16983),
	(16984),
	(16985),
	(16986),
	(16987),
	(16988),
	(16989),
	(16990),
	(16991),
	(16992),
	(16993),
	(16994),
	(16995),
	(16996),
	(16997),
	(16998),
	(16999),
	(17000),
	(17001),
	(17002),
	(17003),
	(17004),
	(17005),
	(17006),
	(17007),
	(17008),
	(17009),
	(17010),
	(17011),
	(17012),
	(17013),
	(17014),
	(17015),
	(17016),
	(17017),
	(17018),
	(17019),
	(17020),
	(17021),
	(17022),
	(17023),
	(17024),
	(17025),
	(17026),
	(17027),
	(17028),
	(17029),
	(17030),
	(17031),
	(17032),
	(17033),
	(17034),
	(17035),
	(17036),
	(17037),
	(17038),
	(17039),
	(17040),
	(17041),
	(17042),
	(17043),
	(17044),
	(17045),
	(17046),
	(17047),
	(17048),
	(17049),
	(17050),
	(17051),
	(17052),
	(17053),
	(17054),
	(17055),
	(17056),
	(17057),
	(17058),
	(17059),
	(17060),
	(17061),
	(17062),
	(17063),
	(17064),
	(17065),
	(17066),
	(17067),
	(17068),
	(17069),
	(17070),
	(17071),
	(17072),
	(17073),
	(17074),
	(17075),
	(17076),
	(17077),
	(17078),
	(17079),
	(17080),
	(17081),
	(17082),
	(17083),
	(17084),
	(17085),
	(17086),
	(17087),
	(17088),
	(17089),
	(17090),
	(17091),
	(17092),
	(17093),
	(17094),
	(17095),
	(17096),
	(17097),
	(17098),
	(17099),
	(17100),
	(17101),
	(17102),
	(17103),
	(17104),
	(17105),
	(17106),
	(17107),
	(17108),
	(17109),
	(17110),
	(17111),
	(17112),
	(17113),
	(17114),
	(17115),
	(17116),
	(17117),
	(17118),
	(17119),
	(17120),
	(17121),
	(17122),
	(17123),
	(17124),
	(17125),
	(17126),
	(17127),
	(17128),
	(17129),
	(17130),
	(17131),
	(17132),
	(17133),
	(17134),
	(17135),
	(17136),
	(17137),
	(17138),
	(17139),
	(17140),
	(17141),
	(17142),
	(17143),
	(17144),
	(17145),
	(17146),
	(17147),
	(17148),
	(17149),
	(17150),
	(17151),
	(17152),
	(17153),
	(17154),
	(17155),
	(17156),
	(17157),
	(17158),
	(17159),
	(17160),
	(17161),
	(17162),
	(17163),
	(17164),
	(17165),
	(17166),
	(17167),
	(17168),
	(17169),
	(17170),
	(17171),
	(17172),
	(17173),
	(17174),
	(17175),
	(17176),
	(17177),
	(17178),
	(17179),
	(17180),
	(17181),
	(17182),
	(17183),
	(17184),
	(17185),
	(17186),
	(17187),
	(17188),
	(17189),
	(17190),
	(17191),
	(17192),
	(17193),
	(17194),
	(17195),
	(17196),
	(17197),
	(17198),
	(17199),
	(17200),
	(17201),
	(17202),
	(17203),
	(17204),
	(17205),
	(17206),
	(17207),
	(17208),
	(17209),
	(17210),
	(17211),
	(17212),
	(17213),
	(17214),
	(17215),
	(17216),
	(17217),
	(17218),
	(17219),
	(17220),
	(17221),
	(17222),
	(17223),
	(17224),
	(17225),
	(17226),
	(17227),
	(17228),
	(17229),
	(17230),
	(17231),
	(17232),
	(17233),
	(17234),
	(17235),
	(17236),
	(17237),
	(17238),
	(17239),
	(17240),
	(17241),
	(17242),
	(17243),
	(17244),
	(17245),
	(17246),
	(17247),
	(17248),
	(17249),
	(17250),
	(17251),
	(17252),
	(17253),
	(17254),
	(17255),
	(17256),
	(17257),
	(17258),
	(17259),
	(17260),
	(17261),
	(17262),
	(17263),
	(17264),
	(17265),
	(17266),
	(17267),
	(17268),
	(17269),
	(17270),
	(17271),
	(17272),
	(17273),
	(17274),
	(17275),
	(17276),
	(17277),
	(17278),
	(17279),
	(17280),
	(17281),
	(17282),
	(17283),
	(17284),
	(17285),
	(17286),
	(17287),
	(17288),
	(17289),
	(17290),
	(17291),
	(17292),
	(17293),
	(17294),
	(17295),
	(17296),
	(17297),
	(17298),
	(17299),
	(17300),
	(17301),
	(17302),
	(17303),
	(17304),
	(17305),
	(17306),
	(17307),
	(17308),
	(17309),
	(17310),
	(17311),
	(17312),
	(17313),
	(17314),
	(17315),
	(17316),
	(17317),
	(17318),
	(17319),
	(17320),
	(17321),
	(17322),
	(17323),
	(17324),
	(17325),
	(17326),
	(17327),
	(17328),
	(17329),
	(17330),
	(17331),
	(17332),
	(17333),
	(17334),
	(17335),
	(17336),
	(17337),
	(17338),
	(17339),
	(17340),
	(17341),
	(17342),
	(17343),
	(17344),
	(17345),
	(17346),
	(17347),
	(17348),
	(17349),
	(17350),
	(17351),
	(17352),
	(17353),
	(17354),
	(17355),
	(17356),
	(17357),
	(17358),
	(17359),
	(17360),
	(17361),
	(17362),
	(17363),
	(17364),
	(17365),
	(17366),
	(17367),
	(17368),
	(17369),
	(17370),
	(17371),
	(17372),
	(17373),
	(17374),
	(17375),
	(17376),
	(17377),
	(17378),
	(17379),
	(17380),
	(17381),
	(17382),
	(17383),
	(17384),
	(17385),
	(17386),
	(17387),
	(17388),
	(17389),
	(17390),
	(17391),
	(17392),
	(17393),
	(17394),
	(17395),
	(17396),
	(17397),
	(17398),
	(17399),
	(17400),
	(17401),
	(17402),
	(17403),
	(17404),
	(17405),
	(17406),
	(17407),
	(17408),
	(17409),
	(17410),
	(17411),
	(17412),
	(17413),
	(17414),
	(17415),
	(17416),
	(17417),
	(17418),
	(17419),
	(17420),
	(17421),
	(17422),
	(17423),
	(17424),
	(17425),
	(17426),
	(17427),
	(17428),
	(17429),
	(17430),
	(17431),
	(17432),
	(17433),
	(17434),
	(17435),
	(17436),
	(17437),
	(17438),
	(17439),
	(17440),
	(17441),
	(17442),
	(17443),
	(17444),
	(17445),
	(17446),
	(17447),
	(17448),
	(17449),
	(17450),
	(17451),
	(17452),
	(17453),
	(17454),
	(17455),
	(17456),
	(17457),
	(17458),
	(17459),
	(17460),
	(17461),
	(17462),
	(17463),
	(17464),
	(17465),
	(17466),
	(17467),
	(17468),
	(17469),
	(17470),
	(17471),
	(17472),
	(17473),
	(17474),
	(17475),
	(17476),
	(17477),
	(17478),
	(17479),
	(17480),
	(17481),
	(17482),
	(17483),
	(17484),
	(17485),
	(17486),
	(17487),
	(17488),
	(17489),
	(17490),
	(17491),
	(17492),
	(17493),
	(17494),
	(17495),
	(17496),
	(17497),
	(17498),
	(17499),
	(17500),
	(17501),
	(17502),
	(17503),
	(17504),
	(17505),
	(17506),
	(17507),
	(17508),
	(17509),
	(17510),
	(17511),
	(17512),
	(17513),
	(17514),
	(17515),
	(17516),
	(17517),
	(17518),
	(17519),
	(17520),
	(17521),
	(17522),
	(17523),
	(17524),
	(17525),
	(17526),
	(17527),
	(17528),
	(17529),
	(17530),
	(17531),
	(17532),
	(17533),
	(17534),
	(17535),
	(17536),
	(17537),
	(17538),
	(17539),
	(17540),
	(17541),
	(17542),
	(17543),
	(17544),
	(17545),
	(17546),
	(17547),
	(17548),
	(17549),
	(17550),
	(17551),
	(17552),
	(17553),
	(17554),
	(17555),
	(17556),
	(17557),
	(17558),
	(17559),
	(17560),
	(17561),
	(17562),
	(17563),
	(17564),
	(17565),
	(17566),
	(17567),
	(17568),
	(17569),
	(17570),
	(17571),
	(17572),
	(17573),
	(17574),
	(17575),
	(17576),
	(17577),
	(17578),
	(17579),
	(17580),
	(17581),
	(17582),
	(17583),
	(17584),
	(17585),
	(17586),
	(17587),
	(17588),
	(17589),
	(17590),
	(17591),
	(17592),
	(17593),
	(17594),
	(17595),
	(17596),
	(17597),
	(17598),
	(17599),
	(17600),
	(17601),
	(17602),
	(17603),
	(17604),
	(17605),
	(17606),
	(17607),
	(17608),
	(17609),
	(17610),
	(17611),
	(17612),
	(17613),
	(17614),
	(17615),
	(17616),
	(17617),
	(17618),
	(17619),
	(17620),
	(17621),
	(17622),
	(17623),
	(17624),
	(17625),
	(17626),
	(17627),
	(17628),
	(17629),
	(17630),
	(17631),
	(17632),
	(17633),
	(17634),
	(17635),
	(17636),
	(17637),
	(17638),
	(17639),
	(17640),
	(17641),
	(17642),
	(17643),
	(17644),
	(17645),
	(17646),
	(17647),
	(17648),
	(17649),
	(17650),
	(17651),
	(17652),
	(17653),
	(17654),
	(17655),
	(17656),
	(17657),
	(17658),
	(17659),
	(17660),
	(17661),
	(17662),
	(17663),
	(17664),
	(17665),
	(17666),
	(17667),
	(17668),
	(17669),
	(17670),
	(17671),
	(17672),
	(17673),
	(17674),
	(17675),
	(17676),
	(17677),
	(17678),
	(17679),
	(17680),
	(17681),
	(17682),
	(17683),
	(17684),
	(17685),
	(17686),
	(17687),
	(17688),
	(17689),
	(17690),
	(17691),
	(17692),
	(17693),
	(17694),
	(17695),
	(17696),
	(17697),
	(17698),
	(17699),
	(17700),
	(17701),
	(17702),
	(17703),
	(17704),
	(17705),
	(17706),
	(17707),
	(17708),
	(17709),
	(17710),
	(17711),
	(17712),
	(17713),
	(17714),
	(17715),
	(17716),
	(17717),
	(17718),
	(17719),
	(17720),
	(17721),
	(17722),
	(17723),
	(17724),
	(17725),
	(17726),
	(17727),
	(17728),
	(17729),
	(17730),
	(17731),
	(17732),
	(17733),
	(17734),
	(17735),
	(17736),
	(17737),
	(17738),
	(17739),
	(17740),
	(17741),
	(17742),
	(17743),
	(17744),
	(17745),
	(17746),
	(17747),
	(17748),
	(17749),
	(17750),
	(17751),
	(17752),
	(17753),
	(17754),
	(17755),
	(17756),
	(17757),
	(17758),
	(17759),
	(17760),
	(17761),
	(17762),
	(17763),
	(17764),
	(17765),
	(17766),
	(17767),
	(17768),
	(17769),
	(17770),
	(17771),
	(17772),
	(17773),
	(17774),
	(17775),
	(17776),
	(17777),
	(17778),
	(17779),
	(17780),
	(17781),
	(17782),
	(17783),
	(17784),
	(17785),
	(17786),
	(17787),
	(17788),
	(17789),
	(17790),
	(17791),
	(17792),
	(17793),
	(17794),
	(17795),
	(17796),
	(17797),
	(17798),
	(17799),
	(17800),
	(17801),
	(17802),
	(17803),
	(17804),
	(17805),
	(17806),
	(17807),
	(17808),
	(17809),
	(17810),
	(17811),
	(17812),
	(17813),
	(17814),
	(17815),
	(17816),
	(17817),
	(17818),
	(17819),
	(17820),
	(17821),
	(17822),
	(17823),
	(17824),
	(17825),
	(17826),
	(17827),
	(17828),
	(17829),
	(17830),
	(17831),
	(17832),
	(17833),
	(17834),
	(17835),
	(17836),
	(17837),
	(17838),
	(17839),
	(17840),
	(17841),
	(17842),
	(17843),
	(17844),
	(17845),
	(17846),
	(17847),
	(17848),
	(17849),
	(17850),
	(17851),
	(17852),
	(17853),
	(17854),
	(17855),
	(17856),
	(17857),
	(17858),
	(17859),
	(17860),
	(17861),
	(17862),
	(17863),
	(17864),
	(17865),
	(17866),
	(17867),
	(17868),
	(17869),
	(17870),
	(17871),
	(17872),
	(17873),
	(17874),
	(17875),
	(17876),
	(17877),
	(17878),
	(17879),
	(17880),
	(17881),
	(17882),
	(17883),
	(17884),
	(17885),
	(17886),
	(17887),
	(17888),
	(17889),
	(17890),
	(17891),
	(17892),
	(17893),
	(17894),
	(17895),
	(17896),
	(17897),
	(17898),
	(17899),
	(17900),
	(17901),
	(17902),
	(17903),
	(17904),
	(17905),
	(17906),
	(17907),
	(17908),
	(17909),
	(17910),
	(17911),
	(17912),
	(17913),
	(17914),
	(17915),
	(17916),
	(17917),
	(17918),
	(17919),
	(17920),
	(17921),
	(17922),
	(17923),
	(17924),
	(17925),
	(17926),
	(17927),
	(17928),
	(17929),
	(17930),
	(17931),
	(17932),
	(17933),
	(17934),
	(17935),
	(17936),
	(17937),
	(17938),
	(17939),
	(17940),
	(17941),
	(17942),
	(17943),
	(17944),
	(17945),
	(17946),
	(17947),
	(17948),
	(17949),
	(17950),
	(17951),
	(17952),
	(17953),
	(17954),
	(17955),
	(17956),
	(17957),
	(17958),
	(17959),
	(17960),
	(17961),
	(17962),
	(17963),
	(17964),
	(17965),
	(17966),
	(17967),
	(17968),
	(17969),
	(17970),
	(17971),
	(17972),
	(17973),
	(17974),
	(17975),
	(17976),
	(17977),
	(17978),
	(17979),
	(17980),
	(17981),
	(17982),
	(17983),
	(17984),
	(17985),
	(17986),
	(17987),
	(17988),
	(17989),
	(17990),
	(17991),
	(17992),
	(17993),
	(17994),
	(17995),
	(17996),
	(17997),
	(17998),
	(17999),
	(18000),
	(18001),
	(18002),
	(18003),
	(18004),
	(18005),
	(18006),
	(18007),
	(18008),
	(18009),
	(18010),
	(18011),
	(18012),
	(18013),
	(18014),
	(18015),
	(18016),
	(18017),
	(18018),
	(18019),
	(18020),
	(18021),
	(18022),
	(18023),
	(18024),
	(18025),
	(18026),
	(18027),
	(18028),
	(18029),
	(18030),
	(18031),
	(18032),
	(18033),
	(18034),
	(18035),
	(18036),
	(18037),
	(18038),
	(18039),
	(18040),
	(18041),
	(18042),
	(18043),
	(18044),
	(18045),
	(18046),
	(18047),
	(18048),
	(18049),
	(18050),
	(18051),
	(18052),
	(18053),
	(18054),
	(18055),
	(18056),
	(18057),
	(18058),
	(18059),
	(18060),
	(18061),
	(18062),
	(18063),
	(18064),
	(18065),
	(18066),
	(18067),
	(18068),
	(18069),
	(18070),
	(18071),
	(18072),
	(18073),
	(18074),
	(18075),
	(18076),
	(18077),
	(18078),
	(18079),
	(18080),
	(18081),
	(18082),
	(18083),
	(18084),
	(18085),
	(18086),
	(18087),
	(18088),
	(18089),
	(18090),
	(18091),
	(18092),
	(18093),
	(18094),
	(18095),
	(18096),
	(18097),
	(18098),
	(18099),
	(18100),
	(18101),
	(18102),
	(18103),
	(18104),
	(18105),
	(18106),
	(18107),
	(18108),
	(18109),
	(18110),
	(18111),
	(18112),
	(18113),
	(18114),
	(18115),
	(18116),
	(18117),
	(18118),
	(18119),
	(18120),
	(18121),
	(18122),
	(18123),
	(18124),
	(18125),
	(18126),
	(18127),
	(18128),
	(18129),
	(18130),
	(18131),
	(18132),
	(18133),
	(18134),
	(18135),
	(18136),
	(18137),
	(18138),
	(18139),
	(18140),
	(18141),
	(18142),
	(18143),
	(18144),
	(18145),
	(18146),
	(18147),
	(18148),
	(18149),
	(18150),
	(18151),
	(18152),
	(18153),
	(18154),
	(18155),
	(18156),
	(18157),
	(18158),
	(18159),
	(18160),
	(18161),
	(18162),
	(18163),
	(18164),
	(18165),
	(18166),
	(18167),
	(18168),
	(18169),
	(18170),
	(18171),
	(18172),
	(18173),
	(18174),
	(18175),
	(18176),
	(18177),
	(18178),
	(18179),
	(18180),
	(18181),
	(18182),
	(18183),
	(18184),
	(18185),
	(18186),
	(18187),
	(18188),
	(18189),
	(18190),
	(18191),
	(18192),
	(18193),
	(18194),
	(18195),
	(18196),
	(18197),
	(18198),
	(18199),
	(18200),
	(18201),
	(18202),
	(18203),
	(18204),
	(18205),
	(18206),
	(18207),
	(18208),
	(18209),
	(18210),
	(18211),
	(18212),
	(18213),
	(18214),
	(18215),
	(18216),
	(18217),
	(18218),
	(18219),
	(18220),
	(18221),
	(18222),
	(18223),
	(18224),
	(18225),
	(18226),
	(18227),
	(18228),
	(18229),
	(18230),
	(18231),
	(18232),
	(18233),
	(18234),
	(18235),
	(18236),
	(18237),
	(18238),
	(18239),
	(18240),
	(18241),
	(18242),
	(18243),
	(18244),
	(18245),
	(18246),
	(18247),
	(18248),
	(18249),
	(18250),
	(18251),
	(18252),
	(18253),
	(18254),
	(18255),
	(18256),
	(18257),
	(18258),
	(18259),
	(18260),
	(18261),
	(18262),
	(18263),
	(18264),
	(18265),
	(18266),
	(18267),
	(18268),
	(18269),
	(18270),
	(18271),
	(18272),
	(18273),
	(18274),
	(18275),
	(18276),
	(18277),
	(18278),
	(18279),
	(18280),
	(18281),
	(18282),
	(18283),
	(18284),
	(18285),
	(18286),
	(18287),
	(18288),
	(18289),
	(18290),
	(18291),
	(18292),
	(18293),
	(18294),
	(18295),
	(18296),
	(18297),
	(18298),
	(18299),
	(18300),
	(18301),
	(18302),
	(18303),
	(18304),
	(18305),
	(18306),
	(18307),
	(18308),
	(18309),
	(18310),
	(18311),
	(18312),
	(18313),
	(18314),
	(18315),
	(18316),
	(18317),
	(18318),
	(18319),
	(18320),
	(18321),
	(18322),
	(18323),
	(18324),
	(18325),
	(18326),
	(18327),
	(18328),
	(18329),
	(18330),
	(18331),
	(18332),
	(18333),
	(18334),
	(18335),
	(18336),
	(18337),
	(18338),
	(18339),
	(18340),
	(18341),
	(18342),
	(18343),
	(18344),
	(18345),
	(18346),
	(18347),
	(18348),
	(18349),
	(18350),
	(18351),
	(18352),
	(18353),
	(18354),
	(18355),
	(18356),
	(18357),
	(18358),
	(18359),
	(18360),
	(18361),
	(18362),
	(18363),
	(18364),
	(18365),
	(18366),
	(18367),
	(18368),
	(18369),
	(18370),
	(18371),
	(18372),
	(18373),
	(18374),
	(18375),
	(18376),
	(18377),
	(18378),
	(18379),
	(18380),
	(18381),
	(18382),
	(18383),
	(18384),
	(18385),
	(18386),
	(18387),
	(18388),
	(18389),
	(18390),
	(18391),
	(18392),
	(18393),
	(18394),
	(18395),
	(18396),
	(18397),
	(18398),
	(18399),
	(18400),
	(18401),
	(18402),
	(18403),
	(18404),
	(18405),
	(18406),
	(18407),
	(18408),
	(18409),
	(18410),
	(18411),
	(18412),
	(18413),
	(18414),
	(18415),
	(18416),
	(18417),
	(18418),
	(18419),
	(18420),
	(18421),
	(18422),
	(18423),
	(18424),
	(18425),
	(18426),
	(18427),
	(18428),
	(18429),
	(18430),
	(18431),
	(18432),
	(18433),
	(18434),
	(18435),
	(18436),
	(18437),
	(18438),
	(18439),
	(18440),
	(18441),
	(18442),
	(18443),
	(18444),
	(18445),
	(18446),
	(18447),
	(18448),
	(18449),
	(18450),
	(18451),
	(18452),
	(18453),
	(18454),
	(18455),
	(18456),
	(18457),
	(18458),
	(18459),
	(18460),
	(18461),
	(18462),
	(18463),
	(18464),
	(18465),
	(18466),
	(18467),
	(18468),
	(18469),
	(18470),
	(18471),
	(18472),
	(18473),
	(18474),
	(18475),
	(18476),
	(18477),
	(18478),
	(18479),
	(18480),
	(18481),
	(18482),
	(18483),
	(18484),
	(18485),
	(18486),
	(18487),
	(18488),
	(18489),
	(18490),
	(18491),
	(18492),
	(18493),
	(18494),
	(18495),
	(18496),
	(18497),
	(18498),
	(18499),
	(18500),
	(18501),
	(18502),
	(18503),
	(18504),
	(18505),
	(18506),
	(18507),
	(18508),
	(18509),
	(18510),
	(18511),
	(18512),
	(18513),
	(18514),
	(18515),
	(18516),
	(18517),
	(18518),
	(18519),
	(18520),
	(18521),
	(18522),
	(18523),
	(18524),
	(18525),
	(18526),
	(18527),
	(18528),
	(18529),
	(18530),
	(18531),
	(18532),
	(18533),
	(18534),
	(18535),
	(18536),
	(18537),
	(18538),
	(18539),
	(18540),
	(18541),
	(18542),
	(18543),
	(18544),
	(18545),
	(18546),
	(18547),
	(18548),
	(18549),
	(18550),
	(18551),
	(18552),
	(18553),
	(18554),
	(18555),
	(18556),
	(18557),
	(18558),
	(18559),
	(18560),
	(18561),
	(18562),
	(18563),
	(18564),
	(18565),
	(18566),
	(18567),
	(18568),
	(18569),
	(18570),
	(18571),
	(18572),
	(18573),
	(18574),
	(18575),
	(18576),
	(18577),
	(18578),
	(18579),
	(18580),
	(18581),
	(18582),
	(18583),
	(18584),
	(18585),
	(18586),
	(18587),
	(18588),
	(18589),
	(18590),
	(18591),
	(18592),
	(18593),
	(18594),
	(18595),
	(18596),
	(18597),
	(18598),
	(18599),
	(18600),
	(18601),
	(18602),
	(18603),
	(18604),
	(18605),
	(18606),
	(18607),
	(18608),
	(18609),
	(18610),
	(18611),
	(18612),
	(18613),
	(18614),
	(18615),
	(18616),
	(18617),
	(18618),
	(18619),
	(18620),
	(18621),
	(18622),
	(18623),
	(18624),
	(18625),
	(18626),
	(18627),
	(18628),
	(18629),
	(18630),
	(18631),
	(18632),
	(18633),
	(18634),
	(18635),
	(18636),
	(18637),
	(18638),
	(18639),
	(18640),
	(18641),
	(18642),
	(18643),
	(18644),
	(18645),
	(18646),
	(18647),
	(18648),
	(18649),
	(18650),
	(18651),
	(18652),
	(18653),
	(18654),
	(18655),
	(18656),
	(18657),
	(18658),
	(18659),
	(18660),
	(18661),
	(18662),
	(18663),
	(18664),
	(18665),
	(18666),
	(18667),
	(18668),
	(18669),
	(18670),
	(18671),
	(18672),
	(18673),
	(18674),
	(18675),
	(18676),
	(18677),
	(18678),
	(18679),
	(18680),
	(18681),
	(18682),
	(18683),
	(18684),
	(18685),
	(18686),
	(18687),
	(18688),
	(18689),
	(18690),
	(18691),
	(18692),
	(18693),
	(18694),
	(18695),
	(18696),
	(18697),
	(18698),
	(18699),
	(18700),
	(18701),
	(18702),
	(18703),
	(18704),
	(18705),
	(18706),
	(18707),
	(18708),
	(18709),
	(18710),
	(18711),
	(18712),
	(18713),
	(18714),
	(18715),
	(18716),
	(18717),
	(18718),
	(18719),
	(18720),
	(18721),
	(18722),
	(18723),
	(18724),
	(18725),
	(18726),
	(18727),
	(18728),
	(18729),
	(18730),
	(18731),
	(18732),
	(18733),
	(18734),
	(18735),
	(18736),
	(18737),
	(18738),
	(18739),
	(18740),
	(18741),
	(18742),
	(18743),
	(18744),
	(18745),
	(18746),
	(18747),
	(18748),
	(18749),
	(18750),
	(18751),
	(18752),
	(18753),
	(18754),
	(18755),
	(18756),
	(18757),
	(18758),
	(18759),
	(18760),
	(18761),
	(18762),
	(18763),
	(18764),
	(18765),
	(18766),
	(18767),
	(18768),
	(18769),
	(18770),
	(18771),
	(18772),
	(18773),
	(18774),
	(18775),
	(18776),
	(18777),
	(18778),
	(18779),
	(18780),
	(18781),
	(18782),
	(18783),
	(18784),
	(18785),
	(18786),
	(18787),
	(18788),
	(18789),
	(18790),
	(18791),
	(18792),
	(18793),
	(18794),
	(18795),
	(18796),
	(18797),
	(18798),
	(18799),
	(18800),
	(18801),
	(18802),
	(18803),
	(18804),
	(18805),
	(18806),
	(18807),
	(18808),
	(18809),
	(18810),
	(18811),
	(18812),
	(18813),
	(18814),
	(18815),
	(18816),
	(18817),
	(18818),
	(18819),
	(18820),
	(18821),
	(18822),
	(18823),
	(18824),
	(18825),
	(18826),
	(18827),
	(18828),
	(18829),
	(18830),
	(18831),
	(18832),
	(18833),
	(18834),
	(18835),
	(18836),
	(18837),
	(18838),
	(18839),
	(18840),
	(18841),
	(18842),
	(18843),
	(18844),
	(18845),
	(18846),
	(18847),
	(18848),
	(18849),
	(18850),
	(18851),
	(18852),
	(18853),
	(18854),
	(18855),
	(18856),
	(18857),
	(18858),
	(18859),
	(18860),
	(18861),
	(18862),
	(18863),
	(18864),
	(18865),
	(18866),
	(18867),
	(18868),
	(18869),
	(18870),
	(18871),
	(18872),
	(18873),
	(18874),
	(18875),
	(18876),
	(18877),
	(18878),
	(18879),
	(18880),
	(18881),
	(18882),
	(18883),
	(18884),
	(18885),
	(18886),
	(18887),
	(18888),
	(18889),
	(18890),
	(18891),
	(18892),
	(18893),
	(18894),
	(18895),
	(18896),
	(18897),
	(18898),
	(18899),
	(18900),
	(18901),
	(18902),
	(18903),
	(18904),
	(18905),
	(18906),
	(18907),
	(18908),
	(18909),
	(18910),
	(18911),
	(18912),
	(18913),
	(18914),
	(18915),
	(18916),
	(18917),
	(18918),
	(18919),
	(18920),
	(18921),
	(18922),
	(18923),
	(18924),
	(18925),
	(18926),
	(18927),
	(18928),
	(18929),
	(18930),
	(18931),
	(18932),
	(18933),
	(18934),
	(18935),
	(18936),
	(18937),
	(18938),
	(18939),
	(18940),
	(18941),
	(18942),
	(18943),
	(18944),
	(18945),
	(18946),
	(18947),
	(18948),
	(18949),
	(18950),
	(18951),
	(18952),
	(18953),
	(18954),
	(18955),
	(18956),
	(18957),
	(18958),
	(18959),
	(18960),
	(18961),
	(18962),
	(18963),
	(18964),
	(18965),
	(18966),
	(18967),
	(18968),
	(18969),
	(18970),
	(18971),
	(18972),
	(18973),
	(18974),
	(18975),
	(18976),
	(18977),
	(18978),
	(18979),
	(18980),
	(18981),
	(18982),
	(18983),
	(18984),
	(18985),
	(18986),
	(18987),
	(18988),
	(18989),
	(18990),
	(18991),
	(18992),
	(18993),
	(18994),
	(18995),
	(18996),
	(18997),
	(18998),
	(18999),
	(19000),
	(19001),
	(19002),
	(19003),
	(19004),
	(19005),
	(19006),
	(19007),
	(19008),
	(19009),
	(19010),
	(19011),
	(19012),
	(19013),
	(19014),
	(19015),
	(19016),
	(19017),
	(19018),
	(19019),
	(19020),
	(19021),
	(19022),
	(19023),
	(19024),
	(19025),
	(19026),
	(19027),
	(19028),
	(19029),
	(19030),
	(19031),
	(19032),
	(19033),
	(19034),
	(19035),
	(19036),
	(19037),
	(19038),
	(19039),
	(19040),
	(19041),
	(19042),
	(19043),
	(19044),
	(19045),
	(19046),
	(19047),
	(19048),
	(19049),
	(19050),
	(19051),
	(19052),
	(19053),
	(19054),
	(19055),
	(19056),
	(19057),
	(19058),
	(19059),
	(19060),
	(19061),
	(19062),
	(19063),
	(19064),
	(19065),
	(19066),
	(19067),
	(19068),
	(19069),
	(19070),
	(19071),
	(19072),
	(19073),
	(19074),
	(19075),
	(19076),
	(19077),
	(19078),
	(19079),
	(19080),
	(19081),
	(19082),
	(19083),
	(19084),
	(19085),
	(19086),
	(19087),
	(19088),
	(19089),
	(19090),
	(19091),
	(19092),
	(19093),
	(19094),
	(19095),
	(19096),
	(19097),
	(19098),
	(19099),
	(19100),
	(19101),
	(19102),
	(19103),
	(19104),
	(19105),
	(19106),
	(19107),
	(19108),
	(19109),
	(19110),
	(19111),
	(19112),
	(19113),
	(19114),
	(19115),
	(19116),
	(19117),
	(19118),
	(19119),
	(19120),
	(19121),
	(19122),
	(19123),
	(19124),
	(19125),
	(19126),
	(19127),
	(19128),
	(19129),
	(19130),
	(19131),
	(19132),
	(19133),
	(19134),
	(19135),
	(19136),
	(19137),
	(19138),
	(19139),
	(19140),
	(19141),
	(19142),
	(19143),
	(19144),
	(19145),
	(19146),
	(19147),
	(19148),
	(19149),
	(19150),
	(19151),
	(19152),
	(19153),
	(19154),
	(19155),
	(19156),
	(19157),
	(19158),
	(19159),
	(19160),
	(19161),
	(19162),
	(19163),
	(19164),
	(19165),
	(19166),
	(19167),
	(19168),
	(19169),
	(19170),
	(19171),
	(19172),
	(19173),
	(19174),
	(19175),
	(19176),
	(19177),
	(19178),
	(19179),
	(19180),
	(19181),
	(19182),
	(19183),
	(19184),
	(19185),
	(19186),
	(19187),
	(19188),
	(19189),
	(19190),
	(19191),
	(19192),
	(19193),
	(19194),
	(19195),
	(19196),
	(19197),
	(19198),
	(19199),
	(19200),
	(19201),
	(19202),
	(19203),
	(19204),
	(19205),
	(19206),
	(19207),
	(19208),
	(19209),
	(19210),
	(19211),
	(19212),
	(19213),
	(19214),
	(19215),
	(19216),
	(19217),
	(19218),
	(19219),
	(19220),
	(19221),
	(19222),
	(19223),
	(19224),
	(19225),
	(19226),
	(19227),
	(19228),
	(19229),
	(19230),
	(19231),
	(19232),
	(19233),
	(19234),
	(19235),
	(19236),
	(19237),
	(19238),
	(19239),
	(19240),
	(19241),
	(19242),
	(19243),
	(19244),
	(19245),
	(19246),
	(19247),
	(19248),
	(19249),
	(19250),
	(19251),
	(19252),
	(19253),
	(19254),
	(19255),
	(19256),
	(19257),
	(19258),
	(19259),
	(19260),
	(19261),
	(19262),
	(19263),
	(19264),
	(19265),
	(19266),
	(19267),
	(19268),
	(19269),
	(19270),
	(19271),
	(19272),
	(19273),
	(19274),
	(19275),
	(19276),
	(19277),
	(19278),
	(19279),
	(19280),
	(19281),
	(19282),
	(19283),
	(19284),
	(19285),
	(19286),
	(19287),
	(19288),
	(19289),
	(19290),
	(19291),
	(19292),
	(19293),
	(19294),
	(19295),
	(19296),
	(19297),
	(19298),
	(19299),
	(19300),
	(19301),
	(19302),
	(19303),
	(19304),
	(19305),
	(19306),
	(19307),
	(19308),
	(19309),
	(19310),
	(19311),
	(19312),
	(19313),
	(19314),
	(19315),
	(19316),
	(19317),
	(19318),
	(19319),
	(19320),
	(19321),
	(19322),
	(19323),
	(19324),
	(19325),
	(19326),
	(19327),
	(19328),
	(19329),
	(19330),
	(19331),
	(19332),
	(19333),
	(19334),
	(19335),
	(19336),
	(19337),
	(19338),
	(19339),
	(19340),
	(19341),
	(19342),
	(19343),
	(19344),
	(19345),
	(19346),
	(19347),
	(19348),
	(19349),
	(19350),
	(19351),
	(19352),
	(19353),
	(19354),
	(19355),
	(19356),
	(19357),
	(19358),
	(19359),
	(19360),
	(19361),
	(19362),
	(19363),
	(19364),
	(19365),
	(19366),
	(19367),
	(19368),
	(19369),
	(19370),
	(19371),
	(19372),
	(19373),
	(19374),
	(19375),
	(19376),
	(19377),
	(19378),
	(19379),
	(19380),
	(19381),
	(19382),
	(19383),
	(19384),
	(19385),
	(19386),
	(19387),
	(19388),
	(19389),
	(19390),
	(19391),
	(19392),
	(19393),
	(19394),
	(19395),
	(19396),
	(19397),
	(19398),
	(19399),
	(19400),
	(19401),
	(19402),
	(19403),
	(19404),
	(19405),
	(19406),
	(19407),
	(19408),
	(19409),
	(19410),
	(19411),
	(19412),
	(19413),
	(19414),
	(19415),
	(19416),
	(19417),
	(19418),
	(19419),
	(19420),
	(19421),
	(19422),
	(19423),
	(19424),
	(19425),
	(19426),
	(19427),
	(19428),
	(19429),
	(19430),
	(19431),
	(19432),
	(19433),
	(19434),
	(19435),
	(19436),
	(19437),
	(19438),
	(19439),
	(19440),
	(19441),
	(19442),
	(19443),
	(19444),
	(19445),
	(19446),
	(19447),
	(19448),
	(19449),
	(19450),
	(19451),
	(19452),
	(19453),
	(19454),
	(19455),
	(19456),
	(19457),
	(19458),
	(19459),
	(19460),
	(19461),
	(19462),
	(19463),
	(19464),
	(19465),
	(19466),
	(19467),
	(19468),
	(19469),
	(19470),
	(19471),
	(19472),
	(19473),
	(19474),
	(19475),
	(19476),
	(19477),
	(19478),
	(19479),
	(19480),
	(19481),
	(19482),
	(19483),
	(19484),
	(19485),
	(19486),
	(19487),
	(19488),
	(19489),
	(19490),
	(19491),
	(19492),
	(19493),
	(19494),
	(19495),
	(19496),
	(19497),
	(19498),
	(19499),
	(19500),
	(19501),
	(19502),
	(19503),
	(19504),
	(19505),
	(19506),
	(19507),
	(19508),
	(19509),
	(19510),
	(19511),
	(19512),
	(19513),
	(19514),
	(19515),
	(19516),
	(19517),
	(19518),
	(19519),
	(19520),
	(19521),
	(19522),
	(19523),
	(19524),
	(19525),
	(19526),
	(19527),
	(19528),
	(19529),
	(19530),
	(19531),
	(19532),
	(19533),
	(19534),
	(19535),
	(19536),
	(19537),
	(19538),
	(19539),
	(19540),
	(19541),
	(19542),
	(19543),
	(19544),
	(19545),
	(19546),
	(19547),
	(19548),
	(19549),
	(19550),
	(19551),
	(19552),
	(19553),
	(19554),
	(19555),
	(19556),
	(19557),
	(19558),
	(19559),
	(19560),
	(19561),
	(19562),
	(19563),
	(19564),
	(19565),
	(19566),
	(19567),
	(19568),
	(19569),
	(19570),
	(19571),
	(19572),
	(19573),
	(19574),
	(19575),
	(19576),
	(19577),
	(19578),
	(19579),
	(19580),
	(19581),
	(19582),
	(19583),
	(19584),
	(19585),
	(19586),
	(19587),
	(19588),
	(19589),
	(19590),
	(19591),
	(19592),
	(19593),
	(19594),
	(19595),
	(19596),
	(19597),
	(19598),
	(19599),
	(19600),
	(19601),
	(19602),
	(19603),
	(19604),
	(19605),
	(19606),
	(19607),
	(19608),
	(19609),
	(19610),
	(19611),
	(19612),
	(19613),
	(19614),
	(19615),
	(19616),
	(19617),
	(19618),
	(19619),
	(19620),
	(19621),
	(19622),
	(19623),
	(19624),
	(19625),
	(19626),
	(19627),
	(19628),
	(19629),
	(19630),
	(19631),
	(19632),
	(19633),
	(19634),
	(19635),
	(19636),
	(19637),
	(19638),
	(19639),
	(19640),
	(19641),
	(19642),
	(19643),
	(19644),
	(19645),
	(19646),
	(19647),
	(19648),
	(19649),
	(19650),
	(19651),
	(19652),
	(19653),
	(19654),
	(19655),
	(19656),
	(19657),
	(19658),
	(19659),
	(19660),
	(19661),
	(19662),
	(19663),
	(19664),
	(19665),
	(19666),
	(19667),
	(19668),
	(19669),
	(19670),
	(19671),
	(19672),
	(19673),
	(19674),
	(19675),
	(19676),
	(19677),
	(19678),
	(19679),
	(19680),
	(19681),
	(19682),
	(19683),
	(19684),
	(19685),
	(19686),
	(19687),
	(19688),
	(19689),
	(19690),
	(19691),
	(19692),
	(19693),
	(19694),
	(19695),
	(19696),
	(19697),
	(19698),
	(19699),
	(19700),
	(19701),
	(19702),
	(19703),
	(19704),
	(19705),
	(19706),
	(19707),
	(19708),
	(19709),
	(19710),
	(19711),
	(19712),
	(19713),
	(19714),
	(19715),
	(19716),
	(19717),
	(19718),
	(19719),
	(19720),
	(19721),
	(19722),
	(19723),
	(19724),
	(19725),
	(19726),
	(19727),
	(19728),
	(19729),
	(19730),
	(19731),
	(19732),
	(19733),
	(19734),
	(19735),
	(19736),
	(19737),
	(19738),
	(19739),
	(19740),
	(19741),
	(19742),
	(19743),
	(19744),
	(19745),
	(19746),
	(19747),
	(19748),
	(19749),
	(19750),
	(19751),
	(19752),
	(19753),
	(19754),
	(19755),
	(19756),
	(19757),
	(19758),
	(19759),
	(19760),
	(19761),
	(19762),
	(19763),
	(19764),
	(19765),
	(19766),
	(19767),
	(19768),
	(19769),
	(19770),
	(19771),
	(19772),
	(19773),
	(19774),
	(19775),
	(19776),
	(19777),
	(19778),
	(19779),
	(19780),
	(19781),
	(19782),
	(19783),
	(19784),
	(19785),
	(19786),
	(19787),
	(19788),
	(19789),
	(19790),
	(19791),
	(19792),
	(19793),
	(19794),
	(19795),
	(19796),
	(19797),
	(19798),
	(19799),
	(19800),
	(19801),
	(19802),
	(19803),
	(19804),
	(19805),
	(19806),
	(19807),
	(19808),
	(19809),
	(19810),
	(19811),
	(19812),
	(19813),
	(19814),
	(19815),
	(19816),
	(19817),
	(19818),
	(19819),
	(19820),
	(19821),
	(19822),
	(19823),
	(19824),
	(19825),
	(19826),
	(19827),
	(19828),
	(19829),
	(19830),
	(19831),
	(19832),
	(19833),
	(19834),
	(19835),
	(19836),
	(19837),
	(19838),
	(19839),
	(19840),
	(19841),
	(19842),
	(19843),
	(19844),
	(19845),
	(19846),
	(19847),
	(19848),
	(19849),
	(19850),
	(19851),
	(19852),
	(19853),
	(19854),
	(19855),
	(19856),
	(19857),
	(19858),
	(19859),
	(19860),
	(19861),
	(19862),
	(19863),
	(19864),
	(19865),
	(19866),
	(19867),
	(19868),
	(19869),
	(19870),
	(19871),
	(19872),
	(19873),
	(19874),
	(19875),
	(19876),
	(19877),
	(19878),
	(19879),
	(19880),
	(19881),
	(19882),
	(19883),
	(19884),
	(19885),
	(19886),
	(19887),
	(19888),
	(19889),
	(19890),
	(19891),
	(19892),
	(19893),
	(19894),
	(19895),
	(19896),
	(19897),
	(19898),
	(19899),
	(19900),
	(19901),
	(19902),
	(19903),
	(19904),
	(19905),
	(19906),
	(19907),
	(19908),
	(19909),
	(19910),
	(19911),
	(19912),
	(19913),
	(19914),
	(19915),
	(19916),
	(19917),
	(19918),
	(19919),
	(19920),
	(19921),
	(19922),
	(19923),
	(19924),
	(19925),
	(19926),
	(19927),
	(19928),
	(19929),
	(19930),
	(19931),
	(19932),
	(19933),
	(19934),
	(19935),
	(19936),
	(19937),
	(19938),
	(19939),
	(19940),
	(19941),
	(19942),
	(19943),
	(19944),
	(19945),
	(19946),
	(19947),
	(19948),
	(19949),
	(19950),
	(19951),
	(19952),
	(19953),
	(19954),
	(19955),
	(19956),
	(19957),
	(19958),
	(19959),
	(19960),
	(19961),
	(19962),
	(19963),
	(19964),
	(19965),
	(19966),
	(19967),
	(19968),
	(19969),
	(19970),
	(19971),
	(19972),
	(19973),
	(19974),
	(19975),
	(19976),
	(19977),
	(19978),
	(19979),
	(19980),
	(19981),
	(19982),
	(19983),
	(19984),
	(19985),
	(19986),
	(19987),
	(19988),
	(19989),
	(19990),
	(19991),
	(19992),
	(19993),
	(19994),
	(19995),
	(19996),
	(19997),
	(19998),
	(19999),
	(20000),
	(20001),
	(20002),
	(20003),
	(20004),
	(20005),
	(20006),
	(20007),
	(20008),
	(20009),
	(20010),
	(20011),
	(20012),
	(20013),
	(20014),
	(20015),
	(20016),
	(20017),
	(20018),
	(20019),
	(20020),
	(20021),
	(20022),
	(20023),
	(20024),
	(20025),
	(20026),
	(20027),
	(20028),
	(20029),
	(20030),
	(20031),
	(20032),
	(20033),
	(20034),
	(20035),
	(20036),
	(20037),
	(20038),
	(20039),
	(20040),
	(20041),
	(20042),
	(20043),
	(20044),
	(20045),
	(20046),
	(20047),
	(20048),
	(20049),
	(20050),
	(20051),
	(20052),
	(20053),
	(20054),
	(20055),
	(20056),
	(20057),
	(20058),
	(20059),
	(20060),
	(20061),
	(20062),
	(20063),
	(20064),
	(20065),
	(20066),
	(20067),
	(20068),
	(20069),
	(20070),
	(20071),
	(20072),
	(20073),
	(20074),
	(20075),
	(20076),
	(20077),
	(20078),
	(20079),
	(20080),
	(20081),
	(20082),
	(20083),
	(20084),
	(20085),
	(20086),
	(20087),
	(20088),
	(20089),
	(20090),
	(20091),
	(20092),
	(20093),
	(20094),
	(20095),
	(20096),
	(20097),
	(20098),
	(20099),
	(20100),
	(20101),
	(20102),
	(20103),
	(20104),
	(20105),
	(20106),
	(20107),
	(20108),
	(20109),
	(20110),
	(20111),
	(20112),
	(20113),
	(20114),
	(20115),
	(20116),
	(20117),
	(20118),
	(20119),
	(20120),
	(20121),
	(20122),
	(20123),
	(20124),
	(20125),
	(20126),
	(20127),
	(20128),
	(20129),
	(20130),
	(20131),
	(20132),
	(20133),
	(20134),
	(20135),
	(20136),
	(20137),
	(20138),
	(20139),
	(20140),
	(20141),
	(20142),
	(20143),
	(20144),
	(20145),
	(20146),
	(20147),
	(20148),
	(20149),
	(20150),
	(20151),
	(20152),
	(20153),
	(20154),
	(20155),
	(20156),
	(20157),
	(20158),
	(20159),
	(20160),
	(20161),
	(20162),
	(20163),
	(20164),
	(20165),
	(20166),
	(20167),
	(20168),
	(20169),
	(20170),
	(20171),
	(20172),
	(20173),
	(20174),
	(20175),
	(20176),
	(20177),
	(20178),
	(20179),
	(20180),
	(20181),
	(20182),
	(20183),
	(20184),
	(20185),
	(20186),
	(20187),
	(20188),
	(20189),
	(20190),
	(20191),
	(20192),
	(20193),
	(20194),
	(20195),
	(20196),
	(20197),
	(20198),
	(20199),
	(20200),
	(20201),
	(20202),
	(20203),
	(20204),
	(20205),
	(20206),
	(20207),
	(20208),
	(20209),
	(20210),
	(20211),
	(20212),
	(20213),
	(20214),
	(20215),
	(20216),
	(20217),
	(20218),
	(20219),
	(20220),
	(20221),
	(20222),
	(20223),
	(20224),
	(20225),
	(20226),
	(20227),
	(20228),
	(20229),
	(20230),
	(20231),
	(20232),
	(20233),
	(20234),
	(20235),
	(20236),
	(20237),
	(20238),
	(20239),
	(20240),
	(20241),
	(20242),
	(20243),
	(20244),
	(20245),
	(20246),
	(20247),
	(20248),
	(20249),
	(20250),
	(20251),
	(20252),
	(20253),
	(20254),
	(20255),
	(20256),
	(20257),
	(20258),
	(20259),
	(20260),
	(20261),
	(20262),
	(20263),
	(20264),
	(20265),
	(20266),
	(20267),
	(20268),
	(20269),
	(20270),
	(20271),
	(20272),
	(20273),
	(20274),
	(20275),
	(20276),
	(20277),
	(20278),
	(20279),
	(20280),
	(20281),
	(20282),
	(20283),
	(20284),
	(20285),
	(20286),
	(20287),
	(20288),
	(20289),
	(20290),
	(20291),
	(20292),
	(20293),
	(20294),
	(20295),
	(20296),
	(20297),
	(20298),
	(20299),
	(20300),
	(20301),
	(20302),
	(20303),
	(20304),
	(20305),
	(20306),
	(20307),
	(20308),
	(20309),
	(20310),
	(20311),
	(20312),
	(20313),
	(20314),
	(20315),
	(20316),
	(20317),
	(20318),
	(20319),
	(20320),
	(20321),
	(20322),
	(20323),
	(20324),
	(20325),
	(20326),
	(20327),
	(20328),
	(20329),
	(20330),
	(20331),
	(20332),
	(20333),
	(20334),
	(20335),
	(20336),
	(20337),
	(20338),
	(20339),
	(20340),
	(20341),
	(20342),
	(20343),
	(20344),
	(20345),
	(20346),
	(20347),
	(20348),
	(20349),
	(20350),
	(20351),
	(20352),
	(20353),
	(20354),
	(20355),
	(20356),
	(20357),
	(20358),
	(20359),
	(20360),
	(20361),
	(20362),
	(20363),
	(20364),
	(20365),
	(20366),
	(20367),
	(20368),
	(20369),
	(20370),
	(20371),
	(20372),
	(20373),
	(20374),
	(20375),
	(20376),
	(20377),
	(20378),
	(20379),
	(20380),
	(20381),
	(20382),
	(20383),
	(20384),
	(20385),
	(20386),
	(20387),
	(20388),
	(20389),
	(20390),
	(20391),
	(20392),
	(20393),
	(20394),
	(20395),
	(20396),
	(20397),
	(20398),
	(20399),
	(20400),
	(20401),
	(20402),
	(20403),
	(20404),
	(20405),
	(20406),
	(20407),
	(20408),
	(20409),
	(20410),
	(20411),
	(20412),
	(20413),
	(20414),
	(20415),
	(20416),
	(20417),
	(20418),
	(20419),
	(20420),
	(20421),
	(20422),
	(20423),
	(20424),
	(20425),
	(20426),
	(20427),
	(20428),
	(20429),
	(20430),
	(20431),
	(20432),
	(20433),
	(20434),
	(20435),
	(20436),
	(20437),
	(20438),
	(20439),
	(20440),
	(20441),
	(20442),
	(20443),
	(20444),
	(20445),
	(20446),
	(20447),
	(20448),
	(20449),
	(20450),
	(20451),
	(20452),
	(20453),
	(20454),
	(20455),
	(20456),
	(20457),
	(20458),
	(20459),
	(20460),
	(20461),
	(20462),
	(20463),
	(20464),
	(20465),
	(20466),
	(20467),
	(20468),
	(20469),
	(20470),
	(20471),
	(20472),
	(20473),
	(20474),
	(20475),
	(20476),
	(20477),
	(20478),
	(20479),
	(20480),
	(20481),
	(20482),
	(20483),
	(20484),
	(20485),
	(20486),
	(20487),
	(20488),
	(20489),
	(20490),
	(20491),
	(20492),
	(20493),
	(20494),
	(20495),
	(20496),
	(20497),
	(20498),
	(20499),
	(20500),
	(20501),
	(20502),
	(20503),
	(20504),
	(20505),
	(20506),
	(20507),
	(20508),
	(20509),
	(20510),
	(20511),
	(20512),
	(20513),
	(20514),
	(20515),
	(20516),
	(20517),
	(20518),
	(20519),
	(20520),
	(20521),
	(20522),
	(20523),
	(20524),
	(20525),
	(20526),
	(20527),
	(20528),
	(20529),
	(20530),
	(20531),
	(20532),
	(20533),
	(20534),
	(20535),
	(20536),
	(20537),
	(20538),
	(20539),
	(20540),
	(20541),
	(20542),
	(20543),
	(20544),
	(20545),
	(20546),
	(20547),
	(20548),
	(20549),
	(20550),
	(20551),
	(20552),
	(20553),
	(20554),
	(20555),
	(20556),
	(20557),
	(20558),
	(20559),
	(20560),
	(20561),
	(20562),
	(20563),
	(20564),
	(20565),
	(20566),
	(20567),
	(20568),
	(20569),
	(20570),
	(20571),
	(20572),
	(20573),
	(20574),
	(20575),
	(20576),
	(20577),
	(20578),
	(20579),
	(20580),
	(20581),
	(20582),
	(20583),
	(20584),
	(20585),
	(20586),
	(20587),
	(20588),
	(20589),
	(20590),
	(20591),
	(20592),
	(20593),
	(20594),
	(20595),
	(20596),
	(20597),
	(20598),
	(20599),
	(20600),
	(20601),
	(20602),
	(20603),
	(20604),
	(20605),
	(20606),
	(20607),
	(20608),
	(20609),
	(20610),
	(20611),
	(20612),
	(20613),
	(20614),
	(20615),
	(20616),
	(20617),
	(20618),
	(20619),
	(20620),
	(20621),
	(20622),
	(20623),
	(20624),
	(20625),
	(20626),
	(20627),
	(20628),
	(20629),
	(20630),
	(20631),
	(20632),
	(20633),
	(20634),
	(20635),
	(20636),
	(20637),
	(20638),
	(20639),
	(20640),
	(20641),
	(20642),
	(20643),
	(20644),
	(20645),
	(20646),
	(20647),
	(20648),
	(20649),
	(20650),
	(20651),
	(20652),
	(20653),
	(20654),
	(20655),
	(20656),
	(20657),
	(20658),
	(20659),
	(20660),
	(20661),
	(20662),
	(20663),
	(20664),
	(20665),
	(20666),
	(20667),
	(20668),
	(20669),
	(20670),
	(20671),
	(20672),
	(20673),
	(20674),
	(20675),
	(20676),
	(20677),
	(20678),
	(20679),
	(20680),
	(20681),
	(20682),
	(20683),
	(20684),
	(20685),
	(20686),
	(20687),
	(20688),
	(20689),
	(20690),
	(20691),
	(20692),
	(20693),
	(20694),
	(20695),
	(20696),
	(20697),
	(20698),
	(20699),
	(20700),
	(20701),
	(20702),
	(20703),
	(20704),
	(20705),
	(20706),
	(20707),
	(20708),
	(20709),
	(20710),
	(20711),
	(20712),
	(20713),
	(20714),
	(20715),
	(20716),
	(20717),
	(20718),
	(20719),
	(20720),
	(20721),
	(20722),
	(20723),
	(20724),
	(20725),
	(20726),
	(20727),
	(20728),
	(20729),
	(20730),
	(20731),
	(20732),
	(20733),
	(20734),
	(20735),
	(20736),
	(20737),
	(20738),
	(20739),
	(20740),
	(20741),
	(20742),
	(20743),
	(20744),
	(20745),
	(20746),
	(20747),
	(20748),
	(20749),
	(20750),
	(20751),
	(20752),
	(20753),
	(20754),
	(20755),
	(20756),
	(20757),
	(20758),
	(20759),
	(20760),
	(20761),
	(20762),
	(20763),
	(20764),
	(20765),
	(20766),
	(20767),
	(20768),
	(20769),
	(20770),
	(20771),
	(20772),
	(20773),
	(20774),
	(20775),
	(20776),
	(20777),
	(20778),
	(20779),
	(20780),
	(20781),
	(20782),
	(20783),
	(20784),
	(20785),
	(20786),
	(20787),
	(20788),
	(20789),
	(20790),
	(20791),
	(20792),
	(20793),
	(20794),
	(20795),
	(20796),
	(20797),
	(20798),
	(20799),
	(20800),
	(20801),
	(20802),
	(20803),
	(20804),
	(20805),
	(20806),
	(20807),
	(20808),
	(20809),
	(20810),
	(20811),
	(20812),
	(20813),
	(20814),
	(20815),
	(20816),
	(20817),
	(20818),
	(20819),
	(20820),
	(20821),
	(20822),
	(20823),
	(20824),
	(20825),
	(20826),
	(20827),
	(20828),
	(20829),
	(20830),
	(20831),
	(20832),
	(20833),
	(20834),
	(20835),
	(20836),
	(20837),
	(20838),
	(20839),
	(20840),
	(20841),
	(20842),
	(20843),
	(20844),
	(20845),
	(20846),
	(20847),
	(20848),
	(20849),
	(20850),
	(20851),
	(20852),
	(20853),
	(20854),
	(20855),
	(20856),
	(20857),
	(20858),
	(20859),
	(20860),
	(20861),
	(20862),
	(20863),
	(20864),
	(20865),
	(20866),
	(20867),
	(20868),
	(20869),
	(20870),
	(20871),
	(20872),
	(20873),
	(20874),
	(20875),
	(20876),
	(20877),
	(20878),
	(20879),
	(20880),
	(20881),
	(20882),
	(20883),
	(20884),
	(20885),
	(20886),
	(20887),
	(20888),
	(20889),
	(20890),
	(20891),
	(20892),
	(20893),
	(20894),
	(20895),
	(20896),
	(20897),
	(20898),
	(20899),
	(20900),
	(20901),
	(20902),
	(20903),
	(20904),
	(20905),
	(20906),
	(20907),
	(20908),
	(20909),
	(20910),
	(20911),
	(20912),
	(20913),
	(20914),
	(20915),
	(20916),
	(20917),
	(20918),
	(20919),
	(20920),
	(20921),
	(20922),
	(20923),
	(20924),
	(20925),
	(20926),
	(20927),
	(20928),
	(20929),
	(20930),
	(20931),
	(20932),
	(20933),
	(20934),
	(20935),
	(20936),
	(20937),
	(20938),
	(20939),
	(20940),
	(20941),
	(20942),
	(20943),
	(20944),
	(20945),
	(20946),
	(20947),
	(20948),
	(20949),
	(20950),
	(20951),
	(20952),
	(20953),
	(20954),
	(20955),
	(20956),
	(20957),
	(20958),
	(20959),
	(20960),
	(20961),
	(20962),
	(20963),
	(20964),
	(20965),
	(20966),
	(20967),
	(20968),
	(20969),
	(20970),
	(20971),
	(20972),
	(20973),
	(20974),
	(20975),
	(20976),
	(20977),
	(20978),
	(20979),
	(20980),
	(20981),
	(20982),
	(20983),
	(20984),
	(20985),
	(20986),
	(20987),
	(20988),
	(20989),
	(20990),
	(20991),
	(20992),
	(20993),
	(20994),
	(20995),
	(20996),
	(20997),
	(20998),
	(20999),
	(21000),
	(21001),
	(21002),
	(21003),
	(21004),
	(21005),
	(21006),
	(21007),
	(21008),
	(21009),
	(21010),
	(21011),
	(21012),
	(21013),
	(21014),
	(21015),
	(21016),
	(21017),
	(21018),
	(21019),
	(21020),
	(21021),
	(21022),
	(21023),
	(21024),
	(21025),
	(21026),
	(21027),
	(21028),
	(21029),
	(21030),
	(21031),
	(21032),
	(21033),
	(21034),
	(21035),
	(21036),
	(21037),
	(21038),
	(21039),
	(21040),
	(21041),
	(21042),
	(21043),
	(21044),
	(21045),
	(21046),
	(21047),
	(21048),
	(21049),
	(21050),
	(21051),
	(21052),
	(21053),
	(21054),
	(21055),
	(21056),
	(21057),
	(21058),
	(21059),
	(21060),
	(21061),
	(21062),
	(21063),
	(21064),
	(21065),
	(21066),
	(21067),
	(21068),
	(21069),
	(21070),
	(21071),
	(21072),
	(21073),
	(21074),
	(21075),
	(21076),
	(21077),
	(21078),
	(21079),
	(21080),
	(21081),
	(21082),
	(21083),
	(21084),
	(21085),
	(21086),
	(21087),
	(21088),
	(21089),
	(21090),
	(21091),
	(21092),
	(21093),
	(21094),
	(21095),
	(21096),
	(21097),
	(21098),
	(21099),
	(21100),
	(21101),
	(21102),
	(21103),
	(21104),
	(21105),
	(21106),
	(21107),
	(21108),
	(21109),
	(21110),
	(21111),
	(21112),
	(21113),
	(21114),
	(21115),
	(21116),
	(21117),
	(21118),
	(21119),
	(21120),
	(21121),
	(21122),
	(21123),
	(21124),
	(21125),
	(21126),
	(21127),
	(21128),
	(21129),
	(21130),
	(21131),
	(21132),
	(21133),
	(21134),
	(21135),
	(21136),
	(21137),
	(21138),
	(21139),
	(21140),
	(21141),
	(21142),
	(21143),
	(21144),
	(21145),
	(21146),
	(21147),
	(21148),
	(21149),
	(21150),
	(21151),
	(21152),
	(21153),
	(21154),
	(21155),
	(21156),
	(21157),
	(21158),
	(21159),
	(21160),
	(21161),
	(21162),
	(21163),
	(21164),
	(21165),
	(21166),
	(21167),
	(21168),
	(21169),
	(21170),
	(21171),
	(21172),
	(21173),
	(21174),
	(21175),
	(21176),
	(21177),
	(21178),
	(21179),
	(21180),
	(21181),
	(21182),
	(21183),
	(21184),
	(21185),
	(21186),
	(21187),
	(21188),
	(21189),
	(21190),
	(21191),
	(21192),
	(21193),
	(21194),
	(21195),
	(21196),
	(21197),
	(21198),
	(21199),
	(21200),
	(21201),
	(21202),
	(21203),
	(21204),
	(21205),
	(21206),
	(21207),
	(21208),
	(21209),
	(21210),
	(21211),
	(21212),
	(21213),
	(21214),
	(21215),
	(21216),
	(21217),
	(21218),
	(21219),
	(21220),
	(21221),
	(21222),
	(21223),
	(21224),
	(21225),
	(21226),
	(21227),
	(21228),
	(21229),
	(21230),
	(21231),
	(21232),
	(21233),
	(21234),
	(21235),
	(21236),
	(21237),
	(21238),
	(21239),
	(21240),
	(21241),
	(21242),
	(21243),
	(21244),
	(21245),
	(21246),
	(21247),
	(21248),
	(21249),
	(21250),
	(21251),
	(21252),
	(21253),
	(21254),
	(21255),
	(21256),
	(21257),
	(21258),
	(21259),
	(21260),
	(21261),
	(21262),
	(21263),
	(21264),
	(21265),
	(21266),
	(21267),
	(21268),
	(21269),
	(21270),
	(21271),
	(21272),
	(21273),
	(21274),
	(21275),
	(21276),
	(21277),
	(21278),
	(21279),
	(21280),
	(21281),
	(21282),
	(21283),
	(21284),
	(21285),
	(21286),
	(21287),
	(21288),
	(21289),
	(21290),
	(21291),
	(21292),
	(21293),
	(21294),
	(21295),
	(21296),
	(21297),
	(21298),
	(21299),
	(21300),
	(21301),
	(21302),
	(21303),
	(21304),
	(21305),
	(21306),
	(21307),
	(21308),
	(21309),
	(21310),
	(21311),
	(21312),
	(21313),
	(21314),
	(21315),
	(21316),
	(21317),
	(21318),
	(21319),
	(21320),
	(21321),
	(21322),
	(21323),
	(21324),
	(21325),
	(21326),
	(21327),
	(21328),
	(21329),
	(21330),
	(21331),
	(21332),
	(21333),
	(21334),
	(21335),
	(21336),
	(21337),
	(21338),
	(21339),
	(21340),
	(21341),
	(21342),
	(21343),
	(21344),
	(21345),
	(21346),
	(21347),
	(21348),
	(21349),
	(21350),
	(21351),
	(21352),
	(21353),
	(21354),
	(21355),
	(21356),
	(21357),
	(21358),
	(21359),
	(21360),
	(21361),
	(21362),
	(21363),
	(21364),
	(21365),
	(21366),
	(21367),
	(21368),
	(21369),
	(21370),
	(21371),
	(21372),
	(21373),
	(21374),
	(21375),
	(21376),
	(21377),
	(21378),
	(21379),
	(21380),
	(21381),
	(21382),
	(21383),
	(21384),
	(21385),
	(21386),
	(21387),
	(21388),
	(21389),
	(21390),
	(21391),
	(21392),
	(21393),
	(21394),
	(21395),
	(21396),
	(21397),
	(21398),
	(21399),
	(21400),
	(21401),
	(21402),
	(21403),
	(21404),
	(21405),
	(21406),
	(21407),
	(21408),
	(21409),
	(21410),
	(21411),
	(21412),
	(21413),
	(21414),
	(21415),
	(21416),
	(21417),
	(21418),
	(21419),
	(21420),
	(21421),
	(21422),
	(21423),
	(21424),
	(21425),
	(21426),
	(21427),
	(21428),
	(21429),
	(21430),
	(21431),
	(21432),
	(21433),
	(21434),
	(21435),
	(21436),
	(21437),
	(21438),
	(21439),
	(21440),
	(21441),
	(21442),
	(21443),
	(21444),
	(21445),
	(21446),
	(21447),
	(21448),
	(21449),
	(21450),
	(21451),
	(21452),
	(21453),
	(21454),
	(21455),
	(21456),
	(21457),
	(21458),
	(21459),
	(21460),
	(21461),
	(21462),
	(21463),
	(21464),
	(21465),
	(21466),
	(21467),
	(21468),
	(21469),
	(21470),
	(21471),
	(21472),
	(21473),
	(21474),
	(21475),
	(21476),
	(21477),
	(21478),
	(21479),
	(21480),
	(21481),
	(21482),
	(21483),
	(21484),
	(21485),
	(21486),
	(21487),
	(21488),
	(21489),
	(21490),
	(21491),
	(21492),
	(21493),
	(21494),
	(21495),
	(21496),
	(21497),
	(21498),
	(21499),
	(21500),
	(21501),
	(21502),
	(21503),
	(21504),
	(21505),
	(21506),
	(21507),
	(21508),
	(21509),
	(21510),
	(21511),
	(21512),
	(21513),
	(21514),
	(21515),
	(21516),
	(21517),
	(21518),
	(21519),
	(21520),
	(21521),
	(21522),
	(21523),
	(21524),
	(21525),
	(21526),
	(21527),
	(21528),
	(21529),
	(21530),
	(21531),
	(21532),
	(21533),
	(21534),
	(21535),
	(21536),
	(21537),
	(21538),
	(21539),
	(21540),
	(21541),
	(21542),
	(21543),
	(21544),
	(21545),
	(21546),
	(21547),
	(21548),
	(21549),
	(21550),
	(21551),
	(21552),
	(21553),
	(21554),
	(21555),
	(21556),
	(21557),
	(21558),
	(21559),
	(21560),
	(21561),
	(21562),
	(21563),
	(21564),
	(21565),
	(21566),
	(21567),
	(21568),
	(21569),
	(21570),
	(21571),
	(21572),
	(21573),
	(21574),
	(21575),
	(21576),
	(21577),
	(21578),
	(21579),
	(21580),
	(21581),
	(21582),
	(21583),
	(21584),
	(21585),
	(21586),
	(21587),
	(21588),
	(21589),
	(21590),
	(21591),
	(21592),
	(21593),
	(21594),
	(21595),
	(21596),
	(21597),
	(21598),
	(21599),
	(21600),
	(21601),
	(21602),
	(21603),
	(21604),
	(21605),
	(21606),
	(21607),
	(21608),
	(21609),
	(21610),
	(21611),
	(21612),
	(21613),
	(21614),
	(21615),
	(21616),
	(21617),
	(21618),
	(21619),
	(21620),
	(21621),
	(21622),
	(21623),
	(21624),
	(21625),
	(21626),
	(21627),
	(21628),
	(21629),
	(21630),
	(21631),
	(21632),
	(21633),
	(21634),
	(21635),
	(21636),
	(21637),
	(21638),
	(21639),
	(21640),
	(21641),
	(21642),
	(21643),
	(21644),
	(21645),
	(21646),
	(21647),
	(21648),
	(21649),
	(21650),
	(21651),
	(21652),
	(21653),
	(21654),
	(21655),
	(21656),
	(21657),
	(21658),
	(21659),
	(21660),
	(21661),
	(21662),
	(21663),
	(21664),
	(21665),
	(21666),
	(21667),
	(21668),
	(21669),
	(21670),
	(21671),
	(21672),
	(21673),
	(21674),
	(21675),
	(21676),
	(21677),
	(21678),
	(21679),
	(21680),
	(21681),
	(21682),
	(21683),
	(21684),
	(21685),
	(21686),
	(21687),
	(21688),
	(21689),
	(21690),
	(21691),
	(21692),
	(21693),
	(21694),
	(21695),
	(21696),
	(21697),
	(21698),
	(21699),
	(21700),
	(21701),
	(21702),
	(21703),
	(21704),
	(21705),
	(21706),
	(21707),
	(21708),
	(21709),
	(21710),
	(21711),
	(21712),
	(21713),
	(21714),
	(21715),
	(21716),
	(21717),
	(21718),
	(21719),
	(21720),
	(21721),
	(21722),
	(21723),
	(21724),
	(21725),
	(21726),
	(21727),
	(21728),
	(21729),
	(21730),
	(21731),
	(21732),
	(21733),
	(21734),
	(21735),
	(21736),
	(21737),
	(21738),
	(21739),
	(21740),
	(21741),
	(21742),
	(21743),
	(21744),
	(21745),
	(21746),
	(21747),
	(21748),
	(21749),
	(21750),
	(21751),
	(21752),
	(21753),
	(21754),
	(21755),
	(21756),
	(21757),
	(21758),
	(21759),
	(21760),
	(21761),
	(21762),
	(21763),
	(21764),
	(21765),
	(21766),
	(21767),
	(21768),
	(21769),
	(21770),
	(21771),
	(21772),
	(21773),
	(21774),
	(21775),
	(21776),
	(21777),
	(21778),
	(21779),
	(21780),
	(21781),
	(21782),
	(21783),
	(21784),
	(21785),
	(21786),
	(21787),
	(21788),
	(21789),
	(21790),
	(21791),
	(21792),
	(21793),
	(21794),
	(21795),
	(21796),
	(21797),
	(21798),
	(21799),
	(21800),
	(21801),
	(21802),
	(21803),
	(21804),
	(21805),
	(21806),
	(21807),
	(21808),
	(21809),
	(21810),
	(21811),
	(21812),
	(21813),
	(21814),
	(21815),
	(21816),
	(21817),
	(21818),
	(21819),
	(21820),
	(21821),
	(21822),
	(21823),
	(21824),
	(21825),
	(21826),
	(21827),
	(21828),
	(21829),
	(21830),
	(21831),
	(21832),
	(21833),
	(21834),
	(21835),
	(21836),
	(21837),
	(21838),
	(21839),
	(21840),
	(21841),
	(21842),
	(21843),
	(21844),
	(21845),
	(21846),
	(21847),
	(21848),
	(21849),
	(21850),
	(21851),
	(21852),
	(21853),
	(21854),
	(21855),
	(21856),
	(21857),
	(21858),
	(21859),
	(21860),
	(21861),
	(21862),
	(21863),
	(21864),
	(21865),
	(21866),
	(21867),
	(21868),
	(21869),
	(21870),
	(21871),
	(21872),
	(21873),
	(21874),
	(21875),
	(21876),
	(21877),
	(21878),
	(21879),
	(21880),
	(21881),
	(21882),
	(21883),
	(21884),
	(21885),
	(21886),
	(21887),
	(21888),
	(21889),
	(21890),
	(21891),
	(21892),
	(21893),
	(21894),
	(21895),
	(21896),
	(21897),
	(21898),
	(21899),
	(21900),
	(21901),
	(21902),
	(21903),
	(21904),
	(21905),
	(21906),
	(21907),
	(21908),
	(21909),
	(21910),
	(21911),
	(21912),
	(21913),
	(21914),
	(21915),
	(21916),
	(21917),
	(21918),
	(21919),
	(21920),
	(21921),
	(21922),
	(21923),
	(21924),
	(21925),
	(21926),
	(21927),
	(21928),
	(21929),
	(21930),
	(21931),
	(21932),
	(21933),
	(21934),
	(21935),
	(21936),
	(21937),
	(21938),
	(21939),
	(21940),
	(21941),
	(21942),
	(21943),
	(21944),
	(21945),
	(21946),
	(21947),
	(21948),
	(21949),
	(21950),
	(21951),
	(21952),
	(21953),
	(21954),
	(21955),
	(21956),
	(21957),
	(21958),
	(21959),
	(21960),
	(21961),
	(21962),
	(21963),
	(21964),
	(21965),
	(21966),
	(21967),
	(21968),
	(21969),
	(21970),
	(21971),
	(21972),
	(21973),
	(21974),
	(21975),
	(21976),
	(21977),
	(21978),
	(21979),
	(21980),
	(21981),
	(21982),
	(21983),
	(21984),
	(21985),
	(21986),
	(21987),
	(21988),
	(21989),
	(21990),
	(21991),
	(21992),
	(21993),
	(21994),
	(21995),
	(21996),
	(21997),
	(21998),
	(21999),
	(22000),
	(22001),
	(22002),
	(22003),
	(22004),
	(22005),
	(22006),
	(22007),
	(22008),
	(22009),
	(22010),
	(22011),
	(22012),
	(22013),
	(22014),
	(22015),
	(22016),
	(22017),
	(22018),
	(22019),
	(22020),
	(22021),
	(22022),
	(22023),
	(22024),
	(22025),
	(22026),
	(22027),
	(22028),
	(22029),
	(22030),
	(22031),
	(22032),
	(22033),
	(22034),
	(22035),
	(22036),
	(22037),
	(22038),
	(22039),
	(22040),
	(22041),
	(22042),
	(22043),
	(22044),
	(22045),
	(22046),
	(22047),
	(22048),
	(22049),
	(22050),
	(22051),
	(22052),
	(22053),
	(22054),
	(22055),
	(22056),
	(22057),
	(22058),
	(22059),
	(22060),
	(22061),
	(22062),
	(22063),
	(22064),
	(22065),
	(22066),
	(22067),
	(22068),
	(22069),
	(22070),
	(22071),
	(22072),
	(22073),
	(22074),
	(22075),
	(22076),
	(22077),
	(22078),
	(22079),
	(22080),
	(22081),
	(22082),
	(22083),
	(22084),
	(22085),
	(22086),
	(22087),
	(22088),
	(22089),
	(22090),
	(22091),
	(22092),
	(22093),
	(22094),
	(22095),
	(22096),
	(22097),
	(22098),
	(22099),
	(22100),
	(22101),
	(22102),
	(22103),
	(22104),
	(22105),
	(22106),
	(22107),
	(22108),
	(22109),
	(22110),
	(22111),
	(22112),
	(22113),
	(22114),
	(22115),
	(22116),
	(22117),
	(22118),
	(22119),
	(22120),
	(22121),
	(22122),
	(22123),
	(22124),
	(22125),
	(22126),
	(22127),
	(22128),
	(22129),
	(22130),
	(22131),
	(22132),
	(22133),
	(22134),
	(22135),
	(22136),
	(22137),
	(22138),
	(22139),
	(22140),
	(22141),
	(22142),
	(22143),
	(22144),
	(22145),
	(22146),
	(22147),
	(22148),
	(22149),
	(22150),
	(22151),
	(22152),
	(22153),
	(22154),
	(22155),
	(22156),
	(22157),
	(22158),
	(22159),
	(22160),
	(22161),
	(22162),
	(22163),
	(22164),
	(22165),
	(22166),
	(22167),
	(22168),
	(22169),
	(22170),
	(22171),
	(22172),
	(22173),
	(22174),
	(22175),
	(22176),
	(22177),
	(22178),
	(22179),
	(22180),
	(22181),
	(22182),
	(22183),
	(22184),
	(22185),
	(22186),
	(22187),
	(22188),
	(22189),
	(22190),
	(22191),
	(22192),
	(22193),
	(22194),
	(22195),
	(22196),
	(22197),
	(22198),
	(22199),
	(22200),
	(22201),
	(22202),
	(22203),
	(22204),
	(22205),
	(22206),
	(22207),
	(22208),
	(22209),
	(22210),
	(22211),
	(22212),
	(22213),
	(22214),
	(22215),
	(22216),
	(22217),
	(22218),
	(22219),
	(22220),
	(22221),
	(22222),
	(22223),
	(22224),
	(22225),
	(22226),
	(22227),
	(22228),
	(22229),
	(22230),
	(22231),
	(22232),
	(22233),
	(22234),
	(22235),
	(22236),
	(22237),
	(22238),
	(22239),
	(22240),
	(22241),
	(22242),
	(22243),
	(22244),
	(22245),
	(22246),
	(22247),
	(22248),
	(22249),
	(22250),
	(22251),
	(22252),
	(22253),
	(22254),
	(22255),
	(22256),
	(22257),
	(22258),
	(22259),
	(22260),
	(22261),
	(22262),
	(22263),
	(22264),
	(22265),
	(22266),
	(22267),
	(22268),
	(22269),
	(22270),
	(22271),
	(22272),
	(22273),
	(22274),
	(22275),
	(22276),
	(22277),
	(22278),
	(22279),
	(22280),
	(22281),
	(22282),
	(22283),
	(22284),
	(22285),
	(22286),
	(22287),
	(22288),
	(22289),
	(22290),
	(22291),
	(22292),
	(22293),
	(22294),
	(22295),
	(22296),
	(22297),
	(22298),
	(22299),
	(22300),
	(22301),
	(22302),
	(22303),
	(22304),
	(22305),
	(22306),
	(22307),
	(22308),
	(22309),
	(22310),
	(22311),
	(22312),
	(22313),
	(22314),
	(22315),
	(22316),
	(22317),
	(22318),
	(22319),
	(22320),
	(22321),
	(22322),
	(22323),
	(22324),
	(22325),
	(22326),
	(22327),
	(22328),
	(22329),
	(22330),
	(22331),
	(22332),
	(22333),
	(22334),
	(22335),
	(22336),
	(22337),
	(22338),
	(22339),
	(22340),
	(22341),
	(22342),
	(22343),
	(22344),
	(22345),
	(22346),
	(22347),
	(22348),
	(22349),
	(22350),
	(22351),
	(22352),
	(22353),
	(22354),
	(22355),
	(22356),
	(22357),
	(22358),
	(22359),
	(22360),
	(22361),
	(22362),
	(22363),
	(22364),
	(22365),
	(22366),
	(22367),
	(22368),
	(22369),
	(22370),
	(22371),
	(22372),
	(22373),
	(22374),
	(22375),
	(22376),
	(22377),
	(22378),
	(22379),
	(22380),
	(22381),
	(22382),
	(22383),
	(22384),
	(22385),
	(22386),
	(22387),
	(22388),
	(22389),
	(22390),
	(22391),
	(22392),
	(22393),
	(22394),
	(22395),
	(22396),
	(22397),
	(22398),
	(22399),
	(22400),
	(22401),
	(22402),
	(22403),
	(22404),
	(22405),
	(22406),
	(22407),
	(22408),
	(22409),
	(22410),
	(22411),
	(22412),
	(22413),
	(22414),
	(22415),
	(22416),
	(22417),
	(22418),
	(22419),
	(22420),
	(22421),
	(22422),
	(22423),
	(22424),
	(22425),
	(22426),
	(22427),
	(22428),
	(22429),
	(22430),
	(22431),
	(22432),
	(22433),
	(22434),
	(22435),
	(22436),
	(22437),
	(22438),
	(22439),
	(22440),
	(22441),
	(22442),
	(22443),
	(22444),
	(22445),
	(22446),
	(22447),
	(22448),
	(22449),
	(22450),
	(22451),
	(22452),
	(22453),
	(22454),
	(22455),
	(22456),
	(22457),
	(22458),
	(22459),
	(22460),
	(22461),
	(22462),
	(22463),
	(22464),
	(22465),
	(22466),
	(22467),
	(22468),
	(22469),
	(22470),
	(22471),
	(22472),
	(22473),
	(22474),
	(22475),
	(22476),
	(22477),
	(22478),
	(22479),
	(22480),
	(22481),
	(22482),
	(22483),
	(22484),
	(22485),
	(22486),
	(22487),
	(22488),
	(22489),
	(22490),
	(22491),
	(22492),
	(22493),
	(22494),
	(22495),
	(22496),
	(22497),
	(22498),
	(22499),
	(22500),
	(22501),
	(22502),
	(22503),
	(22504),
	(22505),
	(22506),
	(22507),
	(22508),
	(22509),
	(22510),
	(22511),
	(22512),
	(22513),
	(22514),
	(22515),
	(22516),
	(22517),
	(22518),
	(22519),
	(22520),
	(22521),
	(22522),
	(22523),
	(22524),
	(22525),
	(22526),
	(22527),
	(22528),
	(22529),
	(22530),
	(22531),
	(22532),
	(22533),
	(22534),
	(22535),
	(22536),
	(22537),
	(22538),
	(22539),
	(22540),
	(22541),
	(22542),
	(22543),
	(22544),
	(22545),
	(22546),
	(22547),
	(22548),
	(22549),
	(22550),
	(22551),
	(22552),
	(22553),
	(22554),
	(22555),
	(22556),
	(22557),
	(22558),
	(22559),
	(22560),
	(22561),
	(22562),
	(22563),
	(22564),
	(22565),
	(22566),
	(22567),
	(22568),
	(22569),
	(22570),
	(22571),
	(22572),
	(22573),
	(22574),
	(22575),
	(22576),
	(22577),
	(22578),
	(22579),
	(22580),
	(22581),
	(22582),
	(22583),
	(22584),
	(22585),
	(22586),
	(22587),
	(22588),
	(22589),
	(22590),
	(22591),
	(22592),
	(22593),
	(22594),
	(22595),
	(22596),
	(22597),
	(22598),
	(22599),
	(22600),
	(22601),
	(22602),
	(22603),
	(22604),
	(22605),
	(22606),
	(22607),
	(22608),
	(22609),
	(22610),
	(22611),
	(22612),
	(22613),
	(22614),
	(22615),
	(22616),
	(22617),
	(22618),
	(22619),
	(22620),
	(22621),
	(22622),
	(22623),
	(22624),
	(22625),
	(22626),
	(22627),
	(22628),
	(22629),
	(22630),
	(22631),
	(22632),
	(22633),
	(22634),
	(22635),
	(22636),
	(22637),
	(22638),
	(22639),
	(22640),
	(22641),
	(22642),
	(22643),
	(22644),
	(22645),
	(22646),
	(22647),
	(22648),
	(22649),
	(22650),
	(22651),
	(22652),
	(22653),
	(22654),
	(22655),
	(22656),
	(22657),
	(22658),
	(22659),
	(22660),
	(22661),
	(22662),
	(22663),
	(22664),
	(22665),
	(22666),
	(22667),
	(22668),
	(22669),
	(22670),
	(22671),
	(22672),
	(22673),
	(22674),
	(22675),
	(22676),
	(22677),
	(22678),
	(22679),
	(22680),
	(22681),
	(22682),
	(22683),
	(22684),
	(22685),
	(22686),
	(22687),
	(22688),
	(22689),
	(22690),
	(22691),
	(22692),
	(22693),
	(22694),
	(22695),
	(22696),
	(22697),
	(22698),
	(22699),
	(22700),
	(22701),
	(22702),
	(22703),
	(22704),
	(22705),
	(22706),
	(22707),
	(22708),
	(22709),
	(22710),
	(22711),
	(22712),
	(22713),
	(22714),
	(22715),
	(22716),
	(22717),
	(22718),
	(22719),
	(22720),
	(22721),
	(22722),
	(22723),
	(22724),
	(22725),
	(22726),
	(22727),
	(22728),
	(22729),
	(22730),
	(22731),
	(22732),
	(22733),
	(22734),
	(22735),
	(22736),
	(22737),
	(22738),
	(22739),
	(22740),
	(22741),
	(22742),
	(22743),
	(22744),
	(22745),
	(22746),
	(22747),
	(22748),
	(22749),
	(22750),
	(22751),
	(22752),
	(22753),
	(22754),
	(22755),
	(22756),
	(22757),
	(22758),
	(22759),
	(22760),
	(22761),
	(22762),
	(22763),
	(22764),
	(22765),
	(22766),
	(22767),
	(22768),
	(22769),
	(22770),
	(22771),
	(22772),
	(22773),
	(22774),
	(22775),
	(22776),
	(22777),
	(22778),
	(22779),
	(22780),
	(22781),
	(22782),
	(22783),
	(22784),
	(22785),
	(22786),
	(22787),
	(22788),
	(22789),
	(22790),
	(22791),
	(22792),
	(22793),
	(22794),
	(22795),
	(22796),
	(22797),
	(22798),
	(22799),
	(22800),
	(22801),
	(22802),
	(22803),
	(22804),
	(22805),
	(22806),
	(22807),
	(22808),
	(22809),
	(22810),
	(22811),
	(22812),
	(22813),
	(22814),
	(22815),
	(22816),
	(22817),
	(22818),
	(22819),
	(22820),
	(22821),
	(22822),
	(22823),
	(22824),
	(22825),
	(22826),
	(22827),
	(22828),
	(22829),
	(22830),
	(22831),
	(22832),
	(22833),
	(22834),
	(22835),
	(22836),
	(22837),
	(22838),
	(22839),
	(22840),
	(22841),
	(22842),
	(22843),
	(22844),
	(22845),
	(22846),
	(22847),
	(22848),
	(22849),
	(22850),
	(22851),
	(22852),
	(22853),
	(22854),
	(22855),
	(22856),
	(22857),
	(22858),
	(22859),
	(22860),
	(22861),
	(22862),
	(22863),
	(22864),
	(22865),
	(22866),
	(22867),
	(22868),
	(22869),
	(22870),
	(22871),
	(22872),
	(22873),
	(22874),
	(22875),
	(22876),
	(22877),
	(22878),
	(22879),
	(22880),
	(22881),
	(22882),
	(22883),
	(22884),
	(22885),
	(22886),
	(22887),
	(22888),
	(22889),
	(22890),
	(22891),
	(22892),
	(22893),
	(22894),
	(22895),
	(22896),
	(22897),
	(22898),
	(22899),
	(22900),
	(22901),
	(22902),
	(22903),
	(22904),
	(22905),
	(22906),
	(22907),
	(22908),
	(22909),
	(22910),
	(22911),
	(22912),
	(22913),
	(22914),
	(22915),
	(22916),
	(22917),
	(22918),
	(22919),
	(22920),
	(22921),
	(22922),
	(22923),
	(22924),
	(22925),
	(22926),
	(22927),
	(22928),
	(22929),
	(22930),
	(22931),
	(22932),
	(22933),
	(22934),
	(22935),
	(22936),
	(22937),
	(22938),
	(22939),
	(22940),
	(22941),
	(22942),
	(22943),
	(22944),
	(22945),
	(22946),
	(22947),
	(22948),
	(22949),
	(22950),
	(22951),
	(22952),
	(22953),
	(22954),
	(22955),
	(22956),
	(22957),
	(22958),
	(22959),
	(22960),
	(22961),
	(22962),
	(22963),
	(22964),
	(22965),
	(22966),
	(22967),
	(22968),
	(22969),
	(22970),
	(22971),
	(22972),
	(22973),
	(22974),
	(22975),
	(22976),
	(22977),
	(22978),
	(22979),
	(22980),
	(22981),
	(22982),
	(22983),
	(22984),
	(22985),
	(22986),
	(22987),
	(22988),
	(22989),
	(22990),
	(22991),
	(22992),
	(22993),
	(22994),
	(22995),
	(22996),
	(22997),
	(22998),
	(22999),
	(23000),
	(23001),
	(23002),
	(23003),
	(23004),
	(23005),
	(23006),
	(23007),
	(23008),
	(23009),
	(23010),
	(23011),
	(23012),
	(23013),
	(23014),
	(23015),
	(23016),
	(23017),
	(23018),
	(23019),
	(23020),
	(23021),
	(23022),
	(23023),
	(23024),
	(23025),
	(23026),
	(23027),
	(23028),
	(23029),
	(23030),
	(23031),
	(23032),
	(23033),
	(23034),
	(23035),
	(23036),
	(23037),
	(23038),
	(23039),
	(23040),
	(23041),
	(23042),
	(23043),
	(23044),
	(23045),
	(23046),
	(23047),
	(23048),
	(23049),
	(23050),
	(23051),
	(23052),
	(23053),
	(23054),
	(23055),
	(23056),
	(23057),
	(23058),
	(23059),
	(23060),
	(23061),
	(23062),
	(23063),
	(23064),
	(23065),
	(23066),
	(23067),
	(23068),
	(23069),
	(23070),
	(23071),
	(23072),
	(23073),
	(23074),
	(23075),
	(23076),
	(23077),
	(23078),
	(23079),
	(23080),
	(23081),
	(23082),
	(23083),
	(23084),
	(23085),
	(23086),
	(23087),
	(23088),
	(23089),
	(23090),
	(23091),
	(23092),
	(23093),
	(23094),
	(23095),
	(23096),
	(23097),
	(23098),
	(23099),
	(23100),
	(23101),
	(23102),
	(23103),
	(23104),
	(23105),
	(23106),
	(23107),
	(23108),
	(23109),
	(23110),
	(23111),
	(23112),
	(23113),
	(23114),
	(23115),
	(23116),
	(23117),
	(23118),
	(23119),
	(23120),
	(23121),
	(23122),
	(23123),
	(23124),
	(23125),
	(23126),
	(23127),
	(23128),
	(23129),
	(23130),
	(23131),
	(23132),
	(23133),
	(23134),
	(23135),
	(23136),
	(23137),
	(23138),
	(23139),
	(23140),
	(23141),
	(23142),
	(23143),
	(23144),
	(23145),
	(23146),
	(23147),
	(23148),
	(23149),
	(23150),
	(23151),
	(23152),
	(23153),
	(23154),
	(23155),
	(23156),
	(23157),
	(23158),
	(23159),
	(23160),
	(23161),
	(23162),
	(23163),
	(23164),
	(23165),
	(23166),
	(23167),
	(23168),
	(23169),
	(23170),
	(23171),
	(23172),
	(23173),
	(23174),
	(23175),
	(23176),
	(23177),
	(23178),
	(23179),
	(23180),
	(23181),
	(23182),
	(23183),
	(23184),
	(23185),
	(23186),
	(23187),
	(23188),
	(23189),
	(23190),
	(23191),
	(23192),
	(23193),
	(23194),
	(23195),
	(23196),
	(23197),
	(23198),
	(23199),
	(23200),
	(23201),
	(23202),
	(23203),
	(23204),
	(23205),
	(23206),
	(23207),
	(23208),
	(23209),
	(23210),
	(23211),
	(23212),
	(23213),
	(23214),
	(23215),
	(23216),
	(23217),
	(23218),
	(23219),
	(23220),
	(23221),
	(23222),
	(23223),
	(23224),
	(23225),
	(23226),
	(23227),
	(23228),
	(23229),
	(23230),
	(23231),
	(23232),
	(23233),
	(23234),
	(23235),
	(23236),
	(23237),
	(23238),
	(23239),
	(23240),
	(23241),
	(23242),
	(23243),
	(23244),
	(23245),
	(23246),
	(23247),
	(23248),
	(23249),
	(23250),
	(23251),
	(23252),
	(23253),
	(23254),
	(23255),
	(23256),
	(23257),
	(23258),
	(23259),
	(23260),
	(23261),
	(23262),
	(23263),
	(23264),
	(23265),
	(23266),
	(23267),
	(23268),
	(23269),
	(23270),
	(23271),
	(23272),
	(23273),
	(23274),
	(23275),
	(23276),
	(23277),
	(23278),
	(23279),
	(23280),
	(23281),
	(23282),
	(23283),
	(23284),
	(23285),
	(23286),
	(23287),
	(23288),
	(23289),
	(23290),
	(23291),
	(23292),
	(23293),
	(23294),
	(23295),
	(23296),
	(23297),
	(23298),
	(23299),
	(23300),
	(23301),
	(23302),
	(23303),
	(23304),
	(23305),
	(23306),
	(23307),
	(23308),
	(23309),
	(23310),
	(23311),
	(23312),
	(23313),
	(23314),
	(23315),
	(23316),
	(23317),
	(23318),
	(23319),
	(23320),
	(23321),
	(23322),
	(23323),
	(23324),
	(23325),
	(23326),
	(23327),
	(23328),
	(23329),
	(23330),
	(23331),
	(23332),
	(23333),
	(23334),
	(23335),
	(23336),
	(23337),
	(23338),
	(23339),
	(23340),
	(23341),
	(23342),
	(23343),
	(23344),
	(23345),
	(23346),
	(23347),
	(23348),
	(23349),
	(23350),
	(23351),
	(23352),
	(23353),
	(23354),
	(23355),
	(23356),
	(23357),
	(23358),
	(23359),
	(23360),
	(23361),
	(23362),
	(23363),
	(23364),
	(23365),
	(23366),
	(23367),
	(23368),
	(23369),
	(23370),
	(23371),
	(23372),
	(23373),
	(23374),
	(23375),
	(23376),
	(23377),
	(23378),
	(23379),
	(23380),
	(23381),
	(23382),
	(23383),
	(23384),
	(23385),
	(23386),
	(23387),
	(23388),
	(23389),
	(23390),
	(23391),
	(23392),
	(23393),
	(23394),
	(23395),
	(23396),
	(23397),
	(23398),
	(23399),
	(23400),
	(23401),
	(23402),
	(23403),
	(23404),
	(23405),
	(23406),
	(23407),
	(23408),
	(23409),
	(23410),
	(23411),
	(23412),
	(23413),
	(23414),
	(23415),
	(23416),
	(23417),
	(23418),
	(23419),
	(23420),
	(23421),
	(23422),
	(23423),
	(23424),
	(23425),
	(23426),
	(23427),
	(23428),
	(23429),
	(23430),
	(23431),
	(23432),
	(23433),
	(23434),
	(23435),
	(23436),
	(23437),
	(23438),
	(23439),
	(23440),
	(23441),
	(23442),
	(23443),
	(23444),
	(23445),
	(23446),
	(23447),
	(23448),
	(23449),
	(23450),
	(23451),
	(23452),
	(23453),
	(23454),
	(23455),
	(23456),
	(23457),
	(23458),
	(23459),
	(23460),
	(23461),
	(23462),
	(23463),
	(23464),
	(23465),
	(23466),
	(23467),
	(23468),
	(23469),
	(23470),
	(23471),
	(23472),
	(23473),
	(23474),
	(23475),
	(23476),
	(23477),
	(23478),
	(23479),
	(23480),
	(23481),
	(23482),
	(23483),
	(23484),
	(23485),
	(23486),
	(23487),
	(23488),
	(23489),
	(23490),
	(23491),
	(23492),
	(23493),
	(23494),
	(23495),
	(23496),
	(23497),
	(23498),
	(23499),
	(23500),
	(23501),
	(23502),
	(23503),
	(23504),
	(23505),
	(23506),
	(23507),
	(23508),
	(23509),
	(23510),
	(23511),
	(23512),
	(23513),
	(23514),
	(23515),
	(23516),
	(23517),
	(23518),
	(23519),
	(23520),
	(23521),
	(23522),
	(23523),
	(23524),
	(23525),
	(23526),
	(23527),
	(23528),
	(23529),
	(23530),
	(23531),
	(23532),
	(23533),
	(23534),
	(23535),
	(23536),
	(23537),
	(23538),
	(23539),
	(23540),
	(23541),
	(23542),
	(23543),
	(23544),
	(23545),
	(23546),
	(23547),
	(23548),
	(23549),
	(23550),
	(23551),
	(23552),
	(23553),
	(23554),
	(23555),
	(23556),
	(23557),
	(23558),
	(23559),
	(23560),
	(23561),
	(23562),
	(23563),
	(23564),
	(23565),
	(23566),
	(23567),
	(23568),
	(23569),
	(23570),
	(23571),
	(23572),
	(23573),
	(23574),
	(23575),
	(23576),
	(23577),
	(23578),
	(23579),
	(23580),
	(23581),
	(23582),
	(23583),
	(23584),
	(23585),
	(23586),
	(23587),
	(23588),
	(23589),
	(23590),
	(23591),
	(23592),
	(23593),
	(23594),
	(23595),
	(23596),
	(23597),
	(23598),
	(23599),
	(23600),
	(23601),
	(23602),
	(23603),
	(23604),
	(23605),
	(23606),
	(23607),
	(23608),
	(23609),
	(23610),
	(23611),
	(23612),
	(23613),
	(23614),
	(23615),
	(23616),
	(23617),
	(23618),
	(23619),
	(23620),
	(23621),
	(23622),
	(23623),
	(23624),
	(23625),
	(23626),
	(23627),
	(23628),
	(23629),
	(23630),
	(23631),
	(23632),
	(23633),
	(23634),
	(23635),
	(23636),
	(23637),
	(23638),
	(23639),
	(23640),
	(23641),
	(23642),
	(23643),
	(23644),
	(23645),
	(23646),
	(23647),
	(23648),
	(23649),
	(23650),
	(23651),
	(23652),
	(23653),
	(23654),
	(23655),
	(23656),
	(23657),
	(23658),
	(23659),
	(23660),
	(23661),
	(23662),
	(23663),
	(23664),
	(23665),
	(23666),
	(23667),
	(23668),
	(23669),
	(23670),
	(23671),
	(23672),
	(23673),
	(23674),
	(23675),
	(23676),
	(23677),
	(23678),
	(23679),
	(23680),
	(23681),
	(23682),
	(23683),
	(23684),
	(23685),
	(23686),
	(23687),
	(23688),
	(23689),
	(23690),
	(23691),
	(23692),
	(23693),
	(23694),
	(23695),
	(23696),
	(23697),
	(23698),
	(23699),
	(23700),
	(23701),
	(23702),
	(23703),
	(23704),
	(23705),
	(23706),
	(23707),
	(23708),
	(23709),
	(23710),
	(23711),
	(23712),
	(23713),
	(23714),
	(23715),
	(23716),
	(23717),
	(23718),
	(23719),
	(23720),
	(23721),
	(23722),
	(23723),
	(23724),
	(23725),
	(23726),
	(23727),
	(23728),
	(23729),
	(23730),
	(23731),
	(23732),
	(23733),
	(23734),
	(23735),
	(23736),
	(23737),
	(23738),
	(23739),
	(23740),
	(23741),
	(23742),
	(23743),
	(23744),
	(23745),
	(23746),
	(23747),
	(23748),
	(23749),
	(23750),
	(23751),
	(23752),
	(23753),
	(23754),
	(23755),
	(23756),
	(23757),
	(23758),
	(23759),
	(23760),
	(23761),
	(23762),
	(23763),
	(23764),
	(23765),
	(23766),
	(23767),
	(23768),
	(23769),
	(23770),
	(23771),
	(23772),
	(23773),
	(23774),
	(23775),
	(23776),
	(23777),
	(23778),
	(23779),
	(23780),
	(23781),
	(23782),
	(23783),
	(23784),
	(23785),
	(23786),
	(23787),
	(23788),
	(23789),
	(23790),
	(23791),
	(23792),
	(23793),
	(23794),
	(23795),
	(23796),
	(23797),
	(23798),
	(23799),
	(23800),
	(23801),
	(23802),
	(23803),
	(23804),
	(23805),
	(23806),
	(23807),
	(23808),
	(23809),
	(23810),
	(23811),
	(23812),
	(23813),
	(23814),
	(23815),
	(23816),
	(23817),
	(23818),
	(23819),
	(23820),
	(23821),
	(23822),
	(23823),
	(23824),
	(23825),
	(23826),
	(23827),
	(23828),
	(23829),
	(23830),
	(23831),
	(23832),
	(23833),
	(23834),
	(23835),
	(23836),
	(23837),
	(23838),
	(23839),
	(23840),
	(23841),
	(23842),
	(23843),
	(23844),
	(23845),
	(23846),
	(23847),
	(23848),
	(23849),
	(23850),
	(23851),
	(23852),
	(23853),
	(23854),
	(23855),
	(23856),
	(23857),
	(23858),
	(23859),
	(23860),
	(23861),
	(23862),
	(23863),
	(23864),
	(23865),
	(23866),
	(23867),
	(23868),
	(23869),
	(23870),
	(23871),
	(23872),
	(23873),
	(23874),
	(23875),
	(23876),
	(23877),
	(23878),
	(23879),
	(23880),
	(23881),
	(23882),
	(23883),
	(23884),
	(23885),
	(23886),
	(23887),
	(23888),
	(23889),
	(23890),
	(23891),
	(23892),
	(23893),
	(23894),
	(23895),
	(23896),
	(23897),
	(23898),
	(23899),
	(23900),
	(23901),
	(23902),
	(23903),
	(23904),
	(23905),
	(23906),
	(23907),
	(23908),
	(23909),
	(23910),
	(23911),
	(23912),
	(23913),
	(23914),
	(23915),
	(23916),
	(23917),
	(23918),
	(23919),
	(23920),
	(23921),
	(23922),
	(23923),
	(23924),
	(23925),
	(23926),
	(23927),
	(23928),
	(23929),
	(23930),
	(23931),
	(23932),
	(23933),
	(23934),
	(23935),
	(23936),
	(23937),
	(23938),
	(23939),
	(23940),
	(23941),
	(23942),
	(23943),
	(23944),
	(23945),
	(23946),
	(23947),
	(23948),
	(23949),
	(23950),
	(23951),
	(23952),
	(23953),
	(23954),
	(23955),
	(23956),
	(23957),
	(23958),
	(23959),
	(23960),
	(23961),
	(23962),
	(23963),
	(23964),
	(23965),
	(23966),
	(23967),
	(23968),
	(23969),
	(23970),
	(23971),
	(23972),
	(23973),
	(23974),
	(23975),
	(23976),
	(23977),
	(23978),
	(23979),
	(23980),
	(23981),
	(23982),
	(23983),
	(23984),
	(23985),
	(23986),
	(23987),
	(23988),
	(23989),
	(23990),
	(23991),
	(23992),
	(23993),
	(23994),
	(23995),
	(23996),
	(23997),
	(23998),
	(23999),
	(24000),
	(24001),
	(24002),
	(24003),
	(24004),
	(24005),
	(24006),
	(24007),
	(24008),
	(24009),
	(24010),
	(24011),
	(24012),
	(24013),
	(24014),
	(24015),
	(24016),
	(24017),
	(24018),
	(24019),
	(24020),
	(24021),
	(24022),
	(24023),
	(24024),
	(24025),
	(24026),
	(24027),
	(24028),
	(24029),
	(24030),
	(24031),
	(24032),
	(24033),
	(24034),
	(24035),
	(24036),
	(24037),
	(24038),
	(24039),
	(24040),
	(24041),
	(24042),
	(24043),
	(24044),
	(24045),
	(24046),
	(24047),
	(24048),
	(24049),
	(24050),
	(24051),
	(24052),
	(24053),
	(24054),
	(24055),
	(24056),
	(24057),
	(24058),
	(24059),
	(24060),
	(24061),
	(24062),
	(24063),
	(24064),
	(24065),
	(24066),
	(24067),
	(24068),
	(24069),
	(24070),
	(24071),
	(24072),
	(24073),
	(24074),
	(24075),
	(24076),
	(24077),
	(24078),
	(24079),
	(24080),
	(24081),
	(24082),
	(24083),
	(24084),
	(24085),
	(24086),
	(24087),
	(24088),
	(24089),
	(24090),
	(24091),
	(24092),
	(24093),
	(24094),
	(24095),
	(24096),
	(24097),
	(24098),
	(24099),
	(24100),
	(24101),
	(24102),
	(24103),
	(24104),
	(24105),
	(24106),
	(24107),
	(24108),
	(24109),
	(24110),
	(24111),
	(24112),
	(24113),
	(24114),
	(24115),
	(24116),
	(24117),
	(24118),
	(24119),
	(24120),
	(24121),
	(24122),
	(24123),
	(24124),
	(24125),
	(24126),
	(24127),
	(24128),
	(24129),
	(24130),
	(24131),
	(24132),
	(24133),
	(24134),
	(24135),
	(24136),
	(24137),
	(24138),
	(24139),
	(24140),
	(24141),
	(24142),
	(24143),
	(24144),
	(24145),
	(24146),
	(24147),
	(24148),
	(24149),
	(24150),
	(24151),
	(24152),
	(24153),
	(24154),
	(24155),
	(24156),
	(24157),
	(24158),
	(24159),
	(24160),
	(24161),
	(24162),
	(24163),
	(24164),
	(24165),
	(24166),
	(24167),
	(24168),
	(24169),
	(24170),
	(24171),
	(24172),
	(24173),
	(24174),
	(24175),
	(24176),
	(24177),
	(24178),
	(24179),
	(24180),
	(24181),
	(24182),
	(24183),
	(24184),
	(24185),
	(24186),
	(24187),
	(24188),
	(24189),
	(24190),
	(24191),
	(24192),
	(24193),
	(24194),
	(24195),
	(24196),
	(24197),
	(24198),
	(24199),
	(24200),
	(24201),
	(24202),
	(24203),
	(24204),
	(24205),
	(24206),
	(24207),
	(24208),
	(24209),
	(24210),
	(24211),
	(24212),
	(24213),
	(24214),
	(24215),
	(24216),
	(24217),
	(24218),
	(24219),
	(24220),
	(24221),
	(24222),
	(24223),
	(24224),
	(24225),
	(24226),
	(24227),
	(24228),
	(24229),
	(24230),
	(24231),
	(24232),
	(24233),
	(24234),
	(24235),
	(24236),
	(24237),
	(24238),
	(24239),
	(24240),
	(24241),
	(24242),
	(24243),
	(24244),
	(24245),
	(24246),
	(24247),
	(24248),
	(24249),
	(24250),
	(24251),
	(24252),
	(24253),
	(24254),
	(24255),
	(24256),
	(24257),
	(24258),
	(24259),
	(24260),
	(24261),
	(24262),
	(24263),
	(24264),
	(24265),
	(24266),
	(24267),
	(24268),
	(24269),
	(24270),
	(24271),
	(24272),
	(24273),
	(24274),
	(24275),
	(24276),
	(24277),
	(24278),
	(24279),
	(24280),
	(24281),
	(24282),
	(24283),
	(24284),
	(24285),
	(24286),
	(24287),
	(24288),
	(24289),
	(24290),
	(24291),
	(24292),
	(24293),
	(24294),
	(24295),
	(24296),
	(24297),
	(24298),
	(24299),
	(24300),
	(24301),
	(24302),
	(24303),
	(24304),
	(24305),
	(24306),
	(24307),
	(24308),
	(24309),
	(24310),
	(24311),
	(24312),
	(24313),
	(24314),
	(24315),
	(24316),
	(24317),
	(24318),
	(24319),
	(24320),
	(24321),
	(24322),
	(24323),
	(24324),
	(24325),
	(24326),
	(24327),
	(24328),
	(24329),
	(24330),
	(24331),
	(24332),
	(24333),
	(24334),
	(24335),
	(24336),
	(24337),
	(24338),
	(24339),
	(24340),
	(24341),
	(24342),
	(24343),
	(24344),
	(24345),
	(24346),
	(24347),
	(24348),
	(24349),
	(24350),
	(24351),
	(24352),
	(24353),
	(24354),
	(24355),
	(24356),
	(24357),
	(24358),
	(24359),
	(24360),
	(24361),
	(24362),
	(24363),
	(24364),
	(24365),
	(24366),
	(24367),
	(24368),
	(24369),
	(24370),
	(24371),
	(24372),
	(24373),
	(24374),
	(24375),
	(24376),
	(24377),
	(24378),
	(24379),
	(24380),
	(24381),
	(24382),
	(24383),
	(24384),
	(24385),
	(24386),
	(24387),
	(24388),
	(24389),
	(24390),
	(24391),
	(24392),
	(24393),
	(24394),
	(24395),
	(24396),
	(24397),
	(24398),
	(24399),
	(24400),
	(24401),
	(24402),
	(24403),
	(24404),
	(24405),
	(24406),
	(24407),
	(24408),
	(24409),
	(24410),
	(24411),
	(24412),
	(24413),
	(24414),
	(24415),
	(24416),
	(24417),
	(24418),
	(24419),
	(24420),
	(24421),
	(24422),
	(24423),
	(24424),
	(24425),
	(24426),
	(24427),
	(24428),
	(24429),
	(24430),
	(24431),
	(24432),
	(24433),
	(24434),
	(24435),
	(24436),
	(24437),
	(24438),
	(24439),
	(24440),
	(24441),
	(24442),
	(24443),
	(24444),
	(24445),
	(24446),
	(24447),
	(24448),
	(24449),
	(24450),
	(24451),
	(24452),
	(24453),
	(24454),
	(24455),
	(24456),
	(24457),
	(24458),
	(24459),
	(24460),
	(24461),
	(24462),
	(24463),
	(24464),
	(24465),
	(24466),
	(24467),
	(24468),
	(24469),
	(24470),
	(24471),
	(24472),
	(24473),
	(24474),
	(24475),
	(24476),
	(24477),
	(24478),
	(24479),
	(24480),
	(24481),
	(24482),
	(24483),
	(24484),
	(24485),
	(24486),
	(24487),
	(24488),
	(24489),
	(24490),
	(24491),
	(24492),
	(24493),
	(24494),
	(24495),
	(24496),
	(24497),
	(24498),
	(24499),
	(24500),
	(24501),
	(24502),
	(24503),
	(24504),
	(24505),
	(24506),
	(24507),
	(24508),
	(24509),
	(24510),
	(24511),
	(24512),
	(24513),
	(24514),
	(24515),
	(24516),
	(24517),
	(24518),
	(24519),
	(24520),
	(24521),
	(24522),
	(24523),
	(24524),
	(24525),
	(24526),
	(24527),
	(24528),
	(24529),
	(24530),
	(24531),
	(24532),
	(24533),
	(24534),
	(24535),
	(24536),
	(24537),
	(24538),
	(24539),
	(24540),
	(24541),
	(24542),
	(24543),
	(24544),
	(24545),
	(24546),
	(24547),
	(24548),
	(24549),
	(24550),
	(24551),
	(24552),
	(24553),
	(24554),
	(24555),
	(24556),
	(24557),
	(24558),
	(24559),
	(24560),
	(24561),
	(24562),
	(24563),
	(24564),
	(24565),
	(24566),
	(24567),
	(24568),
	(24569),
	(24570),
	(24571),
	(24572),
	(24573),
	(24574),
	(24575),
	(24576),
	(24577),
	(24578),
	(24579),
	(24580),
	(24581),
	(24582),
	(24583),
	(24584),
	(24585),
	(24586),
	(24587),
	(24588),
	(24589),
	(24590),
	(24591),
	(24592),
	(24593),
	(24594),
	(24595),
	(24596),
	(24597),
	(24598),
	(24599),
	(24600),
	(24601),
	(24602),
	(24603),
	(24604),
	(24605),
	(24606),
	(24607),
	(24608),
	(24609),
	(24610),
	(24611),
	(24612),
	(24613),
	(24614),
	(24615),
	(24616),
	(24617),
	(24618),
	(24619),
	(24620),
	(24621),
	(24622),
	(24623),
	(24624),
	(24625),
	(24626),
	(24627),
	(24628),
	(24629),
	(24630),
	(24631),
	(24632),
	(24633),
	(24634),
	(24635),
	(24636),
	(24637),
	(24638),
	(24639),
	(24640),
	(24641),
	(24642),
	(24643),
	(24644),
	(24645),
	(24646),
	(24647),
	(24648),
	(24649),
	(24650),
	(24651),
	(24652),
	(24653),
	(24654),
	(24655),
	(24656),
	(24657),
	(24658),
	(24659),
	(24660),
	(24661),
	(24662),
	(24663),
	(24664),
	(24665),
	(24666),
	(24667),
	(24668),
	(24669),
	(24670),
	(24671),
	(24672),
	(24673),
	(24674),
	(24675),
	(24676),
	(24677),
	(24678),
	(24679),
	(24680),
	(24681),
	(24682),
	(24683),
	(24684),
	(24685),
	(24686),
	(24687),
	(24688),
	(24689),
	(24690),
	(24691),
	(24692),
	(24693),
	(24694),
	(24695),
	(24696),
	(24697),
	(24698),
	(24699),
	(24700),
	(24701),
	(24702),
	(24703),
	(24704),
	(24705),
	(24706),
	(24707),
	(24708),
	(24709),
	(24710),
	(24711),
	(24712),
	(24713),
	(24714),
	(24715),
	(24716),
	(24717),
	(24718),
	(24719),
	(24720),
	(24721),
	(24722),
	(24723),
	(24724),
	(24725),
	(24726),
	(24727),
	(24728),
	(24729),
	(24730),
	(24731),
	(24732),
	(24733),
	(24734),
	(24735),
	(24736),
	(24737),
	(24738),
	(24739),
	(24740),
	(24741),
	(24742),
	(24743),
	(24744),
	(24745),
	(24746),
	(24747),
	(24748),
	(24749),
	(24750),
	(24751),
	(24752),
	(24753),
	(24754),
	(24755),
	(24756),
	(24757),
	(24758),
	(24759),
	(24760),
	(24761),
	(24762),
	(24763),
	(24764),
	(24765),
	(24766),
	(24767),
	(24768),
	(24769),
	(24770),
	(24771),
	(24772),
	(24773),
	(24774),
	(24775),
	(24776),
	(24777),
	(24778),
	(24779),
	(24780),
	(24781),
	(24782),
	(24783),
	(24784),
	(24785),
	(24786),
	(24787),
	(24788),
	(24789),
	(24790),
	(24791),
	(24792),
	(24793),
	(24794),
	(24795),
	(24796),
	(24797),
	(24798),
	(24799),
	(24800),
	(24801),
	(24802),
	(24803),
	(24804),
	(24805),
	(24806),
	(24807),
	(24808),
	(24809),
	(24810),
	(24811),
	(24812),
	(24813),
	(24814),
	(24815),
	(24816),
	(24817),
	(24818),
	(24819),
	(24820),
	(24821),
	(24822),
	(24823),
	(24824),
	(24825),
	(24826),
	(24827),
	(24828),
	(24829),
	(24830),
	(24831),
	(24832),
	(24833),
	(24834),
	(24835),
	(24836),
	(24837),
	(24838),
	(24839),
	(24840),
	(24841),
	(24842),
	(24843),
	(24844),
	(24845),
	(24846),
	(24847),
	(24848),
	(24849),
	(24850),
	(24851),
	(24852),
	(24853),
	(24854),
	(24855),
	(24856),
	(24857),
	(24858),
	(24859),
	(24860),
	(24861),
	(24862),
	(24863),
	(24864),
	(24865),
	(24866),
	(24867),
	(24868),
	(24869),
	(24870),
	(24871),
	(24872),
	(24873),
	(24874),
	(24875),
	(24876),
	(24877),
	(24878),
	(24879),
	(24880),
	(24881),
	(24882),
	(24883),
	(24884),
	(24885),
	(24886),
	(24887),
	(24888),
	(24889),
	(24890),
	(24891),
	(24892),
	(24893),
	(24894),
	(24895),
	(24896),
	(24897),
	(24898),
	(24899),
	(24900),
	(24901),
	(24902),
	(24903),
	(24904),
	(24905),
	(24906),
	(24907),
	(24908),
	(24909),
	(24910),
	(24911),
	(24912),
	(24913),
	(24914),
	(24915),
	(24916),
	(24917),
	(24918),
	(24919),
	(24920),
	(24921),
	(24922),
	(24923),
	(24924),
	(24925),
	(24926),
	(24927),
	(24928),
	(24929),
	(24930),
	(24931),
	(24932),
	(24933),
	(24934),
	(24935),
	(24936),
	(24937),
	(24938),
	(24939),
	(24940),
	(24941),
	(24942),
	(24943),
	(24944),
	(24945),
	(24946),
	(24947),
	(24948),
	(24949),
	(24950),
	(24951),
	(24952),
	(24953),
	(24954),
	(24955),
	(24956),
	(24957),
	(24958),
	(24959),
	(24960),
	(24961),
	(24962),
	(24963),
	(24964),
	(24965),
	(24966),
	(24967),
	(24968),
	(24969),
	(24970),
	(24971),
	(24972),
	(24973),
	(24974),
	(24975),
	(24976),
	(24977),
	(24978),
	(24979),
	(24980),
	(24981),
	(24982),
	(24983),
	(24984),
	(24985),
	(24986),
	(24987),
	(24988),
	(24989),
	(24990),
	(24991),
	(24992),
	(24993),
	(24994),
	(24995),
	(24996),
	(24997),
	(24998),
	(24999),
	(25000),
	(25001),
	(25002),
	(25003),
	(25004),
	(25005),
	(25006),
	(25007),
	(25008),
	(25009),
	(25010),
	(25011),
	(25012),
	(25013),
	(25014),
	(25015),
	(25016),
	(25017),
	(25018),
	(25019),
	(25020),
	(25021),
	(25022),
	(25023),
	(25024),
	(25025),
	(25026),
	(25027),
	(25028),
	(25029),
	(25030),
	(25031),
	(25032),
	(25033),
	(25034),
	(25035),
	(25036),
	(25037),
	(25038),
	(25039),
	(25040),
	(25041),
	(25042),
	(25043),
	(25044),
	(25045),
	(25046),
	(25047),
	(25048),
	(25049),
	(25050),
	(25051),
	(25052),
	(25053),
	(25054),
	(25055),
	(25056),
	(25057),
	(25058),
	(25059),
	(25060),
	(25061),
	(25062),
	(25063),
	(25064),
	(25065),
	(25066),
	(25067),
	(25068),
	(25069),
	(25070),
	(25071),
	(25072),
	(25073),
	(25074),
	(25075),
	(25076),
	(25077),
	(25078),
	(25079),
	(25080),
	(25081),
	(25082),
	(25083),
	(25084),
	(25085),
	(25086),
	(25087),
	(25088),
	(25089),
	(25090),
	(25091),
	(25092),
	(25093),
	(25094),
	(25095),
	(25096),
	(25097),
	(25098),
	(25099),
	(25100),
	(25101),
	(25102),
	(25103),
	(25104),
	(25105),
	(25106),
	(25107),
	(25108),
	(25109),
	(25110),
	(25111),
	(25112),
	(25113),
	(25114),
	(25115),
	(25116),
	(25117),
	(25118),
	(25119),
	(25120),
	(25121),
	(25122),
	(25123),
	(25124),
	(25125),
	(25126),
	(25127),
	(25128),
	(25129),
	(25130),
	(25131),
	(25132),
	(25133),
	(25134),
	(25135),
	(25136),
	(25137),
	(25138),
	(25139),
	(25140),
	(25141),
	(25142),
	(25143),
	(25144),
	(25145),
	(25146),
	(25147),
	(25148),
	(25149),
	(25150),
	(25151),
	(25152),
	(25153),
	(25154),
	(25155),
	(25156),
	(25157),
	(25158),
	(25159),
	(25160),
	(25161),
	(25162),
	(25163),
	(25164),
	(25165),
	(25166),
	(25167),
	(25168),
	(25169),
	(25170),
	(25171),
	(25172),
	(25173),
	(25174),
	(25175),
	(25176),
	(25177),
	(25178),
	(25179),
	(25180),
	(25181),
	(25182),
	(25183),
	(25184),
	(25185),
	(25186),
	(25187),
	(25188),
	(25189),
	(25190),
	(25191),
	(25192),
	(25193),
	(25194),
	(25195),
	(25196),
	(25197),
	(25198),
	(25199),
	(25200),
	(25201),
	(25202),
	(25203),
	(25204),
	(25205),
	(25206),
	(25207),
	(25208),
	(25209),
	(25210),
	(25211),
	(25212),
	(25213),
	(25214),
	(25215),
	(25216),
	(25217),
	(25218),
	(25219),
	(25220),
	(25221),
	(25222),
	(25223),
	(25224),
	(25225),
	(25226),
	(25227),
	(25228),
	(25229),
	(25230),
	(25231),
	(25232),
	(25233),
	(25234),
	(25235),
	(25236),
	(25237),
	(25238),
	(25239),
	(25240),
	(25241),
	(25242),
	(25243),
	(25244),
	(25245),
	(25246),
	(25247),
	(25248),
	(25249),
	(25250),
	(25251),
	(25252),
	(25253),
	(25254),
	(25255),
	(25256),
	(25257),
	(25258),
	(25259),
	(25260),
	(25261),
	(25262),
	(25263),
	(25264),
	(25265),
	(25266),
	(25267),
	(25268),
	(25269),
	(25270),
	(25271),
	(25272),
	(25273),
	(25274),
	(25275),
	(25276),
	(25277),
	(25278),
	(25279),
	(25280),
	(25281),
	(25282),
	(25283),
	(25284),
	(25285),
	(25286),
	(25287),
	(25288),
	(25289),
	(25290),
	(25291),
	(25292),
	(25293),
	(25294),
	(25295),
	(25296),
	(25297),
	(25298),
	(25299),
	(25300),
	(25301),
	(25302),
	(25303),
	(25304),
	(25305),
	(25306),
	(25307),
	(25308),
	(25309),
	(25310),
	(25311),
	(25312),
	(25313),
	(25314),
	(25315),
	(25316),
	(25317),
	(25318),
	(25319),
	(25320),
	(25321),
	(25322),
	(25323),
	(25324),
	(25325),
	(25326),
	(25327),
	(25328),
	(25329),
	(25330),
	(25331),
	(25332),
	(25333),
	(25334),
	(25335),
	(25336),
	(25337),
	(25338),
	(25339),
	(25340),
	(25341),
	(25342),
	(25343),
	(25344),
	(25345),
	(25346),
	(25347),
	(25348),
	(25349),
	(25350),
	(25351),
	(25352),
	(25353),
	(25354),
	(25355),
	(25356),
	(25357),
	(25358),
	(25359),
	(25360),
	(25361),
	(25362),
	(25363),
	(25364),
	(25365),
	(25366),
	(25367),
	(25368),
	(25369),
	(25370),
	(25371),
	(25372),
	(25373),
	(25374),
	(25375),
	(25376),
	(25377),
	(25378),
	(25379),
	(25380),
	(25381),
	(25382),
	(25383),
	(25384),
	(25385),
	(25386),
	(25387),
	(25388),
	(25389),
	(25390),
	(25391),
	(25392),
	(25393),
	(25394),
	(25395),
	(25396),
	(25397),
	(25398),
	(25399),
	(25400),
	(25401),
	(25402),
	(25403),
	(25404),
	(25405),
	(25406),
	(25407),
	(25408),
	(25409),
	(25410),
	(25411),
	(25412),
	(25413),
	(25414),
	(25415),
	(25416),
	(25417),
	(25418),
	(25419),
	(25420),
	(25421),
	(25422),
	(25423),
	(25424),
	(25425),
	(25426),
	(25427),
	(25428),
	(25429),
	(25430),
	(25431),
	(25432),
	(25433),
	(25434),
	(25435),
	(25436),
	(25437),
	(25438),
	(25439),
	(25440),
	(25441),
	(25442),
	(25443),
	(25444),
	(25445),
	(25446),
	(25447),
	(25448),
	(25449),
	(25450),
	(25451),
	(25452),
	(25453),
	(25454),
	(25455),
	(25456),
	(25457),
	(25458),
	(25459),
	(25460),
	(25461),
	(25462),
	(25463),
	(25464),
	(25465),
	(25466),
	(25467),
	(25468),
	(25469),
	(25470),
	(25471),
	(25472),
	(25473),
	(25474),
	(25475),
	(25476),
	(25477),
	(25478),
	(25479),
	(25480),
	(25481),
	(25482),
	(25483),
	(25484),
	(25485),
	(25486),
	(25487),
	(25488),
	(25489),
	(25490),
	(25491),
	(25492),
	(25493),
	(25494),
	(25495),
	(25496),
	(25497),
	(25498),
	(25499),
	(25500),
	(25501),
	(25502),
	(25503),
	(25504),
	(25505),
	(25506),
	(25507),
	(25508),
	(25509),
	(25510),
	(25511),
	(25512),
	(25513),
	(25514),
	(25515),
	(25516),
	(25517),
	(25518),
	(25519),
	(25520),
	(25521),
	(25522),
	(25523),
	(25524),
	(25525),
	(25526),
	(25527),
	(25528),
	(25529),
	(25530),
	(25531),
	(25532),
	(25533),
	(25534),
	(25535),
	(25536),
	(25537),
	(25538),
	(25539),
	(25540),
	(25541),
	(25542),
	(25543),
	(25544),
	(25545),
	(25546),
	(25547),
	(25548),
	(25549),
	(25550),
	(25551),
	(25552),
	(25553),
	(25554),
	(25555),
	(25556),
	(25557),
	(25558),
	(25559),
	(25560),
	(25561),
	(25562),
	(25563),
	(25564),
	(25565),
	(25566),
	(25567),
	(25568),
	(25569),
	(25570),
	(25571),
	(25572),
	(25573),
	(25574),
	(25575),
	(25576),
	(25577),
	(25578),
	(25579),
	(25580),
	(25581),
	(25582),
	(25583),
	(25584),
	(25585),
	(25586),
	(25587),
	(25588),
	(25589),
	(25590),
	(25591),
	(25592),
	(25593),
	(25594),
	(25595),
	(25596),
	(25597),
	(25598),
	(25599),
	(25600),
	(25601),
	(25602),
	(25603),
	(25604),
	(25605),
	(25606),
	(25607),
	(25608),
	(25609),
	(25610),
	(25611),
	(25612),
	(25613),
	(25614),
	(25615),
	(25616),
	(25617),
	(25618),
	(25619),
	(25620),
	(25621),
	(25622),
	(25623),
	(25624),
	(25625),
	(25626),
	(25627),
	(25628),
	(25629),
	(25630),
	(25631),
	(25632),
	(25633),
	(25634),
	(25635),
	(25636),
	(25637),
	(25638),
	(25639),
	(25640),
	(25641),
	(25642),
	(25643),
	(25644),
	(25645),
	(25646),
	(25647),
	(25648),
	(25649),
	(25650),
	(25651),
	(25652),
	(25653),
	(25654),
	(25655),
	(25656),
	(25657),
	(25658),
	(25659),
	(25660),
	(25661),
	(25662),
	(25663),
	(25664),
	(25665),
	(25666),
	(25667),
	(25668),
	(25669),
	(25670),
	(25671),
	(25672),
	(25673),
	(25674),
	(25675),
	(25676),
	(25677),
	(25678),
	(25679),
	(25680),
	(25681),
	(25682),
	(25683),
	(25684),
	(25685),
	(25686),
	(25687),
	(25688),
	(25689),
	(25690),
	(25691),
	(25692),
	(25693),
	(25694),
	(25695),
	(25696),
	(25697),
	(25698),
	(25699),
	(25700),
	(25701),
	(25702),
	(25703),
	(25704),
	(25705),
	(25706),
	(25707),
	(25708),
	(25709),
	(25710),
	(25711),
	(25712),
	(25713),
	(25714),
	(25715),
	(25716),
	(25717),
	(25718),
	(25719),
	(25720),
	(25721),
	(25722),
	(25723),
	(25724),
	(25725),
	(25726),
	(25727),
	(25728),
	(25729),
	(25730),
	(25731),
	(25732),
	(25733),
	(25734),
	(25735),
	(25736),
	(25737),
	(25738),
	(25739),
	(25740),
	(25741),
	(25742),
	(25743),
	(25744),
	(25745),
	(25746),
	(25747),
	(25748),
	(25749),
	(25750),
	(25751),
	(25752),
	(25753),
	(25754),
	(25755),
	(25756),
	(25757),
	(25758),
	(25759),
	(25760),
	(25761),
	(25762),
	(25763),
	(25764),
	(25765),
	(25766),
	(25767),
	(25768),
	(25769),
	(25770),
	(25771),
	(25772),
	(25773),
	(25774),
	(25775),
	(25776),
	(25777),
	(25778),
	(25779),
	(25780),
	(25781),
	(25782),
	(25783),
	(25784),
	(25785),
	(25786),
	(25787),
	(25788),
	(25789),
	(25790),
	(25791),
	(25792),
	(25793),
	(25794),
	(25795),
	(25796),
	(25797),
	(25798),
	(25799),
	(25800),
	(25801),
	(25802),
	(25803),
	(25804),
	(25805),
	(25806),
	(25807),
	(25808),
	(25809),
	(25810),
	(25811),
	(25812),
	(25813),
	(25814),
	(25815),
	(25816),
	(25817),
	(25818),
	(25819),
	(25820),
	(25821),
	(25822),
	(25823),
	(25824),
	(25825),
	(25826),
	(25827),
	(25828),
	(25829),
	(25830),
	(25831),
	(25832),
	(25833),
	(25834),
	(25835),
	(25836),
	(25837),
	(25838),
	(25839),
	(25840),
	(25841),
	(25842),
	(25843),
	(25844),
	(25845),
	(25846),
	(25847),
	(25848),
	(25849),
	(25850),
	(25851),
	(25852),
	(25853),
	(25854),
	(25855),
	(25856),
	(25857),
	(25858),
	(25859),
	(25860),
	(25861),
	(25862),
	(25863),
	(25864),
	(25865),
	(25866),
	(25867),
	(25868),
	(25869),
	(25870),
	(25871),
	(25872),
	(25873),
	(25874),
	(25875),
	(25876),
	(25877),
	(25878),
	(25879),
	(25880),
	(25881),
	(25882),
	(25883),
	(25884),
	(25885),
	(25886),
	(25887),
	(25888),
	(25889),
	(25890),
	(25891),
	(25892),
	(25893),
	(25894),
	(25895),
	(25896),
	(25897),
	(25898),
	(25899),
	(25900),
	(25901),
	(25902),
	(25903),
	(25904),
	(25905),
	(25906),
	(25907),
	(25908),
	(25909),
	(25910),
	(25911),
	(25912),
	(25913),
	(25914),
	(25915),
	(25916),
	(25917),
	(25918),
	(25919),
	(25920),
	(25921),
	(25922),
	(25923),
	(25924),
	(25925),
	(25926),
	(25927),
	(25928),
	(25929),
	(25930),
	(25931),
	(25932),
	(25933),
	(25934),
	(25935),
	(25936),
	(25937),
	(25938),
	(25939),
	(25940),
	(25941),
	(25942),
	(25943),
	(25944),
	(25945),
	(25946),
	(25947),
	(25948),
	(25949),
	(25950),
	(25951),
	(25952),
	(25953),
	(25954),
	(25955),
	(25956),
	(25957),
	(25958),
	(25959),
	(25960),
	(25961),
	(25962),
	(25963),
	(25964),
	(25965),
	(25966),
	(25967),
	(25968),
	(25969),
	(25970),
	(25971),
	(25972),
	(25973),
	(25974),
	(25975),
	(25976),
	(25977),
	(25978),
	(25979),
	(25980),
	(25981),
	(25982),
	(25983),
	(25984),
	(25985),
	(25986),
	(25987),
	(25988),
	(25989),
	(25990),
	(25991),
	(25992),
	(25993),
	(25994),
	(25995),
	(25996),
	(25997),
	(25998),
	(25999),
	(26000),
	(26001),
	(26002),
	(26003),
	(26004),
	(26005),
	(26006),
	(26007),
	(26008),
	(26009),
	(26010),
	(26011),
	(26012),
	(26013),
	(26014),
	(26015),
	(26016),
	(26017),
	(26018),
	(26019),
	(26020),
	(26021),
	(26022),
	(26023),
	(26024),
	(26025),
	(26026),
	(26027),
	(26028),
	(26029),
	(26030),
	(26031),
	(26032),
	(26033),
	(26034),
	(26035),
	(26036),
	(26037),
	(26038),
	(26039),
	(26040),
	(26041),
	(26042),
	(26043),
	(26044),
	(26045),
	(26046),
	(26047),
	(26048),
	(26049),
	(26050),
	(26051),
	(26052),
	(26053),
	(26054),
	(26055),
	(26056),
	(26057),
	(26058),
	(26059),
	(26060),
	(26061),
	(26062),
	(26063),
	(26064),
	(26065),
	(26066),
	(26067),
	(26068),
	(26069),
	(26070),
	(26071),
	(26072),
	(26073),
	(26074),
	(26075),
	(26076),
	(26077),
	(26078),
	(26079),
	(26080),
	(26081),
	(26082),
	(26083),
	(26084),
	(26085),
	(26086),
	(26087),
	(26088),
	(26089),
	(26090),
	(26091),
	(26092),
	(26093),
	(26094),
	(26095),
	(26096),
	(26097),
	(26098),
	(26099),
	(26100),
	(26101),
	(26102),
	(26103),
	(26104),
	(26105),
	(26106),
	(26107),
	(26108),
	(26109),
	(26110),
	(26111),
	(26112),
	(26113),
	(26114),
	(26115),
	(26116),
	(26117),
	(26118),
	(26119),
	(26120),
	(26121),
	(26122),
	(26123),
	(26124),
	(26125),
	(26126),
	(26127),
	(26128),
	(26129),
	(26130),
	(26131),
	(26132),
	(26133),
	(26134),
	(26135),
	(26136),
	(26137),
	(26138),
	(26139),
	(26140),
	(26141),
	(26142),
	(26143),
	(26144),
	(26145),
	(26146),
	(26147),
	(26148),
	(26149),
	(26150),
	(26151),
	(26152),
	(26153),
	(26154),
	(26155),
	(26156),
	(26157),
	(26158),
	(26159),
	(26160),
	(26161),
	(26162),
	(26163),
	(26164),
	(26165),
	(26166),
	(26167),
	(26168),
	(26169),
	(26170),
	(26171),
	(26172),
	(26173),
	(26174),
	(26175),
	(26176),
	(26177),
	(26178),
	(26179),
	(26180),
	(26181),
	(26182),
	(26183),
	(26184),
	(26185),
	(26186),
	(26187),
	(26188),
	(26189),
	(26190),
	(26191),
	(26192),
	(26193),
	(26194),
	(26195),
	(26196),
	(26197),
	(26198),
	(26199),
	(26200),
	(26201),
	(26202),
	(26203),
	(26204),
	(26205),
	(26206),
	(26207),
	(26208),
	(26209),
	(26210),
	(26211),
	(26212),
	(26213),
	(26214),
	(26215),
	(26216),
	(26217),
	(26218),
	(26219),
	(26220),
	(26221),
	(26222),
	(26223),
	(26224),
	(26225),
	(26226),
	(26227),
	(26228),
	(26229),
	(26230),
	(26231),
	(26232),
	(26233),
	(26234),
	(26235),
	(26236),
	(26237),
	(26238),
	(26239),
	(26240),
	(26241),
	(26242),
	(26243),
	(26244),
	(26245),
	(26246),
	(26247),
	(26248),
	(26249),
	(26250),
	(26251),
	(26252),
	(26253),
	(26254),
	(26255),
	(26256),
	(26257),
	(26258),
	(26259),
	(26260),
	(26261),
	(26262),
	(26263),
	(26264),
	(26265),
	(26266),
	(26267),
	(26268),
	(26269),
	(26270),
	(26271),
	(26272),
	(26273),
	(26274),
	(26275),
	(26276),
	(26277),
	(26278),
	(26279),
	(26280),
	(26281),
	(26282),
	(26283),
	(26284),
	(26285),
	(26286),
	(26287),
	(26288),
	(26289),
	(26290),
	(26291),
	(26292),
	(26293),
	(26294),
	(26295),
	(26296),
	(26297),
	(26298),
	(26299),
	(26300),
	(26301),
	(26302),
	(26303),
	(26304),
	(26305),
	(26306),
	(26307),
	(26308),
	(26309),
	(26310),
	(26311),
	(26312),
	(26313),
	(26314),
	(26315),
	(26316),
	(26317),
	(26318),
	(26319),
	(26320),
	(26321),
	(26322),
	(26323),
	(26324),
	(26325),
	(26326),
	(26327),
	(26328),
	(26329),
	(26330),
	(26331),
	(26332),
	(26333),
	(26334),
	(26335),
	(26336),
	(26337),
	(26338),
	(26339),
	(26340),
	(26341),
	(26342),
	(26343),
	(26344),
	(26345),
	(26346),
	(26347),
	(26348),
	(26349),
	(26350),
	(26351),
	(26352),
	(26353),
	(26354),
	(26355),
	(26356),
	(26357),
	(26358),
	(26359),
	(26360),
	(26361),
	(26362),
	(26363),
	(26364),
	(26365),
	(26366),
	(26367),
	(26368),
	(26369),
	(26370),
	(26371),
	(26372),
	(26373),
	(26374),
	(26375),
	(26376),
	(26377),
	(26378),
	(26379),
	(26380),
	(26381),
	(26382),
	(26383),
	(26384),
	(26385),
	(26386),
	(26387),
	(26388),
	(26389),
	(26390),
	(26391),
	(26392),
	(26393),
	(26394),
	(26395),
	(26396),
	(26397),
	(26398),
	(26399),
	(26400),
	(26401),
	(26402),
	(26403),
	(26404),
	(26405),
	(26406),
	(26407),
	(26408),
	(26409),
	(26410),
	(26411),
	(26412),
	(26413),
	(26414),
	(26415),
	(26416),
	(26417),
	(26418),
	(26419),
	(26420),
	(26421),
	(26422),
	(26423),
	(26424),
	(26425),
	(26426),
	(26427),
	(26428),
	(26429),
	(26430),
	(26431),
	(26432),
	(26433),
	(26434),
	(26435),
	(26436),
	(26437),
	(26438),
	(26439),
	(26440),
	(26441),
	(26442),
	(26443),
	(26444),
	(26445),
	(26446),
	(26447),
	(26448),
	(26449),
	(26450),
	(26451),
	(26452),
	(26453),
	(26454),
	(26455),
	(26456),
	(26457),
	(26458),
	(26459),
	(26460),
	(26461),
	(26462),
	(26463),
	(26464),
	(26465),
	(26466),
	(26467),
	(26468),
	(26469),
	(26470),
	(26471),
	(26472),
	(26473),
	(26474),
	(26475),
	(26476),
	(26477),
	(26478),
	(26479),
	(26480),
	(26481),
	(26482),
	(26483),
	(26484),
	(26485),
	(26486),
	(26487),
	(26488),
	(26489),
	(26490),
	(26491),
	(26492),
	(26493),
	(26494),
	(26495),
	(26496),
	(26497),
	(26498),
	(26499),
	(26500),
	(26501),
	(26502),
	(26503),
	(26504),
	(26505),
	(26506),
	(26507),
	(26508),
	(26509),
	(26510),
	(26511),
	(26512),
	(26513),
	(26514),
	(26515),
	(26516),
	(26517),
	(26518),
	(26519),
	(26520),
	(26521),
	(26522),
	(26523),
	(26524),
	(26525),
	(26526),
	(26527),
	(26528),
	(26529),
	(26530),
	(26531),
	(26532),
	(26533),
	(26534),
	(26535),
	(26536),
	(26537),
	(26538),
	(26539),
	(26540),
	(26541),
	(26542),
	(26543),
	(26544),
	(26545),
	(26546),
	(26547),
	(26548),
	(26549),
	(26550),
	(26551),
	(26552),
	(26553),
	(26554),
	(26555),
	(26556),
	(26557),
	(26558),
	(26559),
	(26560),
	(26561),
	(26562),
	(26563),
	(26564),
	(26565),
	(26566),
	(26567),
	(26568),
	(26569),
	(26570),
	(26571),
	(26572),
	(26573),
	(26574),
	(26575),
	(26576),
	(26577),
	(26578),
	(26579),
	(26580),
	(26581),
	(26582),
	(26583),
	(26584),
	(26585),
	(26586),
	(26587),
	(26588),
	(26589),
	(26590),
	(26591),
	(26592),
	(26593),
	(26594),
	(26595),
	(26596),
	(26597),
	(26598),
	(26599),
	(26600),
	(26601),
	(26602),
	(26603),
	(26604),
	(26605),
	(26606),
	(26607),
	(26608),
	(26609),
	(26610),
	(26611),
	(26612),
	(26613),
	(26614),
	(26615),
	(26616),
	(26617),
	(26618),
	(26619),
	(26620),
	(26621),
	(26622),
	(26623),
	(26624),
	(26625),
	(26626),
	(26627),
	(26628),
	(26629),
	(26630),
	(26631),
	(26632),
	(26633),
	(26634),
	(26635),
	(26636),
	(26637),
	(26638),
	(26639),
	(26640),
	(26641),
	(26642),
	(26643),
	(26644),
	(26645),
	(26646),
	(26647),
	(26648),
	(26649),
	(26650),
	(26651),
	(26652),
	(26653),
	(26654),
	(26655),
	(26656),
	(26657),
	(26658),
	(26659),
	(26660),
	(26661),
	(26662),
	(26663),
	(26664),
	(26665),
	(26666),
	(26667),
	(26668),
	(26669),
	(26670),
	(26671),
	(26672),
	(26673),
	(26674),
	(26675),
	(26676),
	(26677),
	(26678),
	(26679),
	(26680),
	(26681),
	(26682),
	(26683),
	(26684),
	(26685),
	(26686),
	(26687),
	(26688),
	(26689),
	(26690),
	(26691),
	(26692),
	(26693),
	(26694),
	(26695),
	(26696),
	(26697),
	(26698),
	(26699),
	(26700),
	(26701),
	(26702),
	(26703),
	(26704),
	(26705),
	(26706),
	(26707),
	(26708),
	(26709),
	(26710),
	(26711),
	(26712),
	(26713),
	(26714),
	(26715),
	(26716),
	(26717),
	(26718),
	(26719),
	(26720),
	(26721),
	(26722),
	(26723),
	(26724),
	(26725),
	(26726),
	(26727),
	(26728),
	(26729),
	(26730),
	(26731),
	(26732),
	(26733),
	(26734),
	(26735),
	(26736),
	(26737),
	(26738),
	(26739),
	(26740),
	(26741),
	(26742),
	(26743),
	(26744),
	(26745),
	(26746),
	(26747),
	(26748),
	(26749),
	(26750),
	(26751),
	(26752),
	(26753),
	(26754),
	(26755),
	(26756),
	(26757),
	(26758),
	(26759),
	(26760),
	(26761),
	(26762),
	(26763),
	(26764),
	(26765),
	(26766),
	(26767),
	(26768),
	(26769),
	(26770),
	(26771),
	(26772),
	(26773),
	(26774),
	(26775),
	(26776),
	(26777),
	(26778),
	(26779),
	(26780),
	(26781),
	(26782),
	(26783),
	(26784),
	(26785),
	(26786),
	(26787),
	(26788),
	(26789),
	(26790),
	(26791),
	(26792),
	(26793),
	(26794),
	(26795),
	(26796),
	(26797),
	(26798),
	(26799),
	(26800),
	(26801),
	(26802),
	(26803),
	(26804),
	(26805),
	(26806),
	(26807),
	(26808),
	(26809),
	(26810),
	(26811),
	(26812),
	(26813),
	(26814),
	(26815),
	(26816),
	(26817),
	(26818),
	(26819),
	(26820),
	(26821),
	(26822),
	(26823),
	(26824),
	(26825),
	(26826),
	(26827),
	(26828),
	(26829),
	(26830),
	(26831),
	(26832),
	(26833),
	(26834),
	(26835),
	(26836),
	(26837),
	(26838),
	(26839),
	(26840),
	(26841),
	(26842),
	(26843),
	(26844),
	(26845),
	(26846),
	(26847),
	(26848),
	(26849),
	(26850),
	(26851),
	(26852),
	(26853),
	(26854),
	(26855),
	(26856),
	(26857),
	(26858),
	(26859),
	(26860),
	(26861),
	(26862),
	(26863),
	(26864),
	(26865),
	(26866),
	(26867),
	(26868),
	(26869),
	(26870),
	(26871),
	(26872),
	(26873),
	(26874),
	(26875),
	(26876),
	(26877),
	(26878),
	(26879),
	(26880),
	(26881),
	(26882),
	(26883),
	(26884),
	(26885),
	(26886),
	(26887),
	(26888),
	(26889),
	(26890),
	(26891),
	(26892),
	(26893),
	(26894),
	(26895),
	(26896),
	(26897),
	(26898),
	(26899),
	(26900),
	(26901),
	(26902),
	(26903),
	(26904),
	(26905),
	(26906),
	(26907),
	(26908),
	(26909),
	(26910),
	(26911),
	(26912),
	(26913),
	(26914),
	(26915),
	(26916),
	(26917),
	(26918),
	(26919),
	(26920),
	(26921),
	(26922),
	(26923),
	(26924),
	(26925),
	(26926),
	(26927),
	(26928),
	(26929),
	(26930),
	(26931),
	(26932),
	(26933),
	(26934),
	(26935),
	(26936),
	(26937),
	(26938),
	(26939),
	(26940),
	(26941),
	(26942),
	(26943),
	(26944),
	(26945),
	(26946),
	(26947),
	(26948),
	(26949),
	(26950),
	(26951),
	(26952),
	(26953),
	(26954),
	(26955),
	(26956),
	(26957),
	(26958),
	(26959),
	(26960),
	(26961),
	(26962),
	(26963),
	(26964),
	(26965),
	(26966),
	(26967),
	(26968),
	(26969),
	(26970),
	(26971),
	(26972),
	(26973),
	(26974),
	(26975),
	(26976),
	(26977),
	(26978),
	(26979),
	(26980),
	(26981),
	(26982),
	(26983),
	(26984),
	(26985),
	(26986),
	(26987),
	(26988),
	(26989),
	(26990),
	(26991),
	(26992),
	(26993),
	(26994),
	(26995),
	(26996),
	(26997),
	(26998),
	(26999),
	(27000),
	(27001),
	(27002),
	(27003),
	(27004),
	(27005),
	(27006),
	(27007),
	(27008),
	(27009),
	(27010),
	(27011),
	(27012),
	(27013),
	(27014),
	(27015),
	(27016),
	(27017),
	(27018),
	(27019),
	(27020),
	(27021),
	(27022),
	(27023),
	(27024),
	(27025),
	(27026),
	(27027),
	(27028),
	(27029),
	(27030),
	(27031),
	(27032),
	(27033),
	(27034),
	(27035),
	(27036),
	(27037),
	(27038),
	(27039),
	(27040),
	(27041),
	(27042),
	(27043),
	(27044),
	(27045),
	(27046),
	(27047),
	(27048),
	(27049),
	(27050),
	(27051),
	(27052),
	(27053),
	(27054),
	(27055),
	(27056),
	(27057),
	(27058),
	(27059),
	(27060),
	(27061),
	(27062),
	(27063),
	(27064),
	(27065),
	(27066),
	(27067),
	(27068),
	(27069),
	(27070),
	(27071),
	(27072),
	(27073),
	(27074),
	(27075),
	(27076),
	(27077),
	(27078),
	(27079),
	(27080),
	(27081),
	(27082),
	(27083),
	(27084),
	(27085),
	(27086),
	(27087),
	(27088),
	(27089),
	(27090),
	(27091),
	(27092),
	(27093),
	(27094),
	(27095),
	(27096),
	(27097),
	(27098),
	(27099),
	(27100),
	(27101),
	(27102),
	(27103),
	(27104),
	(27105),
	(27106),
	(27107),
	(27108),
	(27109),
	(27110),
	(27111),
	(27112),
	(27113),
	(27114),
	(27115),
	(27116),
	(27117),
	(27118),
	(27119),
	(27120),
	(27121),
	(27122),
	(27123),
	(27124),
	(27125),
	(27126),
	(27127),
	(27128),
	(27129),
	(27130),
	(27131),
	(27132),
	(27133),
	(27134),
	(27135),
	(27136),
	(27137),
	(27138),
	(27139),
	(27140),
	(27141),
	(27142),
	(27143),
	(27144),
	(27145),
	(27146),
	(27147),
	(27148),
	(27149),
	(27150),
	(27151),
	(27152),
	(27153),
	(27154),
	(27155),
	(27156),
	(27157),
	(27158),
	(27159),
	(27160),
	(27161),
	(27162),
	(27163),
	(27164),
	(27165),
	(27166),
	(27167),
	(27168),
	(27169),
	(27170),
	(27171),
	(27172),
	(27173),
	(27174),
	(27175),
	(27176),
	(27177),
	(27178),
	(27179),
	(27180),
	(27181),
	(27182),
	(27183),
	(27184),
	(27185),
	(27186),
	(27187),
	(27188),
	(27189),
	(27190),
	(27191),
	(27192),
	(27193),
	(27194),
	(27195),
	(27196),
	(27197),
	(27198),
	(27199),
	(27200),
	(27201),
	(27202),
	(27203),
	(27204),
	(27205),
	(27206),
	(27207),
	(27208),
	(27209),
	(27210),
	(27211),
	(27212),
	(27213),
	(27214),
	(27215),
	(27216),
	(27217),
	(27218),
	(27219),
	(27220),
	(27221),
	(27222),
	(27223),
	(27224),
	(27225),
	(27226),
	(27227),
	(27228),
	(27229),
	(27230),
	(27231),
	(27232),
	(27233),
	(27234),
	(27235),
	(27236),
	(27237),
	(27238),
	(27239),
	(27240),
	(27241),
	(27242),
	(27243),
	(27244),
	(27245),
	(27246),
	(27247),
	(27248),
	(27249),
	(27250),
	(27251),
	(27252),
	(27253),
	(27254),
	(27255),
	(27256),
	(27257),
	(27258),
	(27259),
	(27260),
	(27261),
	(27262),
	(27263),
	(27264),
	(27265),
	(27266),
	(27267),
	(27268),
	(27269),
	(27270),
	(27271),
	(27272),
	(27273),
	(27274),
	(27275),
	(27276),
	(27277),
	(27278),
	(27279),
	(27280),
	(27281),
	(27282),
	(27283),
	(27284),
	(27285),
	(27286),
	(27287),
	(27288),
	(27289),
	(27290),
	(27291),
	(27292),
	(27293),
	(27294),
	(27295),
	(27296),
	(27297),
	(27298),
	(27299),
	(27300),
	(27301),
	(27302),
	(27303),
	(27304),
	(27305),
	(27306),
	(27307),
	(27308),
	(27309),
	(27310),
	(27311),
	(27312),
	(27313),
	(27314),
	(27315),
	(27316),
	(27317),
	(27318),
	(27319),
	(27320),
	(27321),
	(27322),
	(27323),
	(27324),
	(27325),
	(27326),
	(27327),
	(27328),
	(27329),
	(27330),
	(27331),
	(27332),
	(27333),
	(27334),
	(27335),
	(27336),
	(27337),
	(27338),
	(27339),
	(27340),
	(27341),
	(27342),
	(27343),
	(27344),
	(27345),
	(27346),
	(27347),
	(27348),
	(27349),
	(27350),
	(27351),
	(27352),
	(27353),
	(27354),
	(27355),
	(27356),
	(27357),
	(27358),
	(27359),
	(27360),
	(27361),
	(27362),
	(27363),
	(27364),
	(27365),
	(27366),
	(27367),
	(27368),
	(27369),
	(27370),
	(27371),
	(27372),
	(27373),
	(27374),
	(27375),
	(27376),
	(27377),
	(27378),
	(27379),
	(27380),
	(27381),
	(27382),
	(27383),
	(27384),
	(27385),
	(27386),
	(27387),
	(27388),
	(27389),
	(27390),
	(27391),
	(27392),
	(27393),
	(27394),
	(27395),
	(27396),
	(27397),
	(27398),
	(27399),
	(27400),
	(27401),
	(27402),
	(27403),
	(27404),
	(27405),
	(27406),
	(27407),
	(27408),
	(27409),
	(27410),
	(27411),
	(27412),
	(27413),
	(27414),
	(27415),
	(27416),
	(27417),
	(27418),
	(27419),
	(27420),
	(27421),
	(27422),
	(27423),
	(27424),
	(27425),
	(27426),
	(27427),
	(27428),
	(27429),
	(27430),
	(27431),
	(27432),
	(27433),
	(27434),
	(27435),
	(27436),
	(27437),
	(27438),
	(27439),
	(27440),
	(27441),
	(27442),
	(27443),
	(27444),
	(27445),
	(27446),
	(27447),
	(27448),
	(27449),
	(27450),
	(27451),
	(27452),
	(27453),
	(27454),
	(27455),
	(27456),
	(27457),
	(27458),
	(27459),
	(27460),
	(27461),
	(27462),
	(27463),
	(27464),
	(27465),
	(27466),
	(27467),
	(27468),
	(27469),
	(27470),
	(27471),
	(27472),
	(27473),
	(27474),
	(27475),
	(27476),
	(27477),
	(27478),
	(27479),
	(27480),
	(27481),
	(27482),
	(27483),
	(27484),
	(27485),
	(27486),
	(27487),
	(27488),
	(27489),
	(27490),
	(27491),
	(27492),
	(27493),
	(27494),
	(27495),
	(27496),
	(27497),
	(27498),
	(27499),
	(27500),
	(27501),
	(27502),
	(27503),
	(27504),
	(27505),
	(27506),
	(27507),
	(27508),
	(27509),
	(27510),
	(27511),
	(27512),
	(27513),
	(27514),
	(27515),
	(27516),
	(27517),
	(27518),
	(27519),
	(27520),
	(27521),
	(27522),
	(27523),
	(27524),
	(27525),
	(27526),
	(27527),
	(27528),
	(27529),
	(27530),
	(27531),
	(27532),
	(27533),
	(27534),
	(27535),
	(27536),
	(27537),
	(27538),
	(27539),
	(27540),
	(27541),
	(27542),
	(27543),
	(27544),
	(27545),
	(27546),
	(27547),
	(27548),
	(27549),
	(27550),
	(27551),
	(27552),
	(27553),
	(27554),
	(27555),
	(27556),
	(27557),
	(27558),
	(27559),
	(27560),
	(27561),
	(27562),
	(27563),
	(27564),
	(27565),
	(27566),
	(27567),
	(27568),
	(27569),
	(27570),
	(27571),
	(27572),
	(27573),
	(27574),
	(27575),
	(27576),
	(27577),
	(27578),
	(27579),
	(27580),
	(27581),
	(27582),
	(27583),
	(27584),
	(27585),
	(27586),
	(27587),
	(27588),
	(27589),
	(27590),
	(27591),
	(27592),
	(27593),
	(27594),
	(27595),
	(27596),
	(27597),
	(27598),
	(27599),
	(27600),
	(27601),
	(27602),
	(27603),
	(27604),
	(27605),
	(27606),
	(27607),
	(27608),
	(27609),
	(27610),
	(27611),
	(27612),
	(27613),
	(27614),
	(27615),
	(27616),
	(27617),
	(27618),
	(27619),
	(27620),
	(27621),
	(27622),
	(27623),
	(27624),
	(27625),
	(27626),
	(27627),
	(27628),
	(27629),
	(27630),
	(27631),
	(27632),
	(27633),
	(27634),
	(27635),
	(27636),
	(27637),
	(27638),
	(27639),
	(27640),
	(27641),
	(27642),
	(27643),
	(27644),
	(27645),
	(27646),
	(27647),
	(27648),
	(27649),
	(27650),
	(27651),
	(27652),
	(27653),
	(27654),
	(27655),
	(27656),
	(27657),
	(27658),
	(27659),
	(27660),
	(27661),
	(27662),
	(27663),
	(27664),
	(27665),
	(27666),
	(27667),
	(27668),
	(27669),
	(27670),
	(27671),
	(27672),
	(27673),
	(27674),
	(27675),
	(27676),
	(27677),
	(27678),
	(27679),
	(27680),
	(27681),
	(27682),
	(27683),
	(27684),
	(27685),
	(27686),
	(27687),
	(27688),
	(27689),
	(27690),
	(27691),
	(27692),
	(27693),
	(27694),
	(27695),
	(27696),
	(27697),
	(27698),
	(27699),
	(27700),
	(27701),
	(27702),
	(27703),
	(27704),
	(27705),
	(27706),
	(27707),
	(27708),
	(27709),
	(27710),
	(27711),
	(27712),
	(27713),
	(27714),
	(27715),
	(27716),
	(27717),
	(27718),
	(27719),
	(27720),
	(27721),
	(27722),
	(27723),
	(27724),
	(27725),
	(27726),
	(27727),
	(27728),
	(27729),
	(27730),
	(27731),
	(27732),
	(27733),
	(27734),
	(27735),
	(27736),
	(27737),
	(27738),
	(27739),
	(27740),
	(27741),
	(27742),
	(27743),
	(27744),
	(27745),
	(27746),
	(27747),
	(27748),
	(27749),
	(27750),
	(27751),
	(27752),
	(27753),
	(27754),
	(27755),
	(27756),
	(27757),
	(27758),
	(27759),
	(27760),
	(27761),
	(27762),
	(27763),
	(27764),
	(27765),
	(27766),
	(27767),
	(27768),
	(27769),
	(27770),
	(27771),
	(27772),
	(27773),
	(27774),
	(27775),
	(27776),
	(27777),
	(27778),
	(27779),
	(27780),
	(27781),
	(27782),
	(27783),
	(27784),
	(27785),
	(27786),
	(27787),
	(27788),
	(27789),
	(27790),
	(27791),
	(27792),
	(27793),
	(27794),
	(27795),
	(27796),
	(27797),
	(27798),
	(27799),
	(27800),
	(27801),
	(27802),
	(27803),
	(27804),
	(27805),
	(27806),
	(27807),
	(27808),
	(27809),
	(27810),
	(27811),
	(27812),
	(27813),
	(27814),
	(27815),
	(27816),
	(27817),
	(27818),
	(27819),
	(27820),
	(27821),
	(27822),
	(27823),
	(27824),
	(27825),
	(27826),
	(27827),
	(27828),
	(27829),
	(27830),
	(27831),
	(27832),
	(27833),
	(27834),
	(27835),
	(27836),
	(27837),
	(27838),
	(27839),
	(27840),
	(27841),
	(27842),
	(27843),
	(27844),
	(27845),
	(27846),
	(27847),
	(27848),
	(27849),
	(27850),
	(27851),
	(27852),
	(27853),
	(27854),
	(27855),
	(27856),
	(27857),
	(27858),
	(27859),
	(27860),
	(27861),
	(27862),
	(27863),
	(27864),
	(27865),
	(27866),
	(27867),
	(27868),
	(27869),
	(27870),
	(27871),
	(27872),
	(27873),
	(27874),
	(27875),
	(27876),
	(27877),
	(27878),
	(27879),
	(27880),
	(27881),
	(27882),
	(27883),
	(27884),
	(27885),
	(27886),
	(27887),
	(27888),
	(27889),
	(27890),
	(27891),
	(27892),
	(27893),
	(27894),
	(27895),
	(27896),
	(27897),
	(27898),
	(27899),
	(27900),
	(27901),
	(27902),
	(27903),
	(27904),
	(27905),
	(27906),
	(27907),
	(27908),
	(27909),
	(27910),
	(27911),
	(27912),
	(27913),
	(27914),
	(27915),
	(27916),
	(27917),
	(27918),
	(27919),
	(27920),
	(27921),
	(27922),
	(27923),
	(27924),
	(27925),
	(27926),
	(27927),
	(27928),
	(27929),
	(27930),
	(27931),
	(27932),
	(27933),
	(27934),
	(27935),
	(27936),
	(27937),
	(27938),
	(27939),
	(27940),
	(27941),
	(27942),
	(27943),
	(27944),
	(27945),
	(27946),
	(27947),
	(27948),
	(27949),
	(27950),
	(27951),
	(27952),
	(27953),
	(27954),
	(27955),
	(27956),
	(27957),
	(27958),
	(27959),
	(27960),
	(27961),
	(27962),
	(27963),
	(27964),
	(27965),
	(27966),
	(27967),
	(27968),
	(27969),
	(27970),
	(27971),
	(27972),
	(27973),
	(27974),
	(27975),
	(27976),
	(27977),
	(27978),
	(27979),
	(27980),
	(27981),
	(27982),
	(27983),
	(27984),
	(27985),
	(27986),
	(27987),
	(27988),
	(27989),
	(27990),
	(27991),
	(27992),
	(27993),
	(27994),
	(27995),
	(27996),
	(27997),
	(27998),
	(27999),
	(28000),
	(28001),
	(28002),
	(28003),
	(28004),
	(28005),
	(28006),
	(28007),
	(28008),
	(28009),
	(28010),
	(28011),
	(28012),
	(28013),
	(28014),
	(28015),
	(28016),
	(28017),
	(28018),
	(28019),
	(28020),
	(28021),
	(28022),
	(28023),
	(28024),
	(28025),
	(28026),
	(28027),
	(28028),
	(28029),
	(28030),
	(28031),
	(28032),
	(28033),
	(28034),
	(28035),
	(28036),
	(28037),
	(28038),
	(28039),
	(28040),
	(28041),
	(28042),
	(28043),
	(28044),
	(28045),
	(28046),
	(28047),
	(28048),
	(28049),
	(28050),
	(28051),
	(28052),
	(28053),
	(28054),
	(28055),
	(28056),
	(28057),
	(28058),
	(28059),
	(28060),
	(28061),
	(28062),
	(28063),
	(28064),
	(28065),
	(28066),
	(28067),
	(28068),
	(28069),
	(28070),
	(28071),
	(28072),
	(28073),
	(28074),
	(28075),
	(28076),
	(28077),
	(28078),
	(28079),
	(28080),
	(28081),
	(28082),
	(28083),
	(28084),
	(28085),
	(28086),
	(28087),
	(28088),
	(28089),
	(28090),
	(28091),
	(28092),
	(28093),
	(28094),
	(28095),
	(28096),
	(28097),
	(28098),
	(28099),
	(28100),
	(28101),
	(28102),
	(28103),
	(28104),
	(28105),
	(28106),
	(28107),
	(28108),
	(28109),
	(28110),
	(28111),
	(28112),
	(28113),
	(28114),
	(28115),
	(28116),
	(28117),
	(28118),
	(28119),
	(28120),
	(28121),
	(28122),
	(28123),
	(28124),
	(28125),
	(28126),
	(28127),
	(28128),
	(28129),
	(28130),
	(28131),
	(28132),
	(28133),
	(28134),
	(28135),
	(28136),
	(28137),
	(28138),
	(28139),
	(28140),
	(28141),
	(28142),
	(28143),
	(28144),
	(28145),
	(28146),
	(28147),
	(28148),
	(28149),
	(28150),
	(28151),
	(28152),
	(28153),
	(28154),
	(28155),
	(28156),
	(28157),
	(28158),
	(28159),
	(28160),
	(28161),
	(28162),
	(28163),
	(28164),
	(28165),
	(28166),
	(28167),
	(28168),
	(28169),
	(28170),
	(28171),
	(28172),
	(28173),
	(28174),
	(28175),
	(28176),
	(28177),
	(28178),
	(28179),
	(28180),
	(28181),
	(28182),
	(28183),
	(28184),
	(28185),
	(28186),
	(28187),
	(28188),
	(28189),
	(28190),
	(28191),
	(28192),
	(28193),
	(28194),
	(28195),
	(28196),
	(28197),
	(28198),
	(28199),
	(28200),
	(28201),
	(28202),
	(28203),
	(28204),
	(28205),
	(28206),
	(28207),
	(28208),
	(28209),
	(28210),
	(28211),
	(28212),
	(28213),
	(28214),
	(28215),
	(28216),
	(28217),
	(28218),
	(28219),
	(28220),
	(28221),
	(28222),
	(28223),
	(28224),
	(28225),
	(28226),
	(28227),
	(28228),
	(28229),
	(28230),
	(28231),
	(28232),
	(28233),
	(28234),
	(28235),
	(28236),
	(28237),
	(28238),
	(28239),
	(28240),
	(28241),
	(28242),
	(28243),
	(28244),
	(28245),
	(28246),
	(28247),
	(28248),
	(28249),
	(28250),
	(28251),
	(28252),
	(28253),
	(28254),
	(28255),
	(28256),
	(28257),
	(28258),
	(28259),
	(28260),
	(28261),
	(28262),
	(28263),
	(28264),
	(28265),
	(28266),
	(28267),
	(28268),
	(28269),
	(28270),
	(28271),
	(28272),
	(28273),
	(28274),
	(28275),
	(28276),
	(28277),
	(28278),
	(28279),
	(28280),
	(28281),
	(28282),
	(28283),
	(28284),
	(28285),
	(28286),
	(28287),
	(28288),
	(28289),
	(28290),
	(28291),
	(28292),
	(28293),
	(28294),
	(28295),
	(28296),
	(28297),
	(28298),
	(28299),
	(28300),
	(28301),
	(28302),
	(28303),
	(28304),
	(28305),
	(28306),
	(28307),
	(28308),
	(28309),
	(28310),
	(28311),
	(28312),
	(28313),
	(28314),
	(28315),
	(28316),
	(28317),
	(28318),
	(28319),
	(28320),
	(28321),
	(28322),
	(28323),
	(28324),
	(28325),
	(28326),
	(28327),
	(28328),
	(28329),
	(28330),
	(28331),
	(28332),
	(28333),
	(28334),
	(28335),
	(28336),
	(28337),
	(28338),
	(28339),
	(28340),
	(28341),
	(28342),
	(28343),
	(28344),
	(28345),
	(28346),
	(28347),
	(28348),
	(28349),
	(28350),
	(28351),
	(28352),
	(28353),
	(28354),
	(28355),
	(28356),
	(28357),
	(28358),
	(28359),
	(28360),
	(28361),
	(28362),
	(28363),
	(28364),
	(28365),
	(28366),
	(28367),
	(28368),
	(28369),
	(28370),
	(28371),
	(28372),
	(28373),
	(28374),
	(28375),
	(28376),
	(28377),
	(28378),
	(28379),
	(28380),
	(28381),
	(28382),
	(28383),
	(28384),
	(28385),
	(28386),
	(28387),
	(28388),
	(28389),
	(28390),
	(28391),
	(28392),
	(28393),
	(28394),
	(28395),
	(28396),
	(28397),
	(28398),
	(28399),
	(28400),
	(28401),
	(28402),
	(28403),
	(28404),
	(28405),
	(28406),
	(28407),
	(28408),
	(28409),
	(28410),
	(28411),
	(28412),
	(28413),
	(28414),
	(28415),
	(28416),
	(28417),
	(28418),
	(28419),
	(28420),
	(28421),
	(28422),
	(28423),
	(28424),
	(28425),
	(28426),
	(28427),
	(28428),
	(28429),
	(28430),
	(28431),
	(28432),
	(28433),
	(28434),
	(28435),
	(28436),
	(28437),
	(28438),
	(28439),
	(28440),
	(28441),
	(28442),
	(28443),
	(28444),
	(28445),
	(28446),
	(28447),
	(28448),
	(28449),
	(28450),
	(28451),
	(28452),
	(28453),
	(28454),
	(28455),
	(28456),
	(28457),
	(28458),
	(28459),
	(28460),
	(28461),
	(28462),
	(28463),
	(28464),
	(28465),
	(28466),
	(28467),
	(28468),
	(28469),
	(28470),
	(28471),
	(28472),
	(28473),
	(28474),
	(28475),
	(28476),
	(28477),
	(28478),
	(28479),
	(28480),
	(28481),
	(28482),
	(28483),
	(28484),
	(28485),
	(28486),
	(28487),
	(28488),
	(28489),
	(28490),
	(28491),
	(28492),
	(28493),
	(28494),
	(28495),
	(28496),
	(28497),
	(28498),
	(28499),
	(28500),
	(28501),
	(28502),
	(28503),
	(28504),
	(28505),
	(28506),
	(28507),
	(28508),
	(28509),
	(28510),
	(28511),
	(28512),
	(28513),
	(28514),
	(28515),
	(28516),
	(28517),
	(28518),
	(28519),
	(28520),
	(28521),
	(28522),
	(28523),
	(28524),
	(28525),
	(28526),
	(28527),
	(28528),
	(28529),
	(28530),
	(28531),
	(28532),
	(28533),
	(28534),
	(28535),
	(28536),
	(28537),
	(28538),
	(28539),
	(28540),
	(28541),
	(28542),
	(28543),
	(28544),
	(28545),
	(28546),
	(28547),
	(28548),
	(28549),
	(28550),
	(28551),
	(28552),
	(28553),
	(28554),
	(28555),
	(28556),
	(28557),
	(28558),
	(28559),
	(28560),
	(28561),
	(28562),
	(28563),
	(28564),
	(28565),
	(28566),
	(28567),
	(28568),
	(28569),
	(28570),
	(28571),
	(28572),
	(28573),
	(28574),
	(28575),
	(28576),
	(28577),
	(28578),
	(28579),
	(28580),
	(28581),
	(28582),
	(28583),
	(28584),
	(28585),
	(28586),
	(28587),
	(28588),
	(28589),
	(28590),
	(28591),
	(28592),
	(28593),
	(28594),
	(28595),
	(28596),
	(28597),
	(28598),
	(28599),
	(28600),
	(28601),
	(28602),
	(28603),
	(28604),
	(28605),
	(28606),
	(28607),
	(28608),
	(28609),
	(28610),
	(28611),
	(28612),
	(28613),
	(28614),
	(28615),
	(28616),
	(28617),
	(28618),
	(28619),
	(28620),
	(28621),
	(28622),
	(28623),
	(28624),
	(28625),
	(28626),
	(28627),
	(28628),
	(28629),
	(28630),
	(28631),
	(28632),
	(28633),
	(28634),
	(28635),
	(28636),
	(28637),
	(28638),
	(28639),
	(28640),
	(28641),
	(28642),
	(28643),
	(28644),
	(28645),
	(28646),
	(28647),
	(28648),
	(28649),
	(28650),
	(28651),
	(28652),
	(28653),
	(28654),
	(28655),
	(28656),
	(28657),
	(28658),
	(28659),
	(28660),
	(28661),
	(28662),
	(28663),
	(28664),
	(28665),
	(28666),
	(28667),
	(28668),
	(28669),
	(28670),
	(28671),
	(28672),
	(28673),
	(28674),
	(28675),
	(28676),
	(28677),
	(28678),
	(28679),
	(28680),
	(28681),
	(28682),
	(28683),
	(28684),
	(28685),
	(28686),
	(28687),
	(28688),
	(28689),
	(28690),
	(28691),
	(28692),
	(28693),
	(28694),
	(28695),
	(28696),
	(28697),
	(28698),
	(28699),
	(28700),
	(28701),
	(28702),
	(28703),
	(28704),
	(28705),
	(28706),
	(28707),
	(28708),
	(28709),
	(28710),
	(28711),
	(28712),
	(28713),
	(28714),
	(28715),
	(28716),
	(28717),
	(28718),
	(28719),
	(28720),
	(28721),
	(28722),
	(28723),
	(28724),
	(28725),
	(28726),
	(28727),
	(28728),
	(28729),
	(28730),
	(28731),
	(28732),
	(28733),
	(28734),
	(28735),
	(28736),
	(28737),
	(28738),
	(28739),
	(28740),
	(28741),
	(28742),
	(28743),
	(28744),
	(28745),
	(28746),
	(28747),
	(28748),
	(28749),
	(28750),
	(28751),
	(28752),
	(28753),
	(28754),
	(28755),
	(28756),
	(28757),
	(28758),
	(28759),
	(28760),
	(28761),
	(28762),
	(28763),
	(28764),
	(28765),
	(28766),
	(28767),
	(28768),
	(28769),
	(28770),
	(28771),
	(28772),
	(28773),
	(28774),
	(28775),
	(28776),
	(28777),
	(28778),
	(28779),
	(28780),
	(28781),
	(28782),
	(28783),
	(28784),
	(28785),
	(28786),
	(28787),
	(28788),
	(28789),
	(28790),
	(28791),
	(28792),
	(28793),
	(28794),
	(28795),
	(28796),
	(28797),
	(28798),
	(28799),
	(28800),
	(28801),
	(28802),
	(28803),
	(28804),
	(28805),
	(28806),
	(28807),
	(28808),
	(28809),
	(28810),
	(28811),
	(28812),
	(28813),
	(28814),
	(28815),
	(28816),
	(28817),
	(28818),
	(28819),
	(28820),
	(28821),
	(28822),
	(28823),
	(28824),
	(28825),
	(28826),
	(28827),
	(28828),
	(28829),
	(28830),
	(28831),
	(28832),
	(28833),
	(28834),
	(28835),
	(28836),
	(28837),
	(28838),
	(28839),
	(28840),
	(28841),
	(28842),
	(28843),
	(28844),
	(28845),
	(28846),
	(28847),
	(28848),
	(28849),
	(28850),
	(28851),
	(28852),
	(28853),
	(28854),
	(28855),
	(28856),
	(28857),
	(28858),
	(28859),
	(28860),
	(28861),
	(28862),
	(28863),
	(28864),
	(28865),
	(28866),
	(28867),
	(28868),
	(28869),
	(28870),
	(28871),
	(28872),
	(28873),
	(28874),
	(28875),
	(28876),
	(28877),
	(28878),
	(28879),
	(28880),
	(28881),
	(28882),
	(28883),
	(28884),
	(28885),
	(28886),
	(28887),
	(28888),
	(28889),
	(28890),
	(28891),
	(28892),
	(28893),
	(28894),
	(28895),
	(28896),
	(28897),
	(28898),
	(28899),
	(28900),
	(28901),
	(28902),
	(28903),
	(28904),
	(28905),
	(28906),
	(28907),
	(28908),
	(28909),
	(28910),
	(28911),
	(28912),
	(28913),
	(28914),
	(28915),
	(28916),
	(28917),
	(28918),
	(28919),
	(28920),
	(28921),
	(28922),
	(28923),
	(28924),
	(28925),
	(28926),
	(28927),
	(28928),
	(28929),
	(28930),
	(28931),
	(28932),
	(28933),
	(28934),
	(28935),
	(28936),
	(28937),
	(28938),
	(28939),
	(28940),
	(28941),
	(28942),
	(28943),
	(28944),
	(28945),
	(28946),
	(28947),
	(28948),
	(28949),
	(28950),
	(28951),
	(28952),
	(28953),
	(28954),
	(28955),
	(28956),
	(28957),
	(28958),
	(28959),
	(28960),
	(28961),
	(28962),
	(28963),
	(28964),
	(28965),
	(28966),
	(28967),
	(28968),
	(28969),
	(28970),
	(28971),
	(28972),
	(28973),
	(28974),
	(28975),
	(28976),
	(28977),
	(28978),
	(28979),
	(28980),
	(28981),
	(28982),
	(28983),
	(28984),
	(28985),
	(28986),
	(28987),
	(28988),
	(28989),
	(28990),
	(28991),
	(28992),
	(28993),
	(28994),
	(28995),
	(28996),
	(28997),
	(28998),
	(28999),
	(29000),
	(29001),
	(29002),
	(29003),
	(29004),
	(29005),
	(29006),
	(29007),
	(29008),
	(29009),
	(29010),
	(29011),
	(29012),
	(29013),
	(29014),
	(29015),
	(29016),
	(29017),
	(29018),
	(29019),
	(29020),
	(29021),
	(29022),
	(29023),
	(29024),
	(29025),
	(29026),
	(29027),
	(29028),
	(29029),
	(29030),
	(29031),
	(29032),
	(29033),
	(29034),
	(29035),
	(29036),
	(29037),
	(29038),
	(29039),
	(29040),
	(29041),
	(29042),
	(29043),
	(29044),
	(29045),
	(29046),
	(29047),
	(29048),
	(29049),
	(29050),
	(29051),
	(29052),
	(29053),
	(29054),
	(29055),
	(29056),
	(29057),
	(29058),
	(29059),
	(29060),
	(29061),
	(29062),
	(29063),
	(29064),
	(29065),
	(29066),
	(29067),
	(29068),
	(29069),
	(29070),
	(29071),
	(29072),
	(29073),
	(29074),
	(29075),
	(29076),
	(29077),
	(29078),
	(29079),
	(29080),
	(29081),
	(29082),
	(29083),
	(29084),
	(29085),
	(29086),
	(29087),
	(29088),
	(29089),
	(29090),
	(29091),
	(29092),
	(29093),
	(29094),
	(29095),
	(29096),
	(29097),
	(29098),
	(29099),
	(29100),
	(29101),
	(29102),
	(29103),
	(29104),
	(29105),
	(29106),
	(29107),
	(29108),
	(29109),
	(29110),
	(29111),
	(29112),
	(29113),
	(29114),
	(29115),
	(29116),
	(29117),
	(29118),
	(29119),
	(29120),
	(29121),
	(29122),
	(29123),
	(29124),
	(29125),
	(29126),
	(29127),
	(29128),
	(29129),
	(29130),
	(29131),
	(29132),
	(29133),
	(29134),
	(29135),
	(29136),
	(29137),
	(29138),
	(29139),
	(29140),
	(29141),
	(29142),
	(29143),
	(29144),
	(29145),
	(29146),
	(29147),
	(29148),
	(29149),
	(29150),
	(29151),
	(29152),
	(29153),
	(29154),
	(29155),
	(29156),
	(29157),
	(29158),
	(29159),
	(29160),
	(29161),
	(29162),
	(29163),
	(29164),
	(29165),
	(29166),
	(29167),
	(29168),
	(29169),
	(29170),
	(29171),
	(29172),
	(29173),
	(29174),
	(29175),
	(29176),
	(29177),
	(29178),
	(29179),
	(29180),
	(29181),
	(29182),
	(29183),
	(29184),
	(29185),
	(29186),
	(29187),
	(29188),
	(29189),
	(29190),
	(29191),
	(29192),
	(29193),
	(29194),
	(29195),
	(29196),
	(29197),
	(29198),
	(29199),
	(29200),
	(29201),
	(29202),
	(29203),
	(29204),
	(29205),
	(29206),
	(29207),
	(29208),
	(29209),
	(29210),
	(29211),
	(29212),
	(29213),
	(29214),
	(29215),
	(29216),
	(29217),
	(29218),
	(29219),
	(29220),
	(29221),
	(29222),
	(29223),
	(29224),
	(29225),
	(29226),
	(29227),
	(29228),
	(29229),
	(29230),
	(29231),
	(29232),
	(29233),
	(29234),
	(29235),
	(29236),
	(29237),
	(29238),
	(29239),
	(29240),
	(29241),
	(29242),
	(29243),
	(29244),
	(29245),
	(29246),
	(29247),
	(29248),
	(29249),
	(29250),
	(29251),
	(29252),
	(29253),
	(29254),
	(29255),
	(29256),
	(29257),
	(29258),
	(29259),
	(29260),
	(29261),
	(29262),
	(29263),
	(29264),
	(29265),
	(29266),
	(29267),
	(29268),
	(29269),
	(29270),
	(29271),
	(29272),
	(29273),
	(29274),
	(29275),
	(29276),
	(29277),
	(29278),
	(29279),
	(29280),
	(29281),
	(29282),
	(29283),
	(29284),
	(29285),
	(29286),
	(29287),
	(29288),
	(29289),
	(29290),
	(29291),
	(29292),
	(29293),
	(29294),
	(29295),
	(29296),
	(29297),
	(29298),
	(29299),
	(29300),
	(29301),
	(29302),
	(29303),
	(29304),
	(29305),
	(29306),
	(29307),
	(29308),
	(29309),
	(29310),
	(29311),
	(29312),
	(29313),
	(29314),
	(29315),
	(29316),
	(29317),
	(29318),
	(29319),
	(29320),
	(29321),
	(29322),
	(29323),
	(29324),
	(29325),
	(29326),
	(29327),
	(29328),
	(29329),
	(29330),
	(29331),
	(29332),
	(29333),
	(29334),
	(29335),
	(29336),
	(29337),
	(29338),
	(29339),
	(29340),
	(29341),
	(29342),
	(29343),
	(29344),
	(29345),
	(29346),
	(29347),
	(29348),
	(29349),
	(29350),
	(29351),
	(29352),
	(29353),
	(29354),
	(29355),
	(29356),
	(29357),
	(29358),
	(29359),
	(29360),
	(29361),
	(29362),
	(29363),
	(29364),
	(29365),
	(29366),
	(29367),
	(29368),
	(29369),
	(29370),
	(29371),
	(29372),
	(29373),
	(29374),
	(29375),
	(29376),
	(29377),
	(29378),
	(29379),
	(29380),
	(29381),
	(29382),
	(29383),
	(29384),
	(29385),
	(29386),
	(29387),
	(29388),
	(29389),
	(29390),
	(29391),
	(29392),
	(29393),
	(29394),
	(29395),
	(29396),
	(29397),
	(29398),
	(29399),
	(29400),
	(29401),
	(29402),
	(29403),
	(29404),
	(29405),
	(29406),
	(29407),
	(29408),
	(29409),
	(29410),
	(29411),
	(29412),
	(29413),
	(29414),
	(29415),
	(29416),
	(29417),
	(29418),
	(29419),
	(29420),
	(29421),
	(29422),
	(29423),
	(29424),
	(29425),
	(29426),
	(29427),
	(29428),
	(29429),
	(29430),
	(29431),
	(29432),
	(29433),
	(29434),
	(29435),
	(29436),
	(29437),
	(29438),
	(29439),
	(29440),
	(29441),
	(29442),
	(29443),
	(29444),
	(29445),
	(29446),
	(29447),
	(29448),
	(29449),
	(29450),
	(29451),
	(29452),
	(29453),
	(29454),
	(29455),
	(29456),
	(29457),
	(29458),
	(29459),
	(29460),
	(29461),
	(29462),
	(29463),
	(29464),
	(29465),
	(29466),
	(29467),
	(29468),
	(29469),
	(29470),
	(29471),
	(29472),
	(29473),
	(29474),
	(29475),
	(29476),
	(29477),
	(29478),
	(29479),
	(29480),
	(29481),
	(29482),
	(29483),
	(29484),
	(29485),
	(29486),
	(29487),
	(29488),
	(29489),
	(29490),
	(29491),
	(29492),
	(29493),
	(29494),
	(29495),
	(29496),
	(29497),
	(29498),
	(29499),
	(29500),
	(29501),
	(29502),
	(29503),
	(29504),
	(29505),
	(29506),
	(29507),
	(29508),
	(29509),
	(29510),
	(29511),
	(29512),
	(29513),
	(29514),
	(29515),
	(29516),
	(29517),
	(29518),
	(29519),
	(29520),
	(29521),
	(29522),
	(29523),
	(29524),
	(29525),
	(29526),
	(29527),
	(29528),
	(29529),
	(29530),
	(29531),
	(29532),
	(29533),
	(29534),
	(29535),
	(29536),
	(29537),
	(29538),
	(29539),
	(29540),
	(29541),
	(29542),
	(29543),
	(29544),
	(29545),
	(29546),
	(29547),
	(29548),
	(29549),
	(29550),
	(29551),
	(29552),
	(29553),
	(29554),
	(29555),
	(29556),
	(29557),
	(29558),
	(29559),
	(29560),
	(29561),
	(29562),
	(29563),
	(29564),
	(29565),
	(29566),
	(29567),
	(29568),
	(29569),
	(29570),
	(29571),
	(29572),
	(29573),
	(29574),
	(29575),
	(29576),
	(29577),
	(29578),
	(29579),
	(29580),
	(29581),
	(29582),
	(29583),
	(29584),
	(29585),
	(29586),
	(29587),
	(29588),
	(29589),
	(29590),
	(29591),
	(29592),
	(29593),
	(29594),
	(29595),
	(29596),
	(29597),
	(29598),
	(29599),
	(29600),
	(29601),
	(29602),
	(29603),
	(29604),
	(29605),
	(29606),
	(29607),
	(29608),
	(29609),
	(29610),
	(29611),
	(29612),
	(29613),
	(29614),
	(29615),
	(29616),
	(29617),
	(29618),
	(29619),
	(29620),
	(29621),
	(29622),
	(29623),
	(29624),
	(29625),
	(29626),
	(29627),
	(29628),
	(29629),
	(29630),
	(29631),
	(29632),
	(29633),
	(29634),
	(29635),
	(29636),
	(29637),
	(29638),
	(29639),
	(29640),
	(29641),
	(29642),
	(29643),
	(29644),
	(29645),
	(29646),
	(29647),
	(29648),
	(29649),
	(29650),
	(29651),
	(29652),
	(29653),
	(29654),
	(29655),
	(29656),
	(29657),
	(29658),
	(29659),
	(29660),
	(29661),
	(29662),
	(29663),
	(29664),
	(29665),
	(29666),
	(29667),
	(29668),
	(29669),
	(29670),
	(29671),
	(29672),
	(29673),
	(29674),
	(29675),
	(29676),
	(29677),
	(29678),
	(29679),
	(29680),
	(29681),
	(29682),
	(29683),
	(29684),
	(29685),
	(29686),
	(29687),
	(29688),
	(29689),
	(29690),
	(29691),
	(29692),
	(29693),
	(29694),
	(29695),
	(29696),
	(29697),
	(29698),
	(29699),
	(29700),
	(29701),
	(29702),
	(29703),
	(29704),
	(29705),
	(29706),
	(29707),
	(29708),
	(29709),
	(29710),
	(29711),
	(29712),
	(29713),
	(29714),
	(29715),
	(29716),
	(29717),
	(29718),
	(29719),
	(29720),
	(29721),
	(29722),
	(29723),
	(29724),
	(29725),
	(29726),
	(29727),
	(29728),
	(29729),
	(29730),
	(29731),
	(29732),
	(29733),
	(29734),
	(29735),
	(29736),
	(29737),
	(29738),
	(29739),
	(29740),
	(29741),
	(29742),
	(29743),
	(29744),
	(29745),
	(29746),
	(29747),
	(29748),
	(29749),
	(29750),
	(29751),
	(29752),
	(29753),
	(29754),
	(29755),
	(29756),
	(29757),
	(29758),
	(29759),
	(29760),
	(29761),
	(29762),
	(29763),
	(29764),
	(29765),
	(29766),
	(29767),
	(29768),
	(29769),
	(29770),
	(29771),
	(29772),
	(29773),
	(29774),
	(29775),
	(29776),
	(29777),
	(29778),
	(29779),
	(29780),
	(29781),
	(29782),
	(29783),
	(29784),
	(29785),
	(29786),
	(29787),
	(29788),
	(29789),
	(29790),
	(29791),
	(29792),
	(29793),
	(29794),
	(29795),
	(29796),
	(29797),
	(29798),
	(29799),
	(29800),
	(29801),
	(29802),
	(29803),
	(29804),
	(29805),
	(29806),
	(29807),
	(29808),
	(29809),
	(29810),
	(29811),
	(29812),
	(29813),
	(29814),
	(29815),
	(29816),
	(29817),
	(29818),
	(29819),
	(29820),
	(29821),
	(29822),
	(29823),
	(29824),
	(29825),
	(29826),
	(29827),
	(29828),
	(29829),
	(29830),
	(29831),
	(29832),
	(29833),
	(29834),
	(29835),
	(29836),
	(29837),
	(29838),
	(29839),
	(29840),
	(29841),
	(29842),
	(29843),
	(29844),
	(29845),
	(29846),
	(29847),
	(29848),
	(29849),
	(29850),
	(29851),
	(29852),
	(29853),
	(29854),
	(29855),
	(29856),
	(29857),
	(29858),
	(29859),
	(29860),
	(29861),
	(29862),
	(29863),
	(29864),
	(29865),
	(29866),
	(29867),
	(29868),
	(29869),
	(29870),
	(29871),
	(29872),
	(29873),
	(29874),
	(29875),
	(29876),
	(29877),
	(29878),
	(29879),
	(29880),
	(29881),
	(29882),
	(29883),
	(29884),
	(29885),
	(29886),
	(29887),
	(29888),
	(29889),
	(29890),
	(29891),
	(29892),
	(29893),
	(29894),
	(29895),
	(29896),
	(29897),
	(29898),
	(29899),
	(29900),
	(29901),
	(29902),
	(29903),
	(29904),
	(29905),
	(29906),
	(29907),
	(29908),
	(29909),
	(29910),
	(29911),
	(29912),
	(29913),
	(29914),
	(29915),
	(29916),
	(29917),
	(29918),
	(29919),
	(29920),
	(29921),
	(29922),
	(29923),
	(29924),
	(29925),
	(29926),
	(29927),
	(29928),
	(29929),
	(29930),
	(29931),
	(29932),
	(29933),
	(29934),
	(29935),
	(29936),
	(29937),
	(29938),
	(29939),
	(29940),
	(29941),
	(29942),
	(29943),
	(29944),
	(29945),
	(29946),
	(29947),
	(29948),
	(29949),
	(29950),
	(29951),
	(29952),
	(29953),
	(29954),
	(29955),
	(29956),
	(29957),
	(29958),
	(29959),
	(29960),
	(29961),
	(29962),
	(29963),
	(29964),
	(29965),
	(29966),
	(29967),
	(29968),
	(29969),
	(29970),
	(29971),
	(29972),
	(29973),
	(29974),
	(29975),
	(29976),
	(29977),
	(29978),
	(29979),
	(29980),
	(29981),
	(29982),
	(29983),
	(29984),
	(29985),
	(29986),
	(29987),
	(29988),
	(29989),
	(29990),
	(29991),
	(29992),
	(29993),
	(29994),
	(29995),
	(29996),
	(29997),
	(29998),
	(29999),
	(30000),
	(30001),
	(30002),
	(30003),
	(30004),
	(30005),
	(30006),
	(30007),
	(30008),
	(30009),
	(30010),
	(30011),
	(30012),
	(30013),
	(30014),
	(30015),
	(30016),
	(30017),
	(30018),
	(30019),
	(30020),
	(30021),
	(30022),
	(30023),
	(30024),
	(30025),
	(30026),
	(30027),
	(30028),
	(30029),
	(30030),
	(30031),
	(30032),
	(30033),
	(30034),
	(30035),
	(30036),
	(30037),
	(30038),
	(30039),
	(30040),
	(30041),
	(30042),
	(30043),
	(30044),
	(30045),
	(30046),
	(30047),
	(30048),
	(30049),
	(30050),
	(30051),
	(30052),
	(30053),
	(30054),
	(30055),
	(30056),
	(30057),
	(30058),
	(30059),
	(30060),
	(30061),
	(30062),
	(30063),
	(30064),
	(30065),
	(30066),
	(30067),
	(30068),
	(30069),
	(30070),
	(30071),
	(30072),
	(30073),
	(30074),
	(30075),
	(30076),
	(30077),
	(30078),
	(30079),
	(30080),
	(30081),
	(30082),
	(30083),
	(30084),
	(30085),
	(30086),
	(30087),
	(30088),
	(30089),
	(30090),
	(30091),
	(30092),
	(30093),
	(30094),
	(30095),
	(30096),
	(30097),
	(30098),
	(30099),
	(30100),
	(30101),
	(30102),
	(30103),
	(30104),
	(30105),
	(30106),
	(30107),
	(30108),
	(30109),
	(30110),
	(30111),
	(30112),
	(30113),
	(30114),
	(30115),
	(30116),
	(30117),
	(30118),
	(30119),
	(30120),
	(30121),
	(30122),
	(30123),
	(30124),
	(30125),
	(30126),
	(30127),
	(30128),
	(30129),
	(30130),
	(30131),
	(30132),
	(30133),
	(30134),
	(30135),
	(30136),
	(30137),
	(30138),
	(30139),
	(30140),
	(30141),
	(30142),
	(30143),
	(30144),
	(30145),
	(30146),
	(30147),
	(30148),
	(30149),
	(30150),
	(30151),
	(30152),
	(30153),
	(30154),
	(30155),
	(30156),
	(30157),
	(30158),
	(30159),
	(30160),
	(30161),
	(30162),
	(30163),
	(30164),
	(30165),
	(30166),
	(30167),
	(30168),
	(30169),
	(30170),
	(30171),
	(30172),
	(30173),
	(30174),
	(30175),
	(30176),
	(30177),
	(30178),
	(30179),
	(30180),
	(30181),
	(30182),
	(30183),
	(30184),
	(30185),
	(30186),
	(30187),
	(30188),
	(30189),
	(30190),
	(30191),
	(30192),
	(30193),
	(30194),
	(30195),
	(30196),
	(30197),
	(30198),
	(30199),
	(30200),
	(30201),
	(30202),
	(30203),
	(30204),
	(30205),
	(30206),
	(30207),
	(30208),
	(30209),
	(30210),
	(30211),
	(30212),
	(30213),
	(30214),
	(30215),
	(30216),
	(30217),
	(30218),
	(30219),
	(30220),
	(30221),
	(30222),
	(30223),
	(30224),
	(30225),
	(30226),
	(30227),
	(30228),
	(30229),
	(30230),
	(30231),
	(30232),
	(30233),
	(30234),
	(30235),
	(30236),
	(30237),
	(30238),
	(30239),
	(30240),
	(30241),
	(30242),
	(30243),
	(30244),
	(30245),
	(30246),
	(30247),
	(30248),
	(30249),
	(30250),
	(30251),
	(30252),
	(30253),
	(30254),
	(30255),
	(30256),
	(30257),
	(30258),
	(30259),
	(30260),
	(30261),
	(30262),
	(30263),
	(30264),
	(30265),
	(30266),
	(30267),
	(30268),
	(30269),
	(30270),
	(30271),
	(30272),
	(30273),
	(30274),
	(30275),
	(30276),
	(30277),
	(30278),
	(30279),
	(30280),
	(30281),
	(30282),
	(30283),
	(30284),
	(30285),
	(30286),
	(30287),
	(30288),
	(30289),
	(30290),
	(30291),
	(30292),
	(30293),
	(30294),
	(30295),
	(30296),
	(30297),
	(30298),
	(30299),
	(30300),
	(30301),
	(30302),
	(30303),
	(30304),
	(30305),
	(30306),
	(30307),
	(30308),
	(30309),
	(30310),
	(30311),
	(30312),
	(30313),
	(30314),
	(30315),
	(30316),
	(30317),
	(30318),
	(30319),
	(30320),
	(30321),
	(30322),
	(30323),
	(30324),
	(30325),
	(30326),
	(30327),
	(30328),
	(30329),
	(30330),
	(30331),
	(30332),
	(30333),
	(30334),
	(30335),
	(30336),
	(30337),
	(30338),
	(30339),
	(30340),
	(30341),
	(30342),
	(30343),
	(30344),
	(30345),
	(30346),
	(30347),
	(30348),
	(30349),
	(30350),
	(30351),
	(30352),
	(30353),
	(30354),
	(30355),
	(30356),
	(30357),
	(30358),
	(30359),
	(30360),
	(30361),
	(30362),
	(30363),
	(30364),
	(30365),
	(30366),
	(30367),
	(30368),
	(30369),
	(30370),
	(30371),
	(30372),
	(30373),
	(30374),
	(30375),
	(30376),
	(30377),
	(30378),
	(30379),
	(30380),
	(30381),
	(30382),
	(30383),
	(30384),
	(30385),
	(30386),
	(30387),
	(30388),
	(30389),
	(30390),
	(30391),
	(30392),
	(30393),
	(30394),
	(30395),
	(30396),
	(30397),
	(30398),
	(30399),
	(30400),
	(30401),
	(30402),
	(30403),
	(30404),
	(30405),
	(30406),
	(30407),
	(30408),
	(30409),
	(30410),
	(30411),
	(30412),
	(30413),
	(30414),
	(30415),
	(30416),
	(30417),
	(30418),
	(30419),
	(30420),
	(30421),
	(30422),
	(30423),
	(30424),
	(30425),
	(30426),
	(30427),
	(30428),
	(30429),
	(30430),
	(30431),
	(30432),
	(30433),
	(30434),
	(30435),
	(30436),
	(30437),
	(30438),
	(30439),
	(30440),
	(30441),
	(30442),
	(30443),
	(30444),
	(30445),
	(30446),
	(30447),
	(30448),
	(30449),
	(30450),
	(30451),
	(30452),
	(30453),
	(30454),
	(30455),
	(30456),
	(30457),
	(30458),
	(30459),
	(30460),
	(30461),
	(30462),
	(30463),
	(30464),
	(30465),
	(30466),
	(30467),
	(30468),
	(30469),
	(30470),
	(30471),
	(30472),
	(30473),
	(30474),
	(30475),
	(30476),
	(30477),
	(30478),
	(30479),
	(30480),
	(30481),
	(30482),
	(30483),
	(30484),
	(30485),
	(30486),
	(30487),
	(30488),
	(30489),
	(30490),
	(30491),
	(30492),
	(30493),
	(30494),
	(30495),
	(30496),
	(30497),
	(30498),
	(30499),
	(30500),
	(30501),
	(30502),
	(30503),
	(30504),
	(30505),
	(30506),
	(30507),
	(30508),
	(30509),
	(30510),
	(30511),
	(30512),
	(30513),
	(30514),
	(30515),
	(30516),
	(30517),
	(30518),
	(30519),
	(30520),
	(30521),
	(30522),
	(30523),
	(30524),
	(30525),
	(30526),
	(30527),
	(30528),
	(30529),
	(30530),
	(30531),
	(30532),
	(30533),
	(30534),
	(30535),
	(30536),
	(30537),
	(30538),
	(30539),
	(30540),
	(30541),
	(30542),
	(30543),
	(30544),
	(30545),
	(30546),
	(30547),
	(30548),
	(30549),
	(30550),
	(30551),
	(30552),
	(30553),
	(30554),
	(30555),
	(30556),
	(30557),
	(30558),
	(30559),
	(30560),
	(30561),
	(30562),
	(30563),
	(30564),
	(30565),
	(30566),
	(30567),
	(30568),
	(30569),
	(30570),
	(30571),
	(30572),
	(30573),
	(30574),
	(30575),
	(30576),
	(30577),
	(30578),
	(30579),
	(30580),
	(30581),
	(30582),
	(30583),
	(30584),
	(30585),
	(30586),
	(30587),
	(30588),
	(30589),
	(30590),
	(30591),
	(30592),
	(30593),
	(30594),
	(30595),
	(30596),
	(30597),
	(30598),
	(30599),
	(30600),
	(30601),
	(30602),
	(30603),
	(30604),
	(30605),
	(30606),
	(30607),
	(30608),
	(30609),
	(30610),
	(30611),
	(30612),
	(30613),
	(30614),
	(30615),
	(30616),
	(30617),
	(30618),
	(30619),
	(30620),
	(30621),
	(30622),
	(30623),
	(30624),
	(30625),
	(30626),
	(30627),
	(30628),
	(30629),
	(30630),
	(30631),
	(30632),
	(30633),
	(30634),
	(30635),
	(30636),
	(30637),
	(30638),
	(30639),
	(30640),
	(30641),
	(30642),
	(30643),
	(30644),
	(30645),
	(30646),
	(30647),
	(30648),
	(30649),
	(30650),
	(30651),
	(30652),
	(30653),
	(30654),
	(30655),
	(30656),
	(30657),
	(30658),
	(30659),
	(30660),
	(30661),
	(30662),
	(30663),
	(30664),
	(30665),
	(30666),
	(30667),
	(30668),
	(30669),
	(30670),
	(30671),
	(30672),
	(30673),
	(30674),
	(30675),
	(30676),
	(30677),
	(30678),
	(30679),
	(30680),
	(30681),
	(30682),
	(30683),
	(30684),
	(30685),
	(30686),
	(30687),
	(30688),
	(30689),
	(30690),
	(30691),
	(30692),
	(30693),
	(30694),
	(30695),
	(30696),
	(30697),
	(30698),
	(30699),
	(30700),
	(30701),
	(30702),
	(30703),
	(30704),
	(30705),
	(30706),
	(30707),
	(30708),
	(30709),
	(30710),
	(30711),
	(30712),
	(30713),
	(30714),
	(30715),
	(30716),
	(30717),
	(30718),
	(30719),
	(30720),
	(30721),
	(30722),
	(30723),
	(30724),
	(30725),
	(30726),
	(30727),
	(30728),
	(30729),
	(30730),
	(30731),
	(30732),
	(30733),
	(30734),
	(30735),
	(30736),
	(30737),
	(30738),
	(30739),
	(30740),
	(30741),
	(30742),
	(30743),
	(30744),
	(30745),
	(30746),
	(30747),
	(30748),
	(30749),
	(30750),
	(30751),
	(30752),
	(30753),
	(30754),
	(30755),
	(30756),
	(30757),
	(30758),
	(30759),
	(30760),
	(30761),
	(30762),
	(30763),
	(30764),
	(30765),
	(30766),
	(30767),
	(30768),
	(30769),
	(30770),
	(30771),
	(30772),
	(30773),
	(30774),
	(30775),
	(30776),
	(30777),
	(30778),
	(30779),
	(30780),
	(30781),
	(30782),
	(30783),
	(30784),
	(30785),
	(30786),
	(30787),
	(30788),
	(30789),
	(30790),
	(30791),
	(30792),
	(30793),
	(30794),
	(30795),
	(30796),
	(30797),
	(30798),
	(30799),
	(30800),
	(30801),
	(30802),
	(30803),
	(30804),
	(30805),
	(30806),
	(30807),
	(30808),
	(30809),
	(30810),
	(30811),
	(30812),
	(30813),
	(30814),
	(30815),
	(30816),
	(30817),
	(30818),
	(30819),
	(30820),
	(30821),
	(30822),
	(30823),
	(30824),
	(30825),
	(30826),
	(30827),
	(30828),
	(30829),
	(30830),
	(30831),
	(30832),
	(30833),
	(30834),
	(30835),
	(30836),
	(30837),
	(30838),
	(30839),
	(30840),
	(30841),
	(30842),
	(30843),
	(30844),
	(30845),
	(30846),
	(30847),
	(30848),
	(30849),
	(30850),
	(30851),
	(30852),
	(30853),
	(30854),
	(30855),
	(30856),
	(30857),
	(30858),
	(30859),
	(30860),
	(30861),
	(30862),
	(30863),
	(30864),
	(30865),
	(30866),
	(30867),
	(30868),
	(30869),
	(30870),
	(30871),
	(30872),
	(30873),
	(30874),
	(30875),
	(30876),
	(30877),
	(30878),
	(30879),
	(30880),
	(30881),
	(30882),
	(30883),
	(30884),
	(30885),
	(30886),
	(30887),
	(30888),
	(30889),
	(30890),
	(30891),
	(30892),
	(30893),
	(30894),
	(30895),
	(30896),
	(30897),
	(30898),
	(30899),
	(30900),
	(30901),
	(30902),
	(30903),
	(30904),
	(30905),
	(30906),
	(30907),
	(30908),
	(30909),
	(30910),
	(30911),
	(30912),
	(30913),
	(30914),
	(30915),
	(30916),
	(30917),
	(30918),
	(30919),
	(30920),
	(30921),
	(30922),
	(30923),
	(30924),
	(30925),
	(30926),
	(30927),
	(30928),
	(30929),
	(30930),
	(30931),
	(30932),
	(30933),
	(30934),
	(30935),
	(30936),
	(30937),
	(30938),
	(30939),
	(30940),
	(30941),
	(30942),
	(30943),
	(30944),
	(30945),
	(30946),
	(30947),
	(30948),
	(30949),
	(30950),
	(30951),
	(30952),
	(30953),
	(30954),
	(30955),
	(30956),
	(30957),
	(30958),
	(30959),
	(30960),
	(30961),
	(30962),
	(30963),
	(30964),
	(30965),
	(30966),
	(30967),
	(30968),
	(30969),
	(30970),
	(30971),
	(30972),
	(30973),
	(30974),
	(30975),
	(30976),
	(30977),
	(30978),
	(30979),
	(30980),
	(30981),
	(30982),
	(30983),
	(30984),
	(30985),
	(30986),
	(30987),
	(30988),
	(30989),
	(30990),
	(30991),
	(30992),
	(30993),
	(30994),
	(30995),
	(30996),
	(30997),
	(30998),
	(30999),
	(31000),
	(31001),
	(31002),
	(31003),
	(31004),
	(31005),
	(31006),
	(31007),
	(31008),
	(31009),
	(31010),
	(31011),
	(31012),
	(31013),
	(31014),
	(31015),
	(31016),
	(31017),
	(31018),
	(31019),
	(31020),
	(31021),
	(31022),
	(31023),
	(31024),
	(31025),
	(31026),
	(31027),
	(31028),
	(31029),
	(31030),
	(31031),
	(31032),
	(31033),
	(31034),
	(31035),
	(31036),
	(31037),
	(31038),
	(31039),
	(31040),
	(31041),
	(31042),
	(31043),
	(31044),
	(31045),
	(31046),
	(31047),
	(31048),
	(31049),
	(31050),
	(31051),
	(31052),
	(31053),
	(31054),
	(31055),
	(31056),
	(31057),
	(31058),
	(31059),
	(31060),
	(31061),
	(31062),
	(31063),
	(31064),
	(31065),
	(31066),
	(31067),
	(31068),
	(31069),
	(31070),
	(31071),
	(31072),
	(31073),
	(31074),
	(31075),
	(31076),
	(31077),
	(31078),
	(31079),
	(31080),
	(31081),
	(31082),
	(31083),
	(31084),
	(31085),
	(31086),
	(31087),
	(31088),
	(31089),
	(31090),
	(31091),
	(31092),
	(31093),
	(31094),
	(31095),
	(31096),
	(31097),
	(31098),
	(31099),
	(31100),
	(31101),
	(31102),
	(31103),
	(31104),
	(31105),
	(31106),
	(31107),
	(31108),
	(31109),
	(31110),
	(31111),
	(31112),
	(31113),
	(31114),
	(31115),
	(31116),
	(31117),
	(31118),
	(31119),
	(31120),
	(31121),
	(31122),
	(31123),
	(31124),
	(31125),
	(31126),
	(31127),
	(31128),
	(31129),
	(31130),
	(31131),
	(31132),
	(31133),
	(31134),
	(31135),
	(31136),
	(31137),
	(31138),
	(31139),
	(31140),
	(31141),
	(31142),
	(31143),
	(31144),
	(31145),
	(31146),
	(31147),
	(31148),
	(31149),
	(31150),
	(31151),
	(31152),
	(31153),
	(31154),
	(31155),
	(31156),
	(31157),
	(31158),
	(31159),
	(31160),
	(31161),
	(31162),
	(31163),
	(31164),
	(31165),
	(31166),
	(31167),
	(31168),
	(31169),
	(31170),
	(31171),
	(31172),
	(31173),
	(31174),
	(31175),
	(31176),
	(31177),
	(31178),
	(31179),
	(31180),
	(31181),
	(31182),
	(31183),
	(31184),
	(31185),
	(31186),
	(31187),
	(31188),
	(31189),
	(31190),
	(31191),
	(31192),
	(31193),
	(31194),
	(31195),
	(31196),
	(31197),
	(31198),
	(31199),
	(31200),
	(31201),
	(31202),
	(31203),
	(31204),
	(31205),
	(31206),
	(31207),
	(31208),
	(31209),
	(31210),
	(31211),
	(31212),
	(31213),
	(31214),
	(31215),
	(31216),
	(31217),
	(31218),
	(31219),
	(31220),
	(31221),
	(31222),
	(31223),
	(31224),
	(31225),
	(31226),
	(31227),
	(31228),
	(31229),
	(31230),
	(31231),
	(31232),
	(31233),
	(31234),
	(31235),
	(31236),
	(31237),
	(31238),
	(31239),
	(31240),
	(31241),
	(31242),
	(31243),
	(31244),
	(31245),
	(31246),
	(31247),
	(31248),
	(31249),
	(31250),
	(31251),
	(31252),
	(31253),
	(31254),
	(31255),
	(31256),
	(31257),
	(31258),
	(31259),
	(31260),
	(31261),
	(31262),
	(31263),
	(31264),
	(31265),
	(31266),
	(31267),
	(31268),
	(31269),
	(31270),
	(31271),
	(31272),
	(31273),
	(31274),
	(31275),
	(31276),
	(31277),
	(31278),
	(31279),
	(31280),
	(31281),
	(31282),
	(31283),
	(31284),
	(31285),
	(31286),
	(31287),
	(31288),
	(31289),
	(31290),
	(31291),
	(31292),
	(31293),
	(31294),
	(31295),
	(31296),
	(31297),
	(31298),
	(31299),
	(31300),
	(31301),
	(31302),
	(31303),
	(31304),
	(31305),
	(31306),
	(31307),
	(31308),
	(31309),
	(31310),
	(31311),
	(31312),
	(31313),
	(31314),
	(31315),
	(31316),
	(31317),
	(31318),
	(31319),
	(31320),
	(31321),
	(31322),
	(31323),
	(31324),
	(31325),
	(31326),
	(31327),
	(31328),
	(31329),
	(31330),
	(31331),
	(31332),
	(31333),
	(31334),
	(31335),
	(31336),
	(31337),
	(31338),
	(31339),
	(31340),
	(31341),
	(31342),
	(31343),
	(31344),
	(31345),
	(31346),
	(31347),
	(31348),
	(31349),
	(31350),
	(31351),
	(31352),
	(31353),
	(31354),
	(31355),
	(31356),
	(31357),
	(31358),
	(31359),
	(31360),
	(31361),
	(31362),
	(31363),
	(31364),
	(31365),
	(31366),
	(31367),
	(31368),
	(31369),
	(31370),
	(31371),
	(31372),
	(31373),
	(31374),
	(31375),
	(31376),
	(31377),
	(31378),
	(31379),
	(31380),
	(31381),
	(31382),
	(31383),
	(31384),
	(31385),
	(31386),
	(31387),
	(31388),
	(31389),
	(31390),
	(31391),
	(31392),
	(31393),
	(31394),
	(31395),
	(31396),
	(31397),
	(31398),
	(31399),
	(31400),
	(31401),
	(31402),
	(31403),
	(31404),
	(31405),
	(31406),
	(31407),
	(31408),
	(31409),
	(31410),
	(31411),
	(31412),
	(31413),
	(31414),
	(31415),
	(31416),
	(31417),
	(31418),
	(31419),
	(31420),
	(31421),
	(31422),
	(31423),
	(31424),
	(31425),
	(31426),
	(31427),
	(31428),
	(31429),
	(31430),
	(31431),
	(31432),
	(31433),
	(31434),
	(31435),
	(31436),
	(31437),
	(31438),
	(31439),
	(31440),
	(31441),
	(31442),
	(31443),
	(31444),
	(31445),
	(31446),
	(31447),
	(31448),
	(31449),
	(31450),
	(31451),
	(31452),
	(31453),
	(31454),
	(31455),
	(31456),
	(31457),
	(31458),
	(31459),
	(31460),
	(31461),
	(31462),
	(31463),
	(31464),
	(31465),
	(31466),
	(31467),
	(31468),
	(31469),
	(31470),
	(31471),
	(31472),
	(31473),
	(31474),
	(31475),
	(31476),
	(31477),
	(31478),
	(31479),
	(31480),
	(31481),
	(31482),
	(31483),
	(31484),
	(31485),
	(31486),
	(31487),
	(31488),
	(31489),
	(31490),
	(31491),
	(31492),
	(31493),
	(31494),
	(31495),
	(31496),
	(31497),
	(31498),
	(31499),
	(31500),
	(31501),
	(31502),
	(31503),
	(31504),
	(31505),
	(31506),
	(31507),
	(31508),
	(31509),
	(31510),
	(31511),
	(31512),
	(31513),
	(31514),
	(31515),
	(31516),
	(31517),
	(31518),
	(31519),
	(31520),
	(31521),
	(31522),
	(31523),
	(31524),
	(31525),
	(31526),
	(31527),
	(31528),
	(31529),
	(31530),
	(31531),
	(31532),
	(31533),
	(31534),
	(31535),
	(31536),
	(31537),
	(31538),
	(31539),
	(31540),
	(31541),
	(31542),
	(31543),
	(31544),
	(31545),
	(31546),
	(31547),
	(31548),
	(31549),
	(31550),
	(31551),
	(31552),
	(31553),
	(31554),
	(31555),
	(31556),
	(31557),
	(31558),
	(31559),
	(31560),
	(31561),
	(31562),
	(31563),
	(31564),
	(31565),
	(31566),
	(31567),
	(31568),
	(31569),
	(31570),
	(31571),
	(31572),
	(31573),
	(31574),
	(31575),
	(31576),
	(31577),
	(31578),
	(31579),
	(31580),
	(31581),
	(31582),
	(31583),
	(31584),
	(31585),
	(31586),
	(31587),
	(31588),
	(31589),
	(31590),
	(31591),
	(31592),
	(31593),
	(31594),
	(31595),
	(31596),
	(31597),
	(31598),
	(31599),
	(31600),
	(31601),
	(31602),
	(31603),
	(31604),
	(31605),
	(31606),
	(31607),
	(31608),
	(31609),
	(31610),
	(31611),
	(31612),
	(31613),
	(31614),
	(31615),
	(31616),
	(31617),
	(31618),
	(31619),
	(31620),
	(31621),
	(31622),
	(31623),
	(31624),
	(31625),
	(31626),
	(31627),
	(31628),
	(31629),
	(31630),
	(31631),
	(31632),
	(31633),
	(31634),
	(31635),
	(31636),
	(31637),
	(31638),
	(31639),
	(31640),
	(31641),
	(31642),
	(31643),
	(31644),
	(31645),
	(31646),
	(31647),
	(31648),
	(31649),
	(31650),
	(31651),
	(31652),
	(31653),
	(31654),
	(31655),
	(31656),
	(31657),
	(31658),
	(31659),
	(31660),
	(31661),
	(31662),
	(31663),
	(31664),
	(31665),
	(31666),
	(31667),
	(31668),
	(31669),
	(31670),
	(31671),
	(31672),
	(31673),
	(31674),
	(31675),
	(31676),
	(31677),
	(31678),
	(31679),
	(31680),
	(31681),
	(31682),
	(31683),
	(31684),
	(31685),
	(31686),
	(31687),
	(31688),
	(31689),
	(31690),
	(31691),
	(31692),
	(31693),
	(31694),
	(31695),
	(31696),
	(31697),
	(31698),
	(31699),
	(31700),
	(31701),
	(31702),
	(31703),
	(31704),
	(31705),
	(31706),
	(31707),
	(31708),
	(31709),
	(31710),
	(31711),
	(31712),
	(31713),
	(31714),
	(31715),
	(31716),
	(31717),
	(31718),
	(31719),
	(31720),
	(31721),
	(31722),
	(31723),
	(31724),
	(31725),
	(31726),
	(31727),
	(31728),
	(31729),
	(31730),
	(31731),
	(31732),
	(31733),
	(31734),
	(31735),
	(31736),
	(31737),
	(31738),
	(31739),
	(31740),
	(31741),
	(31742),
	(31743),
	(31744),
	(31745),
	(31746),
	(31747),
	(31748),
	(31749),
	(31750),
	(31751),
	(31752),
	(31753),
	(31754),
	(31755),
	(31756),
	(31757),
	(31758),
	(31759),
	(31760),
	(31761),
	(31762),
	(31763),
	(31764),
	(31765),
	(31766),
	(31767),
	(31768),
	(31769),
	(31770),
	(31771),
	(31772),
	(31773),
	(31774),
	(31775),
	(31776),
	(31777),
	(31778),
	(31779),
	(31780),
	(31781),
	(31782),
	(31783),
	(31784),
	(31785),
	(31786),
	(31787),
	(31788),
	(31789),
	(31790),
	(31791),
	(31792),
	(31793),
	(31794),
	(31795),
	(31796),
	(31797),
	(31798),
	(31799),
	(31800),
	(31801),
	(31802),
	(31803),
	(31804),
	(31805),
	(31806),
	(31807),
	(31808),
	(31809),
	(31810),
	(31811),
	(31812),
	(31813),
	(31814),
	(31815),
	(31816),
	(31817),
	(31818),
	(31819),
	(31820),
	(31821),
	(31822),
	(31823),
	(31824),
	(31825),
	(31826),
	(31827),
	(31828),
	(31829),
	(31830),
	(31831),
	(31832),
	(31833),
	(31834),
	(31835),
	(31836),
	(31837),
	(31838),
	(31839),
	(31840),
	(31841),
	(31842),
	(31843),
	(31844),
	(31845),
	(31846),
	(31847),
	(31848),
	(31849),
	(31850),
	(31851),
	(31852),
	(31853),
	(31854),
	(31855),
	(31856),
	(31857),
	(31858),
	(31859),
	(31860),
	(31861),
	(31862),
	(31863),
	(31864),
	(31865),
	(31866),
	(31867),
	(31868),
	(31869),
	(31870),
	(31871),
	(31872),
	(31873),
	(31874),
	(31875),
	(31876),
	(31877),
	(31878),
	(31879),
	(31880),
	(31881),
	(31882),
	(31883),
	(31884),
	(31885),
	(31886),
	(31887),
	(31888),
	(31889),
	(31890),
	(31891),
	(31892),
	(31893),
	(31894),
	(31895),
	(31896),
	(31897),
	(31898),
	(31899),
	(31900),
	(31901),
	(31902),
	(31903),
	(31904),
	(31905),
	(31906),
	(31907),
	(31908),
	(31909),
	(31910),
	(31911),
	(31912),
	(31913),
	(31914),
	(31915),
	(31916),
	(31917),
	(31918),
	(31919),
	(31920),
	(31921),
	(31922),
	(31923),
	(31924),
	(31925),
	(31926),
	(31927),
	(31928),
	(31929),
	(31930),
	(31931),
	(31932),
	(31933),
	(31934),
	(31935),
	(31936),
	(31937),
	(31938),
	(31939),
	(31940),
	(31941),
	(31942),
	(31943),
	(31944),
	(31945),
	(31946),
	(31947),
	(31948),
	(31949),
	(31950),
	(31951),
	(31952),
	(31953),
	(31954),
	(31955),
	(31956),
	(31957),
	(31958),
	(31959),
	(31960),
	(31961),
	(31962),
	(31963),
	(31964),
	(31965),
	(31966),
	(31967),
	(31968),
	(31969),
	(31970),
	(31971),
	(31972),
	(31973),
	(31974),
	(31975),
	(31976),
	(31977),
	(31978),
	(31979),
	(31980),
	(31981),
	(31982),
	(31983),
	(31984),
	(31985),
	(31986),
	(31987),
	(31988),
	(31989),
	(31990),
	(31991),
	(31992),
	(31993),
	(31994),
	(31995),
	(31996),
	(31997),
	(31998),
	(31999),
	(32000),
	(32001),
	(32002),
	(32003),
	(32004),
	(32005),
	(32006),
	(32007),
	(32008),
	(32009),
	(32010),
	(32011),
	(32012),
	(32013),
	(32014),
	(32015),
	(32016),
	(32017),
	(32018),
	(32019),
	(32020),
	(32021),
	(32022),
	(32023),
	(32024),
	(32025),
	(32026),
	(32027),
	(32028),
	(32029),
	(32030),
	(32031),
	(32032),
	(32033),
	(32034),
	(32035),
	(32036),
	(32037),
	(32038),
	(32039),
	(32040),
	(32041),
	(32042),
	(32043),
	(32044),
	(32045),
	(32046),
	(32047),
	(32048),
	(32049),
	(32050),
	(32051),
	(32052),
	(32053),
	(32054),
	(32055),
	(32056),
	(32057),
	(32058),
	(32059),
	(32060),
	(32061),
	(32062),
	(32063),
	(32064),
	(32065),
	(32066),
	(32067),
	(32068),
	(32069),
	(32070),
	(32071),
	(32072),
	(32073),
	(32074),
	(32075),
	(32076),
	(32077),
	(32078),
	(32079),
	(32080),
	(32081),
	(32082),
	(32083),
	(32084),
	(32085),
	(32086),
	(32087),
	(32088),
	(32089),
	(32090),
	(32091),
	(32092),
	(32093),
	(32094),
	(32095),
	(32096),
	(32097),
	(32098),
	(32099),
	(32100),
	(32101),
	(32102),
	(32103),
	(32104),
	(32105),
	(32106),
	(32107),
	(32108),
	(32109),
	(32110),
	(32111),
	(32112),
	(32113),
	(32114),
	(32115),
	(32116),
	(32117),
	(32118),
	(32119),
	(32120),
	(32121),
	(32122),
	(32123),
	(32124),
	(32125),
	(32126),
	(32127),
	(32128),
	(32129),
	(32130),
	(32131),
	(32132),
	(32133),
	(32134),
	(32135),
	(32136),
	(32137),
	(32138),
	(32139),
	(32140),
	(32141),
	(32142),
	(32143),
	(32144),
	(32145),
	(32146),
	(32147),
	(32148),
	(32149),
	(32150),
	(32151),
	(32152),
	(32153),
	(32154),
	(32155),
	(32156),
	(32157),
	(32158),
	(32159),
	(32160),
	(32161),
	(32162),
	(32163),
	(32164),
	(32165),
	(32166),
	(32167),
	(32168),
	(32169),
	(32170),
	(32171),
	(32172),
	(32173),
	(32174),
	(32175),
	(32176),
	(32177),
	(32178),
	(32179),
	(32180),
	(32181),
	(32182),
	(32183),
	(32184),
	(32185),
	(32186),
	(32187),
	(32188),
	(32189),
	(32190),
	(32191),
	(32192),
	(32193),
	(32194),
	(32195),
	(32196),
	(32197),
	(32198),
	(32199),
	(32200),
	(32201),
	(32202),
	(32203),
	(32204),
	(32205),
	(32206),
	(32207),
	(32208),
	(32209),
	(32210),
	(32211),
	(32212),
	(32213),
	(32214),
	(32215),
	(32216),
	(32217),
	(32218),
	(32219),
	(32220),
	(32221),
	(32222),
	(32223),
	(32224),
	(32225),
	(32226),
	(32227),
	(32228),
	(32229),
	(32230),
	(32231),
	(32232),
	(32233),
	(32234),
	(32235),
	(32236),
	(32237),
	(32238),
	(32239),
	(32240),
	(32241),
	(32242),
	(32243),
	(32244),
	(32245),
	(32246),
	(32247),
	(32248),
	(32249),
	(32250),
	(32251),
	(32252),
	(32253),
	(32254),
	(32255),
	(32256),
	(32257),
	(32258),
	(32259),
	(32260),
	(32261),
	(32262),
	(32263),
	(32264),
	(32265),
	(32266),
	(32267),
	(32268),
	(32269),
	(32270),
	(32271),
	(32272),
	(32273),
	(32274),
	(32275),
	(32276),
	(32277),
	(32278),
	(32279),
	(32280),
	(32281),
	(32282),
	(32283),
	(32284),
	(32285),
	(32286),
	(32287),
	(32288),
	(32289),
	(32290),
	(32291),
	(32292),
	(32293),
	(32294),
	(32295),
	(32296),
	(32297),
	(32298),
	(32299),
	(32300),
	(32301),
	(32302),
	(32303),
	(32304),
	(32305),
	(32306),
	(32307),
	(32308),
	(32309),
	(32310),
	(32311),
	(32312),
	(32313),
	(32314),
	(32315),
	(32316),
	(32317),
	(32318),
	(32319),
	(32320),
	(32321),
	(32322),
	(32323),
	(32324),
	(32325),
	(32326),
	(32327),
	(32328),
	(32329),
	(32330),
	(32331),
	(32332),
	(32333),
	(32334),
	(32335),
	(32336),
	(32337),
	(32338),
	(32339),
	(32340),
	(32341),
	(32342),
	(32343),
	(32344),
	(32345),
	(32346),
	(32347),
	(32348),
	(32349),
	(32350),
	(32351),
	(32352),
	(32353),
	(32354),
	(32355),
	(32356),
	(32357),
	(32358),
	(32359),
	(32360),
	(32361),
	(32362),
	(32363),
	(32364),
	(32365),
	(32366),
	(32367),
	(32368),
	(32369),
	(32370),
	(32371),
	(32372),
	(32373),
	(32374),
	(32375),
	(32376),
	(32377),
	(32378),
	(32379),
	(32380),
	(32381),
	(32382),
	(32383),
	(32384),
	(32385),
	(32386),
	(32387),
	(32388),
	(32389),
	(32390),
	(32391),
	(32392),
	(32393),
	(32394),
	(32395),
	(32396),
	(32397),
	(32398),
	(32399),
	(32400),
	(32401),
	(32402),
	(32403),
	(32404),
	(32405),
	(32406),
	(32407),
	(32408),
	(32409),
	(32410),
	(32411),
	(32412),
	(32413),
	(32414),
	(32415),
	(32416),
	(32417),
	(32418),
	(32419),
	(32420),
	(32421),
	(32422),
	(32423),
	(32424),
	(32425),
	(32426),
	(32427),
	(32428),
	(32429),
	(32430),
	(32431),
	(32432),
	(32433),
	(32434),
	(32435),
	(32436),
	(32437),
	(32438),
	(32439),
	(32440),
	(32441),
	(32442),
	(32443),
	(32444),
	(32445),
	(32446),
	(32447),
	(32448),
	(32449),
	(32450),
	(32451),
	(32452),
	(32453),
	(32454),
	(32455),
	(32456),
	(32457),
	(32458),
	(32459),
	(32460),
	(32461),
	(32462),
	(32463),
	(32464),
	(32465),
	(32466),
	(32467),
	(32468),
	(32469),
	(32470),
	(32471),
	(32472),
	(32473),
	(32474),
	(32475),
	(32476),
	(32477),
	(32478),
	(32479),
	(32480),
	(32481),
	(32482),
	(32483),
	(32484),
	(32485),
	(32486),
	(32487),
	(32488),
	(32489),
	(32490),
	(32491),
	(32492),
	(32493),
	(32494),
	(32495),
	(32496),
	(32497),
	(32498),
	(32499),
	(32500),
	(32501),
	(32502),
	(32503),
	(32504),
	(32505),
	(32506),
	(32507),
	(32508),
	(32509),
	(32510),
	(32511),
	(32512),
	(32513),
	(32514),
	(32515),
	(32516),
	(32517),
	(32518),
	(32519),
	(32520),
	(32521),
	(32522),
	(32523),
	(32524),
	(32525),
	(32526),
	(32527),
	(32528),
	(32529),
	(32530),
	(32531),
	(32532),
	(32533),
	(32534),
	(32535),
	(32536),
	(32537),
	(32538),
	(32539),
	(32540),
	(32541),
	(32542),
	(32543),
	(32544),
	(32545),
	(32546),
	(32547),
	(32548),
	(32549),
	(32550),
	(32551),
	(32552),
	(32553),
	(32554),
	(32555),
	(32556),
	(32557),
	(32558),
	(32559),
	(32560),
	(32561),
	(32562),
	(32563),
	(32564),
	(32565),
	(32566),
	(32567),
	(32568),
	(32569),
	(32570),
	(32571),
	(32572),
	(32573),
	(32574),
	(32575),
	(32576),
	(32577),
	(32578),
	(32579),
	(32580),
	(32581),
	(32582),
	(32583),
	(32584),
	(32585),
	(32586),
	(32587),
	(32588),
	(32589),
	(32590),
	(32591),
	(32592),
	(32593),
	(32594),
	(32595),
	(32596),
	(32597),
	(32598),
	(32599),
	(32600),
	(32601),
	(32602),
	(32603),
	(32604),
	(32605),
	(32606),
	(32607),
	(32608),
	(32609),
	(32610),
	(32611),
	(32612),
	(32613),
	(32614),
	(32615),
	(32616),
	(32617),
	(32618),
	(32619),
	(32620),
	(32621),
	(32622),
	(32623),
	(32624),
	(32625),
	(32626),
	(32627),
	(32628),
	(32629),
	(32630),
	(32631),
	(32632),
	(32633),
	(32634),
	(32635),
	(32636),
	(32637),
	(32638),
	(32639),
	(32640),
	(32641),
	(32642),
	(32643),
	(32644),
	(32645),
	(32646),
	(32647),
	(32648),
	(32649),
	(32650),
	(32651),
	(32652),
	(32653),
	(32654),
	(32655),
	(32656),
	(32657),
	(32658),
	(32659),
	(32660),
	(32661),
	(32662),
	(32663),
	(32664),
	(32665),
	(32666),
	(32667),
	(32668),
	(32669),
	(32670),
	(32671),
	(32672),
	(32673),
	(32674),
	(32675),
	(32676),
	(32677),
	(32678),
	(32679),
	(32680),
	(32681),
	(32682),
	(32683),
	(32684),
	(32685),
	(32686),
	(32687),
	(32688),
	(32689),
	(32690),
	(32691),
	(32692),
	(32693),
	(32694),
	(32695),
	(32696),
	(32697),
	(32698),
	(32699),
	(32700),
	(32701),
	(32702),
	(32703),
	(32704),
	(32705),
	(32706),
	(32707),
	(32708),
	(32709),
	(32710),
	(32711),
	(32712),
	(32713),
	(32714),
	(32715),
	(32716),
	(32717),
	(32718),
	(32719),
	(32720),
	(32721),
	(32722),
	(32723),
	(32724),
	(32725),
	(32726),
	(32727),
	(32728),
	(32729),
	(32730),
	(32731),
	(32732),
	(32733),
	(32734),
	(32735),
	(32736),
	(32737),
	(32738),
	(32739),
	(32740),
	(32741),
	(32742),
	(32743),
	(32744),
	(32745),
	(32746),
	(32747),
	(32748),
	(32749),
	(32750),
	(32751),
	(32752),
	(32753),
	(32754),
	(32755),
	(32756),
	(32757),
	(32758),
	(32759),
	(32760),
	(32761),
	(32762),
	(32763),
	(32764),
	(32765),
	(32766),
	(32767),
	(32768),
	(32769),
	(32770),
	(32771),
	(32772),
	(32773),
	(32774),
	(32775),
	(32776),
	(32777),
	(32778),
	(32779),
	(32780),
	(32781),
	(32782),
	(32783),
	(32784),
	(32785),
	(32786),
	(32787),
	(32788),
	(32789),
	(32790),
	(32791),
	(32792),
	(32793),
	(32794),
	(32795),
	(32796),
	(32797),
	(32798),
	(32799),
	(32800),
	(32801),
	(32802),
	(32803),
	(32804),
	(32805),
	(32806),
	(32807),
	(32808),
	(32809),
	(32810),
	(32811),
	(32812),
	(32813),
	(32814),
	(32815),
	(32816),
	(32817),
	(32818),
	(32819),
	(32820),
	(32821),
	(32822),
	(32823),
	(32824),
	(32825),
	(32826),
	(32827),
	(32828),
	(32829),
	(32830),
	(32831),
	(32832),
	(32833),
	(32834),
	(32835),
	(32836),
	(32837),
	(32838),
	(32839),
	(32840),
	(32841),
	(32842),
	(32843),
	(32844),
	(32845),
	(32846),
	(32847),
	(32848),
	(32849),
	(32850),
	(32851),
	(32852),
	(32853),
	(32854),
	(32855),
	(32856),
	(32857),
	(32858),
	(32859),
	(32860),
	(32861),
	(32862),
	(32863),
	(32864),
	(32865),
	(32866),
	(32867),
	(32868),
	(32869),
	(32870),
	(32871),
	(32872),
	(32873),
	(32874),
	(32875),
	(32876),
	(32877),
	(32878),
	(32879),
	(32880),
	(32881),
	(32882),
	(32883),
	(32884),
	(32885),
	(32886),
	(32887),
	(32888),
	(32889),
	(32890),
	(32891),
	(32892),
	(32893),
	(32894),
	(32895),
	(32896),
	(32897),
	(32898),
	(32899),
	(32900),
	(32901),
	(32902),
	(32903),
	(32904),
	(32905),
	(32906),
	(32907),
	(32908),
	(32909),
	(32910),
	(32911),
	(32912),
	(32913),
	(32914),
	(32915),
	(32916),
	(32917),
	(32918),
	(32919),
	(32920),
	(32921),
	(32922),
	(32923),
	(32924),
	(32925),
	(32926),
	(32927),
	(32928),
	(32929),
	(32930),
	(32931),
	(32932),
	(32933),
	(32934),
	(32935),
	(32936),
	(32937),
	(32938),
	(32939),
	(32940),
	(32941),
	(32942),
	(32943),
	(32944),
	(32945),
	(32946),
	(32947),
	(32948),
	(32949),
	(32950),
	(32951),
	(32952),
	(32953),
	(32954),
	(32955),
	(32956),
	(32957),
	(32958),
	(32959),
	(32960),
	(32961),
	(32962),
	(32963),
	(32964),
	(32965),
	(32966),
	(32967),
	(32968),
	(32969),
	(32970),
	(32971),
	(32972),
	(32973),
	(32974),
	(32975),
	(32976),
	(32977),
	(32978),
	(32979),
	(32980),
	(32981),
	(32982),
	(32983),
	(32984),
	(32985),
	(32986),
	(32987),
	(32988),
	(32989),
	(32990),
	(32991),
	(32992),
	(32993),
	(32994),
	(32995),
	(32996),
	(32997),
	(32998),
	(32999),
	(33000),
	(33001),
	(33002),
	(33003),
	(33004),
	(33005),
	(33006),
	(33007),
	(33008),
	(33009),
	(33010),
	(33011),
	(33012),
	(33013),
	(33014),
	(33015),
	(33016),
	(33017),
	(33018),
	(33019),
	(33020),
	(33021),
	(33022),
	(33023),
	(33024),
	(33025),
	(33026),
	(33027),
	(33028),
	(33029),
	(33030),
	(33031),
	(33032),
	(33033),
	(33034),
	(33035),
	(33036),
	(33037),
	(33038),
	(33039),
	(33040),
	(33041),
	(33042),
	(33043),
	(33044),
	(33045),
	(33046),
	(33047),
	(33048),
	(33049),
	(33050),
	(33051),
	(33052),
	(33053),
	(33054),
	(33055),
	(33056),
	(33057),
	(33058),
	(33059),
	(33060),
	(33061),
	(33062),
	(33063),
	(33064),
	(33065),
	(33066),
	(33067),
	(33068),
	(33069),
	(33070),
	(33071),
	(33072),
	(33073),
	(33074),
	(33075),
	(33076),
	(33077),
	(33078),
	(33079),
	(33080),
	(33081),
	(33082),
	(33083),
	(33084),
	(33085),
	(33086),
	(33087),
	(33088),
	(33089),
	(33090),
	(33091),
	(33092),
	(33093),
	(33094),
	(33095),
	(33096),
	(33097),
	(33098),
	(33099),
	(33100),
	(33101),
	(33102),
	(33103),
	(33104),
	(33105),
	(33106),
	(33107),
	(33108),
	(33109),
	(33110),
	(33111),
	(33112),
	(33113),
	(33114),
	(33115),
	(33116),
	(33117),
	(33118),
	(33119),
	(33120),
	(33121),
	(33122),
	(33123),
	(33124),
	(33125),
	(33126),
	(33127),
	(33128),
	(33129),
	(33130),
	(33131),
	(33132),
	(33133),
	(33134),
	(33135),
	(33136),
	(33137),
	(33138),
	(33139),
	(33140),
	(33141),
	(33142),
	(33143),
	(33144),
	(33145),
	(33146),
	(33147),
	(33148),
	(33149),
	(33150),
	(33151),
	(33152),
	(33153),
	(33154),
	(33155),
	(33156),
	(33157),
	(33158),
	(33159),
	(33160),
	(33161),
	(33162),
	(33163),
	(33164),
	(33165),
	(33166),
	(33167),
	(33168),
	(33169),
	(33170),
	(33171),
	(33172),
	(33173),
	(33174),
	(33175),
	(33176),
	(33177),
	(33178),
	(33179),
	(33180),
	(33181),
	(33182),
	(33183),
	(33184),
	(33185),
	(33186),
	(33187),
	(33188),
	(33189),
	(33190),
	(33191),
	(33192),
	(33193),
	(33194),
	(33195),
	(33196),
	(33197),
	(33198),
	(33199),
	(33200),
	(33201),
	(33202),
	(33203),
	(33204),
	(33205),
	(33206),
	(33207),
	(33208),
	(33209),
	(33210),
	(33211),
	(33212),
	(33213),
	(33214),
	(33215),
	(33216),
	(33217),
	(33218),
	(33219),
	(33220),
	(33221),
	(33222),
	(33223),
	(33224),
	(33225),
	(33226),
	(33227),
	(33228),
	(33229),
	(33230),
	(33231),
	(33232),
	(33233),
	(33234),
	(33235),
	(33236),
	(33237),
	(33238),
	(33239),
	(33240),
	(33241),
	(33242),
	(33243),
	(33244),
	(33245),
	(33246),
	(33247),
	(33248),
	(33249),
	(33250),
	(33251),
	(33252),
	(33253),
	(33254),
	(33255),
	(33256),
	(33257),
	(33258),
	(33259),
	(33260),
	(33261),
	(33262),
	(33263),
	(33264),
	(33265),
	(33266),
	(33267),
	(33268),
	(33269),
	(33270),
	(33271),
	(33272),
	(33273),
	(33274),
	(33275),
	(33276),
	(33277),
	(33278),
	(33279),
	(33280),
	(33281),
	(33282),
	(33283),
	(33284),
	(33285),
	(33286),
	(33287),
	(33288),
	(33289),
	(33290),
	(33291),
	(33292),
	(33293),
	(33294),
	(33295),
	(33296),
	(33297),
	(33298),
	(33299),
	(33300),
	(33301),
	(33302),
	(33303),
	(33304),
	(33305),
	(33306),
	(33307),
	(33308),
	(33309),
	(33310),
	(33311),
	(33312),
	(33313),
	(33314),
	(33315),
	(33316),
	(33317),
	(33318),
	(33319),
	(33320),
	(33321),
	(33322),
	(33323),
	(33324),
	(33325),
	(33326),
	(33327),
	(33328),
	(33329),
	(33330),
	(33331),
	(33332),
	(33333),
	(33334),
	(33335),
	(33336),
	(33337),
	(33338),
	(33339),
	(33340),
	(33341),
	(33342),
	(33343),
	(33344),
	(33345),
	(33346),
	(33347),
	(33348),
	(33349),
	(33350),
	(33351),
	(33352),
	(33353),
	(33354),
	(33355),
	(33356),
	(33357),
	(33358),
	(33359),
	(33360),
	(33361),
	(33362),
	(33363),
	(33364),
	(33365),
	(33366),
	(33367),
	(33368),
	(33369),
	(33370),
	(33371),
	(33372),
	(33373),
	(33374),
	(33375),
	(33376),
	(33377),
	(33378),
	(33379),
	(33380),
	(33381),
	(33382),
	(33383),
	(33384),
	(33385),
	(33386),
	(33387),
	(33388),
	(33389),
	(33390),
	(33391),
	(33392),
	(33393),
	(33394),
	(33395),
	(33396),
	(33397),
	(33398),
	(33399),
	(33400),
	(33401),
	(33402),
	(33403),
	(33404),
	(33405),
	(33406),
	(33407),
	(33408),
	(33409),
	(33410),
	(33411),
	(33412),
	(33413),
	(33414),
	(33415),
	(33416),
	(33417),
	(33418),
	(33419),
	(33420),
	(33421),
	(33422),
	(33423),
	(33424),
	(33425),
	(33426),
	(33427),
	(33428),
	(33429),
	(33430),
	(33431),
	(33432),
	(33433),
	(33434),
	(33435),
	(33436),
	(33437),
	(33438),
	(33439),
	(33440),
	(33441),
	(33442),
	(33443),
	(33444),
	(33445),
	(33446),
	(33447),
	(33448),
	(33449),
	(33450),
	(33451),
	(33452),
	(33453),
	(33454),
	(33455),
	(33456),
	(33457),
	(33458),
	(33459),
	(33460),
	(33461),
	(33462),
	(33463),
	(33464),
	(33465),
	(33466),
	(33467),
	(33468),
	(33469),
	(33470),
	(33471),
	(33472),
	(33473),
	(33474),
	(33475),
	(33476),
	(33477),
	(33478),
	(33479),
	(33480),
	(33481),
	(33482),
	(33483),
	(33484),
	(33485),
	(33486),
	(33487),
	(33488),
	(33489),
	(33490),
	(33491),
	(33492),
	(33493),
	(33494),
	(33495),
	(33496),
	(33497),
	(33498),
	(33499),
	(33500),
	(33501),
	(33502),
	(33503),
	(33504),
	(33505),
	(33506),
	(33507),
	(33508),
	(33509),
	(33510),
	(33511),
	(33512),
	(33513),
	(33514),
	(33515),
	(33516),
	(33517),
	(33518),
	(33519),
	(33520),
	(33521),
	(33522),
	(33523),
	(33524),
	(33525),
	(33526),
	(33527),
	(33528),
	(33529),
	(33530),
	(33531),
	(33532),
	(33533),
	(33534),
	(33535),
	(33536),
	(33537),
	(33538),
	(33539),
	(33540),
	(33541),
	(33542),
	(33543),
	(33544),
	(33545),
	(33546),
	(33547),
	(33548),
	(33549),
	(33550),
	(33551),
	(33552),
	(33553),
	(33554),
	(33555),
	(33556),
	(33557),
	(33558),
	(33559),
	(33560),
	(33561),
	(33562),
	(33563),
	(33564),
	(33565),
	(33566),
	(33567),
	(33568),
	(33569),
	(33570),
	(33571),
	(33572),
	(33573),
	(33574),
	(33575),
	(33576),
	(33577),
	(33578),
	(33579),
	(33580),
	(33581),
	(33582),
	(33583),
	(33584),
	(33585),
	(33586),
	(33587),
	(33588),
	(33589),
	(33590),
	(33591),
	(33592),
	(33593),
	(33594),
	(33595),
	(33596),
	(33597),
	(33598),
	(33599),
	(33600),
	(33601),
	(33602),
	(33603),
	(33604),
	(33605),
	(33606),
	(33607),
	(33608),
	(33609),
	(33610),
	(33611),
	(33612),
	(33613),
	(33614),
	(33615),
	(33616),
	(33617),
	(33618),
	(33619),
	(33620),
	(33621),
	(33622),
	(33623),
	(33624),
	(33625),
	(33626),
	(33627),
	(33628),
	(33629),
	(33630),
	(33631),
	(33632),
	(33633),
	(33634),
	(33635),
	(33636),
	(33637),
	(33638),
	(33639),
	(33640),
	(33641),
	(33642),
	(33643),
	(33644),
	(33645),
	(33646),
	(33647),
	(33648),
	(33649),
	(33650),
	(33651),
	(33652),
	(33653),
	(33654),
	(33655),
	(33656),
	(33657),
	(33658),
	(33659),
	(33660),
	(33661),
	(33662),
	(33663),
	(33664),
	(33665),
	(33666),
	(33667),
	(33668),
	(33669),
	(33670),
	(33671),
	(33672),
	(33673),
	(33674),
	(33675),
	(33676),
	(33677),
	(33678),
	(33679),
	(33680),
	(33681),
	(33682),
	(33683),
	(33684),
	(33685),
	(33686),
	(33687),
	(33688),
	(33689),
	(33690),
	(33691),
	(33692),
	(33693),
	(33694),
	(33695),
	(33696),
	(33697),
	(33698),
	(33699),
	(33700),
	(33701),
	(33702),
	(33703),
	(33704),
	(33705),
	(33706),
	(33707),
	(33708),
	(33709),
	(33710),
	(33711),
	(33712),
	(33713),
	(33714),
	(33715),
	(33716),
	(33717),
	(33718),
	(33719),
	(33720),
	(33721),
	(33722),
	(33723),
	(33724),
	(33725),
	(33726),
	(33727),
	(33728),
	(33729),
	(33730),
	(33731),
	(33732),
	(33733),
	(33734),
	(33735),
	(33736),
	(33737),
	(33738),
	(33739),
	(33740),
	(33741),
	(33742),
	(33743),
	(33744),
	(33745),
	(33746),
	(33747),
	(33748),
	(33749),
	(33750),
	(33751),
	(33752),
	(33753),
	(33754),
	(33755),
	(33756),
	(33757),
	(33758),
	(33759),
	(33760),
	(33761),
	(33762),
	(33763),
	(33764),
	(33765),
	(33766),
	(33767),
	(33768),
	(33769),
	(33770),
	(33771),
	(33772),
	(33773),
	(33774),
	(33775),
	(33776),
	(33777),
	(33778),
	(33779),
	(33780),
	(33781),
	(33782),
	(33783),
	(33784),
	(33785),
	(33786),
	(33787),
	(33788),
	(33789),
	(33790),
	(33791),
	(33792),
	(33793),
	(33794),
	(33795),
	(33796),
	(33797),
	(33798),
	(33799),
	(33800),
	(33801),
	(33802),
	(33803),
	(33804),
	(33805),
	(33806),
	(33807),
	(33808),
	(33809),
	(33810),
	(33811),
	(33812),
	(33813),
	(33814),
	(33815),
	(33816),
	(33817),
	(33818),
	(33819),
	(33820),
	(33821),
	(33822),
	(33823),
	(33824),
	(33825),
	(33826),
	(33827),
	(33828),
	(33829),
	(33830),
	(33831),
	(33832),
	(33833),
	(33834),
	(33835),
	(33836),
	(33837),
	(33838),
	(33839),
	(33840),
	(33841),
	(33842),
	(33843),
	(33844),
	(33845),
	(33846),
	(33847),
	(33848),
	(33849),
	(33850),
	(33851),
	(33852),
	(33853),
	(33854),
	(33855),
	(33856),
	(33857),
	(33858),
	(33859),
	(33860),
	(33861),
	(33862),
	(33863),
	(33864),
	(33865),
	(33866),
	(33867),
	(33868),
	(33869),
	(33870),
	(33871),
	(33872),
	(33873),
	(33874),
	(33875),
	(33876),
	(33877),
	(33878),
	(33879),
	(33880),
	(33881),
	(33882),
	(33883),
	(33884),
	(33885),
	(33886),
	(33887),
	(33888),
	(33889),
	(33890),
	(33891),
	(33892),
	(33893),
	(33894),
	(33895),
	(33896),
	(33897),
	(33898),
	(33899),
	(33900),
	(33901),
	(33902),
	(33903),
	(33904),
	(33905),
	(33906),
	(33907),
	(33908),
	(33909),
	(33910),
	(33911),
	(33912),
	(33913),
	(33914),
	(33915),
	(33916),
	(33917),
	(33918),
	(33919),
	(33920),
	(33921),
	(33922),
	(33923),
	(33924),
	(33925),
	(33926),
	(33927),
	(33928),
	(33929),
	(33930),
	(33931),
	(33932),
	(33933),
	(33934),
	(33935),
	(33936),
	(33937),
	(33938),
	(33939),
	(33940),
	(33941),
	(33942),
	(33943),
	(33944),
	(33945),
	(33946),
	(33947),
	(33948),
	(33949),
	(33950),
	(33951),
	(33952),
	(33953),
	(33954),
	(33955),
	(33956),
	(33957),
	(33958),
	(33959),
	(33960),
	(33961),
	(33962),
	(33963),
	(33964),
	(33965),
	(33966),
	(33967),
	(33968),
	(33969),
	(33970),
	(33971),
	(33972),
	(33973),
	(33974),
	(33975),
	(33976),
	(33977),
	(33978),
	(33979),
	(33980),
	(33981),
	(33982),
	(33983),
	(33984),
	(33985),
	(33986),
	(33987),
	(33988),
	(33989),
	(33990),
	(33991),
	(33992),
	(33993),
	(33994),
	(33995),
	(33996),
	(33997),
	(33998),
	(33999),
	(34000),
	(34001),
	(34002),
	(34003),
	(34004),
	(34005),
	(34006),
	(34007),
	(34008),
	(34009),
	(34010),
	(34011),
	(34012),
	(34013),
	(34014),
	(34015),
	(34016),
	(34017),
	(34018),
	(34019),
	(34020),
	(34021),
	(34022),
	(34023),
	(34024),
	(34025),
	(34026),
	(34027),
	(34028),
	(34029),
	(34030),
	(34031),
	(34032),
	(34033),
	(34034),
	(34035),
	(34036),
	(34037),
	(34038),
	(34039),
	(34040),
	(34041),
	(34042),
	(34043),
	(34044),
	(34045),
	(34046),
	(34047),
	(34048),
	(34049),
	(34050),
	(34051),
	(34052),
	(34053),
	(34054),
	(34055),
	(34056),
	(34057),
	(34058),
	(34059),
	(34060),
	(34061),
	(34062),
	(34063),
	(34064),
	(34065),
	(34066),
	(34067),
	(34068),
	(34069),
	(34070),
	(34071),
	(34072),
	(34073),
	(34074),
	(34075),
	(34076),
	(34077),
	(34078),
	(34079),
	(34080),
	(34081),
	(34082),
	(34083),
	(34084),
	(34085),
	(34086),
	(34087),
	(34088),
	(34089),
	(34090),
	(34091),
	(34092),
	(34093),
	(34094),
	(34095),
	(34096),
	(34097),
	(34098),
	(34099),
	(34100),
	(34101),
	(34102),
	(34103),
	(34104),
	(34105),
	(34106),
	(34107),
	(34108),
	(34109),
	(34110),
	(34111),
	(34112),
	(34113),
	(34114),
	(34115),
	(34116),
	(34117),
	(34118),
	(34119),
	(34120),
	(34121),
	(34122),
	(34123),
	(34124),
	(34125),
	(34126),
	(34127),
	(34128),
	(34129),
	(34130),
	(34131),
	(34132),
	(34133),
	(34134),
	(34135),
	(34136),
	(34137),
	(34138),
	(34139),
	(34140),
	(34141),
	(34142),
	(34143),
	(34144),
	(34145),
	(34146),
	(34147),
	(34148),
	(34149),
	(34150),
	(34151),
	(34152),
	(34153),
	(34154),
	(34155),
	(34156),
	(34157),
	(34158),
	(34159),
	(34160),
	(34161),
	(34162),
	(34163),
	(34164),
	(34165),
	(34166),
	(34167),
	(34168),
	(34169),
	(34170),
	(34171),
	(34172),
	(34173),
	(34174),
	(34175),
	(34176),
	(34177),
	(34178),
	(34179),
	(34180),
	(34181),
	(34182),
	(34183),
	(34184),
	(34185),
	(34186),
	(34187),
	(34188),
	(34189),
	(34190),
	(34191),
	(34192),
	(34193),
	(34194),
	(34195),
	(34196),
	(34197),
	(34198),
	(34199),
	(34200),
	(34201),
	(34202),
	(34203),
	(34204),
	(34205),
	(34206),
	(34207),
	(34208),
	(34209),
	(34210),
	(34211),
	(34212),
	(34213),
	(34214),
	(34215),
	(34216),
	(34217),
	(34218),
	(34219),
	(34220),
	(34221),
	(34222),
	(34223),
	(34224),
	(34225),
	(34226),
	(34227),
	(34228),
	(34229),
	(34230),
	(34231),
	(34232),
	(34233),
	(34234),
	(34235),
	(34236),
	(34237),
	(34238),
	(34239),
	(34240),
	(34241),
	(34242),
	(34243),
	(34244),
	(34245),
	(34246),
	(34247),
	(34248),
	(34249),
	(34250),
	(34251),
	(34252),
	(34253),
	(34254),
	(34255),
	(34256),
	(34257),
	(34258),
	(34259),
	(34260),
	(34261),
	(34262),
	(34263),
	(34264),
	(34265),
	(34266),
	(34267),
	(34268),
	(34269),
	(34270),
	(34271),
	(34272),
	(34273),
	(34274),
	(34275),
	(34276),
	(34277),
	(34278),
	(34279),
	(34280),
	(34281),
	(34282),
	(34283),
	(34284),
	(34285),
	(34286),
	(34287),
	(34288),
	(34289),
	(34290),
	(34291),
	(34292),
	(34293),
	(34294),
	(34295),
	(34296),
	(34297),
	(34298),
	(34299),
	(34300),
	(34301),
	(34302),
	(34303),
	(34304),
	(34305),
	(34306),
	(34307),
	(34308),
	(34309),
	(34310),
	(34311),
	(34312),
	(34313),
	(34314),
	(34315),
	(34316),
	(34317),
	(34318),
	(34319),
	(34320),
	(34321),
	(34322),
	(34323),
	(34324),
	(34325),
	(34326),
	(34327),
	(34328),
	(34329),
	(34330),
	(34331),
	(34332),
	(34333),
	(34334),
	(34335),
	(34336),
	(34337),
	(34338),
	(34339),
	(34340),
	(34341),
	(34342),
	(34343),
	(34344),
	(34345),
	(34346),
	(34347),
	(34348),
	(34349),
	(34350),
	(34351),
	(34352),
	(34353),
	(34354),
	(34355),
	(34356),
	(34357),
	(34358),
	(34359),
	(34360),
	(34361),
	(34362),
	(34363),
	(34364),
	(34365),
	(34366),
	(34367),
	(34368),
	(34369),
	(34370),
	(34371),
	(34372),
	(34373),
	(34374),
	(34375),
	(34376),
	(34377),
	(34378),
	(34379),
	(34380),
	(34381),
	(34382),
	(34383),
	(34384),
	(34385),
	(34386),
	(34387),
	(34388),
	(34389),
	(34390),
	(34391),
	(34392),
	(34393),
	(34394),
	(34395),
	(34396),
	(34397),
	(34398),
	(34399),
	(34400),
	(34401),
	(34402),
	(34403),
	(34404),
	(34405),
	(34406),
	(34407),
	(34408),
	(34409),
	(34410),
	(34411),
	(34412),
	(34413),
	(34414),
	(34415),
	(34416),
	(34417),
	(34418),
	(34419),
	(34420),
	(34421),
	(34422),
	(34423),
	(34424),
	(34425),
	(34426),
	(34427),
	(34428),
	(34429),
	(34430),
	(34431),
	(34432),
	(34433),
	(34434),
	(34435),
	(34436),
	(34437),
	(34438),
	(34439),
	(34440),
	(34441),
	(34442),
	(34443),
	(34444),
	(34445),
	(34446),
	(34447),
	(34448),
	(34449),
	(34450),
	(34451),
	(34452),
	(34453),
	(34454),
	(34455),
	(34456),
	(34457),
	(34458),
	(34459),
	(34460),
	(34461),
	(34462),
	(34463),
	(34464),
	(34465),
	(34466),
	(34467),
	(34468),
	(34469),
	(34470),
	(34471),
	(34472),
	(34473),
	(34474),
	(34475),
	(34476),
	(34477),
	(34478),
	(34479),
	(34480),
	(34481),
	(34482),
	(34483),
	(34484),
	(34485),
	(34486),
	(34487),
	(34488),
	(34489),
	(34490),
	(34491),
	(34492),
	(34493),
	(34494),
	(34495),
	(34496),
	(34497),
	(34498),
	(34499),
	(34500),
	(34501),
	(34502),
	(34503),
	(34504),
	(34505),
	(34506),
	(34507),
	(34508),
	(34509),
	(34510),
	(34511),
	(34512),
	(34513),
	(34514),
	(34515),
	(34516),
	(34517),
	(34518),
	(34519),
	(34520),
	(34521),
	(34522),
	(34523),
	(34524),
	(34525),
	(34526),
	(34527),
	(34528),
	(34529),
	(34530),
	(34531),
	(34532),
	(34533),
	(34534),
	(34535),
	(34536),
	(34537),
	(34538),
	(34539),
	(34540),
	(34541),
	(34542),
	(34543),
	(34544),
	(34545),
	(34546),
	(34547),
	(34548),
	(34549),
	(34550),
	(34551),
	(34552),
	(34553),
	(34554),
	(34555),
	(34556),
	(34557),
	(34558),
	(34559),
	(34560),
	(34561),
	(34562),
	(34563),
	(34564),
	(34565),
	(34566),
	(34567),
	(34568),
	(34569),
	(34570),
	(34571),
	(34572),
	(34573),
	(34574),
	(34575),
	(34576),
	(34577),
	(34578),
	(34579),
	(34580),
	(34581),
	(34582),
	(34583),
	(34584),
	(34585),
	(34586),
	(34587),
	(34588),
	(34589),
	(34590),
	(34591),
	(34592),
	(34593),
	(34594),
	(34595),
	(34596),
	(34597),
	(34598),
	(34599),
	(34600),
	(34601),
	(34602),
	(34603),
	(34604),
	(34605),
	(34606),
	(34607),
	(34608),
	(34609),
	(34610),
	(34611),
	(34612),
	(34613),
	(34614),
	(34615),
	(34616),
	(34617),
	(34618),
	(34619),
	(34620),
	(34621),
	(34622),
	(34623),
	(34624),
	(34625),
	(34626),
	(34627),
	(34628),
	(34629),
	(34630),
	(34631),
	(34632),
	(34633),
	(34634),
	(34635),
	(34636),
	(34637),
	(34638),
	(34639),
	(34640),
	(34641),
	(34642),
	(34643),
	(34644),
	(34645),
	(34646),
	(34647),
	(34648),
	(34649),
	(34650),
	(34651),
	(34652),
	(34653),
	(34654),
	(34655),
	(34656),
	(34657),
	(34658),
	(34659),
	(34660),
	(34661),
	(34662),
	(34663),
	(34664),
	(34665),
	(34666),
	(34667),
	(34668),
	(34669),
	(34670),
	(34671),
	(34672),
	(34673),
	(34674),
	(34675),
	(34676),
	(34677),
	(34678),
	(34679),
	(34680),
	(34681),
	(34682),
	(34683),
	(34684),
	(34685),
	(34686),
	(34687),
	(34688),
	(34689),
	(34690),
	(34691),
	(34692),
	(34693),
	(34694),
	(34695),
	(34696),
	(34697),
	(34698),
	(34699),
	(34700),
	(34701),
	(34702),
	(34703),
	(34704),
	(34705),
	(34706),
	(34707),
	(34708),
	(34709),
	(34710),
	(34711),
	(34712),
	(34713),
	(34714),
	(34715),
	(34716),
	(34717),
	(34718),
	(34719),
	(34720),
	(34721),
	(34722),
	(34723),
	(34724),
	(34725),
	(34726),
	(34727),
	(34728),
	(34729),
	(34730),
	(34731),
	(34732),
	(34733),
	(34734),
	(34735),
	(34736),
	(34737),
	(34738),
	(34739),
	(34740),
	(34741),
	(34742),
	(34743),
	(34744),
	(34745),
	(34746),
	(34747),
	(34748),
	(34749),
	(34750),
	(34751),
	(34752),
	(34753),
	(34754),
	(34755),
	(34756),
	(34757),
	(34758),
	(34759),
	(34760),
	(34761),
	(34762),
	(34763),
	(34764),
	(34765),
	(34766),
	(34767),
	(34768),
	(34769),
	(34770),
	(34771),
	(34772),
	(34773),
	(34774),
	(34775),
	(34776),
	(34777),
	(34778),
	(34779),
	(34780),
	(34781),
	(34782),
	(34783),
	(34784),
	(34785),
	(34786),
	(34787),
	(34788),
	(34789),
	(34790),
	(34791),
	(34792),
	(34793),
	(34794),
	(34795),
	(34796),
	(34797),
	(34798),
	(34799),
	(34800),
	(34801),
	(34802),
	(34803),
	(34804),
	(34805),
	(34806),
	(34807),
	(34808),
	(34809),
	(34810),
	(34811),
	(34812),
	(34813),
	(34814),
	(34815),
	(34816),
	(34817),
	(34818),
	(34819),
	(34820),
	(34821),
	(34822),
	(34823),
	(34824),
	(34825),
	(34826),
	(34827),
	(34828),
	(34829),
	(34830),
	(34831),
	(34832),
	(34833),
	(34834),
	(34835),
	(34836),
	(34837),
	(34838),
	(34839),
	(34840),
	(34841),
	(34842),
	(34843),
	(34844),
	(34845),
	(34846),
	(34847),
	(34848),
	(34849),
	(34850),
	(34851),
	(34852),
	(34853),
	(34854),
	(34855),
	(34856),
	(34857),
	(34858),
	(34859),
	(34860),
	(34861),
	(34862),
	(34863),
	(34864),
	(34865),
	(34866),
	(34867),
	(34868),
	(34869),
	(34870),
	(34871),
	(34872),
	(34873),
	(34874),
	(34875),
	(34876),
	(34877),
	(34878),
	(34879),
	(34880),
	(34881),
	(34882),
	(34883),
	(34884),
	(34885),
	(34886),
	(34887),
	(34888),
	(34889),
	(34890),
	(34891),
	(34892),
	(34893),
	(34894),
	(34895),
	(34896),
	(34897),
	(34898),
	(34899),
	(34900),
	(34901),
	(34902),
	(34903),
	(34904),
	(34905),
	(34906),
	(34907),
	(34908),
	(34909),
	(34910),
	(34911),
	(34912),
	(34913),
	(34914),
	(34915),
	(34916),
	(34917),
	(34918),
	(34919),
	(34920),
	(34921),
	(34922),
	(34923),
	(34924),
	(34925),
	(34926),
	(34927),
	(34928),
	(34929),
	(34930),
	(34931),
	(34932),
	(34933),
	(34934),
	(34935),
	(34936),
	(34937),
	(34938),
	(34939),
	(34940),
	(34941),
	(34942),
	(34943),
	(34944),
	(34945),
	(34946),
	(34947),
	(34948),
	(34949),
	(34950),
	(34951),
	(34952),
	(34953),
	(34954),
	(34955),
	(34956),
	(34957),
	(34958),
	(34959),
	(34960),
	(34961),
	(34962),
	(34963),
	(34964),
	(34965),
	(34966),
	(34967),
	(34968),
	(34969),
	(34970),
	(34971),
	(34972),
	(34973),
	(34974),
	(34975),
	(34976),
	(34977),
	(34978),
	(34979),
	(34980),
	(34981),
	(34982),
	(34983),
	(34984),
	(34985),
	(34986),
	(34987),
	(34988),
	(34989),
	(34990),
	(34991),
	(34992),
	(34993),
	(34994),
	(34995),
	(34996),
	(34997),
	(34998),
	(34999),
	(35000),
	(35001),
	(35002),
	(35003),
	(35004),
	(35005),
	(35006),
	(35007),
	(35008),
	(35009),
	(35010),
	(35011),
	(35012),
	(35013),
	(35014),
	(35015),
	(35016),
	(35017),
	(35018),
	(35019),
	(35020),
	(35021),
	(35022),
	(35023),
	(35024),
	(35025),
	(35026),
	(35027),
	(35028),
	(35029),
	(35030),
	(35031),
	(35032),
	(35033),
	(35034),
	(35035),
	(35036),
	(35037),
	(35038),
	(35039),
	(35040),
	(35041),
	(35042),
	(35043),
	(35044),
	(35045),
	(35046),
	(35047),
	(35048),
	(35049),
	(35050),
	(35051),
	(35052),
	(35053),
	(35054),
	(35055),
	(35056),
	(35057),
	(35058),
	(35059),
	(35060),
	(35061),
	(35062),
	(35063),
	(35064),
	(35065),
	(35066),
	(35067),
	(35068),
	(35069),
	(35070),
	(35071),
	(35072),
	(35073),
	(35074),
	(35075),
	(35076),
	(35077),
	(35078),
	(35079),
	(35080),
	(35081),
	(35082),
	(35083),
	(35084),
	(35085),
	(35086),
	(35087),
	(35088),
	(35089),
	(35090),
	(35091),
	(35092),
	(35093),
	(35094),
	(35095),
	(35096),
	(35097),
	(35098),
	(35099),
	(35100),
	(35101),
	(35102),
	(35103),
	(35104),
	(35105),
	(35106),
	(35107),
	(35108),
	(35109),
	(35110),
	(35111),
	(35112),
	(35113),
	(35114),
	(35115),
	(35116),
	(35117),
	(35118),
	(35119),
	(35120),
	(35121),
	(35122),
	(35123),
	(35124),
	(35125),
	(35126),
	(35127),
	(35128),
	(35129),
	(35130),
	(35131),
	(35132),
	(35133),
	(35134),
	(35135),
	(35136),
	(35137),
	(35138),
	(35139),
	(35140),
	(35141),
	(35142),
	(35143),
	(35144),
	(35145),
	(35146),
	(35147),
	(35148),
	(35149),
	(35150),
	(35151),
	(35152),
	(35153),
	(35154),
	(35155),
	(35156),
	(35157),
	(35158),
	(35159),
	(35160),
	(35161),
	(35162),
	(35163),
	(35164),
	(35165),
	(35166),
	(35167),
	(35168),
	(35169),
	(35170),
	(35171),
	(35172),
	(35173),
	(35174),
	(35175),
	(35176),
	(35177),
	(35178),
	(35179),
	(35180),
	(35181),
	(35182),
	(35183),
	(35184),
	(35185),
	(35186),
	(35187),
	(35188),
	(35189),
	(35190),
	(35191),
	(35192),
	(35193),
	(35194),
	(35195),
	(35196),
	(35197),
	(35198),
	(35199),
	(35200),
	(35201),
	(35202),
	(35203),
	(35204),
	(35205),
	(35206),
	(35207),
	(35208),
	(35209),
	(35210),
	(35211),
	(35212),
	(35213),
	(35214),
	(35215),
	(35216),
	(35217),
	(35218),
	(35219),
	(35220),
	(35221),
	(35222),
	(35223),
	(35224),
	(35225),
	(35226),
	(35227),
	(35228),
	(35229),
	(35230),
	(35231),
	(35232),
	(35233),
	(35234),
	(35235),
	(35236),
	(35237),
	(35238),
	(35239),
	(35240),
	(35241),
	(35242),
	(35243),
	(35244),
	(35245),
	(35246),
	(35247),
	(35248),
	(35249),
	(35250),
	(35251),
	(35252),
	(35253),
	(35254),
	(35255),
	(35256),
	(35257),
	(35258),
	(35259),
	(35260),
	(35261),
	(35262),
	(35263),
	(35264),
	(35265),
	(35266),
	(35267),
	(35268),
	(35269),
	(35270),
	(35271),
	(35272),
	(35273),
	(35274),
	(35275),
	(35276),
	(35277),
	(35278),
	(35279),
	(35280),
	(35281),
	(35282),
	(35283),
	(35284),
	(35285),
	(35286),
	(35287),
	(35288),
	(35289),
	(35290),
	(35291),
	(35292),
	(35293),
	(35294),
	(35295),
	(35296),
	(35297),
	(35298),
	(35299),
	(35300),
	(35301),
	(35302),
	(35303),
	(35304),
	(35305),
	(35306),
	(35307),
	(35308),
	(35309),
	(35310),
	(35311),
	(35312),
	(35313),
	(35314),
	(35315),
	(35316),
	(35317),
	(35318),
	(35319),
	(35320),
	(35321),
	(35322),
	(35323),
	(35324),
	(35325),
	(35326),
	(35327),
	(35328),
	(35329),
	(35330),
	(35331),
	(35332),
	(35333),
	(35334),
	(35335),
	(35336),
	(35337),
	(35338),
	(35339),
	(35340),
	(35341),
	(35342),
	(35343),
	(35344),
	(35345),
	(35346),
	(35347),
	(35348),
	(35349),
	(35350),
	(35351),
	(35352),
	(35353),
	(35354),
	(35355),
	(35356),
	(35357),
	(35358),
	(35359),
	(35360),
	(35361),
	(35362),
	(35363),
	(35364),
	(35365),
	(35366),
	(35367),
	(35368),
	(35369),
	(35370),
	(35371),
	(35372),
	(35373),
	(35374),
	(35375),
	(35376),
	(35377),
	(35378),
	(35379),
	(35380),
	(35381),
	(35382),
	(35383),
	(35384),
	(35385),
	(35386),
	(35387),
	(35388),
	(35389),
	(35390),
	(35391),
	(35392),
	(35393),
	(35394),
	(35395),
	(35396),
	(35397),
	(35398),
	(35399),
	(35400),
	(35401),
	(35402),
	(35403),
	(35404),
	(35405),
	(35406),
	(35407),
	(35408),
	(35409),
	(35410),
	(35411),
	(35412),
	(35413),
	(35414),
	(35415),
	(35416),
	(35417),
	(35418),
	(35419),
	(35420),
	(35421),
	(35422),
	(35423),
	(35424),
	(35425),
	(35426),
	(35427),
	(35428),
	(35429),
	(35430),
	(35431),
	(35432),
	(35433),
	(35434),
	(35435),
	(35436),
	(35437),
	(35438),
	(35439),
	(35440),
	(35441),
	(35442),
	(35443),
	(35444),
	(35445),
	(35446),
	(35447),
	(35448),
	(35449),
	(35450),
	(35451),
	(35452),
	(35453),
	(35454),
	(35455),
	(35456),
	(35457),
	(35458),
	(35459),
	(35460),
	(35461),
	(35462),
	(35463),
	(35464),
	(35465),
	(35466),
	(35467),
	(35468),
	(35469),
	(35470),
	(35471),
	(35472),
	(35473),
	(35474),
	(35475),
	(35476),
	(35477),
	(35478),
	(35479),
	(35480),
	(35481),
	(35482),
	(35483),
	(35484),
	(35485),
	(35486),
	(35487),
	(35488),
	(35489),
	(35490),
	(35491),
	(35492),
	(35493),
	(35494),
	(35495),
	(35496),
	(35497),
	(35498),
	(35499),
	(35500),
	(35501),
	(35502),
	(35503),
	(35504),
	(35505),
	(35506),
	(35507),
	(35508),
	(35509),
	(35510),
	(35511),
	(35512),
	(35513),
	(35514),
	(35515),
	(35516),
	(35517),
	(35518),
	(35519),
	(35520),
	(35521),
	(35522),
	(35523),
	(35524),
	(35525),
	(35526),
	(35527),
	(35528),
	(35529),
	(35530),
	(35531),
	(35532),
	(35533),
	(35534),
	(35535),
	(35536),
	(35537),
	(35538),
	(35539),
	(35540),
	(35541),
	(35542),
	(35543),
	(35544),
	(35545),
	(35546),
	(35547),
	(35548),
	(35549),
	(35550),
	(35551),
	(35552),
	(35553),
	(35554),
	(35555),
	(35556),
	(35557),
	(35558),
	(35559),
	(35560),
	(35561),
	(35562),
	(35563),
	(35564),
	(35565),
	(35566),
	(35567),
	(35568),
	(35569),
	(35570),
	(35571),
	(35572),
	(35573),
	(35574),
	(35575),
	(35576),
	(35577),
	(35578),
	(35579),
	(35580),
	(35581),
	(35582),
	(35583),
	(35584),
	(35585),
	(35586),
	(35587),
	(35588),
	(35589),
	(35590),
	(35591),
	(35592),
	(35593),
	(35594),
	(35595),
	(35596),
	(35597),
	(35598),
	(35599),
	(35600),
	(35601),
	(35602),
	(35603),
	(35604),
	(35605),
	(35606),
	(35607),
	(35608),
	(35609),
	(35610),
	(35611),
	(35612),
	(35613),
	(35614),
	(35615),
	(35616),
	(35617),
	(35618),
	(35619),
	(35620),
	(35621),
	(35622),
	(35623),
	(35624),
	(35625),
	(35626),
	(35627),
	(35628),
	(35629),
	(35630),
	(35631),
	(35632),
	(35633),
	(35634),
	(35635),
	(35636),
	(35637),
	(35638),
	(35639),
	(35640),
	(35641),
	(35642),
	(35643),
	(35644),
	(35645),
	(35646),
	(35647),
	(35648),
	(35649),
	(35650),
	(35651),
	(35652),
	(35653),
	(35654),
	(35655),
	(35656),
	(35657),
	(35658),
	(35659),
	(35660),
	(35661),
	(35662),
	(35663),
	(35664),
	(35665),
	(35666),
	(35667),
	(35668),
	(35669),
	(35670),
	(35671),
	(35672),
	(35673),
	(35674),
	(35675),
	(35676),
	(35677),
	(35678),
	(35679),
	(35680),
	(35681),
	(35682),
	(35683),
	(35684),
	(35685),
	(35686),
	(35687),
	(35688),
	(35689),
	(35690),
	(35691),
	(35692),
	(35693),
	(35694),
	(35695),
	(35696),
	(35697),
	(35698),
	(35699),
	(35700),
	(35701),
	(35702),
	(35703),
	(35704),
	(35705),
	(35706),
	(35707),
	(35708),
	(35709),
	(35710),
	(35711),
	(35712),
	(35713),
	(35714),
	(35715),
	(35716),
	(35717),
	(35718),
	(35719),
	(35720),
	(35721),
	(35722),
	(35723),
	(35724),
	(35725),
	(35726),
	(35727),
	(35728),
	(35729),
	(35730),
	(35731),
	(35732),
	(35733),
	(35734),
	(35735),
	(35736),
	(35737),
	(35738),
	(35739),
	(35740),
	(35741),
	(35742),
	(35743),
	(35744),
	(35745),
	(35746),
	(35747),
	(35748),
	(35749),
	(35750),
	(35751),
	(35752),
	(35753),
	(35754),
	(35755),
	(35756),
	(35757),
	(35758),
	(35759),
	(35760),
	(35761),
	(35762),
	(35763),
	(35764),
	(35765),
	(35766),
	(35767),
	(35768),
	(35769),
	(35770),
	(35771),
	(35772),
	(35773),
	(35774),
	(35775),
	(35776),
	(35777),
	(35778),
	(35779),
	(35780),
	(35781),
	(35782),
	(35783),
	(35784),
	(35785),
	(35786),
	(35787),
	(35788),
	(35789),
	(35790),
	(35791),
	(35792),
	(35793),
	(35794),
	(35795),
	(35796),
	(35797),
	(35798),
	(35799),
	(35800),
	(35801),
	(35802),
	(35803),
	(35804),
	(35805),
	(35806),
	(35807),
	(35808),
	(35809),
	(35810),
	(35811),
	(35812),
	(35813),
	(35814),
	(35815),
	(35816),
	(35817),
	(35818),
	(35819),
	(35820),
	(35821),
	(35822),
	(35823),
	(35824),
	(35825),
	(35826),
	(35827),
	(35828),
	(35829),
	(35830),
	(35831),
	(35832),
	(35833),
	(35834),
	(35835),
	(35836),
	(35837),
	(35838),
	(35839),
	(35840),
	(35841),
	(35842),
	(35843),
	(35844),
	(35845),
	(35846),
	(35847),
	(35848),
	(35849),
	(35850),
	(35851),
	(35852),
	(35853),
	(35854),
	(35855),
	(35856),
	(35857),
	(35858),
	(35859),
	(35860),
	(35861),
	(35862),
	(35863),
	(35864),
	(35865),
	(35866),
	(35867),
	(35868),
	(35869),
	(35870),
	(35871),
	(35872),
	(35873),
	(35874),
	(35875),
	(35876),
	(35877),
	(35878),
	(35879),
	(35880),
	(35881),
	(35882),
	(35883),
	(35884),
	(35885),
	(35886),
	(35887),
	(35888),
	(35889),
	(35890),
	(35891),
	(35892),
	(35893),
	(35894),
	(35895),
	(35896),
	(35897),
	(35898),
	(35899),
	(35900),
	(35901),
	(35902),
	(35903),
	(35904),
	(35905),
	(35906),
	(35907),
	(35908),
	(35909),
	(35910),
	(35911),
	(35912),
	(35913),
	(35914),
	(35915),
	(35916),
	(35917),
	(35918),
	(35919),
	(35920),
	(35921),
	(35922),
	(35923),
	(35924),
	(35925),
	(35926),
	(35927),
	(35928),
	(35929),
	(35930),
	(35931),
	(35932),
	(35933),
	(35934),
	(35935),
	(35936),
	(35937),
	(35938),
	(35939),
	(35940),
	(35941),
	(35942),
	(35943),
	(35944),
	(35945),
	(35946),
	(35947),
	(35948),
	(35949),
	(35950),
	(35951),
	(35952),
	(35953),
	(35954),
	(35955),
	(35956),
	(35957),
	(35958),
	(35959),
	(35960),
	(35961),
	(35962),
	(35963),
	(35964),
	(35965),
	(35966),
	(35967),
	(35968),
	(35969),
	(35970),
	(35971),
	(35972),
	(35973),
	(35974),
	(35975),
	(35976),
	(35977),
	(35978),
	(35979),
	(35980),
	(35981),
	(35982),
	(35983),
	(35984),
	(35985),
	(35986),
	(35987),
	(35988),
	(35989),
	(35990),
	(35991),
	(35992),
	(35993),
	(35994),
	(35995),
	(35996),
	(35997),
	(35998),
	(35999),
	(36000),
	(36001),
	(36002),
	(36003),
	(36004),
	(36005),
	(36006),
	(36007),
	(36008),
	(36009),
	(36010),
	(36011),
	(36012),
	(36013),
	(36014),
	(36015),
	(36016),
	(36017),
	(36018),
	(36019),
	(36020),
	(36021),
	(36022),
	(36023),
	(36024),
	(36025),
	(36026),
	(36027),
	(36028),
	(36029),
	(36030),
	(36031),
	(36032),
	(36033),
	(36034),
	(36035),
	(36036),
	(36037),
	(36038),
	(36039),
	(36040),
	(36041),
	(36042),
	(36043),
	(36044),
	(36045),
	(36046),
	(36047),
	(36048),
	(36049),
	(36050),
	(36051),
	(36052),
	(36053),
	(36054),
	(36055),
	(36056),
	(36057),
	(36058),
	(36059),
	(36060),
	(36061),
	(36062),
	(36063),
	(36064),
	(36065),
	(36066),
	(36067),
	(36068),
	(36069),
	(36070),
	(36071),
	(36072),
	(36073),
	(36074),
	(36075),
	(36076),
	(36077),
	(36078),
	(36079),
	(36080),
	(36081),
	(36082),
	(36083),
	(36084),
	(36085),
	(36086),
	(36087),
	(36088),
	(36089),
	(36090),
	(36091),
	(36092),
	(36093),
	(36094),
	(36095),
	(36096),
	(36097),
	(36098),
	(36099),
	(36100),
	(36101),
	(36102),
	(36103),
	(36104),
	(36105),
	(36106),
	(36107),
	(36108),
	(36109),
	(36110),
	(36111),
	(36112),
	(36113),
	(36114),
	(36115),
	(36116),
	(36117),
	(36118),
	(36119),
	(36120),
	(36121),
	(36122),
	(36123),
	(36124),
	(36125),
	(36126),
	(36127),
	(36128),
	(36129),
	(36130),
	(36131),
	(36132),
	(36133),
	(36134),
	(36135),
	(36136),
	(36137),
	(36138),
	(36139),
	(36140),
	(36141),
	(36142),
	(36143),
	(36144),
	(36145),
	(36146),
	(36147),
	(36148),
	(36149),
	(36150),
	(36151),
	(36152),
	(36153),
	(36154),
	(36155),
	(36156),
	(36157),
	(36158),
	(36159),
	(36160),
	(36161),
	(36162),
	(36163),
	(36164),
	(36165),
	(36166),
	(36167),
	(36168),
	(36169),
	(36170),
	(36171),
	(36172),
	(36173),
	(36174),
	(36175),
	(36176),
	(36177),
	(36178),
	(36179),
	(36180),
	(36181),
	(36182),
	(36183),
	(36184),
	(36185),
	(36186),
	(36187),
	(36188),
	(36189),
	(36190),
	(36191),
	(36192),
	(36193),
	(36194),
	(36195),
	(36196),
	(36197),
	(36198),
	(36199),
	(36200),
	(36201),
	(36202),
	(36203),
	(36204),
	(36205),
	(36206),
	(36207),
	(36208),
	(36209),
	(36210),
	(36211),
	(36212),
	(36213),
	(36214),
	(36215),
	(36216),
	(36217),
	(36218),
	(36219),
	(36220),
	(36221),
	(36222),
	(36223),
	(36224),
	(36225),
	(36226),
	(36227),
	(36228),
	(36229),
	(36230),
	(36231),
	(36232),
	(36233),
	(36234),
	(36235),
	(36236),
	(36237),
	(36238),
	(36239),
	(36240),
	(36241),
	(36242),
	(36243),
	(36244),
	(36245),
	(36246),
	(36247),
	(36248),
	(36249),
	(36250),
	(36251),
	(36252),
	(36253),
	(36254),
	(36255),
	(36256),
	(36257),
	(36258),
	(36259),
	(36260),
	(36261),
	(36262),
	(36263),
	(36264),
	(36265),
	(36266),
	(36267),
	(36268),
	(36269),
	(36270),
	(36271),
	(36272),
	(36273),
	(36274),
	(36275),
	(36276),
	(36277),
	(36278),
	(36279),
	(36280),
	(36281),
	(36282),
	(36283),
	(36284),
	(36285),
	(36286),
	(36287),
	(36288),
	(36289),
	(36290),
	(36291),
	(36292),
	(36293),
	(36294),
	(36295),
	(36296),
	(36297),
	(36298),
	(36299),
	(36300),
	(36301),
	(36302),
	(36303),
	(36304),
	(36305),
	(36306),
	(36307),
	(36308),
	(36309),
	(36310),
	(36311),
	(36312),
	(36313),
	(36314),
	(36315),
	(36316),
	(36317),
	(36318),
	(36319),
	(36320),
	(36321),
	(36322),
	(36323),
	(36324),
	(36325),
	(36326),
	(36327),
	(36328),
	(36329),
	(36330),
	(36331),
	(36332),
	(36333),
	(36334),
	(36335),
	(36336),
	(36337),
	(36338),
	(36339),
	(36340),
	(36341),
	(36342),
	(36343),
	(36344),
	(36345),
	(36346),
	(36347),
	(36348),
	(36349),
	(36350),
	(36351),
	(36352),
	(36353),
	(36354),
	(36355),
	(36356),
	(36357),
	(36358),
	(36359),
	(36360),
	(36361),
	(36362),
	(36363),
	(36364),
	(36365),
	(36366),
	(36367),
	(36368),
	(36369),
	(36370),
	(36371),
	(36372),
	(36373),
	(36374),
	(36375),
	(36376),
	(36377),
	(36378),
	(36379),
	(36380),
	(36381),
	(36382),
	(36383),
	(36384),
	(36385),
	(36386),
	(36387),
	(36388),
	(36389),
	(36390),
	(36391),
	(36392),
	(36393),
	(36394),
	(36395),
	(36396),
	(36397),
	(36398),
	(36399),
	(36400),
	(36401),
	(36402),
	(36403),
	(36404),
	(36405),
	(36406),
	(36407),
	(36408),
	(36409),
	(36410),
	(36411),
	(36412),
	(36413),
	(36414),
	(36415),
	(36416),
	(36417),
	(36418),
	(36419),
	(36420),
	(36421),
	(36422),
	(36423),
	(36424),
	(36425),
	(36426),
	(36427),
	(36428),
	(36429),
	(36430),
	(36431),
	(36432),
	(36433),
	(36434),
	(36435),
	(36436),
	(36437),
	(36438),
	(36439),
	(36440),
	(36441),
	(36442),
	(36443),
	(36444),
	(36445),
	(36446),
	(36447),
	(36448),
	(36449),
	(36450),
	(36451),
	(36452),
	(36453),
	(36454),
	(36455),
	(36456),
	(36457),
	(36458),
	(36459),
	(36460),
	(36461),
	(36462),
	(36463),
	(36464),
	(36465),
	(36466),
	(36467),
	(36468),
	(36469),
	(36470),
	(36471),
	(36472),
	(36473),
	(36474),
	(36475),
	(36476),
	(36477),
	(36478),
	(36479),
	(36480),
	(36481),
	(36482),
	(36483),
	(36484),
	(36485),
	(36486),
	(36487),
	(36488),
	(36489),
	(36490),
	(36491),
	(36492),
	(36493),
	(36494),
	(36495),
	(36496),
	(36497),
	(36498),
	(36499),
	(36500),
	(36501),
	(36502),
	(36503),
	(36504),
	(36505),
	(36506),
	(36507),
	(36508),
	(36509),
	(36510),
	(36511),
	(36512),
	(36513),
	(36514),
	(36515),
	(36516),
	(36517),
	(36518),
	(36519),
	(36520),
	(36521),
	(36522),
	(36523),
	(36524),
	(36525),
	(36526),
	(36527),
	(36528),
	(36529),
	(36530),
	(36531),
	(36532),
	(36533),
	(36534),
	(36535),
	(36536),
	(36537),
	(36538),
	(36539),
	(36540),
	(36541),
	(36542),
	(36543),
	(36544),
	(36545),
	(36546),
	(36547),
	(36548),
	(36549),
	(36550),
	(36551),
	(36552),
	(36553),
	(36554),
	(36555),
	(36556),
	(36557),
	(36558),
	(36559),
	(36560),
	(36561),
	(36562),
	(36563),
	(36564),
	(36565),
	(36566),
	(36567),
	(36568),
	(36569),
	(36570),
	(36571),
	(36572),
	(36573),
	(36574),
	(36575),
	(36576),
	(36577),
	(36578),
	(36579),
	(36580),
	(36581),
	(36582),
	(36583),
	(36584),
	(36585),
	(36586),
	(36587),
	(36588),
	(36589),
	(36590),
	(36591),
	(36592),
	(36593),
	(36594),
	(36595),
	(36596),
	(36597),
	(36598),
	(36599),
	(36600),
	(36601),
	(36602),
	(36603),
	(36604),
	(36605),
	(36606),
	(36607),
	(36608),
	(36609),
	(36610),
	(36611),
	(36612),
	(36613),
	(36614),
	(36615),
	(36616),
	(36617),
	(36618),
	(36619),
	(36620),
	(36621),
	(36622),
	(36623),
	(36624),
	(36625),
	(36626),
	(36627),
	(36628),
	(36629),
	(36630),
	(36631),
	(36632),
	(36633),
	(36634),
	(36635),
	(36636),
	(36637),
	(36638),
	(36639),
	(36640),
	(36641),
	(36642),
	(36643),
	(36644),
	(36645),
	(36646),
	(36647),
	(36648),
	(36649),
	(36650),
	(36651),
	(36652),
	(36653),
	(36654),
	(36655),
	(36656),
	(36657),
	(36658),
	(36659),
	(36660),
	(36661),
	(36662),
	(36663),
	(36664),
	(36665),
	(36666),
	(36667),
	(36668),
	(36669),
	(36670),
	(36671),
	(36672),
	(36673),
	(36674),
	(36675),
	(36676),
	(36677),
	(36678),
	(36679),
	(36680),
	(36681),
	(36682),
	(36683),
	(36684),
	(36685),
	(36686),
	(36687),
	(36688),
	(36689),
	(36690),
	(36691),
	(36692),
	(36693),
	(36694),
	(36695),
	(36696),
	(36697),
	(36698),
	(36699),
	(36700),
	(36701),
	(36702),
	(36703),
	(36704),
	(36705),
	(36706),
	(36707),
	(36708),
	(36709),
	(36710),
	(36711),
	(36712),
	(36713),
	(36714),
	(36715),
	(36716),
	(36717),
	(36718),
	(36719),
	(36720),
	(36721),
	(36722),
	(36723),
	(36724),
	(36725),
	(36726),
	(36727),
	(36728),
	(36729),
	(36730),
	(36731),
	(36732),
	(36733),
	(36734),
	(36735),
	(36736),
	(36737),
	(36738),
	(36739),
	(36740),
	(36741),
	(36742),
	(36743),
	(36744),
	(36745),
	(36746),
	(36747),
	(36748),
	(36749),
	(36750),
	(36751),
	(36752),
	(36753),
	(36754),
	(36755),
	(36756),
	(36757),
	(36758),
	(36759),
	(36760),
	(36761),
	(36762),
	(36763),
	(36764),
	(36765),
	(36766),
	(36767),
	(36768),
	(36769),
	(36770),
	(36771),
	(36772),
	(36773),
	(36774),
	(36775),
	(36776),
	(36777),
	(36778),
	(36779),
	(36780),
	(36781),
	(36782),
	(36783),
	(36784),
	(36785),
	(36786),
	(36787),
	(36788),
	(36789),
	(36790),
	(36791),
	(36792),
	(36793),
	(36794),
	(36795),
	(36796),
	(36797),
	(36798),
	(36799),
	(36800),
	(36801),
	(36802),
	(36803),
	(36804),
	(36805),
	(36806),
	(36807),
	(36808),
	(36809),
	(36810),
	(36811),
	(36812),
	(36813),
	(36814),
	(36815),
	(36816),
	(36817),
	(36818),
	(36819),
	(36820),
	(36821),
	(36822),
	(36823),
	(36824),
	(36825),
	(36826),
	(36827),
	(36828),
	(36829),
	(36830),
	(36831),
	(36832),
	(36833),
	(36834),
	(36835),
	(36836),
	(36837),
	(36838),
	(36839),
	(36840),
	(36841),
	(36842),
	(36843),
	(36844),
	(36845),
	(36846),
	(36847),
	(36848),
	(36849),
	(36850),
	(36851),
	(36852),
	(36853),
	(36854),
	(36855),
	(36856),
	(36857),
	(36858),
	(36859),
	(36860),
	(36861),
	(36862),
	(36863),
	(36864),
	(36865),
	(36866),
	(36867),
	(36868),
	(36869),
	(36870),
	(36871),
	(36872),
	(36873),
	(36874),
	(36875),
	(36876),
	(36877),
	(36878),
	(36879),
	(36880),
	(36881),
	(36882),
	(36883),
	(36884),
	(36885),
	(36886),
	(36887),
	(36888),
	(36889),
	(36890),
	(36891),
	(36892),
	(36893),
	(36894),
	(36895),
	(36896),
	(36897),
	(36898),
	(36899),
	(36900),
	(36901),
	(36902),
	(36903),
	(36904),
	(36905),
	(36906),
	(36907),
	(36908),
	(36909),
	(36910),
	(36911),
	(36912),
	(36913),
	(36914),
	(36915),
	(36916),
	(36917),
	(36918),
	(36919),
	(36920),
	(36921),
	(36922),
	(36923),
	(36924),
	(36925),
	(36926),
	(36927),
	(36928),
	(36929),
	(36930),
	(36931),
	(36932),
	(36933),
	(36934),
	(36935),
	(36936),
	(36937),
	(36938),
	(36939),
	(36940),
	(36941),
	(36942),
	(36943),
	(36944),
	(36945),
	(36946),
	(36947),
	(36948),
	(36949),
	(36950),
	(36951),
	(36952),
	(36953),
	(36954),
	(36955),
	(36956),
	(36957),
	(36958),
	(36959),
	(36960),
	(36961),
	(36962),
	(36963),
	(36964),
	(36965),
	(36966),
	(36967),
	(36968),
	(36969),
	(36970),
	(36971),
	(36972),
	(36973),
	(36974),
	(36975),
	(36976),
	(36977),
	(36978),
	(36979),
	(36980),
	(36981),
	(36982),
	(36983),
	(36984),
	(36985),
	(36986),
	(36987),
	(36988),
	(36989),
	(36990),
	(36991),
	(36992),
	(36993),
	(36994),
	(36995),
	(36996),
	(36997),
	(36998),
	(36999),
	(37000),
	(37001),
	(37002),
	(37003),
	(37004),
	(37005),
	(37006),
	(37007),
	(37008),
	(37009),
	(37010),
	(37011),
	(37012),
	(37013),
	(37014),
	(37015),
	(37016),
	(37017),
	(37018),
	(37019),
	(37020),
	(37021),
	(37022),
	(37023),
	(37024),
	(37025),
	(37026),
	(37027),
	(37028),
	(37029),
	(37030),
	(37031),
	(37032),
	(37033),
	(37034),
	(37035),
	(37036),
	(37037),
	(37038),
	(37039),
	(37040),
	(37041),
	(37042),
	(37043),
	(37044),
	(37045),
	(37046),
	(37047),
	(37048),
	(37049),
	(37050),
	(37051),
	(37052),
	(37053),
	(37054),
	(37055),
	(37056),
	(37057),
	(37058),
	(37059),
	(37060),
	(37061),
	(37062),
	(37063),
	(37064),
	(37065),
	(37066),
	(37067),
	(37068),
	(37069),
	(37070),
	(37071),
	(37072),
	(37073),
	(37074),
	(37075),
	(37076),
	(37077),
	(37078),
	(37079),
	(37080),
	(37081),
	(37082),
	(37083),
	(37084),
	(37085),
	(37086),
	(37087),
	(37088),
	(37089),
	(37090),
	(37091),
	(37092),
	(37093),
	(37094),
	(37095),
	(37096),
	(37097),
	(37098),
	(37099),
	(37100),
	(37101),
	(37102),
	(37103),
	(37104),
	(37105),
	(37106),
	(37107),
	(37108),
	(37109),
	(37110),
	(37111),
	(37112),
	(37113),
	(37114),
	(37115),
	(37116),
	(37117),
	(37118),
	(37119),
	(37120),
	(37121),
	(37122),
	(37123),
	(37124),
	(37125),
	(37126),
	(37127),
	(37128),
	(37129),
	(37130),
	(37131),
	(37132),
	(37133),
	(37134),
	(37135),
	(37136),
	(37137),
	(37138),
	(37139),
	(37140),
	(37141),
	(37142),
	(37143),
	(37144),
	(37145),
	(37146),
	(37147),
	(37148),
	(37149),
	(37150),
	(37151),
	(37152),
	(37153),
	(37154),
	(37155),
	(37156),
	(37157),
	(37158),
	(37159),
	(37160),
	(37161),
	(37162),
	(37163),
	(37164),
	(37165),
	(37166),
	(37167),
	(37168),
	(37169),
	(37170),
	(37171),
	(37172),
	(37173),
	(37174),
	(37175),
	(37176),
	(37177),
	(37178),
	(37179),
	(37180),
	(37181),
	(37182),
	(37183),
	(37184),
	(37185),
	(37186),
	(37187),
	(37188),
	(37189),
	(37190),
	(37191),
	(37192),
	(37193),
	(37194),
	(37195),
	(37196),
	(37197),
	(37198),
	(37199),
	(37200),
	(37201),
	(37202),
	(37203),
	(37204),
	(37205),
	(37206),
	(37207),
	(37208),
	(37209),
	(37210),
	(37211),
	(37212),
	(37213),
	(37214),
	(37215),
	(37216),
	(37217),
	(37218),
	(37219),
	(37220),
	(37221),
	(37222),
	(37223),
	(37224),
	(37225),
	(37226),
	(37227),
	(37228),
	(37229),
	(37230),
	(37231),
	(37232),
	(37233),
	(37234),
	(37235),
	(37236),
	(37237),
	(37238),
	(37239),
	(37240),
	(37241),
	(37242),
	(37243),
	(37244),
	(37245),
	(37246),
	(37247),
	(37248),
	(37249),
	(37250),
	(37251),
	(37252),
	(37253),
	(37254),
	(37255),
	(37256),
	(37257),
	(37258),
	(37259),
	(37260),
	(37261),
	(37262),
	(37263),
	(37264),
	(37265),
	(37266),
	(37267),
	(37268),
	(37269),
	(37270),
	(37271),
	(37272),
	(37273),
	(37274),
	(37275),
	(37276),
	(37277),
	(37278),
	(37279),
	(37280),
	(37281),
	(37282),
	(37283),
	(37284),
	(37285),
	(37286),
	(37287),
	(37288),
	(37289),
	(37290),
	(37291),
	(37292),
	(37293),
	(37294),
	(37295),
	(37296),
	(37297),
	(37298),
	(37299),
	(37300),
	(37301),
	(37302),
	(37303),
	(37304),
	(37305),
	(37306),
	(37307),
	(37308),
	(37309),
	(37310),
	(37311),
	(37312),
	(37313),
	(37314),
	(37315),
	(37316),
	(37317),
	(37318),
	(37319),
	(37320),
	(37321),
	(37322),
	(37323),
	(37324),
	(37325),
	(37326),
	(37327),
	(37328),
	(37329),
	(37330),
	(37331),
	(37332),
	(37333),
	(37334),
	(37335),
	(37336),
	(37337),
	(37338),
	(37339),
	(37340),
	(37341),
	(37342),
	(37343),
	(37344),
	(37345),
	(37346),
	(37347),
	(37348),
	(37349),
	(37350),
	(37351),
	(37352),
	(37353),
	(37354),
	(37355),
	(37356),
	(37357),
	(37358),
	(37359),
	(37360),
	(37361),
	(37362),
	(37363),
	(37364),
	(37365),
	(37366),
	(37367),
	(37368),
	(37369),
	(37370),
	(37371),
	(37372),
	(37373),
	(37374),
	(37375),
	(37376),
	(37377),
	(37378),
	(37379),
	(37380),
	(37381),
	(37382),
	(37383),
	(37384),
	(37385),
	(37386),
	(37387),
	(37388),
	(37389),
	(37390),
	(37391),
	(37392),
	(37393),
	(37394),
	(37395),
	(37396),
	(37397),
	(37398),
	(37399),
	(37400),
	(37401),
	(37402),
	(37403),
	(37404),
	(37405),
	(37406),
	(37407),
	(37408),
	(37409),
	(37410),
	(37411),
	(37412),
	(37413),
	(37414),
	(37415),
	(37416),
	(37417),
	(37418),
	(37419),
	(37420),
	(37421),
	(37422),
	(37423),
	(37424),
	(37425),
	(37426),
	(37427),
	(37428),
	(37429),
	(37430),
	(37431),
	(37432),
	(37433),
	(37434),
	(37435),
	(37436),
	(37437),
	(37438),
	(37439),
	(37440),
	(37441),
	(37442),
	(37443),
	(37444),
	(37445),
	(37446),
	(37447),
	(37448),
	(37449),
	(37450),
	(37451),
	(37452),
	(37453),
	(37454),
	(37455),
	(37456),
	(37457),
	(37458),
	(37459),
	(37460),
	(37461),
	(37462),
	(37463),
	(37464),
	(37465),
	(37466),
	(37467),
	(37468),
	(37469),
	(37470),
	(37471),
	(37472),
	(37473),
	(37474),
	(37475),
	(37476),
	(37477),
	(37478),
	(37479),
	(37480),
	(37481),
	(37482),
	(37483),
	(37484),
	(37485),
	(37486),
	(37487),
	(37488),
	(37489),
	(37490),
	(37491),
	(37492),
	(37493),
	(37494),
	(37495),
	(37496),
	(37497),
	(37498),
	(37499),
	(37500),
	(37501),
	(37502),
	(37503),
	(37504),
	(37505),
	(37506),
	(37507),
	(37508),
	(37509),
	(37510),
	(37511),
	(37512),
	(37513),
	(37514),
	(37515),
	(37516),
	(37517),
	(37518),
	(37519),
	(37520),
	(37521),
	(37522),
	(37523),
	(37524),
	(37525),
	(37526),
	(37527),
	(37528),
	(37529),
	(37530),
	(37531),
	(37532),
	(37533),
	(37534),
	(37535),
	(37536),
	(37537),
	(37538),
	(37539),
	(37540),
	(37541),
	(37542),
	(37543),
	(37544),
	(37545),
	(37546),
	(37547),
	(37548),
	(37549),
	(37550),
	(37551),
	(37552),
	(37553),
	(37554),
	(37555),
	(37556),
	(37557),
	(37558),
	(37559),
	(37560),
	(37561),
	(37562),
	(37563),
	(37564),
	(37565),
	(37566),
	(37567),
	(37568),
	(37569),
	(37570),
	(37571),
	(37572),
	(37573),
	(37574),
	(37575),
	(37576),
	(37577),
	(37578),
	(37579),
	(37580),
	(37581),
	(37582),
	(37583),
	(37584),
	(37585),
	(37586),
	(37587),
	(37588),
	(37589),
	(37590),
	(37591),
	(37592),
	(37593),
	(37594),
	(37595),
	(37596),
	(37597),
	(37598),
	(37599),
	(37600),
	(37601),
	(37602),
	(37603),
	(37604),
	(37605),
	(37606),
	(37607),
	(37608),
	(37609),
	(37610),
	(37611),
	(37612),
	(37613),
	(37614),
	(37615),
	(37616),
	(37617),
	(37618),
	(37619),
	(37620),
	(37621),
	(37622),
	(37623),
	(37624),
	(37625),
	(37626),
	(37627),
	(37628),
	(37629),
	(37630),
	(37631),
	(37632),
	(37633),
	(37634),
	(37635),
	(37636),
	(37637),
	(37638),
	(37639),
	(37640),
	(37641),
	(37642),
	(37643),
	(37644),
	(37645),
	(37646),
	(37647),
	(37648),
	(37649),
	(37650),
	(37651),
	(37652),
	(37653),
	(37654),
	(37655),
	(37656),
	(37657),
	(37658),
	(37659),
	(37660),
	(37661),
	(37662),
	(37663),
	(37664),
	(37665),
	(37666),
	(37667),
	(37668),
	(37669),
	(37670),
	(37671),
	(37672),
	(37673),
	(37674),
	(37675),
	(37676),
	(37677),
	(37678),
	(37679),
	(37680),
	(37681),
	(37682),
	(37683),
	(37684),
	(37685),
	(37686),
	(37687),
	(37688),
	(37689),
	(37690),
	(37691),
	(37692),
	(37693),
	(37694),
	(37695),
	(37696),
	(37697),
	(37698),
	(37699),
	(37700),
	(37701),
	(37702),
	(37703),
	(37704),
	(37705),
	(37706),
	(37707),
	(37708),
	(37709),
	(37710),
	(37711),
	(37712),
	(37713),
	(37714),
	(37715),
	(37716),
	(37717),
	(37718),
	(37719),
	(37720),
	(37721),
	(37722),
	(37723),
	(37724),
	(37725),
	(37726),
	(37727),
	(37728),
	(37729),
	(37730),
	(37731),
	(37732),
	(37733),
	(37734),
	(37735),
	(37736),
	(37737),
	(37738),
	(37739),
	(37740),
	(37741),
	(37742),
	(37743),
	(37744),
	(37745),
	(37746),
	(37747),
	(37748),
	(37749),
	(37750),
	(37751),
	(37752),
	(37753),
	(37754),
	(37755),
	(37756),
	(37757),
	(37758),
	(37759),
	(37760),
	(37761),
	(37762),
	(37763),
	(37764),
	(37765),
	(37766),
	(37767),
	(37768),
	(37769),
	(37770),
	(37771),
	(37772),
	(37773),
	(37774),
	(37775),
	(37776),
	(37777),
	(37778),
	(37779),
	(37780),
	(37781),
	(37782),
	(37783),
	(37784),
	(37785),
	(37786),
	(37787),
	(37788),
	(37789),
	(37790),
	(37791),
	(37792),
	(37793),
	(37794),
	(37795),
	(37796),
	(37797),
	(37798),
	(37799),
	(37800),
	(37801),
	(37802),
	(37803),
	(37804),
	(37805),
	(37806),
	(37807),
	(37808),
	(37809),
	(37810),
	(37811),
	(37812),
	(37813),
	(37814),
	(37815),
	(37816),
	(37817),
	(37818),
	(37819),
	(37820),
	(37821),
	(37822),
	(37823),
	(37824),
	(37825),
	(37826),
	(37827),
	(37828),
	(37829),
	(37830),
	(37831),
	(37832),
	(37833),
	(37834),
	(37835),
	(37836),
	(37837),
	(37838),
	(37839),
	(37840),
	(37841),
	(37842),
	(37843),
	(37844),
	(37845),
	(37846),
	(37847),
	(37848),
	(37849),
	(37850),
	(37851),
	(37852),
	(37853),
	(37854),
	(37855),
	(37856),
	(37857),
	(37858),
	(37859),
	(37860),
	(37861),
	(37862),
	(37863),
	(37864),
	(37865),
	(37866),
	(37867),
	(37868),
	(37869),
	(37870),
	(37871),
	(37872),
	(37873),
	(37874),
	(37875),
	(37876),
	(37877),
	(37878),
	(37879),
	(37880),
	(37881),
	(37882),
	(37883),
	(37884),
	(37885),
	(37886),
	(37887),
	(37888),
	(37889),
	(37890),
	(37891),
	(37892),
	(37893),
	(37894),
	(37895),
	(37896),
	(37897),
	(37898),
	(37899),
	(37900),
	(37901),
	(37902),
	(37903),
	(37904),
	(37905),
	(37906),
	(37907),
	(37908),
	(37909),
	(37910),
	(37911),
	(37912),
	(37913),
	(37914),
	(37915),
	(37916),
	(37917),
	(37918),
	(37919),
	(37920),
	(37921),
	(37922),
	(37923),
	(37924),
	(37925),
	(37926),
	(37927),
	(37928),
	(37929),
	(37930),
	(37931),
	(37932),
	(37933),
	(37934),
	(37935),
	(37936),
	(37937),
	(37938),
	(37939),
	(37940),
	(37941),
	(37942),
	(37943),
	(37944),
	(37945),
	(37946),
	(37947),
	(37948),
	(37949),
	(37950),
	(37951),
	(37952),
	(37953),
	(37954),
	(37955),
	(37956),
	(37957),
	(37958),
	(37959),
	(37960),
	(37961),
	(37962),
	(37963),
	(37964),
	(37965),
	(37966),
	(37967),
	(37968),
	(37969),
	(37970),
	(37971),
	(37972),
	(37973),
	(37974),
	(37975),
	(37976),
	(37977),
	(37978),
	(37979),
	(37980),
	(37981),
	(37982),
	(37983),
	(37984),
	(37985),
	(37986),
	(37987),
	(37988),
	(37989),
	(37990),
	(37991),
	(37992),
	(37993),
	(37994),
	(37995),
	(37996),
	(37997),
	(37998),
	(37999),
	(38000),
	(38001),
	(38002),
	(38003),
	(38004),
	(38005),
	(38006),
	(38007),
	(38008),
	(38009),
	(38010),
	(38011),
	(38012),
	(38013),
	(38014),
	(38015),
	(38016),
	(38017),
	(38018),
	(38019),
	(38020),
	(38021),
	(38022),
	(38023),
	(38024),
	(38025),
	(38026),
	(38027),
	(38028),
	(38029),
	(38030),
	(38031),
	(38032),
	(38033),
	(38034),
	(38035),
	(38036),
	(38037),
	(38038),
	(38039),
	(38040),
	(38041),
	(38042),
	(38043),
	(38044),
	(38045),
	(38046),
	(38047),
	(38048),
	(38049),
	(38050),
	(38051),
	(38052),
	(38053),
	(38054),
	(38055),
	(38056),
	(38057),
	(38058),
	(38059),
	(38060),
	(38061),
	(38062),
	(38063),
	(38064),
	(38065),
	(38066),
	(38067),
	(38068),
	(38069),
	(38070),
	(38071),
	(38072),
	(38073),
	(38074),
	(38075),
	(38076),
	(38077),
	(38078),
	(38079),
	(38080),
	(38081),
	(38082),
	(38083),
	(38084),
	(38085),
	(38086),
	(38087),
	(38088),
	(38089),
	(38090),
	(38091),
	(38092),
	(38093),
	(38094),
	(38095),
	(38096),
	(38097),
	(38098),
	(38099),
	(38100),
	(38101),
	(38102),
	(38103),
	(38104),
	(38105),
	(38106),
	(38107),
	(38108),
	(38109),
	(38110),
	(38111),
	(38112),
	(38113),
	(38114),
	(38115),
	(38116),
	(38117),
	(38118),
	(38119),
	(38120),
	(38121),
	(38122),
	(38123),
	(38124),
	(38125),
	(38126),
	(38127),
	(38128),
	(38129),
	(38130),
	(38131),
	(38132),
	(38133),
	(38134),
	(38135),
	(38136),
	(38137),
	(38138),
	(38139),
	(38140),
	(38141),
	(38142),
	(38143),
	(38144),
	(38145),
	(38146),
	(38147),
	(38148),
	(38149),
	(38150),
	(38151),
	(38152),
	(38153),
	(38154),
	(38155),
	(38156),
	(38157),
	(38158),
	(38159),
	(38160),
	(38161),
	(38162),
	(38163),
	(38164),
	(38165),
	(38166),
	(38167),
	(38168),
	(38169),
	(38170),
	(38171),
	(38172),
	(38173),
	(38174),
	(38175),
	(38176),
	(38177),
	(38178),
	(38179),
	(38180),
	(38181),
	(38182),
	(38183),
	(38184),
	(38185),
	(38186),
	(38187),
	(38188),
	(38189),
	(38190),
	(38191),
	(38192),
	(38193),
	(38194),
	(38195),
	(38196),
	(38197),
	(38198),
	(38199),
	(38200),
	(38201),
	(38202),
	(38203),
	(38204),
	(38205),
	(38206),
	(38207),
	(38208),
	(38209),
	(38210),
	(38211),
	(38212),
	(38213),
	(38214),
	(38215),
	(38216),
	(38217),
	(38218),
	(38219),
	(38220),
	(38221),
	(38222),
	(38223),
	(38224),
	(38225),
	(38226),
	(38227),
	(38228),
	(38229),
	(38230),
	(38231),
	(38232),
	(38233),
	(38234),
	(38235),
	(38236),
	(38237),
	(38238),
	(38239),
	(38240),
	(38241),
	(38242),
	(38243),
	(38244),
	(38245),
	(38246),
	(38247),
	(38248),
	(38249),
	(38250),
	(38251),
	(38252),
	(38253),
	(38254),
	(38255),
	(38256),
	(38257),
	(38258),
	(38259),
	(38260),
	(38261),
	(38262),
	(38263),
	(38264),
	(38265),
	(38266),
	(38267),
	(38268),
	(38269),
	(38270),
	(38271),
	(38272),
	(38273),
	(38274),
	(38275),
	(38276),
	(38277),
	(38278),
	(38279),
	(38280),
	(38281),
	(38282),
	(38283),
	(38284),
	(38285),
	(38286),
	(38287),
	(38288),
	(38289),
	(38290),
	(38291),
	(38292),
	(38293),
	(38294),
	(38295),
	(38296),
	(38297),
	(38298),
	(38299),
	(38300),
	(38301),
	(38302),
	(38303),
	(38304),
	(38305),
	(38306),
	(38307),
	(38308),
	(38309),
	(38310),
	(38311),
	(38312),
	(38313),
	(38314),
	(38315),
	(38316),
	(38317),
	(38318),
	(38319),
	(38320),
	(38321),
	(38322),
	(38323),
	(38324),
	(38325),
	(38326),
	(38327),
	(38328),
	(38329),
	(38330),
	(38331),
	(38332),
	(38333),
	(38334),
	(38335),
	(38336),
	(38337),
	(38338),
	(38339),
	(38340),
	(38341),
	(38342),
	(38343),
	(38344),
	(38345),
	(38346),
	(38347),
	(38348),
	(38349),
	(38350),
	(38351),
	(38352),
	(38353),
	(38354),
	(38355),
	(38356),
	(38357),
	(38358),
	(38359),
	(38360),
	(38361),
	(38362),
	(38363),
	(38364),
	(38365),
	(38366),
	(38367),
	(38368),
	(38369),
	(38370),
	(38371),
	(38372),
	(38373),
	(38374),
	(38375),
	(38376),
	(38377),
	(38378),
	(38379),
	(38380),
	(38381),
	(38382),
	(38383),
	(38384),
	(38385),
	(38386),
	(38387),
	(38388),
	(38389),
	(38390),
	(38391),
	(38392),
	(38393),
	(38394),
	(38395),
	(38396),
	(38397),
	(38398),
	(38399),
	(38400),
	(38401),
	(38402),
	(38403),
	(38404),
	(38405),
	(38406),
	(38407),
	(38408),
	(38409),
	(38410),
	(38411),
	(38412),
	(38413),
	(38414),
	(38415),
	(38416),
	(38417),
	(38418),
	(38419),
	(38420),
	(38421),
	(38422),
	(38423),
	(38424),
	(38425),
	(38426),
	(38427),
	(38428),
	(38429),
	(38430),
	(38431),
	(38432),
	(38433),
	(38434),
	(38435),
	(38436),
	(38437),
	(38438),
	(38439),
	(38440),
	(38441),
	(38442),
	(38443),
	(38444),
	(38445),
	(38446),
	(38447),
	(38448),
	(38449),
	(38450),
	(38451),
	(38452),
	(38453),
	(38454),
	(38455),
	(38456),
	(38457),
	(38458),
	(38459),
	(38460),
	(38461),
	(38462),
	(38463),
	(38464),
	(38465),
	(38466),
	(38467),
	(38468),
	(38469),
	(38470),
	(38471),
	(38472),
	(38473),
	(38474),
	(38475),
	(38476),
	(38477),
	(38478),
	(38479),
	(38480),
	(38481),
	(38482),
	(38483),
	(38484),
	(38485),
	(38486),
	(38487),
	(38488),
	(38489),
	(38490),
	(38491),
	(38492),
	(38493),
	(38494),
	(38495),
	(38496),
	(38497),
	(38498),
	(38499),
	(38500),
	(38501),
	(38502),
	(38503),
	(38504),
	(38505),
	(38506),
	(38507),
	(38508),
	(38509),
	(38510),
	(38511),
	(38512),
	(38513),
	(38514),
	(38515),
	(38516),
	(38517),
	(38518),
	(38519),
	(38520),
	(38521),
	(38522),
	(38523),
	(38524),
	(38525),
	(38526),
	(38527),
	(38528),
	(38529),
	(38530),
	(38531),
	(38532),
	(38533),
	(38534),
	(38535),
	(38536),
	(38537),
	(38538),
	(38539),
	(38540),
	(38541),
	(38542),
	(38543),
	(38544),
	(38545),
	(38546),
	(38547),
	(38548),
	(38549),
	(38550),
	(38551),
	(38552),
	(38553),
	(38554),
	(38555),
	(38556),
	(38557),
	(38558),
	(38559),
	(38560),
	(38561),
	(38562),
	(38563),
	(38564),
	(38565),
	(38566),
	(38567),
	(38568),
	(38569),
	(38570),
	(38571),
	(38572),
	(38573),
	(38574),
	(38575),
	(38576),
	(38577),
	(38578),
	(38579),
	(38580),
	(38581),
	(38582),
	(38583),
	(38584),
	(38585),
	(38586),
	(38587),
	(38588),
	(38589),
	(38590),
	(38591),
	(38592),
	(38593),
	(38594),
	(38595),
	(38596),
	(38597),
	(38598),
	(38599),
	(38600),
	(38601),
	(38602),
	(38603),
	(38604),
	(38605),
	(38606),
	(38607),
	(38608),
	(38609),
	(38610),
	(38611),
	(38612),
	(38613),
	(38614),
	(38615),
	(38616),
	(38617),
	(38618),
	(38619),
	(38620),
	(38621),
	(38622),
	(38623),
	(38624),
	(38625),
	(38626),
	(38627),
	(38628),
	(38629),
	(38630),
	(38631),
	(38632),
	(38633),
	(38634),
	(38635),
	(38636),
	(38637),
	(38638),
	(38639),
	(38640),
	(38641),
	(38642),
	(38643),
	(38644),
	(38645),
	(38646),
	(38647),
	(38648),
	(38649),
	(38650),
	(38651),
	(38652),
	(38653),
	(38654),
	(38655),
	(38656),
	(38657),
	(38658),
	(38659),
	(38660),
	(38661),
	(38662),
	(38663),
	(38664),
	(38665),
	(38666),
	(38667),
	(38668),
	(38669),
	(38670),
	(38671),
	(38672),
	(38673),
	(38674),
	(38675),
	(38676),
	(38677),
	(38678),
	(38679),
	(38680),
	(38681),
	(38682),
	(38683),
	(38684),
	(38685),
	(38686),
	(38687),
	(38688),
	(38689),
	(38690),
	(38691),
	(38692),
	(38693),
	(38694),
	(38695),
	(38696),
	(38697),
	(38698),
	(38699),
	(38700),
	(38701),
	(38702),
	(38703),
	(38704),
	(38705),
	(38706),
	(38707),
	(38708),
	(38709),
	(38710),
	(38711),
	(38712),
	(38713),
	(38714),
	(38715),
	(38716),
	(38717),
	(38718),
	(38719),
	(38720),
	(38721),
	(38722),
	(38723),
	(38724),
	(38725),
	(38726),
	(38727),
	(38728),
	(38729),
	(38730),
	(38731),
	(38732),
	(38733),
	(38734),
	(38735),
	(38736),
	(38737),
	(38738),
	(38739),
	(38740),
	(38741),
	(38742),
	(38743),
	(38744),
	(38745),
	(38746),
	(38747),
	(38748),
	(38749),
	(38750),
	(38751),
	(38752),
	(38753),
	(38754),
	(38755),
	(38756),
	(38757),
	(38758),
	(38759),
	(38760),
	(38761),
	(38762),
	(38763),
	(38764),
	(38765),
	(38766),
	(38767),
	(38768),
	(38769),
	(38770),
	(38771),
	(38772),
	(38773),
	(38774),
	(38775),
	(38776),
	(38777),
	(38778),
	(38779),
	(38780),
	(38781),
	(38782),
	(38783),
	(38784),
	(38785),
	(38786),
	(38787),
	(38788),
	(38789),
	(38790),
	(38791),
	(38792),
	(38793),
	(38794),
	(38795),
	(38796),
	(38797),
	(38798),
	(38799),
	(38800),
	(38801),
	(38802),
	(38803),
	(38804),
	(38805),
	(38806),
	(38807),
	(38808),
	(38809),
	(38810),
	(38811),
	(38812),
	(38813),
	(38814),
	(38815),
	(38816),
	(38817),
	(38818),
	(38819),
	(38820),
	(38821),
	(38822),
	(38823),
	(38824),
	(38825),
	(38826),
	(38827),
	(38828),
	(38829),
	(38830),
	(38831),
	(38832),
	(38833),
	(38834),
	(38835),
	(38836),
	(38837),
	(38838),
	(38839),
	(38840),
	(38841),
	(38842),
	(38843),
	(38844),
	(38845),
	(38846),
	(38847),
	(38848),
	(38849),
	(38850),
	(38851),
	(38852),
	(38853),
	(38854),
	(38855),
	(38856),
	(38857),
	(38858),
	(38859),
	(38860),
	(38861),
	(38862),
	(38863),
	(38864),
	(38865),
	(38866),
	(38867),
	(38868),
	(38869),
	(38870),
	(38871),
	(38872),
	(38873),
	(38874),
	(38875),
	(38876),
	(38877),
	(38878),
	(38879),
	(38880),
	(38881),
	(38882),
	(38883),
	(38884),
	(38885),
	(38886),
	(38887),
	(38888),
	(38889),
	(38890),
	(38891),
	(38892),
	(38893),
	(38894),
	(38895),
	(38896),
	(38897),
	(38898),
	(38899),
	(38900),
	(38901),
	(38902),
	(38903),
	(38904),
	(38905),
	(38906),
	(38907),
	(38908),
	(38909),
	(38910),
	(38911),
	(38912),
	(38913),
	(38914),
	(38915),
	(38916),
	(38917),
	(38918),
	(38919),
	(38920),
	(38921),
	(38922),
	(38923),
	(38924),
	(38925),
	(38926),
	(38927),
	(38928),
	(38929),
	(38930),
	(38931),
	(38932),
	(38933),
	(38934),
	(38935),
	(38936),
	(38937),
	(38938),
	(38939),
	(38940),
	(38941),
	(38942),
	(38943),
	(38944),
	(38945),
	(38946),
	(38947),
	(38948),
	(38949),
	(38950),
	(38951),
	(38952),
	(38953),
	(38954),
	(38955),
	(38956),
	(38957),
	(38958),
	(38959),
	(38960),
	(38961),
	(38962),
	(38963),
	(38964),
	(38965),
	(38966),
	(38967),
	(38968),
	(38969),
	(38970),
	(38971),
	(38972),
	(38973),
	(38974),
	(38975),
	(38976),
	(38977),
	(38978),
	(38979),
	(38980),
	(38981),
	(38982),
	(38983),
	(38984),
	(38985),
	(38986),
	(38987),
	(38988),
	(38989),
	(38990),
	(38991),
	(38992),
	(38993),
	(38994),
	(38995),
	(38996),
	(38997),
	(38998),
	(38999),
	(39000),
	(39001),
	(39002),
	(39003),
	(39004),
	(39005),
	(39006),
	(39007),
	(39008),
	(39009),
	(39010),
	(39011),
	(39012),
	(39013),
	(39014),
	(39015),
	(39016),
	(39017),
	(39018),
	(39019),
	(39020),
	(39021),
	(39022),
	(39023),
	(39024),
	(39025),
	(39026),
	(39027),
	(39028),
	(39029),
	(39030),
	(39031),
	(39032),
	(39033),
	(39034),
	(39035),
	(39036),
	(39037),
	(39038),
	(39039),
	(39040),
	(39041),
	(39042),
	(39043),
	(39044),
	(39045),
	(39046),
	(39047),
	(39048),
	(39049),
	(39050),
	(39051),
	(39052),
	(39053),
	(39054),
	(39055),
	(39056),
	(39057),
	(39058),
	(39059),
	(39060),
	(39061),
	(39062),
	(39063),
	(39064),
	(39065),
	(39066),
	(39067),
	(39068),
	(39069),
	(39070),
	(39071),
	(39072),
	(39073),
	(39074),
	(39075),
	(39076),
	(39077),
	(39078),
	(39079),
	(39080),
	(39081),
	(39082),
	(39083),
	(39084),
	(39085),
	(39086),
	(39087),
	(39088),
	(39089),
	(39090),
	(39091),
	(39092),
	(39093),
	(39094),
	(39095),
	(39096),
	(39097),
	(39098),
	(39099),
	(39100),
	(39101),
	(39102),
	(39103),
	(39104),
	(39105),
	(39106),
	(39107),
	(39108),
	(39109),
	(39110),
	(39111),
	(39112),
	(39113),
	(39114),
	(39115),
	(39116),
	(39117),
	(39118),
	(39119),
	(39120),
	(39121),
	(39122),
	(39123),
	(39124),
	(39125),
	(39126),
	(39127),
	(39128),
	(39129),
	(39130),
	(39131),
	(39132),
	(39133),
	(39134),
	(39135),
	(39136),
	(39137),
	(39138),
	(39139),
	(39140),
	(39141),
	(39142),
	(39143),
	(39144),
	(39145),
	(39146),
	(39147),
	(39148),
	(39149),
	(39150),
	(39151),
	(39152),
	(39153),
	(39154),
	(39155),
	(39156),
	(39157),
	(39158),
	(39159),
	(39160),
	(39161),
	(39162),
	(39163),
	(39164),
	(39165),
	(39166),
	(39167),
	(39168),
	(39169),
	(39170),
	(39171),
	(39172),
	(39173),
	(39174),
	(39175),
	(39176),
	(39177),
	(39178),
	(39179),
	(39180),
	(39181),
	(39182),
	(39183),
	(39184),
	(39185),
	(39186),
	(39187),
	(39188),
	(39189),
	(39190),
	(39191),
	(39192),
	(39193),
	(39194),
	(39195),
	(39196),
	(39197),
	(39198),
	(39199),
	(39200),
	(39201),
	(39202),
	(39203),
	(39204),
	(39205),
	(39206),
	(39207),
	(39208),
	(39209),
	(39210),
	(39211),
	(39212),
	(39213),
	(39214),
	(39215),
	(39216),
	(39217),
	(39218),
	(39219),
	(39220),
	(39221),
	(39222),
	(39223),
	(39224),
	(39225),
	(39226),
	(39227),
	(39228),
	(39229),
	(39230),
	(39231),
	(39232),
	(39233),
	(39234),
	(39235),
	(39236),
	(39237),
	(39238),
	(39239),
	(39240),
	(39241),
	(39242),
	(39243),
	(39244),
	(39245),
	(39246),
	(39247),
	(39248),
	(39249),
	(39250),
	(39251),
	(39252),
	(39253),
	(39254),
	(39255),
	(39256),
	(39257),
	(39258),
	(39259),
	(39260),
	(39261),
	(39262),
	(39263),
	(39264),
	(39265),
	(39266),
	(39267),
	(39268),
	(39269),
	(39270),
	(39271),
	(39272),
	(39273),
	(39274),
	(39275),
	(39276),
	(39277),
	(39278),
	(39279),
	(39280),
	(39281),
	(39282),
	(39283),
	(39284),
	(39285),
	(39286),
	(39287),
	(39288),
	(39289),
	(39290),
	(39291),
	(39292),
	(39293),
	(39294),
	(39295),
	(39296),
	(39297),
	(39298),
	(39299),
	(39300),
	(39301),
	(39302),
	(39303),
	(39304),
	(39305),
	(39306),
	(39307),
	(39308),
	(39309),
	(39310),
	(39311),
	(39312),
	(39313),
	(39314),
	(39315),
	(39316),
	(39317),
	(39318),
	(39319),
	(39320),
	(39321),
	(39322),
	(39323),
	(39324),
	(39325),
	(39326),
	(39327),
	(39328),
	(39329),
	(39330),
	(39331),
	(39332),
	(39333),
	(39334),
	(39335),
	(39336),
	(39337),
	(39338),
	(39339),
	(39340),
	(39341),
	(39342),
	(39343),
	(39344),
	(39345),
	(39346),
	(39347),
	(39348),
	(39349),
	(39350),
	(39351),
	(39352),
	(39353),
	(39354),
	(39355),
	(39356),
	(39357),
	(39358),
	(39359),
	(39360),
	(39361),
	(39362),
	(39363),
	(39364),
	(39365),
	(39366),
	(39367),
	(39368),
	(39369),
	(39370),
	(39371),
	(39372),
	(39373),
	(39374),
	(39375),
	(39376),
	(39377),
	(39378),
	(39379),
	(39380),
	(39381),
	(39382),
	(39383),
	(39384),
	(39385),
	(39386),
	(39387),
	(39388),
	(39389),
	(39390),
	(39391),
	(39392),
	(39393),
	(39394),
	(39395),
	(39396),
	(39397),
	(39398),
	(39399),
	(39400),
	(39401),
	(39402),
	(39403),
	(39404),
	(39405),
	(39406),
	(39407),
	(39408),
	(39409),
	(39410),
	(39411),
	(39412),
	(39413),
	(39414),
	(39415),
	(39416),
	(39417),
	(39418),
	(39419),
	(39420),
	(39421),
	(39422),
	(39423),
	(39424),
	(39425),
	(39426),
	(39427),
	(39428),
	(39429),
	(39430),
	(39431),
	(39432),
	(39433),
	(39434),
	(39435),
	(39436),
	(39437),
	(39438),
	(39439),
	(39440),
	(39441),
	(39442),
	(39443),
	(39444),
	(39445),
	(39446),
	(39447),
	(39448),
	(39449),
	(39450),
	(39451),
	(39452),
	(39453),
	(39454),
	(39455),
	(39456),
	(39457),
	(39458),
	(39459),
	(39460),
	(39461),
	(39462),
	(39463),
	(39464),
	(39465),
	(39466),
	(39467),
	(39468),
	(39469),
	(39470),
	(39471),
	(39472),
	(39473),
	(39474),
	(39475),
	(39476),
	(39477),
	(39478),
	(39479),
	(39480),
	(39481),
	(39482),
	(39483),
	(39484),
	(39485),
	(39486),
	(39487),
	(39488),
	(39489),
	(39490),
	(39491),
	(39492),
	(39493),
	(39494),
	(39495),
	(39496),
	(39497),
	(39498),
	(39499),
	(39500),
	(39501),
	(39502),
	(39503),
	(39504),
	(39505),
	(39506),
	(39507),
	(39508),
	(39509),
	(39510),
	(39511),
	(39512),
	(39513),
	(39514),
	(39515),
	(39516),
	(39517),
	(39518),
	(39519),
	(39520),
	(39521),
	(39522),
	(39523),
	(39524),
	(39525),
	(39526),
	(39527),
	(39528),
	(39529),
	(39530),
	(39531),
	(39532),
	(39533),
	(39534),
	(39535),
	(39536),
	(39537),
	(39538),
	(39539),
	(39540),
	(39541),
	(39542),
	(39543),
	(39544),
	(39545),
	(39546),
	(39547),
	(39548),
	(39549),
	(39550),
	(39551),
	(39552),
	(39553),
	(39554),
	(39555),
	(39556),
	(39557),
	(39558),
	(39559),
	(39560),
	(39561),
	(39562),
	(39563),
	(39564),
	(39565),
	(39566),
	(39567),
	(39568),
	(39569),
	(39570),
	(39571),
	(39572),
	(39573),
	(39574),
	(39575),
	(39576),
	(39577),
	(39578),
	(39579),
	(39580),
	(39581),
	(39582),
	(39583),
	(39584),
	(39585),
	(39586),
	(39587),
	(39588),
	(39589),
	(39590),
	(39591),
	(39592),
	(39593),
	(39594),
	(39595),
	(39596),
	(39597),
	(39598),
	(39599),
	(39600),
	(39601),
	(39602),
	(39603),
	(39604),
	(39605),
	(39606),
	(39607),
	(39608),
	(39609),
	(39610),
	(39611),
	(39612),
	(39613),
	(39614),
	(39615),
	(39616),
	(39617),
	(39618),
	(39619),
	(39620),
	(39621),
	(39622),
	(39623),
	(39624),
	(39625),
	(39626),
	(39627),
	(39628),
	(39629),
	(39630),
	(39631),
	(39632),
	(39633),
	(39634),
	(39635),
	(39636),
	(39637),
	(39638),
	(39639),
	(39640),
	(39641),
	(39642),
	(39643),
	(39644),
	(39645),
	(39646),
	(39647),
	(39648),
	(39649),
	(39650),
	(39651),
	(39652),
	(39653),
	(39654),
	(39655),
	(39656),
	(39657),
	(39658),
	(39659),
	(39660),
	(39661),
	(39662),
	(39663),
	(39664),
	(39665),
	(39666),
	(39667),
	(39668),
	(39669),
	(39670),
	(39671),
	(39672),
	(39673),
	(39674),
	(39675),
	(39676),
	(39677),
	(39678),
	(39679),
	(39680),
	(39681),
	(39682),
	(39683),
	(39684),
	(39685),
	(39686),
	(39687),
	(39688),
	(39689),
	(39690),
	(39691),
	(39692),
	(39693),
	(39694),
	(39695),
	(39696),
	(39697),
	(39698),
	(39699),
	(39700),
	(39701),
	(39702),
	(39703),
	(39704),
	(39705),
	(39706),
	(39707),
	(39708),
	(39709),
	(39710),
	(39711),
	(39712),
	(39713),
	(39714),
	(39715),
	(39716),
	(39717),
	(39718),
	(39719),
	(39720),
	(39721),
	(39722),
	(39723),
	(39724),
	(39725),
	(39726),
	(39727),
	(39728),
	(39729),
	(39730),
	(39731),
	(39732),
	(39733),
	(39734),
	(39735),
	(39736),
	(39737),
	(39738),
	(39739),
	(39740),
	(39741),
	(39742),
	(39743),
	(39744),
	(39745),
	(39746),
	(39747),
	(39748),
	(39749),
	(39750),
	(39751),
	(39752),
	(39753),
	(39754),
	(39755),
	(39756),
	(39757),
	(39758),
	(39759),
	(39760),
	(39761),
	(39762),
	(39763),
	(39764),
	(39765),
	(39766),
	(39767),
	(39768),
	(39769),
	(39770),
	(39771),
	(39772),
	(39773),
	(39774),
	(39775),
	(39776),
	(39777),
	(39778),
	(39779),
	(39780),
	(39781),
	(39782),
	(39783),
	(39784),
	(39785),
	(39786),
	(39787),
	(39788),
	(39789),
	(39790),
	(39791),
	(39792),
	(39793),
	(39794),
	(39795),
	(39796),
	(39797),
	(39798),
	(39799),
	(39800),
	(39801),
	(39802),
	(39803),
	(39804),
	(39805),
	(39806),
	(39807),
	(39808),
	(39809),
	(39810),
	(39811),
	(39812),
	(39813),
	(39814),
	(39815),
	(39816),
	(39817),
	(39818),
	(39819),
	(39820),
	(39821),
	(39822),
	(39823),
	(39824),
	(39825),
	(39826),
	(39827),
	(39828),
	(39829),
	(39830),
	(39831),
	(39832),
	(39833),
	(39834),
	(39835),
	(39836),
	(39837),
	(39838),
	(39839),
	(39840),
	(39841),
	(39842),
	(39843),
	(39844),
	(39845),
	(39846),
	(39847),
	(39848),
	(39849),
	(39850),
	(39851),
	(39852),
	(39853),
	(39854),
	(39855),
	(39856),
	(39857),
	(39858),
	(39859),
	(39860),
	(39861),
	(39862),
	(39863),
	(39864),
	(39865),
	(39866),
	(39867),
	(39868),
	(39869),
	(39870),
	(39871),
	(39872),
	(39873),
	(39874),
	(39875),
	(39876),
	(39877),
	(39878),
	(39879),
	(39880),
	(39881),
	(39882),
	(39883),
	(39884),
	(39885),
	(39886),
	(39887),
	(39888),
	(39889),
	(39890),
	(39891),
	(39892),
	(39893),
	(39894),
	(39895),
	(39896),
	(39897),
	(39898),
	(39899),
	(39900),
	(39901),
	(39902),
	(39903),
	(39904),
	(39905),
	(39906),
	(39907),
	(39908),
	(39909),
	(39910),
	(39911),
	(39912),
	(39913),
	(39914),
	(39915),
	(39916),
	(39917),
	(39918),
	(39919),
	(39920),
	(39921),
	(39922),
	(39923),
	(39924),
	(39925),
	(39926),
	(39927),
	(39928),
	(39929),
	(39930),
	(39931),
	(39932),
	(39933),
	(39934),
	(39935),
	(39936),
	(39937),
	(39938),
	(39939),
	(39940),
	(39941),
	(39942),
	(39943),
	(39944),
	(39945),
	(39946),
	(39947),
	(39948),
	(39949),
	(39950),
	(39951),
	(39952),
	(39953),
	(39954),
	(39955),
	(39956),
	(39957),
	(39958),
	(39959),
	(39960),
	(39961),
	(39962),
	(39963),
	(39964),
	(39965),
	(39966),
	(39967),
	(39968),
	(39969),
	(39970),
	(39971),
	(39972),
	(39973),
	(39974),
	(39975),
	(39976),
	(39977),
	(39978),
	(39979),
	(39980),
	(39981),
	(39982),
	(39983),
	(39984),
	(39985),
	(39986),
	(39987),
	(39988),
	(39989),
	(39990),
	(39991),
	(39992),
	(39993),
	(39994),
	(39995),
	(39996),
	(39997),
	(39998),
	(39999),
	(40000),
	(40001),
	(40002),
	(40003),
	(40004),
	(40005),
	(40006),
	(40007),
	(40008),
	(40009),
	(40010),
	(40011),
	(40012),
	(40013),
	(40014),
	(40015),
	(40016),
	(40017),
	(40018),
	(40019),
	(40020),
	(40021),
	(40022),
	(40023),
	(40024),
	(40025),
	(40026),
	(40027),
	(40028),
	(40029),
	(40030),
	(40031),
	(40032),
	(40033),
	(40034),
	(40035),
	(40036),
	(40037),
	(40038),
	(40039),
	(40040),
	(40041),
	(40042),
	(40043),
	(40044),
	(40045),
	(40046),
	(40047),
	(40048),
	(40049),
	(40050),
	(40051),
	(40052),
	(40053),
	(40054),
	(40055),
	(40056),
	(40057),
	(40058),
	(40059),
	(40060),
	(40061),
	(40062),
	(40063),
	(40064),
	(40065),
	(40066),
	(40067),
	(40068),
	(40069),
	(40070),
	(40071),
	(40072),
	(40073),
	(40074),
	(40075),
	(40076),
	(40077),
	(40078),
	(40079),
	(40080),
	(40081),
	(40082),
	(40083),
	(40084),
	(40085),
	(40086),
	(40087),
	(40088),
	(40089),
	(40090),
	(40091),
	(40092),
	(40093),
	(40094),
	(40095),
	(40096),
	(40097),
	(40098),
	(40099),
	(40100),
	(40101),
	(40102),
	(40103),
	(40104),
	(40105),
	(40106),
	(40107),
	(40108),
	(40109),
	(40110),
	(40111),
	(40112),
	(40113),
	(40114),
	(40115),
	(40116),
	(40117),
	(40118),
	(40119),
	(40120),
	(40121),
	(40122),
	(40123),
	(40124),
	(40125),
	(40126),
	(40127),
	(40128),
	(40129),
	(40130),
	(40131),
	(40132),
	(40133),
	(40134),
	(40135),
	(40136),
	(40137),
	(40138),
	(40139),
	(40140),
	(40141),
	(40142),
	(40143),
	(40144),
	(40145),
	(40146),
	(40147),
	(40148),
	(40149),
	(40150),
	(40151),
	(40152),
	(40153),
	(40154),
	(40155),
	(40156),
	(40157),
	(40158),
	(40159),
	(40160),
	(40161),
	(40162),
	(40163),
	(40164),
	(40165),
	(40166),
	(40167),
	(40168),
	(40169),
	(40170),
	(40171),
	(40172),
	(40173),
	(40174),
	(40175),
	(40176),
	(40177),
	(40178),
	(40179),
	(40180),
	(40181),
	(40182),
	(40183),
	(40184),
	(40185),
	(40186),
	(40187),
	(40188),
	(40189),
	(40190),
	(40191),
	(40192),
	(40193),
	(40194),
	(40195),
	(40196),
	(40197),
	(40198),
	(40199),
	(40200),
	(40201),
	(40202),
	(40203),
	(40204),
	(40205),
	(40206),
	(40207),
	(40208),
	(40209),
	(40210),
	(40211),
	(40212),
	(40213),
	(40214),
	(40215),
	(40216),
	(40217),
	(40218),
	(40219),
	(40220),
	(40221),
	(40222),
	(40223),
	(40224),
	(40225),
	(40226),
	(40227),
	(40228),
	(40229),
	(40230),
	(40231),
	(40232),
	(40233),
	(40234),
	(40235),
	(40236),
	(40237),
	(40238),
	(40239),
	(40240),
	(40241),
	(40242),
	(40243),
	(40244),
	(40245),
	(40246),
	(40247),
	(40248),
	(40249),
	(40250),
	(40251),
	(40252),
	(40253),
	(40254),
	(40255),
	(40256),
	(40257),
	(40258),
	(40259),
	(40260),
	(40261),
	(40262),
	(40263),
	(40264),
	(40265),
	(40266),
	(40267),
	(40268),
	(40269),
	(40270),
	(40271),
	(40272),
	(40273),
	(40274),
	(40275),
	(40276),
	(40277),
	(40278),
	(40279),
	(40280),
	(40281),
	(40282),
	(40283),
	(40284),
	(40285),
	(40286),
	(40287),
	(40288),
	(40289),
	(40290),
	(40291),
	(40292),
	(40293),
	(40294),
	(40295),
	(40296),
	(40297),
	(40298),
	(40299),
	(40300),
	(40301),
	(40302),
	(40303),
	(40304),
	(40305),
	(40306),
	(40307),
	(40308),
	(40309),
	(40310),
	(40311),
	(40312),
	(40313),
	(40314),
	(40315),
	(40316),
	(40317),
	(40318),
	(40319),
	(40320),
	(40321),
	(40322),
	(40323),
	(40324),
	(40325),
	(40326),
	(40327),
	(40328),
	(40329),
	(40330),
	(40331),
	(40332),
	(40333),
	(40334),
	(40335),
	(40336),
	(40337),
	(40338),
	(40339),
	(40340),
	(40341),
	(40342),
	(40343),
	(40344),
	(40345),
	(40346),
	(40347),
	(40348),
	(40349),
	(40350),
	(40351),
	(40352),
	(40353),
	(40354),
	(40355),
	(40356),
	(40357),
	(40358),
	(40359),
	(40360),
	(40361),
	(40362),
	(40363),
	(40364),
	(40365),
	(40366),
	(40367),
	(40368),
	(40369),
	(40370),
	(40371),
	(40372),
	(40373),
	(40374),
	(40375),
	(40376),
	(40377),
	(40378),
	(40379),
	(40380),
	(40381),
	(40382),
	(40383),
	(40384),
	(40385),
	(40386),
	(40387),
	(40388),
	(40389),
	(40390),
	(40391),
	(40392),
	(40393),
	(40394),
	(40395),
	(40396),
	(40397),
	(40398),
	(40399),
	(40400),
	(40401),
	(40402),
	(40403),
	(40404),
	(40405),
	(40406),
	(40407),
	(40408),
	(40409),
	(40410),
	(40411),
	(40412),
	(40413),
	(40414),
	(40415),
	(40416),
	(40417),
	(40418),
	(40419),
	(40420),
	(40421),
	(40422),
	(40423),
	(40424),
	(40425),
	(40426),
	(40427),
	(40428),
	(40429),
	(40430),
	(40431),
	(40432),
	(40433),
	(40434),
	(40435),
	(40436),
	(40437),
	(40438),
	(40439),
	(40440),
	(40441),
	(40442),
	(40443),
	(40444),
	(40445),
	(40446),
	(40447),
	(40448),
	(40449),
	(40450),
	(40451),
	(40452),
	(40453),
	(40454),
	(40455),
	(40456),
	(40457),
	(40458),
	(40459),
	(40460),
	(40461),
	(40462),
	(40463),
	(40464),
	(40465),
	(40466),
	(40467),
	(40468),
	(40469),
	(40470),
	(40471),
	(40472),
	(40473),
	(40474),
	(40475),
	(40476),
	(40477),
	(40478),
	(40479),
	(40480),
	(40481),
	(40482),
	(40483),
	(40484),
	(40485),
	(40486),
	(40487),
	(40488),
	(40489),
	(40490),
	(40491),
	(40492),
	(40493),
	(40494),
	(40495),
	(40496),
	(40497),
	(40498),
	(40499),
	(40500),
	(40501),
	(40502),
	(40503),
	(40504),
	(40505),
	(40506),
	(40507),
	(40508),
	(40509),
	(40510),
	(40511),
	(40512),
	(40513),
	(40514),
	(40515),
	(40516),
	(40517),
	(40518),
	(40519),
	(40520),
	(40521),
	(40522),
	(40523),
	(40524),
	(40525),
	(40526),
	(40527),
	(40528),
	(40529),
	(40530),
	(40531),
	(40532),
	(40533),
	(40534),
	(40535),
	(40536),
	(40537),
	(40538),
	(40539),
	(40540),
	(40541),
	(40542),
	(40543),
	(40544),
	(40545),
	(40546),
	(40547),
	(40548),
	(40549),
	(40550),
	(40551),
	(40552),
	(40553),
	(40554),
	(40555),
	(40556),
	(40557),
	(40558),
	(40559),
	(40560),
	(40561),
	(40562),
	(40563),
	(40564),
	(40565),
	(40566),
	(40567),
	(40568),
	(40569),
	(40570),
	(40571),
	(40572),
	(40573),
	(40574),
	(40575),
	(40576),
	(40577),
	(40578),
	(40579),
	(40580),
	(40581),
	(40582),
	(40583),
	(40584),
	(40585),
	(40586),
	(40587),
	(40588),
	(40589),
	(40590),
	(40591),
	(40592),
	(40593),
	(40594),
	(40595),
	(40596),
	(40597),
	(40598),
	(40599),
	(40600),
	(40601),
	(40602),
	(40603),
	(40604),
	(40605),
	(40606),
	(40607),
	(40608),
	(40609),
	(40610),
	(40611),
	(40612),
	(40613),
	(40614),
	(40615),
	(40616),
	(40617),
	(40618),
	(40619),
	(40620),
	(40621),
	(40622),
	(40623),
	(40624),
	(40625),
	(40626),
	(40627),
	(40628),
	(40629),
	(40630),
	(40631),
	(40632),
	(40633),
	(40634),
	(40635),
	(40636),
	(40637),
	(40638),
	(40639),
	(40640),
	(40641),
	(40642),
	(40643),
	(40644),
	(40645),
	(40646),
	(40647),
	(40648),
	(40649),
	(40650),
	(40651),
	(40652),
	(40653),
	(40654),
	(40655),
	(40656),
	(40657),
	(40658),
	(40659),
	(40660),
	(40661),
	(40662),
	(40663),
	(40664),
	(40665),
	(40666),
	(40667),
	(40668),
	(40669),
	(40670),
	(40671),
	(40672),
	(40673),
	(40674),
	(40675),
	(40676),
	(40677),
	(40678),
	(40679),
	(40680),
	(40681),
	(40682),
	(40683),
	(40684),
	(40685),
	(40686),
	(40687),
	(40688),
	(40689),
	(40690),
	(40691),
	(40692),
	(40693),
	(40694),
	(40695),
	(40696),
	(40697),
	(40698),
	(40699),
	(40700),
	(40701),
	(40702),
	(40703),
	(40704),
	(40705),
	(40706),
	(40707),
	(40708),
	(40709),
	(40710),
	(40711),
	(40712),
	(40713),
	(40714),
	(40715),
	(40716),
	(40717),
	(40718),
	(40719),
	(40720),
	(40721),
	(40722),
	(40723),
	(40724),
	(40725),
	(40726),
	(40727),
	(40728),
	(40729),
	(40730),
	(40731),
	(40732),
	(40733),
	(40734),
	(40735),
	(40736),
	(40737),
	(40738),
	(40739),
	(40740),
	(40741),
	(40742),
	(40743),
	(40744),
	(40745),
	(40746),
	(40747),
	(40748),
	(40749),
	(40750),
	(40751),
	(40752),
	(40753),
	(40754),
	(40755),
	(40756),
	(40757),
	(40758),
	(40759),
	(40760),
	(40761),
	(40762),
	(40763),
	(40764),
	(40765),
	(40766),
	(40767),
	(40768),
	(40769),
	(40770),
	(40771),
	(40772),
	(40773),
	(40774),
	(40775),
	(40776),
	(40777),
	(40778),
	(40779),
	(40780),
	(40781),
	(40782),
	(40783),
	(40784),
	(40785),
	(40786),
	(40787),
	(40788),
	(40789),
	(40790),
	(40791),
	(40792),
	(40793),
	(40794),
	(40795),
	(40796),
	(40797),
	(40798),
	(40799),
	(40800),
	(40801),
	(40802),
	(40803),
	(40804),
	(40805),
	(40806),
	(40807),
	(40808),
	(40809),
	(40810),
	(40811),
	(40812),
	(40813),
	(40814),
	(40815),
	(40816),
	(40817),
	(40818),
	(40819),
	(40820),
	(40821),
	(40822),
	(40823),
	(40824),
	(40825),
	(40826),
	(40827),
	(40828),
	(40829),
	(40830),
	(40831),
	(40832),
	(40833),
	(40834),
	(40835),
	(40836),
	(40837),
	(40838),
	(40839),
	(40840),
	(40841),
	(40842),
	(40843),
	(40844),
	(40845),
	(40846),
	(40847),
	(40848),
	(40849),
	(40850),
	(40851),
	(40852),
	(40853),
	(40854),
	(40855),
	(40856),
	(40857),
	(40858),
	(40859),
	(40860),
	(40861),
	(40862),
	(40863),
	(40864),
	(40865),
	(40866),
	(40867),
	(40868),
	(40869),
	(40870),
	(40871),
	(40872),
	(40873),
	(40874),
	(40875),
	(40876),
	(40877),
	(40878),
	(40879),
	(40880),
	(40881),
	(40882),
	(40883),
	(40884),
	(40885),
	(40886),
	(40887),
	(40888),
	(40889),
	(40890),
	(40891),
	(40892),
	(40893),
	(40894),
	(40895),
	(40896),
	(40897),
	(40898),
	(40899),
	(40900),
	(40901),
	(40902),
	(40903),
	(40904),
	(40905),
	(40906),
	(40907),
	(40908),
	(40909),
	(40910),
	(40911),
	(40912),
	(40913),
	(40914),
	(40915),
	(40916),
	(40917),
	(40918),
	(40919),
	(40920),
	(40921),
	(40922),
	(40923),
	(40924),
	(40925),
	(40926),
	(40927),
	(40928),
	(40929),
	(40930),
	(40931),
	(40932),
	(40933),
	(40934),
	(40935),
	(40936),
	(40937),
	(40938),
	(40939),
	(40940),
	(40941),
	(40942),
	(40943),
	(40944),
	(40945),
	(40946),
	(40947),
	(40948),
	(40949),
	(40950),
	(40951),
	(40952),
	(40953),
	(40954),
	(40955),
	(40956),
	(40957),
	(40958),
	(40959),
	(40960),
	(40961),
	(40962),
	(40963),
	(40964),
	(40965),
	(40966),
	(40967),
	(40968),
	(40969),
	(40970),
	(40971),
	(40972),
	(40973),
	(40974),
	(40975),
	(40976),
	(40977),
	(40978),
	(40979),
	(40980),
	(40981),
	(40982),
	(40983),
	(40984),
	(40985),
	(40986),
	(40987),
	(40988),
	(40989),
	(40990),
	(40991),
	(40992),
	(40993),
	(40994),
	(40995),
	(40996),
	(40997),
	(40998),
	(40999),
	(41000),
	(41001),
	(41002),
	(41003),
	(41004),
	(41005),
	(41006),
	(41007),
	(41008),
	(41009),
	(41010),
	(41011),
	(41012),
	(41013),
	(41014),
	(41015),
	(41016),
	(41017),
	(41018),
	(41019),
	(41020),
	(41021),
	(41022),
	(41023),
	(41024),
	(41025),
	(41026),
	(41027),
	(41028),
	(41029),
	(41030),
	(41031),
	(41032),
	(41033),
	(41034),
	(41035),
	(41036),
	(41037),
	(41038),
	(41039),
	(41040),
	(41041),
	(41042),
	(41043),
	(41044),
	(41045),
	(41046),
	(41047),
	(41048),
	(41049),
	(41050),
	(41051),
	(41052),
	(41053),
	(41054),
	(41055),
	(41056),
	(41057),
	(41058),
	(41059),
	(41060),
	(41061),
	(41062),
	(41063),
	(41064),
	(41065),
	(41066),
	(41067),
	(41068),
	(41069),
	(41070),
	(41071),
	(41072),
	(41073),
	(41074),
	(41075),
	(41076),
	(41077),
	(41078),
	(41079),
	(41080),
	(41081),
	(41082),
	(41083),
	(41084),
	(41085),
	(41086),
	(41087),
	(41088),
	(41089),
	(41090),
	(41091),
	(41092),
	(41093),
	(41094),
	(41095),
	(41096),
	(41097),
	(41098),
	(41099),
	(41100),
	(41101),
	(41102),
	(41103),
	(41104),
	(41105),
	(41106),
	(41107),
	(41108),
	(41109),
	(41110),
	(41111),
	(41112),
	(41113),
	(41114),
	(41115),
	(41116),
	(41117),
	(41118),
	(41119),
	(41120),
	(41121),
	(41122),
	(41123),
	(41124),
	(41125),
	(41126),
	(41127),
	(41128),
	(41129),
	(41130),
	(41131),
	(41132),
	(41133),
	(41134),
	(41135),
	(41136),
	(41137),
	(41138),
	(41139),
	(41140),
	(41141),
	(41142),
	(41143),
	(41144),
	(41145),
	(41146),
	(41147),
	(41148),
	(41149),
	(41150),
	(41151),
	(41152),
	(41153),
	(41154),
	(41155),
	(41156),
	(41157),
	(41158),
	(41159),
	(41160),
	(41161),
	(41162),
	(41163),
	(41164),
	(41165),
	(41166),
	(41167),
	(41168),
	(41169),
	(41170),
	(41171),
	(41172),
	(41173),
	(41174),
	(41175),
	(41176),
	(41177),
	(41178),
	(41179),
	(41180),
	(41181),
	(41182),
	(41183),
	(41184),
	(41185),
	(41186),
	(41187),
	(41188),
	(41189),
	(41190),
	(41191),
	(41192),
	(41193),
	(41194),
	(41195),
	(41196),
	(41197),
	(41198),
	(41199),
	(41200),
	(41201),
	(41202),
	(41203),
	(41204),
	(41205),
	(41206),
	(41207),
	(41208),
	(41209),
	(41210),
	(41211),
	(41212),
	(41213),
	(41214),
	(41215),
	(41216),
	(41217),
	(41218),
	(41219),
	(41220),
	(41221),
	(41222),
	(41223),
	(41224),
	(41225),
	(41226),
	(41227),
	(41228),
	(41229),
	(41230),
	(41231),
	(41232),
	(41233),
	(41234),
	(41235),
	(41236),
	(41237),
	(41238),
	(41239),
	(41240),
	(41241),
	(41242),
	(41243),
	(41244),
	(41245),
	(41246),
	(41247),
	(41248),
	(41249),
	(41250),
	(41251),
	(41252),
	(41253),
	(41254),
	(41255),
	(41256),
	(41257),
	(41258),
	(41259),
	(41260),
	(41261),
	(41262),
	(41263),
	(41264),
	(41265),
	(41266),
	(41267),
	(41268),
	(41269),
	(41270),
	(41271),
	(41272),
	(41273),
	(41274),
	(41275),
	(41276),
	(41277),
	(41278),
	(41279),
	(41280),
	(41281),
	(41282),
	(41283),
	(41284),
	(41285),
	(41286),
	(41287),
	(41288),
	(41289),
	(41290),
	(41291),
	(41292),
	(41293),
	(41294),
	(41295),
	(41296),
	(41297),
	(41298),
	(41299),
	(41300),
	(41301),
	(41302),
	(41303),
	(41304),
	(41305),
	(41306),
	(41307),
	(41308),
	(41309),
	(41310),
	(41311),
	(41312),
	(41313),
	(41314),
	(41315),
	(41316),
	(41317),
	(41318),
	(41319),
	(41320),
	(41321),
	(41322),
	(41323),
	(41324),
	(41325),
	(41326),
	(41327),
	(41328),
	(41329),
	(41330),
	(41331),
	(41332),
	(41333),
	(41334),
	(41335),
	(41336),
	(41337),
	(41338),
	(41339),
	(41340),
	(41341),
	(41342),
	(41343),
	(41344),
	(41345),
	(41346),
	(41347),
	(41348),
	(41349),
	(41350),
	(41351),
	(41352),
	(41353),
	(41354),
	(41355),
	(41356),
	(41357),
	(41358),
	(41359),
	(41360),
	(41361),
	(41362),
	(41363),
	(41364),
	(41365),
	(41366),
	(41367),
	(41368),
	(41369),
	(41370),
	(41371),
	(41372),
	(41373),
	(41374),
	(41375),
	(41376),
	(41377),
	(41378),
	(41379),
	(41380),
	(41381),
	(41382),
	(41383),
	(41384),
	(41385),
	(41386),
	(41387),
	(41388),
	(41389),
	(41390),
	(41391),
	(41392),
	(41393),
	(41394),
	(41395),
	(41396),
	(41397),
	(41398),
	(41399),
	(41400),
	(41401),
	(41402),
	(41403),
	(41404),
	(41405),
	(41406),
	(41407),
	(41408),
	(41409),
	(41410),
	(41411),
	(41412),
	(41413),
	(41414),
	(41415),
	(41416),
	(41417),
	(41418),
	(41419),
	(41420),
	(41421),
	(41422),
	(41423),
	(41424),
	(41425),
	(41426),
	(41427),
	(41428),
	(41429),
	(41430),
	(41431),
	(41432),
	(41433),
	(41434),
	(41435),
	(41436),
	(41437),
	(41438),
	(41439),
	(41440),
	(41441),
	(41442),
	(41443),
	(41444),
	(41445),
	(41446),
	(41447),
	(41448),
	(41449),
	(41450),
	(41451),
	(41452),
	(41453),
	(41454),
	(41455),
	(41456),
	(41457),
	(41458),
	(41459),
	(41460),
	(41461),
	(41462),
	(41463),
	(41464),
	(41465),
	(41466),
	(41467),
	(41468),
	(41469),
	(41470),
	(41471),
	(41472),
	(41473),
	(41474),
	(41475),
	(41476),
	(41477),
	(41478),
	(41479),
	(41480),
	(41481),
	(41482),
	(41483),
	(41484),
	(41485),
	(41486),
	(41487),
	(41488),
	(41489),
	(41490),
	(41491),
	(41492),
	(41493),
	(41494),
	(41495),
	(41496),
	(41497),
	(41498),
	(41499),
	(41500),
	(41501),
	(41502),
	(41503),
	(41504),
	(41505),
	(41506),
	(41507),
	(41508),
	(41509),
	(41510),
	(41511),
	(41512),
	(41513),
	(41514),
	(41515),
	(41516),
	(41517),
	(41518),
	(41519),
	(41520),
	(41521),
	(41522),
	(41523),
	(41524),
	(41525),
	(41526),
	(41527),
	(41528),
	(41529),
	(41530),
	(41531),
	(41532),
	(41533),
	(41534),
	(41535),
	(41536),
	(41537),
	(41538),
	(41539),
	(41540),
	(41541),
	(41542),
	(41543),
	(41544),
	(41545),
	(41546),
	(41547),
	(41548),
	(41549),
	(41550),
	(41551),
	(41552),
	(41553),
	(41554),
	(41555),
	(41556),
	(41557),
	(41558),
	(41559),
	(41560),
	(41561),
	(41562),
	(41563),
	(41564),
	(41565),
	(41566),
	(41567),
	(41568),
	(41569),
	(41570),
	(41571),
	(41572),
	(41573),
	(41574),
	(41575),
	(41576),
	(41577),
	(41578),
	(41579),
	(41580),
	(41581),
	(41582),
	(41583),
	(41584),
	(41585),
	(41586),
	(41587),
	(41588),
	(41589),
	(41590),
	(41591),
	(41592),
	(41593),
	(41594),
	(41595),
	(41596),
	(41597),
	(41598),
	(41599),
	(41600),
	(41601),
	(41602),
	(41603),
	(41604),
	(41605),
	(41606),
	(41607),
	(41608),
	(41609),
	(41610),
	(41611),
	(41612),
	(41613),
	(41614),
	(41615),
	(41616),
	(41617),
	(41618),
	(41619),
	(41620),
	(41621),
	(41622),
	(41623),
	(41624),
	(41625),
	(41626),
	(41627),
	(41628),
	(41629),
	(41630),
	(41631),
	(41632),
	(41633),
	(41634),
	(41635),
	(41636),
	(41637),
	(41638),
	(41639),
	(41640),
	(41641),
	(41642),
	(41643),
	(41644),
	(41645),
	(41646),
	(41647),
	(41648),
	(41649),
	(41650),
	(41651),
	(41652),
	(41653),
	(41654),
	(41655),
	(41656),
	(41657),
	(41658),
	(41659),
	(41660),
	(41661),
	(41662),
	(41663),
	(41664),
	(41665),
	(41666),
	(41667),
	(41668),
	(41669),
	(41670),
	(41671),
	(41672),
	(41673),
	(41674),
	(41675),
	(41676),
	(41677),
	(41678),
	(41679),
	(41680),
	(41681),
	(41682),
	(41683),
	(41684),
	(41685),
	(41686),
	(41687),
	(41688),
	(41689),
	(41690),
	(41691),
	(41692),
	(41693),
	(41694),
	(41695),
	(41696),
	(41697),
	(41698),
	(41699),
	(41700),
	(41701),
	(41702),
	(41703),
	(41704),
	(41705),
	(41706),
	(41707),
	(41708),
	(41709),
	(41710),
	(41711),
	(41712),
	(41713),
	(41714),
	(41715),
	(41716),
	(41717),
	(41718),
	(41719),
	(41720),
	(41721),
	(41722),
	(41723),
	(41724),
	(41725),
	(41726),
	(41727),
	(41728),
	(41729),
	(41730),
	(41731),
	(41732),
	(41733),
	(41734),
	(41735),
	(41736),
	(41737),
	(41738),
	(41739),
	(41740),
	(41741),
	(41742),
	(41743),
	(41744),
	(41745),
	(41746),
	(41747),
	(41748),
	(41749),
	(41750),
	(41751),
	(41752),
	(41753),
	(41754),
	(41755),
	(41756),
	(41757),
	(41758),
	(41759),
	(41760),
	(41761),
	(41762),
	(41763),
	(41764),
	(41765),
	(41766),
	(41767),
	(41768),
	(41769),
	(41770),
	(41771),
	(41772),
	(41773),
	(41774),
	(41775),
	(41776),
	(41777),
	(41778),
	(41779),
	(41780),
	(41781),
	(41782),
	(41783),
	(41784),
	(41785),
	(41786),
	(41787),
	(41788),
	(41789),
	(41790),
	(41791),
	(41792),
	(41793),
	(41794),
	(41795),
	(41796),
	(41797),
	(41798),
	(41799),
	(41800),
	(41801),
	(41802),
	(41803),
	(41804),
	(41805),
	(41806),
	(41807),
	(41808),
	(41809),
	(41810),
	(41811),
	(41812),
	(41813),
	(41814),
	(41815),
	(41816),
	(41817),
	(41818),
	(41819),
	(41820),
	(41821),
	(41822),
	(41823),
	(41824),
	(41825),
	(41826),
	(41827),
	(41828),
	(41829),
	(41830),
	(41831),
	(41832),
	(41833),
	(41834),
	(41835),
	(41836),
	(41837),
	(41838),
	(41839),
	(41840),
	(41841),
	(41842),
	(41843),
	(41844),
	(41845),
	(41846),
	(41847),
	(41848),
	(41849),
	(41850),
	(41851),
	(41852),
	(41853),
	(41854),
	(41855),
	(41856),
	(41857),
	(41858),
	(41859),
	(41860),
	(41861),
	(41862),
	(41863),
	(41864),
	(41865),
	(41866),
	(41867),
	(41868),
	(41869),
	(41870),
	(41871),
	(41872),
	(41873),
	(41874),
	(41875),
	(41876),
	(41877),
	(41878),
	(41879),
	(41880),
	(41881),
	(41882),
	(41883),
	(41884),
	(41885),
	(41886),
	(41887),
	(41888),
	(41889),
	(41890),
	(41891),
	(41892),
	(41893),
	(41894),
	(41895),
	(41896),
	(41897),
	(41898),
	(41899),
	(41900),
	(41901),
	(41902),
	(41903),
	(41904),
	(41905),
	(41906),
	(41907),
	(41908),
	(41909),
	(41910),
	(41911),
	(41912),
	(41913),
	(41914),
	(41915),
	(41916),
	(41917),
	(41918),
	(41919),
	(41920),
	(41921),
	(41922),
	(41923),
	(41924),
	(41925),
	(41926),
	(41927),
	(41928),
	(41929),
	(41930),
	(41931),
	(41932),
	(41933),
	(41934),
	(41935),
	(41936),
	(41937),
	(41938),
	(41939),
	(41940),
	(41941),
	(41942),
	(41943),
	(41944),
	(41945),
	(41946),
	(41947),
	(41948),
	(41949),
	(41950),
	(41951),
	(41952),
	(41953),
	(41954),
	(41955),
	(41956),
	(41957),
	(41958),
	(41959),
	(41960),
	(41961),
	(41962),
	(41963),
	(41964),
	(41965),
	(41966),
	(41967),
	(41968),
	(41969),
	(41970),
	(41971),
	(41972),
	(41973),
	(41974),
	(41975),
	(41976),
	(41977),
	(41978),
	(41979),
	(41980),
	(41981),
	(41982),
	(41983),
	(41984),
	(41985),
	(41986),
	(41987),
	(41988),
	(41989),
	(41990),
	(41991),
	(41992),
	(41993),
	(41994),
	(41995),
	(41996),
	(41997),
	(41998),
	(41999),
	(42000),
	(42001),
	(42002),
	(42003),
	(42004),
	(42005),
	(42006),
	(42007),
	(42008),
	(42009),
	(42010),
	(42011),
	(42012),
	(42013),
	(42014),
	(42015),
	(42016),
	(42017),
	(42018),
	(42019),
	(42020),
	(42021),
	(42022),
	(42023),
	(42024),
	(42025),
	(42026),
	(42027),
	(42028),
	(42029),
	(42030),
	(42031),
	(42032),
	(42033),
	(42034),
	(42035),
	(42036),
	(42037),
	(42038),
	(42039),
	(42040),
	(42041),
	(42042),
	(42043),
	(42044),
	(42045),
	(42046),
	(42047),
	(42048),
	(42049),
	(42050),
	(42051),
	(42052),
	(42053),
	(42054),
	(42055),
	(42056),
	(42057),
	(42058),
	(42059),
	(42060),
	(42061),
	(42062),
	(42063),
	(42064),
	(42065),
	(42066),
	(42067),
	(42068),
	(42069),
	(42070),
	(42071),
	(42072),
	(42073),
	(42074),
	(42075),
	(42076),
	(42077),
	(42078),
	(42079),
	(42080),
	(42081),
	(42082),
	(42083),
	(42084),
	(42085),
	(42086),
	(42087),
	(42088),
	(42089),
	(42090),
	(42091),
	(42092),
	(42093),
	(42094),
	(42095),
	(42096),
	(42097),
	(42098),
	(42099),
	(42100),
	(42101),
	(42102),
	(42103),
	(42104),
	(42105),
	(42106),
	(42107),
	(42108),
	(42109),
	(42110),
	(42111),
	(42112),
	(42113),
	(42114),
	(42115),
	(42116),
	(42117),
	(42118),
	(42119),
	(42120),
	(42121),
	(42122),
	(42123),
	(42124),
	(42125),
	(42126),
	(42127),
	(42128),
	(42129),
	(42130),
	(42131),
	(42132),
	(42133),
	(42134),
	(42135),
	(42136),
	(42137),
	(42138),
	(42139),
	(42140),
	(42141),
	(42142),
	(42143),
	(42144),
	(42145),
	(42146),
	(42147),
	(42148),
	(42149),
	(42150),
	(42151),
	(42152),
	(42153),
	(42154),
	(42155),
	(42156),
	(42157),
	(42158),
	(42159),
	(42160),
	(42161),
	(42162),
	(42163),
	(42164),
	(42165),
	(42166),
	(42167),
	(42168),
	(42169),
	(42170),
	(42171),
	(42172),
	(42173),
	(42174),
	(42175),
	(42176),
	(42177),
	(42178),
	(42179),
	(42180),
	(42181),
	(42182),
	(42183),
	(42184),
	(42185),
	(42186),
	(42187),
	(42188),
	(42189),
	(42190),
	(42191),
	(42192),
	(42193),
	(42194),
	(42195),
	(42196),
	(42197),
	(42198),
	(42199),
	(42200),
	(42201),
	(42202),
	(42203),
	(42204),
	(42205),
	(42206),
	(42207),
	(42208),
	(42209),
	(42210),
	(42211),
	(42212),
	(42213),
	(42214),
	(42215),
	(42216),
	(42217),
	(42218),
	(42219),
	(42220),
	(42221),
	(42222),
	(42223),
	(42224),
	(42225),
	(42226),
	(42227),
	(42228),
	(42229),
	(42230),
	(42231),
	(42232),
	(42233),
	(42234),
	(42235),
	(42236),
	(42237),
	(42238),
	(42239),
	(42240),
	(42241),
	(42242),
	(42243),
	(42244),
	(42245),
	(42246),
	(42247),
	(42248),
	(42249),
	(42250),
	(42251),
	(42252),
	(42253),
	(42254),
	(42255),
	(42256),
	(42257),
	(42258),
	(42259),
	(42260),
	(42261),
	(42262),
	(42263),
	(42264),
	(42265),
	(42266),
	(42267),
	(42268),
	(42269),
	(42270),
	(42271),
	(42272),
	(42273),
	(42274),
	(42275),
	(42276),
	(42277),
	(42278),
	(42279),
	(42280),
	(42281),
	(42282),
	(42283),
	(42284),
	(42285),
	(42286),
	(42287),
	(42288),
	(42289),
	(42290),
	(42291),
	(42292),
	(42293),
	(42294),
	(42295),
	(42296),
	(42297),
	(42298),
	(42299),
	(42300),
	(42301),
	(42302),
	(42303),
	(42304),
	(42305),
	(42306),
	(42307),
	(42308),
	(42309),
	(42310),
	(42311),
	(42312),
	(42313),
	(42314),
	(42315),
	(42316),
	(42317),
	(42318),
	(42319),
	(42320),
	(42321),
	(42322),
	(42323),
	(42324),
	(42325),
	(42326),
	(42327),
	(42328),
	(42329),
	(42330),
	(42331),
	(42332),
	(42333),
	(42334),
	(42335),
	(42336),
	(42337),
	(42338),
	(42339),
	(42340),
	(42341),
	(42342),
	(42343),
	(42344),
	(42345),
	(42346),
	(42347),
	(42348),
	(42349),
	(42350),
	(42351),
	(42352),
	(42353),
	(42354),
	(42355),
	(42356),
	(42357),
	(42358),
	(42359),
	(42360),
	(42361),
	(42362),
	(42363),
	(42364),
	(42365),
	(42366),
	(42367),
	(42368),
	(42369),
	(42370),
	(42371),
	(42372),
	(42373),
	(42374),
	(42375),
	(42376),
	(42377),
	(42378),
	(42379),
	(42380),
	(42381),
	(42382),
	(42383),
	(42384),
	(42385),
	(42386),
	(42387),
	(42388),
	(42389),
	(42390),
	(42391),
	(42392),
	(42393),
	(42394),
	(42395),
	(42396),
	(42397),
	(42398),
	(42399),
	(42400),
	(42401),
	(42402),
	(42403),
	(42404),
	(42405),
	(42406),
	(42407),
	(42408),
	(42409),
	(42410),
	(42411),
	(42412),
	(42413),
	(42414),
	(42415),
	(42416),
	(42417),
	(42418),
	(42419),
	(42420),
	(42421),
	(42422),
	(42423),
	(42424),
	(42425),
	(42426),
	(42427),
	(42428),
	(42429),
	(42430),
	(42431),
	(42432),
	(42433),
	(42434),
	(42435),
	(42436),
	(42437),
	(42438),
	(42439),
	(42440),
	(42441),
	(42442),
	(42443),
	(42444),
	(42445),
	(42446),
	(42447),
	(42448),
	(42449),
	(42450),
	(42451),
	(42452),
	(42453),
	(42454),
	(42455),
	(42456),
	(42457),
	(42458),
	(42459),
	(42460),
	(42461),
	(42462),
	(42463),
	(42464),
	(42465),
	(42466),
	(42467),
	(42468),
	(42469),
	(42470),
	(42471),
	(42472),
	(42473),
	(42474),
	(42475),
	(42476),
	(42477),
	(42478),
	(42479),
	(42480),
	(42481),
	(42482),
	(42483),
	(42484),
	(42485),
	(42486),
	(42487),
	(42488),
	(42489),
	(42490),
	(42491),
	(42492),
	(42493),
	(42494),
	(42495),
	(42496),
	(42497),
	(42498),
	(42499),
	(42500),
	(42501),
	(42502),
	(42503),
	(42504),
	(42505),
	(42506),
	(42507),
	(42508),
	(42509),
	(42510),
	(42511),
	(42512),
	(42513),
	(42514),
	(42515),
	(42516),
	(42517),
	(42518),
	(42519),
	(42520),
	(42521),
	(42522),
	(42523),
	(42524),
	(42525),
	(42526),
	(42527),
	(42528),
	(42529),
	(42530),
	(42531),
	(42532),
	(42533),
	(42534),
	(42535),
	(42536),
	(42537),
	(42538),
	(42539),
	(42540),
	(42541),
	(42542),
	(42543),
	(42544),
	(42545),
	(42546),
	(42547),
	(42548),
	(42549),
	(42550),
	(42551),
	(42552),
	(42553),
	(42554),
	(42555),
	(42556),
	(42557),
	(42558),
	(42559),
	(42560),
	(42561),
	(42562),
	(42563),
	(42564),
	(42565),
	(42566),
	(42567),
	(42568),
	(42569),
	(42570),
	(42571),
	(42572),
	(42573),
	(42574),
	(42575),
	(42576),
	(42577),
	(42578),
	(42579),
	(42580),
	(42581),
	(42582),
	(42583),
	(42584),
	(42585),
	(42586),
	(42587),
	(42588),
	(42589),
	(42590),
	(42591),
	(42592),
	(42593),
	(42594),
	(42595),
	(42596),
	(42597),
	(42598),
	(42599),
	(42600),
	(42601),
	(42602),
	(42603),
	(42604),
	(42605),
	(42606),
	(42607),
	(42608),
	(42609),
	(42610),
	(42611),
	(42612),
	(42613),
	(42614),
	(42615),
	(42616),
	(42617),
	(42618),
	(42619),
	(42620),
	(42621),
	(42622),
	(42623),
	(42624),
	(42625),
	(42626),
	(42627),
	(42628),
	(42629),
	(42630),
	(42631),
	(42632),
	(42633),
	(42634),
	(42635),
	(42636),
	(42637),
	(42638),
	(42639),
	(42640),
	(42641),
	(42642),
	(42643),
	(42644),
	(42645),
	(42646),
	(42647),
	(42648),
	(42649),
	(42650),
	(42651),
	(42652),
	(42653),
	(42654),
	(42655),
	(42656),
	(42657),
	(42658),
	(42659),
	(42660),
	(42661),
	(42662),
	(42663),
	(42664),
	(42665),
	(42666),
	(42667),
	(42668),
	(42669),
	(42670),
	(42671),
	(42672),
	(42673),
	(42674),
	(42675),
	(42676),
	(42677),
	(42678),
	(42679),
	(42680),
	(42681),
	(42682),
	(42683),
	(42684),
	(42685),
	(42686),
	(42687),
	(42688),
	(42689),
	(42690),
	(42691),
	(42692),
	(42693),
	(42694),
	(42695),
	(42696),
	(42697),
	(42698),
	(42699),
	(42700),
	(42701),
	(42702),
	(42703),
	(42704),
	(42705),
	(42706),
	(42707),
	(42708),
	(42709),
	(42710),
	(42711),
	(42712),
	(42713),
	(42714),
	(42715),
	(42716),
	(42717),
	(42718),
	(42719),
	(42720),
	(42721),
	(42722),
	(42723),
	(42724),
	(42725),
	(42726),
	(42727),
	(42728),
	(42729),
	(42730),
	(42731),
	(42732),
	(42733),
	(42734),
	(42735),
	(42736),
	(42737),
	(42738),
	(42739),
	(42740),
	(42741),
	(42742),
	(42743),
	(42744),
	(42745),
	(42746),
	(42747),
	(42748),
	(42749),
	(42750),
	(42751),
	(42752),
	(42753),
	(42754),
	(42755),
	(42756),
	(42757),
	(42758),
	(42759),
	(42760),
	(42761),
	(42762),
	(42763),
	(42764),
	(42765),
	(42766),
	(42767),
	(42768),
	(42769),
	(42770),
	(42771),
	(42772),
	(42773),
	(42774),
	(42775),
	(42776),
	(42777),
	(42778),
	(42779),
	(42780),
	(42781),
	(42782),
	(42783),
	(42784),
	(42785),
	(42786),
	(42787),
	(42788),
	(42789),
	(42790),
	(42791),
	(42792),
	(42793),
	(42794),
	(42795),
	(42796),
	(42797),
	(42798),
	(42799),
	(42800),
	(42801),
	(42802),
	(42803),
	(42804),
	(42805),
	(42806),
	(42807),
	(42808),
	(42809),
	(42810),
	(42811),
	(42812),
	(42813),
	(42814),
	(42815),
	(42816),
	(42817),
	(42818),
	(42819),
	(42820),
	(42821),
	(42822),
	(42823),
	(42824),
	(42825),
	(42826),
	(42827),
	(42828),
	(42829),
	(42830),
	(42831),
	(42832),
	(42833),
	(42834),
	(42835),
	(42836),
	(42837),
	(42838),
	(42839),
	(42840),
	(42841),
	(42842),
	(42843),
	(42844),
	(42845),
	(42846),
	(42847),
	(42848),
	(42849),
	(42850),
	(42851),
	(42852),
	(42853),
	(42854),
	(42855),
	(42856),
	(42857),
	(42858),
	(42859),
	(42860),
	(42861),
	(42862),
	(42863),
	(42864),
	(42865),
	(42866),
	(42867),
	(42868),
	(42869),
	(42870),
	(42871),
	(42872),
	(42873),
	(42874),
	(42875),
	(42876),
	(42877),
	(42878),
	(42879),
	(42880),
	(42881),
	(42882),
	(42883),
	(42884),
	(42885),
	(42886),
	(42887),
	(42888),
	(42889),
	(42890),
	(42891),
	(42892),
	(42893),
	(42894),
	(42895),
	(42896),
	(42897),
	(42898),
	(42899),
	(42900),
	(42901),
	(42902),
	(42903),
	(42904),
	(42905),
	(42906),
	(42907),
	(42908),
	(42909),
	(42910),
	(42911),
	(42912),
	(42913),
	(42914),
	(42915),
	(42916),
	(42917),
	(42918),
	(42919),
	(42920),
	(42921),
	(42922),
	(42923),
	(42924),
	(42925),
	(42926),
	(42927),
	(42928),
	(42929),
	(42930),
	(42931),
	(42932),
	(42933),
	(42934),
	(42935),
	(42936),
	(42937),
	(42938),
	(42939),
	(42940),
	(42941),
	(42942),
	(42943),
	(42944),
	(42945),
	(42946),
	(42947),
	(42948),
	(42949),
	(42950),
	(42951),
	(42952),
	(42953),
	(42954),
	(42955),
	(42956),
	(42957),
	(42958),
	(42959),
	(42960),
	(42961),
	(42962),
	(42963),
	(42964),
	(42965),
	(42966),
	(42967),
	(42968),
	(42969),
	(42970),
	(42971),
	(42972),
	(42973),
	(42974),
	(42975),
	(42976),
	(42977),
	(42978),
	(42979),
	(42980),
	(42981),
	(42982),
	(42983),
	(42984),
	(42985),
	(42986),
	(42987),
	(42988),
	(42989),
	(42990),
	(42991),
	(42992),
	(42993),
	(42994),
	(42995),
	(42996),
	(42997),
	(42998),
	(42999),
	(43000),
	(43001),
	(43002),
	(43003),
	(43004),
	(43005),
	(43006),
	(43007),
	(43008),
	(43009),
	(43010),
	(43011),
	(43012),
	(43013),
	(43014),
	(43015),
	(43016),
	(43017),
	(43018),
	(43019),
	(43020),
	(43021),
	(43022),
	(43023),
	(43024),
	(43025),
	(43026),
	(43027),
	(43028),
	(43029),
	(43030),
	(43031),
	(43032),
	(43033),
	(43034),
	(43035),
	(43036),
	(43037),
	(43038),
	(43039),
	(43040),
	(43041),
	(43042),
	(43043),
	(43044),
	(43045),
	(43046),
	(43047),
	(43048),
	(43049),
	(43050),
	(43051),
	(43052),
	(43053),
	(43054),
	(43055),
	(43056),
	(43057),
	(43058),
	(43059),
	(43060),
	(43061),
	(43062),
	(43063),
	(43064),
	(43065),
	(43066),
	(43067),
	(43068),
	(43069),
	(43070),
	(43071),
	(43072),
	(43073),
	(43074),
	(43075),
	(43076),
	(43077),
	(43078),
	(43079),
	(43080),
	(43081),
	(43082),
	(43083),
	(43084),
	(43085),
	(43086),
	(43087),
	(43088),
	(43089),
	(43090),
	(43091),
	(43092),
	(43093),
	(43094),
	(43095),
	(43096),
	(43097),
	(43098),
	(43099),
	(43100),
	(43101),
	(43102),
	(43103),
	(43104),
	(43105),
	(43106),
	(43107),
	(43108),
	(43109),
	(43110),
	(43111),
	(43112),
	(43113),
	(43114),
	(43115),
	(43116),
	(43117),
	(43118),
	(43119),
	(43120),
	(43121),
	(43122),
	(43123),
	(43124),
	(43125),
	(43126),
	(43127),
	(43128),
	(43129),
	(43130),
	(43131),
	(43132),
	(43133),
	(43134),
	(43135),
	(43136),
	(43137),
	(43138),
	(43139),
	(43140),
	(43141),
	(43142),
	(43143),
	(43144),
	(43145),
	(43146),
	(43147),
	(43148),
	(43149),
	(43150),
	(43151),
	(43152),
	(43153),
	(43154),
	(43155),
	(43156),
	(43157),
	(43158),
	(43159),
	(43160),
	(43161),
	(43162),
	(43163),
	(43164),
	(43165),
	(43166),
	(43167),
	(43168),
	(43169),
	(43170),
	(43171),
	(43172),
	(43173),
	(43174),
	(43175),
	(43176),
	(43177),
	(43178),
	(43179),
	(43180),
	(43181),
	(43182),
	(43183),
	(43184),
	(43185),
	(43186),
	(43187),
	(43188),
	(43189),
	(43190),
	(43191),
	(43192),
	(43193),
	(43194),
	(43195),
	(43196),
	(43197),
	(43198),
	(43199),
	(43200),
	(43201),
	(43202),
	(43203),
	(43204),
	(43205),
	(43206),
	(43207),
	(43208),
	(43209),
	(43210),
	(43211),
	(43212),
	(43213),
	(43214),
	(43215),
	(43216),
	(43217),
	(43218),
	(43219),
	(43220),
	(43221),
	(43222),
	(43223),
	(43224),
	(43225),
	(43226),
	(43227),
	(43228),
	(43229),
	(43230),
	(43231),
	(43232),
	(43233),
	(43234),
	(43235),
	(43236),
	(43237),
	(43238),
	(43239),
	(43240),
	(43241),
	(43242),
	(43243),
	(43244),
	(43245),
	(43246),
	(43247),
	(43248),
	(43249),
	(43250),
	(43251),
	(43252),
	(43253),
	(43254),
	(43255),
	(43256),
	(43257),
	(43258),
	(43259),
	(43260),
	(43261),
	(43262),
	(43263),
	(43264),
	(43265),
	(43266),
	(43267),
	(43268),
	(43269),
	(43270),
	(43271),
	(43272),
	(43273),
	(43274),
	(43275),
	(43276),
	(43277),
	(43278),
	(43279),
	(43280),
	(43281),
	(43282),
	(43283),
	(43284),
	(43285),
	(43286),
	(43287),
	(43288),
	(43289),
	(43290),
	(43291),
	(43292),
	(43293),
	(43294),
	(43295),
	(43296),
	(43297),
	(43298),
	(43299),
	(43300),
	(43301),
	(43302),
	(43303),
	(43304),
	(43305),
	(43306),
	(43307),
	(43308),
	(43309),
	(43310),
	(43311),
	(43312),
	(43313),
	(43314),
	(43315),
	(43316),
	(43317),
	(43318),
	(43319),
	(43320),
	(43321),
	(43322),
	(43323),
	(43324),
	(43325),
	(43326),
	(43327),
	(43328),
	(43329),
	(43330),
	(43331),
	(43332),
	(43333),
	(43334),
	(43335),
	(43336),
	(43337),
	(43338),
	(43339),
	(43340),
	(43341),
	(43342),
	(43343),
	(43344),
	(43345),
	(43346),
	(43347),
	(43348),
	(43349),
	(43350),
	(43351),
	(43352),
	(43353),
	(43354),
	(43355),
	(43356),
	(43357),
	(43358),
	(43359),
	(43360),
	(43361),
	(43362),
	(43363),
	(43364),
	(43365),
	(43366),
	(43367),
	(43368),
	(43369),
	(43370),
	(43371),
	(43372),
	(43373),
	(43374),
	(43375),
	(43376),
	(43377),
	(43378),
	(43379),
	(43380),
	(43381),
	(43382),
	(43383),
	(43384),
	(43385),
	(43386),
	(43387),
	(43388),
	(43389),
	(43390),
	(43391),
	(43392),
	(43393),
	(43394),
	(43395),
	(43396),
	(43397),
	(43398),
	(43399),
	(43400),
	(43401),
	(43402),
	(43403),
	(43404),
	(43405),
	(43406),
	(43407),
	(43408),
	(43409),
	(43410),
	(43411),
	(43412),
	(43413),
	(43414),
	(43415),
	(43416),
	(43417),
	(43418),
	(43419),
	(43420),
	(43421),
	(43422),
	(43423),
	(43424),
	(43425),
	(43426),
	(43427),
	(43428),
	(43429),
	(43430),
	(43431),
	(43432),
	(43433),
	(43434),
	(43435),
	(43436),
	(43437),
	(43438),
	(43439),
	(43440),
	(43441),
	(43442),
	(43443),
	(43444),
	(43445),
	(43446),
	(43447),
	(43448),
	(43449),
	(43450),
	(43451),
	(43452),
	(43453),
	(43454),
	(43455),
	(43456),
	(43457),
	(43458),
	(43459),
	(43460),
	(43461),
	(43462),
	(43463),
	(43464),
	(43465),
	(43466),
	(43467),
	(43468),
	(43469),
	(43470),
	(43471),
	(43472),
	(43473),
	(43474),
	(43475),
	(43476),
	(43477),
	(43478),
	(43479),
	(43480),
	(43481),
	(43482),
	(43483),
	(43484),
	(43485),
	(43486),
	(43487),
	(43488),
	(43489),
	(43490),
	(43491),
	(43492),
	(43493),
	(43494),
	(43495),
	(43496),
	(43497),
	(43498),
	(43499),
	(43500),
	(43501),
	(43502),
	(43503),
	(43504),
	(43505),
	(43506),
	(43507),
	(43508),
	(43509),
	(43510),
	(43511),
	(43512),
	(43513),
	(43514),
	(43515),
	(43516),
	(43517),
	(43518),
	(43519),
	(43520),
	(43521),
	(43522),
	(43523),
	(43524),
	(43525),
	(43526),
	(43527),
	(43528),
	(43529),
	(43530),
	(43531),
	(43532),
	(43533),
	(43534),
	(43535),
	(43536),
	(43537),
	(43538),
	(43539),
	(43540),
	(43541),
	(43542),
	(43543),
	(43544),
	(43545),
	(43546),
	(43547),
	(43548),
	(43549),
	(43550),
	(43551),
	(43552),
	(43553),
	(43554),
	(43555),
	(43556),
	(43557),
	(43558),
	(43559),
	(43560),
	(43561),
	(43562),
	(43563),
	(43564),
	(43565),
	(43566),
	(43567),
	(43568),
	(43569),
	(43570),
	(43571),
	(43572),
	(43573),
	(43574),
	(43575),
	(43576),
	(43577),
	(43578),
	(43579),
	(43580),
	(43581),
	(43582),
	(43583),
	(43584),
	(43585),
	(43586),
	(43587),
	(43588),
	(43589),
	(43590),
	(43591),
	(43592),
	(43593),
	(43594),
	(43595),
	(43596),
	(43597),
	(43598),
	(43599),
	(43600),
	(43601),
	(43602),
	(43603),
	(43604),
	(43605),
	(43606),
	(43607),
	(43608),
	(43609),
	(43610),
	(43611),
	(43612),
	(43613),
	(43614),
	(43615),
	(43616),
	(43617),
	(43618),
	(43619),
	(43620),
	(43621),
	(43622),
	(43623),
	(43624),
	(43625),
	(43626),
	(43627),
	(43628),
	(43629),
	(43630),
	(43631),
	(43632),
	(43633),
	(43634),
	(43635),
	(43636),
	(43637),
	(43638),
	(43639),
	(43640),
	(43641),
	(43642),
	(43643),
	(43644),
	(43645),
	(43646),
	(43647),
	(43648),
	(43649),
	(43650),
	(43651),
	(43652),
	(43653),
	(43654),
	(43655),
	(43656),
	(43657),
	(43658),
	(43659),
	(43660),
	(43661),
	(43662),
	(43663),
	(43664),
	(43665),
	(43666),
	(43667),
	(43668),
	(43669),
	(43670),
	(43671),
	(43672),
	(43673),
	(43674),
	(43675),
	(43676),
	(43677),
	(43678),
	(43679),
	(43680),
	(43681),
	(43682),
	(43683),
	(43684),
	(43685),
	(43686),
	(43687),
	(43688),
	(43689),
	(43690),
	(43691),
	(43692),
	(43693),
	(43694),
	(43695),
	(43696),
	(43697),
	(43698),
	(43699),
	(43700),
	(43701),
	(43702),
	(43703),
	(43704),
	(43705),
	(43706),
	(43707),
	(43708),
	(43709),
	(43710),
	(43711),
	(43712),
	(43713),
	(43714),
	(43715),
	(43716),
	(43717),
	(43718),
	(43719),
	(43720),
	(43721),
	(43722),
	(43723),
	(43724),
	(43725),
	(43726),
	(43727),
	(43728),
	(43729),
	(43730),
	(43731),
	(43732),
	(43733),
	(43734),
	(43735),
	(43736),
	(43737),
	(43738),
	(43739),
	(43740),
	(43741),
	(43742),
	(43743),
	(43744),
	(43745),
	(43746),
	(43747),
	(43748),
	(43749),
	(43750),
	(43751),
	(43752),
	(43753),
	(43754),
	(43755),
	(43756),
	(43757),
	(43758),
	(43759),
	(43760),
	(43761),
	(43762),
	(43763),
	(43764),
	(43765),
	(43766),
	(43767),
	(43768),
	(43769),
	(43770),
	(43771),
	(43772),
	(43773),
	(43774),
	(43775),
	(43776),
	(43777),
	(43778),
	(43779),
	(43780),
	(43781),
	(43782),
	(43783),
	(43784),
	(43785),
	(43786),
	(43787),
	(43788),
	(43789),
	(43790),
	(43791),
	(43792),
	(43793),
	(43794),
	(43795),
	(43796),
	(43797),
	(43798),
	(43799),
	(43800),
	(43801),
	(43802),
	(43803),
	(43804),
	(43805),
	(43806),
	(43807),
	(43808),
	(43809),
	(43810),
	(43811),
	(43812),
	(43813),
	(43814),
	(43815),
	(43816),
	(43817),
	(43818),
	(43819),
	(43820),
	(43821),
	(43822),
	(43823),
	(43824),
	(43825),
	(43826),
	(43827),
	(43828),
	(43829),
	(43830),
	(43831),
	(43832),
	(43833),
	(43834),
	(43835),
	(43836),
	(43837),
	(43838),
	(43839),
	(43840),
	(43841),
	(43842),
	(43843),
	(43844),
	(43845),
	(43846),
	(43847),
	(43848),
	(43849),
	(43850),
	(43851),
	(43852),
	(43853),
	(43854),
	(43855),
	(43856),
	(43857),
	(43858),
	(43859),
	(43860),
	(43861),
	(43862),
	(43863),
	(43864),
	(43865),
	(43866),
	(43867),
	(43868),
	(43869),
	(43870),
	(43871),
	(43872),
	(43873),
	(43874),
	(43875),
	(43876),
	(43877),
	(43878),
	(43879),
	(43880),
	(43881),
	(43882),
	(43883),
	(43884),
	(43885),
	(43886),
	(43887),
	(43888),
	(43889),
	(43890),
	(43891),
	(43892),
	(43893),
	(43894),
	(43895),
	(43896),
	(43897),
	(43898),
	(43899),
	(43900),
	(43901),
	(43902),
	(43903),
	(43904),
	(43905),
	(43906),
	(43907),
	(43908),
	(43909),
	(43910),
	(43911),
	(43912),
	(43913),
	(43914),
	(43915),
	(43916),
	(43917),
	(43918),
	(43919),
	(43920),
	(43921),
	(43922),
	(43923),
	(43924),
	(43925),
	(43926),
	(43927),
	(43928),
	(43929),
	(43930),
	(43931),
	(43932),
	(43933),
	(43934),
	(43935),
	(43936),
	(43937),
	(43938),
	(43939),
	(43940),
	(43941),
	(43942),
	(43943),
	(43944),
	(43945),
	(43946),
	(43947),
	(43948),
	(43949),
	(43950),
	(43951),
	(43952),
	(43953),
	(43954),
	(43955),
	(43956),
	(43957),
	(43958),
	(43959),
	(43960),
	(43961),
	(43962),
	(43963),
	(43964),
	(43965),
	(43966),
	(43967),
	(43968),
	(43969),
	(43970),
	(43971),
	(43972),
	(43973),
	(43974),
	(43975),
	(43976),
	(43977),
	(43978),
	(43979),
	(43980),
	(43981),
	(43982),
	(43983),
	(43984),
	(43985),
	(43986),
	(43987),
	(43988),
	(43989),
	(43990),
	(43991),
	(43992),
	(43993),
	(43994),
	(43995),
	(43996),
	(43997),
	(43998),
	(43999),
	(44000),
	(44001),
	(44002),
	(44003),
	(44004),
	(44005),
	(44006),
	(44007),
	(44008),
	(44009),
	(44010),
	(44011),
	(44012),
	(44013),
	(44014),
	(44015),
	(44016),
	(44017),
	(44018),
	(44019),
	(44020),
	(44021),
	(44022),
	(44023),
	(44024),
	(44025),
	(44026),
	(44027),
	(44028),
	(44029),
	(44030),
	(44031),
	(44032),
	(44033),
	(44034),
	(44035),
	(44036),
	(44037),
	(44038),
	(44039),
	(44040),
	(44041),
	(44042),
	(44043),
	(44044),
	(44045),
	(44046),
	(44047),
	(44048),
	(44049),
	(44050),
	(44051),
	(44052),
	(44053),
	(44054),
	(44055),
	(44056),
	(44057),
	(44058),
	(44059),
	(44060),
	(44061),
	(44062),
	(44063),
	(44064),
	(44065),
	(44066),
	(44067),
	(44068),
	(44069),
	(44070),
	(44071),
	(44072),
	(44073),
	(44074),
	(44075),
	(44076),
	(44077),
	(44078),
	(44079),
	(44080),
	(44081),
	(44082),
	(44083),
	(44084),
	(44085),
	(44086),
	(44087),
	(44088),
	(44089),
	(44090),
	(44091),
	(44092),
	(44093),
	(44094),
	(44095),
	(44096),
	(44097),
	(44098),
	(44099),
	(44100),
	(44101),
	(44102),
	(44103),
	(44104),
	(44105),
	(44106),
	(44107),
	(44108),
	(44109),
	(44110),
	(44111),
	(44112),
	(44113),
	(44114),
	(44115),
	(44116),
	(44117),
	(44118),
	(44119),
	(44120),
	(44121),
	(44122),
	(44123),
	(44124),
	(44125),
	(44126),
	(44127),
	(44128),
	(44129),
	(44130),
	(44131),
	(44132),
	(44133),
	(44134),
	(44135),
	(44136),
	(44137),
	(44138),
	(44139),
	(44140),
	(44141),
	(44142),
	(44143),
	(44144),
	(44145),
	(44146),
	(44147),
	(44148),
	(44149),
	(44150),
	(44151),
	(44152),
	(44153),
	(44154),
	(44155),
	(44156),
	(44157),
	(44158),
	(44159),
	(44160),
	(44161),
	(44162),
	(44163),
	(44164),
	(44165),
	(44166),
	(44167),
	(44168),
	(44169),
	(44170),
	(44171),
	(44172),
	(44173),
	(44174),
	(44175),
	(44176),
	(44177),
	(44178),
	(44179),
	(44180),
	(44181),
	(44182),
	(44183),
	(44184),
	(44185),
	(44186),
	(44187),
	(44188),
	(44189),
	(44190),
	(44191),
	(44192),
	(44193),
	(44194),
	(44195),
	(44196),
	(44197),
	(44198),
	(44199),
	(44200),
	(44201),
	(44202),
	(44203),
	(44204),
	(44205),
	(44206),
	(44207),
	(44208),
	(44209),
	(44210),
	(44211),
	(44212),
	(44213),
	(44214),
	(44215),
	(44216),
	(44217),
	(44218),
	(44219),
	(44220),
	(44221),
	(44222),
	(44223),
	(44224),
	(44225),
	(44226),
	(44227),
	(44228),
	(44229),
	(44230),
	(44231),
	(44232),
	(44233),
	(44234),
	(44235),
	(44236),
	(44237),
	(44238),
	(44239),
	(44240),
	(44241),
	(44242),
	(44243),
	(44244),
	(44245),
	(44246),
	(44247),
	(44248),
	(44249),
	(44250),
	(44251),
	(44252),
	(44253),
	(44254),
	(44255),
	(44256),
	(44257),
	(44258),
	(44259),
	(44260),
	(44261),
	(44262),
	(44263),
	(44264),
	(44265),
	(44266),
	(44267),
	(44268),
	(44269),
	(44270),
	(44271),
	(44272),
	(44273),
	(44274),
	(44275),
	(44276),
	(44277),
	(44278),
	(44279),
	(44280),
	(44281),
	(44282),
	(44283),
	(44284),
	(44285),
	(44286),
	(44287),
	(44288),
	(44289),
	(44290),
	(44291),
	(44292),
	(44293),
	(44294),
	(44295),
	(44296),
	(44297),
	(44298),
	(44299),
	(44300),
	(44301),
	(44302),
	(44303),
	(44304),
	(44305),
	(44306),
	(44307),
	(44308),
	(44309),
	(44310),
	(44311),
	(44312),
	(44313),
	(44314),
	(44315),
	(44316),
	(44317),
	(44318),
	(44319),
	(44320),
	(44321),
	(44322),
	(44323),
	(44324),
	(44325),
	(44326),
	(44327),
	(44328),
	(44329),
	(44330),
	(44331),
	(44332),
	(44333),
	(44334),
	(44335),
	(44336),
	(44337),
	(44338),
	(44339),
	(44340),
	(44341),
	(44342),
	(44343),
	(44344),
	(44345),
	(44346),
	(44347),
	(44348),
	(44349),
	(44350),
	(44351),
	(44352),
	(44353),
	(44354),
	(44355),
	(44356),
	(44357),
	(44358),
	(44359),
	(44360),
	(44361),
	(44362),
	(44363),
	(44364),
	(44365),
	(44366),
	(44367),
	(44368),
	(44369),
	(44370),
	(44371),
	(44372),
	(44373),
	(44374),
	(44375),
	(44376),
	(44377),
	(44378),
	(44379),
	(44380),
	(44381),
	(44382),
	(44383),
	(44384),
	(44385),
	(44386),
	(44387),
	(44388),
	(44389),
	(44390),
	(44391),
	(44392),
	(44393),
	(44394),
	(44395),
	(44396),
	(44397),
	(44398),
	(44399),
	(44400),
	(44401),
	(44402),
	(44403),
	(44404),
	(44405),
	(44406),
	(44407),
	(44408),
	(44409),
	(44410),
	(44411),
	(44412),
	(44413),
	(44414),
	(44415),
	(44416),
	(44417),
	(44418),
	(44419),
	(44420),
	(44421),
	(44422),
	(44423),
	(44424),
	(44425),
	(44426),
	(44427),
	(44428),
	(44429),
	(44430),
	(44431),
	(44432),
	(44433),
	(44434),
	(44435),
	(44436),
	(44437),
	(44438),
	(44439),
	(44440),
	(44441),
	(44442),
	(44443),
	(44444),
	(44445),
	(44446),
	(44447),
	(44448),
	(44449),
	(44450),
	(44451),
	(44452),
	(44453),
	(44454),
	(44455),
	(44456),
	(44457),
	(44458),
	(44459),
	(44460),
	(44461),
	(44462),
	(44463),
	(44464),
	(44465),
	(44466),
	(44467),
	(44468),
	(44469),
	(44470),
	(44471),
	(44472),
	(44473),
	(44474),
	(44475),
	(44476),
	(44477),
	(44478),
	(44479),
	(44480),
	(44481),
	(44482),
	(44483),
	(44484),
	(44485),
	(44486),
	(44487),
	(44488),
	(44489),
	(44490),
	(44491),
	(44492),
	(44493),
	(44494),
	(44495),
	(44496),
	(44497),
	(44498),
	(44499),
	(44500),
	(44501),
	(44502),
	(44503),
	(44504),
	(44505),
	(44506),
	(44507),
	(44508),
	(44509),
	(44510),
	(44511),
	(44512),
	(44513),
	(44514),
	(44515),
	(44516),
	(44517),
	(44518),
	(44519),
	(44520),
	(44521),
	(44522),
	(44523),
	(44524),
	(44525),
	(44526),
	(44527),
	(44528),
	(44529),
	(44530),
	(44531),
	(44532),
	(44533),
	(44534),
	(44535),
	(44536),
	(44537),
	(44538),
	(44539),
	(44540),
	(44541),
	(44542),
	(44543),
	(44544),
	(44545),
	(44546),
	(44547),
	(44548),
	(44549),
	(44550),
	(44551),
	(44552),
	(44553),
	(44554),
	(44555),
	(44556),
	(44557),
	(44558),
	(44559),
	(44560),
	(44561),
	(44562),
	(44563),
	(44564),
	(44565),
	(44566),
	(44567),
	(44568),
	(44569),
	(44570),
	(44571),
	(44572),
	(44573),
	(44574),
	(44575),
	(44576),
	(44577),
	(44578),
	(44579),
	(44580),
	(44581),
	(44582),
	(44583),
	(44584),
	(44585),
	(44586),
	(44587),
	(44588),
	(44589),
	(44590),
	(44591),
	(44592),
	(44593),
	(44594),
	(44595),
	(44596),
	(44597),
	(44598),
	(44599),
	(44600),
	(44601),
	(44602),
	(44603),
	(44604),
	(44605),
	(44606),
	(44607),
	(44608),
	(44609),
	(44610),
	(44611),
	(44612),
	(44613),
	(44614),
	(44615),
	(44616),
	(44617),
	(44618),
	(44619),
	(44620),
	(44621),
	(44622),
	(44623),
	(44624),
	(44625),
	(44626),
	(44627),
	(44628),
	(44629),
	(44630),
	(44631),
	(44632),
	(44633),
	(44634),
	(44635),
	(44636),
	(44637),
	(44638),
	(44639),
	(44640),
	(44641),
	(44642),
	(44643),
	(44644),
	(44645),
	(44646),
	(44647),
	(44648),
	(44649),
	(44650),
	(44651),
	(44652),
	(44653),
	(44654),
	(44655),
	(44656),
	(44657),
	(44658),
	(44659),
	(44660),
	(44661),
	(44662),
	(44663),
	(44664),
	(44665),
	(44666),
	(44667),
	(44668),
	(44669),
	(44670),
	(44671),
	(44672),
	(44673),
	(44674),
	(44675),
	(44676),
	(44677),
	(44678),
	(44679),
	(44680),
	(44681),
	(44682),
	(44683),
	(44684),
	(44685),
	(44686),
	(44687),
	(44688),
	(44689),
	(44690),
	(44691),
	(44692),
	(44693),
	(44694),
	(44695),
	(44696),
	(44697),
	(44698),
	(44699),
	(44700),
	(44701),
	(44702),
	(44703),
	(44704),
	(44705),
	(44706),
	(44707),
	(44708),
	(44709),
	(44710),
	(44711),
	(44712),
	(44713),
	(44714),
	(44715),
	(44716),
	(44717),
	(44718),
	(44719),
	(44720),
	(44721),
	(44722),
	(44723),
	(44724),
	(44725),
	(44726),
	(44727),
	(44728),
	(44729),
	(44730),
	(44731),
	(44732),
	(44733),
	(44734),
	(44735),
	(44736),
	(44737),
	(44738),
	(44739),
	(44740),
	(44741),
	(44742),
	(44743),
	(44744),
	(44745),
	(44746),
	(44747),
	(44748),
	(44749),
	(44750),
	(44751),
	(44752),
	(44753),
	(44754),
	(44755),
	(44756),
	(44757),
	(44758),
	(44759),
	(44760),
	(44761),
	(44762),
	(44763),
	(44764),
	(44765),
	(44766),
	(44767),
	(44768),
	(44769),
	(44770),
	(44771),
	(44772),
	(44773),
	(44774),
	(44775),
	(44776),
	(44777),
	(44778),
	(44779),
	(44780),
	(44781),
	(44782),
	(44783),
	(44784),
	(44785),
	(44786),
	(44787),
	(44788),
	(44789),
	(44790),
	(44791),
	(44792),
	(44793),
	(44794),
	(44795),
	(44796),
	(44797),
	(44798),
	(44799),
	(44800),
	(44801),
	(44802),
	(44803),
	(44804),
	(44805),
	(44806),
	(44807),
	(44808),
	(44809),
	(44810),
	(44811),
	(44812),
	(44813),
	(44814),
	(44815),
	(44816),
	(44817),
	(44818),
	(44819),
	(44820),
	(44821),
	(44822),
	(44823),
	(44824),
	(44825),
	(44826),
	(44827),
	(44828),
	(44829),
	(44830),
	(44831),
	(44832),
	(44833),
	(44834),
	(44835),
	(44836),
	(44837),
	(44838),
	(44839),
	(44840),
	(44841),
	(44842),
	(44843),
	(44844),
	(44845),
	(44846),
	(44847),
	(44848),
	(44849),
	(44850),
	(44851),
	(44852),
	(44853),
	(44854),
	(44855),
	(44856),
	(44857),
	(44858),
	(44859),
	(44860),
	(44861),
	(44862),
	(44863),
	(44864),
	(44865),
	(44866),
	(44867),
	(44868),
	(44869),
	(44870),
	(44871),
	(44872),
	(44873),
	(44874),
	(44875),
	(44876),
	(44877),
	(44878),
	(44879),
	(44880),
	(44881),
	(44882),
	(44883),
	(44884),
	(44885),
	(44886),
	(44887),
	(44888),
	(44889),
	(44890),
	(44891),
	(44892),
	(44893),
	(44894),
	(44895),
	(44896),
	(44897),
	(44898),
	(44899),
	(44900),
	(44901),
	(44902),
	(44903),
	(44904),
	(44905),
	(44906),
	(44907),
	(44908),
	(44909),
	(44910),
	(44911),
	(44912),
	(44913),
	(44914),
	(44915),
	(44916),
	(44917),
	(44918),
	(44919),
	(44920),
	(44921),
	(44922),
	(44923),
	(44924),
	(44925),
	(44926),
	(44927),
	(44928),
	(44929),
	(44930),
	(44931),
	(44932),
	(44933),
	(44934),
	(44935),
	(44936),
	(44937),
	(44938),
	(44939),
	(44940),
	(44941),
	(44942),
	(44943),
	(44944),
	(44945),
	(44946),
	(44947),
	(44948),
	(44949),
	(44950),
	(44951),
	(44952),
	(44953),
	(44954),
	(44955),
	(44956),
	(44957),
	(44958),
	(44959),
	(44960),
	(44961),
	(44962),
	(44963),
	(44964),
	(44965),
	(44966),
	(44967),
	(44968),
	(44969),
	(44970),
	(44971),
	(44972),
	(44973),
	(44974),
	(44975),
	(44976),
	(44977),
	(44978),
	(44979),
	(44980),
	(44981),
	(44982),
	(44983),
	(44984),
	(44985),
	(44986),
	(44987),
	(44988),
	(44989),
	(44990),
	(44991),
	(44992),
	(44993),
	(44994),
	(44995),
	(44996),
	(44997),
	(44998),
	(44999),
	(45000),
	(45001),
	(45002),
	(45003),
	(45004),
	(45005),
	(45006),
	(45007),
	(45008),
	(45009),
	(45010),
	(45011),
	(45012),
	(45013),
	(45014),
	(45015),
	(45016),
	(45017),
	(45018),
	(45019),
	(45020),
	(45021),
	(45022),
	(45023),
	(45024),
	(45025),
	(45026),
	(45027),
	(45028),
	(45029),
	(45030),
	(45031),
	(45032),
	(45033),
	(45034),
	(45035),
	(45036),
	(45037),
	(45038),
	(45039),
	(45040),
	(45041),
	(45042),
	(45043),
	(45044),
	(45045),
	(45046),
	(45047),
	(45048),
	(45049),
	(45050),
	(45051),
	(45052),
	(45053),
	(45054),
	(45055),
	(45056),
	(45057),
	(45058),
	(45059),
	(45060),
	(45061),
	(45062),
	(45063),
	(45064),
	(45065),
	(45066),
	(45067),
	(45068),
	(45069),
	(45070),
	(45071),
	(45072),
	(45073),
	(45074),
	(45075),
	(45076),
	(45077),
	(45078),
	(45079),
	(45080),
	(45081),
	(45082),
	(45083),
	(45084),
	(45085),
	(45086),
	(45087),
	(45088),
	(45089),
	(45090),
	(45091),
	(45092),
	(45093),
	(45094),
	(45095),
	(45096),
	(45097),
	(45098),
	(45099),
	(45100),
	(45101),
	(45102),
	(45103),
	(45104),
	(45105),
	(45106),
	(45107),
	(45108),
	(45109),
	(45110),
	(45111),
	(45112),
	(45113),
	(45114),
	(45115),
	(45116),
	(45117),
	(45118),
	(45119),
	(45120),
	(45121),
	(45122),
	(45123),
	(45124),
	(45125),
	(45126),
	(45127),
	(45128),
	(45129),
	(45130),
	(45131),
	(45132),
	(45133),
	(45134),
	(45135),
	(45136),
	(45137),
	(45138),
	(45139),
	(45140),
	(45141),
	(45142),
	(45143),
	(45144),
	(45145),
	(45146),
	(45147),
	(45148),
	(45149),
	(45150),
	(45151),
	(45152),
	(45153),
	(45154),
	(45155),
	(45156),
	(45157),
	(45158),
	(45159),
	(45160),
	(45161),
	(45162),
	(45163),
	(45164),
	(45165),
	(45166),
	(45167),
	(45168),
	(45169),
	(45170),
	(45171),
	(45172),
	(45173),
	(45174),
	(45175),
	(45176),
	(45177),
	(45178),
	(45179),
	(45180),
	(45181),
	(45182),
	(45183),
	(45184),
	(45185),
	(45186),
	(45187),
	(45188),
	(45189),
	(45190),
	(45191),
	(45192),
	(45193),
	(45194),
	(45195),
	(45196),
	(45197),
	(45198),
	(45199),
	(45200),
	(45201),
	(45202),
	(45203),
	(45204),
	(45205),
	(45206),
	(45207),
	(45208),
	(45209),
	(45210),
	(45211),
	(45212),
	(45213),
	(45214),
	(45215),
	(45216),
	(45217),
	(45218),
	(45219),
	(45220),
	(45221),
	(45222),
	(45223),
	(45224),
	(45225),
	(45226),
	(45227),
	(45228),
	(45229),
	(45230),
	(45231),
	(45232),
	(45233),
	(45234),
	(45235),
	(45236),
	(45237),
	(45238),
	(45239),
	(45240),
	(45241),
	(45242),
	(45243),
	(45244),
	(45245),
	(45246),
	(45247),
	(45248),
	(45249),
	(45250),
	(45251),
	(45252),
	(45253),
	(45254),
	(45255),
	(45256),
	(45257),
	(45258),
	(45259),
	(45260),
	(45261),
	(45262),
	(45263),
	(45264),
	(45265),
	(45266),
	(45267),
	(45268),
	(45269),
	(45270),
	(45271),
	(45272),
	(45273),
	(45274),
	(45275),
	(45276),
	(45277),
	(45278),
	(45279),
	(45280),
	(45281),
	(45282),
	(45283),
	(45284),
	(45285),
	(45286),
	(45287),
	(45288),
	(45289),
	(45290),
	(45291),
	(45292),
	(45293),
	(45294),
	(45295),
	(45296),
	(45297),
	(45298),
	(45299),
	(45300),
	(45301),
	(45302),
	(45303),
	(45304),
	(45305),
	(45306),
	(45307),
	(45308),
	(45309),
	(45310),
	(45311),
	(45312),
	(45313),
	(45314),
	(45315),
	(45316),
	(45317),
	(45318),
	(45319),
	(45320),
	(45321),
	(45322),
	(45323),
	(45324),
	(45325),
	(45326),
	(45327),
	(45328),
	(45329),
	(45330),
	(45331),
	(45332),
	(45333),
	(45334),
	(45335),
	(45336),
	(45337),
	(45338),
	(45339),
	(45340),
	(45341),
	(45342),
	(45343),
	(45344),
	(45345),
	(45346),
	(45347),
	(45348),
	(45349),
	(45350),
	(45351),
	(45352),
	(45353),
	(45354),
	(45355),
	(45356),
	(45357),
	(45358),
	(45359),
	(45360),
	(45361),
	(45362),
	(45363),
	(45364),
	(45365),
	(45366),
	(45367),
	(45368),
	(45369),
	(45370),
	(45371),
	(45372),
	(45373),
	(45374),
	(45375),
	(45376),
	(45377),
	(45378),
	(45379),
	(45380),
	(45381),
	(45382),
	(45383),
	(45384),
	(45385),
	(45386),
	(45387),
	(45388),
	(45389),
	(45390),
	(45391),
	(45392),
	(45393),
	(45394),
	(45395),
	(45396),
	(45397),
	(45398),
	(45399),
	(45400),
	(45401),
	(45402),
	(45403),
	(45404),
	(45405),
	(45406),
	(45407),
	(45408),
	(45409),
	(45410),
	(45411),
	(45412),
	(45413),
	(45414),
	(45415),
	(45416),
	(45417),
	(45418),
	(45419),
	(45420),
	(45421),
	(45422),
	(45423),
	(45424),
	(45425),
	(45426),
	(45427),
	(45428),
	(45429),
	(45430),
	(45431),
	(45432),
	(45433),
	(45434),
	(45435),
	(45436),
	(45437),
	(45438),
	(45439),
	(45440),
	(45441),
	(45442),
	(45443),
	(45444),
	(45445),
	(45446),
	(45447),
	(45448),
	(45449),
	(45450),
	(45451),
	(45452),
	(45453),
	(45454),
	(45455),
	(45456),
	(45457),
	(45458),
	(45459),
	(45460),
	(45461),
	(45462),
	(45463),
	(45464),
	(45465),
	(45466),
	(45467),
	(45468),
	(45469),
	(45470),
	(45471),
	(45472),
	(45473),
	(45474),
	(45475),
	(45476),
	(45477),
	(45478),
	(45479),
	(45480),
	(45481),
	(45482),
	(45483),
	(45484),
	(45485),
	(45486),
	(45487),
	(45488),
	(45489),
	(45490),
	(45491),
	(45492),
	(45493),
	(45494),
	(45495),
	(45496),
	(45497),
	(45498),
	(45499),
	(45500),
	(45501),
	(45502),
	(45503),
	(45504),
	(45505),
	(45506),
	(45507),
	(45508),
	(45509),
	(45510),
	(45511),
	(45512),
	(45513),
	(45514),
	(45515),
	(45516),
	(45517),
	(45518),
	(45519),
	(45520),
	(45521),
	(45522),
	(45523),
	(45524),
	(45525),
	(45526),
	(45527),
	(45528),
	(45529),
	(45530),
	(45531),
	(45532),
	(45533),
	(45534),
	(45535),
	(45536),
	(45537),
	(45538),
	(45539),
	(45540),
	(45541),
	(45542),
	(45543),
	(45544),
	(45545),
	(45546),
	(45547),
	(45548),
	(45549),
	(45550),
	(45551),
	(45552),
	(45553),
	(45554),
	(45555),
	(45556),
	(45557),
	(45558),
	(45559),
	(45560),
	(45561),
	(45562),
	(45563),
	(45564),
	(45565),
	(45566),
	(45567),
	(45568),
	(45569),
	(45570),
	(45571),
	(45572),
	(45573),
	(45574),
	(45575),
	(45576),
	(45577),
	(45578),
	(45579),
	(45580),
	(45581),
	(45582),
	(45583),
	(45584),
	(45585),
	(45586),
	(45587),
	(45588),
	(45589),
	(45590),
	(45591),
	(45592),
	(45593),
	(45594),
	(45595),
	(45596),
	(45597),
	(45598),
	(45599),
	(45600),
	(45601),
	(45602),
	(45603),
	(45604),
	(45605),
	(45606),
	(45607),
	(45608),
	(45609),
	(45610),
	(45611),
	(45612),
	(45613),
	(45614),
	(45615),
	(45616),
	(45617),
	(45618),
	(45619),
	(45620),
	(45621),
	(45622),
	(45623),
	(45624),
	(45625),
	(45626),
	(45627),
	(45628),
	(45629),
	(45630),
	(45631),
	(45632),
	(45633),
	(45634),
	(45635),
	(45636),
	(45637),
	(45638),
	(45639),
	(45640),
	(45641),
	(45642),
	(45643),
	(45644),
	(45645),
	(45646),
	(45647),
	(45648),
	(45649),
	(45650),
	(45651),
	(45652),
	(45653),
	(45654),
	(45655),
	(45656),
	(45657),
	(45658),
	(45659),
	(45660),
	(45661),
	(45662),
	(45663),
	(45664),
	(45665),
	(45666),
	(45667),
	(45668),
	(45669),
	(45670),
	(45671),
	(45672),
	(45673),
	(45674),
	(45675),
	(45676),
	(45677),
	(45678),
	(45679),
	(45680),
	(45681),
	(45682),
	(45683),
	(45684),
	(45685),
	(45686),
	(45687),
	(45688),
	(45689),
	(45690),
	(45691),
	(45692),
	(45693),
	(45694),
	(45695),
	(45696),
	(45697),
	(45698),
	(45699),
	(45700),
	(45701),
	(45702),
	(45703),
	(45704),
	(45705),
	(45706),
	(45707),
	(45708),
	(45709),
	(45710),
	(45711),
	(45712),
	(45713),
	(45714),
	(45715),
	(45716),
	(45717),
	(45718),
	(45719),
	(45720),
	(45721),
	(45722),
	(45723),
	(45724),
	(45725),
	(45726),
	(45727),
	(45728),
	(45729),
	(45730),
	(45731),
	(45732),
	(45733),
	(45734),
	(45735),
	(45736),
	(45737),
	(45738),
	(45739),
	(45740),
	(45741),
	(45742),
	(45743),
	(45744),
	(45745),
	(45746),
	(45747),
	(45748),
	(45749),
	(45750),
	(45751),
	(45752),
	(45753),
	(45754),
	(45755),
	(45756),
	(45757),
	(45758),
	(45759),
	(45760),
	(45761),
	(45762),
	(45763),
	(45764),
	(45765),
	(45766),
	(45767),
	(45768),
	(45769),
	(45770),
	(45771),
	(45772),
	(45773),
	(45774),
	(45775),
	(45776),
	(45777),
	(45778),
	(45779),
	(45780),
	(45781),
	(45782),
	(45783),
	(45784),
	(45785),
	(45786),
	(45787),
	(45788),
	(45789),
	(45790),
	(45791),
	(45792),
	(45793),
	(45794),
	(45795),
	(45796),
	(45797),
	(45798),
	(45799),
	(45800),
	(45801),
	(45802),
	(45803),
	(45804),
	(45805),
	(45806),
	(45807),
	(45808),
	(45809),
	(45810),
	(45811),
	(45812),
	(45813),
	(45814),
	(45815),
	(45816),
	(45817),
	(45818),
	(45819),
	(45820),
	(45821),
	(45822),
	(45823),
	(45824),
	(45825),
	(45826),
	(45827),
	(45828),
	(45829),
	(45830),
	(45831),
	(45832),
	(45833),
	(45834),
	(45835),
	(45836),
	(45837),
	(45838),
	(45839),
	(45840),
	(45841),
	(45842),
	(45843),
	(45844),
	(45845),
	(45846),
	(45847),
	(45848),
	(45849),
	(45850),
	(45851),
	(45852),
	(45853),
	(45854),
	(45855),
	(45856),
	(45857),
	(45858),
	(45859),
	(45860),
	(45861),
	(45862),
	(45863),
	(45864),
	(45865),
	(45866),
	(45867),
	(45868),
	(45869),
	(45870),
	(45871),
	(45872),
	(45873),
	(45874),
	(45875),
	(45876),
	(45877),
	(45878),
	(45879),
	(45880),
	(45881),
	(45882),
	(45883),
	(45884),
	(45885),
	(45886),
	(45887),
	(45888),
	(45889),
	(45890),
	(45891),
	(45892),
	(45893),
	(45894),
	(45895),
	(45896),
	(45897),
	(45898),
	(45899),
	(45900),
	(45901),
	(45902),
	(45903),
	(45904),
	(45905),
	(45906),
	(45907),
	(45908),
	(45909),
	(45910),
	(45911),
	(45912),
	(45913),
	(45914),
	(45915),
	(45916),
	(45917),
	(45918),
	(45919),
	(45920),
	(45921),
	(45922),
	(45923),
	(45924),
	(45925),
	(45926),
	(45927),
	(45928),
	(45929),
	(45930),
	(45931),
	(45932),
	(45933),
	(45934),
	(45935),
	(45936),
	(45937),
	(45938),
	(45939),
	(45940),
	(45941),
	(45942),
	(45943),
	(45944),
	(45945),
	(45946),
	(45947),
	(45948),
	(45949),
	(45950),
	(45951),
	(45952),
	(45953),
	(45954),
	(45955),
	(45956),
	(45957),
	(45958),
	(45959),
	(45960),
	(45961),
	(45962),
	(45963),
	(45964),
	(45965),
	(45966),
	(45967),
	(45968),
	(45969),
	(45970),
	(45971),
	(45972),
	(45973),
	(45974),
	(45975),
	(45976),
	(45977),
	(45978),
	(45979),
	(45980),
	(45981),
	(45982),
	(45983),
	(45984),
	(45985),
	(45986),
	(45987),
	(45988),
	(45989),
	(45990),
	(45991),
	(45992),
	(45993),
	(45994),
	(45995),
	(45996),
	(45997),
	(45998),
	(45999),
	(46000),
	(46001),
	(46002),
	(46003),
	(46004),
	(46005),
	(46006),
	(46007),
	(46008),
	(46009),
	(46010),
	(46011),
	(46012),
	(46013),
	(46014),
	(46015),
	(46016),
	(46017),
	(46018),
	(46019),
	(46020),
	(46021),
	(46022),
	(46023),
	(46024),
	(46025),
	(46026),
	(46027),
	(46028),
	(46029),
	(46030),
	(46031),
	(46032),
	(46033),
	(46034),
	(46035),
	(46036),
	(46037),
	(46038),
	(46039),
	(46040),
	(46041),
	(46042),
	(46043),
	(46044),
	(46045),
	(46046),
	(46047),
	(46048),
	(46049),
	(46050),
	(46051),
	(46052),
	(46053),
	(46054),
	(46055),
	(46056),
	(46057),
	(46058),
	(46059),
	(46060),
	(46061),
	(46062),
	(46063),
	(46064),
	(46065),
	(46066),
	(46067),
	(46068),
	(46069),
	(46070),
	(46071),
	(46072),
	(46073),
	(46074),
	(46075),
	(46076),
	(46077),
	(46078),
	(46079),
	(46080),
	(46081),
	(46082),
	(46083),
	(46084),
	(46085),
	(46086),
	(46087),
	(46088),
	(46089),
	(46090),
	(46091),
	(46092),
	(46093),
	(46094),
	(46095),
	(46096),
	(46097),
	(46098),
	(46099),
	(46100),
	(46101),
	(46102),
	(46103),
	(46104),
	(46105),
	(46106),
	(46107),
	(46108),
	(46109),
	(46110),
	(46111),
	(46112),
	(46113),
	(46114),
	(46115),
	(46116),
	(46117),
	(46118),
	(46119),
	(46120),
	(46121),
	(46122),
	(46123),
	(46124),
	(46125),
	(46126),
	(46127),
	(46128),
	(46129),
	(46130),
	(46131),
	(46132),
	(46133),
	(46134),
	(46135),
	(46136),
	(46137),
	(46138),
	(46139),
	(46140),
	(46141),
	(46142),
	(46143),
	(46144),
	(46145),
	(46146),
	(46147),
	(46148),
	(46149),
	(46150),
	(46151),
	(46152),
	(46153),
	(46154),
	(46155),
	(46156),
	(46157),
	(46158),
	(46159),
	(46160),
	(46161),
	(46162),
	(46163),
	(46164),
	(46165),
	(46166),
	(46167),
	(46168),
	(46169),
	(46170),
	(46171),
	(46172),
	(46173),
	(46174),
	(46175),
	(46176),
	(46177),
	(46178),
	(46179),
	(46180),
	(46181),
	(46182),
	(46183),
	(46184),
	(46185),
	(46186),
	(46187),
	(46188),
	(46189),
	(46190),
	(46191),
	(46192),
	(46193),
	(46194),
	(46195),
	(46196),
	(46197),
	(46198),
	(46199),
	(46200),
	(46201),
	(46202),
	(46203),
	(46204),
	(46205),
	(46206),
	(46207),
	(46208),
	(46209),
	(46210),
	(46211),
	(46212),
	(46213),
	(46214),
	(46215),
	(46216),
	(46217),
	(46218),
	(46219),
	(46220),
	(46221),
	(46222),
	(46223),
	(46224),
	(46225),
	(46226),
	(46227),
	(46228),
	(46229),
	(46230),
	(46231),
	(46232),
	(46233),
	(46234),
	(46235),
	(46236),
	(46237),
	(46238),
	(46239),
	(46240),
	(46241),
	(46242),
	(46243),
	(46244),
	(46245),
	(46246),
	(46247),
	(46248),
	(46249),
	(46250),
	(46251),
	(46252),
	(46253),
	(46254),
	(46255),
	(46256),
	(46257),
	(46258),
	(46259),
	(46260),
	(46261),
	(46262),
	(46263),
	(46264),
	(46265),
	(46266),
	(46267),
	(46268),
	(46269),
	(46270),
	(46271),
	(46272),
	(46273),
	(46274),
	(46275),
	(46276),
	(46277),
	(46278),
	(46279),
	(46280),
	(46281),
	(46282),
	(46283),
	(46284),
	(46285),
	(46286),
	(46287),
	(46288),
	(46289),
	(46290),
	(46291),
	(46292),
	(46293),
	(46294),
	(46295),
	(46296),
	(46297),
	(46298),
	(46299),
	(46300),
	(46301),
	(46302),
	(46303),
	(46304),
	(46305),
	(46306),
	(46307),
	(46308),
	(46309),
	(46310),
	(46311),
	(46312),
	(46313),
	(46314),
	(46315),
	(46316),
	(46317),
	(46318),
	(46319),
	(46320),
	(46321),
	(46322),
	(46323),
	(46324),
	(46325),
	(46326),
	(46327),
	(46328),
	(46329),
	(46330),
	(46331),
	(46332),
	(46333),
	(46334),
	(46335),
	(46336),
	(46337),
	(46338),
	(46339),
	(46340),
	(46341),
	(46342),
	(46343),
	(46344),
	(46345),
	(46346),
	(46347),
	(46348),
	(46349),
	(46350),
	(46351),
	(46352),
	(46353),
	(46354),
	(46355),
	(46356),
	(46357),
	(46358),
	(46359),
	(46360),
	(46361),
	(46362),
	(46363),
	(46364),
	(46365),
	(46366),
	(46367),
	(46368),
	(46369),
	(46370),
	(46371),
	(46372),
	(46373),
	(46374),
	(46375),
	(46376),
	(46377),
	(46378),
	(46379),
	(46380),
	(46381),
	(46382),
	(46383),
	(46384),
	(46385),
	(46386),
	(46387),
	(46388),
	(46389),
	(46390),
	(46391),
	(46392),
	(46393),
	(46394),
	(46395),
	(46396),
	(46397),
	(46398),
	(46399),
	(46400),
	(46401),
	(46402),
	(46403),
	(46404),
	(46405),
	(46406),
	(46407),
	(46408),
	(46409),
	(46410),
	(46411),
	(46412),
	(46413),
	(46414),
	(46415),
	(46416),
	(46417),
	(46418),
	(46419),
	(46420),
	(46421),
	(46422),
	(46423),
	(46424),
	(46425),
	(46426),
	(46427),
	(46428),
	(46429),
	(46430),
	(46431),
	(46432),
	(46433),
	(46434),
	(46435),
	(46436),
	(46437),
	(46438),
	(46439),
	(46440),
	(46441),
	(46442),
	(46443),
	(46444),
	(46445),
	(46446),
	(46447),
	(46448),
	(46449),
	(46450),
	(46451),
	(46452),
	(46453),
	(46454),
	(46455),
	(46456),
	(46457),
	(46458),
	(46459),
	(46460),
	(46461),
	(46462),
	(46463),
	(46464),
	(46465),
	(46466),
	(46467),
	(46468),
	(46469),
	(46470),
	(46471),
	(46472),
	(46473),
	(46474),
	(46475),
	(46476),
	(46477),
	(46478),
	(46479),
	(46480),
	(46481),
	(46482),
	(46483),
	(46484),
	(46485),
	(46486),
	(46487),
	(46488),
	(46489),
	(46490),
	(46491),
	(46492),
	(46493),
	(46494),
	(46495),
	(46496),
	(46497),
	(46498),
	(46499),
	(46500),
	(46501),
	(46502),
	(46503),
	(46504),
	(46505),
	(46506),
	(46507),
	(46508),
	(46509),
	(46510),
	(46511),
	(46512),
	(46513),
	(46514),
	(46515),
	(46516),
	(46517),
	(46518),
	(46519),
	(46520),
	(46521),
	(46522),
	(46523),
	(46524),
	(46525),
	(46526),
	(46527),
	(46528),
	(46529),
	(46530),
	(46531),
	(46532),
	(46533),
	(46534),
	(46535),
	(46536),
	(46537),
	(46538),
	(46539),
	(46540),
	(46541),
	(46542),
	(46543),
	(46544),
	(46545),
	(46546),
	(46547),
	(46548),
	(46549),
	(46550),
	(46551),
	(46552),
	(46553),
	(46554),
	(46555),
	(46556),
	(46557),
	(46558),
	(46559),
	(46560),
	(46561),
	(46562),
	(46563),
	(46564),
	(46565),
	(46566),
	(46567),
	(46568),
	(46569),
	(46570),
	(46571),
	(46572),
	(46573),
	(46574),
	(46575),
	(46576),
	(46577),
	(46578),
	(46579),
	(46580),
	(46581),
	(46582),
	(46583),
	(46584),
	(46585),
	(46586),
	(46587),
	(46588),
	(46589),
	(46590),
	(46591),
	(46592),
	(46593),
	(46594),
	(46595),
	(46596),
	(46597),
	(46598),
	(46599),
	(46600),
	(46601),
	(46602),
	(46603),
	(46604),
	(46605),
	(46606),
	(46607),
	(46608),
	(46609),
	(46610),
	(46611),
	(46612),
	(46613),
	(46614),
	(46615),
	(46616),
	(46617),
	(46618),
	(46619),
	(46620),
	(46621),
	(46622),
	(46623),
	(46624),
	(46625),
	(46626),
	(46627),
	(46628),
	(46629),
	(46630),
	(46631),
	(46632),
	(46633),
	(46634),
	(46635),
	(46636),
	(46637),
	(46638),
	(46639),
	(46640),
	(46641),
	(46642),
	(46643),
	(46644),
	(46645),
	(46646),
	(46647),
	(46648),
	(46649),
	(46650),
	(46651),
	(46652),
	(46653),
	(46654),
	(46655),
	(46656),
	(46657),
	(46658),
	(46659),
	(46660),
	(46661),
	(46662),
	(46663),
	(46664),
	(46665),
	(46666),
	(46667),
	(46668),
	(46669),
	(46670),
	(46671),
	(46672),
	(46673),
	(46674),
	(46675),
	(46676),
	(46677),
	(46678),
	(46679),
	(46680),
	(46681),
	(46682),
	(46683),
	(46684),
	(46685),
	(46686),
	(46687),
	(46688),
	(46689),
	(46690),
	(46691),
	(46692),
	(46693),
	(46694),
	(46695),
	(46696),
	(46697),
	(46698),
	(46699),
	(46700),
	(46701),
	(46702),
	(46703),
	(46704),
	(46705),
	(46706),
	(46707),
	(46708),
	(46709),
	(46710),
	(46711),
	(46712),
	(46713),
	(46714),
	(46715),
	(46716),
	(46717),
	(46718),
	(46719),
	(46720),
	(46721),
	(46722),
	(46723),
	(46724),
	(46725),
	(46726),
	(46727),
	(46728),
	(46729),
	(46730),
	(46731),
	(46732),
	(46733),
	(46734),
	(46735),
	(46736),
	(46737),
	(46738),
	(46739),
	(46740),
	(46741),
	(46742),
	(46743),
	(46744),
	(46745),
	(46746),
	(46747),
	(46748),
	(46749),
	(46750),
	(46751),
	(46752),
	(46753),
	(46754),
	(46755),
	(46756),
	(46757),
	(46758),
	(46759),
	(46760),
	(46761),
	(46762),
	(46763),
	(46764),
	(46765),
	(46766),
	(46767),
	(46768),
	(46769),
	(46770),
	(46771),
	(46772),
	(46773),
	(46774),
	(46775),
	(46776),
	(46777),
	(46778),
	(46779),
	(46780),
	(46781),
	(46782),
	(46783),
	(46784),
	(46785),
	(46786),
	(46787),
	(46788),
	(46789),
	(46790),
	(46791),
	(46792),
	(46793),
	(46794),
	(46795),
	(46796),
	(46797),
	(46798),
	(46799),
	(46800),
	(46801),
	(46802),
	(46803),
	(46804),
	(46805),
	(46806),
	(46807),
	(46808),
	(46809),
	(46810),
	(46811),
	(46812),
	(46813),
	(46814),
	(46815),
	(46816),
	(46817),
	(46818),
	(46819),
	(46820),
	(46821),
	(46822),
	(46823),
	(46824),
	(46825),
	(46826),
	(46827),
	(46828),
	(46829),
	(46830),
	(46831),
	(46832),
	(46833),
	(46834),
	(46835),
	(46836),
	(46837),
	(46838),
	(46839),
	(46840),
	(46841),
	(46842),
	(46843),
	(46844),
	(46845),
	(46846),
	(46847),
	(46848),
	(46849),
	(46850),
	(46851),
	(46852),
	(46853),
	(46854),
	(46855),
	(46856),
	(46857),
	(46858),
	(46859),
	(46860),
	(46861),
	(46862),
	(46863),
	(46864),
	(46865),
	(46866),
	(46867),
	(46868),
	(46869),
	(46870),
	(46871),
	(46872),
	(46873),
	(46874),
	(46875),
	(46876),
	(46877),
	(46878),
	(46879),
	(46880),
	(46881),
	(46882),
	(46883),
	(46884),
	(46885),
	(46886),
	(46887),
	(46888),
	(46889),
	(46890),
	(46891),
	(46892),
	(46893),
	(46894),
	(46895),
	(46896),
	(46897),
	(46898),
	(46899),
	(46900),
	(46901),
	(46902),
	(46903),
	(46904),
	(46905),
	(46906),
	(46907),
	(46908),
	(46909),
	(46910),
	(46911),
	(46912),
	(46913),
	(46914),
	(46915),
	(46916),
	(46917),
	(46918),
	(46919),
	(46920),
	(46921),
	(46922),
	(46923),
	(46924),
	(46925),
	(46926),
	(46927),
	(46928),
	(46929),
	(46930),
	(46931),
	(46932),
	(46933),
	(46934),
	(46935),
	(46936),
	(46937),
	(46938),
	(46939),
	(46940),
	(46941),
	(46942),
	(46943),
	(46944),
	(46945),
	(46946),
	(46947),
	(46948),
	(46949),
	(46950),
	(46951),
	(46952),
	(46953),
	(46954),
	(46955),
	(46956),
	(46957),
	(46958),
	(46959),
	(46960),
	(46961),
	(46962),
	(46963),
	(46964),
	(46965),
	(46966),
	(46967),
	(46968),
	(46969),
	(46970),
	(46971),
	(46972),
	(46973),
	(46974),
	(46975),
	(46976),
	(46977),
	(46978),
	(46979),
	(46980),
	(46981),
	(46982),
	(46983),
	(46984),
	(46985),
	(46986),
	(46987),
	(46988),
	(46989),
	(46990),
	(46991),
	(46992),
	(46993),
	(46994),
	(46995),
	(46996),
	(46997),
	(46998),
	(46999),
	(47000),
	(47001),
	(47002),
	(47003),
	(47004),
	(47005),
	(47006),
	(47007),
	(47008),
	(47009),
	(47010),
	(47011),
	(47012),
	(47013),
	(47014),
	(47015),
	(47016),
	(47017),
	(47018),
	(47019),
	(47020),
	(47021),
	(47022),
	(47023),
	(47024),
	(47025),
	(47026),
	(47027),
	(47028),
	(47029),
	(47030),
	(47031),
	(47032),
	(47033),
	(47034),
	(47035),
	(47036),
	(47037),
	(47038),
	(47039),
	(47040),
	(47041),
	(47042),
	(47043),
	(47044),
	(47045),
	(47046),
	(47047),
	(47048),
	(47049),
	(47050),
	(47051),
	(47052),
	(47053),
	(47054),
	(47055),
	(47056),
	(47057),
	(47058),
	(47059),
	(47060),
	(47061),
	(47062),
	(47063),
	(47064),
	(47065),
	(47066),
	(47067),
	(47068),
	(47069),
	(47070),
	(47071),
	(47072),
	(47073),
	(47074),
	(47075),
	(47076),
	(47077),
	(47078),
	(47079),
	(47080),
	(47081),
	(47082),
	(47083),
	(47084),
	(47085),
	(47086),
	(47087),
	(47088),
	(47089),
	(47090),
	(47091),
	(47092),
	(47093),
	(47094),
	(47095),
	(47096),
	(47097),
	(47098),
	(47099),
	(47100),
	(47101),
	(47102),
	(47103),
	(47104),
	(47105),
	(47106),
	(47107),
	(47108),
	(47109),
	(47110),
	(47111),
	(47112),
	(47113),
	(47114),
	(47115),
	(47116),
	(47117),
	(47118),
	(47119),
	(47120),
	(47121),
	(47122),
	(47123),
	(47124),
	(47125),
	(47126),
	(47127),
	(47128),
	(47129),
	(47130),
	(47131),
	(47132),
	(47133),
	(47134),
	(47135),
	(47136),
	(47137),
	(47138),
	(47139),
	(47140),
	(47141),
	(47142),
	(47143),
	(47144),
	(47145),
	(47146),
	(47147),
	(47148),
	(47149),
	(47150),
	(47151),
	(47152),
	(47153),
	(47154),
	(47155),
	(47156),
	(47157),
	(47158),
	(47159),
	(47160),
	(47161),
	(47162),
	(47163),
	(47164),
	(47165),
	(47166),
	(47167),
	(47168),
	(47169),
	(47170),
	(47171),
	(47172),
	(47173),
	(47174),
	(47175),
	(47176),
	(47177),
	(47178),
	(47179),
	(47180),
	(47181),
	(47182),
	(47183),
	(47184),
	(47185),
	(47186),
	(47187),
	(47188),
	(47189),
	(47190),
	(47191),
	(47192),
	(47193),
	(47194),
	(47195),
	(47196),
	(47197),
	(47198),
	(47199),
	(47200),
	(47201),
	(47202),
	(47203),
	(47204),
	(47205),
	(47206),
	(47207),
	(47208),
	(47209),
	(47210),
	(47211),
	(47212),
	(47213),
	(47214),
	(47215),
	(47216),
	(47217),
	(47218),
	(47219),
	(47220),
	(47221),
	(47222),
	(47223),
	(47224),
	(47225),
	(47226),
	(47227),
	(47228),
	(47229),
	(47230),
	(47231),
	(47232),
	(47233),
	(47234),
	(47235),
	(47236),
	(47237),
	(47238),
	(47239),
	(47240),
	(47241),
	(47242),
	(47243),
	(47244),
	(47245),
	(47246),
	(47247),
	(47248),
	(47249),
	(47250),
	(47251),
	(47252),
	(47253),
	(47254),
	(47255),
	(47256),
	(47257),
	(47258),
	(47259),
	(47260),
	(47261),
	(47262),
	(47263),
	(47264),
	(47265),
	(47266),
	(47267),
	(47268),
	(47269),
	(47270),
	(47271),
	(47272),
	(47273),
	(47274),
	(47275),
	(47276),
	(47277),
	(47278),
	(47279),
	(47280),
	(47281),
	(47282),
	(47283),
	(47284),
	(47285),
	(47286),
	(47287),
	(47288),
	(47289),
	(47290),
	(47291),
	(47292),
	(47293),
	(47294),
	(47295),
	(47296),
	(47297),
	(47298),
	(47299),
	(47300),
	(47301),
	(47302),
	(47303),
	(47304),
	(47305),
	(47306),
	(47307),
	(47308),
	(47309),
	(47310),
	(47311),
	(47312),
	(47313),
	(47314),
	(47315),
	(47316),
	(47317),
	(47318),
	(47319),
	(47320),
	(47321),
	(47322),
	(47323),
	(47324),
	(47325),
	(47326),
	(47327),
	(47328),
	(47329),
	(47330),
	(47331),
	(47332),
	(47333),
	(47334),
	(47335),
	(47336),
	(47337),
	(47338),
	(47339),
	(47340),
	(47341),
	(47342),
	(47343),
	(47344),
	(47345),
	(47346),
	(47347),
	(47348),
	(47349),
	(47350),
	(47351),
	(47352),
	(47353),
	(47354),
	(47355),
	(47356),
	(47357),
	(47358),
	(47359),
	(47360),
	(47361),
	(47362),
	(47363),
	(47364),
	(47365),
	(47366),
	(47367),
	(47368),
	(47369),
	(47370),
	(47371),
	(47372),
	(47373),
	(47374),
	(47375),
	(47376),
	(47377),
	(47378),
	(47379),
	(47380),
	(47381),
	(47382),
	(47383),
	(47384),
	(47385),
	(47386),
	(47387),
	(47388),
	(47389),
	(47390),
	(47391),
	(47392),
	(47393),
	(47394),
	(47395),
	(47396),
	(47397),
	(47398),
	(47399),
	(47400),
	(47401),
	(47402),
	(47403),
	(47404),
	(47405),
	(47406),
	(47407),
	(47408),
	(47409),
	(47410),
	(47411),
	(47412),
	(47413),
	(47414),
	(47415),
	(47416),
	(47417),
	(47418),
	(47419),
	(47420),
	(47421),
	(47422),
	(47423),
	(47424),
	(47425),
	(47426),
	(47427),
	(47428),
	(47429),
	(47430),
	(47431),
	(47432),
	(47433),
	(47434),
	(47435),
	(47436),
	(47437),
	(47438),
	(47439),
	(47440),
	(47441),
	(47442),
	(47443),
	(47444),
	(47445),
	(47446),
	(47447),
	(47448),
	(47449),
	(47450),
	(47451),
	(47452),
	(47453),
	(47454),
	(47455),
	(47456),
	(47457),
	(47458),
	(47459),
	(47460),
	(47461),
	(47462),
	(47463),
	(47464),
	(47465),
	(47466),
	(47467),
	(47468),
	(47469),
	(47470),
	(47471),
	(47472),
	(47473),
	(47474),
	(47475),
	(47476),
	(47477),
	(47478),
	(47479),
	(47480),
	(47481),
	(47482),
	(47483),
	(47484),
	(47485),
	(47486),
	(47487),
	(47488),
	(47489),
	(47490),
	(47491),
	(47492),
	(47493),
	(47494),
	(47495),
	(47496),
	(47497),
	(47498),
	(47499),
	(47500),
	(47501),
	(47502),
	(47503),
	(47504),
	(47505),
	(47506),
	(47507),
	(47508),
	(47509),
	(47510),
	(47511),
	(47512),
	(47513),
	(47514),
	(47515),
	(47516),
	(47517),
	(47518),
	(47519),
	(47520),
	(47521),
	(47522),
	(47523),
	(47524),
	(47525),
	(47526),
	(47527),
	(47528),
	(47529),
	(47530),
	(47531),
	(47532),
	(47533),
	(47534),
	(47535),
	(47536),
	(47537),
	(47538),
	(47539),
	(47540),
	(47541),
	(47542),
	(47543),
	(47544),
	(47545),
	(47546),
	(47547),
	(47548),
	(47549),
	(47550),
	(47551),
	(47552),
	(47553),
	(47554),
	(47555),
	(47556),
	(47557),
	(47558),
	(47559),
	(47560),
	(47561),
	(47562),
	(47563),
	(47564),
	(47565),
	(47566),
	(47567),
	(47568),
	(47569),
	(47570),
	(47571),
	(47572),
	(47573),
	(47574),
	(47575),
	(47576),
	(47577),
	(47578),
	(47579),
	(47580),
	(47581),
	(47582),
	(47583),
	(47584),
	(47585),
	(47586),
	(47587),
	(47588),
	(47589),
	(47590),
	(47591),
	(47592),
	(47593),
	(47594),
	(47595),
	(47596),
	(47597),
	(47598),
	(47599),
	(47600),
	(47601),
	(47602),
	(47603),
	(47604),
	(47605),
	(47606),
	(47607),
	(47608),
	(47609),
	(47610),
	(47611),
	(47612),
	(47613),
	(47614),
	(47615),
	(47616),
	(47617),
	(47618),
	(47619),
	(47620),
	(47621),
	(47622),
	(47623),
	(47624),
	(47625),
	(47626),
	(47627),
	(47628),
	(47629),
	(47630),
	(47631),
	(47632),
	(47633),
	(47634),
	(47635),
	(47636),
	(47637),
	(47638),
	(47639),
	(47640),
	(47641),
	(47642),
	(47643),
	(47644),
	(47645),
	(47646),
	(47647),
	(47648),
	(47649),
	(47650),
	(47651),
	(47652),
	(47653),
	(47654),
	(47655),
	(47656),
	(47657),
	(47658),
	(47659),
	(47660),
	(47661),
	(47662),
	(47663),
	(47664),
	(47665),
	(47666),
	(47667),
	(47668),
	(47669),
	(47670),
	(47671),
	(47672),
	(47673),
	(47674),
	(47675),
	(47676),
	(47677),
	(47678),
	(47679),
	(47680),
	(47681),
	(47682),
	(47683),
	(47684),
	(47685),
	(47686),
	(47687),
	(47688),
	(47689),
	(47690),
	(47691),
	(47692),
	(47693),
	(47694),
	(47695),
	(47696),
	(47697),
	(47698),
	(47699),
	(47700),
	(47701),
	(47702),
	(47703),
	(47704),
	(47705),
	(47706),
	(47707),
	(47708),
	(47709),
	(47710),
	(47711),
	(47712),
	(47713),
	(47714),
	(47715),
	(47716),
	(47717),
	(47718),
	(47719),
	(47720),
	(47721),
	(47722),
	(47723),
	(47724),
	(47725),
	(47726),
	(47727),
	(47728),
	(47729),
	(47730),
	(47731),
	(47732),
	(47733),
	(47734),
	(47735),
	(47736),
	(47737),
	(47738),
	(47739),
	(47740),
	(47741),
	(47742),
	(47743),
	(47744),
	(47745),
	(47746),
	(47747),
	(47748),
	(47749),
	(47750),
	(47751),
	(47752),
	(47753),
	(47754),
	(47755),
	(47756),
	(47757),
	(47758),
	(47759),
	(47760),
	(47761),
	(47762),
	(47763),
	(47764),
	(47765),
	(47766),
	(47767),
	(47768),
	(47769),
	(47770),
	(47771),
	(47772),
	(47773),
	(47774),
	(47775),
	(47776),
	(47777),
	(47778),
	(47779),
	(47780),
	(47781),
	(47782),
	(47783),
	(47784),
	(47785),
	(47786),
	(47787),
	(47788),
	(47789),
	(47790),
	(47791),
	(47792),
	(47793),
	(47794),
	(47795),
	(47796),
	(47797),
	(47798),
	(47799),
	(47800),
	(47801),
	(47802),
	(47803),
	(47804),
	(47805),
	(47806),
	(47807),
	(47808),
	(47809),
	(47810),
	(47811),
	(47812),
	(47813),
	(47814),
	(47815),
	(47816),
	(47817),
	(47818),
	(47819),
	(47820),
	(47821),
	(47822),
	(47823),
	(47824),
	(47825),
	(47826),
	(47827),
	(47828),
	(47829),
	(47830),
	(47831),
	(47832),
	(47833),
	(47834),
	(47835),
	(47836),
	(47837),
	(47838),
	(47839),
	(47840),
	(47841),
	(47842),
	(47843),
	(47844),
	(47845),
	(47846),
	(47847),
	(47848),
	(47849),
	(47850),
	(47851),
	(47852),
	(47853),
	(47854),
	(47855),
	(47856),
	(47857),
	(47858),
	(47859),
	(47860),
	(47861),
	(47862),
	(47863),
	(47864),
	(47865),
	(47866),
	(47867),
	(47868),
	(47869),
	(47870),
	(47871),
	(47872),
	(47873),
	(47874),
	(47875),
	(47876),
	(47877),
	(47878),
	(47879),
	(47880),
	(47881),
	(47882),
	(47883),
	(47884),
	(47885),
	(47886),
	(47887),
	(47888),
	(47889),
	(47890),
	(47891),
	(47892),
	(47893),
	(47894),
	(47895),
	(47896),
	(47897),
	(47898),
	(47899),
	(47900),
	(47901),
	(47902),
	(47903),
	(47904),
	(47905),
	(47906),
	(47907),
	(47908),
	(47909),
	(47910),
	(47911),
	(47912),
	(47913),
	(47914),
	(47915),
	(47916),
	(47917),
	(47918),
	(47919),
	(47920),
	(47921),
	(47922),
	(47923),
	(47924),
	(47925),
	(47926),
	(47927),
	(47928),
	(47929),
	(47930),
	(47931),
	(47932),
	(47933),
	(47934),
	(47935),
	(47936),
	(47937),
	(47938),
	(47939),
	(47940),
	(47941),
	(47942),
	(47943),
	(47944),
	(47945),
	(47946),
	(47947),
	(47948),
	(47949),
	(47950),
	(47951),
	(47952),
	(47953),
	(47954),
	(47955),
	(47956),
	(47957),
	(47958),
	(47959),
	(47960),
	(47961),
	(47962),
	(47963),
	(47964),
	(47965),
	(47966),
	(47967),
	(47968),
	(47969),
	(47970),
	(47971),
	(47972),
	(47973),
	(47974),
	(47975),
	(47976),
	(47977),
	(47978),
	(47979),
	(47980),
	(47981),
	(47982),
	(47983),
	(47984),
	(47985),
	(47986),
	(47987),
	(47988),
	(47989),
	(47990),
	(47991),
	(47992),
	(47993),
	(47994),
	(47995),
	(47996),
	(47997),
	(47998),
	(47999),
	(48000),
	(48001),
	(48002),
	(48003),
	(48004),
	(48005),
	(48006),
	(48007),
	(48008),
	(48009),
	(48010),
	(48011),
	(48012),
	(48013),
	(48014),
	(48015),
	(48016),
	(48017),
	(48018),
	(48019),
	(48020),
	(48021),
	(48022),
	(48023),
	(48024),
	(48025),
	(48026),
	(48027),
	(48028),
	(48029),
	(48030),
	(48031),
	(48032),
	(48033),
	(48034),
	(48035),
	(48036),
	(48037),
	(48038),
	(48039),
	(48040),
	(48041),
	(48042),
	(48043),
	(48044),
	(48045),
	(48046),
	(48047),
	(48048),
	(48049),
	(48050),
	(48051),
	(48052),
	(48053),
	(48054),
	(48055),
	(48056),
	(48057),
	(48058),
	(48059),
	(48060),
	(48061),
	(48062),
	(48063),
	(48064),
	(48065),
	(48066),
	(48067),
	(48068),
	(48069),
	(48070),
	(48071),
	(48072),
	(48073),
	(48074),
	(48075),
	(48076),
	(48077),
	(48078),
	(48079),
	(48080),
	(48081),
	(48082),
	(48083),
	(48084),
	(48085),
	(48086),
	(48087),
	(48088),
	(48089),
	(48090),
	(48091),
	(48092),
	(48093),
	(48094),
	(48095),
	(48096),
	(48097),
	(48098),
	(48099),
	(48100),
	(48101),
	(48102),
	(48103),
	(48104),
	(48105),
	(48106),
	(48107),
	(48108),
	(48109),
	(48110),
	(48111),
	(48112),
	(48113),
	(48114),
	(48115),
	(48116),
	(48117),
	(48118),
	(48119),
	(48120),
	(48121),
	(48122),
	(48123),
	(48124),
	(48125),
	(48126),
	(48127),
	(48128),
	(48129),
	(48130),
	(48131),
	(48132),
	(48133),
	(48134),
	(48135),
	(48136),
	(48137),
	(48138),
	(48139),
	(48140),
	(48141),
	(48142),
	(48143),
	(48144),
	(48145),
	(48146),
	(48147),
	(48148),
	(48149),
	(48150),
	(48151),
	(48152),
	(48153),
	(48154),
	(48155),
	(48156),
	(48157),
	(48158),
	(48159),
	(48160),
	(48161),
	(48162),
	(48163),
	(48164),
	(48165),
	(48166),
	(48167),
	(48168),
	(48169),
	(48170),
	(48171),
	(48172),
	(48173),
	(48174),
	(48175),
	(48176),
	(48177),
	(48178),
	(48179),
	(48180),
	(48181),
	(48182),
	(48183),
	(48184),
	(48185),
	(48186),
	(48187),
	(48188),
	(48189),
	(48190),
	(48191),
	(48192),
	(48193),
	(48194),
	(48195),
	(48196),
	(48197),
	(48198),
	(48199),
	(48200),
	(48201),
	(48202),
	(48203),
	(48204),
	(48205),
	(48206),
	(48207),
	(48208),
	(48209),
	(48210),
	(48211),
	(48212),
	(48213),
	(48214),
	(48215),
	(48216),
	(48217),
	(48218),
	(48219),
	(48220),
	(48221),
	(48222),
	(48223),
	(48224),
	(48225),
	(48226),
	(48227),
	(48228),
	(48229),
	(48230),
	(48231),
	(48232),
	(48233),
	(48234),
	(48235),
	(48236),
	(48237),
	(48238),
	(48239),
	(48240),
	(48241),
	(48242),
	(48243),
	(48244),
	(48245),
	(48246),
	(48247),
	(48248),
	(48249),
	(48250),
	(48251),
	(48252),
	(48253),
	(48254),
	(48255),
	(48256),
	(48257),
	(48258),
	(48259),
	(48260),
	(48261),
	(48262),
	(48263),
	(48264),
	(48265),
	(48266),
	(48267),
	(48268),
	(48269),
	(48270),
	(48271),
	(48272),
	(48273),
	(48274),
	(48275),
	(48276),
	(48277),
	(48278),
	(48279),
	(48280),
	(48281),
	(48282),
	(48283),
	(48284),
	(48285),
	(48286),
	(48287),
	(48288),
	(48289),
	(48290),
	(48291),
	(48292),
	(48293),
	(48294),
	(48295),
	(48296),
	(48297),
	(48298),
	(48299),
	(48300),
	(48301),
	(48302),
	(48303),
	(48304),
	(48305),
	(48306),
	(48307),
	(48308),
	(48309),
	(48310),
	(48311),
	(48312),
	(48313),
	(48314),
	(48315),
	(48316),
	(48317),
	(48318),
	(48319),
	(48320),
	(48321),
	(48322),
	(48323),
	(48324),
	(48325),
	(48326),
	(48327),
	(48328),
	(48329),
	(48330),
	(48331),
	(48332),
	(48333),
	(48334),
	(48335),
	(48336),
	(48337),
	(48338),
	(48339),
	(48340),
	(48341),
	(48342),
	(48343),
	(48344),
	(48345),
	(48346),
	(48347),
	(48348),
	(48349),
	(48350),
	(48351),
	(48352),
	(48353),
	(48354),
	(48355),
	(48356),
	(48357),
	(48358),
	(48359),
	(48360),
	(48361),
	(48362),
	(48363),
	(48364),
	(48365),
	(48366),
	(48367),
	(48368),
	(48369),
	(48370),
	(48371),
	(48372),
	(48373),
	(48374),
	(48375),
	(48376),
	(48377),
	(48378),
	(48379),
	(48380),
	(48381),
	(48382),
	(48383),
	(48384),
	(48385),
	(48386),
	(48387),
	(48388),
	(48389),
	(48390),
	(48391),
	(48392),
	(48393),
	(48394),
	(48395),
	(48396),
	(48397),
	(48398),
	(48399),
	(48400),
	(48401),
	(48402),
	(48403),
	(48404),
	(48405),
	(48406),
	(48407),
	(48408),
	(48409),
	(48410),
	(48411),
	(48412),
	(48413),
	(48414),
	(48415),
	(48416),
	(48417),
	(48418),
	(48419),
	(48420),
	(48421),
	(48422),
	(48423),
	(48424),
	(48425),
	(48426),
	(48427),
	(48428),
	(48429),
	(48430),
	(48431),
	(48432),
	(48433),
	(48434),
	(48435),
	(48436),
	(48437),
	(48438),
	(48439),
	(48440),
	(48441),
	(48442),
	(48443),
	(48444),
	(48445),
	(48446),
	(48447),
	(48448),
	(48449),
	(48450),
	(48451),
	(48452),
	(48453),
	(48454),
	(48455),
	(48456),
	(48457),
	(48458),
	(48459),
	(48460),
	(48461),
	(48462),
	(48463),
	(48464),
	(48465),
	(48466),
	(48467),
	(48468),
	(48469),
	(48470),
	(48471),
	(48472),
	(48473),
	(48474),
	(48475),
	(48476),
	(48477),
	(48478),
	(48479),
	(48480),
	(48481),
	(48482),
	(48483),
	(48484),
	(48485),
	(48486),
	(48487),
	(48488),
	(48489),
	(48490),
	(48491),
	(48492),
	(48493),
	(48494),
	(48495),
	(48496),
	(48497),
	(48498),
	(48499),
	(48500),
	(48501),
	(48502),
	(48503),
	(48504),
	(48505),
	(48506),
	(48507),
	(48508),
	(48509),
	(48510),
	(48511),
	(48512),
	(48513),
	(48514),
	(48515),
	(48516),
	(48517),
	(48518),
	(48519),
	(48520),
	(48521),
	(48522),
	(48523),
	(48524),
	(48525),
	(48526),
	(48527),
	(48528),
	(48529),
	(48530),
	(48531),
	(48532),
	(48533),
	(48534),
	(48535),
	(48536),
	(48537),
	(48538),
	(48539),
	(48540),
	(48541),
	(48542),
	(48543),
	(48544),
	(48545),
	(48546),
	(48547),
	(48548),
	(48549),
	(48550),
	(48551),
	(48552),
	(48553),
	(48554),
	(48555),
	(48556),
	(48557),
	(48558),
	(48559),
	(48560),
	(48561),
	(48562),
	(48563),
	(48564),
	(48565),
	(48566),
	(48567),
	(48568),
	(48569),
	(48570),
	(48571),
	(48572),
	(48573),
	(48574),
	(48575),
	(48576),
	(48577),
	(48578),
	(48579),
	(48580),
	(48581),
	(48582),
	(48583),
	(48584),
	(48585),
	(48586),
	(48587),
	(48588),
	(48589),
	(48590),
	(48591),
	(48592),
	(48593),
	(48594),
	(48595),
	(48596),
	(48597),
	(48598),
	(48599),
	(48600),
	(48601),
	(48602),
	(48603),
	(48604),
	(48605),
	(48606),
	(48607),
	(48608),
	(48609),
	(48610),
	(48611),
	(48612),
	(48613),
	(48614),
	(48615),
	(48616),
	(48617),
	(48618),
	(48619),
	(48620),
	(48621),
	(48622),
	(48623),
	(48624),
	(48625),
	(48626),
	(48627),
	(48628),
	(48629),
	(48630),
	(48631),
	(48632),
	(48633),
	(48634),
	(48635),
	(48636),
	(48637),
	(48638),
	(48639),
	(48640),
	(48641),
	(48642),
	(48643),
	(48644),
	(48645),
	(48646),
	(48647),
	(48648),
	(48649),
	(48650),
	(48651),
	(48652),
	(48653),
	(48654),
	(48655),
	(48656),
	(48657),
	(48658),
	(48659),
	(48660),
	(48661),
	(48662),
	(48663),
	(48664),
	(48665),
	(48666),
	(48667),
	(48668),
	(48669),
	(48670),
	(48671),
	(48672),
	(48673),
	(48674),
	(48675),
	(48676),
	(48677),
	(48678),
	(48679),
	(48680),
	(48681),
	(48682),
	(48683),
	(48684),
	(48685),
	(48686),
	(48687),
	(48688),
	(48689),
	(48690),
	(48691),
	(48692),
	(48693),
	(48694),
	(48695),
	(48696),
	(48697),
	(48698),
	(48699),
	(48700),
	(48701),
	(48702),
	(48703),
	(48704),
	(48705),
	(48706),
	(48707),
	(48708),
	(48709),
	(48710),
	(48711),
	(48712),
	(48713),
	(48714),
	(48715),
	(48716),
	(48717),
	(48718),
	(48719),
	(48720),
	(48721),
	(48722),
	(48723),
	(48724),
	(48725),
	(48726),
	(48727),
	(48728),
	(48729),
	(48730),
	(48731),
	(48732),
	(48733),
	(48734),
	(48735),
	(48736),
	(48737),
	(48738),
	(48739),
	(48740),
	(48741),
	(48742),
	(48743),
	(48744),
	(48745),
	(48746),
	(48747),
	(48748),
	(48749),
	(48750),
	(48751),
	(48752),
	(48753),
	(48754),
	(48755),
	(48756),
	(48757),
	(48758),
	(48759),
	(48760),
	(48761),
	(48762),
	(48763),
	(48764),
	(48765),
	(48766),
	(48767),
	(48768),
	(48769),
	(48770),
	(48771),
	(48772),
	(48773),
	(48774),
	(48775),
	(48776),
	(48777),
	(48778),
	(48779),
	(48780),
	(48781),
	(48782),
	(48783),
	(48784),
	(48785),
	(48786),
	(48787),
	(48788),
	(48789),
	(48790),
	(48791),
	(48792),
	(48793),
	(48794),
	(48795),
	(48796),
	(48797),
	(48798),
	(48799),
	(48800),
	(48801),
	(48802),
	(48803),
	(48804),
	(48805),
	(48806),
	(48807),
	(48808),
	(48809),
	(48810),
	(48811),
	(48812),
	(48813),
	(48814),
	(48815),
	(48816),
	(48817),
	(48818),
	(48819),
	(48820),
	(48821),
	(48822),
	(48823),
	(48824),
	(48825),
	(48826),
	(48827),
	(48828),
	(48829),
	(48830),
	(48831),
	(48832),
	(48833),
	(48834),
	(48835),
	(48836),
	(48837),
	(48838),
	(48839),
	(48840),
	(48841),
	(48842),
	(48843),
	(48844),
	(48845),
	(48846),
	(48847),
	(48848),
	(48849),
	(48850),
	(48851),
	(48852),
	(48853),
	(48854),
	(48855),
	(48856),
	(48857),
	(48858),
	(48859),
	(48860),
	(48861),
	(48862),
	(48863),
	(48864),
	(48865),
	(48866),
	(48867),
	(48868),
	(48869),
	(48870),
	(48871),
	(48872),
	(48873),
	(48874),
	(48875),
	(48876),
	(48877),
	(48878),
	(48879),
	(48880),
	(48881),
	(48882),
	(48883),
	(48884),
	(48885),
	(48886),
	(48887),
	(48888),
	(48889),
	(48890),
	(48891),
	(48892),
	(48893),
	(48894),
	(48895),
	(48896),
	(48897),
	(48898),
	(48899),
	(48900),
	(48901),
	(48902),
	(48903),
	(48904),
	(48905),
	(48906),
	(48907),
	(48908),
	(48909),
	(48910),
	(48911),
	(48912),
	(48913),
	(48914),
	(48915),
	(48916),
	(48917),
	(48918),
	(48919),
	(48920),
	(48921),
	(48922),
	(48923),
	(48924),
	(48925),
	(48926),
	(48927),
	(48928),
	(48929),
	(48930),
	(48931),
	(48932),
	(48933),
	(48934),
	(48935),
	(48936),
	(48937),
	(48938),
	(48939),
	(48940),
	(48941),
	(48942),
	(48943),
	(48944),
	(48945),
	(48946),
	(48947),
	(48948),
	(48949),
	(48950),
	(48951),
	(48952),
	(48953),
	(48954),
	(48955),
	(48956),
	(48957),
	(48958),
	(48959),
	(48960),
	(48961),
	(48962),
	(48963),
	(48964),
	(48965),
	(48966),
	(48967),
	(48968),
	(48969),
	(48970),
	(48971),
	(48972),
	(48973),
	(48974),
	(48975),
	(48976),
	(48977),
	(48978),
	(48979),
	(48980),
	(48981),
	(48982),
	(48983),
	(48984),
	(48985),
	(48986),
	(48987),
	(48988),
	(48989),
	(48990),
	(48991),
	(48992),
	(48993),
	(48994),
	(48995),
	(48996),
	(48997),
	(48998),
	(48999),
	(49000),
	(49001),
	(49002),
	(49003),
	(49004),
	(49005),
	(49006),
	(49007),
	(49008),
	(49009),
	(49010),
	(49011),
	(49012),
	(49013),
	(49014),
	(49015),
	(49016),
	(49017),
	(49018),
	(49019),
	(49020),
	(49021),
	(49022),
	(49023),
	(49024),
	(49025),
	(49026),
	(49027),
	(49028),
	(49029),
	(49030),
	(49031),
	(49032),
	(49033),
	(49034),
	(49035),
	(49036),
	(49037),
	(49038),
	(49039),
	(49040),
	(49041),
	(49042),
	(49043),
	(49044),
	(49045),
	(49046),
	(49047),
	(49048),
	(49049),
	(49050),
	(49051),
	(49052),
	(49053),
	(49054),
	(49055),
	(49056),
	(49057),
	(49058),
	(49059),
	(49060),
	(49061),
	(49062),
	(49063),
	(49064),
	(49065),
	(49066),
	(49067),
	(49068),
	(49069),
	(49070),
	(49071),
	(49072),
	(49073),
	(49074),
	(49075),
	(49076),
	(49077),
	(49078),
	(49079),
	(49080),
	(49081),
	(49082),
	(49083),
	(49084),
	(49085),
	(49086),
	(49087),
	(49088),
	(49089),
	(49090),
	(49091),
	(49092),
	(49093),
	(49094),
	(49095),
	(49096),
	(49097),
	(49098),
	(49099),
	(49100),
	(49101),
	(49102),
	(49103),
	(49104),
	(49105),
	(49106),
	(49107),
	(49108),
	(49109),
	(49110),
	(49111),
	(49112),
	(49113),
	(49114),
	(49115),
	(49116),
	(49117),
	(49118),
	(49119),
	(49120),
	(49121),
	(49122),
	(49123),
	(49124),
	(49125),
	(49126),
	(49127),
	(49128),
	(49129),
	(49130),
	(49131),
	(49132),
	(49133),
	(49134),
	(49135),
	(49136),
	(49137),
	(49138),
	(49139),
	(49140),
	(49141),
	(49142),
	(49143),
	(49144),
	(49145),
	(49146),
	(49147),
	(49148),
	(49149),
	(49150),
	(49151),
	(49152),
	(49153),
	(49154),
	(49155),
	(49156),
	(49157),
	(49158),
	(49159),
	(49160),
	(49161),
	(49162),
	(49163),
	(49164),
	(49165),
	(49166),
	(49167),
	(49168),
	(49169),
	(49170),
	(49171),
	(49172),
	(49173),
	(49174),
	(49175),
	(49176),
	(49177),
	(49178),
	(49179),
	(49180),
	(49181),
	(49182),
	(49183),
	(49184),
	(49185),
	(49186),
	(49187),
	(49188),
	(49189),
	(49190),
	(49191),
	(49192),
	(49193),
	(49194),
	(49195),
	(49196),
	(49197),
	(49198),
	(49199),
	(49200),
	(49201),
	(49202),
	(49203),
	(49204),
	(49205),
	(49206),
	(49207),
	(49208),
	(49209),
	(49210),
	(49211),
	(49212),
	(49213),
	(49214),
	(49215),
	(49216),
	(49217),
	(49218),
	(49219),
	(49220),
	(49221),
	(49222),
	(49223),
	(49224),
	(49225),
	(49226),
	(49227),
	(49228),
	(49229),
	(49230),
	(49231),
	(49232),
	(49233),
	(49234),
	(49235),
	(49236),
	(49237),
	(49238),
	(49239),
	(49240),
	(49241),
	(49242),
	(49243),
	(49244),
	(49245),
	(49246),
	(49247),
	(49248),
	(49249),
	(49250),
	(49251),
	(49252),
	(49253),
	(49254),
	(49255),
	(49256),
	(49257),
	(49258),
	(49259),
	(49260),
	(49261),
	(49262),
	(49263),
	(49264),
	(49265),
	(49266),
	(49267),
	(49268),
	(49269),
	(49270),
	(49271),
	(49272),
	(49273),
	(49274),
	(49275),
	(49276),
	(49277),
	(49278),
	(49279),
	(49280),
	(49281),
	(49282),
	(49283),
	(49284),
	(49285),
	(49286),
	(49287),
	(49288),
	(49289),
	(49290),
	(49291),
	(49292),
	(49293),
	(49294),
	(49295),
	(49296),
	(49297),
	(49298),
	(49299),
	(49300),
	(49301),
	(49302),
	(49303),
	(49304),
	(49305),
	(49306),
	(49307),
	(49308),
	(49309),
	(49310),
	(49311),
	(49312),
	(49313),
	(49314),
	(49315),
	(49316),
	(49317),
	(49318),
	(49319),
	(49320),
	(49321),
	(49322),
	(49323),
	(49324),
	(49325),
	(49326),
	(49327),
	(49328),
	(49329),
	(49330),
	(49331),
	(49332),
	(49333),
	(49334),
	(49335),
	(49336),
	(49337),
	(49338),
	(49339),
	(49340),
	(49341),
	(49342),
	(49343),
	(49344),
	(49345),
	(49346),
	(49347),
	(49348),
	(49349),
	(49350),
	(49351),
	(49352),
	(49353),
	(49354),
	(49355),
	(49356),
	(49357),
	(49358),
	(49359),
	(49360),
	(49361),
	(49362),
	(49363),
	(49364),
	(49365),
	(49366),
	(49367),
	(49368),
	(49369),
	(49370),
	(49371),
	(49372),
	(49373),
	(49374),
	(49375),
	(49376),
	(49377),
	(49378),
	(49379),
	(49380),
	(49381),
	(49382),
	(49383),
	(49384),
	(49385),
	(49386),
	(49387),
	(49388),
	(49389),
	(49390),
	(49391),
	(49392),
	(49393),
	(49394),
	(49395),
	(49396),
	(49397),
	(49398),
	(49399),
	(49400),
	(49401),
	(49402),
	(49403),
	(49404),
	(49405),
	(49406),
	(49407),
	(49408),
	(49409),
	(49410),
	(49411),
	(49412),
	(49413),
	(49414),
	(49415),
	(49416),
	(49417),
	(49418),
	(49419),
	(49420),
	(49421),
	(49422),
	(49423),
	(49424),
	(49425),
	(49426),
	(49427),
	(49428),
	(49429),
	(49430),
	(49431),
	(49432),
	(49433),
	(49434),
	(49435),
	(49436),
	(49437),
	(49438),
	(49439),
	(49440),
	(49441),
	(49442),
	(49443),
	(49444),
	(49445),
	(49446),
	(49447),
	(49448),
	(49449),
	(49450),
	(49451),
	(49452),
	(49453),
	(49454),
	(49455),
	(49456),
	(49457),
	(49458),
	(49459),
	(49460),
	(49461),
	(49462),
	(49463),
	(49464),
	(49465),
	(49466),
	(49467),
	(49468),
	(49469),
	(49470),
	(49471),
	(49472),
	(49473),
	(49474),
	(49475),
	(49476),
	(49477),
	(49478),
	(49479),
	(49480),
	(49481),
	(49482),
	(49483),
	(49484),
	(49485),
	(49486),
	(49487),
	(49488),
	(49489),
	(49490),
	(49491),
	(49492),
	(49493),
	(49494),
	(49495),
	(49496),
	(49497),
	(49498),
	(49499),
	(49500),
	(49501),
	(49502),
	(49503),
	(49504),
	(49505),
	(49506),
	(49507),
	(49508),
	(49509),
	(49510),
	(49511),
	(49512),
	(49513),
	(49514),
	(49515),
	(49516),
	(49517),
	(49518),
	(49519),
	(49520),
	(49521),
	(49522),
	(49523),
	(49524),
	(49525),
	(49526),
	(49527),
	(49528),
	(49529),
	(49530),
	(49531),
	(49532),
	(49533),
	(49534),
	(49535),
	(49536),
	(49537),
	(49538),
	(49539),
	(49540),
	(49541),
	(49542),
	(49543),
	(49544),
	(49545),
	(49546),
	(49547),
	(49548),
	(49549),
	(49550),
	(49551),
	(49552),
	(49553),
	(49554),
	(49555),
	(49556),
	(49557),
	(49558),
	(49559),
	(49560),
	(49561),
	(49562),
	(49563),
	(49564),
	(49565),
	(49566),
	(49567),
	(49568),
	(49569),
	(49570),
	(49571),
	(49572),
	(49573),
	(49574),
	(49575),
	(49576),
	(49577),
	(49578),
	(49579),
	(49580),
	(49581),
	(49582),
	(49583),
	(49584),
	(49585),
	(49586),
	(49587),
	(49588),
	(49589),
	(49590),
	(49591),
	(49592),
	(49593),
	(49594),
	(49595),
	(49596),
	(49597),
	(49598),
	(49599),
	(49600),
	(49601),
	(49602),
	(49603),
	(49604),
	(49605),
	(49606),
	(49607),
	(49608),
	(49609),
	(49610),
	(49611),
	(49612),
	(49613),
	(49614),
	(49615),
	(49616),
	(49617),
	(49618),
	(49619),
	(49620),
	(49621),
	(49622),
	(49623),
	(49624),
	(49625),
	(49626),
	(49627),
	(49628),
	(49629),
	(49630),
	(49631),
	(49632),
	(49633),
	(49634),
	(49635),
	(49636),
	(49637),
	(49638),
	(49639),
	(49640),
	(49641),
	(49642),
	(49643),
	(49644),
	(49645),
	(49646),
	(49647),
	(49648),
	(49649),
	(49650),
	(49651),
	(49652),
	(49653),
	(49654),
	(49655),
	(49656),
	(49657),
	(49658),
	(49659),
	(49660),
	(49661),
	(49662),
	(49663),
	(49664),
	(49665),
	(49666),
	(49667),
	(49668),
	(49669),
	(49670),
	(49671),
	(49672),
	(49673),
	(49674),
	(49675),
	(49676),
	(49677),
	(49678),
	(49679),
	(49680),
	(49681),
	(49682),
	(49683),
	(49684),
	(49685),
	(49686),
	(49687),
	(49688),
	(49689),
	(49690),
	(49691),
	(49692),
	(49693),
	(49694),
	(49695),
	(49696),
	(49697),
	(49698),
	(49699),
	(49700),
	(49701),
	(49702),
	(49703),
	(49704),
	(49705),
	(49706),
	(49707),
	(49708),
	(49709),
	(49710),
	(49711),
	(49712),
	(49713),
	(49714),
	(49715),
	(49716),
	(49717),
	(49718),
	(49719),
	(49720),
	(49721),
	(49722),
	(49723),
	(49724),
	(49725),
	(49726),
	(49727),
	(49728),
	(49729),
	(49730),
	(49731),
	(49732),
	(49733),
	(49734),
	(49735),
	(49736),
	(49737),
	(49738),
	(49739),
	(49740),
	(49741),
	(49742),
	(49743),
	(49744),
	(49745),
	(49746),
	(49747),
	(49748),
	(49749),
	(49750),
	(49751),
	(49752),
	(49753),
	(49754),
	(49755),
	(49756),
	(49757),
	(49758),
	(49759),
	(49760),
	(49761),
	(49762),
	(49763),
	(49764),
	(49765),
	(49766),
	(49767),
	(49768),
	(49769),
	(49770),
	(49771),
	(49772),
	(49773),
	(49774),
	(49775),
	(49776),
	(49777),
	(49778),
	(49779),
	(49780),
	(49781),
	(49782),
	(49783),
	(49784),
	(49785),
	(49786),
	(49787),
	(49788),
	(49789),
	(49790),
	(49791),
	(49792),
	(49793),
	(49794),
	(49795),
	(49796),
	(49797),
	(49798),
	(49799),
	(49800),
	(49801),
	(49802),
	(49803),
	(49804),
	(49805),
	(49806),
	(49807),
	(49808),
	(49809),
	(49810),
	(49811),
	(49812),
	(49813),
	(49814),
	(49815),
	(49816),
	(49817),
	(49818),
	(49819),
	(49820),
	(49821),
	(49822),
	(49823),
	(49824),
	(49825),
	(49826),
	(49827),
	(49828),
	(49829),
	(49830),
	(49831),
	(49832),
	(49833),
	(49834),
	(49835),
	(49836),
	(49837),
	(49838),
	(49839),
	(49840),
	(49841),
	(49842),
	(49843),
	(49844),
	(49845),
	(49846),
	(49847),
	(49848),
	(49849),
	(49850),
	(49851),
	(49852),
	(49853),
	(49854),
	(49855),
	(49856),
	(49857),
	(49858),
	(49859),
	(49860),
	(49861),
	(49862),
	(49863),
	(49864),
	(49865),
	(49866),
	(49867),
	(49868),
	(49869),
	(49870),
	(49871),
	(49872),
	(49873),
	(49874),
	(49875),
	(49876),
	(49877),
	(49878),
	(49879),
	(49880),
	(49881),
	(49882),
	(49883),
	(49884),
	(49885),
	(49886),
	(49887),
	(49888),
	(49889),
	(49890),
	(49891),
	(49892),
	(49893),
	(49894),
	(49895),
	(49896),
	(49897),
	(49898),
	(49899),
	(49900),
	(49901),
	(49902),
	(49903),
	(49904),
	(49905),
	(49906),
	(49907),
	(49908),
	(49909),
	(49910),
	(49911),
	(49912),
	(49913),
	(49914),
	(49915),
	(49916),
	(49917),
	(49918),
	(49919),
	(49920),
	(49921),
	(49922),
	(49923),
	(49924),
	(49925),
	(49926),
	(49927),
	(49928),
	(49929),
	(49930),
	(49931),
	(49932),
	(49933),
	(49934),
	(49935),
	(49936),
	(49937),
	(49938),
	(49939),
	(49940),
	(49941),
	(49942),
	(49943),
	(49944),
	(49945),
	(49946),
	(49947),
	(49948),
	(49949),
	(49950),
	(49951),
	(49952),
	(49953),
	(49954),
	(49955),
	(49956),
	(49957),
	(49958),
	(49959),
	(49960),
	(49961),
	(49962),
	(49963),
	(49964),
	(49965),
	(49966),
	(49967),
	(49968),
	(49969),
	(49970),
	(49971),
	(49972),
	(49973),
	(49974),
	(49975),
	(49976),
	(49977),
	(49978),
	(49979),
	(49980),
	(49981),
	(49982),
	(49983),
	(49984),
	(49985),
	(49986),
	(49987),
	(49988),
	(49989),
	(49990),
	(49991),
	(49992),
	(49993),
	(49994),
	(49995),
	(49996),
	(49997),
	(49998),
	(49999),
	(50000),
	(50001),
	(50002),
	(50003),
	(50004),
	(50005),
	(50006),
	(50007),
	(50008),
	(50009),
	(50010),
	(50011),
	(50012),
	(50013),
	(50014),
	(50015),
	(50016),
	(50017),
	(50018),
	(50019),
	(50020),
	(50021),
	(50022),
	(50023),
	(50024),
	(50025),
	(50026),
	(50027),
	(50028),
	(50029),
	(50030),
	(50031),
	(50032),
	(50033),
	(50034),
	(50035),
	(50036),
	(50037),
	(50038),
	(50039),
	(50040),
	(50041),
	(50042),
	(50043),
	(50044),
	(50045),
	(50046),
	(50047),
	(50048),
	(50049),
	(50050),
	(50051),
	(50052),
	(50053),
	(50054),
	(50055),
	(50056),
	(50057),
	(50058),
	(50059),
	(50060),
	(50061),
	(50062),
	(50063),
	(50064),
	(50065),
	(50066),
	(50067),
	(50068),
	(50069),
	(50070),
	(50071),
	(50072),
	(50073),
	(50074),
	(50075),
	(50076),
	(50077),
	(50078),
	(50079),
	(50080),
	(50081),
	(50082),
	(50083),
	(50084),
	(50085),
	(50086),
	(50087),
	(50088),
	(50089),
	(50090),
	(50091),
	(50092),
	(50093),
	(50094),
	(50095),
	(50096),
	(50097),
	(50098),
	(50099),
	(50100),
	(50101),
	(50102),
	(50103),
	(50104),
	(50105),
	(50106),
	(50107),
	(50108),
	(50109),
	(50110),
	(50111),
	(50112),
	(50113),
	(50114),
	(50115),
	(50116),
	(50117),
	(50118),
	(50119),
	(50120),
	(50121),
	(50122),
	(50123),
	(50124),
	(50125),
	(50126),
	(50127),
	(50128),
	(50129),
	(50130),
	(50131),
	(50132),
	(50133),
	(50134),
	(50135),
	(50136),
	(50137),
	(50138),
	(50139),
	(50140),
	(50141),
	(50142),
	(50143),
	(50144),
	(50145),
	(50146),
	(50147),
	(50148),
	(50149),
	(50150),
	(50151),
	(50152),
	(50153),
	(50154),
	(50155),
	(50156),
	(50157),
	(50158),
	(50159),
	(50160),
	(50161),
	(50162),
	(50163),
	(50164),
	(50165),
	(50166),
	(50167),
	(50168),
	(50169),
	(50170),
	(50171),
	(50172),
	(50173),
	(50174),
	(50175),
	(50176),
	(50177),
	(50178),
	(50179),
	(50180),
	(50181),
	(50182),
	(50183),
	(50184),
	(50185),
	(50186),
	(50187),
	(50188),
	(50189),
	(50190),
	(50191),
	(50192),
	(50193),
	(50194),
	(50195),
	(50196),
	(50197),
	(50198),
	(50199),
	(50200),
	(50201),
	(50202),
	(50203),
	(50204),
	(50205),
	(50206),
	(50207),
	(50208),
	(50209),
	(50210),
	(50211),
	(50212),
	(50213),
	(50214),
	(50215),
	(50216),
	(50217),
	(50218),
	(50219),
	(50220),
	(50221),
	(50222),
	(50223),
	(50224),
	(50225),
	(50226),
	(50227),
	(50228),
	(50229),
	(50230),
	(50231),
	(50232),
	(50233),
	(50234),
	(50235),
	(50236),
	(50237),
	(50238),
	(50239),
	(50240),
	(50241),
	(50242),
	(50243),
	(50244),
	(50245),
	(50246),
	(50247),
	(50248),
	(50249),
	(50250),
	(50251),
	(50252),
	(50253),
	(50254),
	(50255),
	(50256),
	(50257),
	(50258),
	(50259),
	(50260),
	(50261),
	(50262),
	(50263),
	(50264),
	(50265),
	(50266),
	(50267),
	(50268),
	(50269),
	(50270),
	(50271),
	(50272),
	(50273),
	(50274),
	(50275),
	(50276),
	(50277),
	(50278),
	(50279),
	(50280),
	(50281),
	(50282),
	(50283),
	(50284),
	(50285),
	(50286),
	(50287),
	(50288),
	(50289),
	(50290),
	(50291),
	(50292),
	(50293),
	(50294),
	(50295),
	(50296),
	(50297),
	(50298),
	(50299),
	(50300),
	(50301),
	(50302),
	(50303),
	(50304),
	(50305),
	(50306),
	(50307),
	(50308),
	(50309),
	(50310),
	(50311),
	(50312),
	(50313),
	(50314),
	(50315),
	(50316),
	(50317),
	(50318),
	(50319),
	(50320),
	(50321),
	(50322),
	(50323),
	(50324),
	(50325),
	(50326),
	(50327),
	(50328),
	(50329),
	(50330),
	(50331),
	(50332),
	(50333),
	(50334),
	(50335),
	(50336),
	(50337),
	(50338),
	(50339),
	(50340),
	(50341),
	(50342),
	(50343),
	(50344),
	(50345),
	(50346),
	(50347),
	(50348),
	(50349),
	(50350),
	(50351),
	(50352),
	(50353),
	(50354),
	(50355),
	(50356),
	(50357),
	(50358),
	(50359),
	(50360),
	(50361),
	(50362),
	(50363),
	(50364),
	(50365),
	(50366),
	(50367),
	(50368),
	(50369),
	(50370),
	(50371),
	(50372),
	(50373),
	(50374),
	(50375),
	(50376),
	(50377),
	(50378),
	(50379),
	(50380),
	(50381),
	(50382),
	(50383),
	(50384),
	(50385),
	(50386),
	(50387),
	(50388),
	(50389),
	(50390),
	(50391),
	(50392),
	(50393),
	(50394),
	(50395),
	(50396),
	(50397),
	(50398),
	(50399),
	(50400),
	(50401),
	(50402),
	(50403),
	(50404),
	(50405),
	(50406),
	(50407),
	(50408),
	(50409),
	(50410),
	(50411),
	(50412),
	(50413),
	(50414),
	(50415),
	(50416),
	(50417),
	(50418),
	(50419),
	(50420),
	(50421),
	(50422),
	(50423),
	(50424),
	(50425),
	(50426),
	(50427),
	(50428),
	(50429),
	(50430),
	(50431),
	(50432),
	(50433),
	(50434),
	(50435),
	(50436),
	(50437),
	(50438),
	(50439),
	(50440),
	(50441),
	(50442),
	(50443),
	(50444),
	(50445),
	(50446),
	(50447),
	(50448),
	(50449),
	(50450),
	(50451),
	(50452),
	(50453),
	(50454),
	(50455),
	(50456),
	(50457),
	(50458),
	(50459),
	(50460),
	(50461),
	(50462),
	(50463),
	(50464),
	(50465),
	(50466),
	(50467),
	(50468),
	(50469),
	(50470),
	(50471),
	(50472),
	(50473),
	(50474),
	(50475),
	(50476),
	(50477),
	(50478),
	(50479),
	(50480),
	(50481),
	(50482),
	(50483),
	(50484),
	(50485),
	(50486),
	(50487),
	(50488),
	(50489),
	(50490),
	(50491),
	(50492),
	(50493),
	(50494),
	(50495),
	(50496),
	(50497),
	(50498),
	(50499),
	(50500),
	(50501),
	(50502),
	(50503),
	(50504),
	(50505),
	(50506),
	(50507),
	(50508),
	(50509),
	(50510),
	(50511),
	(50512),
	(50513),
	(50514),
	(50515),
	(50516),
	(50517),
	(50518),
	(50519),
	(50520),
	(50521),
	(50522),
	(50523),
	(50524),
	(50525),
	(50526),
	(50527),
	(50528),
	(50529),
	(50530),
	(50531),
	(50532),
	(50533),
	(50534),
	(50535),
	(50536),
	(50537),
	(50538),
	(50539),
	(50540),
	(50541),
	(50542),
	(50543),
	(50544),
	(50545),
	(50546),
	(50547),
	(50548),
	(50549),
	(50550),
	(50551),
	(50552),
	(50553),
	(50554),
	(50555),
	(50556),
	(50557),
	(50558),
	(50559),
	(50560),
	(50561),
	(50562),
	(50563),
	(50564),
	(50565),
	(50566),
	(50567),
	(50568),
	(50569),
	(50570),
	(50571),
	(50572),
	(50573),
	(50574),
	(50575),
	(50576),
	(50577),
	(50578),
	(50579),
	(50580),
	(50581),
	(50582),
	(50583),
	(50584),
	(50585),
	(50586),
	(50587),
	(50588),
	(50589),
	(50590),
	(50591),
	(50592),
	(50593),
	(50594),
	(50595),
	(50596),
	(50597),
	(50598),
	(50599),
	(50600),
	(50601),
	(50602),
	(50603),
	(50604),
	(50605),
	(50606),
	(50607),
	(50608),
	(50609),
	(50610),
	(50611),
	(50612),
	(50613),
	(50614),
	(50615),
	(50616),
	(50617),
	(50618),
	(50619),
	(50620),
	(50621),
	(50622),
	(50623),
	(50624),
	(50625),
	(50626),
	(50627),
	(50628),
	(50629),
	(50630),
	(50631),
	(50632),
	(50633),
	(50634),
	(50635),
	(50636),
	(50637),
	(50638),
	(50639),
	(50640),
	(50641),
	(50642),
	(50643),
	(50644),
	(50645),
	(50646),
	(50647),
	(50648),
	(50649),
	(50650),
	(50651),
	(50652),
	(50653),
	(50654),
	(50655),
	(50656),
	(50657),
	(50658),
	(50659),
	(50660),
	(50661),
	(50662),
	(50663),
	(50664),
	(50665),
	(50666),
	(50667),
	(50668),
	(50669),
	(50670),
	(50671),
	(50672),
	(50673),
	(50674),
	(50675),
	(50676),
	(50677),
	(50678),
	(50679),
	(50680),
	(50681),
	(50682),
	(50683),
	(50684),
	(50685),
	(50686),
	(50687),
	(50688),
	(50689),
	(50690),
	(50691),
	(50692),
	(50693),
	(50694),
	(50695),
	(50696),
	(50697),
	(50698),
	(50699),
	(50700),
	(50701),
	(50702),
	(50703),
	(50704),
	(50705),
	(50706),
	(50707),
	(50708),
	(50709),
	(50710),
	(50711),
	(50712),
	(50713),
	(50714),
	(50715),
	(50716),
	(50717),
	(50718),
	(50719),
	(50720),
	(50721),
	(50722),
	(50723),
	(50724),
	(50725),
	(50726),
	(50727),
	(50728),
	(50729),
	(50730),
	(50731),
	(50732),
	(50733),
	(50734),
	(50735),
	(50736),
	(50737),
	(50738),
	(50739),
	(50740),
	(50741),
	(50742),
	(50743),
	(50744),
	(50745),
	(50746),
	(50747),
	(50748),
	(50749),
	(50750),
	(50751),
	(50752),
	(50753),
	(50754),
	(50755),
	(50756),
	(50757),
	(50758),
	(50759),
	(50760),
	(50761),
	(50762),
	(50763),
	(50764),
	(50765),
	(50766),
	(50767),
	(50768),
	(50769),
	(50770),
	(50771),
	(50772),
	(50773),
	(50774),
	(50775),
	(50776),
	(50777),
	(50778),
	(50779),
	(50780),
	(50781),
	(50782),
	(50783),
	(50784),
	(50785),
	(50786),
	(50787),
	(50788),
	(50789),
	(50790),
	(50791),
	(50792),
	(50793),
	(50794),
	(50795),
	(50796),
	(50797),
	(50798),
	(50799),
	(50800),
	(50801),
	(50802),
	(50803),
	(50804),
	(50805),
	(50806),
	(50807),
	(50808),
	(50809),
	(50810),
	(50811),
	(50812),
	(50813),
	(50814),
	(50815),
	(50816),
	(50817),
	(50818),
	(50819),
	(50820),
	(50821),
	(50822),
	(50823),
	(50824),
	(50825),
	(50826),
	(50827),
	(50828),
	(50829),
	(50830),
	(50831),
	(50832),
	(50833),
	(50834),
	(50835),
	(50836),
	(50837),
	(50838),
	(50839),
	(50840),
	(50841),
	(50842),
	(50843),
	(50844),
	(50845),
	(50846),
	(50847),
	(50848),
	(50849),
	(50850),
	(50851),
	(50852),
	(50853),
	(50854),
	(50855),
	(50856),
	(50857),
	(50858),
	(50859),
	(50860),
	(50861),
	(50862),
	(50863),
	(50864),
	(50865),
	(50866),
	(50867),
	(50868),
	(50869),
	(50870),
	(50871),
	(50872),
	(50873),
	(50874),
	(50875),
	(50876),
	(50877),
	(50878),
	(50879),
	(50880),
	(50881),
	(50882),
	(50883),
	(50884),
	(50885),
	(50886),
	(50887),
	(50888),
	(50889),
	(50890),
	(50891),
	(50892),
	(50893),
	(50894),
	(50895),
	(50896),
	(50897),
	(50898),
	(50899),
	(50900),
	(50901),
	(50902),
	(50903),
	(50904),
	(50905),
	(50906),
	(50907),
	(50908),
	(50909),
	(50910),
	(50911),
	(50912),
	(50913),
	(50914),
	(50915),
	(50916),
	(50917),
	(50918),
	(50919),
	(50920),
	(50921),
	(50922),
	(50923),
	(50924),
	(50925),
	(50926),
	(50927),
	(50928),
	(50929),
	(50930),
	(50931),
	(50932),
	(50933),
	(50934),
	(50935),
	(50936),
	(50937),
	(50938),
	(50939),
	(50940),
	(50941),
	(50942),
	(50943),
	(50944),
	(50945),
	(50946),
	(50947),
	(50948),
	(50949),
	(50950),
	(50951),
	(50952),
	(50953),
	(50954),
	(50955),
	(50956),
	(50957),
	(50958),
	(50959),
	(50960),
	(50961),
	(50962),
	(50963),
	(50964),
	(50965),
	(50966),
	(50967),
	(50968),
	(50969),
	(50970),
	(50971),
	(50972),
	(50973),
	(50974),
	(50975),
	(50976),
	(50977),
	(50978),
	(50979),
	(50980),
	(50981),
	(50982),
	(50983),
	(50984),
	(50985),
	(50986),
	(50987),
	(50988),
	(50989),
	(50990),
	(50991),
	(50992),
	(50993),
	(50994),
	(50995),
	(50996),
	(50997),
	(50998),
	(50999),
	(51000),
	(51001),
	(51002),
	(51003),
	(51004),
	(51005),
	(51006),
	(51007),
	(51008),
	(51009),
	(51010),
	(51011),
	(51012),
	(51013),
	(51014),
	(51015),
	(51016),
	(51017),
	(51018),
	(51019),
	(51020),
	(51021),
	(51022),
	(51023),
	(51024),
	(51025),
	(51026),
	(51027),
	(51028),
	(51029),
	(51030),
	(51031),
	(51032),
	(51033),
	(51034),
	(51035),
	(51036),
	(51037),
	(51038),
	(51039),
	(51040),
	(51041),
	(51042),
	(51043),
	(51044),
	(51045),
	(51046),
	(51047),
	(51048),
	(51049),
	(51050),
	(51051),
	(51052),
	(51053),
	(51054),
	(51055),
	(51056),
	(51057),
	(51058),
	(51059),
	(51060),
	(51061),
	(51062),
	(51063),
	(51064),
	(51065),
	(51066),
	(51067),
	(51068),
	(51069),
	(51070),
	(51071),
	(51072),
	(51073),
	(51074),
	(51075),
	(51076),
	(51077),
	(51078),
	(51079),
	(51080),
	(51081),
	(51082),
	(51083),
	(51084),
	(51085),
	(51086),
	(51087),
	(51088),
	(51089),
	(51090),
	(51091),
	(51092),
	(51093),
	(51094),
	(51095),
	(51096),
	(51097),
	(51098),
	(51099),
	(51100),
	(51101),
	(51102),
	(51103),
	(51104),
	(51105),
	(51106),
	(51107),
	(51108),
	(51109),
	(51110),
	(51111),
	(51112),
	(51113),
	(51114),
	(51115),
	(51116),
	(51117),
	(51118),
	(51119),
	(51120),
	(51121),
	(51122),
	(51123),
	(51124),
	(51125),
	(51126),
	(51127),
	(51128),
	(51129),
	(51130),
	(51131),
	(51132),
	(51133),
	(51134),
	(51135),
	(51136),
	(51137),
	(51138),
	(51139),
	(51140),
	(51141),
	(51142),
	(51143),
	(51144),
	(51145),
	(51146),
	(51147),
	(51148),
	(51149),
	(51150),
	(51151),
	(51152),
	(51153),
	(51154),
	(51155),
	(51156),
	(51157),
	(51158),
	(51159),
	(51160),
	(51161),
	(51162),
	(51163),
	(51164),
	(51165),
	(51166),
	(51167),
	(51168),
	(51169),
	(51170),
	(51171),
	(51172),
	(51173),
	(51174),
	(51175),
	(51176),
	(51177),
	(51178),
	(51179),
	(51180),
	(51181),
	(51182),
	(51183),
	(51184),
	(51185),
	(51186),
	(51187),
	(51188),
	(51189),
	(51190),
	(51191),
	(51192),
	(51193),
	(51194),
	(51195),
	(51196),
	(51197),
	(51198),
	(51199),
	(51200),
	(51201),
	(51202),
	(51203),
	(51204),
	(51205),
	(51206),
	(51207),
	(51208),
	(51209),
	(51210),
	(51211),
	(51212),
	(51213),
	(51214),
	(51215),
	(51216),
	(51217),
	(51218),
	(51219),
	(51220),
	(51221),
	(51222),
	(51223),
	(51224),
	(51225),
	(51226),
	(51227),
	(51228),
	(51229),
	(51230),
	(51231),
	(51232),
	(51233),
	(51234),
	(51235),
	(51236),
	(51237),
	(51238),
	(51239),
	(51240),
	(51241),
	(51242),
	(51243),
	(51244),
	(51245),
	(51246),
	(51247),
	(51248),
	(51249),
	(51250),
	(51251),
	(51252),
	(51253),
	(51254),
	(51255),
	(51256),
	(51257),
	(51258),
	(51259),
	(51260),
	(51261),
	(51262),
	(51263),
	(51264),
	(51265),
	(51266),
	(51267),
	(51268),
	(51269),
	(51270),
	(51271),
	(51272),
	(51273),
	(51274),
	(51275),
	(51276),
	(51277),
	(51278),
	(51279),
	(51280),
	(51281),
	(51282),
	(51283),
	(51284),
	(51285),
	(51286),
	(51287),
	(51288),
	(51289),
	(51290),
	(51291),
	(51292),
	(51293),
	(51294),
	(51295),
	(51296),
	(51297),
	(51298),
	(51299),
	(51300),
	(51301),
	(51302),
	(51303),
	(51304),
	(51305),
	(51306),
	(51307),
	(51308),
	(51309),
	(51310),
	(51311),
	(51312),
	(51313),
	(51314),
	(51315),
	(51316),
	(51317),
	(51318),
	(51319),
	(51320),
	(51321),
	(51322),
	(51323),
	(51324),
	(51325),
	(51326),
	(51327),
	(51328),
	(51329),
	(51330),
	(51331),
	(51332),
	(51333),
	(51334),
	(51335),
	(51336),
	(51337),
	(51338),
	(51339),
	(51340),
	(51341),
	(51342),
	(51343),
	(51344),
	(51345),
	(51346),
	(51347),
	(51348),
	(51349),
	(51350),
	(51351),
	(51352),
	(51353),
	(51354),
	(51355),
	(51356),
	(51357),
	(51358),
	(51359),
	(51360),
	(51361),
	(51362),
	(51363),
	(51364),
	(51365),
	(51366),
	(51367),
	(51368),
	(51369),
	(51370),
	(51371),
	(51372),
	(51373),
	(51374),
	(51375),
	(51376),
	(51377),
	(51378),
	(51379),
	(51380),
	(51381),
	(51382),
	(51383),
	(51384),
	(51385),
	(51386),
	(51387),
	(51388),
	(51389),
	(51390),
	(51391),
	(51392),
	(51393),
	(51394),
	(51395),
	(51396),
	(51397),
	(51398),
	(51399),
	(51400),
	(51401),
	(51402),
	(51403),
	(51404),
	(51405),
	(51406),
	(51407),
	(51408),
	(51409),
	(51410),
	(51411),
	(51412),
	(51413),
	(51414),
	(51415),
	(51416),
	(51417),
	(51418),
	(51419),
	(51420),
	(51421),
	(51422),
	(51423),
	(51424),
	(51425),
	(51426),
	(51427),
	(51428),
	(51429),
	(51430),
	(51431),
	(51432),
	(51433),
	(51434),
	(51435),
	(51436),
	(51437),
	(51438),
	(51439),
	(51440),
	(51441),
	(51442),
	(51443),
	(51444),
	(51445),
	(51446),
	(51447),
	(51448),
	(51449),
	(51450),
	(51451),
	(51452),
	(51453),
	(51454),
	(51455),
	(51456),
	(51457),
	(51458),
	(51459),
	(51460),
	(51461),
	(51462),
	(51463),
	(51464),
	(51465),
	(51466),
	(51467),
	(51468),
	(51469),
	(51470),
	(51471),
	(51472),
	(51473),
	(51474),
	(51475),
	(51476),
	(51477),
	(51478),
	(51479),
	(51480),
	(51481),
	(51482),
	(51483),
	(51484),
	(51485),
	(51486),
	(51487),
	(51488),
	(51489),
	(51490),
	(51491),
	(51492),
	(51493),
	(51494),
	(51495),
	(51496),
	(51497),
	(51498),
	(51499),
	(51500),
	(51501),
	(51502),
	(51503),
	(51504),
	(51505),
	(51506),
	(51507),
	(51508),
	(51509),
	(51510),
	(51511),
	(51512),
	(51513),
	(51514),
	(51515),
	(51516),
	(51517),
	(51518),
	(51519),
	(51520),
	(51521),
	(51522),
	(51523),
	(51524),
	(51525),
	(51526),
	(51527),
	(51528),
	(51529),
	(51530),
	(51531),
	(51532),
	(51533),
	(51534),
	(51535),
	(51536),
	(51537),
	(51538),
	(51539),
	(51540),
	(51541),
	(51542),
	(51543),
	(51544),
	(51545),
	(51546),
	(51547),
	(51548),
	(51549),
	(51550),
	(51551),
	(51552),
	(51553),
	(51554),
	(51555),
	(51556),
	(51557),
	(51558),
	(51559),
	(51560),
	(51561),
	(51562),
	(51563),
	(51564),
	(51565),
	(51566),
	(51567),
	(51568),
	(51569),
	(51570),
	(51571),
	(51572),
	(51573),
	(51574),
	(51575),
	(51576),
	(51577),
	(51578),
	(51579),
	(51580),
	(51581),
	(51582),
	(51583),
	(51584),
	(51585),
	(51586),
	(51587),
	(51588),
	(51589),
	(51590),
	(51591),
	(51592),
	(51593),
	(51594),
	(51595),
	(51596),
	(51597),
	(51598),
	(51599),
	(51600),
	(51601),
	(51602),
	(51603),
	(51604),
	(51605),
	(51606),
	(51607),
	(51608),
	(51609),
	(51610),
	(51611),
	(51612),
	(51613),
	(51614),
	(51615),
	(51616),
	(51617),
	(51618),
	(51619),
	(51620),
	(51621),
	(51622),
	(51623),
	(51624),
	(51625),
	(51626),
	(51627),
	(51628),
	(51629),
	(51630),
	(51631),
	(51632),
	(51633),
	(51634),
	(51635),
	(51636),
	(51637),
	(51638),
	(51639),
	(51640),
	(51641),
	(51642),
	(51643),
	(51644),
	(51645),
	(51646),
	(51647),
	(51648),
	(51649),
	(51650),
	(51651),
	(51652),
	(51653),
	(51654),
	(51655),
	(51656),
	(51657),
	(51658),
	(51659),
	(51660),
	(51661),
	(51662),
	(51663),
	(51664),
	(51665),
	(51666),
	(51667),
	(51668),
	(51669),
	(51670),
	(51671),
	(51672),
	(51673),
	(51674),
	(51675),
	(51676),
	(51677),
	(51678),
	(51679),
	(51680),
	(51681),
	(51682),
	(51683),
	(51684),
	(51685),
	(51686),
	(51687),
	(51688),
	(51689),
	(51690),
	(51691),
	(51692),
	(51693),
	(51694),
	(51695),
	(51696),
	(51697),
	(51698),
	(51699),
	(51700),
	(51701),
	(51702),
	(51703),
	(51704),
	(51705),
	(51706),
	(51707),
	(51708),
	(51709),
	(51710),
	(51711),
	(51712),
	(51713),
	(51714),
	(51715),
	(51716),
	(51717),
	(51718),
	(51719),
	(51720),
	(51721),
	(51722),
	(51723),
	(51724),
	(51725),
	(51726),
	(51727),
	(51728),
	(51729),
	(51730),
	(51731),
	(51732),
	(51733),
	(51734),
	(51735),
	(51736),
	(51737),
	(51738),
	(51739),
	(51740),
	(51741),
	(51742),
	(51743),
	(51744),
	(51745),
	(51746),
	(51747),
	(51748),
	(51749),
	(51750),
	(51751),
	(51752),
	(51753),
	(51754),
	(51755),
	(51756),
	(51757),
	(51758),
	(51759),
	(51760),
	(51761),
	(51762),
	(51763),
	(51764),
	(51765),
	(51766),
	(51767),
	(51768),
	(51769),
	(51770),
	(51771),
	(51772),
	(51773),
	(51774),
	(51775),
	(51776),
	(51777),
	(51778),
	(51779),
	(51780),
	(51781),
	(51782),
	(51783),
	(51784),
	(51785),
	(51786),
	(51787),
	(51788),
	(51789),
	(51790),
	(51791),
	(51792),
	(51793),
	(51794),
	(51795),
	(51796),
	(51797),
	(51798),
	(51799),
	(51800),
	(51801),
	(51802),
	(51803),
	(51804),
	(51805),
	(51806),
	(51807),
	(51808),
	(51809),
	(51810),
	(51811),
	(51812),
	(51813),
	(51814),
	(51815),
	(51816),
	(51817),
	(51818),
	(51819),
	(51820),
	(51821),
	(51822),
	(51823),
	(51824),
	(51825),
	(51826),
	(51827),
	(51828),
	(51829),
	(51830),
	(51831),
	(51832),
	(51833),
	(51834),
	(51835),
	(51836),
	(51837),
	(51838),
	(51839),
	(51840),
	(51841),
	(51842),
	(51843),
	(51844),
	(51845),
	(51846),
	(51847),
	(51848),
	(51849),
	(51850),
	(51851),
	(51852),
	(51853),
	(51854),
	(51855),
	(51856),
	(51857),
	(51858),
	(51859),
	(51860),
	(51861),
	(51862),
	(51863),
	(51864),
	(51865),
	(51866),
	(51867),
	(51868),
	(51869),
	(51870),
	(51871),
	(51872),
	(51873),
	(51874),
	(51875),
	(51876),
	(51877),
	(51878),
	(51879),
	(51880),
	(51881),
	(51882),
	(51883),
	(51884),
	(51885),
	(51886),
	(51887),
	(51888),
	(51889),
	(51890),
	(51891),
	(51892),
	(51893),
	(51894),
	(51895),
	(51896),
	(51897),
	(51898),
	(51899),
	(51900),
	(51901),
	(51902),
	(51903),
	(51904),
	(51905),
	(51906),
	(51907),
	(51908),
	(51909),
	(51910),
	(51911),
	(51912),
	(51913),
	(51914),
	(51915),
	(51916),
	(51917),
	(51918),
	(51919),
	(51920),
	(51921),
	(51922),
	(51923),
	(51924),
	(51925),
	(51926),
	(51927),
	(51928),
	(51929),
	(51930),
	(51931),
	(51932),
	(51933),
	(51934),
	(51935),
	(51936),
	(51937),
	(51938),
	(51939),
	(51940),
	(51941),
	(51942),
	(51943),
	(51944),
	(51945),
	(51946),
	(51947),
	(51948),
	(51949),
	(51950),
	(51951),
	(51952),
	(51953),
	(51954),
	(51955),
	(51956),
	(51957),
	(51958),
	(51959),
	(51960),
	(51961),
	(51962),
	(51963),
	(51964),
	(51965),
	(51966),
	(51967),
	(51968),
	(51969),
	(51970),
	(51971),
	(51972),
	(51973),
	(51974),
	(51975),
	(51976),
	(51977),
	(51978),
	(51979),
	(51980),
	(51981),
	(51982),
	(51983),
	(51984),
	(51985),
	(51986),
	(51987),
	(51988),
	(51989),
	(51990),
	(51991),
	(51992),
	(51993),
	(51994),
	(51995),
	(51996),
	(51997),
	(51998),
	(51999),
	(52000),
	(52001),
	(52002),
	(52003),
	(52004),
	(52005),
	(52006),
	(52007),
	(52008),
	(52009),
	(52010),
	(52011),
	(52012),
	(52013),
	(52014),
	(52015),
	(52016),
	(52017),
	(52018),
	(52019),
	(52020),
	(52021),
	(52022),
	(52023),
	(52024),
	(52025),
	(52026),
	(52027),
	(52028),
	(52029),
	(52030),
	(52031),
	(52032),
	(52033),
	(52034),
	(52035),
	(52036),
	(52037),
	(52038),
	(52039),
	(52040),
	(52041),
	(52042),
	(52043),
	(52044),
	(52045),
	(52046),
	(52047),
	(52048),
	(52049),
	(52050),
	(52051),
	(52052),
	(52053),
	(52054),
	(52055),
	(52056),
	(52057),
	(52058),
	(52059),
	(52060),
	(52061),
	(52062),
	(52063),
	(52064),
	(52065),
	(52066),
	(52067),
	(52068),
	(52069),
	(52070),
	(52071),
	(52072),
	(52073),
	(52074),
	(52075),
	(52076),
	(52077),
	(52078),
	(52079),
	(52080),
	(52081),
	(52082),
	(52083),
	(52084),
	(52085),
	(52086),
	(52087),
	(52088),
	(52089),
	(52090),
	(52091),
	(52092),
	(52093),
	(52094),
	(52095),
	(52096),
	(52097),
	(52098),
	(52099),
	(52100),
	(52101),
	(52102),
	(52103),
	(52104),
	(52105),
	(52106),
	(52107),
	(52108),
	(52109),
	(52110),
	(52111),
	(52112),
	(52113),
	(52114),
	(52115),
	(52116),
	(52117),
	(52118),
	(52119),
	(52120),
	(52121),
	(52122),
	(52123),
	(52124),
	(52125),
	(52126),
	(52127),
	(52128),
	(52129),
	(52130),
	(52131),
	(52132),
	(52133),
	(52134),
	(52135),
	(52136),
	(52137),
	(52138),
	(52139),
	(52140),
	(52141),
	(52142),
	(52143),
	(52144),
	(52145),
	(52146),
	(52147),
	(52148),
	(52149),
	(52150),
	(52151),
	(52152),
	(52153),
	(52154),
	(52155),
	(52156),
	(52157),
	(52158),
	(52159),
	(52160),
	(52161),
	(52162),
	(52163),
	(52164),
	(52165),
	(52166),
	(52167),
	(52168),
	(52169),
	(52170),
	(52171),
	(52172),
	(52173),
	(52174),
	(52175),
	(52176),
	(52177),
	(52178),
	(52179),
	(52180),
	(52181),
	(52182),
	(52183),
	(52184),
	(52185),
	(52186),
	(52187),
	(52188),
	(52189),
	(52190),
	(52191),
	(52192),
	(52193),
	(52194),
	(52195),
	(52196),
	(52197),
	(52198),
	(52199),
	(52200),
	(52201),
	(52202),
	(52203),
	(52204),
	(52205),
	(52206),
	(52207),
	(52208),
	(52209),
	(52210),
	(52211),
	(52212),
	(52213),
	(52214),
	(52215),
	(52216),
	(52217),
	(52218),
	(52219),
	(52220),
	(52221),
	(52222),
	(52223),
	(52224),
	(52225),
	(52226),
	(52227),
	(52228),
	(52229),
	(52230),
	(52231),
	(52232),
	(52233),
	(52234),
	(52235),
	(52236),
	(52237),
	(52238),
	(52239),
	(52240),
	(52241),
	(52242),
	(52243),
	(52244),
	(52245),
	(52246),
	(52247),
	(52248),
	(52249),
	(52250),
	(52251),
	(52252),
	(52253),
	(52254),
	(52255),
	(52256),
	(52257),
	(52258),
	(52259),
	(52260),
	(52261),
	(52262),
	(52263),
	(52264),
	(52265),
	(52266),
	(52267),
	(52268),
	(52269),
	(52270),
	(52271),
	(52272),
	(52273),
	(52274),
	(52275),
	(52276),
	(52277),
	(52278),
	(52279),
	(52280),
	(52281),
	(52282),
	(52283),
	(52284),
	(52285),
	(52286),
	(52287),
	(52288),
	(52289),
	(52290),
	(52291),
	(52292),
	(52293),
	(52294),
	(52295),
	(52296),
	(52297),
	(52298),
	(52299),
	(52300),
	(52301),
	(52302),
	(52303),
	(52304),
	(52305),
	(52306),
	(52307),
	(52308),
	(52309),
	(52310),
	(52311),
	(52312),
	(52313),
	(52314),
	(52315),
	(52316),
	(52317),
	(52318),
	(52319),
	(52320),
	(52321),
	(52322),
	(52323),
	(52324),
	(52325),
	(52326),
	(52327),
	(52328),
	(52329),
	(52330),
	(52331),
	(52332),
	(52333),
	(52334),
	(52335),
	(52336),
	(52337),
	(52338),
	(52339),
	(52340),
	(52341),
	(52342),
	(52343),
	(52344),
	(52345),
	(52346),
	(52347),
	(52348),
	(52349),
	(52350),
	(52351),
	(52352),
	(52353),
	(52354),
	(52355),
	(52356),
	(52357),
	(52358),
	(52359),
	(52360),
	(52361),
	(52362),
	(52363),
	(52364),
	(52365),
	(52366),
	(52367),
	(52368),
	(52369),
	(52370),
	(52371),
	(52372),
	(52373),
	(52374),
	(52375),
	(52376),
	(52377),
	(52378),
	(52379),
	(52380),
	(52381),
	(52382),
	(52383),
	(52384),
	(52385),
	(52386),
	(52387),
	(52388),
	(52389),
	(52390),
	(52391),
	(52392),
	(52393),
	(52394),
	(52395),
	(52396),
	(52397),
	(52398),
	(52399),
	(52400),
	(52401),
	(52402),
	(52403),
	(52404),
	(52405),
	(52406),
	(52407),
	(52408),
	(52409),
	(52410),
	(52411),
	(52412),
	(52413),
	(52414),
	(52415),
	(52416),
	(52417),
	(52418),
	(52419),
	(52420),
	(52421),
	(52422),
	(52423),
	(52424),
	(52425),
	(52426),
	(52427),
	(52428),
	(52429),
	(52430),
	(52431),
	(52432),
	(52433),
	(52434),
	(52435),
	(52436),
	(52437),
	(52438),
	(52439),
	(52440),
	(52441),
	(52442),
	(52443),
	(52444),
	(52445),
	(52446),
	(52447),
	(52448),
	(52449),
	(52450),
	(52451),
	(52452),
	(52453),
	(52454),
	(52455),
	(52456),
	(52457),
	(52458),
	(52459),
	(52460),
	(52461),
	(52462),
	(52463),
	(52464),
	(52465),
	(52466),
	(52467),
	(52468),
	(52469),
	(52470),
	(52471),
	(52472),
	(52473),
	(52474),
	(52475),
	(52476),
	(52477),
	(52478),
	(52479),
	(52480),
	(52481),
	(52482),
	(52483),
	(52484),
	(52485),
	(52486),
	(52487),
	(52488),
	(52489),
	(52490),
	(52491),
	(52492),
	(52493),
	(52494),
	(52495),
	(52496),
	(52497),
	(52498),
	(52499),
	(52500),
	(52501),
	(52502),
	(52503),
	(52504),
	(52505),
	(52506),
	(52507),
	(52508),
	(52509),
	(52510),
	(52511),
	(52512),
	(52513),
	(52514),
	(52515),
	(52516),
	(52517),
	(52518),
	(52519),
	(52520),
	(52521),
	(52522),
	(52523),
	(52524),
	(52525),
	(52526),
	(52527),
	(52528),
	(52529),
	(52530),
	(52531),
	(52532),
	(52533),
	(52534),
	(52535),
	(52536),
	(52537),
	(52538),
	(52539),
	(52540),
	(52541),
	(52542),
	(52543),
	(52544),
	(52545),
	(52546),
	(52547),
	(52548),
	(52549),
	(52550),
	(52551),
	(52552),
	(52553),
	(52554),
	(52555),
	(52556),
	(52557),
	(52558),
	(52559),
	(52560),
	(52561),
	(52562),
	(52563),
	(52564),
	(52565),
	(52566),
	(52567),
	(52568),
	(52569),
	(52570),
	(52571),
	(52572),
	(52573),
	(52574),
	(52575),
	(52576),
	(52577),
	(52578),
	(52579),
	(52580),
	(52581),
	(52582),
	(52583),
	(52584),
	(52585),
	(52586),
	(52587),
	(52588),
	(52589),
	(52590),
	(52591),
	(52592),
	(52593),
	(52594),
	(52595),
	(52596),
	(52597),
	(52598),
	(52599),
	(52600),
	(52601),
	(52602),
	(52603),
	(52604),
	(52605),
	(52606),
	(52607),
	(52608),
	(52609),
	(52610),
	(52611),
	(52612),
	(52613),
	(52614),
	(52615),
	(52616),
	(52617),
	(52618),
	(52619),
	(52620),
	(52621),
	(52622),
	(52623),
	(52624),
	(52625),
	(52626),
	(52627),
	(52628),
	(52629),
	(52630),
	(52631),
	(52632),
	(52633),
	(52634),
	(52635),
	(52636),
	(52637),
	(52638),
	(52639),
	(52640),
	(52641),
	(52642),
	(52643),
	(52644),
	(52645),
	(52646),
	(52647),
	(52648),
	(52649),
	(52650),
	(52651),
	(52652),
	(52653),
	(52654),
	(52655),
	(52656),
	(52657),
	(52658),
	(52659),
	(52660),
	(52661),
	(52662),
	(52663),
	(52664),
	(52665),
	(52666),
	(52667),
	(52668),
	(52669),
	(52670),
	(52671),
	(52672),
	(52673),
	(52674),
	(52675),
	(52676),
	(52677),
	(52678),
	(52679),
	(52680),
	(52681),
	(52682),
	(52683),
	(52684),
	(52685),
	(52686),
	(52687),
	(52688),
	(52689),
	(52690),
	(52691),
	(52692),
	(52693),
	(52694),
	(52695),
	(52696),
	(52697),
	(52698),
	(52699),
	(52700),
	(52701),
	(52702),
	(52703),
	(52704),
	(52705),
	(52706),
	(52707),
	(52708),
	(52709),
	(52710),
	(52711),
	(52712),
	(52713),
	(52714),
	(52715),
	(52716),
	(52717),
	(52718),
	(52719),
	(52720),
	(52721),
	(52722),
	(52723),
	(52724),
	(52725),
	(52726),
	(52727),
	(52728),
	(52729),
	(52730),
	(52731),
	(52732),
	(52733),
	(52734),
	(52735),
	(52736),
	(52737),
	(52738),
	(52739),
	(52740),
	(52741),
	(52742),
	(52743),
	(52744),
	(52745),
	(52746),
	(52747),
	(52748),
	(52749),
	(52750),
	(52751),
	(52752),
	(52753),
	(52754),
	(52755),
	(52756),
	(52757),
	(52758),
	(52759),
	(52760),
	(52761),
	(52762),
	(52763),
	(52764),
	(52765),
	(52766),
	(52767),
	(52768),
	(52769),
	(52770),
	(52771),
	(52772),
	(52773),
	(52774),
	(52775),
	(52776),
	(52777),
	(52778),
	(52779),
	(52780),
	(52781),
	(52782),
	(52783),
	(52784),
	(52785),
	(52786),
	(52787),
	(52788),
	(52789),
	(52790),
	(52791),
	(52792),
	(52793),
	(52794),
	(52795),
	(52796),
	(52797),
	(52798),
	(52799),
	(52800),
	(52801),
	(52802),
	(52803),
	(52804),
	(52805),
	(52806),
	(52807),
	(52808),
	(52809),
	(52810),
	(52811),
	(52812),
	(52813),
	(52814),
	(52815),
	(52816),
	(52817),
	(52818),
	(52819),
	(52820),
	(52821),
	(52822),
	(52823),
	(52824),
	(52825),
	(52826),
	(52827),
	(52828),
	(52829),
	(52830),
	(52831),
	(52832),
	(52833),
	(52834),
	(52835),
	(52836),
	(52837),
	(52838),
	(52839),
	(52840),
	(52841),
	(52842),
	(52843),
	(52844),
	(52845),
	(52846),
	(52847),
	(52848),
	(52849),
	(52850),
	(52851),
	(52852),
	(52853),
	(52854),
	(52855),
	(52856),
	(52857),
	(52858),
	(52859),
	(52860),
	(52861),
	(52862),
	(52863),
	(52864),
	(52865),
	(52866),
	(52867),
	(52868),
	(52869),
	(52870),
	(52871),
	(52872),
	(52873),
	(52874),
	(52875),
	(52876),
	(52877),
	(52878),
	(52879),
	(52880),
	(52881),
	(52882),
	(52883),
	(52884),
	(52885),
	(52886),
	(52887),
	(52888),
	(52889),
	(52890),
	(52891),
	(52892),
	(52893),
	(52894),
	(52895),
	(52896),
	(52897),
	(52898),
	(52899),
	(52900),
	(52901),
	(52902),
	(52903),
	(52904),
	(52905),
	(52906),
	(52907),
	(52908),
	(52909),
	(52910),
	(52911),
	(52912),
	(52913),
	(52914),
	(52915),
	(52916),
	(52917),
	(52918),
	(52919),
	(52920),
	(52921),
	(52922),
	(52923),
	(52924),
	(52925),
	(52926),
	(52927),
	(52928),
	(52929),
	(52930),
	(52931),
	(52932),
	(52933),
	(52934),
	(52935),
	(52936),
	(52937),
	(52938),
	(52939),
	(52940),
	(52941),
	(52942),
	(52943),
	(52944),
	(52945),
	(52946),
	(52947),
	(52948),
	(52949),
	(52950),
	(52951),
	(52952),
	(52953),
	(52954),
	(52955),
	(52956),
	(52957),
	(52958),
	(52959),
	(52960),
	(52961),
	(52962),
	(52963),
	(52964),
	(52965),
	(52966),
	(52967),
	(52968),
	(52969),
	(52970),
	(52971),
	(52972),
	(52973),
	(52974),
	(52975),
	(52976),
	(52977),
	(52978),
	(52979),
	(52980),
	(52981),
	(52982),
	(52983),
	(52984),
	(52985),
	(52986),
	(52987),
	(52988),
	(52989),
	(52990),
	(52991),
	(52992),
	(52993),
	(52994),
	(52995),
	(52996),
	(52997),
	(52998),
	(52999),
	(53000),
	(53001),
	(53002),
	(53003),
	(53004),
	(53005),
	(53006),
	(53007),
	(53008),
	(53009),
	(53010),
	(53011),
	(53012),
	(53013),
	(53014),
	(53015),
	(53016),
	(53017),
	(53018),
	(53019),
	(53020),
	(53021),
	(53022),
	(53023),
	(53024),
	(53025),
	(53026),
	(53027),
	(53028),
	(53029),
	(53030),
	(53031),
	(53032),
	(53033),
	(53034),
	(53035),
	(53036),
	(53037),
	(53038),
	(53039),
	(53040),
	(53041),
	(53042),
	(53043),
	(53044),
	(53045),
	(53046),
	(53047),
	(53048),
	(53049),
	(53050),
	(53051),
	(53052),
	(53053),
	(53054),
	(53055),
	(53056),
	(53057),
	(53058),
	(53059),
	(53060),
	(53061),
	(53062),
	(53063),
	(53064),
	(53065),
	(53066),
	(53067),
	(53068),
	(53069),
	(53070),
	(53071),
	(53072),
	(53073),
	(53074),
	(53075),
	(53076),
	(53077),
	(53078),
	(53079),
	(53080),
	(53081),
	(53082),
	(53083),
	(53084),
	(53085),
	(53086),
	(53087),
	(53088),
	(53089),
	(53090),
	(53091),
	(53092),
	(53093),
	(53094),
	(53095),
	(53096),
	(53097),
	(53098),
	(53099),
	(53100),
	(53101),
	(53102),
	(53103),
	(53104),
	(53105),
	(53106),
	(53107),
	(53108),
	(53109),
	(53110),
	(53111),
	(53112),
	(53113),
	(53114),
	(53115),
	(53116),
	(53117),
	(53118),
	(53119),
	(53120),
	(53121),
	(53122),
	(53123),
	(53124),
	(53125),
	(53126),
	(53127),
	(53128),
	(53129),
	(53130),
	(53131),
	(53132),
	(53133),
	(53134),
	(53135),
	(53136),
	(53137),
	(53138),
	(53139),
	(53140),
	(53141),
	(53142),
	(53143),
	(53144),
	(53145),
	(53146),
	(53147),
	(53148),
	(53149),
	(53150),
	(53151),
	(53152),
	(53153),
	(53154),
	(53155),
	(53156),
	(53157),
	(53158),
	(53159),
	(53160),
	(53161),
	(53162),
	(53163),
	(53164),
	(53165),
	(53166),
	(53167),
	(53168),
	(53169),
	(53170),
	(53171),
	(53172),
	(53173),
	(53174),
	(53175),
	(53176),
	(53177),
	(53178),
	(53179),
	(53180),
	(53181),
	(53182),
	(53183),
	(53184),
	(53185),
	(53186),
	(53187),
	(53188),
	(53189),
	(53190),
	(53191),
	(53192),
	(53193),
	(53194),
	(53195),
	(53196),
	(53197),
	(53198),
	(53199),
	(53200),
	(53201),
	(53202),
	(53203),
	(53204),
	(53205),
	(53206),
	(53207),
	(53208),
	(53209),
	(53210),
	(53211),
	(53212),
	(53213),
	(53214),
	(53215),
	(53216),
	(53217),
	(53218),
	(53219),
	(53220),
	(53221),
	(53222),
	(53223),
	(53224),
	(53225),
	(53226),
	(53227),
	(53228),
	(53229),
	(53230),
	(53231),
	(53232),
	(53233),
	(53234),
	(53235),
	(53236),
	(53237),
	(53238),
	(53239),
	(53240),
	(53241),
	(53242),
	(53243),
	(53244),
	(53245),
	(53246),
	(53247),
	(53248),
	(53249),
	(53250),
	(53251),
	(53252),
	(53253),
	(53254),
	(53255),
	(53256),
	(53257),
	(53258),
	(53259),
	(53260),
	(53261),
	(53262),
	(53263),
	(53264),
	(53265),
	(53266),
	(53267),
	(53268),
	(53269),
	(53270),
	(53271),
	(53272),
	(53273),
	(53274),
	(53275),
	(53276),
	(53277),
	(53278),
	(53279),
	(53280),
	(53281),
	(53282),
	(53283),
	(53284),
	(53285),
	(53286),
	(53287),
	(53288),
	(53289),
	(53290),
	(53291),
	(53292),
	(53293),
	(53294),
	(53295),
	(53296),
	(53297),
	(53298),
	(53299),
	(53300),
	(53301),
	(53302),
	(53303),
	(53304),
	(53305),
	(53306),
	(53307),
	(53308),
	(53309),
	(53310),
	(53311),
	(53312),
	(53313),
	(53314),
	(53315),
	(53316),
	(53317),
	(53318),
	(53319),
	(53320),
	(53321),
	(53322),
	(53323),
	(53324),
	(53325),
	(53326),
	(53327),
	(53328),
	(53329),
	(53330),
	(53331),
	(53332),
	(53333),
	(53334),
	(53335),
	(53336),
	(53337),
	(53338),
	(53339),
	(53340),
	(53341),
	(53342),
	(53343),
	(53344),
	(53345),
	(53346),
	(53347),
	(53348),
	(53349),
	(53350),
	(53351),
	(53352),
	(53353),
	(53354),
	(53355),
	(53356),
	(53357),
	(53358),
	(53359),
	(53360),
	(53361),
	(53362),
	(53363),
	(53364),
	(53365),
	(53366),
	(53367),
	(53368),
	(53369),
	(53370),
	(53371),
	(53372),
	(53373),
	(53374),
	(53375),
	(53376),
	(53377),
	(53378),
	(53379),
	(53380),
	(53381),
	(53382),
	(53383),
	(53384),
	(53385),
	(53386),
	(53387),
	(53388),
	(53389),
	(53390),
	(53391),
	(53392),
	(53393),
	(53394),
	(53395),
	(53396),
	(53397),
	(53398),
	(53399),
	(53400),
	(53401),
	(53402),
	(53403),
	(53404),
	(53405),
	(53406),
	(53407),
	(53408),
	(53409),
	(53410),
	(53411),
	(53412),
	(53413),
	(53414),
	(53415),
	(53416),
	(53417),
	(53418),
	(53419),
	(53420),
	(53421),
	(53422),
	(53423),
	(53424),
	(53425),
	(53426),
	(53427),
	(53428),
	(53429),
	(53430),
	(53431),
	(53432),
	(53433),
	(53434),
	(53435),
	(53436),
	(53437),
	(53438),
	(53439),
	(53440),
	(53441),
	(53442),
	(53443),
	(53444),
	(53445),
	(53446),
	(53447),
	(53448),
	(53449),
	(53450),
	(53451),
	(53452),
	(53453),
	(53454),
	(53455),
	(53456),
	(53457),
	(53458),
	(53459),
	(53460),
	(53461),
	(53462),
	(53463),
	(53464),
	(53465),
	(53466),
	(53467),
	(53468),
	(53469),
	(53470),
	(53471),
	(53472),
	(53473),
	(53474),
	(53475),
	(53476),
	(53477),
	(53478),
	(53479),
	(53480),
	(53481),
	(53482),
	(53483),
	(53484),
	(53485),
	(53486),
	(53487),
	(53488),
	(53489),
	(53490),
	(53491),
	(53492),
	(53493),
	(53494),
	(53495),
	(53496),
	(53497),
	(53498),
	(53499),
	(53500),
	(53501),
	(53502),
	(53503),
	(53504),
	(53505),
	(53506),
	(53507),
	(53508),
	(53509),
	(53510),
	(53511),
	(53512),
	(53513),
	(53514),
	(53515),
	(53516),
	(53517),
	(53518),
	(53519),
	(53520),
	(53521),
	(53522),
	(53523),
	(53524),
	(53525),
	(53526),
	(53527),
	(53528),
	(53529),
	(53530),
	(53531),
	(53532),
	(53533),
	(53534),
	(53535),
	(53536),
	(53537),
	(53538),
	(53539),
	(53540),
	(53541),
	(53542),
	(53543),
	(53544),
	(53545),
	(53546),
	(53547),
	(53548),
	(53549),
	(53550),
	(53551),
	(53552),
	(53553),
	(53554),
	(53555),
	(53556),
	(53557),
	(53558),
	(53559),
	(53560),
	(53561),
	(53562),
	(53563),
	(53564),
	(53565),
	(53566),
	(53567),
	(53568),
	(53569),
	(53570),
	(53571),
	(53572),
	(53573),
	(53574),
	(53575),
	(53576),
	(53577),
	(53578),
	(53579),
	(53580),
	(53581),
	(53582),
	(53583),
	(53584),
	(53585),
	(53586),
	(53587),
	(53588),
	(53589),
	(53590),
	(53591),
	(53592),
	(53593),
	(53594),
	(53595),
	(53596),
	(53597),
	(53598),
	(53599),
	(53600),
	(53601),
	(53602),
	(53603),
	(53604),
	(53605),
	(53606),
	(53607),
	(53608),
	(53609),
	(53610),
	(53611),
	(53612),
	(53613),
	(53614),
	(53615),
	(53616),
	(53617),
	(53618),
	(53619),
	(53620),
	(53621),
	(53622),
	(53623),
	(53624),
	(53625),
	(53626),
	(53627),
	(53628),
	(53629),
	(53630),
	(53631),
	(53632),
	(53633),
	(53634),
	(53635),
	(53636),
	(53637),
	(53638),
	(53639),
	(53640),
	(53641),
	(53642),
	(53643),
	(53644),
	(53645),
	(53646),
	(53647),
	(53648),
	(53649),
	(53650),
	(53651),
	(53652),
	(53653),
	(53654),
	(53655),
	(53656),
	(53657),
	(53658),
	(53659),
	(53660),
	(53661),
	(53662),
	(53663),
	(53664),
	(53665),
	(53666),
	(53667),
	(53668),
	(53669),
	(53670),
	(53671),
	(53672),
	(53673),
	(53674),
	(53675),
	(53676),
	(53677),
	(53678),
	(53679),
	(53680),
	(53681),
	(53682),
	(53683),
	(53684),
	(53685),
	(53686),
	(53687),
	(53688),
	(53689),
	(53690),
	(53691),
	(53692),
	(53693),
	(53694),
	(53695),
	(53696),
	(53697),
	(53698),
	(53699),
	(53700),
	(53701),
	(53702),
	(53703),
	(53704),
	(53705),
	(53706),
	(53707),
	(53708),
	(53709),
	(53710),
	(53711),
	(53712),
	(53713),
	(53714),
	(53715),
	(53716),
	(53717),
	(53718),
	(53719),
	(53720),
	(53721),
	(53722),
	(53723),
	(53724),
	(53725),
	(53726),
	(53727),
	(53728),
	(53729),
	(53730),
	(53731),
	(53732),
	(53733),
	(53734),
	(53735),
	(53736),
	(53737),
	(53738),
	(53739),
	(53740),
	(53741),
	(53742),
	(53743),
	(53744),
	(53745),
	(53746),
	(53747),
	(53748),
	(53749),
	(53750),
	(53751),
	(53752),
	(53753),
	(53754),
	(53755),
	(53756),
	(53757),
	(53758),
	(53759),
	(53760),
	(53761),
	(53762),
	(53763),
	(53764),
	(53765),
	(53766),
	(53767),
	(53768),
	(53769),
	(53770),
	(53771),
	(53772),
	(53773),
	(53774),
	(53775),
	(53776),
	(53777),
	(53778),
	(53779),
	(53780),
	(53781),
	(53782),
	(53783),
	(53784),
	(53785),
	(53786),
	(53787),
	(53788),
	(53789),
	(53790),
	(53791),
	(53792),
	(53793),
	(53794),
	(53795),
	(53796),
	(53797),
	(53798),
	(53799),
	(53800),
	(53801),
	(53802),
	(53803),
	(53804),
	(53805),
	(53806),
	(53807),
	(53808),
	(53809),
	(53810),
	(53811),
	(53812),
	(53813),
	(53814),
	(53815),
	(53816),
	(53817),
	(53818),
	(53819),
	(53820),
	(53821),
	(53822),
	(53823),
	(53824),
	(53825),
	(53826),
	(53827),
	(53828),
	(53829),
	(53830),
	(53831),
	(53832),
	(53833),
	(53834),
	(53835),
	(53836),
	(53837),
	(53838),
	(53839),
	(53840),
	(53841),
	(53842),
	(53843),
	(53844),
	(53845),
	(53846),
	(53847),
	(53848),
	(53849),
	(53850),
	(53851),
	(53852),
	(53853),
	(53854),
	(53855),
	(53856),
	(53857),
	(53858),
	(53859),
	(53860),
	(53861),
	(53862),
	(53863),
	(53864),
	(53865),
	(53866),
	(53867),
	(53868),
	(53869),
	(53870),
	(53871),
	(53872),
	(53873),
	(53874),
	(53875),
	(53876),
	(53877),
	(53878),
	(53879),
	(53880),
	(53881),
	(53882),
	(53883),
	(53884),
	(53885),
	(53886),
	(53887),
	(53888),
	(53889),
	(53890),
	(53891),
	(53892),
	(53893),
	(53894),
	(53895),
	(53896),
	(53897),
	(53898),
	(53899),
	(53900),
	(53901),
	(53902),
	(53903),
	(53904),
	(53905),
	(53906),
	(53907),
	(53908),
	(53909),
	(53910),
	(53911),
	(53912),
	(53913),
	(53914),
	(53915),
	(53916),
	(53917),
	(53918),
	(53919),
	(53920),
	(53921),
	(53922),
	(53923),
	(53924),
	(53925),
	(53926),
	(53927),
	(53928),
	(53929),
	(53930),
	(53931),
	(53932),
	(53933),
	(53934),
	(53935),
	(53936),
	(53937),
	(53938),
	(53939),
	(53940),
	(53941),
	(53942),
	(53943),
	(53944),
	(53945),
	(53946),
	(53947),
	(53948),
	(53949),
	(53950),
	(53951),
	(53952),
	(53953),
	(53954),
	(53955),
	(53956),
	(53957),
	(53958),
	(53959),
	(53960),
	(53961),
	(53962),
	(53963),
	(53964),
	(53965),
	(53966),
	(53967),
	(53968),
	(53969),
	(53970),
	(53971),
	(53972),
	(53973),
	(53974),
	(53975),
	(53976),
	(53977),
	(53978),
	(53979),
	(53980),
	(53981),
	(53982),
	(53983),
	(53984),
	(53985),
	(53986),
	(53987),
	(53988),
	(53989),
	(53990),
	(53991),
	(53992),
	(53993),
	(53994),
	(53995),
	(53996),
	(53997),
	(53998),
	(53999),
	(54000),
	(54001),
	(54002),
	(54003),
	(54004),
	(54005),
	(54006),
	(54007),
	(54008),
	(54009),
	(54010),
	(54011),
	(54012),
	(54013),
	(54014),
	(54015),
	(54016),
	(54017),
	(54018),
	(54019),
	(54020),
	(54021),
	(54022),
	(54023),
	(54024),
	(54025),
	(54026),
	(54027),
	(54028),
	(54029),
	(54030),
	(54031),
	(54032),
	(54033),
	(54034),
	(54035),
	(54036),
	(54037),
	(54038),
	(54039),
	(54040),
	(54041),
	(54042),
	(54043),
	(54044),
	(54045),
	(54046),
	(54047),
	(54048),
	(54049),
	(54050),
	(54051),
	(54052),
	(54053),
	(54054),
	(54055),
	(54056),
	(54057),
	(54058),
	(54059),
	(54060),
	(54061),
	(54062),
	(54063),
	(54064),
	(54065),
	(54066),
	(54067),
	(54068),
	(54069),
	(54070),
	(54071),
	(54072),
	(54073),
	(54074),
	(54075),
	(54076),
	(54077),
	(54078),
	(54079),
	(54080),
	(54081),
	(54082),
	(54083),
	(54084),
	(54085),
	(54086),
	(54087),
	(54088),
	(54089),
	(54090),
	(54091),
	(54092),
	(54093),
	(54094),
	(54095),
	(54096),
	(54097),
	(54098),
	(54099),
	(54100),
	(54101),
	(54102),
	(54103),
	(54104),
	(54105),
	(54106),
	(54107),
	(54108),
	(54109),
	(54110),
	(54111),
	(54112),
	(54113),
	(54114),
	(54115),
	(54116),
	(54117),
	(54118),
	(54119),
	(54120),
	(54121),
	(54122),
	(54123),
	(54124),
	(54125),
	(54126),
	(54127),
	(54128),
	(54129),
	(54130),
	(54131),
	(54132),
	(54133),
	(54134),
	(54135),
	(54136),
	(54137),
	(54138),
	(54139),
	(54140),
	(54141),
	(54142),
	(54143),
	(54144),
	(54145),
	(54146),
	(54147),
	(54148),
	(54149),
	(54150),
	(54151),
	(54152),
	(54153),
	(54154),
	(54155),
	(54156),
	(54157),
	(54158),
	(54159),
	(54160),
	(54161),
	(54162),
	(54163),
	(54164),
	(54165),
	(54166),
	(54167),
	(54168),
	(54169),
	(54170),
	(54171),
	(54172),
	(54173),
	(54174),
	(54175),
	(54176),
	(54177),
	(54178),
	(54179),
	(54180),
	(54181),
	(54182),
	(54183),
	(54184),
	(54185),
	(54186),
	(54187),
	(54188),
	(54189),
	(54190),
	(54191),
	(54192),
	(54193),
	(54194),
	(54195),
	(54196),
	(54197),
	(54198),
	(54199),
	(54200),
	(54201),
	(54202),
	(54203),
	(54204),
	(54205),
	(54206),
	(54207),
	(54208),
	(54209),
	(54210),
	(54211),
	(54212),
	(54213),
	(54214),
	(54215),
	(54216),
	(54217),
	(54218),
	(54219),
	(54220),
	(54221),
	(54222),
	(54223),
	(54224),
	(54225),
	(54226),
	(54227),
	(54228),
	(54229),
	(54230),
	(54231),
	(54232),
	(54233),
	(54234),
	(54235),
	(54236),
	(54237),
	(54238),
	(54239),
	(54240),
	(54241),
	(54242),
	(54243),
	(54244),
	(54245),
	(54246),
	(54247),
	(54248),
	(54249),
	(54250),
	(54251),
	(54252),
	(54253),
	(54254),
	(54255),
	(54256),
	(54257),
	(54258),
	(54259),
	(54260),
	(54261),
	(54262),
	(54263),
	(54264),
	(54265),
	(54266),
	(54267),
	(54268),
	(54269),
	(54270),
	(54271),
	(54272),
	(54273),
	(54274),
	(54275),
	(54276),
	(54277),
	(54278),
	(54279),
	(54280),
	(54281),
	(54282),
	(54283),
	(54284),
	(54285),
	(54286),
	(54287),
	(54288),
	(54289),
	(54290),
	(54291),
	(54292),
	(54293),
	(54294),
	(54295),
	(54296),
	(54297),
	(54298),
	(54299),
	(54300),
	(54301),
	(54302),
	(54303),
	(54304),
	(54305),
	(54306),
	(54307),
	(54308),
	(54309),
	(54310),
	(54311),
	(54312),
	(54313),
	(54314),
	(54315),
	(54316),
	(54317),
	(54318),
	(54319),
	(54320),
	(54321),
	(54322),
	(54323),
	(54324),
	(54325),
	(54326),
	(54327),
	(54328),
	(54329),
	(54330),
	(54331),
	(54332),
	(54333),
	(54334),
	(54335),
	(54336),
	(54337),
	(54338),
	(54339),
	(54340),
	(54341),
	(54342),
	(54343),
	(54344),
	(54345),
	(54346),
	(54347),
	(54348),
	(54349),
	(54350),
	(54351),
	(54352),
	(54353),
	(54354),
	(54355),
	(54356),
	(54357),
	(54358),
	(54359),
	(54360),
	(54361),
	(54362),
	(54363),
	(54364),
	(54365),
	(54366),
	(54367),
	(54368),
	(54369),
	(54370),
	(54371),
	(54372),
	(54373),
	(54374),
	(54375),
	(54376),
	(54377),
	(54378),
	(54379),
	(54380),
	(54381),
	(54382),
	(54383),
	(54384),
	(54385),
	(54386),
	(54387),
	(54388),
	(54389),
	(54390),
	(54391),
	(54392),
	(54393),
	(54394),
	(54395),
	(54396),
	(54397),
	(54398),
	(54399),
	(54400),
	(54401),
	(54402),
	(54403),
	(54404),
	(54405),
	(54406),
	(54407),
	(54408),
	(54409),
	(54410),
	(54411),
	(54412),
	(54413),
	(54414),
	(54415),
	(54416),
	(54417),
	(54418),
	(54419),
	(54420),
	(54421),
	(54422),
	(54423),
	(54424),
	(54425),
	(54426),
	(54427),
	(54428),
	(54429),
	(54430),
	(54431),
	(54432),
	(54433),
	(54434),
	(54435),
	(54436),
	(54437),
	(54438),
	(54439),
	(54440),
	(54441),
	(54442),
	(54443),
	(54444),
	(54445),
	(54446),
	(54447),
	(54448),
	(54449),
	(54450),
	(54451),
	(54452),
	(54453),
	(54454),
	(54455),
	(54456),
	(54457),
	(54458),
	(54459),
	(54460),
	(54461),
	(54462),
	(54463),
	(54464),
	(54465),
	(54466),
	(54467),
	(54468),
	(54469),
	(54470),
	(54471),
	(54472),
	(54473),
	(54474),
	(54475),
	(54476),
	(54477),
	(54478),
	(54479),
	(54480),
	(54481),
	(54482),
	(54483),
	(54484),
	(54485),
	(54486),
	(54487),
	(54488),
	(54489),
	(54490),
	(54491),
	(54492),
	(54493),
	(54494),
	(54495),
	(54496),
	(54497),
	(54498),
	(54499),
	(54500),
	(54501),
	(54502),
	(54503),
	(54504),
	(54505),
	(54506),
	(54507),
	(54508),
	(54509),
	(54510),
	(54511),
	(54512),
	(54513),
	(54514),
	(54515),
	(54516),
	(54517),
	(54518),
	(54519),
	(54520),
	(54521),
	(54522),
	(54523),
	(54524),
	(54525),
	(54526),
	(54527),
	(54528),
	(54529),
	(54530),
	(54531),
	(54532),
	(54533),
	(54534),
	(54535),
	(54536),
	(54537),
	(54538),
	(54539),
	(54540),
	(54541),
	(54542),
	(54543),
	(54544),
	(54545),
	(54546),
	(54547),
	(54548),
	(54549),
	(54550),
	(54551),
	(54552),
	(54553),
	(54554),
	(54555),
	(54556),
	(54557),
	(54558),
	(54559),
	(54560),
	(54561),
	(54562),
	(54563),
	(54564),
	(54565),
	(54566),
	(54567),
	(54568),
	(54569),
	(54570),
	(54571),
	(54572),
	(54573),
	(54574),
	(54575),
	(54576),
	(54577),
	(54578),
	(54579),
	(54580),
	(54581),
	(54582),
	(54583),
	(54584),
	(54585),
	(54586),
	(54587),
	(54588),
	(54589),
	(54590),
	(54591),
	(54592),
	(54593),
	(54594),
	(54595),
	(54596),
	(54597),
	(54598),
	(54599),
	(54600),
	(54601),
	(54602),
	(54603),
	(54604),
	(54605),
	(54606),
	(54607),
	(54608),
	(54609),
	(54610),
	(54611),
	(54612),
	(54613),
	(54614),
	(54615),
	(54616),
	(54617),
	(54618),
	(54619),
	(54620),
	(54621),
	(54622),
	(54623),
	(54624),
	(54625),
	(54626),
	(54627),
	(54628),
	(54629),
	(54630),
	(54631),
	(54632),
	(54633),
	(54634),
	(54635),
	(54636),
	(54637),
	(54638),
	(54639),
	(54640),
	(54641),
	(54642),
	(54643),
	(54644),
	(54645),
	(54646),
	(54647),
	(54648),
	(54649),
	(54650),
	(54651),
	(54652),
	(54653),
	(54654),
	(54655),
	(54656),
	(54657),
	(54658),
	(54659),
	(54660),
	(54661),
	(54662),
	(54663),
	(54664),
	(54665),
	(54666),
	(54667),
	(54668),
	(54669),
	(54670),
	(54671),
	(54672),
	(54673),
	(54674),
	(54675),
	(54676),
	(54677),
	(54678),
	(54679),
	(54680),
	(54681),
	(54682),
	(54683),
	(54684),
	(54685),
	(54686),
	(54687),
	(54688),
	(54689),
	(54690),
	(54691),
	(54692),
	(54693),
	(54694),
	(54695),
	(54696),
	(54697),
	(54698),
	(54699),
	(54700),
	(54701),
	(54702),
	(54703),
	(54704),
	(54705),
	(54706),
	(54707),
	(54708),
	(54709),
	(54710),
	(54711),
	(54712),
	(54713),
	(54714),
	(54715),
	(54716),
	(54717),
	(54718),
	(54719),
	(54720),
	(54721),
	(54722),
	(54723),
	(54724),
	(54725),
	(54726),
	(54727),
	(54728),
	(54729),
	(54730),
	(54731),
	(54732),
	(54733),
	(54734),
	(54735),
	(54736),
	(54737),
	(54738),
	(54739),
	(54740),
	(54741),
	(54742),
	(54743),
	(54744),
	(54745),
	(54746),
	(54747),
	(54748),
	(54749),
	(54750),
	(54751),
	(54752),
	(54753),
	(54754),
	(54755),
	(54756),
	(54757),
	(54758),
	(54759),
	(54760),
	(54761),
	(54762),
	(54763),
	(54764),
	(54765),
	(54766),
	(54767),
	(54768),
	(54769),
	(54770),
	(54771),
	(54772),
	(54773),
	(54774),
	(54775),
	(54776),
	(54777),
	(54778),
	(54779),
	(54780),
	(54781),
	(54782),
	(54783),
	(54784),
	(54785),
	(54786),
	(54787),
	(54788),
	(54789),
	(54790),
	(54791),
	(54792),
	(54793),
	(54794),
	(54795),
	(54796),
	(54797),
	(54798),
	(54799),
	(54800),
	(54801),
	(54802),
	(54803),
	(54804),
	(54805),
	(54806),
	(54807),
	(54808),
	(54809),
	(54810),
	(54811),
	(54812),
	(54813),
	(54814),
	(54815),
	(54816),
	(54817),
	(54818),
	(54819),
	(54820),
	(54821),
	(54822),
	(54823),
	(54824),
	(54825),
	(54826),
	(54827),
	(54828),
	(54829),
	(54830),
	(54831),
	(54832),
	(54833),
	(54834),
	(54835),
	(54836),
	(54837),
	(54838),
	(54839),
	(54840),
	(54841),
	(54842),
	(54843),
	(54844),
	(54845),
	(54846),
	(54847),
	(54848),
	(54849),
	(54850),
	(54851),
	(54852),
	(54853),
	(54854),
	(54855),
	(54856),
	(54857),
	(54858),
	(54859),
	(54860),
	(54861),
	(54862),
	(54863),
	(54864),
	(54865),
	(54866),
	(54867),
	(54868),
	(54869),
	(54870),
	(54871),
	(54872),
	(54873),
	(54874),
	(54875),
	(54876),
	(54877),
	(54878),
	(54879),
	(54880),
	(54881),
	(54882),
	(54883),
	(54884),
	(54885),
	(54886),
	(54887),
	(54888),
	(54889),
	(54890),
	(54891),
	(54892),
	(54893),
	(54894),
	(54895),
	(54896),
	(54897),
	(54898),
	(54899),
	(54900),
	(54901),
	(54902),
	(54903),
	(54904),
	(54905),
	(54906),
	(54907),
	(54908),
	(54909),
	(54910),
	(54911),
	(54912),
	(54913),
	(54914),
	(54915),
	(54916),
	(54917),
	(54918),
	(54919),
	(54920),
	(54921),
	(54922),
	(54923),
	(54924),
	(54925),
	(54926),
	(54927),
	(54928),
	(54929),
	(54930),
	(54931),
	(54932),
	(54933),
	(54934),
	(54935),
	(54936),
	(54937),
	(54938),
	(54939),
	(54940),
	(54941),
	(54942),
	(54943),
	(54944),
	(54945),
	(54946),
	(54947),
	(54948),
	(54949),
	(54950),
	(54951),
	(54952),
	(54953),
	(54954),
	(54955),
	(54956),
	(54957),
	(54958),
	(54959),
	(54960),
	(54961),
	(54962),
	(54963),
	(54964),
	(54965),
	(54966),
	(54967),
	(54968),
	(54969),
	(54970),
	(54971),
	(54972),
	(54973),
	(54974),
	(54975),
	(54976),
	(54977),
	(54978),
	(54979),
	(54980),
	(54981),
	(54982),
	(54983),
	(54984),
	(54985),
	(54986),
	(54987),
	(54988),
	(54989),
	(54990),
	(54991),
	(54992),
	(54993),
	(54994),
	(54995),
	(54996),
	(54997),
	(54998),
	(54999),
	(55000),
	(55001),
	(55002),
	(55003),
	(55004),
	(55005),
	(55006),
	(55007),
	(55008),
	(55009),
	(55010),
	(55011),
	(55012),
	(55013),
	(55014),
	(55015),
	(55016),
	(55017),
	(55018),
	(55019),
	(55020),
	(55021),
	(55022),
	(55023),
	(55024),
	(55025),
	(55026),
	(55027),
	(55028),
	(55029),
	(55030),
	(55031),
	(55032),
	(55033),
	(55034),
	(55035),
	(55036),
	(55037),
	(55038),
	(55039),
	(55040),
	(55041),
	(55042),
	(55043),
	(55044),
	(55045),
	(55046),
	(55047),
	(55048),
	(55049),
	(55050),
	(55051),
	(55052),
	(55053),
	(55054),
	(55055),
	(55056),
	(55057),
	(55058),
	(55059),
	(55060),
	(55061),
	(55062),
	(55063),
	(55064),
	(55065),
	(55066),
	(55067),
	(55068),
	(55069),
	(55070),
	(55071),
	(55072),
	(55073),
	(55074),
	(55075),
	(55076),
	(55077),
	(55078),
	(55079),
	(55080),
	(55081),
	(55082),
	(55083),
	(55084),
	(55085),
	(55086),
	(55087),
	(55088),
	(55089),
	(55090),
	(55091),
	(55092),
	(55093),
	(55094),
	(55095),
	(55096),
	(55097),
	(55098),
	(55099),
	(55100),
	(55101),
	(55102),
	(55103),
	(55104),
	(55105),
	(55106),
	(55107),
	(55108),
	(55109),
	(55110),
	(55111),
	(55112),
	(55113),
	(55114),
	(55115),
	(55116),
	(55117),
	(55118),
	(55119),
	(55120),
	(55121),
	(55122),
	(55123),
	(55124),
	(55125),
	(55126),
	(55127),
	(55128),
	(55129),
	(55130),
	(55131),
	(55132),
	(55133),
	(55134),
	(55135),
	(55136),
	(55137),
	(55138),
	(55139),
	(55140),
	(55141),
	(55142),
	(55143),
	(55144),
	(55145),
	(55146),
	(55147),
	(55148),
	(55149),
	(55150),
	(55151),
	(55152),
	(55153),
	(55154),
	(55155),
	(55156),
	(55157),
	(55158),
	(55159),
	(55160),
	(55161),
	(55162),
	(55163),
	(55164),
	(55165),
	(55166),
	(55167),
	(55168),
	(55169),
	(55170),
	(55171),
	(55172),
	(55173),
	(55174),
	(55175),
	(55176),
	(55177),
	(55178),
	(55179),
	(55180),
	(55181),
	(55182),
	(55183),
	(55184),
	(55185),
	(55186),
	(55187),
	(55188),
	(55189),
	(55190),
	(55191),
	(55192),
	(55193),
	(55194),
	(55195),
	(55196),
	(55197),
	(55198),
	(55199),
	(55200),
	(55201),
	(55202),
	(55203),
	(55204),
	(55205),
	(55206),
	(55207),
	(55208),
	(55209),
	(55210),
	(55211),
	(55212),
	(55213),
	(55214),
	(55215),
	(55216),
	(55217),
	(55218),
	(55219),
	(55220),
	(55221),
	(55222),
	(55223),
	(55224),
	(55225),
	(55226),
	(55227),
	(55228),
	(55229),
	(55230),
	(55231),
	(55232),
	(55233),
	(55234),
	(55235),
	(55236),
	(55237),
	(55238),
	(55239),
	(55240),
	(55241),
	(55242),
	(55243),
	(55244),
	(55245),
	(55246),
	(55247),
	(55248),
	(55249),
	(55250),
	(55251),
	(55252),
	(55253),
	(55254),
	(55255),
	(55256),
	(55257),
	(55258),
	(55259),
	(55260),
	(55261),
	(55262),
	(55263),
	(55264),
	(55265),
	(55266),
	(55267),
	(55268),
	(55269),
	(55270),
	(55271),
	(55272),
	(55273),
	(55274),
	(55275),
	(55276),
	(55277),
	(55278),
	(55279),
	(55280),
	(55281),
	(55282),
	(55283),
	(55284),
	(55285),
	(55286),
	(55287),
	(55288),
	(55289),
	(55290),
	(55291),
	(55292),
	(55293),
	(55294),
	(55295),
	(55296),
	(55297),
	(55298),
	(55299),
	(55300),
	(55301),
	(55302),
	(55303),
	(55304),
	(55305),
	(55306),
	(55307),
	(55308),
	(55309),
	(55310),
	(55311),
	(55312),
	(55313),
	(55314),
	(55315),
	(55316),
	(55317),
	(55318),
	(55319),
	(55320),
	(55321),
	(55322),
	(55323),
	(55324),
	(55325),
	(55326),
	(55327),
	(55328),
	(55329),
	(55330),
	(55331),
	(55332),
	(55333),
	(55334),
	(55335),
	(55336),
	(55337),
	(55338),
	(55339),
	(55340),
	(55341),
	(55342),
	(55343),
	(55344),
	(55345),
	(55346),
	(55347),
	(55348),
	(55349),
	(55350),
	(55351),
	(55352),
	(55353),
	(55354),
	(55355),
	(55356),
	(55357),
	(55358),
	(55359),
	(55360),
	(55361),
	(55362),
	(55363),
	(55364),
	(55365),
	(55366),
	(55367),
	(55368),
	(55369),
	(55370),
	(55371),
	(55372),
	(55373),
	(55374),
	(55375),
	(55376),
	(55377),
	(55378),
	(55379),
	(55380),
	(55381),
	(55382),
	(55383),
	(55384),
	(55385),
	(55386),
	(55387),
	(55388),
	(55389),
	(55390),
	(55391),
	(55392),
	(55393),
	(55394),
	(55395),
	(55396),
	(55397),
	(55398),
	(55399),
	(55400),
	(55401),
	(55402),
	(55403),
	(55404),
	(55405),
	(55406),
	(55407),
	(55408),
	(55409),
	(55410),
	(55411),
	(55412),
	(55413),
	(55414),
	(55415),
	(55416),
	(55417),
	(55418),
	(55419),
	(55420),
	(55421),
	(55422),
	(55423),
	(55424),
	(55425),
	(55426),
	(55427),
	(55428),
	(55429),
	(55430),
	(55431),
	(55432),
	(55433),
	(55434),
	(55435),
	(55436),
	(55437),
	(55438),
	(55439),
	(55440),
	(55441),
	(55442),
	(55443),
	(55444),
	(55445),
	(55446),
	(55447),
	(55448),
	(55449),
	(55450),
	(55451),
	(55452),
	(55453),
	(55454),
	(55455),
	(55456),
	(55457),
	(55458),
	(55459),
	(55460),
	(55461),
	(55462),
	(55463),
	(55464),
	(55465),
	(55466),
	(55467),
	(55468),
	(55469),
	(55470),
	(55471),
	(55472),
	(55473),
	(55474),
	(55475),
	(55476),
	(55477),
	(55478),
	(55479),
	(55480),
	(55481),
	(55482),
	(55483),
	(55484),
	(55485),
	(55486),
	(55487),
	(55488),
	(55489),
	(55490),
	(55491),
	(55492),
	(55493),
	(55494),
	(55495),
	(55496),
	(55497),
	(55498),
	(55499),
	(55500),
	(55501),
	(55502),
	(55503),
	(55504),
	(55505),
	(55506),
	(55507),
	(55508),
	(55509),
	(55510),
	(55511),
	(55512),
	(55513),
	(55514),
	(55515),
	(55516),
	(55517),
	(55518),
	(55519),
	(55520),
	(55521),
	(55522),
	(55523),
	(55524),
	(55525),
	(55526),
	(55527),
	(55528),
	(55529),
	(55530),
	(55531),
	(55532),
	(55533),
	(55534),
	(55535),
	(55536),
	(55537),
	(55538),
	(55539),
	(55540),
	(55541),
	(55542),
	(55543),
	(55544),
	(55545),
	(55546),
	(55547),
	(55548),
	(55549),
	(55550),
	(55551),
	(55552),
	(55553),
	(55554),
	(55555),
	(55556),
	(55557),
	(55558),
	(55559),
	(55560),
	(55561),
	(55562),
	(55563),
	(55564),
	(55565),
	(55566),
	(55567),
	(55568),
	(55569),
	(55570),
	(55571),
	(55572),
	(55573),
	(55574),
	(55575),
	(55576),
	(55577),
	(55578),
	(55579),
	(55580),
	(55581),
	(55582),
	(55583),
	(55584),
	(55585),
	(55586),
	(55587),
	(55588),
	(55589),
	(55590),
	(55591),
	(55592),
	(55593),
	(55594),
	(55595),
	(55596),
	(55597),
	(55598),
	(55599),
	(55600),
	(55601),
	(55602),
	(55603),
	(55604),
	(55605),
	(55606),
	(55607),
	(55608),
	(55609),
	(55610),
	(55611),
	(55612),
	(55613),
	(55614),
	(55615),
	(55616),
	(55617),
	(55618),
	(55619),
	(55620),
	(55621),
	(55622),
	(55623),
	(55624),
	(55625),
	(55626),
	(55627),
	(55628),
	(55629),
	(55630),
	(55631),
	(55632),
	(55633),
	(55634),
	(55635),
	(55636),
	(55637),
	(55638),
	(55639),
	(55640),
	(55641),
	(55642),
	(55643),
	(55644),
	(55645),
	(55646),
	(55647),
	(55648),
	(55649),
	(55650),
	(55651),
	(55652),
	(55653),
	(55654),
	(55655),
	(55656),
	(55657),
	(55658),
	(55659),
	(55660),
	(55661),
	(55662),
	(55663),
	(55664),
	(55665),
	(55666),
	(55667),
	(55668),
	(55669),
	(55670),
	(55671),
	(55672),
	(55673),
	(55674),
	(55675),
	(55676),
	(55677),
	(55678),
	(55679),
	(55680),
	(55681),
	(55682),
	(55683),
	(55684),
	(55685),
	(55686),
	(55687),
	(55688),
	(55689),
	(55690),
	(55691),
	(55692),
	(55693),
	(55694),
	(55695),
	(55696),
	(55697),
	(55698),
	(55699),
	(55700),
	(55701),
	(55702),
	(55703),
	(55704),
	(55705),
	(55706),
	(55707),
	(55708),
	(55709),
	(55710),
	(55711),
	(55712),
	(55713),
	(55714),
	(55715),
	(55716),
	(55717),
	(55718),
	(55719),
	(55720),
	(55721),
	(55722),
	(55723),
	(55724),
	(55725),
	(55726),
	(55727),
	(55728),
	(55729),
	(55730),
	(55731),
	(55732),
	(55733),
	(55734),
	(55735),
	(55736),
	(55737),
	(55738),
	(55739),
	(55740),
	(55741),
	(55742),
	(55743),
	(55744),
	(55745),
	(55746),
	(55747),
	(55748),
	(55749),
	(55750),
	(55751),
	(55752),
	(55753),
	(55754),
	(55755),
	(55756),
	(55757),
	(55758),
	(55759),
	(55760),
	(55761),
	(55762),
	(55763),
	(55764),
	(55765),
	(55766),
	(55767),
	(55768),
	(55769),
	(55770),
	(55771),
	(55772),
	(55773),
	(55774),
	(55775),
	(55776),
	(55777),
	(55778),
	(55779),
	(55780),
	(55781),
	(55782),
	(55783),
	(55784),
	(55785),
	(55786),
	(55787),
	(55788),
	(55789),
	(55790),
	(55791),
	(55792),
	(55793),
	(55794),
	(55795),
	(55796),
	(55797),
	(55798),
	(55799),
	(55800),
	(55801),
	(55802),
	(55803),
	(55804),
	(55805),
	(55806),
	(55807),
	(55808),
	(55809),
	(55810),
	(55811),
	(55812),
	(55813),
	(55814),
	(55815),
	(55816),
	(55817),
	(55818),
	(55819),
	(55820),
	(55821),
	(55822),
	(55823),
	(55824),
	(55825),
	(55826),
	(55827),
	(55828),
	(55829),
	(55830),
	(55831),
	(55832),
	(55833),
	(55834),
	(55835),
	(55836),
	(55837),
	(55838),
	(55839),
	(55840),
	(55841),
	(55842),
	(55843),
	(55844),
	(55845),
	(55846),
	(55847),
	(55848),
	(55849),
	(55850),
	(55851),
	(55852),
	(55853),
	(55854),
	(55855),
	(55856),
	(55857),
	(55858),
	(55859),
	(55860),
	(55861),
	(55862),
	(55863),
	(55864),
	(55865),
	(55866),
	(55867),
	(55868),
	(55869),
	(55870),
	(55871),
	(55872),
	(55873),
	(55874),
	(55875),
	(55876),
	(55877),
	(55878),
	(55879),
	(55880),
	(55881),
	(55882),
	(55883),
	(55884),
	(55885),
	(55886),
	(55887),
	(55888),
	(55889),
	(55890),
	(55891),
	(55892),
	(55893),
	(55894),
	(55895),
	(55896),
	(55897),
	(55898),
	(55899),
	(55900),
	(55901),
	(55902),
	(55903),
	(55904),
	(55905),
	(55906),
	(55907),
	(55908),
	(55909),
	(55910),
	(55911),
	(55912),
	(55913),
	(55914),
	(55915),
	(55916),
	(55917),
	(55918),
	(55919),
	(55920),
	(55921),
	(55922),
	(55923),
	(55924),
	(55925),
	(55926),
	(55927),
	(55928),
	(55929),
	(55930),
	(55931),
	(55932),
	(55933),
	(55934),
	(55935),
	(55936),
	(55937),
	(55938),
	(55939),
	(55940),
	(55941),
	(55942),
	(55943),
	(55944),
	(55945),
	(55946),
	(55947),
	(55948),
	(55949),
	(55950),
	(55951),
	(55952),
	(55953),
	(55954),
	(55955),
	(55956),
	(55957),
	(55958),
	(55959),
	(55960),
	(55961),
	(55962),
	(55963),
	(55964),
	(55965),
	(55966),
	(55967),
	(55968),
	(55969),
	(55970),
	(55971),
	(55972),
	(55973),
	(55974),
	(55975),
	(55976),
	(55977),
	(55978),
	(55979),
	(55980),
	(55981),
	(55982),
	(55983),
	(55984),
	(55985),
	(55986),
	(55987),
	(55988),
	(55989),
	(55990),
	(55991),
	(55992),
	(55993),
	(55994),
	(55995),
	(55996),
	(55997),
	(55998),
	(55999),
	(56000),
	(56001),
	(56002),
	(56003),
	(56004),
	(56005),
	(56006),
	(56007),
	(56008),
	(56009),
	(56010),
	(56011),
	(56012),
	(56013),
	(56014),
	(56015),
	(56016),
	(56017),
	(56018),
	(56019),
	(56020),
	(56021),
	(56022),
	(56023),
	(56024),
	(56025),
	(56026),
	(56027),
	(56028),
	(56029),
	(56030),
	(56031),
	(56032),
	(56033),
	(56034),
	(56035),
	(56036),
	(56037),
	(56038),
	(56039),
	(56040),
	(56041),
	(56042),
	(56043),
	(56044),
	(56045),
	(56046),
	(56047),
	(56048),
	(56049),
	(56050),
	(56051),
	(56052),
	(56053),
	(56054),
	(56055),
	(56056),
	(56057),
	(56058),
	(56059),
	(56060),
	(56061),
	(56062),
	(56063),
	(56064),
	(56065),
	(56066),
	(56067),
	(56068),
	(56069),
	(56070),
	(56071),
	(56072),
	(56073),
	(56074),
	(56075),
	(56076),
	(56077),
	(56078),
	(56079),
	(56080),
	(56081),
	(56082),
	(56083),
	(56084),
	(56085),
	(56086),
	(56087),
	(56088),
	(56089),
	(56090),
	(56091),
	(56092),
	(56093),
	(56094),
	(56095),
	(56096),
	(56097),
	(56098),
	(56099),
	(56100),
	(56101),
	(56102),
	(56103),
	(56104),
	(56105),
	(56106),
	(56107),
	(56108),
	(56109),
	(56110),
	(56111),
	(56112),
	(56113),
	(56114),
	(56115),
	(56116),
	(56117),
	(56118),
	(56119),
	(56120),
	(56121),
	(56122),
	(56123),
	(56124),
	(56125),
	(56126),
	(56127),
	(56128),
	(56129),
	(56130),
	(56131),
	(56132),
	(56133),
	(56134),
	(56135),
	(56136),
	(56137),
	(56138),
	(56139),
	(56140),
	(56141),
	(56142),
	(56143),
	(56144),
	(56145),
	(56146),
	(56147),
	(56148),
	(56149),
	(56150),
	(56151),
	(56152),
	(56153),
	(56154),
	(56155),
	(56156),
	(56157),
	(56158),
	(56159),
	(56160),
	(56161),
	(56162),
	(56163),
	(56164),
	(56165),
	(56166),
	(56167),
	(56168),
	(56169),
	(56170),
	(56171),
	(56172),
	(56173),
	(56174),
	(56175),
	(56176),
	(56177),
	(56178),
	(56179),
	(56180),
	(56181),
	(56182),
	(56183),
	(56184),
	(56185),
	(56186),
	(56187),
	(56188),
	(56189),
	(56190),
	(56191),
	(56192),
	(56193),
	(56194),
	(56195),
	(56196),
	(56197),
	(56198),
	(56199),
	(56200),
	(56201),
	(56202),
	(56203),
	(56204),
	(56205),
	(56206),
	(56207),
	(56208),
	(56209),
	(56210),
	(56211),
	(56212),
	(56213),
	(56214),
	(56215),
	(56216),
	(56217),
	(56218),
	(56219),
	(56220),
	(56221),
	(56222),
	(56223),
	(56224),
	(56225),
	(56226),
	(56227),
	(56228),
	(56229),
	(56230),
	(56231),
	(56232),
	(56233),
	(56234),
	(56235),
	(56236),
	(56237),
	(56238),
	(56239),
	(56240),
	(56241),
	(56242),
	(56243),
	(56244),
	(56245),
	(56246),
	(56247),
	(56248),
	(56249),
	(56250),
	(56251),
	(56252),
	(56253),
	(56254),
	(56255),
	(56256),
	(56257),
	(56258),
	(56259),
	(56260),
	(56261),
	(56262),
	(56263),
	(56264),
	(56265),
	(56266),
	(56267),
	(56268),
	(56269),
	(56270),
	(56271),
	(56272),
	(56273),
	(56274),
	(56275),
	(56276),
	(56277),
	(56278),
	(56279),
	(56280),
	(56281),
	(56282),
	(56283),
	(56284),
	(56285),
	(56286),
	(56287),
	(56288),
	(56289),
	(56290),
	(56291),
	(56292),
	(56293),
	(56294),
	(56295),
	(56296),
	(56297),
	(56298),
	(56299),
	(56300),
	(56301),
	(56302),
	(56303),
	(56304),
	(56305),
	(56306),
	(56307),
	(56308),
	(56309),
	(56310),
	(56311),
	(56312),
	(56313),
	(56314),
	(56315),
	(56316),
	(56317),
	(56318),
	(56319),
	(56320),
	(56321),
	(56322),
	(56323),
	(56324),
	(56325),
	(56326),
	(56327),
	(56328),
	(56329),
	(56330),
	(56331),
	(56332),
	(56333),
	(56334),
	(56335),
	(56336),
	(56337),
	(56338),
	(56339),
	(56340),
	(56341),
	(56342),
	(56343),
	(56344),
	(56345),
	(56346),
	(56347),
	(56348),
	(56349),
	(56350),
	(56351),
	(56352),
	(56353),
	(56354),
	(56355),
	(56356),
	(56357),
	(56358),
	(56359),
	(56360),
	(56361),
	(56362),
	(56363),
	(56364),
	(56365),
	(56366),
	(56367),
	(56368),
	(56369),
	(56370),
	(56371),
	(56372),
	(56373),
	(56374),
	(56375),
	(56376),
	(56377),
	(56378),
	(56379),
	(56380),
	(56381),
	(56382),
	(56383),
	(56384),
	(56385),
	(56386),
	(56387),
	(56388),
	(56389),
	(56390),
	(56391),
	(56392),
	(56393),
	(56394),
	(56395),
	(56396),
	(56397),
	(56398),
	(56399),
	(56400),
	(56401),
	(56402),
	(56403),
	(56404),
	(56405),
	(56406),
	(56407),
	(56408),
	(56409),
	(56410),
	(56411),
	(56412),
	(56413),
	(56414),
	(56415),
	(56416),
	(56417),
	(56418),
	(56419),
	(56420),
	(56421),
	(56422),
	(56423),
	(56424),
	(56425),
	(56426),
	(56427),
	(56428),
	(56429),
	(56430),
	(56431),
	(56432),
	(56433),
	(56434),
	(56435),
	(56436),
	(56437),
	(56438),
	(56439),
	(56440),
	(56441),
	(56442),
	(56443),
	(56444),
	(56445),
	(56446),
	(56447),
	(56448),
	(56449),
	(56450),
	(56451),
	(56452),
	(56453),
	(56454),
	(56455),
	(56456),
	(56457),
	(56458),
	(56459),
	(56460),
	(56461),
	(56462),
	(56463),
	(56464),
	(56465),
	(56466),
	(56467),
	(56468),
	(56469),
	(56470),
	(56471),
	(56472),
	(56473),
	(56474),
	(56475),
	(56476),
	(56477),
	(56478),
	(56479),
	(56480),
	(56481),
	(56482),
	(56483),
	(56484),
	(56485),
	(56486),
	(56487),
	(56488),
	(56489),
	(56490),
	(56491),
	(56492),
	(56493),
	(56494),
	(56495),
	(56496),
	(56497),
	(56498),
	(56499),
	(56500),
	(56501),
	(56502),
	(56503),
	(56504),
	(56505),
	(56506),
	(56507),
	(56508),
	(56509),
	(56510),
	(56511),
	(56512),
	(56513),
	(56514),
	(56515),
	(56516),
	(56517),
	(56518),
	(56519),
	(56520),
	(56521),
	(56522),
	(56523),
	(56524),
	(56525),
	(56526),
	(56527),
	(56528),
	(56529),
	(56530),
	(56531),
	(56532),
	(56533),
	(56534),
	(56535),
	(56536),
	(56537),
	(56538),
	(56539),
	(56540),
	(56541),
	(56542),
	(56543),
	(56544),
	(56545),
	(56546),
	(56547),
	(56548),
	(56549),
	(56550),
	(56551),
	(56552),
	(56553),
	(56554),
	(56555),
	(56556),
	(56557),
	(56558),
	(56559),
	(56560),
	(56561),
	(56562),
	(56563),
	(56564),
	(56565),
	(56566),
	(56567),
	(56568),
	(56569),
	(56570),
	(56571),
	(56572),
	(56573),
	(56574),
	(56575),
	(56576),
	(56577),
	(56578),
	(56579),
	(56580),
	(56581),
	(56582),
	(56583),
	(56584),
	(56585),
	(56586),
	(56587),
	(56588),
	(56589),
	(56590),
	(56591),
	(56592),
	(56593),
	(56594),
	(56595),
	(56596),
	(56597),
	(56598),
	(56599),
	(56600),
	(56601),
	(56602),
	(56603),
	(56604),
	(56605),
	(56606),
	(56607),
	(56608),
	(56609),
	(56610),
	(56611),
	(56612),
	(56613),
	(56614),
	(56615),
	(56616),
	(56617),
	(56618),
	(56619),
	(56620),
	(56621),
	(56622),
	(56623),
	(56624),
	(56625),
	(56626),
	(56627),
	(56628),
	(56629),
	(56630),
	(56631),
	(56632),
	(56633),
	(56634),
	(56635),
	(56636),
	(56637),
	(56638),
	(56639),
	(56640),
	(56641),
	(56642),
	(56643),
	(56644),
	(56645),
	(56646),
	(56647),
	(56648),
	(56649),
	(56650),
	(56651),
	(56652),
	(56653),
	(56654),
	(56655),
	(56656),
	(56657),
	(56658),
	(56659),
	(56660),
	(56661),
	(56662),
	(56663),
	(56664),
	(56665),
	(56666),
	(56667),
	(56668),
	(56669),
	(56670),
	(56671),
	(56672),
	(56673),
	(56674),
	(56675),
	(56676),
	(56677),
	(56678),
	(56679),
	(56680),
	(56681),
	(56682),
	(56683),
	(56684),
	(56685),
	(56686),
	(56687),
	(56688),
	(56689),
	(56690),
	(56691),
	(56692),
	(56693),
	(56694),
	(56695),
	(56696),
	(56697),
	(56698),
	(56699),
	(56700),
	(56701),
	(56702),
	(56703),
	(56704),
	(56705),
	(56706),
	(56707),
	(56708),
	(56709),
	(56710),
	(56711),
	(56712),
	(56713),
	(56714),
	(56715),
	(56716),
	(56717),
	(56718),
	(56719),
	(56720),
	(56721),
	(56722),
	(56723),
	(56724),
	(56725),
	(56726),
	(56727),
	(56728),
	(56729),
	(56730),
	(56731),
	(56732),
	(56733),
	(56734),
	(56735),
	(56736),
	(56737),
	(56738),
	(56739),
	(56740),
	(56741),
	(56742),
	(56743),
	(56744),
	(56745),
	(56746),
	(56747),
	(56748),
	(56749),
	(56750),
	(56751),
	(56752),
	(56753),
	(56754),
	(56755),
	(56756),
	(56757),
	(56758),
	(56759),
	(56760),
	(56761),
	(56762),
	(56763),
	(56764),
	(56765),
	(56766),
	(56767),
	(56768),
	(56769),
	(56770),
	(56771),
	(56772),
	(56773),
	(56774),
	(56775),
	(56776),
	(56777),
	(56778),
	(56779),
	(56780),
	(56781),
	(56782),
	(56783),
	(56784),
	(56785),
	(56786),
	(56787),
	(56788),
	(56789),
	(56790),
	(56791),
	(56792),
	(56793),
	(56794),
	(56795),
	(56796),
	(56797),
	(56798),
	(56799),
	(56800),
	(56801),
	(56802),
	(56803),
	(56804),
	(56805),
	(56806),
	(56807),
	(56808),
	(56809),
	(56810),
	(56811),
	(56812),
	(56813),
	(56814),
	(56815),
	(56816),
	(56817),
	(56818),
	(56819),
	(56820),
	(56821),
	(56822),
	(56823),
	(56824),
	(56825),
	(56826),
	(56827),
	(56828),
	(56829),
	(56830),
	(56831),
	(56832),
	(56833),
	(56834),
	(56835),
	(56836),
	(56837),
	(56838),
	(56839),
	(56840),
	(56841),
	(56842),
	(56843),
	(56844),
	(56845),
	(56846),
	(56847),
	(56848),
	(56849),
	(56850),
	(56851),
	(56852),
	(56853),
	(56854),
	(56855),
	(56856),
	(56857),
	(56858),
	(56859),
	(56860),
	(56861),
	(56862),
	(56863),
	(56864),
	(56865),
	(56866),
	(56867),
	(56868),
	(56869),
	(56870),
	(56871),
	(56872),
	(56873),
	(56874),
	(56875),
	(56876),
	(56877),
	(56878),
	(56879),
	(56880),
	(56881),
	(56882),
	(56883),
	(56884),
	(56885),
	(56886),
	(56887),
	(56888),
	(56889),
	(56890),
	(56891),
	(56892),
	(56893),
	(56894),
	(56895),
	(56896),
	(56897),
	(56898),
	(56899),
	(56900),
	(56901),
	(56902),
	(56903),
	(56904),
	(56905),
	(56906),
	(56907),
	(56908),
	(56909),
	(56910),
	(56911),
	(56912),
	(56913),
	(56914),
	(56915),
	(56916),
	(56917),
	(56918),
	(56919),
	(56920),
	(56921),
	(56922),
	(56923),
	(56924),
	(56925),
	(56926),
	(56927),
	(56928),
	(56929),
	(56930),
	(56931),
	(56932),
	(56933),
	(56934),
	(56935),
	(56936),
	(56937),
	(56938),
	(56939),
	(56940),
	(56941),
	(56942),
	(56943),
	(56944),
	(56945),
	(56946),
	(56947),
	(56948),
	(56949),
	(56950),
	(56951),
	(56952),
	(56953),
	(56954),
	(56955),
	(56956),
	(56957),
	(56958),
	(56959),
	(56960),
	(56961),
	(56962),
	(56963),
	(56964),
	(56965),
	(56966),
	(56967),
	(56968),
	(56969),
	(56970),
	(56971),
	(56972),
	(56973),
	(56974),
	(56975),
	(56976),
	(56977),
	(56978),
	(56979),
	(56980),
	(56981),
	(56982),
	(56983),
	(56984),
	(56985),
	(56986),
	(56987),
	(56988),
	(56989),
	(56990),
	(56991),
	(56992),
	(56993),
	(56994),
	(56995),
	(56996),
	(56997),
	(56998),
	(56999),
	(57000),
	(57001),
	(57002),
	(57003),
	(57004),
	(57005),
	(57006),
	(57007),
	(57008),
	(57009),
	(57010),
	(57011),
	(57012),
	(57013),
	(57014),
	(57015),
	(57016),
	(57017),
	(57018),
	(57019),
	(57020),
	(57021),
	(57022),
	(57023),
	(57024),
	(57025),
	(57026),
	(57027),
	(57028),
	(57029),
	(57030),
	(57031),
	(57032),
	(57033),
	(57034),
	(57035),
	(57036),
	(57037),
	(57038),
	(57039),
	(57040),
	(57041),
	(57042),
	(57043),
	(57044),
	(57045),
	(57046),
	(57047),
	(57048),
	(57049),
	(57050),
	(57051),
	(57052),
	(57053),
	(57054),
	(57055),
	(57056),
	(57057),
	(57058),
	(57059),
	(57060),
	(57061),
	(57062),
	(57063),
	(57064),
	(57065),
	(57066),
	(57067),
	(57068),
	(57069),
	(57070),
	(57071),
	(57072),
	(57073),
	(57074),
	(57075),
	(57076),
	(57077),
	(57078),
	(57079),
	(57080),
	(57081),
	(57082),
	(57083),
	(57084),
	(57085),
	(57086),
	(57087),
	(57088),
	(57089),
	(57090),
	(57091),
	(57092),
	(57093),
	(57094),
	(57095),
	(57096),
	(57097),
	(57098),
	(57099),
	(57100),
	(57101),
	(57102),
	(57103),
	(57104),
	(57105),
	(57106),
	(57107),
	(57108),
	(57109),
	(57110),
	(57111),
	(57112),
	(57113),
	(57114),
	(57115),
	(57116),
	(57117),
	(57118),
	(57119),
	(57120),
	(57121),
	(57122),
	(57123),
	(57124),
	(57125),
	(57126),
	(57127),
	(57128),
	(57129),
	(57130),
	(57131),
	(57132),
	(57133),
	(57134),
	(57135),
	(57136),
	(57137),
	(57138),
	(57139),
	(57140),
	(57141),
	(57142),
	(57143),
	(57144),
	(57145),
	(57146),
	(57147),
	(57148),
	(57149),
	(57150),
	(57151),
	(57152),
	(57153),
	(57154),
	(57155),
	(57156),
	(57157),
	(57158),
	(57159),
	(57160),
	(57161),
	(57162),
	(57163),
	(57164),
	(57165),
	(57166),
	(57167),
	(57168),
	(57169),
	(57170),
	(57171),
	(57172),
	(57173),
	(57174),
	(57175),
	(57176),
	(57177),
	(57178),
	(57179),
	(57180),
	(57181),
	(57182),
	(57183),
	(57184),
	(57185),
	(57186),
	(57187),
	(57188),
	(57189),
	(57190),
	(57191),
	(57192),
	(57193),
	(57194),
	(57195),
	(57196),
	(57197),
	(57198),
	(57199),
	(57200),
	(57201),
	(57202),
	(57203),
	(57204),
	(57205),
	(57206),
	(57207),
	(57208),
	(57209),
	(57210),
	(57211),
	(57212),
	(57213),
	(57214),
	(57215),
	(57216),
	(57217),
	(57218),
	(57219),
	(57220),
	(57221),
	(57222),
	(57223),
	(57224),
	(57225),
	(57226),
	(57227),
	(57228),
	(57229),
	(57230),
	(57231),
	(57232),
	(57233),
	(57234),
	(57235),
	(57236),
	(57237),
	(57238),
	(57239),
	(57240),
	(57241),
	(57242),
	(57243),
	(57244),
	(57245),
	(57246),
	(57247),
	(57248),
	(57249),
	(57250),
	(57251),
	(57252),
	(57253),
	(57254),
	(57255),
	(57256),
	(57257),
	(57258),
	(57259),
	(57260),
	(57261),
	(57262),
	(57263),
	(57264),
	(57265),
	(57266),
	(57267),
	(57268),
	(57269),
	(57270),
	(57271),
	(57272),
	(57273),
	(57274),
	(57275),
	(57276),
	(57277),
	(57278),
	(57279),
	(57280),
	(57281),
	(57282),
	(57283),
	(57284),
	(57285),
	(57286),
	(57287),
	(57288),
	(57289),
	(57290),
	(57291),
	(57292),
	(57293),
	(57294),
	(57295),
	(57296),
	(57297),
	(57298),
	(57299),
	(57300),
	(57301),
	(57302),
	(57303),
	(57304),
	(57305),
	(57306),
	(57307),
	(57308),
	(57309),
	(57310),
	(57311),
	(57312),
	(57313),
	(57314),
	(57315),
	(57316),
	(57317),
	(57318),
	(57319),
	(57320),
	(57321),
	(57322),
	(57323),
	(57324),
	(57325),
	(57326),
	(57327),
	(57328),
	(57329),
	(57330),
	(57331),
	(57332),
	(57333),
	(57334),
	(57335),
	(57336),
	(57337),
	(57338),
	(57339),
	(57340),
	(57341),
	(57342),
	(57343),
	(57344),
	(57345),
	(57346),
	(57347),
	(57348),
	(57349),
	(57350),
	(57351),
	(57352),
	(57353),
	(57354),
	(57355),
	(57356),
	(57357),
	(57358),
	(57359),
	(57360),
	(57361),
	(57362),
	(57363),
	(57364),
	(57365),
	(57366),
	(57367),
	(57368),
	(57369),
	(57370),
	(57371),
	(57372),
	(57373),
	(57374),
	(57375),
	(57376),
	(57377),
	(57378),
	(57379),
	(57380),
	(57381),
	(57382),
	(57383),
	(57384),
	(57385),
	(57386),
	(57387),
	(57388),
	(57389),
	(57390),
	(57391),
	(57392),
	(57393),
	(57394),
	(57395),
	(57396),
	(57397),
	(57398),
	(57399),
	(57400),
	(57401),
	(57402),
	(57403),
	(57404),
	(57405),
	(57406),
	(57407),
	(57408),
	(57409),
	(57410),
	(57411),
	(57412),
	(57413),
	(57414),
	(57415),
	(57416),
	(57417),
	(57418),
	(57419),
	(57420),
	(57421),
	(57422),
	(57423),
	(57424),
	(57425),
	(57426),
	(57427),
	(57428),
	(57429),
	(57430),
	(57431),
	(57432),
	(57433),
	(57434),
	(57435),
	(57436),
	(57437),
	(57438),
	(57439),
	(57440),
	(57441),
	(57442),
	(57443),
	(57444),
	(57445),
	(57446),
	(57447),
	(57448),
	(57449),
	(57450),
	(57451),
	(57452),
	(57453),
	(57454),
	(57455),
	(57456),
	(57457),
	(57458),
	(57459),
	(57460),
	(57461),
	(57462),
	(57463),
	(57464),
	(57465),
	(57466),
	(57467),
	(57468),
	(57469),
	(57470),
	(57471),
	(57472),
	(57473),
	(57474),
	(57475),
	(57476),
	(57477),
	(57478),
	(57479),
	(57480),
	(57481),
	(57482),
	(57483),
	(57484),
	(57485),
	(57486),
	(57487),
	(57488),
	(57489),
	(57490),
	(57491),
	(57492),
	(57493),
	(57494),
	(57495),
	(57496),
	(57497),
	(57498),
	(57499),
	(57500),
	(57501),
	(57502),
	(57503),
	(57504),
	(57505),
	(57506),
	(57507),
	(57508),
	(57509),
	(57510),
	(57511),
	(57512),
	(57513),
	(57514),
	(57515),
	(57516),
	(57517),
	(57518),
	(57519),
	(57520),
	(57521),
	(57522),
	(57523),
	(57524),
	(57525),
	(57526),
	(57527),
	(57528),
	(57529),
	(57530),
	(57531),
	(57532),
	(57533),
	(57534),
	(57535),
	(57536),
	(57537),
	(57538),
	(57539),
	(57540),
	(57541),
	(57542),
	(57543),
	(57544),
	(57545),
	(57546),
	(57547),
	(57548),
	(57549),
	(57550),
	(57551),
	(57552),
	(57553),
	(57554),
	(57555),
	(57556),
	(57557),
	(57558),
	(57559),
	(57560),
	(57561),
	(57562),
	(57563),
	(57564),
	(57565),
	(57566),
	(57567),
	(57568),
	(57569),
	(57570),
	(57571),
	(57572),
	(57573),
	(57574),
	(57575),
	(57576),
	(57577),
	(57578),
	(57579),
	(57580),
	(57581),
	(57582),
	(57583),
	(57584),
	(57585),
	(57586),
	(57587),
	(57588),
	(57589),
	(57590),
	(57591),
	(57592),
	(57593),
	(57594),
	(57595),
	(57596),
	(57597),
	(57598),
	(57599),
	(57600),
	(57601),
	(57602),
	(57603),
	(57604),
	(57605),
	(57606),
	(57607),
	(57608),
	(57609),
	(57610),
	(57611),
	(57612),
	(57613),
	(57614),
	(57615),
	(57616),
	(57617),
	(57618),
	(57619),
	(57620),
	(57621),
	(57622),
	(57623),
	(57624),
	(57625),
	(57626),
	(57627),
	(57628),
	(57629),
	(57630),
	(57631),
	(57632),
	(57633),
	(57634),
	(57635),
	(57636),
	(57637),
	(57638),
	(57639),
	(57640),
	(57641),
	(57642),
	(57643),
	(57644),
	(57645),
	(57646),
	(57647),
	(57648),
	(57649),
	(57650),
	(57651),
	(57652),
	(57653),
	(57654),
	(57655),
	(57656),
	(57657),
	(57658),
	(57659),
	(57660),
	(57661),
	(57662),
	(57663),
	(57664),
	(57665),
	(57666),
	(57667),
	(57668),
	(57669),
	(57670),
	(57671),
	(57672),
	(57673),
	(57674),
	(57675),
	(57676),
	(57677),
	(57678),
	(57679),
	(57680),
	(57681),
	(57682),
	(57683),
	(57684),
	(57685),
	(57686),
	(57687),
	(57688),
	(57689),
	(57690),
	(57691),
	(57692),
	(57693),
	(57694),
	(57695),
	(57696),
	(57697),
	(57698),
	(57699),
	(57700),
	(57701),
	(57702),
	(57703),
	(57704),
	(57705),
	(57706),
	(57707),
	(57708),
	(57709),
	(57710),
	(57711),
	(57712),
	(57713),
	(57714),
	(57715),
	(57716),
	(57717),
	(57718),
	(57719),
	(57720),
	(57721),
	(57722),
	(57723),
	(57724),
	(57725),
	(57726),
	(57727),
	(57728),
	(57729),
	(57730),
	(57731),
	(57732),
	(57733),
	(57734),
	(57735),
	(57736),
	(57737),
	(57738),
	(57739),
	(57740),
	(57741),
	(57742),
	(57743),
	(57744),
	(57745),
	(57746),
	(57747),
	(57748),
	(57749),
	(57750),
	(57751),
	(57752),
	(57753),
	(57754),
	(57755),
	(57756),
	(57757),
	(57758),
	(57759),
	(57760),
	(57761),
	(57762),
	(57763),
	(57764),
	(57765),
	(57766),
	(57767),
	(57768),
	(57769),
	(57770),
	(57771),
	(57772),
	(57773),
	(57774),
	(57775),
	(57776),
	(57777),
	(57778),
	(57779),
	(57780),
	(57781),
	(57782),
	(57783),
	(57784),
	(57785),
	(57786),
	(57787),
	(57788),
	(57789),
	(57790),
	(57791),
	(57792),
	(57793),
	(57794),
	(57795),
	(57796),
	(57797),
	(57798),
	(57799),
	(57800),
	(57801),
	(57802),
	(57803),
	(57804),
	(57805),
	(57806),
	(57807),
	(57808),
	(57809),
	(57810),
	(57811),
	(57812),
	(57813),
	(57814),
	(57815),
	(57816),
	(57817),
	(57818),
	(57819),
	(57820),
	(57821),
	(57822),
	(57823),
	(57824),
	(57825),
	(57826),
	(57827),
	(57828),
	(57829),
	(57830),
	(57831),
	(57832),
	(57833),
	(57834),
	(57835),
	(57836),
	(57837),
	(57838),
	(57839),
	(57840),
	(57841),
	(57842),
	(57843),
	(57844),
	(57845),
	(57846),
	(57847),
	(57848),
	(57849),
	(57850),
	(57851),
	(57852),
	(57853),
	(57854),
	(57855),
	(57856),
	(57857),
	(57858),
	(57859),
	(57860),
	(57861),
	(57862),
	(57863),
	(57864),
	(57865),
	(57866),
	(57867),
	(57868),
	(57869),
	(57870),
	(57871),
	(57872),
	(57873),
	(57874),
	(57875),
	(57876),
	(57877),
	(57878),
	(57879),
	(57880),
	(57881),
	(57882),
	(57883),
	(57884),
	(57885),
	(57886),
	(57887),
	(57888),
	(57889),
	(57890),
	(57891),
	(57892),
	(57893),
	(57894),
	(57895),
	(57896),
	(57897),
	(57898),
	(57899),
	(57900),
	(57901),
	(57902),
	(57903),
	(57904),
	(57905),
	(57906),
	(57907),
	(57908),
	(57909),
	(57910),
	(57911),
	(57912),
	(57913),
	(57914),
	(57915),
	(57916),
	(57917),
	(57918),
	(57919),
	(57920),
	(57921),
	(57922),
	(57923),
	(57924),
	(57925),
	(57926),
	(57927),
	(57928),
	(57929),
	(57930),
	(57931),
	(57932),
	(57933),
	(57934),
	(57935),
	(57936),
	(57937),
	(57938),
	(57939),
	(57940),
	(57941),
	(57942),
	(57943),
	(57944),
	(57945),
	(57946),
	(57947),
	(57948),
	(57949),
	(57950),
	(57951),
	(57952),
	(57953),
	(57954),
	(57955),
	(57956),
	(57957),
	(57958),
	(57959),
	(57960),
	(57961),
	(57962),
	(57963),
	(57964),
	(57965),
	(57966),
	(57967),
	(57968),
	(57969),
	(57970),
	(57971),
	(57972),
	(57973),
	(57974),
	(57975),
	(57976),
	(57977),
	(57978),
	(57979),
	(57980),
	(57981),
	(57982),
	(57983),
	(57984),
	(57985),
	(57986),
	(57987),
	(57988),
	(57989),
	(57990),
	(57991),
	(57992),
	(57993),
	(57994),
	(57995),
	(57996),
	(57997),
	(57998),
	(57999),
	(58000),
	(58001),
	(58002),
	(58003),
	(58004),
	(58005),
	(58006),
	(58007),
	(58008),
	(58009),
	(58010),
	(58011),
	(58012),
	(58013),
	(58014),
	(58015),
	(58016),
	(58017),
	(58018),
	(58019),
	(58020),
	(58021),
	(58022),
	(58023),
	(58024),
	(58025),
	(58026),
	(58027),
	(58028),
	(58029),
	(58030),
	(58031),
	(58032),
	(58033),
	(58034),
	(58035),
	(58036),
	(58037),
	(58038),
	(58039),
	(58040),
	(58041),
	(58042),
	(58043),
	(58044),
	(58045),
	(58046),
	(58047),
	(58048),
	(58049),
	(58050),
	(58051),
	(58052),
	(58053),
	(58054),
	(58055),
	(58056),
	(58057),
	(58058),
	(58059),
	(58060),
	(58061),
	(58062),
	(58063),
	(58064),
	(58065),
	(58066),
	(58067),
	(58068),
	(58069),
	(58070),
	(58071),
	(58072),
	(58073),
	(58074),
	(58075),
	(58076),
	(58077),
	(58078),
	(58079),
	(58080),
	(58081),
	(58082),
	(58083),
	(58084),
	(58085),
	(58086),
	(58087),
	(58088),
	(58089),
	(58090),
	(58091),
	(58092),
	(58093),
	(58094),
	(58095),
	(58096),
	(58097),
	(58098),
	(58099),
	(58100),
	(58101),
	(58102),
	(58103),
	(58104),
	(58105),
	(58106),
	(58107),
	(58108),
	(58109),
	(58110),
	(58111),
	(58112),
	(58113),
	(58114),
	(58115),
	(58116),
	(58117),
	(58118),
	(58119),
	(58120),
	(58121),
	(58122),
	(58123),
	(58124),
	(58125),
	(58126),
	(58127),
	(58128),
	(58129),
	(58130),
	(58131),
	(58132),
	(58133),
	(58134),
	(58135),
	(58136),
	(58137),
	(58138),
	(58139),
	(58140),
	(58141),
	(58142),
	(58143),
	(58144),
	(58145),
	(58146),
	(58147),
	(58148),
	(58149),
	(58150),
	(58151),
	(58152),
	(58153),
	(58154),
	(58155),
	(58156),
	(58157),
	(58158),
	(58159),
	(58160),
	(58161),
	(58162),
	(58163),
	(58164),
	(58165),
	(58166),
	(58167),
	(58168),
	(58169),
	(58170),
	(58171),
	(58172),
	(58173),
	(58174),
	(58175),
	(58176),
	(58177),
	(58178),
	(58179),
	(58180),
	(58181),
	(58182),
	(58183),
	(58184),
	(58185),
	(58186),
	(58187),
	(58188),
	(58189),
	(58190),
	(58191),
	(58192),
	(58193),
	(58194),
	(58195),
	(58196),
	(58197),
	(58198),
	(58199),
	(58200),
	(58201),
	(58202),
	(58203),
	(58204),
	(58205),
	(58206),
	(58207),
	(58208),
	(58209),
	(58210),
	(58211),
	(58212),
	(58213),
	(58214),
	(58215),
	(58216),
	(58217),
	(58218),
	(58219),
	(58220),
	(58221),
	(58222),
	(58223),
	(58224),
	(58225),
	(58226),
	(58227),
	(58228),
	(58229),
	(58230),
	(58231),
	(58232),
	(58233),
	(58234),
	(58235),
	(58236),
	(58237),
	(58238),
	(58239),
	(58240),
	(58241),
	(58242),
	(58243),
	(58244),
	(58245),
	(58246),
	(58247),
	(58248),
	(58249),
	(58250),
	(58251),
	(58252),
	(58253),
	(58254),
	(58255),
	(58256),
	(58257),
	(58258),
	(58259),
	(58260),
	(58261),
	(58262),
	(58263),
	(58264),
	(58265),
	(58266),
	(58267),
	(58268),
	(58269),
	(58270),
	(58271),
	(58272),
	(58273),
	(58274),
	(58275),
	(58276),
	(58277),
	(58278),
	(58279),
	(58280),
	(58281),
	(58282),
	(58283),
	(58284),
	(58285),
	(58286),
	(58287),
	(58288),
	(58289),
	(58290),
	(58291),
	(58292),
	(58293),
	(58294),
	(58295),
	(58296),
	(58297),
	(58298),
	(58299),
	(58300),
	(58301),
	(58302),
	(58303),
	(58304),
	(58305),
	(58306),
	(58307),
	(58308),
	(58309),
	(58310),
	(58311),
	(58312),
	(58313),
	(58314),
	(58315),
	(58316),
	(58317),
	(58318),
	(58319),
	(58320),
	(58321),
	(58322),
	(58323),
	(58324),
	(58325),
	(58326),
	(58327),
	(58328),
	(58329),
	(58330),
	(58331),
	(58332),
	(58333),
	(58334),
	(58335),
	(58336),
	(58337),
	(58338),
	(58339),
	(58340),
	(58341),
	(58342),
	(58343),
	(58344),
	(58345),
	(58346),
	(58347),
	(58348),
	(58349),
	(58350),
	(58351),
	(58352),
	(58353),
	(58354),
	(58355),
	(58356),
	(58357),
	(58358),
	(58359),
	(58360),
	(58361),
	(58362),
	(58363),
	(58364),
	(58365),
	(58366),
	(58367),
	(58368),
	(58369),
	(58370),
	(58371),
	(58372),
	(58373),
	(58374),
	(58375),
	(58376),
	(58377),
	(58378),
	(58379),
	(58380),
	(58381),
	(58382),
	(58383),
	(58384),
	(58385),
	(58386),
	(58387),
	(58388),
	(58389),
	(58390),
	(58391),
	(58392),
	(58393),
	(58394),
	(58395),
	(58396),
	(58397),
	(58398),
	(58399),
	(58400),
	(58401),
	(58402),
	(58403),
	(58404),
	(58405),
	(58406),
	(58407),
	(58408),
	(58409),
	(58410),
	(58411),
	(58412),
	(58413),
	(58414),
	(58415),
	(58416),
	(58417),
	(58418),
	(58419),
	(58420),
	(58421),
	(58422),
	(58423),
	(58424),
	(58425),
	(58426),
	(58427),
	(58428),
	(58429),
	(58430),
	(58431),
	(58432),
	(58433),
	(58434),
	(58435),
	(58436),
	(58437),
	(58438),
	(58439),
	(58440),
	(58441),
	(58442),
	(58443),
	(58444),
	(58445),
	(58446),
	(58447),
	(58448),
	(58449),
	(58450),
	(58451),
	(58452),
	(58453),
	(58454),
	(58455),
	(58456),
	(58457),
	(58458),
	(58459),
	(58460),
	(58461),
	(58462),
	(58463),
	(58464),
	(58465),
	(58466),
	(58467),
	(58468),
	(58469),
	(58470),
	(58471),
	(58472),
	(58473),
	(58474),
	(58475),
	(58476),
	(58477),
	(58478),
	(58479),
	(58480),
	(58481),
	(58482),
	(58483),
	(58484),
	(58485),
	(58486),
	(58487),
	(58488),
	(58489),
	(58490),
	(58491),
	(58492),
	(58493),
	(58494),
	(58495),
	(58496),
	(58497),
	(58498),
	(58499),
	(58500),
	(58501),
	(58502),
	(58503),
	(58504),
	(58505),
	(58506),
	(58507),
	(58508),
	(58509),
	(58510),
	(58511),
	(58512),
	(58513),
	(58514),
	(58515),
	(58516),
	(58517),
	(58518),
	(58519),
	(58520),
	(58521),
	(58522),
	(58523),
	(58524),
	(58525),
	(58526),
	(58527),
	(58528),
	(58529),
	(58530),
	(58531),
	(58532),
	(58533),
	(58534),
	(58535),
	(58536),
	(58537),
	(58538),
	(58539),
	(58540),
	(58541),
	(58542),
	(58543),
	(58544),
	(58545),
	(58546),
	(58547),
	(58548),
	(58549),
	(58550),
	(58551),
	(58552),
	(58553),
	(58554),
	(58555),
	(58556),
	(58557),
	(58558),
	(58559),
	(58560),
	(58561),
	(58562),
	(58563),
	(58564),
	(58565),
	(58566),
	(58567),
	(58568),
	(58569),
	(58570),
	(58571),
	(58572),
	(58573),
	(58574),
	(58575),
	(58576),
	(58577),
	(58578),
	(58579),
	(58580),
	(58581),
	(58582),
	(58583),
	(58584),
	(58585),
	(58586),
	(58587),
	(58588),
	(58589),
	(58590),
	(58591),
	(58592),
	(58593),
	(58594),
	(58595),
	(58596),
	(58597),
	(58598),
	(58599),
	(58600),
	(58601),
	(58602),
	(58603),
	(58604),
	(58605),
	(58606),
	(58607),
	(58608),
	(58609),
	(58610),
	(58611),
	(58612),
	(58613),
	(58614),
	(58615),
	(58616),
	(58617),
	(58618),
	(58619),
	(58620),
	(58621),
	(58622),
	(58623),
	(58624),
	(58625),
	(58626),
	(58627),
	(58628),
	(58629),
	(58630),
	(58631),
	(58632),
	(58633),
	(58634),
	(58635),
	(58636),
	(58637),
	(58638),
	(58639),
	(58640),
	(58641),
	(58642),
	(58643),
	(58644),
	(58645),
	(58646),
	(58647),
	(58648),
	(58649),
	(58650),
	(58651),
	(58652),
	(58653),
	(58654),
	(58655),
	(58656),
	(58657),
	(58658),
	(58659),
	(58660),
	(58661),
	(58662),
	(58663),
	(58664),
	(58665),
	(58666),
	(58667),
	(58668),
	(58669),
	(58670),
	(58671),
	(58672),
	(58673),
	(58674),
	(58675),
	(58676),
	(58677),
	(58678),
	(58679),
	(58680),
	(58681),
	(58682),
	(58683),
	(58684),
	(58685),
	(58686),
	(58687),
	(58688),
	(58689),
	(58690),
	(58691),
	(58692),
	(58693),
	(58694),
	(58695),
	(58696),
	(58697),
	(58698),
	(58699),
	(58700),
	(58701),
	(58702),
	(58703),
	(58704),
	(58705),
	(58706),
	(58707),
	(58708),
	(58709),
	(58710),
	(58711),
	(58712),
	(58713),
	(58714),
	(58715),
	(58716),
	(58717),
	(58718),
	(58719),
	(58720),
	(58721),
	(58722),
	(58723),
	(58724),
	(58725),
	(58726),
	(58727),
	(58728),
	(58729),
	(58730),
	(58731),
	(58732),
	(58733),
	(58734),
	(58735),
	(58736),
	(58737),
	(58738),
	(58739),
	(58740),
	(58741),
	(58742),
	(58743),
	(58744),
	(58745),
	(58746),
	(58747),
	(58748),
	(58749),
	(58750),
	(58751),
	(58752),
	(58753),
	(58754),
	(58755),
	(58756),
	(58757),
	(58758),
	(58759),
	(58760),
	(58761),
	(58762),
	(58763),
	(58764),
	(58765),
	(58766),
	(58767),
	(58768),
	(58769),
	(58770),
	(58771),
	(58772),
	(58773),
	(58774),
	(58775),
	(58776),
	(58777),
	(58778),
	(58779),
	(58780),
	(58781),
	(58782),
	(58783),
	(58784),
	(58785),
	(58786),
	(58787),
	(58788),
	(58789),
	(58790),
	(58791),
	(58792),
	(58793),
	(58794),
	(58795),
	(58796),
	(58797),
	(58798),
	(58799),
	(58800),
	(58801),
	(58802),
	(58803),
	(58804),
	(58805),
	(58806),
	(58807),
	(58808),
	(58809),
	(58810),
	(58811),
	(58812),
	(58813),
	(58814),
	(58815),
	(58816),
	(58817),
	(58818),
	(58819),
	(58820),
	(58821),
	(58822),
	(58823),
	(58824),
	(58825),
	(58826),
	(58827),
	(58828),
	(58829),
	(58830),
	(58831),
	(58832),
	(58833),
	(58834),
	(58835),
	(58836),
	(58837),
	(58838),
	(58839),
	(58840),
	(58841),
	(58842),
	(58843),
	(58844),
	(58845),
	(58846),
	(58847),
	(58848),
	(58849),
	(58850),
	(58851),
	(58852),
	(58853),
	(58854),
	(58855),
	(58856),
	(58857),
	(58858),
	(58859),
	(58860),
	(58861),
	(58862),
	(58863),
	(58864),
	(58865),
	(58866),
	(58867),
	(58868),
	(58869),
	(58870),
	(58871),
	(58872),
	(58873),
	(58874),
	(58875),
	(58876),
	(58877),
	(58878),
	(58879),
	(58880),
	(58881),
	(58882),
	(58883),
	(58884),
	(58885),
	(58886),
	(58887),
	(58888),
	(58889),
	(58890),
	(58891),
	(58892),
	(58893),
	(58894),
	(58895),
	(58896),
	(58897),
	(58898),
	(58899),
	(58900),
	(58901),
	(58902),
	(58903),
	(58904),
	(58905),
	(58906),
	(58907),
	(58908),
	(58909),
	(58910),
	(58911),
	(58912),
	(58913),
	(58914),
	(58915),
	(58916),
	(58917),
	(58918),
	(58919),
	(58920),
	(58921),
	(58922),
	(58923),
	(58924),
	(58925),
	(58926),
	(58927),
	(58928),
	(58929),
	(58930),
	(58931),
	(58932),
	(58933),
	(58934),
	(58935),
	(58936),
	(58937),
	(58938),
	(58939),
	(58940),
	(58941),
	(58942),
	(58943),
	(58944),
	(58945),
	(58946),
	(58947),
	(58948),
	(58949),
	(58950),
	(58951),
	(58952),
	(58953),
	(58954),
	(58955),
	(58956),
	(58957),
	(58958),
	(58959),
	(58960),
	(58961),
	(58962),
	(58963),
	(58964),
	(58965),
	(58966),
	(58967),
	(58968),
	(58969),
	(58970),
	(58971),
	(58972),
	(58973),
	(58974),
	(58975),
	(58976),
	(58977),
	(58978),
	(58979),
	(58980),
	(58981),
	(58982),
	(58983),
	(58984),
	(58985),
	(58986),
	(58987),
	(58988),
	(58989),
	(58990),
	(58991),
	(58992),
	(58993),
	(58994),
	(58995),
	(58996),
	(58997),
	(58998),
	(58999),
	(59000),
	(59001),
	(59002),
	(59003),
	(59004),
	(59005),
	(59006),
	(59007),
	(59008),
	(59009),
	(59010),
	(59011),
	(59012),
	(59013),
	(59014),
	(59015),
	(59016),
	(59017),
	(59018),
	(59019),
	(59020),
	(59021),
	(59022),
	(59023),
	(59024),
	(59025),
	(59026),
	(59027),
	(59028),
	(59029),
	(59030),
	(59031),
	(59032),
	(59033),
	(59034),
	(59035),
	(59036),
	(59037),
	(59038),
	(59039),
	(59040),
	(59041),
	(59042),
	(59043),
	(59044),
	(59045),
	(59046),
	(59047),
	(59048),
	(59049),
	(59050),
	(59051),
	(59052),
	(59053),
	(59054),
	(59055),
	(59056),
	(59057),
	(59058),
	(59059),
	(59060),
	(59061),
	(59062),
	(59063),
	(59064),
	(59065),
	(59066),
	(59067),
	(59068),
	(59069),
	(59070),
	(59071),
	(59072),
	(59073),
	(59074),
	(59075),
	(59076),
	(59077),
	(59078),
	(59079),
	(59080),
	(59081),
	(59082),
	(59083),
	(59084),
	(59085),
	(59086),
	(59087),
	(59088),
	(59089),
	(59090),
	(59091),
	(59092),
	(59093),
	(59094),
	(59095),
	(59096),
	(59097),
	(59098),
	(59099),
	(59100),
	(59101),
	(59102),
	(59103),
	(59104),
	(59105),
	(59106),
	(59107),
	(59108),
	(59109),
	(59110),
	(59111),
	(59112),
	(59113),
	(59114),
	(59115),
	(59116),
	(59117),
	(59118),
	(59119),
	(59120),
	(59121),
	(59122),
	(59123),
	(59124),
	(59125),
	(59126),
	(59127),
	(59128),
	(59129),
	(59130),
	(59131),
	(59132),
	(59133),
	(59134),
	(59135),
	(59136),
	(59137),
	(59138),
	(59139),
	(59140),
	(59141),
	(59142),
	(59143),
	(59144),
	(59145),
	(59146),
	(59147),
	(59148),
	(59149),
	(59150),
	(59151),
	(59152),
	(59153),
	(59154),
	(59155),
	(59156),
	(59157),
	(59158),
	(59159),
	(59160),
	(59161),
	(59162),
	(59163),
	(59164),
	(59165),
	(59166),
	(59167),
	(59168),
	(59169),
	(59170),
	(59171),
	(59172),
	(59173),
	(59174),
	(59175),
	(59176),
	(59177),
	(59178),
	(59179),
	(59180),
	(59181),
	(59182),
	(59183),
	(59184),
	(59185),
	(59186),
	(59187),
	(59188),
	(59189),
	(59190),
	(59191),
	(59192),
	(59193),
	(59194),
	(59195),
	(59196),
	(59197),
	(59198),
	(59199),
	(59200),
	(59201),
	(59202),
	(59203),
	(59204),
	(59205),
	(59206),
	(59207),
	(59208),
	(59209),
	(59210),
	(59211),
	(59212),
	(59213),
	(59214),
	(59215),
	(59216),
	(59217),
	(59218),
	(59219),
	(59220),
	(59221),
	(59222),
	(59223),
	(59224),
	(59225),
	(59226),
	(59227),
	(59228),
	(59229),
	(59230),
	(59231),
	(59232),
	(59233),
	(59234),
	(59235),
	(59236),
	(59237),
	(59238),
	(59239),
	(59240),
	(59241),
	(59242),
	(59243),
	(59244),
	(59245),
	(59246),
	(59247),
	(59248),
	(59249),
	(59250),
	(59251),
	(59252),
	(59253),
	(59254),
	(59255),
	(59256),
	(59257),
	(59258),
	(59259),
	(59260),
	(59261),
	(59262),
	(59263),
	(59264),
	(59265),
	(59266),
	(59267),
	(59268),
	(59269),
	(59270),
	(59271),
	(59272),
	(59273),
	(59274),
	(59275),
	(59276),
	(59277),
	(59278),
	(59279),
	(59280),
	(59281),
	(59282),
	(59283),
	(59284),
	(59285),
	(59286),
	(59287),
	(59288),
	(59289),
	(59290),
	(59291),
	(59292),
	(59293),
	(59294),
	(59295),
	(59296),
	(59297),
	(59298),
	(59299),
	(59300),
	(59301),
	(59302),
	(59303),
	(59304),
	(59305),
	(59306),
	(59307),
	(59308),
	(59309),
	(59310),
	(59311),
	(59312),
	(59313),
	(59314),
	(59315),
	(59316),
	(59317),
	(59318),
	(59319),
	(59320),
	(59321),
	(59322),
	(59323),
	(59324),
	(59325),
	(59326),
	(59327),
	(59328),
	(59329),
	(59330),
	(59331),
	(59332),
	(59333),
	(59334),
	(59335),
	(59336),
	(59337),
	(59338),
	(59339),
	(59340),
	(59341),
	(59342),
	(59343),
	(59344),
	(59345),
	(59346),
	(59347),
	(59348),
	(59349),
	(59350),
	(59351),
	(59352),
	(59353),
	(59354),
	(59355),
	(59356),
	(59357),
	(59358),
	(59359),
	(59360),
	(59361),
	(59362),
	(59363),
	(59364),
	(59365),
	(59366),
	(59367),
	(59368),
	(59369),
	(59370),
	(59371),
	(59372),
	(59373),
	(59374),
	(59375),
	(59376),
	(59377),
	(59378),
	(59379),
	(59380),
	(59381),
	(59382),
	(59383),
	(59384),
	(59385),
	(59386),
	(59387),
	(59388),
	(59389),
	(59390),
	(59391),
	(59392),
	(59393),
	(59394),
	(59395),
	(59396),
	(59397),
	(59398),
	(59399),
	(59400),
	(59401),
	(59402),
	(59403),
	(59404),
	(59405),
	(59406),
	(59407),
	(59408),
	(59409),
	(59410),
	(59411),
	(59412),
	(59413),
	(59414),
	(59415),
	(59416),
	(59417),
	(59418),
	(59419),
	(59420),
	(59421),
	(59422),
	(59423),
	(59424),
	(59425),
	(59426),
	(59427),
	(59428),
	(59429),
	(59430),
	(59431),
	(59432),
	(59433),
	(59434),
	(59435),
	(59436),
	(59437),
	(59438),
	(59439),
	(59440),
	(59441),
	(59442),
	(59443),
	(59444),
	(59445),
	(59446),
	(59447),
	(59448),
	(59449),
	(59450),
	(59451),
	(59452),
	(59453),
	(59454),
	(59455),
	(59456),
	(59457),
	(59458),
	(59459),
	(59460),
	(59461),
	(59462),
	(59463),
	(59464),
	(59465),
	(59466),
	(59467),
	(59468),
	(59469),
	(59470),
	(59471),
	(59472),
	(59473),
	(59474),
	(59475),
	(59476),
	(59477),
	(59478),
	(59479),
	(59480),
	(59481),
	(59482),
	(59483),
	(59484),
	(59485),
	(59486),
	(59487),
	(59488),
	(59489),
	(59490),
	(59491),
	(59492),
	(59493),
	(59494),
	(59495),
	(59496),
	(59497),
	(59498),
	(59499),
	(59500),
	(59501),
	(59502),
	(59503),
	(59504),
	(59505),
	(59506),
	(59507),
	(59508),
	(59509),
	(59510),
	(59511),
	(59512),
	(59513),
	(59514),
	(59515),
	(59516),
	(59517),
	(59518),
	(59519),
	(59520),
	(59521),
	(59522),
	(59523),
	(59524),
	(59525),
	(59526),
	(59527),
	(59528),
	(59529),
	(59530),
	(59531),
	(59532),
	(59533),
	(59534),
	(59535),
	(59536),
	(59537),
	(59538),
	(59539),
	(59540),
	(59541),
	(59542),
	(59543),
	(59544),
	(59545),
	(59546),
	(59547),
	(59548),
	(59549),
	(59550),
	(59551),
	(59552),
	(59553),
	(59554),
	(59555),
	(59556),
	(59557),
	(59558),
	(59559),
	(59560),
	(59561),
	(59562),
	(59563),
	(59564),
	(59565),
	(59566),
	(59567),
	(59568),
	(59569),
	(59570),
	(59571),
	(59572),
	(59573),
	(59574),
	(59575),
	(59576),
	(59577),
	(59578),
	(59579),
	(59580),
	(59581),
	(59582),
	(59583),
	(59584),
	(59585),
	(59586),
	(59587),
	(59588),
	(59589),
	(59590),
	(59591),
	(59592),
	(59593),
	(59594),
	(59595),
	(59596),
	(59597),
	(59598),
	(59599),
	(59600),
	(59601),
	(59602),
	(59603),
	(59604),
	(59605),
	(59606),
	(59607),
	(59608),
	(59609),
	(59610),
	(59611),
	(59612),
	(59613),
	(59614),
	(59615),
	(59616),
	(59617),
	(59618),
	(59619),
	(59620),
	(59621),
	(59622),
	(59623),
	(59624),
	(59625),
	(59626),
	(59627),
	(59628),
	(59629),
	(59630),
	(59631),
	(59632),
	(59633),
	(59634),
	(59635),
	(59636),
	(59637),
	(59638),
	(59639),
	(59640),
	(59641),
	(59642),
	(59643),
	(59644),
	(59645),
	(59646),
	(59647),
	(59648),
	(59649),
	(59650),
	(59651),
	(59652),
	(59653),
	(59654),
	(59655),
	(59656),
	(59657),
	(59658),
	(59659),
	(59660),
	(59661),
	(59662),
	(59663),
	(59664),
	(59665),
	(59666),
	(59667),
	(59668),
	(59669),
	(59670),
	(59671),
	(59672),
	(59673),
	(59674),
	(59675),
	(59676),
	(59677),
	(59678),
	(59679),
	(59680),
	(59681),
	(59682),
	(59683),
	(59684),
	(59685),
	(59686),
	(59687),
	(59688),
	(59689),
	(59690),
	(59691),
	(59692),
	(59693),
	(59694),
	(59695),
	(59696),
	(59697),
	(59698),
	(59699),
	(59700),
	(59701),
	(59702),
	(59703),
	(59704),
	(59705),
	(59706),
	(59707),
	(59708),
	(59709),
	(59710),
	(59711),
	(59712),
	(59713),
	(59714),
	(59715),
	(59716),
	(59717),
	(59718),
	(59719),
	(59720),
	(59721),
	(59722),
	(59723),
	(59724),
	(59725),
	(59726),
	(59727),
	(59728),
	(59729),
	(59730),
	(59731),
	(59732),
	(59733),
	(59734),
	(59735),
	(59736),
	(59737),
	(59738),
	(59739),
	(59740),
	(59741),
	(59742),
	(59743),
	(59744),
	(59745),
	(59746),
	(59747),
	(59748),
	(59749),
	(59750),
	(59751),
	(59752),
	(59753),
	(59754),
	(59755),
	(59756),
	(59757),
	(59758),
	(59759),
	(59760),
	(59761),
	(59762),
	(59763),
	(59764),
	(59765),
	(59766),
	(59767),
	(59768),
	(59769),
	(59770),
	(59771),
	(59772),
	(59773),
	(59774),
	(59775),
	(59776),
	(59777),
	(59778),
	(59779),
	(59780),
	(59781),
	(59782),
	(59783),
	(59784),
	(59785),
	(59786),
	(59787),
	(59788),
	(59789),
	(59790),
	(59791),
	(59792),
	(59793),
	(59794),
	(59795),
	(59796),
	(59797),
	(59798),
	(59799),
	(59800),
	(59801),
	(59802),
	(59803),
	(59804),
	(59805),
	(59806),
	(59807),
	(59808),
	(59809),
	(59810),
	(59811),
	(59812),
	(59813),
	(59814),
	(59815),
	(59816),
	(59817),
	(59818),
	(59819),
	(59820),
	(59821),
	(59822),
	(59823),
	(59824),
	(59825),
	(59826),
	(59827),
	(59828),
	(59829),
	(59830),
	(59831),
	(59832),
	(59833),
	(59834),
	(59835),
	(59836),
	(59837),
	(59838),
	(59839),
	(59840),
	(59841),
	(59842),
	(59843),
	(59844),
	(59845),
	(59846),
	(59847),
	(59848),
	(59849),
	(59850),
	(59851),
	(59852),
	(59853),
	(59854),
	(59855),
	(59856),
	(59857),
	(59858),
	(59859),
	(59860),
	(59861),
	(59862),
	(59863),
	(59864),
	(59865),
	(59866),
	(59867),
	(59868),
	(59869),
	(59870),
	(59871),
	(59872),
	(59873),
	(59874),
	(59875),
	(59876),
	(59877),
	(59878),
	(59879),
	(59880),
	(59881),
	(59882),
	(59883),
	(59884),
	(59885),
	(59886),
	(59887),
	(59888),
	(59889),
	(59890),
	(59891),
	(59892),
	(59893),
	(59894),
	(59895),
	(59896),
	(59897),
	(59898),
	(59899),
	(59900),
	(59901),
	(59902),
	(59903),
	(59904),
	(59905),
	(59906),
	(59907),
	(59908),
	(59909),
	(59910),
	(59911),
	(59912),
	(59913),
	(59914),
	(59915),
	(59916),
	(59917),
	(59918),
	(59919),
	(59920),
	(59921),
	(59922),
	(59923),
	(59924),
	(59925),
	(59926),
	(59927),
	(59928),
	(59929),
	(59930),
	(59931),
	(59932),
	(59933),
	(59934),
	(59935),
	(59936),
	(59937),
	(59938),
	(59939),
	(59940),
	(59941),
	(59942),
	(59943),
	(59944),
	(59945),
	(59946),
	(59947),
	(59948),
	(59949),
	(59950),
	(59951),
	(59952),
	(59953),
	(59954),
	(59955),
	(59956),
	(59957),
	(59958),
	(59959),
	(59960),
	(59961),
	(59962),
	(59963),
	(59964),
	(59965),
	(59966),
	(59967),
	(59968),
	(59969),
	(59970),
	(59971),
	(59972),
	(59973),
	(59974),
	(59975),
	(59976),
	(59977),
	(59978),
	(59979),
	(59980),
	(59981),
	(59982),
	(59983),
	(59984),
	(59985),
	(59986),
	(59987),
	(59988),
	(59989),
	(59990),
	(59991),
	(59992),
	(59993),
	(59994),
	(59995),
	(59996),
	(59997),
	(59998),
	(59999),
	(60000),
	(60001),
	(60002),
	(60003),
	(60004),
	(60005),
	(60006),
	(60007),
	(60008),
	(60009),
	(60010),
	(60011),
	(60012),
	(60013),
	(60014),
	(60015),
	(60016),
	(60017),
	(60018),
	(60019),
	(60020),
	(60021),
	(60022),
	(60023),
	(60024),
	(60025),
	(60026),
	(60027),
	(60028),
	(60029),
	(60030),
	(60031),
	(60032),
	(60033),
	(60034),
	(60035),
	(60036),
	(60037),
	(60038),
	(60039),
	(60040),
	(60041),
	(60042),
	(60043),
	(60044),
	(60045),
	(60046),
	(60047),
	(60048),
	(60049),
	(60050),
	(60051),
	(60052),
	(60053),
	(60054),
	(60055),
	(60056),
	(60057),
	(60058),
	(60059),
	(60060),
	(60061),
	(60062),
	(60063),
	(60064),
	(60065),
	(60066),
	(60067),
	(60068),
	(60069),
	(60070),
	(60071),
	(60072),
	(60073),
	(60074),
	(60075),
	(60076),
	(60077),
	(60078),
	(60079),
	(60080),
	(60081),
	(60082),
	(60083),
	(60084),
	(60085),
	(60086),
	(60087),
	(60088),
	(60089),
	(60090),
	(60091),
	(60092),
	(60093),
	(60094),
	(60095),
	(60096),
	(60097),
	(60098),
	(60099),
	(60100),
	(60101),
	(60102),
	(60103),
	(60104),
	(60105),
	(60106),
	(60107),
	(60108),
	(60109),
	(60110),
	(60111),
	(60112),
	(60113),
	(60114),
	(60115),
	(60116),
	(60117),
	(60118),
	(60119),
	(60120),
	(60121),
	(60122),
	(60123),
	(60124),
	(60125),
	(60126),
	(60127),
	(60128),
	(60129),
	(60130),
	(60131),
	(60132),
	(60133),
	(60134),
	(60135),
	(60136),
	(60137),
	(60138),
	(60139),
	(60140),
	(60141),
	(60142),
	(60143),
	(60144),
	(60145),
	(60146),
	(60147),
	(60148),
	(60149),
	(60150),
	(60151),
	(60152),
	(60153),
	(60154),
	(60155),
	(60156),
	(60157),
	(60158),
	(60159),
	(60160),
	(60161),
	(60162),
	(60163),
	(60164),
	(60165),
	(60166),
	(60167),
	(60168),
	(60169),
	(60170),
	(60171),
	(60172),
	(60173),
	(60174),
	(60175),
	(60176),
	(60177),
	(60178),
	(60179),
	(60180),
	(60181),
	(60182),
	(60183),
	(60184),
	(60185),
	(60186),
	(60187),
	(60188),
	(60189),
	(60190),
	(60191),
	(60192),
	(60193),
	(60194),
	(60195),
	(60196),
	(60197),
	(60198),
	(60199),
	(60200),
	(60201),
	(60202),
	(60203),
	(60204),
	(60205),
	(60206),
	(60207),
	(60208),
	(60209),
	(60210),
	(60211),
	(60212),
	(60213),
	(60214),
	(60215),
	(60216),
	(60217),
	(60218),
	(60219),
	(60220),
	(60221),
	(60222),
	(60223),
	(60224),
	(60225),
	(60226),
	(60227),
	(60228),
	(60229),
	(60230),
	(60231),
	(60232),
	(60233),
	(60234),
	(60235),
	(60236),
	(60237),
	(60238),
	(60239),
	(60240),
	(60241),
	(60242),
	(60243),
	(60244),
	(60245),
	(60246),
	(60247),
	(60248),
	(60249),
	(60250),
	(60251),
	(60252),
	(60253),
	(60254),
	(60255),
	(60256),
	(60257),
	(60258),
	(60259),
	(60260),
	(60261),
	(60262),
	(60263),
	(60264),
	(60265),
	(60266),
	(60267),
	(60268),
	(60269),
	(60270),
	(60271),
	(60272),
	(60273),
	(60274),
	(60275),
	(60276),
	(60277),
	(60278),
	(60279),
	(60280),
	(60281),
	(60282),
	(60283),
	(60284),
	(60285),
	(60286),
	(60287),
	(60288),
	(60289),
	(60290),
	(60291),
	(60292),
	(60293),
	(60294),
	(60295),
	(60296),
	(60297),
	(60298),
	(60299),
	(60300),
	(60301),
	(60302),
	(60303),
	(60304),
	(60305),
	(60306),
	(60307),
	(60308),
	(60309),
	(60310),
	(60311),
	(60312),
	(60313),
	(60314),
	(60315),
	(60316),
	(60317),
	(60318),
	(60319),
	(60320),
	(60321),
	(60322),
	(60323),
	(60324),
	(60325),
	(60326),
	(60327),
	(60328),
	(60329),
	(60330),
	(60331),
	(60332),
	(60333),
	(60334),
	(60335),
	(60336),
	(60337),
	(60338),
	(60339),
	(60340),
	(60341),
	(60342),
	(60343),
	(60344),
	(60345),
	(60346),
	(60347),
	(60348),
	(60349),
	(60350),
	(60351),
	(60352),
	(60353),
	(60354),
	(60355),
	(60356),
	(60357),
	(60358),
	(60359),
	(60360),
	(60361),
	(60362),
	(60363),
	(60364),
	(60365),
	(60366),
	(60367),
	(60368),
	(60369),
	(60370),
	(60371),
	(60372),
	(60373),
	(60374),
	(60375),
	(60376),
	(60377),
	(60378),
	(60379),
	(60380),
	(60381),
	(60382),
	(60383),
	(60384),
	(60385),
	(60386),
	(60387),
	(60388),
	(60389),
	(60390),
	(60391),
	(60392),
	(60393),
	(60394),
	(60395),
	(60396),
	(60397),
	(60398),
	(60399),
	(60400),
	(60401),
	(60402),
	(60403),
	(60404),
	(60405),
	(60406),
	(60407),
	(60408),
	(60409),
	(60410),
	(60411),
	(60412),
	(60413),
	(60414),
	(60415),
	(60416),
	(60417),
	(60418),
	(60419),
	(60420),
	(60421),
	(60422),
	(60423),
	(60424),
	(60425),
	(60426),
	(60427),
	(60428),
	(60429),
	(60430),
	(60431),
	(60432),
	(60433),
	(60434),
	(60435),
	(60436),
	(60437),
	(60438),
	(60439),
	(60440),
	(60441),
	(60442),
	(60443),
	(60444),
	(60445),
	(60446),
	(60447),
	(60448),
	(60449),
	(60450),
	(60451),
	(60452),
	(60453),
	(60454),
	(60455),
	(60456),
	(60457),
	(60458),
	(60459),
	(60460),
	(60461),
	(60462),
	(60463),
	(60464),
	(60465),
	(60466),
	(60467),
	(60468),
	(60469),
	(60470),
	(60471),
	(60472),
	(60473),
	(60474),
	(60475),
	(60476),
	(60477),
	(60478),
	(60479),
	(60480),
	(60481),
	(60482),
	(60483),
	(60484),
	(60485),
	(60486),
	(60487),
	(60488),
	(60489),
	(60490),
	(60491),
	(60492),
	(60493),
	(60494),
	(60495),
	(60496),
	(60497),
	(60498),
	(60499),
	(60500),
	(60501),
	(60502),
	(60503),
	(60504),
	(60505),
	(60506),
	(60507),
	(60508),
	(60509),
	(60510),
	(60511),
	(60512),
	(60513),
	(60514),
	(60515),
	(60516),
	(60517),
	(60518),
	(60519),
	(60520),
	(60521),
	(60522),
	(60523),
	(60524),
	(60525),
	(60526),
	(60527),
	(60528),
	(60529),
	(60530),
	(60531),
	(60532),
	(60533),
	(60534),
	(60535),
	(60536),
	(60537),
	(60538),
	(60539),
	(60540),
	(60541),
	(60542),
	(60543),
	(60544),
	(60545),
	(60546),
	(60547),
	(60548),
	(60549),
	(60550),
	(60551),
	(60552),
	(60553),
	(60554),
	(60555),
	(60556),
	(60557),
	(60558),
	(60559),
	(60560),
	(60561),
	(60562),
	(60563),
	(60564),
	(60565),
	(60566),
	(60567),
	(60568),
	(60569),
	(60570),
	(60571),
	(60572),
	(60573),
	(60574),
	(60575),
	(60576),
	(60577),
	(60578),
	(60579),
	(60580),
	(60581),
	(60582),
	(60583),
	(60584),
	(60585),
	(60586),
	(60587),
	(60588),
	(60589),
	(60590),
	(60591),
	(60592),
	(60593),
	(60594),
	(60595),
	(60596),
	(60597),
	(60598),
	(60599),
	(60600),
	(60601),
	(60602),
	(60603),
	(60604),
	(60605),
	(60606),
	(60607),
	(60608),
	(60609),
	(60610),
	(60611),
	(60612),
	(60613),
	(60614),
	(60615),
	(60616),
	(60617),
	(60618),
	(60619),
	(60620),
	(60621),
	(60622),
	(60623),
	(60624),
	(60625),
	(60626),
	(60627),
	(60628),
	(60629),
	(60630),
	(60631),
	(60632),
	(60633),
	(60634),
	(60635),
	(60636),
	(60637),
	(60638),
	(60639),
	(60640),
	(60641),
	(60642),
	(60643),
	(60644),
	(60645),
	(60646),
	(60647),
	(60648),
	(60649),
	(60650),
	(60651),
	(60652),
	(60653),
	(60654),
	(60655),
	(60656),
	(60657),
	(60658),
	(60659),
	(60660),
	(60661),
	(60662),
	(60663),
	(60664),
	(60665),
	(60666),
	(60667),
	(60668),
	(60669),
	(60670),
	(60671),
	(60672),
	(60673),
	(60674),
	(60675),
	(60676),
	(60677),
	(60678),
	(60679),
	(60680),
	(60681),
	(60682),
	(60683),
	(60684),
	(60685),
	(60686),
	(60687),
	(60688),
	(60689),
	(60690),
	(60691),
	(60692),
	(60693),
	(60694),
	(60695),
	(60696),
	(60697),
	(60698),
	(60699),
	(60700),
	(60701),
	(60702),
	(60703),
	(60704),
	(60705),
	(60706),
	(60707),
	(60708),
	(60709),
	(60710),
	(60711),
	(60712),
	(60713),
	(60714),
	(60715),
	(60716),
	(60717),
	(60718),
	(60719),
	(60720),
	(60721),
	(60722),
	(60723),
	(60724),
	(60725),
	(60726),
	(60727),
	(60728),
	(60729),
	(60730),
	(60731),
	(60732),
	(60733),
	(60734),
	(60735),
	(60736),
	(60737),
	(60738),
	(60739),
	(60740),
	(60741),
	(60742),
	(60743),
	(60744),
	(60745),
	(60746),
	(60747),
	(60748),
	(60749),
	(60750),
	(60751),
	(60752),
	(60753),
	(60754),
	(60755),
	(60756),
	(60757),
	(60758),
	(60759),
	(60760),
	(60761),
	(60762),
	(60763),
	(60764),
	(60765),
	(60766),
	(60767),
	(60768),
	(60769),
	(60770),
	(60771),
	(60772),
	(60773),
	(60774),
	(60775),
	(60776),
	(60777),
	(60778),
	(60779),
	(60780),
	(60781),
	(60782),
	(60783),
	(60784),
	(60785),
	(60786),
	(60787),
	(60788),
	(60789),
	(60790),
	(60791),
	(60792),
	(60793),
	(60794),
	(60795),
	(60796),
	(60797),
	(60798),
	(60799),
	(60800),
	(60801),
	(60802),
	(60803),
	(60804),
	(60805),
	(60806),
	(60807),
	(60808),
	(60809),
	(60810),
	(60811),
	(60812),
	(60813),
	(60814),
	(60815),
	(60816),
	(60817),
	(60818),
	(60819),
	(60820),
	(60821),
	(60822),
	(60823),
	(60824),
	(60825),
	(60826),
	(60827),
	(60828),
	(60829),
	(60830),
	(60831),
	(60832),
	(60833),
	(60834),
	(60835),
	(60836),
	(60837),
	(60838),
	(60839),
	(60840),
	(60841),
	(60842),
	(60843),
	(60844),
	(60845),
	(60846),
	(60847),
	(60848),
	(60849),
	(60850),
	(60851),
	(60852),
	(60853),
	(60854),
	(60855),
	(60856),
	(60857),
	(60858),
	(60859),
	(60860),
	(60861),
	(60862),
	(60863),
	(60864),
	(60865),
	(60866),
	(60867),
	(60868),
	(60869),
	(60870),
	(60871),
	(60872),
	(60873),
	(60874),
	(60875),
	(60876),
	(60877),
	(60878),
	(60879),
	(60880),
	(60881),
	(60882),
	(60883),
	(60884),
	(60885),
	(60886),
	(60887),
	(60888),
	(60889),
	(60890),
	(60891),
	(60892),
	(60893),
	(60894),
	(60895),
	(60896),
	(60897),
	(60898),
	(60899),
	(60900),
	(60901),
	(60902),
	(60903),
	(60904),
	(60905),
	(60906),
	(60907),
	(60908),
	(60909),
	(60910),
	(60911),
	(60912),
	(60913),
	(60914),
	(60915),
	(60916),
	(60917),
	(60918),
	(60919),
	(60920),
	(60921),
	(60922),
	(60923),
	(60924),
	(60925),
	(60926),
	(60927),
	(60928),
	(60929),
	(60930),
	(60931),
	(60932),
	(60933),
	(60934),
	(60935),
	(60936),
	(60937),
	(60938),
	(60939),
	(60940),
	(60941),
	(60942),
	(60943),
	(60944),
	(60945),
	(60946),
	(60947),
	(60948),
	(60949),
	(60950),
	(60951),
	(60952),
	(60953),
	(60954),
	(60955),
	(60956),
	(60957),
	(60958),
	(60959),
	(60960),
	(60961),
	(60962),
	(60963),
	(60964),
	(60965),
	(60966),
	(60967),
	(60968),
	(60969),
	(60970),
	(60971),
	(60972),
	(60973),
	(60974),
	(60975),
	(60976),
	(60977),
	(60978),
	(60979),
	(60980),
	(60981),
	(60982),
	(60983),
	(60984),
	(60985),
	(60986),
	(60987),
	(60988),
	(60989),
	(60990),
	(60991),
	(60992),
	(60993),
	(60994),
	(60995),
	(60996),
	(60997),
	(60998),
	(60999),
	(61000),
	(61001),
	(61002),
	(61003),
	(61004),
	(61005),
	(61006),
	(61007),
	(61008),
	(61009),
	(61010),
	(61011),
	(61012),
	(61013),
	(61014),
	(61015),
	(61016),
	(61017),
	(61018),
	(61019),
	(61020),
	(61021),
	(61022),
	(61023),
	(61024),
	(61025),
	(61026),
	(61027),
	(61028),
	(61029),
	(61030),
	(61031),
	(61032),
	(61033),
	(61034),
	(61035),
	(61036),
	(61037),
	(61038),
	(61039),
	(61040),
	(61041),
	(61042),
	(61043),
	(61044),
	(61045),
	(61046),
	(61047),
	(61048),
	(61049),
	(61050),
	(61051),
	(61052),
	(61053),
	(61054),
	(61055),
	(61056),
	(61057),
	(61058),
	(61059),
	(61060),
	(61061),
	(61062),
	(61063),
	(61064),
	(61065),
	(61066),
	(61067),
	(61068),
	(61069),
	(61070),
	(61071),
	(61072),
	(61073),
	(61074),
	(61075),
	(61076),
	(61077),
	(61078),
	(61079),
	(61080),
	(61081),
	(61082),
	(61083),
	(61084),
	(61085),
	(61086),
	(61087),
	(61088),
	(61089),
	(61090),
	(61091),
	(61092),
	(61093),
	(61094),
	(61095),
	(61096),
	(61097),
	(61098),
	(61099),
	(61100),
	(61101),
	(61102),
	(61103),
	(61104),
	(61105),
	(61106),
	(61107),
	(61108),
	(61109),
	(61110),
	(61111),
	(61112),
	(61113),
	(61114),
	(61115),
	(61116),
	(61117),
	(61118),
	(61119),
	(61120),
	(61121),
	(61122),
	(61123),
	(61124),
	(61125),
	(61126),
	(61127),
	(61128),
	(61129),
	(61130),
	(61131),
	(61132),
	(61133),
	(61134),
	(61135),
	(61136),
	(61137),
	(61138),
	(61139),
	(61140),
	(61141),
	(61142),
	(61143),
	(61144),
	(61145),
	(61146),
	(61147),
	(61148),
	(61149),
	(61150),
	(61151),
	(61152),
	(61153),
	(61154),
	(61155),
	(61156),
	(61157),
	(61158),
	(61159),
	(61160),
	(61161),
	(61162),
	(61163),
	(61164),
	(61165),
	(61166),
	(61167),
	(61168),
	(61169),
	(61170),
	(61171),
	(61172),
	(61173),
	(61174),
	(61175),
	(61176),
	(61177),
	(61178),
	(61179),
	(61180),
	(61181),
	(61182),
	(61183),
	(61184),
	(61185),
	(61186),
	(61187),
	(61188),
	(61189),
	(61190),
	(61191),
	(61192),
	(61193),
	(61194),
	(61195),
	(61196),
	(61197),
	(61198),
	(61199),
	(61200),
	(61201),
	(61202),
	(61203),
	(61204),
	(61205),
	(61206),
	(61207),
	(61208),
	(61209),
	(61210),
	(61211),
	(61212),
	(61213),
	(61214),
	(61215),
	(61216),
	(61217),
	(61218),
	(61219),
	(61220),
	(61221),
	(61222),
	(61223),
	(61224),
	(61225),
	(61226),
	(61227),
	(61228),
	(61229),
	(61230),
	(61231),
	(61232),
	(61233),
	(61234),
	(61235),
	(61236),
	(61237),
	(61238),
	(61239),
	(61240),
	(61241),
	(61242),
	(61243),
	(61244),
	(61245),
	(61246),
	(61247),
	(61248),
	(61249),
	(61250),
	(61251),
	(61252),
	(61253),
	(61254),
	(61255),
	(61256),
	(61257),
	(61258),
	(61259),
	(61260),
	(61261),
	(61262),
	(61263),
	(61264),
	(61265),
	(61266),
	(61267),
	(61268),
	(61269),
	(61270),
	(61271),
	(61272),
	(61273),
	(61274),
	(61275),
	(61276),
	(61277),
	(61278),
	(61279),
	(61280),
	(61281),
	(61282),
	(61283),
	(61284),
	(61285),
	(61286),
	(61287),
	(61288),
	(61289),
	(61290),
	(61291),
	(61292),
	(61293),
	(61294),
	(61295),
	(61296),
	(61297),
	(61298),
	(61299),
	(61300),
	(61301),
	(61302),
	(61303),
	(61304),
	(61305),
	(61306),
	(61307),
	(61308),
	(61309),
	(61310),
	(61311),
	(61312),
	(61313),
	(61314),
	(61315),
	(61316),
	(61317),
	(61318),
	(61319),
	(61320),
	(61321),
	(61322),
	(61323),
	(61324),
	(61325),
	(61326),
	(61327),
	(61328),
	(61329),
	(61330),
	(61331),
	(61332),
	(61333),
	(61334),
	(61335),
	(61336),
	(61337),
	(61338),
	(61339),
	(61340),
	(61341),
	(61342),
	(61343),
	(61344),
	(61345),
	(61346),
	(61347),
	(61348),
	(61349),
	(61350),
	(61351),
	(61352),
	(61353),
	(61354),
	(61355),
	(61356),
	(61357),
	(61358),
	(61359),
	(61360),
	(61361),
	(61362),
	(61363),
	(61364),
	(61365),
	(61366),
	(61367),
	(61368),
	(61369),
	(61370),
	(61371),
	(61372),
	(61373),
	(61374),
	(61375),
	(61376),
	(61377),
	(61378),
	(61379),
	(61380),
	(61381),
	(61382),
	(61383),
	(61384),
	(61385),
	(61386),
	(61387),
	(61388),
	(61389),
	(61390),
	(61391),
	(61392),
	(61393),
	(61394),
	(61395),
	(61396),
	(61397),
	(61398),
	(61399),
	(61400),
	(61401),
	(61402),
	(61403),
	(61404),
	(61405),
	(61406),
	(61407),
	(61408),
	(61409),
	(61410),
	(61411),
	(61412),
	(61413),
	(61414),
	(61415),
	(61416),
	(61417),
	(61418),
	(61419),
	(61420),
	(61421),
	(61422),
	(61423),
	(61424),
	(61425),
	(61426),
	(61427),
	(61428),
	(61429),
	(61430),
	(61431),
	(61432),
	(61433),
	(61434),
	(61435),
	(61436),
	(61437),
	(61438),
	(61439),
	(61440),
	(61441),
	(61442),
	(61443),
	(61444),
	(61445),
	(61446),
	(61447),
	(61448),
	(61449),
	(61450),
	(61451),
	(61452),
	(61453),
	(61454),
	(61455),
	(61456),
	(61457),
	(61458),
	(61459),
	(61460),
	(61461),
	(61462),
	(61463),
	(61464),
	(61465),
	(61466),
	(61467),
	(61468),
	(61469),
	(61470),
	(61471),
	(61472),
	(61473),
	(61474),
	(61475),
	(61476),
	(61477),
	(61478),
	(61479),
	(61480),
	(61481),
	(61482),
	(61483),
	(61484),
	(61485),
	(61486),
	(61487),
	(61488),
	(61489),
	(61490),
	(61491),
	(61492),
	(61493),
	(61494),
	(61495),
	(61496),
	(61497),
	(61498),
	(61499),
	(61500),
	(61501),
	(61502),
	(61503),
	(61504),
	(61505),
	(61506),
	(61507),
	(61508),
	(61509),
	(61510),
	(61511),
	(61512),
	(61513),
	(61514),
	(61515),
	(61516),
	(61517),
	(61518),
	(61519),
	(61520),
	(61521),
	(61522),
	(61523),
	(61524),
	(61525),
	(61526),
	(61527),
	(61528),
	(61529),
	(61530),
	(61531),
	(61532),
	(61533),
	(61534),
	(61535),
	(61536),
	(61537),
	(61538),
	(61539),
	(61540),
	(61541),
	(61542),
	(61543),
	(61544),
	(61545),
	(61546),
	(61547),
	(61548),
	(61549),
	(61550),
	(61551),
	(61552),
	(61553),
	(61554),
	(61555),
	(61556),
	(61557),
	(61558),
	(61559),
	(61560),
	(61561),
	(61562),
	(61563),
	(61564),
	(61565),
	(61566),
	(61567),
	(61568),
	(61569),
	(61570),
	(61571),
	(61572),
	(61573),
	(61574),
	(61575),
	(61576),
	(61577),
	(61578),
	(61579),
	(61580),
	(61581),
	(61582),
	(61583),
	(61584),
	(61585),
	(61586),
	(61587),
	(61588),
	(61589),
	(61590),
	(61591),
	(61592),
	(61593),
	(61594),
	(61595),
	(61596),
	(61597),
	(61598),
	(61599),
	(61600),
	(61601),
	(61602),
	(61603),
	(61604),
	(61605),
	(61606),
	(61607),
	(61608),
	(61609),
	(61610),
	(61611),
	(61612),
	(61613),
	(61614),
	(61615),
	(61616),
	(61617),
	(61618),
	(61619),
	(61620),
	(61621),
	(61622),
	(61623),
	(61624),
	(61625),
	(61626),
	(61627),
	(61628),
	(61629),
	(61630),
	(61631),
	(61632),
	(61633),
	(61634),
	(61635),
	(61636),
	(61637),
	(61638),
	(61639),
	(61640),
	(61641),
	(61642),
	(61643),
	(61644),
	(61645),
	(61646),
	(61647),
	(61648),
	(61649),
	(61650),
	(61651),
	(61652),
	(61653),
	(61654),
	(61655),
	(61656),
	(61657),
	(61658),
	(61659),
	(61660),
	(61661),
	(61662),
	(61663),
	(61664),
	(61665),
	(61666),
	(61667),
	(61668),
	(61669),
	(61670),
	(61671),
	(61672),
	(61673),
	(61674),
	(61675),
	(61676),
	(61677),
	(61678),
	(61679),
	(61680),
	(61681),
	(61682),
	(61683),
	(61684),
	(61685),
	(61686),
	(61687),
	(61688),
	(61689),
	(61690),
	(61691),
	(61692),
	(61693),
	(61694),
	(61695),
	(61696),
	(61697),
	(61698),
	(61699),
	(61700),
	(61701),
	(61702),
	(61703),
	(61704),
	(61705),
	(61706),
	(61707),
	(61708),
	(61709),
	(61710),
	(61711),
	(61712),
	(61713),
	(61714),
	(61715),
	(61716),
	(61717),
	(61718),
	(61719),
	(61720),
	(61721),
	(61722),
	(61723),
	(61724),
	(61725),
	(61726),
	(61727),
	(61728),
	(61729),
	(61730),
	(61731),
	(61732),
	(61733),
	(61734),
	(61735),
	(61736),
	(61737),
	(61738),
	(61739),
	(61740),
	(61741),
	(61742),
	(61743),
	(61744),
	(61745),
	(61746),
	(61747),
	(61748),
	(61749),
	(61750),
	(61751),
	(61752),
	(61753),
	(61754),
	(61755),
	(61756),
	(61757),
	(61758),
	(61759),
	(61760),
	(61761),
	(61762),
	(61763),
	(61764),
	(61765),
	(61766),
	(61767),
	(61768),
	(61769),
	(61770),
	(61771),
	(61772),
	(61773),
	(61774),
	(61775),
	(61776),
	(61777),
	(61778),
	(61779),
	(61780),
	(61781),
	(61782),
	(61783),
	(61784),
	(61785),
	(61786),
	(61787),
	(61788),
	(61789),
	(61790),
	(61791),
	(61792),
	(61793),
	(61794),
	(61795),
	(61796),
	(61797),
	(61798),
	(61799),
	(61800),
	(61801),
	(61802),
	(61803),
	(61804),
	(61805),
	(61806),
	(61807),
	(61808),
	(61809),
	(61810),
	(61811),
	(61812),
	(61813),
	(61814),
	(61815),
	(61816),
	(61817),
	(61818),
	(61819),
	(61820),
	(61821),
	(61822),
	(61823),
	(61824),
	(61825),
	(61826),
	(61827),
	(61828),
	(61829),
	(61830),
	(61831),
	(61832),
	(61833),
	(61834),
	(61835),
	(61836),
	(61837),
	(61838),
	(61839),
	(61840),
	(61841),
	(61842),
	(61843),
	(61844),
	(61845),
	(61846),
	(61847),
	(61848),
	(61849),
	(61850),
	(61851),
	(61852),
	(61853),
	(61854),
	(61855),
	(61856),
	(61857),
	(61858),
	(61859),
	(61860),
	(61861),
	(61862),
	(61863),
	(61864),
	(61865),
	(61866),
	(61867),
	(61868),
	(61869),
	(61870),
	(61871),
	(61872),
	(61873),
	(61874),
	(61875),
	(61876),
	(61877),
	(61878),
	(61879),
	(61880),
	(61881),
	(61882),
	(61883),
	(61884),
	(61885),
	(61886),
	(61887),
	(61888),
	(61889),
	(61890),
	(61891),
	(61892),
	(61893),
	(61894),
	(61895),
	(61896),
	(61897),
	(61898),
	(61899),
	(61900),
	(61901),
	(61902),
	(61903),
	(61904),
	(61905),
	(61906),
	(61907),
	(61908),
	(61909),
	(61910),
	(61911),
	(61912),
	(61913),
	(61914),
	(61915),
	(61916),
	(61917),
	(61918),
	(61919),
	(61920),
	(61921),
	(61922),
	(61923),
	(61924),
	(61925),
	(61926),
	(61927),
	(61928),
	(61929),
	(61930),
	(61931),
	(61932),
	(61933),
	(61934),
	(61935),
	(61936),
	(61937),
	(61938),
	(61939),
	(61940),
	(61941),
	(61942),
	(61943),
	(61944),
	(61945),
	(61946),
	(61947),
	(61948),
	(61949),
	(61950),
	(61951),
	(61952),
	(61953),
	(61954),
	(61955),
	(61956),
	(61957),
	(61958),
	(61959),
	(61960),
	(61961),
	(61962),
	(61963),
	(61964),
	(61965),
	(61966),
	(61967),
	(61968),
	(61969),
	(61970),
	(61971),
	(61972),
	(61973),
	(61974),
	(61975),
	(61976),
	(61977),
	(61978),
	(61979),
	(61980),
	(61981),
	(61982),
	(61983),
	(61984),
	(61985),
	(61986),
	(61987),
	(61988),
	(61989),
	(61990),
	(61991),
	(61992),
	(61993),
	(61994),
	(61995),
	(61996),
	(61997),
	(61998),
	(61999),
	(62000),
	(62001),
	(62002),
	(62003),
	(62004),
	(62005),
	(62006),
	(62007),
	(62008),
	(62009),
	(62010),
	(62011),
	(62012),
	(62013),
	(62014),
	(62015),
	(62016),
	(62017),
	(62018),
	(62019),
	(62020),
	(62021),
	(62022),
	(62023),
	(62024),
	(62025),
	(62026),
	(62027),
	(62028),
	(62029),
	(62030),
	(62031),
	(62032),
	(62033),
	(62034),
	(62035),
	(62036),
	(62037),
	(62038),
	(62039),
	(62040),
	(62041),
	(62042),
	(62043),
	(62044),
	(62045),
	(62046),
	(62047),
	(62048),
	(62049),
	(62050),
	(62051),
	(62052),
	(62053),
	(62054),
	(62055),
	(62056),
	(62057),
	(62058),
	(62059),
	(62060),
	(62061),
	(62062),
	(62063),
	(62064),
	(62065),
	(62066),
	(62067),
	(62068),
	(62069),
	(62070),
	(62071),
	(62072),
	(62073),
	(62074),
	(62075),
	(62076),
	(62077),
	(62078),
	(62079),
	(62080),
	(62081),
	(62082),
	(62083),
	(62084),
	(62085),
	(62086),
	(62087),
	(62088),
	(62089),
	(62090),
	(62091),
	(62092),
	(62093),
	(62094),
	(62095),
	(62096),
	(62097),
	(62098),
	(62099),
	(62100),
	(62101),
	(62102),
	(62103),
	(62104),
	(62105),
	(62106),
	(62107),
	(62108),
	(62109),
	(62110),
	(62111),
	(62112),
	(62113),
	(62114),
	(62115),
	(62116),
	(62117),
	(62118),
	(62119),
	(62120),
	(62121),
	(62122),
	(62123),
	(62124),
	(62125),
	(62126),
	(62127),
	(62128),
	(62129),
	(62130),
	(62131),
	(62132),
	(62133),
	(62134),
	(62135),
	(62136),
	(62137),
	(62138),
	(62139),
	(62140),
	(62141),
	(62142),
	(62143),
	(62144),
	(62145),
	(62146),
	(62147),
	(62148),
	(62149),
	(62150),
	(62151),
	(62152),
	(62153),
	(62154),
	(62155),
	(62156),
	(62157),
	(62158),
	(62159),
	(62160),
	(62161),
	(62162),
	(62163),
	(62164),
	(62165),
	(62166),
	(62167),
	(62168),
	(62169),
	(62170),
	(62171),
	(62172),
	(62173),
	(62174),
	(62175),
	(62176),
	(62177),
	(62178),
	(62179),
	(62180),
	(62181),
	(62182),
	(62183),
	(62184),
	(62185),
	(62186),
	(62187),
	(62188),
	(62189),
	(62190),
	(62191),
	(62192),
	(62193),
	(62194),
	(62195),
	(62196),
	(62197),
	(62198),
	(62199),
	(62200),
	(62201),
	(62202),
	(62203),
	(62204),
	(62205),
	(62206),
	(62207),
	(62208),
	(62209),
	(62210),
	(62211),
	(62212),
	(62213),
	(62214),
	(62215),
	(62216),
	(62217),
	(62218),
	(62219),
	(62220),
	(62221),
	(62222),
	(62223),
	(62224),
	(62225),
	(62226),
	(62227),
	(62228),
	(62229),
	(62230),
	(62231),
	(62232),
	(62233),
	(62234),
	(62235),
	(62236),
	(62237),
	(62238),
	(62239),
	(62240),
	(62241),
	(62242),
	(62243),
	(62244),
	(62245),
	(62246),
	(62247),
	(62248),
	(62249),
	(62250),
	(62251),
	(62252),
	(62253),
	(62254),
	(62255),
	(62256),
	(62257),
	(62258),
	(62259),
	(62260),
	(62261),
	(62262),
	(62263),
	(62264),
	(62265),
	(62266),
	(62267),
	(62268),
	(62269),
	(62270),
	(62271),
	(62272),
	(62273),
	(62274),
	(62275),
	(62276),
	(62277),
	(62278),
	(62279),
	(62280),
	(62281),
	(62282),
	(62283),
	(62284),
	(62285),
	(62286),
	(62287),
	(62288),
	(62289),
	(62290),
	(62291),
	(62292),
	(62293),
	(62294),
	(62295),
	(62296),
	(62297),
	(62298),
	(62299),
	(62300),
	(62301),
	(62302),
	(62303),
	(62304),
	(62305),
	(62306),
	(62307),
	(62308),
	(62309),
	(62310),
	(62311),
	(62312),
	(62313),
	(62314),
	(62315),
	(62316),
	(62317),
	(62318),
	(62319),
	(62320),
	(62321),
	(62322),
	(62323),
	(62324),
	(62325),
	(62326),
	(62327),
	(62328),
	(62329),
	(62330),
	(62331),
	(62332),
	(62333),
	(62334),
	(62335),
	(62336),
	(62337),
	(62338),
	(62339),
	(62340),
	(62341),
	(62342),
	(62343),
	(62344),
	(62345),
	(62346),
	(62347),
	(62348),
	(62349),
	(62350),
	(62351),
	(62352),
	(62353),
	(62354),
	(62355),
	(62356),
	(62357),
	(62358),
	(62359),
	(62360),
	(62361),
	(62362),
	(62363),
	(62364),
	(62365),
	(62366),
	(62367),
	(62368),
	(62369),
	(62370),
	(62371),
	(62372),
	(62373),
	(62374),
	(62375),
	(62376),
	(62377),
	(62378),
	(62379),
	(62380),
	(62381),
	(62382),
	(62383),
	(62384),
	(62385),
	(62386),
	(62387),
	(62388),
	(62389),
	(62390),
	(62391),
	(62392),
	(62393),
	(62394),
	(62395),
	(62396),
	(62397),
	(62398),
	(62399),
	(62400),
	(62401),
	(62402),
	(62403),
	(62404),
	(62405),
	(62406),
	(62407),
	(62408),
	(62409),
	(62410),
	(62411),
	(62412),
	(62413),
	(62414),
	(62415),
	(62416),
	(62417),
	(62418),
	(62419),
	(62420),
	(62421),
	(62422),
	(62423),
	(62424),
	(62425),
	(62426),
	(62427),
	(62428),
	(62429),
	(62430),
	(62431),
	(62432),
	(62433),
	(62434),
	(62435),
	(62436),
	(62437),
	(62438),
	(62439),
	(62440),
	(62441),
	(62442),
	(62443),
	(62444),
	(62445),
	(62446),
	(62447),
	(62448),
	(62449),
	(62450),
	(62451),
	(62452),
	(62453),
	(62454),
	(62455),
	(62456),
	(62457),
	(62458),
	(62459),
	(62460),
	(62461),
	(62462),
	(62463),
	(62464),
	(62465),
	(62466),
	(62467),
	(62468),
	(62469),
	(62470),
	(62471),
	(62472),
	(62473),
	(62474),
	(62475),
	(62476),
	(62477),
	(62478),
	(62479),
	(62480),
	(62481),
	(62482),
	(62483),
	(62484),
	(62485),
	(62486),
	(62487),
	(62488),
	(62489),
	(62490),
	(62491),
	(62492),
	(62493),
	(62494),
	(62495),
	(62496),
	(62497),
	(62498),
	(62499),
	(62500),
	(62501),
	(62502),
	(62503),
	(62504),
	(62505),
	(62506),
	(62507),
	(62508),
	(62509),
	(62510),
	(62511),
	(62512),
	(62513),
	(62514),
	(62515),
	(62516),
	(62517),
	(62518),
	(62519),
	(62520),
	(62521),
	(62522),
	(62523),
	(62524),
	(62525),
	(62526),
	(62527),
	(62528),
	(62529),
	(62530),
	(62531),
	(62532),
	(62533),
	(62534),
	(62535),
	(62536),
	(62537),
	(62538),
	(62539),
	(62540),
	(62541),
	(62542),
	(62543),
	(62544),
	(62545),
	(62546),
	(62547),
	(62548),
	(62549),
	(62550),
	(62551),
	(62552),
	(62553),
	(62554),
	(62555),
	(62556),
	(62557),
	(62558),
	(62559),
	(62560),
	(62561),
	(62562),
	(62563),
	(62564),
	(62565),
	(62566),
	(62567),
	(62568),
	(62569),
	(62570),
	(62571),
	(62572),
	(62573),
	(62574),
	(62575),
	(62576),
	(62577),
	(62578),
	(62579),
	(62580),
	(62581),
	(62582),
	(62583),
	(62584),
	(62585),
	(62586),
	(62587),
	(62588),
	(62589),
	(62590),
	(62591),
	(62592),
	(62593),
	(62594),
	(62595),
	(62596),
	(62597),
	(62598),
	(62599),
	(62600),
	(62601),
	(62602),
	(62603),
	(62604),
	(62605),
	(62606),
	(62607),
	(62608),
	(62609),
	(62610),
	(62611),
	(62612),
	(62613),
	(62614),
	(62615),
	(62616),
	(62617),
	(62618),
	(62619),
	(62620),
	(62621),
	(62622),
	(62623),
	(62624),
	(62625),
	(62626),
	(62627),
	(62628),
	(62629),
	(62630),
	(62631),
	(62632),
	(62633),
	(62634),
	(62635),
	(62636),
	(62637),
	(62638),
	(62639),
	(62640),
	(62641),
	(62642),
	(62643),
	(62644),
	(62645),
	(62646),
	(62647),
	(62648),
	(62649),
	(62650),
	(62651),
	(62652),
	(62653),
	(62654),
	(62655),
	(62656),
	(62657),
	(62658),
	(62659),
	(62660),
	(62661),
	(62662),
	(62663),
	(62664),
	(62665),
	(62666),
	(62667),
	(62668),
	(62669),
	(62670),
	(62671),
	(62672),
	(62673),
	(62674),
	(62675),
	(62676),
	(62677),
	(62678),
	(62679),
	(62680),
	(62681),
	(62682),
	(62683),
	(62684),
	(62685),
	(62686),
	(62687),
	(62688),
	(62689),
	(62690),
	(62691),
	(62692),
	(62693),
	(62694),
	(62695),
	(62696),
	(62697),
	(62698),
	(62699),
	(62700),
	(62701),
	(62702),
	(62703),
	(62704),
	(62705),
	(62706),
	(62707),
	(62708),
	(62709),
	(62710),
	(62711),
	(62712),
	(62713),
	(62714),
	(62715),
	(62716),
	(62717),
	(62718),
	(62719),
	(62720),
	(62721),
	(62722),
	(62723),
	(62724),
	(62725),
	(62726),
	(62727),
	(62728),
	(62729),
	(62730),
	(62731),
	(62732),
	(62733),
	(62734),
	(62735),
	(62736),
	(62737),
	(62738),
	(62739),
	(62740),
	(62741),
	(62742),
	(62743),
	(62744),
	(62745),
	(62746),
	(62747),
	(62748),
	(62749),
	(62750),
	(62751),
	(62752),
	(62753),
	(62754),
	(62755),
	(62756),
	(62757),
	(62758),
	(62759),
	(62760),
	(62761),
	(62762),
	(62763),
	(62764),
	(62765),
	(62766),
	(62767),
	(62768),
	(62769),
	(62770),
	(62771),
	(62772),
	(62773),
	(62774),
	(62775),
	(62776),
	(62777),
	(62778),
	(62779),
	(62780),
	(62781),
	(62782),
	(62783),
	(62784),
	(62785),
	(62786),
	(62787),
	(62788),
	(62789),
	(62790),
	(62791),
	(62792),
	(62793),
	(62794),
	(62795),
	(62796),
	(62797),
	(62798),
	(62799),
	(62800),
	(62801),
	(62802),
	(62803),
	(62804),
	(62805),
	(62806),
	(62807),
	(62808),
	(62809),
	(62810),
	(62811),
	(62812),
	(62813),
	(62814),
	(62815),
	(62816),
	(62817),
	(62818),
	(62819),
	(62820),
	(62821),
	(62822),
	(62823),
	(62824),
	(62825),
	(62826),
	(62827),
	(62828),
	(62829),
	(62830),
	(62831),
	(62832),
	(62833),
	(62834),
	(62835),
	(62836),
	(62837),
	(62838),
	(62839),
	(62840),
	(62841),
	(62842),
	(62843),
	(62844),
	(62845),
	(62846),
	(62847),
	(62848),
	(62849),
	(62850),
	(62851),
	(62852),
	(62853),
	(62854),
	(62855),
	(62856),
	(62857),
	(62858),
	(62859),
	(62860),
	(62861),
	(62862),
	(62863),
	(62864),
	(62865),
	(62866),
	(62867),
	(62868),
	(62869),
	(62870),
	(62871),
	(62872),
	(62873),
	(62874),
	(62875),
	(62876),
	(62877),
	(62878),
	(62879),
	(62880),
	(62881),
	(62882),
	(62883),
	(62884),
	(62885),
	(62886),
	(62887),
	(62888),
	(62889),
	(62890),
	(62891),
	(62892),
	(62893),
	(62894),
	(62895),
	(62896),
	(62897),
	(62898),
	(62899),
	(62900),
	(62901),
	(62902),
	(62903),
	(62904),
	(62905),
	(62906),
	(62907),
	(62908),
	(62909),
	(62910),
	(62911),
	(62912),
	(62913),
	(62914),
	(62915),
	(62916),
	(62917),
	(62918),
	(62919),
	(62920),
	(62921),
	(62922),
	(62923),
	(62924),
	(62925),
	(62926),
	(62927),
	(62928),
	(62929),
	(62930),
	(62931),
	(62932),
	(62933),
	(62934),
	(62935),
	(62936),
	(62937),
	(62938),
	(62939),
	(62940),
	(62941),
	(62942),
	(62943),
	(62944),
	(62945),
	(62946),
	(62947),
	(62948),
	(62949),
	(62950),
	(62951),
	(62952),
	(62953),
	(62954),
	(62955),
	(62956),
	(62957),
	(62958),
	(62959),
	(62960),
	(62961),
	(62962),
	(62963),
	(62964),
	(62965),
	(62966),
	(62967),
	(62968),
	(62969),
	(62970),
	(62971),
	(62972),
	(62973),
	(62974),
	(62975),
	(62976),
	(62977),
	(62978),
	(62979),
	(62980),
	(62981),
	(62982),
	(62983),
	(62984),
	(62985),
	(62986),
	(62987),
	(62988),
	(62989),
	(62990),
	(62991),
	(62992),
	(62993),
	(62994),
	(62995),
	(62996),
	(62997),
	(62998),
	(62999),
	(63000),
	(63001),
	(63002),
	(63003),
	(63004),
	(63005),
	(63006),
	(63007),
	(63008),
	(63009),
	(63010),
	(63011),
	(63012),
	(63013),
	(63014),
	(63015),
	(63016),
	(63017),
	(63018),
	(63019),
	(63020),
	(63021),
	(63022),
	(63023),
	(63024),
	(63025),
	(63026),
	(63027),
	(63028),
	(63029),
	(63030),
	(63031),
	(63032),
	(63033),
	(63034),
	(63035),
	(63036),
	(63037),
	(63038),
	(63039),
	(63040),
	(63041),
	(63042),
	(63043),
	(63044),
	(63045),
	(63046),
	(63047),
	(63048),
	(63049),
	(63050),
	(63051),
	(63052),
	(63053),
	(63054),
	(63055),
	(63056),
	(63057),
	(63058),
	(63059),
	(63060),
	(63061),
	(63062),
	(63063),
	(63064),
	(63065),
	(63066),
	(63067),
	(63068),
	(63069),
	(63070),
	(63071),
	(63072),
	(63073),
	(63074),
	(63075),
	(63076),
	(63077),
	(63078),
	(63079),
	(63080),
	(63081),
	(63082),
	(63083),
	(63084),
	(63085),
	(63086),
	(63087),
	(63088),
	(63089),
	(63090),
	(63091),
	(63092),
	(63093),
	(63094),
	(63095),
	(63096),
	(63097),
	(63098),
	(63099),
	(63100),
	(63101),
	(63102),
	(63103),
	(63104),
	(63105),
	(63106),
	(63107),
	(63108),
	(63109),
	(63110),
	(63111),
	(63112),
	(63113),
	(63114),
	(63115),
	(63116),
	(63117),
	(63118),
	(63119),
	(63120),
	(63121),
	(63122),
	(63123),
	(63124),
	(63125),
	(63126),
	(63127),
	(63128),
	(63129),
	(63130),
	(63131),
	(63132),
	(63133),
	(63134),
	(63135),
	(63136),
	(63137),
	(63138),
	(63139),
	(63140),
	(63141),
	(63142),
	(63143),
	(63144),
	(63145),
	(63146),
	(63147),
	(63148),
	(63149),
	(63150),
	(63151),
	(63152),
	(63153),
	(63154),
	(63155),
	(63156),
	(63157),
	(63158),
	(63159),
	(63160),
	(63161),
	(63162),
	(63163),
	(63164),
	(63165),
	(63166),
	(63167),
	(63168),
	(63169),
	(63170),
	(63171),
	(63172),
	(63173),
	(63174),
	(63175),
	(63176),
	(63177),
	(63178),
	(63179),
	(63180),
	(63181),
	(63182),
	(63183),
	(63184),
	(63185),
	(63186),
	(63187),
	(63188),
	(63189),
	(63190),
	(63191),
	(63192),
	(63193),
	(63194),
	(63195),
	(63196),
	(63197),
	(63198),
	(63199),
	(63200),
	(63201),
	(63202),
	(63203),
	(63204),
	(63205),
	(63206),
	(63207),
	(63208),
	(63209),
	(63210),
	(63211),
	(63212),
	(63213),
	(63214),
	(63215),
	(63216),
	(63217),
	(63218),
	(63219),
	(63220),
	(63221),
	(63222),
	(63223),
	(63224),
	(63225),
	(63226),
	(63227),
	(63228),
	(63229),
	(63230),
	(63231),
	(63232),
	(63233),
	(63234),
	(63235),
	(63236),
	(63237),
	(63238),
	(63239),
	(63240),
	(63241),
	(63242),
	(63243),
	(63244),
	(63245),
	(63246),
	(63247),
	(63248),
	(63249),
	(63250),
	(63251),
	(63252),
	(63253),
	(63254),
	(63255),
	(63256),
	(63257),
	(63258),
	(63259),
	(63260),
	(63261),
	(63262),
	(63263),
	(63264),
	(63265),
	(63266),
	(63267),
	(63268),
	(63269),
	(63270),
	(63271),
	(63272),
	(63273),
	(63274),
	(63275),
	(63276),
	(63277),
	(63278),
	(63279),
	(63280),
	(63281),
	(63282),
	(63283),
	(63284),
	(63285),
	(63286),
	(63287),
	(63288),
	(63289),
	(63290),
	(63291),
	(63292),
	(63293),
	(63294),
	(63295),
	(63296),
	(63297),
	(63298),
	(63299),
	(63300),
	(63301),
	(63302),
	(63303),
	(63304),
	(63305),
	(63306),
	(63307),
	(63308),
	(63309),
	(63310),
	(63311),
	(63312),
	(63313),
	(63314),
	(63315),
	(63316),
	(63317),
	(63318),
	(63319),
	(63320),
	(63321),
	(63322),
	(63323),
	(63324),
	(63325),
	(63326),
	(63327),
	(63328),
	(63329),
	(63330),
	(63331),
	(63332),
	(63333),
	(63334),
	(63335),
	(63336),
	(63337),
	(63338),
	(63339),
	(63340),
	(63341),
	(63342),
	(63343),
	(63344),
	(63345),
	(63346),
	(63347),
	(63348),
	(63349),
	(63350),
	(63351),
	(63352),
	(63353),
	(63354),
	(63355),
	(63356),
	(63357),
	(63358),
	(63359),
	(63360),
	(63361),
	(63362),
	(63363),
	(63364),
	(63365),
	(63366),
	(63367),
	(63368),
	(63369),
	(63370),
	(63371),
	(63372),
	(63373),
	(63374),
	(63375),
	(63376),
	(63377),
	(63378),
	(63379),
	(63380),
	(63381),
	(63382),
	(63383),
	(63384),
	(63385),
	(63386),
	(63387),
	(63388),
	(63389),
	(63390),
	(63391),
	(63392),
	(63393),
	(63394),
	(63395),
	(63396),
	(63397),
	(63398),
	(63399),
	(63400),
	(63401),
	(63402),
	(63403),
	(63404),
	(63405),
	(63406),
	(63407),
	(63408),
	(63409),
	(63410),
	(63411),
	(63412),
	(63413),
	(63414),
	(63415),
	(63416),
	(63417),
	(63418),
	(63419),
	(63420),
	(63421),
	(63422),
	(63423),
	(63424),
	(63425),
	(63426),
	(63427),
	(63428),
	(63429),
	(63430),
	(63431),
	(63432),
	(63433),
	(63434),
	(63435),
	(63436),
	(63437),
	(63438),
	(63439),
	(63440),
	(63441),
	(63442),
	(63443),
	(63444),
	(63445),
	(63446),
	(63447),
	(63448),
	(63449),
	(63450),
	(63451),
	(63452),
	(63453),
	(63454),
	(63455),
	(63456),
	(63457),
	(63458),
	(63459),
	(63460),
	(63461),
	(63462),
	(63463),
	(63464),
	(63465),
	(63466),
	(63467),
	(63468),
	(63469),
	(63470),
	(63471),
	(63472),
	(63473),
	(63474),
	(63475),
	(63476),
	(63477),
	(63478),
	(63479),
	(63480),
	(63481),
	(63482),
	(63483),
	(63484),
	(63485),
	(63486),
	(63487),
	(63488),
	(63489),
	(63490),
	(63491),
	(63492),
	(63493),
	(63494),
	(63495),
	(63496),
	(63497),
	(63498),
	(63499),
	(63500),
	(63501),
	(63502),
	(63503),
	(63504),
	(63505),
	(63506),
	(63507),
	(63508),
	(63509),
	(63510),
	(63511),
	(63512),
	(63513),
	(63514),
	(63515),
	(63516),
	(63517),
	(63518),
	(63519),
	(63520),
	(63521),
	(63522),
	(63523),
	(63524),
	(63525),
	(63526),
	(63527),
	(63528),
	(63529),
	(63530),
	(63531),
	(63532),
	(63533),
	(63534),
	(63535),
	(63536),
	(63537),
	(63538),
	(63539),
	(63540),
	(63541),
	(63542),
	(63543),
	(63544),
	(63545),
	(63546),
	(63547),
	(63548),
	(63549),
	(63550),
	(63551),
	(63552),
	(63553),
	(63554),
	(63555),
	(63556),
	(63557),
	(63558),
	(63559),
	(63560),
	(63561),
	(63562),
	(63563),
	(63564),
	(63565),
	(63566),
	(63567),
	(63568),
	(63569),
	(63570),
	(63571),
	(63572),
	(63573),
	(63574),
	(63575),
	(63576),
	(63577),
	(63578),
	(63579),
	(63580),
	(63581),
	(63582),
	(63583),
	(63584),
	(63585),
	(63586),
	(63587),
	(63588),
	(63589),
	(63590),
	(63591),
	(63592),
	(63593),
	(63594),
	(63595),
	(63596),
	(63597),
	(63598),
	(63599),
	(63600),
	(63601),
	(63602),
	(63603),
	(63604),
	(63605),
	(63606),
	(63607),
	(63608),
	(63609),
	(63610),
	(63611),
	(63612),
	(63613),
	(63614),
	(63615),
	(63616),
	(63617),
	(63618),
	(63619),
	(63620),
	(63621),
	(63622),
	(63623),
	(63624),
	(63625),
	(63626),
	(63627),
	(63628),
	(63629),
	(63630),
	(63631),
	(63632),
	(63633),
	(63634),
	(63635),
	(63636),
	(63637),
	(63638),
	(63639),
	(63640),
	(63641),
	(63642),
	(63643),
	(63644),
	(63645),
	(63646),
	(63647),
	(63648),
	(63649),
	(63650),
	(63651),
	(63652),
	(63653),
	(63654),
	(63655),
	(63656),
	(63657),
	(63658),
	(63659),
	(63660),
	(63661),
	(63662),
	(63663),
	(63664),
	(63665),
	(63666),
	(63667),
	(63668),
	(63669),
	(63670),
	(63671),
	(63672),
	(63673),
	(63674),
	(63675),
	(63676),
	(63677),
	(63678),
	(63679),
	(63680),
	(63681),
	(63682),
	(63683),
	(63684),
	(63685),
	(63686),
	(63687),
	(63688),
	(63689),
	(63690),
	(63691),
	(63692),
	(63693),
	(63694),
	(63695),
	(63696),
	(63697),
	(63698),
	(63699),
	(63700),
	(63701),
	(63702),
	(63703),
	(63704),
	(63705),
	(63706),
	(63707),
	(63708),
	(63709),
	(63710),
	(63711),
	(63712),
	(63713),
	(63714),
	(63715),
	(63716),
	(63717),
	(63718),
	(63719),
	(63720),
	(63721),
	(63722),
	(63723),
	(63724),
	(63725),
	(63726),
	(63727),
	(63728),
	(63729),
	(63730),
	(63731),
	(63732),
	(63733),
	(63734),
	(63735),
	(63736),
	(63737),
	(63738),
	(63739),
	(63740),
	(63741),
	(63742),
	(63743),
	(63744),
	(63745),
	(63746),
	(63747),
	(63748),
	(63749),
	(63750),
	(63751),
	(63752),
	(63753),
	(63754),
	(63755),
	(63756),
	(63757),
	(63758),
	(63759),
	(63760),
	(63761),
	(63762),
	(63763),
	(63764),
	(63765),
	(63766),
	(63767),
	(63768),
	(63769),
	(63770),
	(63771),
	(63772),
	(63773),
	(63774),
	(63775),
	(63776),
	(63777),
	(63778),
	(63779),
	(63780),
	(63781),
	(63782),
	(63783),
	(63784),
	(63785),
	(63786),
	(63787),
	(63788),
	(63789),
	(63790),
	(63791),
	(63792),
	(63793),
	(63794),
	(63795),
	(63796),
	(63797),
	(63798),
	(63799),
	(63800),
	(63801),
	(63802),
	(63803),
	(63804),
	(63805),
	(63806),
	(63807),
	(63808),
	(63809),
	(63810),
	(63811),
	(63812),
	(63813),
	(63814),
	(63815),
	(63816),
	(63817),
	(63818),
	(63819),
	(63820),
	(63821),
	(63822),
	(63823),
	(63824),
	(63825),
	(63826),
	(63827),
	(63828),
	(63829),
	(63830),
	(63831),
	(63832),
	(63833),
	(63834),
	(63835),
	(63836),
	(63837),
	(63838),
	(63839),
	(63840),
	(63841),
	(63842),
	(63843),
	(63844),
	(63845),
	(63846),
	(63847),
	(63848),
	(63849),
	(63850),
	(63851),
	(63852),
	(63853),
	(63854),
	(63855),
	(63856),
	(63857),
	(63858),
	(63859),
	(63860),
	(63861),
	(63862),
	(63863),
	(63864),
	(63865),
	(63866),
	(63867),
	(63868),
	(63869),
	(63870),
	(63871),
	(63872),
	(63873),
	(63874),
	(63875),
	(63876),
	(63877),
	(63878),
	(63879),
	(63880),
	(63881),
	(63882),
	(63883),
	(63884),
	(63885),
	(63886),
	(63887),
	(63888),
	(63889),
	(63890),
	(63891),
	(63892),
	(63893),
	(63894),
	(63895),
	(63896),
	(63897),
	(63898),
	(63899),
	(63900),
	(63901),
	(63902),
	(63903),
	(63904),
	(63905),
	(63906),
	(63907),
	(63908),
	(63909),
	(63910),
	(63911),
	(63912),
	(63913),
	(63914),
	(63915),
	(63916),
	(63917),
	(63918),
	(63919),
	(63920),
	(63921),
	(63922),
	(63923),
	(63924),
	(63925),
	(63926),
	(63927),
	(63928),
	(63929),
	(63930),
	(63931),
	(63932),
	(63933),
	(63934),
	(63935),
	(63936),
	(63937),
	(63938),
	(63939),
	(63940),
	(63941),
	(63942),
	(63943),
	(63944),
	(63945),
	(63946),
	(63947),
	(63948),
	(63949),
	(63950),
	(63951),
	(63952),
	(63953),
	(63954),
	(63955),
	(63956),
	(63957),
	(63958),
	(63959),
	(63960),
	(63961),
	(63962),
	(63963),
	(63964),
	(63965),
	(63966),
	(63967),
	(63968),
	(63969),
	(63970),
	(63971),
	(63972),
	(63973),
	(63974),
	(63975),
	(63976),
	(63977),
	(63978),
	(63979),
	(63980),
	(63981),
	(63982),
	(63983),
	(63984),
	(63985),
	(63986),
	(63987),
	(63988),
	(63989),
	(63990),
	(63991),
	(63992),
	(63993),
	(63994),
	(63995),
	(63996),
	(63997),
	(63998),
	(63999),
	(64000),
	(64001),
	(64002),
	(64003),
	(64004),
	(64005),
	(64006),
	(64007),
	(64008),
	(64009),
	(64010),
	(64011),
	(64012),
	(64013),
	(64014),
	(64015),
	(64016),
	(64017),
	(64018),
	(64019),
	(64020),
	(64021),
	(64022),
	(64023),
	(64024),
	(64025),
	(64026),
	(64027),
	(64028),
	(64029),
	(64030),
	(64031),
	(64032),
	(64033),
	(64034),
	(64035),
	(64036),
	(64037),
	(64038),
	(64039),
	(64040),
	(64041),
	(64042),
	(64043),
	(64044),
	(64045),
	(64046),
	(64047),
	(64048),
	(64049),
	(64050),
	(64051),
	(64052),
	(64053),
	(64054),
	(64055),
	(64056),
	(64057),
	(64058),
	(64059),
	(64060),
	(64061),
	(64062),
	(64063),
	(64064),
	(64065),
	(64066),
	(64067),
	(64068),
	(64069),
	(64070),
	(64071),
	(64072),
	(64073),
	(64074),
	(64075),
	(64076),
	(64077),
	(64078),
	(64079),
	(64080),
	(64081),
	(64082),
	(64083),
	(64084),
	(64085),
	(64086),
	(64087),
	(64088),
	(64089),
	(64090),
	(64091),
	(64092),
	(64093),
	(64094),
	(64095),
	(64096),
	(64097),
	(64098),
	(64099),
	(64100),
	(64101),
	(64102),
	(64103),
	(64104),
	(64105),
	(64106),
	(64107),
	(64108),
	(64109),
	(64110),
	(64111),
	(64112),
	(64113),
	(64114),
	(64115),
	(64116),
	(64117),
	(64118),
	(64119),
	(64120),
	(64121),
	(64122),
	(64123),
	(64124),
	(64125),
	(64126),
	(64127),
	(64128),
	(64129),
	(64130),
	(64131),
	(64132),
	(64133),
	(64134),
	(64135),
	(64136),
	(64137),
	(64138),
	(64139),
	(64140),
	(64141),
	(64142),
	(64143),
	(64144),
	(64145),
	(64146),
	(64147),
	(64148),
	(64149),
	(64150),
	(64151),
	(64152),
	(64153),
	(64154),
	(64155),
	(64156),
	(64157),
	(64158),
	(64159),
	(64160),
	(64161),
	(64162),
	(64163),
	(64164),
	(64165),
	(64166),
	(64167),
	(64168),
	(64169),
	(64170),
	(64171),
	(64172),
	(64173),
	(64174),
	(64175),
	(64176),
	(64177),
	(64178),
	(64179),
	(64180),
	(64181),
	(64182),
	(64183),
	(64184),
	(64185),
	(64186),
	(64187),
	(64188),
	(64189),
	(64190),
	(64191),
	(64192),
	(64193),
	(64194),
	(64195),
	(64196),
	(64197),
	(64198),
	(64199),
	(64200),
	(64201),
	(64202),
	(64203),
	(64204),
	(64205),
	(64206),
	(64207),
	(64208),
	(64209),
	(64210),
	(64211),
	(64212),
	(64213),
	(64214),
	(64215),
	(64216),
	(64217),
	(64218),
	(64219),
	(64220),
	(64221),
	(64222),
	(64223),
	(64224),
	(64225),
	(64226),
	(64227),
	(64228),
	(64229),
	(64230),
	(64231),
	(64232),
	(64233),
	(64234),
	(64235),
	(64236),
	(64237),
	(64238),
	(64239),
	(64240),
	(64241),
	(64242),
	(64243),
	(64244),
	(64245),
	(64246),
	(64247),
	(64248),
	(64249),
	(64250),
	(64251),
	(64252),
	(64253),
	(64254),
	(64255),
	(64256),
	(64257),
	(64258),
	(64259),
	(64260),
	(64261),
	(64262),
	(64263),
	(64264),
	(64265),
	(64266),
	(64267),
	(64268),
	(64269),
	(64270),
	(64271),
	(64272),
	(64273),
	(64274),
	(64275),
	(64276),
	(64277),
	(64278),
	(64279),
	(64280),
	(64281),
	(64282),
	(64283),
	(64284),
	(64285),
	(64286),
	(64287),
	(64288),
	(64289),
	(64290),
	(64291),
	(64292),
	(64293),
	(64294),
	(64295),
	(64296),
	(64297),
	(64298),
	(64299),
	(64300),
	(64301),
	(64302),
	(64303),
	(64304),
	(64305),
	(64306),
	(64307),
	(64308),
	(64309),
	(64310),
	(64311),
	(64312),
	(64313),
	(64314),
	(64315),
	(64316),
	(64317),
	(64318),
	(64319),
	(64320),
	(64321),
	(64322),
	(64323),
	(64324),
	(64325),
	(64326),
	(64327),
	(64328),
	(64329),
	(64330),
	(64331),
	(64332),
	(64333),
	(64334),
	(64335),
	(64336),
	(64337),
	(64338),
	(64339),
	(64340),
	(64341),
	(64342),
	(64343),
	(64344),
	(64345),
	(64346),
	(64347),
	(64348),
	(64349),
	(64350),
	(64351),
	(64352),
	(64353),
	(64354),
	(64355),
	(64356),
	(64357),
	(64358),
	(64359),
	(64360),
	(64361),
	(64362),
	(64363),
	(64364),
	(64365),
	(64366),
	(64367),
	(64368),
	(64369),
	(64370),
	(64371),
	(64372),
	(64373),
	(64374),
	(64375),
	(64376),
	(64377),
	(64378),
	(64379),
	(64380),
	(64381),
	(64382),
	(64383),
	(64384),
	(64385),
	(64386),
	(64387),
	(64388),
	(64389),
	(64390),
	(64391),
	(64392),
	(64393),
	(64394),
	(64395),
	(64396),
	(64397),
	(64398),
	(64399),
	(64400),
	(64401),
	(64402),
	(64403),
	(64404),
	(64405),
	(64406),
	(64407),
	(64408),
	(64409),
	(64410),
	(64411),
	(64412),
	(64413),
	(64414),
	(64415),
	(64416),
	(64417),
	(64418),
	(64419),
	(64420),
	(64421),
	(64422),
	(64423),
	(64424),
	(64425),
	(64426),
	(64427),
	(64428),
	(64429),
	(64430),
	(64431),
	(64432),
	(64433),
	(64434),
	(64435),
	(64436),
	(64437),
	(64438),
	(64439),
	(64440),
	(64441),
	(64442),
	(64443),
	(64444),
	(64445),
	(64446),
	(64447),
	(64448),
	(64449),
	(64450),
	(64451),
	(64452),
	(64453),
	(64454),
	(64455),
	(64456),
	(64457),
	(64458),
	(64459),
	(64460),
	(64461),
	(64462),
	(64463),
	(64464),
	(64465),
	(64466),
	(64467),
	(64468),
	(64469),
	(64470),
	(64471),
	(64472),
	(64473),
	(64474),
	(64475),
	(64476),
	(64477),
	(64478),
	(64479),
	(64480),
	(64481),
	(64482),
	(64483),
	(64484),
	(64485),
	(64486),
	(64487),
	(64488),
	(64489),
	(64490),
	(64491),
	(64492),
	(64493),
	(64494),
	(64495),
	(64496),
	(64497),
	(64498),
	(64499),
	(64500),
	(64501),
	(64502),
	(64503),
	(64504),
	(64505),
	(64506),
	(64507),
	(64508),
	(64509),
	(64510),
	(64511),
	(64512),
	(64513),
	(64514),
	(64515),
	(64516),
	(64517),
	(64518),
	(64519),
	(64520),
	(64521),
	(64522),
	(64523),
	(64524),
	(64525),
	(64526),
	(64527),
	(64528),
	(64529),
	(64530),
	(64531),
	(64532),
	(64533),
	(64534),
	(64535),
	(64536),
	(64537),
	(64538),
	(64539),
	(64540),
	(64541),
	(64542),
	(64543),
	(64544),
	(64545),
	(64546),
	(64547),
	(64548),
	(64549),
	(64550),
	(64551),
	(64552),
	(64553),
	(64554),
	(64555),
	(64556),
	(64557),
	(64558),
	(64559),
	(64560),
	(64561),
	(64562),
	(64563),
	(64564),
	(64565),
	(64566),
	(64567),
	(64568),
	(64569),
	(64570),
	(64571),
	(64572),
	(64573),
	(64574),
	(64575),
	(64576),
	(64577),
	(64578),
	(64579),
	(64580),
	(64581),
	(64582),
	(64583),
	(64584),
	(64585),
	(64586),
	(64587),
	(64588),
	(64589),
	(64590),
	(64591),
	(64592),
	(64593),
	(64594),
	(64595),
	(64596),
	(64597),
	(64598),
	(64599),
	(64600),
	(64601),
	(64602),
	(64603),
	(64604),
	(64605),
	(64606),
	(64607),
	(64608),
	(64609),
	(64610),
	(64611),
	(64612),
	(64613),
	(64614),
	(64615),
	(64616),
	(64617),
	(64618),
	(64619),
	(64620),
	(64621),
	(64622),
	(64623),
	(64624),
	(64625),
	(64626),
	(64627),
	(64628),
	(64629),
	(64630),
	(64631),
	(64632),
	(64633),
	(64634),
	(64635),
	(64636),
	(64637),
	(64638),
	(64639),
	(64640),
	(64641),
	(64642),
	(64643),
	(64644),
	(64645),
	(64646),
	(64647),
	(64648),
	(64649),
	(64650),
	(64651),
	(64652),
	(64653),
	(64654),
	(64655),
	(64656),
	(64657),
	(64658),
	(64659),
	(64660),
	(64661),
	(64662),
	(64663),
	(64664),
	(64665),
	(64666),
	(64667),
	(64668),
	(64669),
	(64670),
	(64671),
	(64672),
	(64673),
	(64674),
	(64675),
	(64676),
	(64677),
	(64678),
	(64679),
	(64680),
	(64681),
	(64682),
	(64683),
	(64684),
	(64685),
	(64686),
	(64687),
	(64688),
	(64689),
	(64690),
	(64691),
	(64692),
	(64693),
	(64694),
	(64695),
	(64696),
	(64697),
	(64698),
	(64699),
	(64700),
	(64701),
	(64702),
	(64703),
	(64704),
	(64705),
	(64706),
	(64707),
	(64708),
	(64709),
	(64710),
	(64711),
	(64712),
	(64713),
	(64714),
	(64715),
	(64716),
	(64717),
	(64718),
	(64719),
	(64720),
	(64721),
	(64722),
	(64723),
	(64724),
	(64725),
	(64726),
	(64727),
	(64728),
	(64729),
	(64730),
	(64731),
	(64732),
	(64733),
	(64734),
	(64735),
	(64736),
	(64737),
	(64738),
	(64739),
	(64740),
	(64741),
	(64742),
	(64743),
	(64744),
	(64745),
	(64746),
	(64747),
	(64748),
	(64749),
	(64750),
	(64751),
	(64752),
	(64753),
	(64754),
	(64755),
	(64756),
	(64757),
	(64758),
	(64759),
	(64760),
	(64761),
	(64762),
	(64763),
	(64764),
	(64765),
	(64766),
	(64767),
	(64768),
	(64769),
	(64770),
	(64771),
	(64772),
	(64773),
	(64774),
	(64775),
	(64776),
	(64777),
	(64778),
	(64779),
	(64780),
	(64781),
	(64782),
	(64783),
	(64784),
	(64785),
	(64786),
	(64787),
	(64788),
	(64789),
	(64790),
	(64791),
	(64792),
	(64793),
	(64794),
	(64795),
	(64796),
	(64797),
	(64798),
	(64799),
	(64800),
	(64801),
	(64802),
	(64803),
	(64804),
	(64805),
	(64806),
	(64807),
	(64808),
	(64809),
	(64810),
	(64811),
	(64812),
	(64813),
	(64814),
	(64815),
	(64816),
	(64817),
	(64818),
	(64819),
	(64820),
	(64821),
	(64822),
	(64823),
	(64824),
	(64825),
	(64826),
	(64827),
	(64828),
	(64829),
	(64830),
	(64831),
	(64832),
	(64833),
	(64834),
	(64835),
	(64836),
	(64837),
	(64838),
	(64839),
	(64840),
	(64841),
	(64842),
	(64843),
	(64844),
	(64845),
	(64846),
	(64847),
	(64848),
	(64849),
	(64850),
	(64851),
	(64852),
	(64853),
	(64854),
	(64855),
	(64856),
	(64857),
	(64858),
	(64859),
	(64860),
	(64861),
	(64862),
	(64863),
	(64864),
	(64865),
	(64866),
	(64867),
	(64868),
	(64869),
	(64870),
	(64871),
	(64872),
	(64873),
	(64874),
	(64875),
	(64876),
	(64877),
	(64878),
	(64879),
	(64880),
	(64881),
	(64882),
	(64883),
	(64884),
	(64885),
	(64886),
	(64887),
	(64888),
	(64889),
	(64890),
	(64891),
	(64892),
	(64893),
	(64894),
	(64895),
	(64896),
	(64897),
	(64898),
	(64899),
	(64900),
	(64901),
	(64902),
	(64903),
	(64904),
	(64905),
	(64906),
	(64907),
	(64908),
	(64909),
	(64910),
	(64911),
	(64912),
	(64913),
	(64914),
	(64915),
	(64916),
	(64917),
	(64918),
	(64919),
	(64920),
	(64921),
	(64922),
	(64923),
	(64924),
	(64925),
	(64926),
	(64927),
	(64928),
	(64929),
	(64930),
	(64931),
	(64932),
	(64933),
	(64934),
	(64935),
	(64936),
	(64937),
	(64938),
	(64939),
	(64940),
	(64941),
	(64942),
	(64943),
	(64944),
	(64945),
	(64946),
	(64947),
	(64948),
	(64949),
	(64950),
	(64951),
	(64952),
	(64953),
	(64954),
	(64955),
	(64956),
	(64957),
	(64958),
	(64959),
	(64960),
	(64961),
	(64962),
	(64963),
	(64964),
	(64965),
	(64966),
	(64967),
	(64968),
	(64969),
	(64970),
	(64971),
	(64972),
	(64973),
	(64974),
	(64975),
	(64976),
	(64977),
	(64978),
	(64979),
	(64980),
	(64981),
	(64982),
	(64983),
	(64984),
	(64985),
	(64986),
	(64987),
	(64988),
	(64989),
	(64990),
	(64991),
	(64992),
	(64993),
	(64994),
	(64995),
	(64996),
	(64997),
	(64998),
	(64999),
	(65000),
	(65001),
	(65002),
	(65003),
	(65004),
	(65005),
	(65006),
	(65007),
	(65008),
	(65009),
	(65010),
	(65011),
	(65012),
	(65013),
	(65014),
	(65015),
	(65016),
	(65017),
	(65018),
	(65019),
	(65020),
	(65021),
	(65022),
	(65023),
	(65024),
	(65025),
	(65026),
	(65027),
	(65028),
	(65029),
	(65030),
	(65031),
	(65032),
	(65033),
	(65034),
	(65035),
	(65036),
	(65037),
	(65038),
	(65039),
	(65040),
	(65041),
	(65042),
	(65043),
	(65044),
	(65045),
	(65046),
	(65047),
	(65048),
	(65049),
	(65050),
	(65051),
	(65052),
	(65053),
	(65054),
	(65055),
	(65056),
	(65057),
	(65058),
	(65059),
	(65060),
	(65061),
	(65062),
	(65063),
	(65064),
	(65065),
	(65066),
	(65067),
	(65068),
	(65069),
	(65070),
	(65071),
	(65072),
	(65073),
	(65074),
	(65075),
	(65076),
	(65077),
	(65078),
	(65079),
	(65080),
	(65081),
	(65082),
	(65083),
	(65084),
	(65085),
	(65086),
	(65087),
	(65088),
	(65089),
	(65090),
	(65091),
	(65092),
	(65093),
	(65094),
	(65095),
	(65096),
	(65097),
	(65098),
	(65099),
	(65100),
	(65101),
	(65102),
	(65103),
	(65104),
	(65105),
	(65106),
	(65107),
	(65108),
	(65109),
	(65110),
	(65111),
	(65112),
	(65113),
	(65114),
	(65115),
	(65116),
	(65117),
	(65118),
	(65119),
	(65120),
	(65121),
	(65122),
	(65123),
	(65124),
	(65125),
	(65126),
	(65127),
	(65128),
	(65129),
	(65130),
	(65131),
	(65132),
	(65133),
	(65134),
	(65135),
	(65136),
	(65137),
	(65138),
	(65139),
	(65140),
	(65141),
	(65142),
	(65143),
	(65144),
	(65145),
	(65146),
	(65147),
	(65148),
	(65149),
	(65150),
	(65151),
	(65152),
	(65153),
	(65154),
	(65155),
	(65156),
	(65157),
	(65158),
	(65159),
	(65160),
	(65161),
	(65162),
	(65163),
	(65164),
	(65165),
	(65166),
	(65167),
	(65168),
	(65169),
	(65170),
	(65171),
	(65172),
	(65173),
	(65174),
	(65175),
	(65176),
	(65177),
	(65178),
	(65179),
	(65180),
	(65181),
	(65182),
	(65183),
	(65184),
	(65185),
	(65186),
	(65187),
	(65188),
	(65189),
	(65190),
	(65191),
	(65192),
	(65193),
	(65194),
	(65195),
	(65196),
	(65197),
	(65198),
	(65199),
	(65200),
	(65201),
	(65202),
	(65203),
	(65204),
	(65205),
	(65206),
	(65207),
	(65208),
	(65209),
	(65210),
	(65211),
	(65212),
	(65213),
	(65214),
	(65215),
	(65216),
	(65217),
	(65218),
	(65219),
	(65220),
	(65221),
	(65222),
	(65223),
	(65224),
	(65225),
	(65226),
	(65227),
	(65228),
	(65229),
	(65230),
	(65231),
	(65232),
	(65233),
	(65234),
	(65235),
	(65236),
	(65237),
	(65238),
	(65239),
	(65240),
	(65241),
	(65242),
	(65243),
	(65244),
	(65245),
	(65246),
	(65247),
	(65248),
	(65249),
	(65250),
	(65251),
	(65252),
	(65253),
	(65254),
	(65255),
	(65256),
	(65257),
	(65258),
	(65259),
	(65260),
	(65261),
	(65262),
	(65263),
	(65264),
	(65265),
	(65266),
	(65267),
	(65268),
	(65269),
	(65270),
	(65271),
	(65272),
	(65273),
	(65274),
	(65275),
	(65276),
	(65277),
	(65278),
	(65279),
	(65280),
	(65281),
	(65282),
	(65283),
	(65284),
	(65285),
	(65286),
	(65287),
	(65288),
	(65289),
	(65290),
	(65291),
	(65292),
	(65293),
	(65294),
	(65295),
	(65296),
	(65297),
	(65298),
	(65299),
	(65300),
	(65301),
	(65302),
	(65303),
	(65304),
	(65305),
	(65306),
	(65307),
	(65308),
	(65309),
	(65310),
	(65311),
	(65312),
	(65313),
	(65314),
	(65315),
	(65316),
	(65317),
	(65318),
	(65319),
	(65320),
	(65321),
	(65322),
	(65323),
	(65324),
	(65325),
	(65326),
	(65327),
	(65328),
	(65329),
	(65330),
	(65331),
	(65332),
	(65333),
	(65334),
	(65335),
	(65336),
	(65337),
	(65338),
	(65339),
	(65340),
	(65341),
	(65342),
	(65343),
	(65344),
	(65345),
	(65346),
	(65347),
	(65348),
	(65349),
	(65350),
	(65351),
	(65352),
	(65353),
	(65354),
	(65355),
	(65356),
	(65357),
	(65358),
	(65359),
	(65360),
	(65361),
	(65362),
	(65363),
	(65364),
	(65365),
	(65366),
	(65367),
	(65368),
	(65369),
	(65370),
	(65371),
	(65372),
	(65373),
	(65374),
	(65375),
	(65376),
	(65377),
	(65378),
	(65379),
	(65380),
	(65381),
	(65382),
	(65383),
	(65384),
	(65385),
	(65386),
	(65387),
	(65388),
	(65389),
	(65390),
	(65391),
	(65392),
	(65393),
	(65394),
	(65395),
	(65396),
	(65397),
	(65398),
	(65399),
	(65400),
	(65401),
	(65402),
	(65403),
	(65404),
	(65405),
	(65406),
	(65407),
	(65408),
	(65409),
	(65410),
	(65411),
	(65412),
	(65413),
	(65414),
	(65415),
	(65416),
	(65417),
	(65418),
	(65419),
	(65420),
	(65421),
	(65422),
	(65423),
	(65424),
	(65425),
	(65426),
	(65427),
	(65428),
	(65429),
	(65430),
	(65431),
	(65432),
	(65433),
	(65434),
	(65435),
	(65436),
	(65437),
	(65438),
	(65439),
	(65440),
	(65441),
	(65442),
	(65443),
	(65444),
	(65445),
	(65446),
	(65447),
	(65448),
	(65449),
	(65450),
	(65451),
	(65452),
	(65453),
	(65454),
	(65455),
	(65456),
	(65457),
	(65458),
	(65459),
	(65460),
	(65461),
	(65462),
	(65463),
	(65464),
	(65465),
	(65466),
	(65467),
	(65468),
	(65469),
	(65470),
	(65471),
	(65472),
	(65473),
	(65474),
	(65475),
	(65476),
	(65477),
	(65478),
	(65479),
	(65480),
	(65481),
	(65482),
	(65483),
	(65484),
	(65485),
	(65486),
	(65487),
	(65488),
	(65489),
	(65490),
	(65491),
	(65492),
	(65493),
	(65494),
	(65495),
	(65496),
	(65497),
	(65498),
	(65499),
	(65500),
	(65501),
	(65502),
	(65503),
	(65504),
	(65505),
	(65506),
	(65507),
	(65508),
	(65509),
	(65510),
	(65511),
	(65512),
	(65513),
	(65514),
	(65515),
	(65516),
	(65517),
	(65518),
	(65519),
	(65520),
	(65521),
	(65522),
	(65523),
	(65524),
	(65525),
	(65526),
	(65527),
	(65528),
	(65529),
	(65530),
	(65531),
	(65532),
	(65533),
	(65534),
	(65535),
	(65536),
	(65537),
	(65538),
	(65539),
	(65540),
	(65541),
	(65542),
	(65543),
	(65544),
	(65545),
	(65546),
	(65547),
	(65548),
	(65549),
	(65550),
	(65551),
	(65552),
	(65553),
	(65554),
	(65555),
	(65556),
	(65557),
	(65558),
	(65559),
	(65560),
	(65561),
	(65562),
	(65563),
	(65564),
	(65565),
	(65566),
	(65567),
	(65568),
	(65569),
	(65570),
	(65571),
	(65572),
	(65573),
	(65574),
	(65575),
	(65576),
	(65577),
	(65578),
	(65579),
	(65580),
	(65581),
	(65582),
	(65583),
	(65584),
	(65585),
	(65586),
	(65587),
	(65588),
	(65589),
	(65590),
	(65591),
	(65592),
	(65593),
	(65594),
	(65595),
	(65596),
	(65597),
	(65598),
	(65599),
	(65600),
	(65601),
	(65602),
	(65603),
	(65604),
	(65605),
	(65606),
	(65607),
	(65608),
	(65609),
	(65610),
	(65611),
	(65612),
	(65613),
	(65614),
	(65615),
	(65616),
	(65617),
	(65618),
	(65619),
	(65620),
	(65621),
	(65622),
	(65623),
	(65624),
	(65625),
	(65626),
	(65627),
	(65628),
	(65629),
	(65630),
	(65631),
	(65632),
	(65633),
	(65634),
	(65635),
	(65636),
	(65637),
	(65638),
	(65639),
	(65640),
	(65641),
	(65642),
	(65643),
	(65644),
	(65645),
	(65646),
	(65647),
	(65648),
	(65649),
	(65650),
	(65651),
	(65652),
	(65653),
	(65654),
	(65655),
	(65656),
	(65657),
	(65658),
	(65659),
	(65660),
	(65661),
	(65662),
	(65663),
	(65664),
	(65665),
	(65666),
	(65667),
	(65668),
	(65669),
	(65670),
	(65671),
	(65672),
	(65673),
	(65674),
	(65675),
	(65676),
	(65677),
	(65678),
	(65679),
	(65680),
	(65681),
	(65682),
	(65683),
	(65684),
	(65685),
	(65686),
	(65687),
	(65688),
	(65689),
	(65690),
	(65691),
	(65692),
	(65693),
	(65694),
	(65695),
	(65696),
	(65697),
	(65698),
	(65699),
	(65700),
	(65701),
	(65702),
	(65703),
	(65704),
	(65705),
	(65706),
	(65707),
	(65708),
	(65709),
	(65710),
	(65711),
	(65712),
	(65713),
	(65714),
	(65715),
	(65716),
	(65717),
	(65718),
	(65719),
	(65720),
	(65721),
	(65722),
	(65723),
	(65724),
	(65725),
	(65726),
	(65727),
	(65728),
	(65729),
	(65730),
	(65731),
	(65732),
	(65733),
	(65734),
	(65735),
	(65736),
	(65737),
	(65738),
	(65739),
	(65740),
	(65741),
	(65742),
	(65743),
	(65744),
	(65745),
	(65746),
	(65747),
	(65748),
	(65749),
	(65750),
	(65751),
	(65752),
	(65753),
	(65754),
	(65755),
	(65756),
	(65757),
	(65758),
	(65759),
	(65760),
	(65761),
	(65762),
	(65763),
	(65764),
	(65765),
	(65766),
	(65767),
	(65768),
	(65769),
	(65770),
	(65771),
	(65772),
	(65773),
	(65774),
	(65775),
	(65776),
	(65777),
	(65778),
	(65779),
	(65780),
	(65781),
	(65782),
	(65783),
	(65784),
	(65785),
	(65786),
	(65787),
	(65788),
	(65789),
	(65790),
	(65791),
	(65792),
	(65793),
	(65794),
	(65795),
	(65796),
	(65797),
	(65798),
	(65799),
	(65800),
	(65801),
	(65802),
	(65803),
	(65804),
	(65805),
	(65806),
	(65807),
	(65808),
	(65809),
	(65810),
	(65811),
	(65812),
	(65813),
	(65814),
	(65815),
	(65816),
	(65817),
	(65818),
	(65819),
	(65820),
	(65821),
	(65822),
	(65823),
	(65824),
	(65825),
	(65826),
	(65827),
	(65828),
	(65829),
	(65830),
	(65831),
	(65832),
	(65833),
	(65834),
	(65835),
	(65836),
	(65837),
	(65838),
	(65839),
	(65840),
	(65841),
	(65842),
	(65843),
	(65844),
	(65845),
	(65846),
	(65847),
	(65848),
	(65849),
	(65850),
	(65851),
	(65852),
	(65853),
	(65854),
	(65855),
	(65856),
	(65857),
	(65858),
	(65859),
	(65860),
	(65861),
	(65862),
	(65863),
	(65864),
	(65865),
	(65866),
	(65867),
	(65868),
	(65869),
	(65870),
	(65871),
	(65872),
	(65873),
	(65874),
	(65875),
	(65876),
	(65877),
	(65878),
	(65879),
	(65880),
	(65881),
	(65882),
	(65883),
	(65884),
	(65885),
	(65886),
	(65887),
	(65888),
	(65889),
	(65890),
	(65891),
	(65892),
	(65893),
	(65894),
	(65895),
	(65896),
	(65897),
	(65898),
	(65899),
	(65900),
	(65901),
	(65902),
	(65903),
	(65904),
	(65905),
	(65906),
	(65907),
	(65908),
	(65909),
	(65910),
	(65911),
	(65912),
	(65913),
	(65914),
	(65915),
	(65916),
	(65917),
	(65918),
	(65919),
	(65920),
	(65921),
	(65922),
	(65923),
	(65924),
	(65925),
	(65926),
	(65927),
	(65928),
	(65929),
	(65930),
	(65931),
	(65932),
	(65933),
	(65934),
	(65935),
	(65936),
	(65937),
	(65938),
	(65939),
	(65940),
	(65941),
	(65942),
	(65943),
	(65944),
	(65945),
	(65946),
	(65947),
	(65948),
	(65949),
	(65950),
	(65951),
	(65952),
	(65953),
	(65954),
	(65955),
	(65956),
	(65957),
	(65958),
	(65959),
	(65960),
	(65961),
	(65962),
	(65963),
	(65964),
	(65965),
	(65966),
	(65967),
	(65968),
	(65969),
	(65970),
	(65971),
	(65972),
	(65973),
	(65974),
	(65975),
	(65976),
	(65977),
	(65978),
	(65979),
	(65980),
	(65981),
	(65982),
	(65983),
	(65984),
	(65985),
	(65986),
	(65987),
	(65988),
	(65989),
	(65990),
	(65991),
	(65992),
	(65993),
	(65994),
	(65995),
	(65996),
	(65997),
	(65998),
	(65999),
	(66000),
	(66001),
	(66002),
	(66003),
	(66004),
	(66005),
	(66006),
	(66007),
	(66008),
	(66009),
	(66010),
	(66011),
	(66012),
	(66013),
	(66014),
	(66015),
	(66016),
	(66017),
	(66018),
	(66019),
	(66020),
	(66021),
	(66022),
	(66023),
	(66024),
	(66025),
	(66026),
	(66027),
	(66028),
	(66029),
	(66030),
	(66031),
	(66032),
	(66033),
	(66034),
	(66035),
	(66036),
	(66037),
	(66038),
	(66039),
	(66040),
	(66041),
	(66042),
	(66043),
	(66044),
	(66045),
	(66046),
	(66047),
	(66048),
	(66049),
	(66050),
	(66051),
	(66052),
	(66053),
	(66054),
	(66055),
	(66056),
	(66057),
	(66058),
	(66059),
	(66060),
	(66061),
	(66062),
	(66063),
	(66064),
	(66065),
	(66066),
	(66067),
	(66068),
	(66069),
	(66070),
	(66071),
	(66072),
	(66073),
	(66074),
	(66075),
	(66076),
	(66077),
	(66078),
	(66079),
	(66080),
	(66081),
	(66082),
	(66083),
	(66084),
	(66085),
	(66086),
	(66087),
	(66088),
	(66089),
	(66090),
	(66091),
	(66092),
	(66093),
	(66094),
	(66095),
	(66096),
	(66097),
	(66098),
	(66099),
	(66100),
	(66101),
	(66102),
	(66103),
	(66104),
	(66105),
	(66106),
	(66107),
	(66108),
	(66109),
	(66110),
	(66111),
	(66112),
	(66113),
	(66114),
	(66115),
	(66116),
	(66117),
	(66118),
	(66119),
	(66120),
	(66121),
	(66122),
	(66123),
	(66124),
	(66125),
	(66126),
	(66127),
	(66128),
	(66129),
	(66130),
	(66131),
	(66132),
	(66133),
	(66134),
	(66135),
	(66136),
	(66137),
	(66138),
	(66139),
	(66140),
	(66141),
	(66142),
	(66143),
	(66144),
	(66145),
	(66146),
	(66147),
	(66148),
	(66149),
	(66150),
	(66151),
	(66152),
	(66153),
	(66154),
	(66155),
	(66156),
	(66157),
	(66158),
	(66159),
	(66160),
	(66161),
	(66162),
	(66163),
	(66164),
	(66165),
	(66166),
	(66167),
	(66168),
	(66169),
	(66170),
	(66171),
	(66172),
	(66173),
	(66174),
	(66175),
	(66176),
	(66177),
	(66178),
	(66179),
	(66180),
	(66181),
	(66182),
	(66183),
	(66184),
	(66185),
	(66186),
	(66187),
	(66188),
	(66189),
	(66190),
	(66191),
	(66192),
	(66193),
	(66194),
	(66195),
	(66196),
	(66197),
	(66198),
	(66199),
	(66200),
	(66201),
	(66202),
	(66203),
	(66204),
	(66205),
	(66206),
	(66207),
	(66208),
	(66209),
	(66210),
	(66211),
	(66212),
	(66213),
	(66214),
	(66215),
	(66216),
	(66217),
	(66218),
	(66219),
	(66220),
	(66221),
	(66222),
	(66223),
	(66224),
	(66225),
	(66226),
	(66227),
	(66228),
	(66229),
	(66230),
	(66231),
	(66232),
	(66233),
	(66234),
	(66235),
	(66236),
	(66237),
	(66238),
	(66239),
	(66240),
	(66241),
	(66242),
	(66243),
	(66244),
	(66245),
	(66246),
	(66247),
	(66248),
	(66249),
	(66250),
	(66251),
	(66252),
	(66253),
	(66254),
	(66255),
	(66256),
	(66257),
	(66258),
	(66259),
	(66260),
	(66261),
	(66262),
	(66263),
	(66264),
	(66265),
	(66266),
	(66267),
	(66268),
	(66269),
	(66270),
	(66271),
	(66272),
	(66273),
	(66274),
	(66275),
	(66276),
	(66277),
	(66278),
	(66279),
	(66280),
	(66281),
	(66282),
	(66283),
	(66284),
	(66285),
	(66286),
	(66287),
	(66288),
	(66289),
	(66290),
	(66291),
	(66292),
	(66293),
	(66294),
	(66295),
	(66296),
	(66297),
	(66298),
	(66299),
	(66300),
	(66301),
	(66302),
	(66303),
	(66304),
	(66305),
	(66306),
	(66307),
	(66308),
	(66309),
	(66310),
	(66311),
	(66312),
	(66313),
	(66314),
	(66315),
	(66316),
	(66317),
	(66318),
	(66319),
	(66320),
	(66321),
	(66322),
	(66323),
	(66324),
	(66325),
	(66326),
	(66327),
	(66328),
	(66329),
	(66330),
	(66331),
	(66332),
	(66333),
	(66334),
	(66335),
	(66336),
	(66337),
	(66338),
	(66339),
	(66340),
	(66341),
	(66342),
	(66343),
	(66344),
	(66345),
	(66346),
	(66347),
	(66348),
	(66349),
	(66350),
	(66351),
	(66352),
	(66353),
	(66354),
	(66355),
	(66356),
	(66357),
	(66358),
	(66359),
	(66360),
	(66361),
	(66362),
	(66363),
	(66364),
	(66365),
	(66366),
	(66367),
	(66368),
	(66369),
	(66370),
	(66371),
	(66372),
	(66373),
	(66374),
	(66375),
	(66376),
	(66377),
	(66378),
	(66379),
	(66380),
	(66381),
	(66382),
	(66383),
	(66384),
	(66385),
	(66386),
	(66387),
	(66388),
	(66389),
	(66390),
	(66391),
	(66392),
	(66393),
	(66394),
	(66395),
	(66396),
	(66397),
	(66398),
	(66399),
	(66400),
	(66401),
	(66402),
	(66403),
	(66404),
	(66405),
	(66406),
	(66407),
	(66408),
	(66409),
	(66410),
	(66411),
	(66412),
	(66413),
	(66414),
	(66415),
	(66416),
	(66417),
	(66418),
	(66419),
	(66420),
	(66421),
	(66422),
	(66423),
	(66424),
	(66425),
	(66426),
	(66427),
	(66428),
	(66429),
	(66430),
	(66431),
	(66432),
	(66433),
	(66434),
	(66435),
	(66436),
	(66437),
	(66438),
	(66439),
	(66440),
	(66441),
	(66442),
	(66443),
	(66444),
	(66445),
	(66446),
	(66447),
	(66448),
	(66449),
	(66450),
	(66451),
	(66452),
	(66453),
	(66454),
	(66455),
	(66456),
	(66457),
	(66458),
	(66459),
	(66460),
	(66461),
	(66462),
	(66463),
	(66464),
	(66465),
	(66466),
	(66467),
	(66468),
	(66469),
	(66470),
	(66471),
	(66472),
	(66473),
	(66474),
	(66475),
	(66476),
	(66477),
	(66478),
	(66479),
	(66480),
	(66481),
	(66482),
	(66483),
	(66484),
	(66485),
	(66486),
	(66487),
	(66488),
	(66489),
	(66490),
	(66491),
	(66492),
	(66493),
	(66494),
	(66495),
	(66496),
	(66497),
	(66498),
	(66499),
	(66500),
	(66501),
	(66502),
	(66503),
	(66504),
	(66505),
	(66506),
	(66507),
	(66508),
	(66509),
	(66510),
	(66511),
	(66512),
	(66513),
	(66514),
	(66515),
	(66516),
	(66517),
	(66518),
	(66519),
	(66520),
	(66521),
	(66522),
	(66523),
	(66524),
	(66525),
	(66526),
	(66527),
	(66528),
	(66529),
	(66530),
	(66531),
	(66532),
	(66533),
	(66534),
	(66535),
	(66536),
	(66537),
	(66538),
	(66539),
	(66540),
	(66541),
	(66542),
	(66543),
	(66544),
	(66545),
	(66546),
	(66547),
	(66548),
	(66549),
	(66550),
	(66551),
	(66552),
	(66553),
	(66554),
	(66555),
	(66556),
	(66557),
	(66558),
	(66559),
	(66560),
	(66561),
	(66562),
	(66563),
	(66564),
	(66565),
	(66566),
	(66567),
	(66568),
	(66569),
	(66570),
	(66571),
	(66572),
	(66573),
	(66574),
	(66575),
	(66576),
	(66577),
	(66578),
	(66579),
	(66580),
	(66581),
	(66582),
	(66583),
	(66584),
	(66585),
	(66586),
	(66587),
	(66588),
	(66589),
	(66590),
	(66591),
	(66592),
	(66593),
	(66594),
	(66595),
	(66596),
	(66597),
	(66598),
	(66599),
	(66600),
	(66601),
	(66602),
	(66603),
	(66604),
	(66605),
	(66606),
	(66607),
	(66608),
	(66609),
	(66610),
	(66611),
	(66612),
	(66613),
	(66614),
	(66615),
	(66616),
	(66617),
	(66618),
	(66619),
	(66620),
	(66621),
	(66622),
	(66623),
	(66624),
	(66625),
	(66626),
	(66627),
	(66628),
	(66629),
	(66630),
	(66631),
	(66632),
	(66633),
	(66634),
	(66635),
	(66636),
	(66637),
	(66638),
	(66639),
	(66640),
	(66641),
	(66642),
	(66643),
	(66644),
	(66645),
	(66646),
	(66647),
	(66648),
	(66649),
	(66650),
	(66651),
	(66652),
	(66653),
	(66654),
	(66655),
	(66656),
	(66657),
	(66658),
	(66659),
	(66660),
	(66661),
	(66662),
	(66663),
	(66664),
	(66665),
	(66666),
	(66667),
	(66668),
	(66669),
	(66670),
	(66671),
	(66672),
	(66673),
	(66674),
	(66675),
	(66676),
	(66677),
	(66678),
	(66679),
	(66680),
	(66681),
	(66682),
	(66683),
	(66684),
	(66685),
	(66686),
	(66687),
	(66688),
	(66689),
	(66690),
	(66691),
	(66692),
	(66693),
	(66694),
	(66695),
	(66696),
	(66697),
	(66698),
	(66699),
	(66700),
	(66701),
	(66702),
	(66703),
	(66704),
	(66705),
	(66706),
	(66707),
	(66708),
	(66709),
	(66710),
	(66711),
	(66712),
	(66713),
	(66714),
	(66715),
	(66716),
	(66717),
	(66718),
	(66719),
	(66720),
	(66721),
	(66722),
	(66723),
	(66724),
	(66725),
	(66726),
	(66727),
	(66728),
	(66729),
	(66730),
	(66731),
	(66732),
	(66733),
	(66734),
	(66735),
	(66736),
	(66737),
	(66738),
	(66739),
	(66740),
	(66741),
	(66742),
	(66743),
	(66744),
	(66745),
	(66746),
	(66747),
	(66748),
	(66749),
	(66750),
	(66751),
	(66752),
	(66753),
	(66754),
	(66755),
	(66756),
	(66757),
	(66758),
	(66759),
	(66760),
	(66761),
	(66762),
	(66763),
	(66764),
	(66765),
	(66766),
	(66767),
	(66768),
	(66769),
	(66770),
	(66771),
	(66772),
	(66773),
	(66774),
	(66775),
	(66776),
	(66777),
	(66778),
	(66779),
	(66780),
	(66781),
	(66782),
	(66783),
	(66784),
	(66785),
	(66786),
	(66787),
	(66788),
	(66789),
	(66790),
	(66791),
	(66792),
	(66793),
	(66794),
	(66795),
	(66796),
	(66797),
	(66798),
	(66799),
	(66800),
	(66801),
	(66802),
	(66803),
	(66804),
	(66805),
	(66806),
	(66807),
	(66808),
	(66809),
	(66810),
	(66811),
	(66812),
	(66813),
	(66814),
	(66815),
	(66816),
	(66817),
	(66818),
	(66819),
	(66820),
	(66821),
	(66822),
	(66823),
	(66824),
	(66825),
	(66826),
	(66827),
	(66828),
	(66829),
	(66830),
	(66831),
	(66832),
	(66833),
	(66834),
	(66835),
	(66836),
	(66837),
	(66838),
	(66839),
	(66840),
	(66841),
	(66842),
	(66843),
	(66844),
	(66845),
	(66846),
	(66847),
	(66848),
	(66849),
	(66850),
	(66851),
	(66852),
	(66853),
	(66854),
	(66855),
	(66856),
	(66857),
	(66858),
	(66859),
	(66860),
	(66861),
	(66862),
	(66863),
	(66864),
	(66865),
	(66866),
	(66867),
	(66868),
	(66869),
	(66870),
	(66871),
	(66872),
	(66873),
	(66874),
	(66875),
	(66876),
	(66877),
	(66878),
	(66879),
	(66880),
	(66881),
	(66882),
	(66883),
	(66884),
	(66885),
	(66886),
	(66887),
	(66888),
	(66889),
	(66890),
	(66891),
	(66892),
	(66893),
	(66894),
	(66895),
	(66896),
	(66897),
	(66898),
	(66899),
	(66900),
	(66901),
	(66902),
	(66903),
	(66904),
	(66905),
	(66906),
	(66907),
	(66908),
	(66909),
	(66910),
	(66911),
	(66912),
	(66913),
	(66914),
	(66915),
	(66916),
	(66917),
	(66918),
	(66919),
	(66920),
	(66921),
	(66922),
	(66923),
	(66924),
	(66925),
	(66926),
	(66927),
	(66928),
	(66929),
	(66930),
	(66931),
	(66932),
	(66933),
	(66934),
	(66935),
	(66936),
	(66937),
	(66938),
	(66939),
	(66940),
	(66941),
	(66942),
	(66943),
	(66944),
	(66945),
	(66946),
	(66947),
	(66948),
	(66949),
	(66950),
	(66951),
	(66952),
	(66953),
	(66954),
	(66955),
	(66956),
	(66957),
	(66958),
	(66959),
	(66960),
	(66961),
	(66962),
	(66963),
	(66964),
	(66965),
	(66966),
	(66967),
	(66968),
	(66969),
	(66970),
	(66971),
	(66972),
	(66973),
	(66974),
	(66975),
	(66976),
	(66977),
	(66978),
	(66979),
	(66980),
	(66981),
	(66982),
	(66983),
	(66984),
	(66985),
	(66986),
	(66987),
	(66988),
	(66989),
	(66990),
	(66991),
	(66992),
	(66993),
	(66994),
	(66995),
	(66996),
	(66997),
	(66998),
	(66999),
	(67000),
	(67001),
	(67002),
	(67003),
	(67004),
	(67005),
	(67006),
	(67007),
	(67008),
	(67009),
	(67010),
	(67011),
	(67012),
	(67013),
	(67014),
	(67015),
	(67016),
	(67017),
	(67018),
	(67019),
	(67020),
	(67021),
	(67022),
	(67023),
	(67024),
	(67025),
	(67026),
	(67027),
	(67028),
	(67029),
	(67030),
	(67031),
	(67032),
	(67033),
	(67034),
	(67035),
	(67036),
	(67037),
	(67038),
	(67039),
	(67040),
	(67041),
	(67042),
	(67043),
	(67044),
	(67045),
	(67046),
	(67047),
	(67048),
	(67049),
	(67050),
	(67051),
	(67052),
	(67053),
	(67054),
	(67055),
	(67056),
	(67057),
	(67058),
	(67059),
	(67060),
	(67061),
	(67062),
	(67063),
	(67064),
	(67065),
	(67066),
	(67067),
	(67068),
	(67069),
	(67070),
	(67071),
	(67072),
	(67073),
	(67074),
	(67075),
	(67076),
	(67077),
	(67078),
	(67079),
	(67080),
	(67081),
	(67082),
	(67083),
	(67084),
	(67085),
	(67086),
	(67087),
	(67088),
	(67089),
	(67090),
	(67091),
	(67092),
	(67093),
	(67094),
	(67095),
	(67096),
	(67097),
	(67098),
	(67099),
	(67100),
	(67101),
	(67102),
	(67103),
	(67104),
	(67105),
	(67106),
	(67107),
	(67108),
	(67109),
	(67110),
	(67111),
	(67112),
	(67113),
	(67114),
	(67115),
	(67116),
	(67117),
	(67118),
	(67119),
	(67120),
	(67121),
	(67122),
	(67123),
	(67124),
	(67125),
	(67126),
	(67127),
	(67128),
	(67129),
	(67130),
	(67131),
	(67132),
	(67133),
	(67134),
	(67135),
	(67136),
	(67137),
	(67138),
	(67139),
	(67140),
	(67141),
	(67142),
	(67143),
	(67144),
	(67145),
	(67146),
	(67147),
	(67148),
	(67149),
	(67150),
	(67151),
	(67152),
	(67153),
	(67154),
	(67155),
	(67156),
	(67157),
	(67158),
	(67159),
	(67160),
	(67161),
	(67162),
	(67163),
	(67164),
	(67165),
	(67166),
	(67167),
	(67168),
	(67169),
	(67170),
	(67171),
	(67172),
	(67173),
	(67174),
	(67175),
	(67176),
	(67177),
	(67178),
	(67179),
	(67180),
	(67181),
	(67182),
	(67183),
	(67184),
	(67185),
	(67186),
	(67187),
	(67188),
	(67189),
	(67190),
	(67191),
	(67192),
	(67193),
	(67194),
	(67195),
	(67196),
	(67197),
	(67198),
	(67199),
	(67200),
	(67201),
	(67202),
	(67203),
	(67204),
	(67205),
	(67206),
	(67207),
	(67208),
	(67209),
	(67210),
	(67211),
	(67212),
	(67213),
	(67214),
	(67215),
	(67216),
	(67217),
	(67218),
	(67219),
	(67220),
	(67221),
	(67222),
	(67223),
	(67224),
	(67225),
	(67226),
	(67227),
	(67228),
	(67229),
	(67230),
	(67231),
	(67232),
	(67233),
	(67234),
	(67235),
	(67236),
	(67237),
	(67238),
	(67239),
	(67240),
	(67241),
	(67242),
	(67243),
	(67244),
	(67245),
	(67246),
	(67247),
	(67248),
	(67249),
	(67250),
	(67251),
	(67252),
	(67253),
	(67254),
	(67255),
	(67256),
	(67257),
	(67258),
	(67259),
	(67260),
	(67261),
	(67262),
	(67263),
	(67264),
	(67265),
	(67266),
	(67267),
	(67268),
	(67269),
	(67270),
	(67271),
	(67272),
	(67273),
	(67274),
	(67275),
	(67276),
	(67277),
	(67278),
	(67279),
	(67280),
	(67281),
	(67282),
	(67283),
	(67284),
	(67285),
	(67286),
	(67287),
	(67288),
	(67289),
	(67290),
	(67291),
	(67292),
	(67293),
	(67294),
	(67295),
	(67296),
	(67297),
	(67298),
	(67299),
	(67300),
	(67301),
	(67302),
	(67303),
	(67304),
	(67305),
	(67306),
	(67307),
	(67308),
	(67309),
	(67310),
	(67311),
	(67312),
	(67313),
	(67314),
	(67315),
	(67316),
	(67317),
	(67318),
	(67319),
	(67320),
	(67321),
	(67322),
	(67323),
	(67324),
	(67325),
	(67326),
	(67327),
	(67328),
	(67329),
	(67330),
	(67331),
	(67332),
	(67333),
	(67334),
	(67335),
	(67336),
	(67337),
	(67338),
	(67339),
	(67340),
	(67341),
	(67342),
	(67343),
	(67344),
	(67345),
	(67346),
	(67347),
	(67348),
	(67349),
	(67350),
	(67351),
	(67352),
	(67353),
	(67354),
	(67355),
	(67356),
	(67357),
	(67358),
	(67359),
	(67360),
	(67361),
	(67362),
	(67363),
	(67364),
	(67365),
	(67366),
	(67367),
	(67368),
	(67369),
	(67370),
	(67371),
	(67372),
	(67373),
	(67374),
	(67375),
	(67376),
	(67377),
	(67378),
	(67379),
	(67380),
	(67381),
	(67382),
	(67383),
	(67384),
	(67385),
	(67386),
	(67387),
	(67388),
	(67389),
	(67390),
	(67391),
	(67392),
	(67393),
	(67394),
	(67395),
	(67396),
	(67397),
	(67398),
	(67399),
	(67400),
	(67401),
	(67402),
	(67403),
	(67404),
	(67405),
	(67406),
	(67407),
	(67408),
	(67409),
	(67410),
	(67411),
	(67412),
	(67413),
	(67414),
	(67415),
	(67416),
	(67417),
	(67418),
	(67419),
	(67420),
	(67421),
	(67422),
	(67423),
	(67424),
	(67425),
	(67426),
	(67427),
	(67428),
	(67429),
	(67430),
	(67431),
	(67432),
	(67433),
	(67434),
	(67435),
	(67436),
	(67437),
	(67438),
	(67439),
	(67440),
	(67441),
	(67442),
	(67443),
	(67444),
	(67445),
	(67446),
	(67447),
	(67448),
	(67449),
	(67450),
	(67451),
	(67452),
	(67453),
	(67454),
	(67455),
	(67456),
	(67457),
	(67458),
	(67459),
	(67460),
	(67461),
	(67462),
	(67463),
	(67464),
	(67465),
	(67466),
	(67467),
	(67468),
	(67469),
	(67470),
	(67471),
	(67472),
	(67473),
	(67474),
	(67475),
	(67476),
	(67477),
	(67478),
	(67479),
	(67480),
	(67481),
	(67482),
	(67483),
	(67484),
	(67485),
	(67486),
	(67487),
	(67488),
	(67489),
	(67490),
	(67491),
	(67492),
	(67493),
	(67494),
	(67495),
	(67496),
	(67497),
	(67498),
	(67499),
	(67500),
	(67501),
	(67502),
	(67503),
	(67504),
	(67505),
	(67506),
	(67507),
	(67508),
	(67509),
	(67510),
	(67511),
	(67512),
	(67513),
	(67514),
	(67515),
	(67516),
	(67517),
	(67518),
	(67519),
	(67520),
	(67521),
	(67522),
	(67523),
	(67524),
	(67525),
	(67526),
	(67527),
	(67528),
	(67529),
	(67530),
	(67531),
	(67532),
	(67533),
	(67534),
	(67535),
	(67536),
	(67537),
	(67538),
	(67539),
	(67540),
	(67541),
	(67542),
	(67543),
	(67544),
	(67545),
	(67546),
	(67547),
	(67548),
	(67549),
	(67550),
	(67551),
	(67552),
	(67553),
	(67554),
	(67555),
	(67556),
	(67557),
	(67558),
	(67559),
	(67560),
	(67561),
	(67562),
	(67563),
	(67564),
	(67565),
	(67566),
	(67567),
	(67568),
	(67569),
	(67570),
	(67571),
	(67572),
	(67573),
	(67574),
	(67575),
	(67576),
	(67577),
	(67578),
	(67579),
	(67580),
	(67581),
	(67582),
	(67583),
	(67584),
	(67585),
	(67586),
	(67587),
	(67588),
	(67589),
	(67590),
	(67591),
	(67592),
	(67593),
	(67594),
	(67595),
	(67596),
	(67597),
	(67598),
	(67599),
	(67600),
	(67601),
	(67602),
	(67603),
	(67604),
	(67605),
	(67606),
	(67607),
	(67608),
	(67609),
	(67610),
	(67611),
	(67612),
	(67613),
	(67614),
	(67615),
	(67616),
	(67617),
	(67618),
	(67619),
	(67620),
	(67621),
	(67622),
	(67623),
	(67624),
	(67625),
	(67626),
	(67627),
	(67628),
	(67629),
	(67630),
	(67631),
	(67632),
	(67633),
	(67634),
	(67635),
	(67636),
	(67637),
	(67638),
	(67639),
	(67640),
	(67641),
	(67642),
	(67643),
	(67644),
	(67645),
	(67646),
	(67647),
	(67648),
	(67649),
	(67650),
	(67651),
	(67652),
	(67653),
	(67654),
	(67655),
	(67656),
	(67657),
	(67658),
	(67659),
	(67660),
	(67661),
	(67662),
	(67663),
	(67664),
	(67665),
	(67666),
	(67667),
	(67668),
	(67669),
	(67670),
	(67671),
	(67672),
	(67673),
	(67674),
	(67675),
	(67676),
	(67677),
	(67678),
	(67679),
	(67680),
	(67681),
	(67682),
	(67683),
	(67684),
	(67685),
	(67686),
	(67687),
	(67688),
	(67689),
	(67690),
	(67691),
	(67692),
	(67693),
	(67694),
	(67695),
	(67696),
	(67697),
	(67698),
	(67699),
	(67700),
	(67701),
	(67702),
	(67703),
	(67704),
	(67705),
	(67706),
	(67707),
	(67708),
	(67709),
	(67710),
	(67711),
	(67712),
	(67713),
	(67714),
	(67715),
	(67716),
	(67717),
	(67718),
	(67719),
	(67720),
	(67721),
	(67722),
	(67723),
	(67724),
	(67725),
	(67726),
	(67727),
	(67728),
	(67729),
	(67730),
	(67731),
	(67732),
	(67733),
	(67734),
	(67735),
	(67736),
	(67737),
	(67738),
	(67739),
	(67740),
	(67741),
	(67742),
	(67743),
	(67744),
	(67745),
	(67746),
	(67747),
	(67748),
	(67749),
	(67750),
	(67751),
	(67752),
	(67753),
	(67754),
	(67755),
	(67756),
	(67757),
	(67758),
	(67759),
	(67760),
	(67761),
	(67762),
	(67763),
	(67764),
	(67765),
	(67766),
	(67767),
	(67768),
	(67769),
	(67770),
	(67771),
	(67772),
	(67773),
	(67774),
	(67775),
	(67776),
	(67777),
	(67778),
	(67779),
	(67780),
	(67781),
	(67782),
	(67783),
	(67784),
	(67785),
	(67786),
	(67787),
	(67788),
	(67789),
	(67790),
	(67791),
	(67792),
	(67793),
	(67794),
	(67795),
	(67796),
	(67797),
	(67798),
	(67799),
	(67800),
	(67801),
	(67802),
	(67803),
	(67804),
	(67805),
	(67806),
	(67807),
	(67808),
	(67809),
	(67810),
	(67811),
	(67812),
	(67813),
	(67814),
	(67815),
	(67816),
	(67817),
	(67818),
	(67819),
	(67820),
	(67821),
	(67822),
	(67823),
	(67824),
	(67825),
	(67826),
	(67827),
	(67828),
	(67829),
	(67830),
	(67831),
	(67832),
	(67833),
	(67834),
	(67835),
	(67836),
	(67837),
	(67838),
	(67839),
	(67840),
	(67841),
	(67842),
	(67843),
	(67844),
	(67845),
	(67846),
	(67847),
	(67848),
	(67849),
	(67850),
	(67851),
	(67852),
	(67853),
	(67854),
	(67855),
	(67856),
	(67857),
	(67858),
	(67859),
	(67860),
	(67861),
	(67862),
	(67863),
	(67864),
	(67865),
	(67866),
	(67867),
	(67868),
	(67869),
	(67870),
	(67871),
	(67872),
	(67873),
	(67874),
	(67875),
	(67876),
	(67877),
	(67878),
	(67879),
	(67880),
	(67881),
	(67882),
	(67883),
	(67884),
	(67885),
	(67886),
	(67887),
	(67888),
	(67889),
	(67890),
	(67891),
	(67892),
	(67893),
	(67894),
	(67895),
	(67896),
	(67897),
	(67898),
	(67899),
	(67900),
	(67901),
	(67902),
	(67903),
	(67904),
	(67905),
	(67906),
	(67907),
	(67908),
	(67909),
	(67910),
	(67911),
	(67912),
	(67913),
	(67914),
	(67915),
	(67916),
	(67917),
	(67918),
	(67919),
	(67920),
	(67921),
	(67922),
	(67923),
	(67924),
	(67925),
	(67926),
	(67927),
	(67928),
	(67929),
	(67930),
	(67931),
	(67932),
	(67933),
	(67934),
	(67935),
	(67936),
	(67937),
	(67938),
	(67939),
	(67940),
	(67941),
	(67942),
	(67943),
	(67944),
	(67945),
	(67946),
	(67947),
	(67948),
	(67949),
	(67950),
	(67951),
	(67952),
	(67953),
	(67954),
	(67955),
	(67956),
	(67957),
	(67958),
	(67959),
	(67960),
	(67961),
	(67962),
	(67963),
	(67964),
	(67965),
	(67966),
	(67967),
	(67968),
	(67969),
	(67970),
	(67971),
	(67972),
	(67973),
	(67974),
	(67975),
	(67976),
	(67977),
	(67978),
	(67979),
	(67980),
	(67981),
	(67982),
	(67983),
	(67984),
	(67985),
	(67986),
	(67987),
	(67988),
	(67989),
	(67990),
	(67991),
	(67992),
	(67993),
	(67994),
	(67995),
	(67996),
	(67997),
	(67998),
	(67999),
	(68000),
	(68001),
	(68002),
	(68003),
	(68004),
	(68005),
	(68006),
	(68007),
	(68008),
	(68009),
	(68010),
	(68011),
	(68012),
	(68013),
	(68014),
	(68015),
	(68016),
	(68017),
	(68018),
	(68019),
	(68020),
	(68021),
	(68022),
	(68023),
	(68024),
	(68025),
	(68026),
	(68027),
	(68028),
	(68029),
	(68030),
	(68031),
	(68032),
	(68033),
	(68034),
	(68035),
	(68036),
	(68037),
	(68038),
	(68039),
	(68040),
	(68041),
	(68042),
	(68043),
	(68044),
	(68045),
	(68046),
	(68047),
	(68048),
	(68049),
	(68050),
	(68051),
	(68052),
	(68053),
	(68054),
	(68055),
	(68056),
	(68057),
	(68058),
	(68059),
	(68060),
	(68061),
	(68062),
	(68063),
	(68064),
	(68065),
	(68066),
	(68067),
	(68068),
	(68069),
	(68070),
	(68071),
	(68072),
	(68073),
	(68074),
	(68075),
	(68076),
	(68077),
	(68078),
	(68079),
	(68080),
	(68081),
	(68082),
	(68083),
	(68084),
	(68085),
	(68086),
	(68087),
	(68088),
	(68089),
	(68090),
	(68091),
	(68092),
	(68093),
	(68094),
	(68095),
	(68096),
	(68097),
	(68098),
	(68099),
	(68100),
	(68101),
	(68102),
	(68103),
	(68104),
	(68105),
	(68106),
	(68107),
	(68108),
	(68109),
	(68110),
	(68111),
	(68112),
	(68113),
	(68114),
	(68115),
	(68116),
	(68117),
	(68118),
	(68119),
	(68120),
	(68121),
	(68122),
	(68123),
	(68124),
	(68125),
	(68126),
	(68127),
	(68128),
	(68129),
	(68130),
	(68131),
	(68132),
	(68133),
	(68134),
	(68135),
	(68136),
	(68137),
	(68138),
	(68139),
	(68140),
	(68141),
	(68142),
	(68143),
	(68144),
	(68145),
	(68146),
	(68147),
	(68148),
	(68149),
	(68150),
	(68151),
	(68152),
	(68153),
	(68154),
	(68155),
	(68156),
	(68157),
	(68158),
	(68159),
	(68160),
	(68161),
	(68162),
	(68163),
	(68164),
	(68165),
	(68166),
	(68167),
	(68168),
	(68169),
	(68170),
	(68171),
	(68172),
	(68173),
	(68174),
	(68175),
	(68176),
	(68177),
	(68178),
	(68179),
	(68180),
	(68181),
	(68182),
	(68183),
	(68184),
	(68185),
	(68186),
	(68187),
	(68188),
	(68189),
	(68190),
	(68191),
	(68192),
	(68193),
	(68194),
	(68195),
	(68196),
	(68197),
	(68198),
	(68199),
	(68200),
	(68201),
	(68202),
	(68203),
	(68204),
	(68205),
	(68206),
	(68207),
	(68208),
	(68209),
	(68210),
	(68211),
	(68212),
	(68213),
	(68214),
	(68215),
	(68216),
	(68217),
	(68218),
	(68219),
	(68220),
	(68221),
	(68222),
	(68223),
	(68224),
	(68225),
	(68226),
	(68227),
	(68228),
	(68229),
	(68230),
	(68231),
	(68232),
	(68233),
	(68234),
	(68235),
	(68236),
	(68237),
	(68238),
	(68239),
	(68240),
	(68241),
	(68242),
	(68243),
	(68244),
	(68245),
	(68246),
	(68247),
	(68248),
	(68249),
	(68250),
	(68251),
	(68252),
	(68253),
	(68254),
	(68255),
	(68256),
	(68257),
	(68258),
	(68259),
	(68260),
	(68261),
	(68262),
	(68263),
	(68264),
	(68265),
	(68266),
	(68267),
	(68268),
	(68269),
	(68270),
	(68271),
	(68272),
	(68273),
	(68274),
	(68275),
	(68276),
	(68277),
	(68278),
	(68279),
	(68280),
	(68281),
	(68282),
	(68283),
	(68284),
	(68285),
	(68286),
	(68287),
	(68288),
	(68289),
	(68290),
	(68291),
	(68292),
	(68293),
	(68294),
	(68295),
	(68296),
	(68297),
	(68298),
	(68299),
	(68300),
	(68301),
	(68302),
	(68303),
	(68304),
	(68305),
	(68306),
	(68307),
	(68308),
	(68309),
	(68310),
	(68311),
	(68312),
	(68313),
	(68314),
	(68315),
	(68316),
	(68317),
	(68318),
	(68319),
	(68320),
	(68321),
	(68322),
	(68323),
	(68324),
	(68325),
	(68326),
	(68327),
	(68328),
	(68329),
	(68330),
	(68331),
	(68332),
	(68333),
	(68334),
	(68335),
	(68336),
	(68337),
	(68338),
	(68339),
	(68340),
	(68341),
	(68342),
	(68343),
	(68344),
	(68345),
	(68346),
	(68347),
	(68348),
	(68349),
	(68350),
	(68351),
	(68352),
	(68353),
	(68354),
	(68355),
	(68356),
	(68357),
	(68358),
	(68359),
	(68360),
	(68361),
	(68362),
	(68363),
	(68364),
	(68365),
	(68366),
	(68367),
	(68368),
	(68369),
	(68370),
	(68371),
	(68372),
	(68373),
	(68374),
	(68375),
	(68376),
	(68377),
	(68378),
	(68379),
	(68380),
	(68381),
	(68382),
	(68383),
	(68384),
	(68385),
	(68386),
	(68387),
	(68388),
	(68389),
	(68390),
	(68391),
	(68392),
	(68393),
	(68394),
	(68395),
	(68396),
	(68397),
	(68398),
	(68399),
	(68400),
	(68401),
	(68402),
	(68403),
	(68404),
	(68405),
	(68406),
	(68407),
	(68408),
	(68409),
	(68410),
	(68411),
	(68412),
	(68413),
	(68414),
	(68415),
	(68416),
	(68417),
	(68418),
	(68419),
	(68420),
	(68421),
	(68422),
	(68423),
	(68424),
	(68425),
	(68426),
	(68427),
	(68428),
	(68429),
	(68430),
	(68431),
	(68432),
	(68433),
	(68434),
	(68435),
	(68436),
	(68437),
	(68438),
	(68439),
	(68440),
	(68441),
	(68442),
	(68443),
	(68444),
	(68445),
	(68446),
	(68447),
	(68448),
	(68449),
	(68450),
	(68451),
	(68452),
	(68453),
	(68454),
	(68455),
	(68456),
	(68457),
	(68458),
	(68459),
	(68460),
	(68461),
	(68462),
	(68463),
	(68464),
	(68465),
	(68466),
	(68467),
	(68468),
	(68469),
	(68470),
	(68471),
	(68472),
	(68473),
	(68474),
	(68475),
	(68476),
	(68477),
	(68478),
	(68479),
	(68480),
	(68481),
	(68482),
	(68483),
	(68484),
	(68485),
	(68486),
	(68487),
	(68488),
	(68489),
	(68490),
	(68491),
	(68492),
	(68493),
	(68494),
	(68495),
	(68496),
	(68497),
	(68498),
	(68499),
	(68500),
	(68501),
	(68502),
	(68503),
	(68504),
	(68505),
	(68506),
	(68507),
	(68508),
	(68509),
	(68510),
	(68511),
	(68512),
	(68513),
	(68514),
	(68515),
	(68516),
	(68517),
	(68518),
	(68519),
	(68520),
	(68521),
	(68522),
	(68523),
	(68524),
	(68525),
	(68526),
	(68527),
	(68528),
	(68529),
	(68530),
	(68531),
	(68532),
	(68533),
	(68534),
	(68535),
	(68536),
	(68537),
	(68538),
	(68539),
	(68540),
	(68541),
	(68542),
	(68543),
	(68544),
	(68545),
	(68546),
	(68547),
	(68548),
	(68549),
	(68550),
	(68551),
	(68552),
	(68553),
	(68554),
	(68555),
	(68556),
	(68557),
	(68558),
	(68559),
	(68560),
	(68561),
	(68562),
	(68563),
	(68564),
	(68565),
	(68566),
	(68567),
	(68568),
	(68569),
	(68570),
	(68571),
	(68572),
	(68573),
	(68574),
	(68575),
	(68576),
	(68577),
	(68578),
	(68579),
	(68580),
	(68581),
	(68582),
	(68583),
	(68584),
	(68585),
	(68586),
	(68587),
	(68588),
	(68589),
	(68590),
	(68591),
	(68592),
	(68593),
	(68594),
	(68595),
	(68596),
	(68597),
	(68598),
	(68599),
	(68600),
	(68601),
	(68602),
	(68603),
	(68604),
	(68605),
	(68606),
	(68607),
	(68608),
	(68609),
	(68610),
	(68611),
	(68612),
	(68613),
	(68614),
	(68615),
	(68616),
	(68617),
	(68618),
	(68619),
	(68620),
	(68621),
	(68622),
	(68623),
	(68624),
	(68625),
	(68626),
	(68627),
	(68628),
	(68629),
	(68630),
	(68631),
	(68632),
	(68633),
	(68634),
	(68635),
	(68636),
	(68637),
	(68638),
	(68639),
	(68640),
	(68641),
	(68642),
	(68643),
	(68644),
	(68645),
	(68646),
	(68647),
	(68648),
	(68649),
	(68650),
	(68651),
	(68652),
	(68653),
	(68654),
	(68655),
	(68656),
	(68657),
	(68658),
	(68659),
	(68660),
	(68661),
	(68662),
	(68663),
	(68664),
	(68665),
	(68666),
	(68667),
	(68668),
	(68669),
	(68670),
	(68671),
	(68672),
	(68673),
	(68674),
	(68675),
	(68676),
	(68677),
	(68678),
	(68679),
	(68680),
	(68681),
	(68682),
	(68683),
	(68684),
	(68685),
	(68686),
	(68687),
	(68688),
	(68689),
	(68690),
	(68691),
	(68692),
	(68693),
	(68694),
	(68695),
	(68696),
	(68697),
	(68698),
	(68699),
	(68700),
	(68701),
	(68702),
	(68703),
	(68704),
	(68705),
	(68706),
	(68707),
	(68708),
	(68709),
	(68710),
	(68711),
	(68712),
	(68713),
	(68714),
	(68715),
	(68716),
	(68717),
	(68718),
	(68719),
	(68720),
	(68721),
	(68722),
	(68723),
	(68724),
	(68725),
	(68726),
	(68727),
	(68728),
	(68729),
	(68730),
	(68731),
	(68732),
	(68733),
	(68734),
	(68735),
	(68736),
	(68737),
	(68738),
	(68739),
	(68740),
	(68741),
	(68742),
	(68743),
	(68744),
	(68745),
	(68746),
	(68747),
	(68748),
	(68749),
	(68750),
	(68751),
	(68752),
	(68753),
	(68754),
	(68755),
	(68756),
	(68757),
	(68758),
	(68759),
	(68760),
	(68761),
	(68762),
	(68763),
	(68764),
	(68765),
	(68766),
	(68767),
	(68768),
	(68769),
	(68770),
	(68771),
	(68772),
	(68773),
	(68774),
	(68775),
	(68776),
	(68777),
	(68778),
	(68779),
	(68780),
	(68781),
	(68782),
	(68783),
	(68784),
	(68785),
	(68786),
	(68787),
	(68788),
	(68789),
	(68790),
	(68791),
	(68792),
	(68793),
	(68794),
	(68795),
	(68796),
	(68797),
	(68798),
	(68799),
	(68800),
	(68801),
	(68802),
	(68803),
	(68804),
	(68805),
	(68806),
	(68807),
	(68808),
	(68809),
	(68810),
	(68811),
	(68812),
	(68813),
	(68814),
	(68815),
	(68816),
	(68817),
	(68818),
	(68819),
	(68820),
	(68821),
	(68822),
	(68823),
	(68824),
	(68825),
	(68826),
	(68827),
	(68828),
	(68829),
	(68830),
	(68831),
	(68832),
	(68833),
	(68834),
	(68835),
	(68836),
	(68837),
	(68838),
	(68839),
	(68840),
	(68841),
	(68842),
	(68843),
	(68844),
	(68845),
	(68846),
	(68847),
	(68848),
	(68849),
	(68850),
	(68851),
	(68852),
	(68853),
	(68854),
	(68855),
	(68856),
	(68857),
	(68858),
	(68859),
	(68860),
	(68861),
	(68862),
	(68863),
	(68864),
	(68865),
	(68866),
	(68867),
	(68868),
	(68869),
	(68870),
	(68871),
	(68872),
	(68873),
	(68874),
	(68875),
	(68876),
	(68877),
	(68878),
	(68879),
	(68880),
	(68881),
	(68882),
	(68883),
	(68884),
	(68885),
	(68886),
	(68887),
	(68888),
	(68889),
	(68890),
	(68891),
	(68892),
	(68893),
	(68894),
	(68895),
	(68896),
	(68897),
	(68898),
	(68899),
	(68900),
	(68901),
	(68902),
	(68903),
	(68904),
	(68905),
	(68906),
	(68907),
	(68908),
	(68909),
	(68910),
	(68911),
	(68912),
	(68913),
	(68914),
	(68915),
	(68916),
	(68917),
	(68918),
	(68919),
	(68920),
	(68921),
	(68922),
	(68923),
	(68924),
	(68925),
	(68926),
	(68927),
	(68928),
	(68929),
	(68930),
	(68931),
	(68932),
	(68933),
	(68934),
	(68935),
	(68936),
	(68937),
	(68938),
	(68939),
	(68940),
	(68941),
	(68942),
	(68943),
	(68944),
	(68945),
	(68946),
	(68947),
	(68948),
	(68949),
	(68950),
	(68951),
	(68952),
	(68953),
	(68954),
	(68955),
	(68956),
	(68957),
	(68958),
	(68959),
	(68960),
	(68961),
	(68962),
	(68963),
	(68964),
	(68965),
	(68966),
	(68967),
	(68968),
	(68969),
	(68970),
	(68971),
	(68972),
	(68973),
	(68974),
	(68975),
	(68976),
	(68977),
	(68978),
	(68979),
	(68980),
	(68981),
	(68982),
	(68983),
	(68984),
	(68985),
	(68986),
	(68987),
	(68988),
	(68989),
	(68990),
	(68991),
	(68992),
	(68993),
	(68994),
	(68995),
	(68996),
	(68997),
	(68998),
	(68999),
	(69000),
	(69001),
	(69002),
	(69003),
	(69004),
	(69005),
	(69006),
	(69007),
	(69008),
	(69009),
	(69010),
	(69011),
	(69012),
	(69013),
	(69014),
	(69015),
	(69016),
	(69017),
	(69018),
	(69019),
	(69020),
	(69021),
	(69022),
	(69023),
	(69024),
	(69025),
	(69026),
	(69027),
	(69028),
	(69029),
	(69030),
	(69031),
	(69032),
	(69033),
	(69034),
	(69035),
	(69036),
	(69037),
	(69038),
	(69039),
	(69040),
	(69041),
	(69042),
	(69043),
	(69044),
	(69045),
	(69046),
	(69047),
	(69048),
	(69049),
	(69050),
	(69051),
	(69052),
	(69053),
	(69054),
	(69055),
	(69056),
	(69057),
	(69058),
	(69059),
	(69060),
	(69061),
	(69062),
	(69063),
	(69064),
	(69065),
	(69066),
	(69067),
	(69068),
	(69069),
	(69070),
	(69071),
	(69072),
	(69073),
	(69074),
	(69075),
	(69076),
	(69077),
	(69078),
	(69079),
	(69080),
	(69081),
	(69082),
	(69083),
	(69084),
	(69085),
	(69086),
	(69087),
	(69088),
	(69089),
	(69090),
	(69091),
	(69092),
	(69093),
	(69094),
	(69095),
	(69096),
	(69097),
	(69098),
	(69099),
	(69100),
	(69101),
	(69102),
	(69103),
	(69104),
	(69105),
	(69106),
	(69107),
	(69108),
	(69109),
	(69110),
	(69111),
	(69112),
	(69113),
	(69114),
	(69115),
	(69116),
	(69117),
	(69118),
	(69119),
	(69120),
	(69121),
	(69122),
	(69123),
	(69124),
	(69125),
	(69126),
	(69127),
	(69128),
	(69129),
	(69130),
	(69131),
	(69132),
	(69133),
	(69134),
	(69135),
	(69136),
	(69137),
	(69138),
	(69139),
	(69140),
	(69141),
	(69142),
	(69143),
	(69144),
	(69145),
	(69146),
	(69147),
	(69148),
	(69149),
	(69150),
	(69151),
	(69152),
	(69153),
	(69154),
	(69155),
	(69156),
	(69157),
	(69158),
	(69159),
	(69160),
	(69161),
	(69162),
	(69163),
	(69164),
	(69165),
	(69166),
	(69167),
	(69168),
	(69169),
	(69170),
	(69171),
	(69172),
	(69173),
	(69174),
	(69175),
	(69176),
	(69177),
	(69178),
	(69179),
	(69180),
	(69181),
	(69182),
	(69183),
	(69184),
	(69185),
	(69186),
	(69187),
	(69188),
	(69189),
	(69190),
	(69191),
	(69192),
	(69193),
	(69194),
	(69195),
	(69196),
	(69197),
	(69198),
	(69199),
	(69200),
	(69201),
	(69202),
	(69203),
	(69204),
	(69205),
	(69206),
	(69207),
	(69208),
	(69209),
	(69210),
	(69211),
	(69212),
	(69213),
	(69214),
	(69215),
	(69216),
	(69217),
	(69218),
	(69219),
	(69220),
	(69221),
	(69222),
	(69223),
	(69224),
	(69225),
	(69226),
	(69227),
	(69228),
	(69229),
	(69230),
	(69231),
	(69232),
	(69233),
	(69234),
	(69235),
	(69236),
	(69237),
	(69238),
	(69239),
	(69240),
	(69241),
	(69242),
	(69243),
	(69244),
	(69245),
	(69246),
	(69247),
	(69248),
	(69249),
	(69250),
	(69251),
	(69252),
	(69253),
	(69254),
	(69255),
	(69256),
	(69257),
	(69258),
	(69259),
	(69260),
	(69261),
	(69262),
	(69263),
	(69264),
	(69265),
	(69266),
	(69267),
	(69268),
	(69269),
	(69270),
	(69271),
	(69272),
	(69273),
	(69274),
	(69275),
	(69276),
	(69277),
	(69278),
	(69279),
	(69280),
	(69281),
	(69282),
	(69283),
	(69284),
	(69285),
	(69286),
	(69287),
	(69288),
	(69289),
	(69290),
	(69291),
	(69292),
	(69293),
	(69294),
	(69295),
	(69296),
	(69297),
	(69298),
	(69299),
	(69300),
	(69301),
	(69302),
	(69303),
	(69304),
	(69305),
	(69306),
	(69307),
	(69308),
	(69309),
	(69310),
	(69311),
	(69312),
	(69313),
	(69314),
	(69315),
	(69316),
	(69317),
	(69318),
	(69319),
	(69320),
	(69321),
	(69322),
	(69323),
	(69324),
	(69325),
	(69326),
	(69327),
	(69328),
	(69329),
	(69330),
	(69331),
	(69332),
	(69333),
	(69334),
	(69335),
	(69336),
	(69337),
	(69338),
	(69339),
	(69340),
	(69341),
	(69342),
	(69343),
	(69344),
	(69345),
	(69346),
	(69347),
	(69348),
	(69349),
	(69350),
	(69351),
	(69352),
	(69353),
	(69354),
	(69355),
	(69356),
	(69357),
	(69358),
	(69359),
	(69360),
	(69361),
	(69362),
	(69363),
	(69364),
	(69365),
	(69366),
	(69367),
	(69368),
	(69369),
	(69370),
	(69371),
	(69372),
	(69373),
	(69374),
	(69375),
	(69376),
	(69377),
	(69378),
	(69379),
	(69380),
	(69381),
	(69382),
	(69383),
	(69384),
	(69385),
	(69386),
	(69387),
	(69388),
	(69389),
	(69390),
	(69391),
	(69392),
	(69393),
	(69394),
	(69395),
	(69396),
	(69397),
	(69398),
	(69399),
	(69400),
	(69401),
	(69402),
	(69403),
	(69404),
	(69405),
	(69406),
	(69407),
	(69408),
	(69409),
	(69410),
	(69411),
	(69412),
	(69413),
	(69414),
	(69415),
	(69416),
	(69417),
	(69418),
	(69419),
	(69420),
	(69421),
	(69422),
	(69423),
	(69424),
	(69425),
	(69426),
	(69427),
	(69428),
	(69429),
	(69430),
	(69431),
	(69432),
	(69433),
	(69434),
	(69435),
	(69436),
	(69437),
	(69438),
	(69439),
	(69440),
	(69441),
	(69442),
	(69443),
	(69444),
	(69445),
	(69446),
	(69447),
	(69448),
	(69449),
	(69450),
	(69451),
	(69452),
	(69453),
	(69454),
	(69455),
	(69456),
	(69457),
	(69458),
	(69459),
	(69460),
	(69461),
	(69462),
	(69463),
	(69464),
	(69465),
	(69466),
	(69467),
	(69468),
	(69469),
	(69470),
	(69471),
	(69472),
	(69473),
	(69474),
	(69475),
	(69476),
	(69477),
	(69478),
	(69479),
	(69480),
	(69481),
	(69482),
	(69483),
	(69484),
	(69485),
	(69486),
	(69487),
	(69488),
	(69489),
	(69490),
	(69491),
	(69492),
	(69493),
	(69494),
	(69495),
	(69496),
	(69497),
	(69498),
	(69499),
	(69500),
	(69501),
	(69502),
	(69503),
	(69504),
	(69505),
	(69506),
	(69507),
	(69508),
	(69509),
	(69510),
	(69511),
	(69512),
	(69513),
	(69514),
	(69515),
	(69516),
	(69517),
	(69518),
	(69519),
	(69520),
	(69521),
	(69522),
	(69523),
	(69524),
	(69525),
	(69526),
	(69527),
	(69528),
	(69529),
	(69530),
	(69531),
	(69532),
	(69533),
	(69534),
	(69535),
	(69536),
	(69537),
	(69538),
	(69539),
	(69540),
	(69541),
	(69542),
	(69543),
	(69544),
	(69545),
	(69546),
	(69547),
	(69548),
	(69549),
	(69550),
	(69551),
	(69552),
	(69553),
	(69554),
	(69555),
	(69556),
	(69557),
	(69558),
	(69559),
	(69560),
	(69561),
	(69562),
	(69563),
	(69564),
	(69565),
	(69566),
	(69567),
	(69568),
	(69569),
	(69570),
	(69571),
	(69572),
	(69573),
	(69574),
	(69575),
	(69576),
	(69577),
	(69578),
	(69579),
	(69580),
	(69581),
	(69582),
	(69583),
	(69584),
	(69585),
	(69586),
	(69587),
	(69588),
	(69589),
	(69590),
	(69591),
	(69592),
	(69593),
	(69594),
	(69595),
	(69596),
	(69597),
	(69598),
	(69599),
	(69600),
	(69601),
	(69602),
	(69603),
	(69604),
	(69605),
	(69606),
	(69607),
	(69608),
	(69609),
	(69610),
	(69611),
	(69612),
	(69613),
	(69614),
	(69615),
	(69616),
	(69617),
	(69618),
	(69619),
	(69620),
	(69621),
	(69622),
	(69623),
	(69624),
	(69625),
	(69626),
	(69627),
	(69628),
	(69629),
	(69630),
	(69631),
	(69632),
	(69633),
	(69634),
	(69635),
	(69636),
	(69637),
	(69638),
	(69639),
	(69640),
	(69641),
	(69642),
	(69643),
	(69644),
	(69645),
	(69646),
	(69647),
	(69648),
	(69649),
	(69650),
	(69651),
	(69652),
	(69653),
	(69654),
	(69655),
	(69656),
	(69657),
	(69658),
	(69659),
	(69660),
	(69661),
	(69662),
	(69663),
	(69664),
	(69665),
	(69666),
	(69667),
	(69668),
	(69669),
	(69670),
	(69671),
	(69672),
	(69673),
	(69674),
	(69675),
	(69676),
	(69677),
	(69678),
	(69679),
	(69680),
	(69681),
	(69682),
	(69683),
	(69684),
	(69685),
	(69686),
	(69687),
	(69688),
	(69689),
	(69690),
	(69691),
	(69692),
	(69693),
	(69694),
	(69695),
	(69696),
	(69697),
	(69698),
	(69699),
	(69700),
	(69701),
	(69702),
	(69703),
	(69704),
	(69705),
	(69706),
	(69707),
	(69708),
	(69709),
	(69710),
	(69711),
	(69712),
	(69713),
	(69714),
	(69715),
	(69716),
	(69717),
	(69718),
	(69719),
	(69720),
	(69721),
	(69722),
	(69723),
	(69724),
	(69725),
	(69726),
	(69727),
	(69728),
	(69729),
	(69730),
	(69731),
	(69732),
	(69733),
	(69734),
	(69735),
	(69736),
	(69737),
	(69738),
	(69739),
	(69740),
	(69741),
	(69742),
	(69743),
	(69744),
	(69745),
	(69746),
	(69747),
	(69748),
	(69749),
	(69750),
	(69751),
	(69752),
	(69753),
	(69754),
	(69755),
	(69756),
	(69757),
	(69758),
	(69759),
	(69760),
	(69761),
	(69762),
	(69763),
	(69764),
	(69765),
	(69766),
	(69767),
	(69768),
	(69769),
	(69770),
	(69771),
	(69772),
	(69773),
	(69774),
	(69775),
	(69776),
	(69777),
	(69778),
	(69779),
	(69780),
	(69781),
	(69782),
	(69783),
	(69784),
	(69785),
	(69786),
	(69787),
	(69788),
	(69789),
	(69790),
	(69791),
	(69792),
	(69793),
	(69794),
	(69795),
	(69796),
	(69797),
	(69798),
	(69799),
	(69800),
	(69801),
	(69802),
	(69803),
	(69804),
	(69805),
	(69806),
	(69807),
	(69808),
	(69809),
	(69810),
	(69811),
	(69812),
	(69813),
	(69814),
	(69815),
	(69816),
	(69817),
	(69818),
	(69819),
	(69820),
	(69821),
	(69822),
	(69823),
	(69824),
	(69825),
	(69826),
	(69827),
	(69828),
	(69829),
	(69830),
	(69831),
	(69832),
	(69833),
	(69834),
	(69835),
	(69836),
	(69837),
	(69838),
	(69839),
	(69840),
	(69841),
	(69842),
	(69843),
	(69844),
	(69845),
	(69846),
	(69847),
	(69848),
	(69849),
	(69850),
	(69851),
	(69852),
	(69853),
	(69854),
	(69855),
	(69856),
	(69857),
	(69858),
	(69859),
	(69860),
	(69861),
	(69862),
	(69863),
	(69864),
	(69865),
	(69866),
	(69867),
	(69868),
	(69869),
	(69870),
	(69871),
	(69872),
	(69873),
	(69874),
	(69875),
	(69876),
	(69877),
	(69878),
	(69879),
	(69880),
	(69881),
	(69882),
	(69883),
	(69884),
	(69885),
	(69886),
	(69887),
	(69888),
	(69889),
	(69890),
	(69891),
	(69892),
	(69893),
	(69894),
	(69895),
	(69896),
	(69897),
	(69898),
	(69899),
	(69900),
	(69901),
	(69902),
	(69903),
	(69904),
	(69905),
	(69906),
	(69907),
	(69908),
	(69909),
	(69910),
	(69911),
	(69912),
	(69913),
	(69914),
	(69915),
	(69916),
	(69917),
	(69918),
	(69919),
	(69920),
	(69921),
	(69922),
	(69923),
	(69924),
	(69925),
	(69926),
	(69927),
	(69928),
	(69929),
	(69930),
	(69931),
	(69932),
	(69933),
	(69934),
	(69935),
	(69936),
	(69937),
	(69938),
	(69939),
	(69940),
	(69941),
	(69942),
	(69943),
	(69944),
	(69945),
	(69946),
	(69947),
	(69948),
	(69949),
	(69950),
	(69951),
	(69952),
	(69953),
	(69954),
	(69955),
	(69956),
	(69957),
	(69958),
	(69959),
	(69960),
	(69961),
	(69962),
	(69963),
	(69964),
	(69965),
	(69966),
	(69967),
	(69968),
	(69969),
	(69970),
	(69971),
	(69972),
	(69973),
	(69974),
	(69975),
	(69976),
	(69977),
	(69978),
	(69979),
	(69980),
	(69981),
	(69982),
	(69983),
	(69984),
	(69985),
	(69986),
	(69987),
	(69988),
	(69989),
	(69990),
	(69991),
	(69992),
	(69993),
	(69994),
	(69995),
	(69996),
	(69997),
	(69998),
	(69999),
	(70000),
	(70001),
	(70002),
	(70003),
	(70004),
	(70005),
	(70006),
	(70007),
	(70008),
	(70009),
	(70010),
	(70011),
	(70012),
	(70013),
	(70014),
	(70015),
	(70016),
	(70017),
	(70018),
	(70019),
	(70020),
	(70021),
	(70022),
	(70023),
	(70024),
	(70025),
	(70026),
	(70027),
	(70028),
	(70029),
	(70030),
	(70031),
	(70032),
	(70033),
	(70034),
	(70035),
	(70036),
	(70037),
	(70038),
	(70039),
	(70040),
	(70041),
	(70042),
	(70043),
	(70044),
	(70045),
	(70046),
	(70047),
	(70048),
	(70049),
	(70050),
	(70051),
	(70052),
	(70053),
	(70054),
	(70055),
	(70056),
	(70057),
	(70058),
	(70059),
	(70060),
	(70061),
	(70062),
	(70063),
	(70064),
	(70065),
	(70066),
	(70067),
	(70068),
	(70069),
	(70070),
	(70071),
	(70072),
	(70073),
	(70074),
	(70075),
	(70076),
	(70077),
	(70078),
	(70079),
	(70080),
	(70081),
	(70082),
	(70083),
	(70084),
	(70085),
	(70086),
	(70087),
	(70088),
	(70089),
	(70090),
	(70091),
	(70092),
	(70093),
	(70094),
	(70095),
	(70096),
	(70097),
	(70098),
	(70099),
	(70100),
	(70101),
	(70102),
	(70103),
	(70104),
	(70105),
	(70106),
	(70107),
	(70108),
	(70109),
	(70110),
	(70111),
	(70112),
	(70113),
	(70114),
	(70115),
	(70116),
	(70117),
	(70118),
	(70119),
	(70120),
	(70121),
	(70122),
	(70123),
	(70124),
	(70125),
	(70126),
	(70127),
	(70128),
	(70129),
	(70130),
	(70131),
	(70132),
	(70133),
	(70134),
	(70135),
	(70136),
	(70137),
	(70138),
	(70139),
	(70140),
	(70141),
	(70142),
	(70143),
	(70144),
	(70145),
	(70146),
	(70147),
	(70148),
	(70149),
	(70150),
	(70151),
	(70152),
	(70153),
	(70154),
	(70155),
	(70156),
	(70157),
	(70158),
	(70159),
	(70160),
	(70161),
	(70162),
	(70163),
	(70164),
	(70165),
	(70166),
	(70167),
	(70168),
	(70169),
	(70170),
	(70171),
	(70172),
	(70173),
	(70174),
	(70175),
	(70176),
	(70177),
	(70178),
	(70179),
	(70180),
	(70181),
	(70182),
	(70183),
	(70184),
	(70185),
	(70186),
	(70187),
	(70188),
	(70189),
	(70190),
	(70191),
	(70192),
	(70193),
	(70194),
	(70195),
	(70196),
	(70197),
	(70198),
	(70199),
	(70200),
	(70201),
	(70202),
	(70203),
	(70204),
	(70205),
	(70206),
	(70207),
	(70208),
	(70209),
	(70210),
	(70211),
	(70212),
	(70213),
	(70214),
	(70215),
	(70216),
	(70217),
	(70218),
	(70219),
	(70220),
	(70221),
	(70222),
	(70223),
	(70224),
	(70225),
	(70226),
	(70227),
	(70228),
	(70229),
	(70230),
	(70231),
	(70232),
	(70233),
	(70234),
	(70235),
	(70236),
	(70237),
	(70238),
	(70239),
	(70240),
	(70241),
	(70242),
	(70243),
	(70244),
	(70245),
	(70246),
	(70247),
	(70248),
	(70249),
	(70250),
	(70251),
	(70252),
	(70253),
	(70254),
	(70255),
	(70256),
	(70257),
	(70258),
	(70259),
	(70260),
	(70261),
	(70262),
	(70263),
	(70264),
	(70265),
	(70266),
	(70267),
	(70268),
	(70269),
	(70270),
	(70271),
	(70272),
	(70273),
	(70274),
	(70275),
	(70276),
	(70277),
	(70278),
	(70279),
	(70280),
	(70281),
	(70282),
	(70283),
	(70284),
	(70285),
	(70286),
	(70287),
	(70288),
	(70289),
	(70290),
	(70291),
	(70292),
	(70293),
	(70294),
	(70295),
	(70296),
	(70297),
	(70298),
	(70299),
	(70300),
	(70301),
	(70302),
	(70303),
	(70304),
	(70305),
	(70306),
	(70307),
	(70308),
	(70309),
	(70310),
	(70311),
	(70312),
	(70313),
	(70314),
	(70315),
	(70316),
	(70317),
	(70318),
	(70319),
	(70320),
	(70321),
	(70322),
	(70323),
	(70324),
	(70325),
	(70326),
	(70327),
	(70328),
	(70329),
	(70330),
	(70331),
	(70332),
	(70333),
	(70334),
	(70335),
	(70336),
	(70337),
	(70338),
	(70339),
	(70340),
	(70341),
	(70342),
	(70343),
	(70344),
	(70345),
	(70346),
	(70347),
	(70348),
	(70349),
	(70350),
	(70351),
	(70352),
	(70353),
	(70354),
	(70355),
	(70356),
	(70357),
	(70358),
	(70359),
	(70360),
	(70361),
	(70362),
	(70363),
	(70364),
	(70365),
	(70366),
	(70367),
	(70368),
	(70369),
	(70370),
	(70371),
	(70372),
	(70373),
	(70374),
	(70375),
	(70376),
	(70377),
	(70378),
	(70379),
	(70380),
	(70381),
	(70382),
	(70383),
	(70384),
	(70385),
	(70386),
	(70387),
	(70388),
	(70389),
	(70390),
	(70391),
	(70392),
	(70393),
	(70394),
	(70395),
	(70396),
	(70397),
	(70398),
	(70399),
	(70400),
	(70401),
	(70402),
	(70403),
	(70404),
	(70405),
	(70406),
	(70407),
	(70408),
	(70409),
	(70410),
	(70411),
	(70412),
	(70413),
	(70414),
	(70415),
	(70416),
	(70417),
	(70418),
	(70419),
	(70420),
	(70421),
	(70422),
	(70423),
	(70424),
	(70425),
	(70426),
	(70427),
	(70428),
	(70429),
	(70430),
	(70431),
	(70432),
	(70433),
	(70434),
	(70435),
	(70436),
	(70437),
	(70438),
	(70439),
	(70440),
	(70441),
	(70442),
	(70443),
	(70444),
	(70445),
	(70446),
	(70447),
	(70448),
	(70449),
	(70450),
	(70451),
	(70452),
	(70453),
	(70454),
	(70455),
	(70456),
	(70457),
	(70458),
	(70459),
	(70460),
	(70461),
	(70462),
	(70463),
	(70464),
	(70465),
	(70466),
	(70467),
	(70468),
	(70469),
	(70470),
	(70471),
	(70472),
	(70473),
	(70474),
	(70475),
	(70476),
	(70477),
	(70478),
	(70479),
	(70480),
	(70481),
	(70482),
	(70483),
	(70484),
	(70485),
	(70486),
	(70487),
	(70488),
	(70489),
	(70490),
	(70491),
	(70492),
	(70493),
	(70494),
	(70495),
	(70496),
	(70497),
	(70498),
	(70499),
	(70500),
	(70501),
	(70502),
	(70503),
	(70504),
	(70505),
	(70506),
	(70507),
	(70508),
	(70509),
	(70510),
	(70511),
	(70512),
	(70513),
	(70514),
	(70515),
	(70516),
	(70517),
	(70518),
	(70519),
	(70520),
	(70521),
	(70522),
	(70523),
	(70524),
	(70525),
	(70526),
	(70527),
	(70528),
	(70529),
	(70530),
	(70531),
	(70532),
	(70533),
	(70534),
	(70535),
	(70536),
	(70537),
	(70538),
	(70539),
	(70540),
	(70541),
	(70542),
	(70543),
	(70544),
	(70545),
	(70546),
	(70547),
	(70548),
	(70549),
	(70550),
	(70551),
	(70552),
	(70553),
	(70554),
	(70555),
	(70556),
	(70557),
	(70558),
	(70559),
	(70560),
	(70561),
	(70562),
	(70563),
	(70564),
	(70565),
	(70566),
	(70567),
	(70568),
	(70569),
	(70570),
	(70571),
	(70572),
	(70573),
	(70574),
	(70575),
	(70576),
	(70577),
	(70578),
	(70579),
	(70580),
	(70581),
	(70582),
	(70583),
	(70584),
	(70585),
	(70586),
	(70587),
	(70588),
	(70589),
	(70590),
	(70591),
	(70592),
	(70593),
	(70594),
	(70595),
	(70596),
	(70597),
	(70598),
	(70599),
	(70600),
	(70601),
	(70602),
	(70603),
	(70604),
	(70605),
	(70606),
	(70607),
	(70608),
	(70609),
	(70610),
	(70611),
	(70612),
	(70613),
	(70614),
	(70615),
	(70616),
	(70617),
	(70618),
	(70619),
	(70620),
	(70621),
	(70622),
	(70623),
	(70624),
	(70625),
	(70626),
	(70627),
	(70628),
	(70629),
	(70630),
	(70631),
	(70632),
	(70633),
	(70634),
	(70635),
	(70636),
	(70637),
	(70638),
	(70639),
	(70640),
	(70641),
	(70642),
	(70643),
	(70644),
	(70645),
	(70646),
	(70647),
	(70648),
	(70649),
	(70650),
	(70651),
	(70652),
	(70653),
	(70654),
	(70655),
	(70656),
	(70657),
	(70658),
	(70659),
	(70660),
	(70661),
	(70662),
	(70663),
	(70664),
	(70665),
	(70666),
	(70667),
	(70668),
	(70669),
	(70670),
	(70671),
	(70672),
	(70673),
	(70674),
	(70675),
	(70676),
	(70677),
	(70678),
	(70679),
	(70680),
	(70681),
	(70682),
	(70683),
	(70684),
	(70685),
	(70686),
	(70687),
	(70688),
	(70689),
	(70690),
	(70691),
	(70692),
	(70693),
	(70694),
	(70695),
	(70696),
	(70697),
	(70698),
	(70699),
	(70700),
	(70701),
	(70702),
	(70703),
	(70704),
	(70705),
	(70706),
	(70707),
	(70708),
	(70709),
	(70710),
	(70711),
	(70712),
	(70713),
	(70714),
	(70715),
	(70716),
	(70717),
	(70718),
	(70719),
	(70720),
	(70721),
	(70722),
	(70723),
	(70724),
	(70725),
	(70726),
	(70727),
	(70728),
	(70729),
	(70730),
	(70731),
	(70732),
	(70733),
	(70734),
	(70735),
	(70736),
	(70737),
	(70738),
	(70739),
	(70740),
	(70741),
	(70742),
	(70743),
	(70744),
	(70745),
	(70746),
	(70747),
	(70748),
	(70749),
	(70750),
	(70751),
	(70752),
	(70753),
	(70754),
	(70755),
	(70756),
	(70757),
	(70758),
	(70759),
	(70760),
	(70761),
	(70762),
	(70763),
	(70764),
	(70765),
	(70766),
	(70767),
	(70768),
	(70769),
	(70770),
	(70771),
	(70772),
	(70773),
	(70774),
	(70775),
	(70776),
	(70777),
	(70778),
	(70779),
	(70780),
	(70781),
	(70782),
	(70783),
	(70784),
	(70785),
	(70786),
	(70787),
	(70788),
	(70789),
	(70790),
	(70791),
	(70792),
	(70793),
	(70794),
	(70795),
	(70796),
	(70797),
	(70798),
	(70799),
	(70800),
	(70801),
	(70802),
	(70803),
	(70804),
	(70805),
	(70806),
	(70807),
	(70808),
	(70809),
	(70810),
	(70811),
	(70812),
	(70813),
	(70814),
	(70815),
	(70816),
	(70817),
	(70818),
	(70819),
	(70820),
	(70821),
	(70822),
	(70823),
	(70824),
	(70825),
	(70826),
	(70827),
	(70828),
	(70829),
	(70830),
	(70831),
	(70832),
	(70833),
	(70834),
	(70835),
	(70836),
	(70837),
	(70838),
	(70839),
	(70840),
	(70841),
	(70842),
	(70843),
	(70844),
	(70845),
	(70846),
	(70847),
	(70848),
	(70849),
	(70850),
	(70851),
	(70852),
	(70853),
	(70854),
	(70855),
	(70856),
	(70857),
	(70858),
	(70859),
	(70860),
	(70861),
	(70862),
	(70863),
	(70864),
	(70865),
	(70866),
	(70867),
	(70868),
	(70869),
	(70870),
	(70871),
	(70872),
	(70873),
	(70874),
	(70875),
	(70876),
	(70877),
	(70878),
	(70879),
	(70880),
	(70881),
	(70882),
	(70883),
	(70884),
	(70885),
	(70886),
	(70887),
	(70888),
	(70889),
	(70890),
	(70891),
	(70892),
	(70893),
	(70894),
	(70895),
	(70896),
	(70897),
	(70898),
	(70899),
	(70900),
	(70901),
	(70902),
	(70903),
	(70904),
	(70905),
	(70906),
	(70907),
	(70908),
	(70909),
	(70910),
	(70911),
	(70912),
	(70913),
	(70914),
	(70915),
	(70916),
	(70917),
	(70918),
	(70919),
	(70920),
	(70921),
	(70922),
	(70923),
	(70924),
	(70925),
	(70926),
	(70927),
	(70928),
	(70929),
	(70930),
	(70931),
	(70932),
	(70933),
	(70934),
	(70935),
	(70936),
	(70937),
	(70938),
	(70939),
	(70940),
	(70941),
	(70942),
	(70943),
	(70944),
	(70945),
	(70946),
	(70947),
	(70948),
	(70949),
	(70950),
	(70951),
	(70952),
	(70953),
	(70954),
	(70955),
	(70956),
	(70957),
	(70958),
	(70959),
	(70960),
	(70961),
	(70962),
	(70963),
	(70964),
	(70965),
	(70966),
	(70967),
	(70968),
	(70969),
	(70970),
	(70971),
	(70972),
	(70973),
	(70974),
	(70975),
	(70976),
	(70977),
	(70978),
	(70979),
	(70980),
	(70981),
	(70982),
	(70983),
	(70984),
	(70985),
	(70986),
	(70987),
	(70988),
	(70989),
	(70990),
	(70991),
	(70992),
	(70993),
	(70994),
	(70995),
	(70996),
	(70997),
	(70998),
	(70999),
	(71000),
	(71001),
	(71002),
	(71003),
	(71004),
	(71005),
	(71006),
	(71007),
	(71008),
	(71009),
	(71010),
	(71011),
	(71012),
	(71013),
	(71014),
	(71015),
	(71016),
	(71017),
	(71018),
	(71019),
	(71020),
	(71021),
	(71022),
	(71023),
	(71024),
	(71025),
	(71026),
	(71027),
	(71028),
	(71029),
	(71030),
	(71031),
	(71032),
	(71033),
	(71034),
	(71035),
	(71036),
	(71037),
	(71038),
	(71039),
	(71040),
	(71041),
	(71042),
	(71043),
	(71044),
	(71045),
	(71046),
	(71047),
	(71048),
	(71049),
	(71050),
	(71051),
	(71052),
	(71053),
	(71054),
	(71055),
	(71056),
	(71057),
	(71058),
	(71059),
	(71060),
	(71061),
	(71062),
	(71063),
	(71064),
	(71065),
	(71066),
	(71067),
	(71068),
	(71069),
	(71070),
	(71071),
	(71072),
	(71073),
	(71074),
	(71075),
	(71076),
	(71077),
	(71078),
	(71079),
	(71080),
	(71081),
	(71082),
	(71083),
	(71084),
	(71085),
	(71086),
	(71087),
	(71088),
	(71089),
	(71090),
	(71091),
	(71092),
	(71093),
	(71094),
	(71095),
	(71096),
	(71097),
	(71098),
	(71099),
	(71100),
	(71101),
	(71102),
	(71103),
	(71104),
	(71105),
	(71106),
	(71107),
	(71108),
	(71109),
	(71110),
	(71111),
	(71112),
	(71113),
	(71114),
	(71115),
	(71116),
	(71117),
	(71118),
	(71119),
	(71120),
	(71121),
	(71122),
	(71123),
	(71124),
	(71125),
	(71126),
	(71127),
	(71128),
	(71129),
	(71130),
	(71131),
	(71132),
	(71133),
	(71134),
	(71135),
	(71136),
	(71137),
	(71138),
	(71139),
	(71140),
	(71141),
	(71142),
	(71143),
	(71144),
	(71145),
	(71146),
	(71147),
	(71148),
	(71149),
	(71150),
	(71151),
	(71152),
	(71153),
	(71154),
	(71155),
	(71156),
	(71157),
	(71158),
	(71159),
	(71160),
	(71161),
	(71162),
	(71163),
	(71164),
	(71165),
	(71166),
	(71167),
	(71168),
	(71169),
	(71170),
	(71171),
	(71172),
	(71173),
	(71174),
	(71175),
	(71176),
	(71177),
	(71178),
	(71179),
	(71180),
	(71181),
	(71182),
	(71183),
	(71184),
	(71185),
	(71186),
	(71187),
	(71188),
	(71189),
	(71190),
	(71191),
	(71192),
	(71193),
	(71194),
	(71195),
	(71196),
	(71197),
	(71198),
	(71199),
	(71200),
	(71201),
	(71202),
	(71203),
	(71204),
	(71205),
	(71206),
	(71207),
	(71208),
	(71209),
	(71210),
	(71211),
	(71212),
	(71213),
	(71214),
	(71215),
	(71216),
	(71217),
	(71218),
	(71219),
	(71220),
	(71221),
	(71222),
	(71223),
	(71224),
	(71225),
	(71226),
	(71227),
	(71228),
	(71229),
	(71230),
	(71231),
	(71232),
	(71233),
	(71234),
	(71235),
	(71236),
	(71237),
	(71238),
	(71239),
	(71240),
	(71241),
	(71242),
	(71243),
	(71244),
	(71245),
	(71246),
	(71247),
	(71248),
	(71249),
	(71250),
	(71251),
	(71252),
	(71253),
	(71254),
	(71255),
	(71256),
	(71257),
	(71258),
	(71259),
	(71260),
	(71261),
	(71262),
	(71263),
	(71264),
	(71265),
	(71266),
	(71267),
	(71268),
	(71269),
	(71270),
	(71271),
	(71272),
	(71273),
	(71274),
	(71275),
	(71276),
	(71277),
	(71278),
	(71279),
	(71280),
	(71281),
	(71282),
	(71283),
	(71284),
	(71285),
	(71286),
	(71287),
	(71288),
	(71289),
	(71290),
	(71291),
	(71292),
	(71293),
	(71294),
	(71295),
	(71296),
	(71297),
	(71298),
	(71299),
	(71300),
	(71301),
	(71302),
	(71303),
	(71304),
	(71305),
	(71306),
	(71307),
	(71308),
	(71309),
	(71310),
	(71311),
	(71312),
	(71313),
	(71314),
	(71315),
	(71316),
	(71317),
	(71318),
	(71319),
	(71320),
	(71321),
	(71322),
	(71323),
	(71324),
	(71325),
	(71326),
	(71327),
	(71328),
	(71329),
	(71330),
	(71331),
	(71332),
	(71333),
	(71334),
	(71335),
	(71336),
	(71337),
	(71338),
	(71339),
	(71340),
	(71341),
	(71342),
	(71343),
	(71344),
	(71345),
	(71346),
	(71347),
	(71348),
	(71349),
	(71350),
	(71351),
	(71352),
	(71353),
	(71354),
	(71355),
	(71356),
	(71357),
	(71358),
	(71359),
	(71360),
	(71361),
	(71362),
	(71363),
	(71364),
	(71365),
	(71366),
	(71367),
	(71368),
	(71369),
	(71370),
	(71371),
	(71372),
	(71373),
	(71374),
	(71375),
	(71376),
	(71377),
	(71378),
	(71379),
	(71380),
	(71381),
	(71382),
	(71383),
	(71384),
	(71385),
	(71386),
	(71387),
	(71388),
	(71389),
	(71390),
	(71391),
	(71392),
	(71393),
	(71394),
	(71395),
	(71396),
	(71397),
	(71398),
	(71399),
	(71400),
	(71401),
	(71402),
	(71403),
	(71404),
	(71405),
	(71406),
	(71407),
	(71408),
	(71409),
	(71410),
	(71411),
	(71412),
	(71413),
	(71414),
	(71415),
	(71416),
	(71417),
	(71418),
	(71419),
	(71420),
	(71421),
	(71422),
	(71423),
	(71424),
	(71425),
	(71426),
	(71427),
	(71428),
	(71429),
	(71430),
	(71431),
	(71432),
	(71433),
	(71434),
	(71435),
	(71436),
	(71437),
	(71438),
	(71439),
	(71440),
	(71441),
	(71442),
	(71443),
	(71444),
	(71445),
	(71446),
	(71447),
	(71448),
	(71449),
	(71450),
	(71451),
	(71452),
	(71453),
	(71454),
	(71455),
	(71456),
	(71457),
	(71458),
	(71459),
	(71460),
	(71461),
	(71462),
	(71463),
	(71464),
	(71465),
	(71466),
	(71467),
	(71468),
	(71469),
	(71470),
	(71471),
	(71472),
	(71473),
	(71474),
	(71475),
	(71476),
	(71477),
	(71478),
	(71479),
	(71480),
	(71481),
	(71482),
	(71483),
	(71484),
	(71485),
	(71486),
	(71487),
	(71488),
	(71489),
	(71490),
	(71491),
	(71492),
	(71493),
	(71494),
	(71495),
	(71496),
	(71497),
	(71498),
	(71499),
	(71500),
	(71501),
	(71502),
	(71503),
	(71504),
	(71505),
	(71506),
	(71507),
	(71508),
	(71509),
	(71510),
	(71511),
	(71512),
	(71513),
	(71514),
	(71515),
	(71516),
	(71517),
	(71518),
	(71519),
	(71520),
	(71521),
	(71522),
	(71523),
	(71524),
	(71525),
	(71526),
	(71527),
	(71528),
	(71529),
	(71530),
	(71531),
	(71532),
	(71533),
	(71534),
	(71535),
	(71536),
	(71537),
	(71538),
	(71539),
	(71540),
	(71541),
	(71542),
	(71543),
	(71544),
	(71545),
	(71546),
	(71547),
	(71548),
	(71549),
	(71550),
	(71551),
	(71552),
	(71553),
	(71554),
	(71555),
	(71556),
	(71557),
	(71558),
	(71559),
	(71560),
	(71561),
	(71562),
	(71563),
	(71564),
	(71565),
	(71566),
	(71567),
	(71568),
	(71569),
	(71570),
	(71571),
	(71572),
	(71573),
	(71574),
	(71575),
	(71576),
	(71577),
	(71578),
	(71579),
	(71580),
	(71581),
	(71582),
	(71583),
	(71584),
	(71585),
	(71586),
	(71587),
	(71588),
	(71589),
	(71590),
	(71591),
	(71592),
	(71593),
	(71594),
	(71595),
	(71596),
	(71597),
	(71598),
	(71599),
	(71600),
	(71601),
	(71602),
	(71603),
	(71604),
	(71605),
	(71606),
	(71607),
	(71608),
	(71609),
	(71610),
	(71611),
	(71612),
	(71613),
	(71614),
	(71615),
	(71616),
	(71617),
	(71618),
	(71619),
	(71620),
	(71621),
	(71622),
	(71623),
	(71624),
	(71625),
	(71626),
	(71627),
	(71628),
	(71629),
	(71630),
	(71631),
	(71632),
	(71633),
	(71634),
	(71635),
	(71636),
	(71637),
	(71638),
	(71639),
	(71640),
	(71641),
	(71642),
	(71643),
	(71644),
	(71645),
	(71646),
	(71647),
	(71648),
	(71649),
	(71650),
	(71651),
	(71652),
	(71653),
	(71654),
	(71655),
	(71656),
	(71657),
	(71658),
	(71659),
	(71660),
	(71661),
	(71662),
	(71663),
	(71664),
	(71665),
	(71666),
	(71667),
	(71668),
	(71669),
	(71670),
	(71671),
	(71672),
	(71673),
	(71674),
	(71675),
	(71676),
	(71677),
	(71678),
	(71679),
	(71680),
	(71681),
	(71682),
	(71683),
	(71684),
	(71685),
	(71686),
	(71687),
	(71688),
	(71689),
	(71690),
	(71691),
	(71692),
	(71693),
	(71694),
	(71695),
	(71696),
	(71697),
	(71698),
	(71699),
	(71700),
	(71701),
	(71702),
	(71703),
	(71704),
	(71705),
	(71706),
	(71707),
	(71708),
	(71709),
	(71710),
	(71711),
	(71712),
	(71713),
	(71714),
	(71715),
	(71716),
	(71717),
	(71718),
	(71719),
	(71720),
	(71721),
	(71722),
	(71723),
	(71724),
	(71725),
	(71726),
	(71727),
	(71728),
	(71729),
	(71730),
	(71731),
	(71732),
	(71733),
	(71734),
	(71735),
	(71736),
	(71737),
	(71738),
	(71739),
	(71740),
	(71741),
	(71742),
	(71743),
	(71744),
	(71745),
	(71746),
	(71747),
	(71748),
	(71749),
	(71750),
	(71751),
	(71752),
	(71753),
	(71754),
	(71755),
	(71756),
	(71757),
	(71758),
	(71759),
	(71760),
	(71761),
	(71762),
	(71763),
	(71764),
	(71765),
	(71766),
	(71767),
	(71768),
	(71769),
	(71770),
	(71771),
	(71772),
	(71773),
	(71774),
	(71775),
	(71776),
	(71777),
	(71778),
	(71779),
	(71780),
	(71781),
	(71782),
	(71783),
	(71784),
	(71785),
	(71786),
	(71787),
	(71788),
	(71789),
	(71790),
	(71791),
	(71792),
	(71793),
	(71794),
	(71795),
	(71796),
	(71797),
	(71798),
	(71799),
	(71800),
	(71801),
	(71802),
	(71803),
	(71804),
	(71805),
	(71806),
	(71807),
	(71808),
	(71809),
	(71810),
	(71811),
	(71812),
	(71813),
	(71814),
	(71815),
	(71816),
	(71817),
	(71818),
	(71819),
	(71820),
	(71821),
	(71822),
	(71823),
	(71824),
	(71825),
	(71826),
	(71827),
	(71828),
	(71829),
	(71830),
	(71831),
	(71832),
	(71833),
	(71834),
	(71835),
	(71836),
	(71837),
	(71838),
	(71839),
	(71840),
	(71841),
	(71842),
	(71843),
	(71844),
	(71845),
	(71846),
	(71847),
	(71848),
	(71849),
	(71850),
	(71851),
	(71852),
	(71853),
	(71854),
	(71855),
	(71856),
	(71857),
	(71858),
	(71859),
	(71860),
	(71861),
	(71862),
	(71863),
	(71864),
	(71865),
	(71866),
	(71867),
	(71868),
	(71869),
	(71870),
	(71871),
	(71872),
	(71873),
	(71874),
	(71875),
	(71876),
	(71877),
	(71878),
	(71879),
	(71880),
	(71881),
	(71882),
	(71883),
	(71884),
	(71885),
	(71886),
	(71887),
	(71888),
	(71889),
	(71890),
	(71891),
	(71892),
	(71893),
	(71894),
	(71895),
	(71896),
	(71897),
	(71898),
	(71899),
	(71900),
	(71901),
	(71902),
	(71903),
	(71904),
	(71905),
	(71906),
	(71907),
	(71908),
	(71909),
	(71910),
	(71911),
	(71912),
	(71913),
	(71914),
	(71915),
	(71916),
	(71917),
	(71918),
	(71919),
	(71920),
	(71921),
	(71922),
	(71923),
	(71924),
	(71925),
	(71926),
	(71927),
	(71928),
	(71929),
	(71930),
	(71931),
	(71932),
	(71933),
	(71934),
	(71935),
	(71936),
	(71937),
	(71938),
	(71939),
	(71940),
	(71941),
	(71942),
	(71943),
	(71944),
	(71945),
	(71946),
	(71947),
	(71948),
	(71949),
	(71950),
	(71951),
	(71952),
	(71953),
	(71954),
	(71955),
	(71956),
	(71957),
	(71958),
	(71959),
	(71960),
	(71961),
	(71962),
	(71963),
	(71964),
	(71965),
	(71966),
	(71967),
	(71968),
	(71969),
	(71970),
	(71971),
	(71972),
	(71973),
	(71974),
	(71975),
	(71976),
	(71977),
	(71978),
	(71979),
	(71980),
	(71981),
	(71982),
	(71983),
	(71984),
	(71985),
	(71986),
	(71987),
	(71988),
	(71989),
	(71990),
	(71991),
	(71992),
	(71993),
	(71994),
	(71995),
	(71996),
	(71997),
	(71998),
	(71999),
	(72000),
	(72001),
	(72002),
	(72003),
	(72004),
	(72005),
	(72006),
	(72007),
	(72008),
	(72009),
	(72010),
	(72011),
	(72012),
	(72013),
	(72014),
	(72015),
	(72016),
	(72017),
	(72018),
	(72019),
	(72020),
	(72021),
	(72022),
	(72023),
	(72024),
	(72025),
	(72026),
	(72027),
	(72028),
	(72029),
	(72030),
	(72031),
	(72032),
	(72033),
	(72034),
	(72035),
	(72036),
	(72037),
	(72038),
	(72039),
	(72040),
	(72041),
	(72042),
	(72043),
	(72044),
	(72045),
	(72046),
	(72047),
	(72048),
	(72049),
	(72050),
	(72051),
	(72052),
	(72053),
	(72054),
	(72055),
	(72056),
	(72057),
	(72058),
	(72059),
	(72060),
	(72061),
	(72062),
	(72063),
	(72064),
	(72065),
	(72066),
	(72067),
	(72068),
	(72069),
	(72070),
	(72071),
	(72072),
	(72073),
	(72074),
	(72075),
	(72076),
	(72077),
	(72078),
	(72079),
	(72080),
	(72081),
	(72082),
	(72083),
	(72084),
	(72085),
	(72086),
	(72087),
	(72088),
	(72089),
	(72090),
	(72091),
	(72092),
	(72093),
	(72094),
	(72095),
	(72096),
	(72097),
	(72098),
	(72099),
	(72100),
	(72101),
	(72102),
	(72103),
	(72104),
	(72105),
	(72106),
	(72107),
	(72108),
	(72109),
	(72110),
	(72111),
	(72112),
	(72113),
	(72114),
	(72115),
	(72116),
	(72117),
	(72118),
	(72119),
	(72120),
	(72121),
	(72122),
	(72123),
	(72124),
	(72125),
	(72126),
	(72127),
	(72128),
	(72129),
	(72130),
	(72131),
	(72132),
	(72133),
	(72134),
	(72135),
	(72136),
	(72137),
	(72138),
	(72139),
	(72140),
	(72141),
	(72142),
	(72143),
	(72144),
	(72145),
	(72146),
	(72147),
	(72148),
	(72149),
	(72150),
	(72151),
	(72152),
	(72153),
	(72154),
	(72155),
	(72156),
	(72157),
	(72158),
	(72159),
	(72160),
	(72161),
	(72162),
	(72163),
	(72164),
	(72165),
	(72166),
	(72167),
	(72168),
	(72169),
	(72170),
	(72171),
	(72172),
	(72173),
	(72174),
	(72175),
	(72176),
	(72177),
	(72178),
	(72179),
	(72180),
	(72181),
	(72182),
	(72183),
	(72184),
	(72185),
	(72186),
	(72187),
	(72188),
	(72189),
	(72190),
	(72191),
	(72192),
	(72193),
	(72194),
	(72195),
	(72196),
	(72197),
	(72198),
	(72199),
	(72200),
	(72201),
	(72202),
	(72203),
	(72204),
	(72205),
	(72206),
	(72207),
	(72208),
	(72209),
	(72210),
	(72211),
	(72212),
	(72213),
	(72214),
	(72215),
	(72216),
	(72217),
	(72218),
	(72219),
	(72220),
	(72221),
	(72222),
	(72223),
	(72224),
	(72225),
	(72226),
	(72227),
	(72228),
	(72229),
	(72230),
	(72231),
	(72232),
	(72233),
	(72234),
	(72235),
	(72236),
	(72237),
	(72238),
	(72239),
	(72240),
	(72241),
	(72242),
	(72243),
	(72244),
	(72245),
	(72246),
	(72247),
	(72248),
	(72249),
	(72250),
	(72251),
	(72252),
	(72253),
	(72254),
	(72255),
	(72256),
	(72257),
	(72258),
	(72259),
	(72260),
	(72261),
	(72262),
	(72263),
	(72264),
	(72265),
	(72266),
	(72267),
	(72268),
	(72269),
	(72270),
	(72271),
	(72272),
	(72273),
	(72274),
	(72275),
	(72276),
	(72277),
	(72278),
	(72279),
	(72280),
	(72281),
	(72282),
	(72283),
	(72284),
	(72285),
	(72286),
	(72287),
	(72288),
	(72289),
	(72290),
	(72291),
	(72292),
	(72293),
	(72294),
	(72295),
	(72296),
	(72297),
	(72298),
	(72299),
	(72300),
	(72301),
	(72302),
	(72303),
	(72304),
	(72305),
	(72306),
	(72307),
	(72308),
	(72309),
	(72310),
	(72311),
	(72312),
	(72313),
	(72314),
	(72315),
	(72316),
	(72317),
	(72318),
	(72319),
	(72320),
	(72321),
	(72322),
	(72323),
	(72324),
	(72325),
	(72326),
	(72327),
	(72328),
	(72329),
	(72330),
	(72331),
	(72332),
	(72333),
	(72334),
	(72335),
	(72336),
	(72337),
	(72338),
	(72339),
	(72340),
	(72341),
	(72342),
	(72343),
	(72344),
	(72345),
	(72346),
	(72347),
	(72348),
	(72349),
	(72350),
	(72351),
	(72352),
	(72353),
	(72354),
	(72355),
	(72356),
	(72357),
	(72358),
	(72359),
	(72360),
	(72361),
	(72362),
	(72363),
	(72364),
	(72365),
	(72366),
	(72367),
	(72368),
	(72369),
	(72370),
	(72371),
	(72372),
	(72373),
	(72374),
	(72375),
	(72376),
	(72377),
	(72378),
	(72379),
	(72380),
	(72381),
	(72382),
	(72383),
	(72384),
	(72385),
	(72386),
	(72387),
	(72388),
	(72389),
	(72390),
	(72391),
	(72392),
	(72393),
	(72394),
	(72395),
	(72396),
	(72397),
	(72398),
	(72399),
	(72400),
	(72401),
	(72402),
	(72403),
	(72404),
	(72405),
	(72406),
	(72407),
	(72408),
	(72409),
	(72410),
	(72411),
	(72412),
	(72413),
	(72414),
	(72415),
	(72416),
	(72417),
	(72418),
	(72419),
	(72420),
	(72421),
	(72422),
	(72423),
	(72424),
	(72425),
	(72426),
	(72427),
	(72428),
	(72429),
	(72430),
	(72431),
	(72432),
	(72433),
	(72434),
	(72435),
	(72436),
	(72437),
	(72438),
	(72439),
	(72440),
	(72441),
	(72442),
	(72443),
	(72444),
	(72445),
	(72446),
	(72447),
	(72448),
	(72449),
	(72450),
	(72451),
	(72452),
	(72453),
	(72454),
	(72455),
	(72456),
	(72457),
	(72458),
	(72459),
	(72460),
	(72461),
	(72462),
	(72463),
	(72464),
	(72465),
	(72466),
	(72467),
	(72468),
	(72469),
	(72470),
	(72471),
	(72472),
	(72473),
	(72474),
	(72475),
	(72476),
	(72477),
	(72478),
	(72479),
	(72480),
	(72481),
	(72482),
	(72483),
	(72484),
	(72485),
	(72486),
	(72487),
	(72488),
	(72489),
	(72490),
	(72491),
	(72492),
	(72493),
	(72494),
	(72495),
	(72496),
	(72497),
	(72498),
	(72499),
	(72500),
	(72501),
	(72502),
	(72503),
	(72504),
	(72505),
	(72506),
	(72507),
	(72508),
	(72509),
	(72510),
	(72511),
	(72512),
	(72513),
	(72514),
	(72515),
	(72516),
	(72517),
	(72518),
	(72519),
	(72520),
	(72521),
	(72522),
	(72523),
	(72524),
	(72525),
	(72526),
	(72527),
	(72528),
	(72529),
	(72530),
	(72531),
	(72532),
	(72533),
	(72534),
	(72535),
	(72536),
	(72537),
	(72538),
	(72539),
	(72540),
	(72541),
	(72542),
	(72543),
	(72544),
	(72545),
	(72546),
	(72547),
	(72548),
	(72549),
	(72550),
	(72551),
	(72552),
	(72553),
	(72554),
	(72555),
	(72556),
	(72557),
	(72558),
	(72559),
	(72560),
	(72561),
	(72562),
	(72563),
	(72564),
	(72565),
	(72566),
	(72567),
	(72568),
	(72569),
	(72570),
	(72571),
	(72572),
	(72573),
	(72574),
	(72575),
	(72576),
	(72577),
	(72578),
	(72579),
	(72580),
	(72581),
	(72582),
	(72583),
	(72584),
	(72585),
	(72586),
	(72587),
	(72588),
	(72589),
	(72590),
	(72591),
	(72592),
	(72593),
	(72594),
	(72595),
	(72596),
	(72597),
	(72598),
	(72599),
	(72600),
	(72601),
	(72602),
	(72603),
	(72604),
	(72605),
	(72606),
	(72607),
	(72608),
	(72609),
	(72610),
	(72611),
	(72612),
	(72613),
	(72614),
	(72615),
	(72616),
	(72617),
	(72618),
	(72619),
	(72620),
	(72621),
	(72622),
	(72623),
	(72624),
	(72625),
	(72626),
	(72627),
	(72628),
	(72629),
	(72630),
	(72631),
	(72632),
	(72633),
	(72634),
	(72635),
	(72636),
	(72637),
	(72638),
	(72639),
	(72640),
	(72641),
	(72642),
	(72643),
	(72644),
	(72645),
	(72646),
	(72647),
	(72648),
	(72649),
	(72650),
	(72651),
	(72652),
	(72653),
	(72654),
	(72655),
	(72656),
	(72657),
	(72658),
	(72659),
	(72660),
	(72661),
	(72662),
	(72663),
	(72664),
	(72665),
	(72666),
	(72667),
	(72668),
	(72669),
	(72670),
	(72671),
	(72672),
	(72673),
	(72674),
	(72675),
	(72676),
	(72677),
	(72678),
	(72679),
	(72680),
	(72681),
	(72682),
	(72683),
	(72684),
	(72685),
	(72686),
	(72687),
	(72688),
	(72689),
	(72690),
	(72691),
	(72692),
	(72693),
	(72694),
	(72695),
	(72696),
	(72697),
	(72698),
	(72699),
	(72700),
	(72701),
	(72702),
	(72703),
	(72704),
	(72705),
	(72706),
	(72707),
	(72708),
	(72709),
	(72710),
	(72711),
	(72712),
	(72713),
	(72714),
	(72715),
	(72716),
	(72717),
	(72718),
	(72719),
	(72720),
	(72721),
	(72722),
	(72723),
	(72724),
	(72725),
	(72726),
	(72727),
	(72728),
	(72729),
	(72730),
	(72731),
	(72732),
	(72733),
	(72734),
	(72735),
	(72736),
	(72737),
	(72738),
	(72739),
	(72740),
	(72741),
	(72742),
	(72743),
	(72744),
	(72745),
	(72746),
	(72747),
	(72748),
	(72749),
	(72750),
	(72751),
	(72752),
	(72753),
	(72754),
	(72755),
	(72756),
	(72757),
	(72758),
	(72759),
	(72760),
	(72761),
	(72762),
	(72763),
	(72764),
	(72765),
	(72766),
	(72767),
	(72768),
	(72769),
	(72770),
	(72771),
	(72772),
	(72773),
	(72774),
	(72775),
	(72776),
	(72777),
	(72778),
	(72779),
	(72780),
	(72781),
	(72782),
	(72783),
	(72784),
	(72785),
	(72786),
	(72787),
	(72788),
	(72789),
	(72790),
	(72791),
	(72792),
	(72793),
	(72794),
	(72795),
	(72796),
	(72797),
	(72798),
	(72799),
	(72800),
	(72801),
	(72802),
	(72803),
	(72804),
	(72805),
	(72806),
	(72807),
	(72808),
	(72809),
	(72810),
	(72811),
	(72812),
	(72813),
	(72814),
	(72815),
	(72816),
	(72817),
	(72818),
	(72819),
	(72820),
	(72821),
	(72822),
	(72823),
	(72824),
	(72825),
	(72826),
	(72827),
	(72828),
	(72829),
	(72830),
	(72831),
	(72832),
	(72833),
	(72834),
	(72835),
	(72836),
	(72837),
	(72838),
	(72839),
	(72840),
	(72841),
	(72842),
	(72843),
	(72844),
	(72845),
	(72846),
	(72847),
	(72848),
	(72849),
	(72850),
	(72851),
	(72852),
	(72853),
	(72854),
	(72855),
	(72856),
	(72857),
	(72858),
	(72859),
	(72860),
	(72861),
	(72862),
	(72863),
	(72864),
	(72865),
	(72866),
	(72867),
	(72868),
	(72869),
	(72870),
	(72871),
	(72872),
	(72873),
	(72874),
	(72875),
	(72876),
	(72877),
	(72878),
	(72879),
	(72880),
	(72881),
	(72882),
	(72883),
	(72884),
	(72885),
	(72886),
	(72887),
	(72888),
	(72889),
	(72890),
	(72891),
	(72892),
	(72893),
	(72894),
	(72895),
	(72896),
	(72897),
	(72898),
	(72899),
	(72900),
	(72901),
	(72902),
	(72903),
	(72904),
	(72905),
	(72906),
	(72907),
	(72908),
	(72909),
	(72910),
	(72911),
	(72912),
	(72913),
	(72914),
	(72915),
	(72916),
	(72917),
	(72918),
	(72919),
	(72920),
	(72921),
	(72922),
	(72923),
	(72924),
	(72925),
	(72926),
	(72927),
	(72928),
	(72929),
	(72930),
	(72931),
	(72932),
	(72933),
	(72934),
	(72935),
	(72936),
	(72937),
	(72938),
	(72939),
	(72940),
	(72941),
	(72942),
	(72943),
	(72944),
	(72945),
	(72946),
	(72947),
	(72948),
	(72949),
	(72950),
	(72951),
	(72952),
	(72953),
	(72954),
	(72955),
	(72956),
	(72957),
	(72958),
	(72959),
	(72960),
	(72961),
	(72962),
	(72963),
	(72964),
	(72965),
	(72966),
	(72967),
	(72968),
	(72969),
	(72970),
	(72971),
	(72972),
	(72973),
	(72974),
	(72975),
	(72976),
	(72977),
	(72978),
	(72979),
	(72980),
	(72981),
	(72982),
	(72983),
	(72984),
	(72985),
	(72986),
	(72987),
	(72988),
	(72989),
	(72990),
	(72991),
	(72992),
	(72993),
	(72994),
	(72995),
	(72996),
	(72997),
	(72998),
	(72999),
	(73000),
	(73001),
	(73002),
	(73003),
	(73004),
	(73005),
	(73006),
	(73007),
	(73008),
	(73009),
	(73010),
	(73011),
	(73012),
	(73013),
	(73014),
	(73015),
	(73016),
	(73017),
	(73018),
	(73019),
	(73020),
	(73021),
	(73022),
	(73023),
	(73024),
	(73025),
	(73026),
	(73027),
	(73028),
	(73029),
	(73030),
	(73031),
	(73032),
	(73033),
	(73034),
	(73035),
	(73036),
	(73037),
	(73038),
	(73039),
	(73040),
	(73041),
	(73042),
	(73043),
	(73044),
	(73045),
	(73046),
	(73047),
	(73048),
	(73049),
	(73050),
	(73051),
	(73052),
	(73053),
	(73054),
	(73055),
	(73056),
	(73057),
	(73058),
	(73059),
	(73060),
	(73061),
	(73062),
	(73063),
	(73064),
	(73065),
	(73066),
	(73067),
	(73068),
	(73069),
	(73070),
	(73071),
	(73072),
	(73073),
	(73074),
	(73075),
	(73076),
	(73077),
	(73078),
	(73079),
	(73080),
	(73081),
	(73082),
	(73083),
	(73084),
	(73085),
	(73086),
	(73087),
	(73088),
	(73089),
	(73090),
	(73091),
	(73092),
	(73093),
	(73094),
	(73095),
	(73096),
	(73097),
	(73098),
	(73099),
	(73100),
	(73101),
	(73102),
	(73103),
	(73104),
	(73105),
	(73106),
	(73107),
	(73108),
	(73109),
	(73110),
	(73111),
	(73112),
	(73113),
	(73114),
	(73115),
	(73116),
	(73117),
	(73118),
	(73119),
	(73120),
	(73121),
	(73122),
	(73123),
	(73124),
	(73125),
	(73126),
	(73127),
	(73128),
	(73129),
	(73130),
	(73131),
	(73132),
	(73133),
	(73134),
	(73135),
	(73136),
	(73137),
	(73138),
	(73139),
	(73140),
	(73141),
	(73142),
	(73143),
	(73144),
	(73145),
	(73146),
	(73147),
	(73148),
	(73149),
	(73150),
	(73151),
	(73152),
	(73153),
	(73154),
	(73155),
	(73156),
	(73157),
	(73158),
	(73159),
	(73160),
	(73161),
	(73162),
	(73163),
	(73164),
	(73165),
	(73166),
	(73167),
	(73168),
	(73169),
	(73170),
	(73171),
	(73172),
	(73173),
	(73174),
	(73175),
	(73176),
	(73177),
	(73178),
	(73179),
	(73180),
	(73181),
	(73182),
	(73183),
	(73184),
	(73185),
	(73186),
	(73187),
	(73188),
	(73189),
	(73190),
	(73191),
	(73192),
	(73193),
	(73194),
	(73195),
	(73196),
	(73197),
	(73198),
	(73199),
	(73200),
	(73201),
	(73202),
	(73203),
	(73204),
	(73205),
	(73206),
	(73207),
	(73208),
	(73209),
	(73210),
	(73211),
	(73212),
	(73213),
	(73214),
	(73215),
	(73216),
	(73217),
	(73218),
	(73219),
	(73220),
	(73221),
	(73222),
	(73223),
	(73224),
	(73225),
	(73226),
	(73227),
	(73228),
	(73229),
	(73230),
	(73231),
	(73232),
	(73233),
	(73234),
	(73235),
	(73236),
	(73237),
	(73238),
	(73239),
	(73240),
	(73241),
	(73242),
	(73243),
	(73244),
	(73245),
	(73246),
	(73247),
	(73248),
	(73249),
	(73250),
	(73251),
	(73252),
	(73253),
	(73254),
	(73255),
	(73256),
	(73257),
	(73258),
	(73259),
	(73260),
	(73261),
	(73262),
	(73263),
	(73264),
	(73265),
	(73266),
	(73267),
	(73268),
	(73269),
	(73270),
	(73271),
	(73272),
	(73273),
	(73274),
	(73275),
	(73276),
	(73277),
	(73278),
	(73279),
	(73280),
	(73281),
	(73282),
	(73283),
	(73284),
	(73285),
	(73286),
	(73287),
	(73288),
	(73289),
	(73290),
	(73291),
	(73292),
	(73293),
	(73294),
	(73295),
	(73296),
	(73297),
	(73298),
	(73299),
	(73300),
	(73301),
	(73302),
	(73303),
	(73304),
	(73305),
	(73306),
	(73307),
	(73308),
	(73309),
	(73310),
	(73311),
	(73312),
	(73313),
	(73314),
	(73315),
	(73316),
	(73317),
	(73318),
	(73319),
	(73320),
	(73321),
	(73322),
	(73323),
	(73324),
	(73325),
	(73326),
	(73327),
	(73328),
	(73329),
	(73330),
	(73331),
	(73332),
	(73333),
	(73334),
	(73335),
	(73336),
	(73337),
	(73338),
	(73339),
	(73340),
	(73341),
	(73342),
	(73343),
	(73344),
	(73345),
	(73346),
	(73347),
	(73348),
	(73349),
	(73350),
	(73351),
	(73352),
	(73353),
	(73354),
	(73355),
	(73356),
	(73357),
	(73358),
	(73359),
	(73360),
	(73361),
	(73362),
	(73363),
	(73364),
	(73365),
	(73366),
	(73367),
	(73368),
	(73369),
	(73370),
	(73371),
	(73372),
	(73373),
	(73374),
	(73375),
	(73376),
	(73377),
	(73378),
	(73379),
	(73380),
	(73381),
	(73382),
	(73383),
	(73384),
	(73385),
	(73386),
	(73387),
	(73388),
	(73389),
	(73390),
	(73391),
	(73392),
	(73393),
	(73394),
	(73395),
	(73396),
	(73397),
	(73398),
	(73399),
	(73400),
	(73401),
	(73402),
	(73403),
	(73404),
	(73405),
	(73406),
	(73407),
	(73408),
	(73409),
	(73410),
	(73411),
	(73412),
	(73413),
	(73414),
	(73415),
	(73416),
	(73417),
	(73418),
	(73419),
	(73420),
	(73421),
	(73422),
	(73423),
	(73424),
	(73425),
	(73426),
	(73427),
	(73428),
	(73429),
	(73430),
	(73431),
	(73432),
	(73433),
	(73434),
	(73435),
	(73436),
	(73437),
	(73438),
	(73439),
	(73440),
	(73441),
	(73442),
	(73443),
	(73444),
	(73445),
	(73446),
	(73447),
	(73448),
	(73449),
	(73450),
	(73451),
	(73452),
	(73453),
	(73454),
	(73455),
	(73456),
	(73457),
	(73458),
	(73459),
	(73460),
	(73461),
	(73462),
	(73463),
	(73464),
	(73465),
	(73466),
	(73467),
	(73468),
	(73469),
	(73470),
	(73471),
	(73472),
	(73473),
	(73474),
	(73475),
	(73476),
	(73477),
	(73478),
	(73479),
	(73480),
	(73481),
	(73482),
	(73483),
	(73484),
	(73485),
	(73486),
	(73487),
	(73488),
	(73489),
	(73490),
	(73491),
	(73492),
	(73493),
	(73494),
	(73495),
	(73496),
	(73497),
	(73498),
	(73499),
	(73500),
	(73501),
	(73502),
	(73503),
	(73504),
	(73505),
	(73506),
	(73507),
	(73508),
	(73509),
	(73510),
	(73511),
	(73512),
	(73513),
	(73514),
	(73515),
	(73516),
	(73517),
	(73518),
	(73519),
	(73520),
	(73521),
	(73522),
	(73523),
	(73524),
	(73525),
	(73526),
	(73527),
	(73528),
	(73529),
	(73530),
	(73531),
	(73532),
	(73533),
	(73534),
	(73535),
	(73536),
	(73537),
	(73538),
	(73539),
	(73540),
	(73541),
	(73542),
	(73543),
	(73544),
	(73545),
	(73546),
	(73547),
	(73548),
	(73549),
	(73550),
	(73551),
	(73552),
	(73553),
	(73554),
	(73555),
	(73556),
	(73557),
	(73558),
	(73559),
	(73560),
	(73561),
	(73562),
	(73563),
	(73564),
	(73565),
	(73566),
	(73567),
	(73568),
	(73569),
	(73570),
	(73571),
	(73572),
	(73573),
	(73574),
	(73575),
	(73576),
	(73577),
	(73578),
	(73579),
	(73580),
	(73581),
	(73582),
	(73583),
	(73584),
	(73585),
	(73586),
	(73587),
	(73588),
	(73589),
	(73590),
	(73591),
	(73592),
	(73593),
	(73594),
	(73595),
	(73596),
	(73597),
	(73598),
	(73599),
	(73600),
	(73601),
	(73602),
	(73603),
	(73604),
	(73605),
	(73606),
	(73607),
	(73608),
	(73609),
	(73610),
	(73611),
	(73612),
	(73613),
	(73614),
	(73615),
	(73616),
	(73617),
	(73618),
	(73619),
	(73620),
	(73621),
	(73622),
	(73623),
	(73624),
	(73625),
	(73626),
	(73627),
	(73628),
	(73629),
	(73630),
	(73631),
	(73632),
	(73633),
	(73634),
	(73635),
	(73636),
	(73637),
	(73638),
	(73639),
	(73640),
	(73641),
	(73642),
	(73643),
	(73644),
	(73645),
	(73646),
	(73647),
	(73648),
	(73649),
	(73650),
	(73651),
	(73652),
	(73653),
	(73654),
	(73655),
	(73656),
	(73657),
	(73658),
	(73659),
	(73660),
	(73661),
	(73662),
	(73663),
	(73664),
	(73665),
	(73666),
	(73667),
	(73668),
	(73669),
	(73670),
	(73671),
	(73672),
	(73673),
	(73674),
	(73675),
	(73676),
	(73677),
	(73678),
	(73679),
	(73680),
	(73681),
	(73682),
	(73683),
	(73684),
	(73685),
	(73686),
	(73687),
	(73688),
	(73689),
	(73690),
	(73691),
	(73692),
	(73693),
	(73694),
	(73695),
	(73696),
	(73697),
	(73698),
	(73699),
	(73700),
	(73701),
	(73702),
	(73703),
	(73704),
	(73705),
	(73706),
	(73707),
	(73708),
	(73709),
	(73710),
	(73711),
	(73712),
	(73713),
	(73714),
	(73715),
	(73716),
	(73717),
	(73718),
	(73719),
	(73720),
	(73721),
	(73722),
	(73723),
	(73724),
	(73725),
	(73726),
	(73727),
	(73728),
	(73729),
	(73730),
	(73731),
	(73732),
	(73733),
	(73734),
	(73735),
	(73736),
	(73737),
	(73738),
	(73739),
	(73740),
	(73741),
	(73742),
	(73743),
	(73744),
	(73745),
	(73746),
	(73747),
	(73748),
	(73749),
	(73750),
	(73751),
	(73752),
	(73753),
	(73754),
	(73755),
	(73756),
	(73757),
	(73758),
	(73759),
	(73760),
	(73761),
	(73762),
	(73763),
	(73764),
	(73765),
	(73766),
	(73767),
	(73768),
	(73769),
	(73770),
	(73771),
	(73772),
	(73773),
	(73774),
	(73775),
	(73776),
	(73777),
	(73778),
	(73779),
	(73780),
	(73781),
	(73782),
	(73783),
	(73784),
	(73785),
	(73786),
	(73787),
	(73788),
	(73789),
	(73790),
	(73791),
	(73792),
	(73793),
	(73794),
	(73795),
	(73796),
	(73797),
	(73798),
	(73799),
	(73800),
	(73801),
	(73802),
	(73803),
	(73804),
	(73805),
	(73806),
	(73807),
	(73808),
	(73809),
	(73810),
	(73811),
	(73812),
	(73813),
	(73814),
	(73815),
	(73816),
	(73817),
	(73818),
	(73819),
	(73820),
	(73821),
	(73822),
	(73823),
	(73824),
	(73825),
	(73826),
	(73827),
	(73828),
	(73829),
	(73830),
	(73831),
	(73832),
	(73833),
	(73834),
	(73835),
	(73836),
	(73837),
	(73838),
	(73839),
	(73840),
	(73841),
	(73842),
	(73843),
	(73844),
	(73845),
	(73846),
	(73847),
	(73848),
	(73849),
	(73850),
	(73851),
	(73852),
	(73853),
	(73854),
	(73855),
	(73856),
	(73857),
	(73858),
	(73859),
	(73860),
	(73861),
	(73862),
	(73863),
	(73864),
	(73865),
	(73866),
	(73867),
	(73868),
	(73869),
	(73870),
	(73871),
	(73872),
	(73873),
	(73874),
	(73875),
	(73876),
	(73877),
	(73878),
	(73879),
	(73880),
	(73881),
	(73882),
	(73883),
	(73884),
	(73885),
	(73886),
	(73887),
	(73888),
	(73889),
	(73890),
	(73891),
	(73892),
	(73893),
	(73894),
	(73895),
	(73896),
	(73897),
	(73898),
	(73899),
	(73900),
	(73901),
	(73902),
	(73903),
	(73904),
	(73905),
	(73906),
	(73907),
	(73908),
	(73909),
	(73910),
	(73911),
	(73912),
	(73913),
	(73914),
	(73915),
	(73916),
	(73917),
	(73918),
	(73919),
	(73920),
	(73921),
	(73922),
	(73923),
	(73924),
	(73925),
	(73926),
	(73927),
	(73928),
	(73929),
	(73930),
	(73931),
	(73932),
	(73933),
	(73934),
	(73935),
	(73936),
	(73937),
	(73938),
	(73939),
	(73940),
	(73941),
	(73942),
	(73943),
	(73944),
	(73945),
	(73946),
	(73947),
	(73948),
	(73949),
	(73950),
	(73951),
	(73952),
	(73953),
	(73954),
	(73955),
	(73956),
	(73957),
	(73958),
	(73959),
	(73960),
	(73961),
	(73962),
	(73963),
	(73964),
	(73965),
	(73966),
	(73967),
	(73968),
	(73969),
	(73970),
	(73971),
	(73972),
	(73973),
	(73974),
	(73975),
	(73976),
	(73977),
	(73978),
	(73979),
	(73980),
	(73981),
	(73982),
	(73983),
	(73984),
	(73985),
	(73986),
	(73987),
	(73988),
	(73989),
	(73990),
	(73991),
	(73992),
	(73993),
	(73994),
	(73995),
	(73996),
	(73997),
	(73998),
	(73999),
	(74000),
	(74001),
	(74002),
	(74003),
	(74004),
	(74005),
	(74006),
	(74007),
	(74008),
	(74009),
	(74010),
	(74011),
	(74012),
	(74013),
	(74014),
	(74015),
	(74016),
	(74017),
	(74018),
	(74019),
	(74020),
	(74021),
	(74022),
	(74023),
	(74024),
	(74025),
	(74026),
	(74027),
	(74028),
	(74029),
	(74030),
	(74031),
	(74032),
	(74033),
	(74034),
	(74035),
	(74036),
	(74037),
	(74038),
	(74039),
	(74040),
	(74041),
	(74042),
	(74043),
	(74044),
	(74045),
	(74046),
	(74047),
	(74048),
	(74049),
	(74050),
	(74051),
	(74052),
	(74053),
	(74054),
	(74055),
	(74056),
	(74057),
	(74058),
	(74059),
	(74060),
	(74061),
	(74062),
	(74063),
	(74064),
	(74065),
	(74066),
	(74067),
	(74068),
	(74069),
	(74070),
	(74071),
	(74072),
	(74073),
	(74074),
	(74075),
	(74076),
	(74077),
	(74078),
	(74079),
	(74080),
	(74081),
	(74082),
	(74083),
	(74084),
	(74085),
	(74086),
	(74087),
	(74088),
	(74089),
	(74090),
	(74091),
	(74092),
	(74093),
	(74094),
	(74095),
	(74096),
	(74097),
	(74098),
	(74099),
	(74100),
	(74101),
	(74102),
	(74103),
	(74104),
	(74105),
	(74106),
	(74107),
	(74108),
	(74109),
	(74110),
	(74111),
	(74112),
	(74113),
	(74114),
	(74115),
	(74116),
	(74117),
	(74118),
	(74119),
	(74120),
	(74121),
	(74122),
	(74123),
	(74124),
	(74125),
	(74126),
	(74127),
	(74128),
	(74129),
	(74130),
	(74131),
	(74132),
	(74133),
	(74134),
	(74135),
	(74136),
	(74137),
	(74138),
	(74139),
	(74140),
	(74141),
	(74142),
	(74143),
	(74144),
	(74145),
	(74146),
	(74147),
	(74148),
	(74149),
	(74150),
	(74151),
	(74152),
	(74153),
	(74154),
	(74155),
	(74156),
	(74157),
	(74158),
	(74159),
	(74160),
	(74161),
	(74162),
	(74163),
	(74164),
	(74165),
	(74166),
	(74167),
	(74168),
	(74169),
	(74170),
	(74171),
	(74172),
	(74173),
	(74174),
	(74175),
	(74176),
	(74177),
	(74178),
	(74179),
	(74180),
	(74181),
	(74182),
	(74183),
	(74184),
	(74185),
	(74186),
	(74187),
	(74188),
	(74189),
	(74190),
	(74191),
	(74192),
	(74193),
	(74194),
	(74195),
	(74196),
	(74197),
	(74198),
	(74199),
	(74200),
	(74201),
	(74202),
	(74203),
	(74204),
	(74205),
	(74206),
	(74207),
	(74208),
	(74209),
	(74210),
	(74211),
	(74212),
	(74213),
	(74214),
	(74215),
	(74216),
	(74217),
	(74218),
	(74219),
	(74220),
	(74221),
	(74222),
	(74223),
	(74224),
	(74225),
	(74226),
	(74227),
	(74228),
	(74229),
	(74230),
	(74231),
	(74232),
	(74233),
	(74234),
	(74235),
	(74236),
	(74237),
	(74238),
	(74239),
	(74240),
	(74241),
	(74242),
	(74243),
	(74244),
	(74245),
	(74246),
	(74247),
	(74248),
	(74249),
	(74250),
	(74251),
	(74252),
	(74253),
	(74254),
	(74255),
	(74256),
	(74257),
	(74258),
	(74259),
	(74260),
	(74261),
	(74262),
	(74263),
	(74264),
	(74265),
	(74266),
	(74267),
	(74268),
	(74269),
	(74270),
	(74271),
	(74272),
	(74273),
	(74274),
	(74275),
	(74276),
	(74277),
	(74278),
	(74279),
	(74280),
	(74281),
	(74282),
	(74283),
	(74284),
	(74285),
	(74286),
	(74287),
	(74288),
	(74289),
	(74290),
	(74291),
	(74292),
	(74293),
	(74294),
	(74295),
	(74296),
	(74297),
	(74298),
	(74299),
	(74300),
	(74301),
	(74302),
	(74303),
	(74304),
	(74305),
	(74306),
	(74307),
	(74308),
	(74309),
	(74310),
	(74311),
	(74312),
	(74313),
	(74314),
	(74315),
	(74316),
	(74317),
	(74318),
	(74319),
	(74320),
	(74321),
	(74322),
	(74323),
	(74324),
	(74325),
	(74326),
	(74327),
	(74328),
	(74329),
	(74330),
	(74331),
	(74332),
	(74333),
	(74334),
	(74335),
	(74336),
	(74337),
	(74338),
	(74339),
	(74340),
	(74341),
	(74342),
	(74343),
	(74344),
	(74345),
	(74346),
	(74347),
	(74348),
	(74349),
	(74350),
	(74351),
	(74352),
	(74353),
	(74354),
	(74355),
	(74356),
	(74357),
	(74358),
	(74359),
	(74360),
	(74361),
	(74362),
	(74363),
	(74364),
	(74365),
	(74366),
	(74367),
	(74368),
	(74369),
	(74370),
	(74371),
	(74372),
	(74373),
	(74374),
	(74375),
	(74376),
	(74377),
	(74378),
	(74379),
	(74380),
	(74381),
	(74382),
	(74383),
	(74384),
	(74385),
	(74386),
	(74387),
	(74388),
	(74389),
	(74390),
	(74391),
	(74392),
	(74393),
	(74394),
	(74395),
	(74396),
	(74397),
	(74398),
	(74399),
	(74400),
	(74401),
	(74402),
	(74403),
	(74404),
	(74405),
	(74406),
	(74407),
	(74408),
	(74409),
	(74410),
	(74411),
	(74412),
	(74413),
	(74414),
	(74415),
	(74416),
	(74417),
	(74418),
	(74419),
	(74420),
	(74421),
	(74422),
	(74423),
	(74424),
	(74425),
	(74426),
	(74427),
	(74428),
	(74429),
	(74430),
	(74431),
	(74432),
	(74433),
	(74434),
	(74435),
	(74436),
	(74437),
	(74438),
	(74439),
	(74440),
	(74441),
	(74442),
	(74443),
	(74444),
	(74445),
	(74446),
	(74447),
	(74448),
	(74449),
	(74450),
	(74451),
	(74452),
	(74453),
	(74454),
	(74455),
	(74456),
	(74457),
	(74458),
	(74459),
	(74460),
	(74461),
	(74462),
	(74463),
	(74464),
	(74465),
	(74466),
	(74467),
	(74468),
	(74469),
	(74470),
	(74471),
	(74472),
	(74473),
	(74474),
	(74475),
	(74476),
	(74477),
	(74478),
	(74479),
	(74480),
	(74481),
	(74482),
	(74483),
	(74484),
	(74485),
	(74486),
	(74487),
	(74488),
	(74489),
	(74490),
	(74491),
	(74492),
	(74493),
	(74494),
	(74495),
	(74496),
	(74497),
	(74498),
	(74499),
	(74500),
	(74501),
	(74502),
	(74503),
	(74504),
	(74505),
	(74506),
	(74507),
	(74508),
	(74509),
	(74510),
	(74511),
	(74512),
	(74513),
	(74514),
	(74515),
	(74516),
	(74517),
	(74518),
	(74519),
	(74520),
	(74521),
	(74522),
	(74523),
	(74524),
	(74525),
	(74526),
	(74527),
	(74528),
	(74529),
	(74530),
	(74531),
	(74532),
	(74533),
	(74534),
	(74535),
	(74536),
	(74537),
	(74538),
	(74539),
	(74540),
	(74541),
	(74542),
	(74543),
	(74544),
	(74545),
	(74546),
	(74547),
	(74548),
	(74549),
	(74550),
	(74551),
	(74552),
	(74553),
	(74554),
	(74555),
	(74556),
	(74557),
	(74558),
	(74559),
	(74560),
	(74561),
	(74562),
	(74563),
	(74564),
	(74565),
	(74566),
	(74567),
	(74568),
	(74569),
	(74570),
	(74571),
	(74572),
	(74573),
	(74574),
	(74575),
	(74576),
	(74577),
	(74578),
	(74579),
	(74580),
	(74581),
	(74582),
	(74583),
	(74584),
	(74585),
	(74586),
	(74587),
	(74588),
	(74589),
	(74590),
	(74591),
	(74592),
	(74593),
	(74594),
	(74595),
	(74596),
	(74597),
	(74598),
	(74599),
	(74600),
	(74601),
	(74602),
	(74603),
	(74604),
	(74605),
	(74606),
	(74607),
	(74608),
	(74609),
	(74610),
	(74611),
	(74612),
	(74613),
	(74614),
	(74615),
	(74616),
	(74617),
	(74618),
	(74619),
	(74620),
	(74621),
	(74622),
	(74623),
	(74624),
	(74625),
	(74626),
	(74627),
	(74628),
	(74629),
	(74630),
	(74631),
	(74632),
	(74633),
	(74634),
	(74635),
	(74636),
	(74637),
	(74638),
	(74639),
	(74640),
	(74641),
	(74642),
	(74643),
	(74644),
	(74645),
	(74646),
	(74647),
	(74648),
	(74649),
	(74650),
	(74651),
	(74652),
	(74653),
	(74654),
	(74655),
	(74656),
	(74657),
	(74658),
	(74659),
	(74660),
	(74661),
	(74662),
	(74663),
	(74664),
	(74665),
	(74666),
	(74667),
	(74668),
	(74669),
	(74670),
	(74671),
	(74672),
	(74673),
	(74674),
	(74675),
	(74676),
	(74677),
	(74678),
	(74679),
	(74680),
	(74681),
	(74682),
	(74683),
	(74684),
	(74685),
	(74686),
	(74687),
	(74688),
	(74689),
	(74690),
	(74691),
	(74692),
	(74693),
	(74694),
	(74695),
	(74696),
	(74697),
	(74698),
	(74699),
	(74700),
	(74701),
	(74702),
	(74703),
	(74704),
	(74705),
	(74706),
	(74707),
	(74708),
	(74709),
	(74710),
	(74711),
	(74712),
	(74713),
	(74714),
	(74715),
	(74716),
	(74717),
	(74718),
	(74719),
	(74720),
	(74721),
	(74722),
	(74723),
	(74724),
	(74725),
	(74726),
	(74727),
	(74728),
	(74729),
	(74730),
	(74731),
	(74732),
	(74733),
	(74734),
	(74735),
	(74736),
	(74737),
	(74738),
	(74739),
	(74740),
	(74741),
	(74742),
	(74743),
	(74744),
	(74745),
	(74746),
	(74747),
	(74748),
	(74749),
	(74750),
	(74751),
	(74752),
	(74753),
	(74754),
	(74755),
	(74756),
	(74757),
	(74758),
	(74759),
	(74760),
	(74761),
	(74762),
	(74763),
	(74764),
	(74765),
	(74766),
	(74767),
	(74768),
	(74769),
	(74770),
	(74771),
	(74772),
	(74773),
	(74774),
	(74775),
	(74776),
	(74777),
	(74778),
	(74779),
	(74780),
	(74781),
	(74782),
	(74783),
	(74784),
	(74785),
	(74786),
	(74787),
	(74788),
	(74789),
	(74790),
	(74791),
	(74792),
	(74793),
	(74794),
	(74795),
	(74796),
	(74797),
	(74798),
	(74799),
	(74800),
	(74801),
	(74802),
	(74803),
	(74804),
	(74805),
	(74806),
	(74807),
	(74808),
	(74809),
	(74810),
	(74811),
	(74812),
	(74813),
	(74814),
	(74815),
	(74816),
	(74817),
	(74818),
	(74819),
	(74820),
	(74821),
	(74822),
	(74823),
	(74824),
	(74825),
	(74826),
	(74827),
	(74828),
	(74829),
	(74830),
	(74831),
	(74832),
	(74833),
	(74834),
	(74835),
	(74836),
	(74837),
	(74838),
	(74839),
	(74840),
	(74841),
	(74842),
	(74843),
	(74844),
	(74845),
	(74846),
	(74847),
	(74848),
	(74849),
	(74850),
	(74851),
	(74852),
	(74853),
	(74854),
	(74855),
	(74856),
	(74857),
	(74858),
	(74859),
	(74860),
	(74861),
	(74862),
	(74863),
	(74864),
	(74865),
	(74866),
	(74867),
	(74868),
	(74869),
	(74870),
	(74871),
	(74872),
	(74873),
	(74874),
	(74875),
	(74876),
	(74877),
	(74878),
	(74879),
	(74880),
	(74881),
	(74882),
	(74883),
	(74884),
	(74885),
	(74886),
	(74887),
	(74888),
	(74889),
	(74890),
	(74891),
	(74892),
	(74893),
	(74894),
	(74895),
	(74896),
	(74897),
	(74898),
	(74899),
	(74900),
	(74901),
	(74902),
	(74903),
	(74904),
	(74905),
	(74906),
	(74907),
	(74908),
	(74909),
	(74910),
	(74911),
	(74912),
	(74913),
	(74914),
	(74915),
	(74916),
	(74917),
	(74918),
	(74919),
	(74920),
	(74921),
	(74922),
	(74923),
	(74924),
	(74925),
	(74926),
	(74927),
	(74928),
	(74929),
	(74930),
	(74931),
	(74932),
	(74933),
	(74934),
	(74935),
	(74936),
	(74937),
	(74938),
	(74939),
	(74940),
	(74941),
	(74942),
	(74943),
	(74944),
	(74945),
	(74946),
	(74947),
	(74948),
	(74949),
	(74950),
	(74951),
	(74952),
	(74953),
	(74954),
	(74955),
	(74956),
	(74957),
	(74958),
	(74959),
	(74960),
	(74961),
	(74962),
	(74963),
	(74964),
	(74965),
	(74966),
	(74967),
	(74968),
	(74969),
	(74970),
	(74971),
	(74972),
	(74973),
	(74974),
	(74975),
	(74976),
	(74977),
	(74978),
	(74979),
	(74980),
	(74981),
	(74982),
	(74983),
	(74984),
	(74985),
	(74986),
	(74987),
	(74988),
	(74989),
	(74990),
	(74991),
	(74992),
	(74993),
	(74994),
	(74995),
	(74996),
	(74997),
	(74998),
	(74999),
	(75000),
	(75001),
	(75002),
	(75003),
	(75004),
	(75005),
	(75006),
	(75007),
	(75008),
	(75009),
	(75010),
	(75011),
	(75012),
	(75013),
	(75014),
	(75015),
	(75016),
	(75017),
	(75018),
	(75019),
	(75020),
	(75021),
	(75022),
	(75023),
	(75024),
	(75025),
	(75026),
	(75027),
	(75028),
	(75029),
	(75030),
	(75031),
	(75032),
	(75033),
	(75034),
	(75035),
	(75036),
	(75037),
	(75038),
	(75039),
	(75040),
	(75041),
	(75042),
	(75043),
	(75044),
	(75045),
	(75046),
	(75047),
	(75048),
	(75049),
	(75050),
	(75051),
	(75052),
	(75053),
	(75054),
	(75055),
	(75056),
	(75057),
	(75058),
	(75059),
	(75060),
	(75061),
	(75062),
	(75063),
	(75064),
	(75065),
	(75066),
	(75067),
	(75068),
	(75069),
	(75070),
	(75071),
	(75072),
	(75073),
	(75074),
	(75075),
	(75076),
	(75077),
	(75078),
	(75079),
	(75080),
	(75081),
	(75082),
	(75083),
	(75084),
	(75085),
	(75086),
	(75087),
	(75088),
	(75089),
	(75090),
	(75091),
	(75092),
	(75093),
	(75094),
	(75095),
	(75096),
	(75097),
	(75098),
	(75099),
	(75100),
	(75101),
	(75102),
	(75103),
	(75104),
	(75105),
	(75106),
	(75107),
	(75108),
	(75109),
	(75110),
	(75111),
	(75112),
	(75113),
	(75114),
	(75115),
	(75116),
	(75117),
	(75118),
	(75119),
	(75120),
	(75121),
	(75122),
	(75123),
	(75124),
	(75125),
	(75126),
	(75127),
	(75128),
	(75129),
	(75130),
	(75131),
	(75132),
	(75133),
	(75134),
	(75135),
	(75136),
	(75137),
	(75138),
	(75139),
	(75140),
	(75141),
	(75142),
	(75143),
	(75144),
	(75145),
	(75146),
	(75147),
	(75148),
	(75149),
	(75150),
	(75151),
	(75152),
	(75153),
	(75154),
	(75155),
	(75156),
	(75157),
	(75158),
	(75159),
	(75160),
	(75161),
	(75162),
	(75163),
	(75164),
	(75165),
	(75166),
	(75167),
	(75168),
	(75169),
	(75170),
	(75171),
	(75172),
	(75173),
	(75174),
	(75175),
	(75176),
	(75177),
	(75178),
	(75179),
	(75180),
	(75181),
	(75182),
	(75183),
	(75184),
	(75185),
	(75186),
	(75187),
	(75188),
	(75189),
	(75190),
	(75191),
	(75192),
	(75193),
	(75194),
	(75195),
	(75196),
	(75197),
	(75198),
	(75199),
	(75200),
	(75201),
	(75202),
	(75203),
	(75204),
	(75205),
	(75206),
	(75207),
	(75208),
	(75209),
	(75210),
	(75211),
	(75212),
	(75213),
	(75214),
	(75215),
	(75216),
	(75217),
	(75218),
	(75219),
	(75220),
	(75221),
	(75222),
	(75223),
	(75224),
	(75225),
	(75226),
	(75227),
	(75228),
	(75229),
	(75230),
	(75231),
	(75232),
	(75233),
	(75234),
	(75235),
	(75236),
	(75237),
	(75238),
	(75239),
	(75240),
	(75241),
	(75242),
	(75243),
	(75244),
	(75245),
	(75246),
	(75247),
	(75248),
	(75249),
	(75250),
	(75251),
	(75252),
	(75253),
	(75254),
	(75255),
	(75256),
	(75257),
	(75258),
	(75259),
	(75260),
	(75261),
	(75262),
	(75263),
	(75264),
	(75265),
	(75266),
	(75267),
	(75268),
	(75269),
	(75270),
	(75271),
	(75272),
	(75273),
	(75274),
	(75275),
	(75276),
	(75277),
	(75278),
	(75279),
	(75280),
	(75281),
	(75282),
	(75283),
	(75284),
	(75285),
	(75286),
	(75287),
	(75288),
	(75289),
	(75290),
	(75291),
	(75292),
	(75293),
	(75294),
	(75295),
	(75296),
	(75297),
	(75298),
	(75299),
	(75300),
	(75301),
	(75302),
	(75303),
	(75304),
	(75305),
	(75306),
	(75307),
	(75308),
	(75309),
	(75310),
	(75311),
	(75312),
	(75313),
	(75314),
	(75315),
	(75316),
	(75317),
	(75318),
	(75319),
	(75320),
	(75321),
	(75322),
	(75323),
	(75324),
	(75325),
	(75326),
	(75327),
	(75328),
	(75329),
	(75330),
	(75331),
	(75332),
	(75333),
	(75334),
	(75335),
	(75336),
	(75337),
	(75338),
	(75339),
	(75340),
	(75341),
	(75342),
	(75343),
	(75344),
	(75345),
	(75346),
	(75347),
	(75348),
	(75349),
	(75350),
	(75351),
	(75352),
	(75353),
	(75354),
	(75355),
	(75356),
	(75357),
	(75358),
	(75359),
	(75360),
	(75361),
	(75362),
	(75363),
	(75364),
	(75365),
	(75366),
	(75367),
	(75368),
	(75369),
	(75370),
	(75371),
	(75372),
	(75373),
	(75374),
	(75375),
	(75376),
	(75377),
	(75378),
	(75379),
	(75380),
	(75381),
	(75382),
	(75383),
	(75384),
	(75385),
	(75386),
	(75387),
	(75388),
	(75389),
	(75390),
	(75391),
	(75392),
	(75393),
	(75394),
	(75395),
	(75396),
	(75397),
	(75398),
	(75399),
	(75400),
	(75401),
	(75402),
	(75403),
	(75404),
	(75405),
	(75406),
	(75407),
	(75408),
	(75409),
	(75410),
	(75411),
	(75412),
	(75413),
	(75414),
	(75415),
	(75416),
	(75417),
	(75418),
	(75419),
	(75420),
	(75421),
	(75422),
	(75423),
	(75424),
	(75425),
	(75426),
	(75427),
	(75428),
	(75429),
	(75430),
	(75431),
	(75432),
	(75433),
	(75434),
	(75435),
	(75436),
	(75437),
	(75438),
	(75439),
	(75440),
	(75441),
	(75442),
	(75443),
	(75444),
	(75445),
	(75446),
	(75447),
	(75448),
	(75449),
	(75450),
	(75451),
	(75452),
	(75453),
	(75454),
	(75455),
	(75456),
	(75457),
	(75458),
	(75459),
	(75460),
	(75461),
	(75462),
	(75463),
	(75464),
	(75465),
	(75466),
	(75467),
	(75468),
	(75469),
	(75470),
	(75471),
	(75472),
	(75473),
	(75474),
	(75475),
	(75476),
	(75477),
	(75478),
	(75479),
	(75480),
	(75481),
	(75482),
	(75483),
	(75484),
	(75485),
	(75486),
	(75487),
	(75488),
	(75489),
	(75490),
	(75491),
	(75492),
	(75493),
	(75494),
	(75495),
	(75496),
	(75497),
	(75498),
	(75499),
	(75500),
	(75501),
	(75502),
	(75503),
	(75504),
	(75505),
	(75506),
	(75507),
	(75508),
	(75509),
	(75510),
	(75511),
	(75512),
	(75513),
	(75514),
	(75515),
	(75516),
	(75517),
	(75518),
	(75519),
	(75520),
	(75521),
	(75522),
	(75523),
	(75524),
	(75525),
	(75526),
	(75527),
	(75528),
	(75529),
	(75530),
	(75531),
	(75532),
	(75533),
	(75534),
	(75535),
	(75536),
	(75537),
	(75538),
	(75539),
	(75540),
	(75541),
	(75542),
	(75543),
	(75544),
	(75545),
	(75546),
	(75547),
	(75548),
	(75549),
	(75550),
	(75551),
	(75552),
	(75553),
	(75554),
	(75555),
	(75556),
	(75557),
	(75558),
	(75559),
	(75560),
	(75561),
	(75562),
	(75563),
	(75564),
	(75565),
	(75566),
	(75567),
	(75568),
	(75569),
	(75570),
	(75571),
	(75572),
	(75573),
	(75574),
	(75575),
	(75576),
	(75577),
	(75578),
	(75579),
	(75580),
	(75581),
	(75582),
	(75583),
	(75584),
	(75585),
	(75586),
	(75587),
	(75588),
	(75589),
	(75590),
	(75591),
	(75592),
	(75593),
	(75594),
	(75595),
	(75596),
	(75597),
	(75598),
	(75599),
	(75600),
	(75601),
	(75602),
	(75603),
	(75604),
	(75605),
	(75606),
	(75607),
	(75608),
	(75609),
	(75610),
	(75611),
	(75612),
	(75613),
	(75614),
	(75615),
	(75616),
	(75617),
	(75618),
	(75619),
	(75620),
	(75621),
	(75622),
	(75623),
	(75624),
	(75625),
	(75626),
	(75627),
	(75628),
	(75629),
	(75630),
	(75631),
	(75632),
	(75633),
	(75634),
	(75635),
	(75636),
	(75637),
	(75638),
	(75639),
	(75640),
	(75641),
	(75642),
	(75643),
	(75644),
	(75645),
	(75646),
	(75647),
	(75648),
	(75649),
	(75650),
	(75651),
	(75652),
	(75653),
	(75654),
	(75655),
	(75656),
	(75657),
	(75658),
	(75659),
	(75660),
	(75661),
	(75662),
	(75663),
	(75664),
	(75665),
	(75666),
	(75667),
	(75668),
	(75669),
	(75670),
	(75671),
	(75672),
	(75673),
	(75674),
	(75675),
	(75676),
	(75677),
	(75678),
	(75679),
	(75680),
	(75681),
	(75682),
	(75683),
	(75684),
	(75685),
	(75686),
	(75687),
	(75688),
	(75689),
	(75690),
	(75691),
	(75692),
	(75693),
	(75694),
	(75695),
	(75696),
	(75697),
	(75698),
	(75699),
	(75700),
	(75701),
	(75702),
	(75703),
	(75704),
	(75705),
	(75706),
	(75707),
	(75708),
	(75709),
	(75710),
	(75711),
	(75712),
	(75713),
	(75714),
	(75715),
	(75716),
	(75717),
	(75718),
	(75719),
	(75720),
	(75721),
	(75722),
	(75723),
	(75724),
	(75725),
	(75726),
	(75727),
	(75728),
	(75729),
	(75730),
	(75731),
	(75732),
	(75733),
	(75734),
	(75735),
	(75736),
	(75737),
	(75738),
	(75739),
	(75740),
	(75741),
	(75742),
	(75743),
	(75744),
	(75745),
	(75746),
	(75747),
	(75748),
	(75749),
	(75750),
	(75751),
	(75752),
	(75753),
	(75754),
	(75755),
	(75756),
	(75757),
	(75758),
	(75759),
	(75760),
	(75761),
	(75762),
	(75763),
	(75764),
	(75765),
	(75766),
	(75767),
	(75768),
	(75769),
	(75770),
	(75771),
	(75772),
	(75773),
	(75774),
	(75775),
	(75776),
	(75777),
	(75778),
	(75779),
	(75780),
	(75781),
	(75782),
	(75783),
	(75784),
	(75785),
	(75786),
	(75787),
	(75788),
	(75789),
	(75790),
	(75791),
	(75792),
	(75793),
	(75794),
	(75795),
	(75796),
	(75797),
	(75798),
	(75799),
	(75800),
	(75801),
	(75802),
	(75803),
	(75804),
	(75805),
	(75806),
	(75807),
	(75808),
	(75809),
	(75810),
	(75811),
	(75812),
	(75813),
	(75814),
	(75815),
	(75816),
	(75817),
	(75818),
	(75819),
	(75820),
	(75821),
	(75822),
	(75823),
	(75824),
	(75825),
	(75826),
	(75827),
	(75828),
	(75829),
	(75830),
	(75831),
	(75832),
	(75833),
	(75834),
	(75835),
	(75836),
	(75837),
	(75838),
	(75839),
	(75840),
	(75841),
	(75842),
	(75843),
	(75844),
	(75845),
	(75846),
	(75847),
	(75848),
	(75849),
	(75850),
	(75851),
	(75852),
	(75853),
	(75854),
	(75855),
	(75856),
	(75857),
	(75858),
	(75859),
	(75860),
	(75861),
	(75862),
	(75863),
	(75864),
	(75865),
	(75866),
	(75867),
	(75868),
	(75869),
	(75870),
	(75871),
	(75872),
	(75873),
	(75874),
	(75875),
	(75876),
	(75877),
	(75878),
	(75879),
	(75880),
	(75881),
	(75882),
	(75883),
	(75884),
	(75885),
	(75886),
	(75887),
	(75888),
	(75889),
	(75890),
	(75891),
	(75892),
	(75893),
	(75894),
	(75895),
	(75896),
	(75897),
	(75898),
	(75899),
	(75900),
	(75901),
	(75902),
	(75903),
	(75904),
	(75905),
	(75906),
	(75907),
	(75908),
	(75909),
	(75910),
	(75911),
	(75912),
	(75913),
	(75914),
	(75915),
	(75916),
	(75917),
	(75918),
	(75919),
	(75920),
	(75921),
	(75922),
	(75923),
	(75924),
	(75925),
	(75926),
	(75927),
	(75928),
	(75929),
	(75930),
	(75931),
	(75932),
	(75933),
	(75934),
	(75935),
	(75936),
	(75937),
	(75938),
	(75939),
	(75940),
	(75941),
	(75942),
	(75943),
	(75944),
	(75945),
	(75946),
	(75947),
	(75948),
	(75949),
	(75950),
	(75951),
	(75952),
	(75953),
	(75954),
	(75955),
	(75956),
	(75957),
	(75958),
	(75959),
	(75960),
	(75961),
	(75962),
	(75963),
	(75964),
	(75965),
	(75966),
	(75967),
	(75968),
	(75969),
	(75970),
	(75971),
	(75972),
	(75973),
	(75974),
	(75975),
	(75976),
	(75977),
	(75978),
	(75979),
	(75980),
	(75981),
	(75982),
	(75983),
	(75984),
	(75985),
	(75986),
	(75987),
	(75988),
	(75989),
	(75990),
	(75991),
	(75992),
	(75993),
	(75994),
	(75995),
	(75996),
	(75997),
	(75998),
	(75999),
	(76000),
	(76001),
	(76002),
	(76003),
	(76004),
	(76005),
	(76006),
	(76007),
	(76008),
	(76009),
	(76010),
	(76011),
	(76012),
	(76013),
	(76014),
	(76015),
	(76016),
	(76017),
	(76018),
	(76019),
	(76020),
	(76021),
	(76022),
	(76023),
	(76024),
	(76025),
	(76026),
	(76027),
	(76028),
	(76029),
	(76030),
	(76031),
	(76032),
	(76033),
	(76034),
	(76035),
	(76036),
	(76037),
	(76038),
	(76039),
	(76040),
	(76041),
	(76042),
	(76043),
	(76044),
	(76045),
	(76046),
	(76047),
	(76048),
	(76049),
	(76050),
	(76051),
	(76052),
	(76053),
	(76054),
	(76055),
	(76056),
	(76057),
	(76058),
	(76059),
	(76060),
	(76061),
	(76062),
	(76063),
	(76064),
	(76065),
	(76066),
	(76067),
	(76068),
	(76069),
	(76070),
	(76071),
	(76072),
	(76073),
	(76074),
	(76075),
	(76076),
	(76077),
	(76078),
	(76079),
	(76080),
	(76081),
	(76082),
	(76083),
	(76084),
	(76085),
	(76086),
	(76087),
	(76088),
	(76089),
	(76090),
	(76091),
	(76092),
	(76093),
	(76094),
	(76095),
	(76096),
	(76097),
	(76098),
	(76099),
	(76100),
	(76101),
	(76102),
	(76103),
	(76104),
	(76105),
	(76106),
	(76107),
	(76108),
	(76109),
	(76110),
	(76111),
	(76112),
	(76113),
	(76114),
	(76115),
	(76116),
	(76117),
	(76118),
	(76119),
	(76120),
	(76121),
	(76122),
	(76123),
	(76124),
	(76125),
	(76126),
	(76127),
	(76128),
	(76129),
	(76130),
	(76131),
	(76132),
	(76133),
	(76134),
	(76135),
	(76136),
	(76137),
	(76138),
	(76139),
	(76140),
	(76141),
	(76142),
	(76143),
	(76144),
	(76145),
	(76146),
	(76147),
	(76148),
	(76149),
	(76150),
	(76151),
	(76152),
	(76153),
	(76154),
	(76155),
	(76156),
	(76157),
	(76158),
	(76159),
	(76160),
	(76161),
	(76162),
	(76163),
	(76164),
	(76165),
	(76166),
	(76167),
	(76168),
	(76169),
	(76170),
	(76171),
	(76172),
	(76173),
	(76174),
	(76175),
	(76176),
	(76177),
	(76178),
	(76179),
	(76180),
	(76181),
	(76182),
	(76183),
	(76184),
	(76185),
	(76186),
	(76187),
	(76188),
	(76189),
	(76190),
	(76191),
	(76192),
	(76193),
	(76194),
	(76195),
	(76196),
	(76197),
	(76198),
	(76199),
	(76200),
	(76201),
	(76202),
	(76203),
	(76204),
	(76205),
	(76206),
	(76207),
	(76208),
	(76209),
	(76210),
	(76211),
	(76212),
	(76213),
	(76214),
	(76215),
	(76216),
	(76217),
	(76218),
	(76219),
	(76220),
	(76221),
	(76222),
	(76223),
	(76224),
	(76225),
	(76226),
	(76227),
	(76228),
	(76229),
	(76230),
	(76231),
	(76232),
	(76233),
	(76234),
	(76235),
	(76236),
	(76237),
	(76238),
	(76239),
	(76240),
	(76241),
	(76242),
	(76243),
	(76244),
	(76245),
	(76246),
	(76247),
	(76248),
	(76249),
	(76250),
	(76251),
	(76252),
	(76253),
	(76254),
	(76255),
	(76256),
	(76257),
	(76258),
	(76259),
	(76260),
	(76261),
	(76262),
	(76263),
	(76264),
	(76265),
	(76266),
	(76267),
	(76268),
	(76269),
	(76270),
	(76271),
	(76272),
	(76273),
	(76274),
	(76275),
	(76276),
	(76277),
	(76278),
	(76279),
	(76280),
	(76281),
	(76282),
	(76283),
	(76284),
	(76285),
	(76286),
	(76287),
	(76288),
	(76289),
	(76290),
	(76291),
	(76292),
	(76293),
	(76294),
	(76295),
	(76296),
	(76297),
	(76298),
	(76299),
	(76300),
	(76301),
	(76302),
	(76303),
	(76304),
	(76305),
	(76306),
	(76307),
	(76308),
	(76309),
	(76310),
	(76311),
	(76312),
	(76313),
	(76314),
	(76315),
	(76316),
	(76317),
	(76318),
	(76319),
	(76320),
	(76321),
	(76322),
	(76323),
	(76324),
	(76325),
	(76326),
	(76327),
	(76328),
	(76329),
	(76330),
	(76331),
	(76332),
	(76333),
	(76334),
	(76335),
	(76336),
	(76337),
	(76338),
	(76339),
	(76340),
	(76341),
	(76342),
	(76343),
	(76344),
	(76345),
	(76346),
	(76347),
	(76348),
	(76349),
	(76350),
	(76351),
	(76352),
	(76353),
	(76354),
	(76355),
	(76356),
	(76357),
	(76358),
	(76359),
	(76360),
	(76361),
	(76362),
	(76363),
	(76364),
	(76365),
	(76366),
	(76367),
	(76368),
	(76369),
	(76370),
	(76371),
	(76372),
	(76373),
	(76374),
	(76375),
	(76376),
	(76377),
	(76378),
	(76379),
	(76380),
	(76381),
	(76382),
	(76383),
	(76384),
	(76385),
	(76386),
	(76387),
	(76388),
	(76389),
	(76390),
	(76391),
	(76392),
	(76393),
	(76394),
	(76395),
	(76396),
	(76397),
	(76398),
	(76399),
	(76400),
	(76401),
	(76402),
	(76403),
	(76404),
	(76405),
	(76406),
	(76407),
	(76408),
	(76409),
	(76410),
	(76411),
	(76412),
	(76413),
	(76414),
	(76415),
	(76416),
	(76417),
	(76418),
	(76419),
	(76420),
	(76421),
	(76422),
	(76423),
	(76424),
	(76425),
	(76426),
	(76427),
	(76428),
	(76429),
	(76430),
	(76431),
	(76432),
	(76433),
	(76434),
	(76435),
	(76436),
	(76437),
	(76438),
	(76439),
	(76440),
	(76441),
	(76442),
	(76443),
	(76444),
	(76445),
	(76446),
	(76447),
	(76448),
	(76449),
	(76450),
	(76451),
	(76452),
	(76453),
	(76454),
	(76455),
	(76456),
	(76457),
	(76458),
	(76459),
	(76460),
	(76461),
	(76462),
	(76463),
	(76464),
	(76465),
	(76466),
	(76467),
	(76468),
	(76469),
	(76470),
	(76471),
	(76472),
	(76473),
	(76474),
	(76475),
	(76476),
	(76477),
	(76478),
	(76479),
	(76480),
	(76481),
	(76482),
	(76483),
	(76484),
	(76485),
	(76486),
	(76487),
	(76488),
	(76489),
	(76490),
	(76491),
	(76492),
	(76493),
	(76494),
	(76495),
	(76496),
	(76497),
	(76498),
	(76499),
	(76500),
	(76501),
	(76502),
	(76503),
	(76504),
	(76505),
	(76506),
	(76507),
	(76508),
	(76509),
	(76510),
	(76511),
	(76512),
	(76513),
	(76514),
	(76515),
	(76516),
	(76517),
	(76518),
	(76519),
	(76520),
	(76521),
	(76522),
	(76523),
	(76524),
	(76525),
	(76526),
	(76527),
	(76528),
	(76529),
	(76530),
	(76531),
	(76532),
	(76533),
	(76534),
	(76535),
	(76536),
	(76537),
	(76538),
	(76539),
	(76540),
	(76541),
	(76542),
	(76543),
	(76544),
	(76545),
	(76546),
	(76547),
	(76548),
	(76549),
	(76550),
	(76551),
	(76552),
	(76553),
	(76554),
	(76555),
	(76556),
	(76557),
	(76558),
	(76559),
	(76560),
	(76561),
	(76562),
	(76563),
	(76564),
	(76565),
	(76566),
	(76567),
	(76568),
	(76569),
	(76570),
	(76571),
	(76572),
	(76573),
	(76574),
	(76575),
	(76576),
	(76577),
	(76578),
	(76579),
	(76580),
	(76581),
	(76582),
	(76583),
	(76584),
	(76585),
	(76586),
	(76587),
	(76588),
	(76589),
	(76590),
	(76591),
	(76592),
	(76593),
	(76594),
	(76595),
	(76596),
	(76597),
	(76598),
	(76599),
	(76600),
	(76601),
	(76602),
	(76603),
	(76604),
	(76605),
	(76606),
	(76607),
	(76608),
	(76609),
	(76610),
	(76611),
	(76612),
	(76613),
	(76614),
	(76615),
	(76616),
	(76617),
	(76618),
	(76619),
	(76620),
	(76621),
	(76622),
	(76623),
	(76624),
	(76625),
	(76626),
	(76627),
	(76628),
	(76629),
	(76630),
	(76631),
	(76632),
	(76633),
	(76634),
	(76635),
	(76636),
	(76637),
	(76638),
	(76639),
	(76640),
	(76641),
	(76642),
	(76643),
	(76644),
	(76645),
	(76646),
	(76647),
	(76648),
	(76649),
	(76650),
	(76651),
	(76652),
	(76653),
	(76654),
	(76655),
	(76656),
	(76657),
	(76658),
	(76659),
	(76660),
	(76661),
	(76662),
	(76663),
	(76664),
	(76665),
	(76666),
	(76667),
	(76668),
	(76669),
	(76670),
	(76671),
	(76672),
	(76673),
	(76674),
	(76675),
	(76676),
	(76677),
	(76678),
	(76679),
	(76680),
	(76681),
	(76682),
	(76683),
	(76684),
	(76685),
	(76686),
	(76687),
	(76688),
	(76689),
	(76690),
	(76691),
	(76692),
	(76693),
	(76694),
	(76695),
	(76696),
	(76697),
	(76698),
	(76699),
	(76700),
	(76701),
	(76702),
	(76703),
	(76704),
	(76705),
	(76706),
	(76707),
	(76708),
	(76709),
	(76710),
	(76711),
	(76712),
	(76713),
	(76714),
	(76715),
	(76716),
	(76717),
	(76718),
	(76719),
	(76720),
	(76721),
	(76722),
	(76723),
	(76724),
	(76725),
	(76726),
	(76727),
	(76728),
	(76729),
	(76730),
	(76731),
	(76732),
	(76733),
	(76734),
	(76735),
	(76736),
	(76737),
	(76738),
	(76739),
	(76740),
	(76741),
	(76742),
	(76743),
	(76744),
	(76745),
	(76746),
	(76747),
	(76748),
	(76749),
	(76750),
	(76751),
	(76752),
	(76753),
	(76754),
	(76755),
	(76756),
	(76757),
	(76758),
	(76759),
	(76760),
	(76761),
	(76762),
	(76763),
	(76764),
	(76765),
	(76766),
	(76767),
	(76768),
	(76769),
	(76770),
	(76771),
	(76772),
	(76773),
	(76774),
	(76775),
	(76776),
	(76777),
	(76778),
	(76779),
	(76780),
	(76781),
	(76782),
	(76783),
	(76784),
	(76785),
	(76786),
	(76787),
	(76788),
	(76789),
	(76790),
	(76791),
	(76792),
	(76793),
	(76794),
	(76795),
	(76796),
	(76797),
	(76798),
	(76799),
	(76800),
	(76801),
	(76802),
	(76803),
	(76804),
	(76805),
	(76806),
	(76807),
	(76808),
	(76809),
	(76810),
	(76811),
	(76812),
	(76813),
	(76814),
	(76815),
	(76816),
	(76817),
	(76818),
	(76819),
	(76820),
	(76821),
	(76822),
	(76823),
	(76824),
	(76825),
	(76826),
	(76827),
	(76828),
	(76829),
	(76830),
	(76831),
	(76832),
	(76833),
	(76834),
	(76835),
	(76836),
	(76837),
	(76838),
	(76839),
	(76840),
	(76841),
	(76842),
	(76843),
	(76844),
	(76845),
	(76846),
	(76847),
	(76848),
	(76849),
	(76850),
	(76851),
	(76852),
	(76853),
	(76854),
	(76855),
	(76856),
	(76857),
	(76858),
	(76859),
	(76860),
	(76861),
	(76862),
	(76863),
	(76864),
	(76865),
	(76866),
	(76867),
	(76868),
	(76869),
	(76870),
	(76871),
	(76872),
	(76873),
	(76874),
	(76875),
	(76876),
	(76877),
	(76878),
	(76879),
	(76880),
	(76881),
	(76882),
	(76883),
	(76884),
	(76885),
	(76886),
	(76887),
	(76888),
	(76889),
	(76890),
	(76891),
	(76892),
	(76893),
	(76894),
	(76895),
	(76896),
	(76897),
	(76898),
	(76899),
	(76900),
	(76901),
	(76902),
	(76903),
	(76904),
	(76905),
	(76906),
	(76907),
	(76908),
	(76909),
	(76910),
	(76911),
	(76912),
	(76913),
	(76914),
	(76915),
	(76916),
	(76917),
	(76918),
	(76919),
	(76920),
	(76921),
	(76922),
	(76923),
	(76924),
	(76925),
	(76926),
	(76927),
	(76928),
	(76929),
	(76930),
	(76931),
	(76932),
	(76933),
	(76934),
	(76935),
	(76936),
	(76937),
	(76938),
	(76939),
	(76940),
	(76941),
	(76942),
	(76943),
	(76944),
	(76945),
	(76946),
	(76947),
	(76948),
	(76949),
	(76950),
	(76951),
	(76952),
	(76953),
	(76954),
	(76955),
	(76956),
	(76957),
	(76958),
	(76959),
	(76960),
	(76961),
	(76962),
	(76963),
	(76964),
	(76965),
	(76966),
	(76967),
	(76968),
	(76969),
	(76970),
	(76971),
	(76972),
	(76973),
	(76974),
	(76975),
	(76976),
	(76977),
	(76978),
	(76979),
	(76980),
	(76981),
	(76982),
	(76983),
	(76984),
	(76985),
	(76986),
	(76987),
	(76988),
	(76989),
	(76990),
	(76991),
	(76992),
	(76993),
	(76994),
	(76995),
	(76996),
	(76997),
	(76998),
	(76999),
	(77000),
	(77001),
	(77002),
	(77003),
	(77004),
	(77005),
	(77006),
	(77007),
	(77008),
	(77009),
	(77010),
	(77011),
	(77012),
	(77013),
	(77014),
	(77015),
	(77016),
	(77017),
	(77018),
	(77019),
	(77020),
	(77021),
	(77022),
	(77023),
	(77024),
	(77025),
	(77026),
	(77027),
	(77028),
	(77029),
	(77030),
	(77031),
	(77032),
	(77033),
	(77034),
	(77035),
	(77036),
	(77037),
	(77038),
	(77039),
	(77040),
	(77041),
	(77042),
	(77043),
	(77044),
	(77045),
	(77046),
	(77047),
	(77048),
	(77049),
	(77050),
	(77051),
	(77052),
	(77053),
	(77054),
	(77055),
	(77056),
	(77057),
	(77058),
	(77059),
	(77060),
	(77061),
	(77062),
	(77063),
	(77064),
	(77065),
	(77066),
	(77067),
	(77068),
	(77069),
	(77070),
	(77071),
	(77072),
	(77073),
	(77074),
	(77075),
	(77076),
	(77077),
	(77078),
	(77079),
	(77080),
	(77081),
	(77082),
	(77083),
	(77084),
	(77085),
	(77086),
	(77087),
	(77088),
	(77089),
	(77090),
	(77091),
	(77092),
	(77093),
	(77094),
	(77095),
	(77096),
	(77097),
	(77098),
	(77099),
	(77100),
	(77101),
	(77102),
	(77103),
	(77104),
	(77105),
	(77106),
	(77107),
	(77108),
	(77109),
	(77110),
	(77111),
	(77112),
	(77113),
	(77114),
	(77115),
	(77116),
	(77117),
	(77118),
	(77119),
	(77120),
	(77121),
	(77122),
	(77123),
	(77124),
	(77125),
	(77126),
	(77127),
	(77128),
	(77129),
	(77130),
	(77131),
	(77132),
	(77133),
	(77134),
	(77135),
	(77136),
	(77137),
	(77138),
	(77139),
	(77140),
	(77141),
	(77142),
	(77143),
	(77144),
	(77145),
	(77146),
	(77147),
	(77148),
	(77149),
	(77150),
	(77151),
	(77152),
	(77153),
	(77154),
	(77155),
	(77156),
	(77157),
	(77158),
	(77159),
	(77160),
	(77161),
	(77162),
	(77163),
	(77164),
	(77165),
	(77166),
	(77167),
	(77168),
	(77169),
	(77170),
	(77171),
	(77172),
	(77173),
	(77174),
	(77175),
	(77176),
	(77177),
	(77178),
	(77179),
	(77180),
	(77181),
	(77182),
	(77183),
	(77184),
	(77185),
	(77186),
	(77187),
	(77188),
	(77189),
	(77190),
	(77191),
	(77192),
	(77193),
	(77194),
	(77195),
	(77196),
	(77197),
	(77198),
	(77199),
	(77200),
	(77201),
	(77202),
	(77203),
	(77204),
	(77205),
	(77206),
	(77207),
	(77208),
	(77209),
	(77210),
	(77211),
	(77212),
	(77213),
	(77214),
	(77215),
	(77216),
	(77217),
	(77218),
	(77219),
	(77220),
	(77221),
	(77222),
	(77223),
	(77224),
	(77225),
	(77226),
	(77227),
	(77228),
	(77229),
	(77230),
	(77231),
	(77232),
	(77233),
	(77234),
	(77235),
	(77236),
	(77237),
	(77238),
	(77239),
	(77240),
	(77241),
	(77242),
	(77243),
	(77244),
	(77245),
	(77246),
	(77247),
	(77248),
	(77249),
	(77250),
	(77251),
	(77252),
	(77253),
	(77254),
	(77255),
	(77256),
	(77257),
	(77258),
	(77259),
	(77260),
	(77261),
	(77262),
	(77263),
	(77264),
	(77265),
	(77266),
	(77267),
	(77268),
	(77269),
	(77270),
	(77271),
	(77272),
	(77273),
	(77274),
	(77275),
	(77276),
	(77277),
	(77278),
	(77279),
	(77280),
	(77281),
	(77282),
	(77283),
	(77284),
	(77285),
	(77286),
	(77287),
	(77288),
	(77289),
	(77290),
	(77291),
	(77292),
	(77293),
	(77294),
	(77295),
	(77296),
	(77297),
	(77298),
	(77299),
	(77300),
	(77301),
	(77302),
	(77303),
	(77304),
	(77305),
	(77306),
	(77307),
	(77308),
	(77309),
	(77310),
	(77311),
	(77312),
	(77313),
	(77314),
	(77315),
	(77316),
	(77317),
	(77318),
	(77319),
	(77320),
	(77321),
	(77322),
	(77323),
	(77324),
	(77325),
	(77326),
	(77327),
	(77328),
	(77329),
	(77330),
	(77331),
	(77332),
	(77333),
	(77334),
	(77335),
	(77336),
	(77337),
	(77338),
	(77339),
	(77340),
	(77341),
	(77342),
	(77343),
	(77344),
	(77345),
	(77346),
	(77347),
	(77348),
	(77349),
	(77350),
	(77351),
	(77352),
	(77353),
	(77354),
	(77355),
	(77356),
	(77357),
	(77358),
	(77359),
	(77360),
	(77361),
	(77362),
	(77363),
	(77364),
	(77365),
	(77366),
	(77367),
	(77368),
	(77369),
	(77370),
	(77371),
	(77372),
	(77373),
	(77374),
	(77375),
	(77376),
	(77377),
	(77378),
	(77379),
	(77380),
	(77381),
	(77382),
	(77383),
	(77384),
	(77385),
	(77386),
	(77387),
	(77388),
	(77389),
	(77390),
	(77391),
	(77392),
	(77393),
	(77394),
	(77395),
	(77396),
	(77397),
	(77398),
	(77399),
	(77400),
	(77401),
	(77402),
	(77403),
	(77404),
	(77405),
	(77406),
	(77407),
	(77408),
	(77409),
	(77410),
	(77411),
	(77412),
	(77413),
	(77414),
	(77415),
	(77416),
	(77417),
	(77418),
	(77419),
	(77420),
	(77421),
	(77422),
	(77423),
	(77424),
	(77425),
	(77426),
	(77427),
	(77428),
	(77429),
	(77430),
	(77431),
	(77432),
	(77433),
	(77434),
	(77435),
	(77436),
	(77437),
	(77438),
	(77439),
	(77440),
	(77441),
	(77442),
	(77443),
	(77444),
	(77445),
	(77446),
	(77447),
	(77448),
	(77449),
	(77450),
	(77451),
	(77452),
	(77453),
	(77454),
	(77455),
	(77456),
	(77457),
	(77458),
	(77459),
	(77460),
	(77461),
	(77462),
	(77463),
	(77464),
	(77465),
	(77466),
	(77467),
	(77468),
	(77469),
	(77470),
	(77471),
	(77472),
	(77473),
	(77474),
	(77475),
	(77476),
	(77477),
	(77478),
	(77479),
	(77480),
	(77481),
	(77482),
	(77483),
	(77484),
	(77485),
	(77486),
	(77487),
	(77488),
	(77489),
	(77490),
	(77491),
	(77492),
	(77493),
	(77494),
	(77495),
	(77496),
	(77497),
	(77498),
	(77499),
	(77500),
	(77501),
	(77502),
	(77503),
	(77504),
	(77505),
	(77506),
	(77507),
	(77508),
	(77509),
	(77510),
	(77511),
	(77512),
	(77513),
	(77514),
	(77515),
	(77516),
	(77517),
	(77518),
	(77519),
	(77520),
	(77521),
	(77522),
	(77523),
	(77524),
	(77525),
	(77526),
	(77527),
	(77528),
	(77529),
	(77530),
	(77531),
	(77532),
	(77533),
	(77534),
	(77535),
	(77536),
	(77537),
	(77538),
	(77539),
	(77540),
	(77541),
	(77542),
	(77543),
	(77544),
	(77545),
	(77546),
	(77547),
	(77548),
	(77549),
	(77550),
	(77551),
	(77552),
	(77553),
	(77554),
	(77555),
	(77556),
	(77557),
	(77558),
	(77559),
	(77560),
	(77561),
	(77562),
	(77563),
	(77564),
	(77565),
	(77566),
	(77567),
	(77568),
	(77569),
	(77570),
	(77571),
	(77572),
	(77573),
	(77574),
	(77575),
	(77576),
	(77577),
	(77578),
	(77579),
	(77580),
	(77581),
	(77582),
	(77583),
	(77584),
	(77585),
	(77586),
	(77587),
	(77588),
	(77589),
	(77590),
	(77591),
	(77592),
	(77593),
	(77594),
	(77595),
	(77596),
	(77597),
	(77598),
	(77599),
	(77600),
	(77601),
	(77602),
	(77603),
	(77604),
	(77605),
	(77606),
	(77607),
	(77608),
	(77609),
	(77610),
	(77611),
	(77612),
	(77613),
	(77614),
	(77615),
	(77616),
	(77617),
	(77618),
	(77619),
	(77620),
	(77621),
	(77622),
	(77623),
	(77624),
	(77625),
	(77626),
	(77627),
	(77628),
	(77629),
	(77630),
	(77631),
	(77632),
	(77633),
	(77634),
	(77635),
	(77636),
	(77637),
	(77638),
	(77639),
	(77640),
	(77641),
	(77642),
	(77643),
	(77644),
	(77645),
	(77646),
	(77647),
	(77648),
	(77649),
	(77650),
	(77651),
	(77652),
	(77653),
	(77654),
	(77655),
	(77656),
	(77657),
	(77658),
	(77659),
	(77660),
	(77661),
	(77662),
	(77663),
	(77664),
	(77665),
	(77666),
	(77667),
	(77668),
	(77669),
	(77670),
	(77671),
	(77672),
	(77673),
	(77674),
	(77675),
	(77676),
	(77677),
	(77678),
	(77679),
	(77680),
	(77681),
	(77682),
	(77683),
	(77684),
	(77685),
	(77686),
	(77687),
	(77688),
	(77689),
	(77690),
	(77691),
	(77692),
	(77693),
	(77694),
	(77695),
	(77696),
	(77697),
	(77698),
	(77699),
	(77700),
	(77701),
	(77702),
	(77703),
	(77704),
	(77705),
	(77706),
	(77707),
	(77708),
	(77709),
	(77710),
	(77711),
	(77712),
	(77713),
	(77714),
	(77715),
	(77716),
	(77717),
	(77718),
	(77719),
	(77720),
	(77721),
	(77722),
	(77723),
	(77724),
	(77725),
	(77726),
	(77727),
	(77728),
	(77729),
	(77730),
	(77731),
	(77732),
	(77733),
	(77734),
	(77735),
	(77736),
	(77737),
	(77738),
	(77739),
	(77740),
	(77741),
	(77742),
	(77743),
	(77744),
	(77745),
	(77746),
	(77747),
	(77748),
	(77749),
	(77750),
	(77751),
	(77752),
	(77753),
	(77754),
	(77755),
	(77756),
	(77757),
	(77758),
	(77759),
	(77760),
	(77761),
	(77762),
	(77763),
	(77764),
	(77765),
	(77766),
	(77767),
	(77768),
	(77769),
	(77770),
	(77771),
	(77772),
	(77773),
	(77774),
	(77775),
	(77776),
	(77777),
	(77778),
	(77779),
	(77780),
	(77781),
	(77782),
	(77783),
	(77784),
	(77785),
	(77786),
	(77787),
	(77788),
	(77789),
	(77790),
	(77791),
	(77792),
	(77793),
	(77794),
	(77795),
	(77796),
	(77797),
	(77798),
	(77799),
	(77800),
	(77801),
	(77802),
	(77803),
	(77804),
	(77805),
	(77806),
	(77807),
	(77808),
	(77809),
	(77810),
	(77811),
	(77812),
	(77813),
	(77814),
	(77815),
	(77816),
	(77817),
	(77818),
	(77819),
	(77820),
	(77821),
	(77822),
	(77823),
	(77824),
	(77825),
	(77826),
	(77827),
	(77828),
	(77829),
	(77830),
	(77831),
	(77832),
	(77833),
	(77834),
	(77835),
	(77836),
	(77837),
	(77838),
	(77839),
	(77840),
	(77841),
	(77842),
	(77843),
	(77844),
	(77845),
	(77846),
	(77847),
	(77848),
	(77849),
	(77850),
	(77851),
	(77852),
	(77853),
	(77854),
	(77855),
	(77856),
	(77857),
	(77858),
	(77859),
	(77860),
	(77861),
	(77862),
	(77863),
	(77864),
	(77865),
	(77866),
	(77867),
	(77868),
	(77869),
	(77870),
	(77871),
	(77872),
	(77873),
	(77874),
	(77875),
	(77876),
	(77877),
	(77878),
	(77879),
	(77880),
	(77881),
	(77882),
	(77883),
	(77884),
	(77885),
	(77886),
	(77887),
	(77888),
	(77889),
	(77890),
	(77891),
	(77892),
	(77893),
	(77894),
	(77895),
	(77896),
	(77897),
	(77898),
	(77899),
	(77900),
	(77901),
	(77902),
	(77903),
	(77904),
	(77905),
	(77906),
	(77907),
	(77908),
	(77909),
	(77910),
	(77911),
	(77912),
	(77913),
	(77914),
	(77915),
	(77916),
	(77917),
	(77918),
	(77919),
	(77920),
	(77921),
	(77922),
	(77923),
	(77924),
	(77925),
	(77926),
	(77927),
	(77928),
	(77929),
	(77930),
	(77931),
	(77932),
	(77933),
	(77934),
	(77935),
	(77936),
	(77937),
	(77938),
	(77939),
	(77940),
	(77941),
	(77942),
	(77943),
	(77944),
	(77945),
	(77946),
	(77947),
	(77948),
	(77949),
	(77950),
	(77951),
	(77952),
	(77953),
	(77954),
	(77955),
	(77956),
	(77957),
	(77958),
	(77959),
	(77960),
	(77961),
	(77962),
	(77963),
	(77964),
	(77965),
	(77966),
	(77967),
	(77968),
	(77969),
	(77970),
	(77971),
	(77972),
	(77973),
	(77974),
	(77975),
	(77976),
	(77977),
	(77978),
	(77979),
	(77980),
	(77981),
	(77982),
	(77983),
	(77984),
	(77985),
	(77986),
	(77987),
	(77988),
	(77989),
	(77990),
	(77991),
	(77992),
	(77993),
	(77994),
	(77995),
	(77996),
	(77997),
	(77998),
	(77999),
	(78000),
	(78001),
	(78002),
	(78003),
	(78004),
	(78005),
	(78006),
	(78007),
	(78008),
	(78009),
	(78010),
	(78011),
	(78012),
	(78013),
	(78014),
	(78015),
	(78016),
	(78017),
	(78018),
	(78019),
	(78020),
	(78021),
	(78022),
	(78023),
	(78024),
	(78025),
	(78026),
	(78027),
	(78028),
	(78029),
	(78030),
	(78031),
	(78032),
	(78033),
	(78034),
	(78035),
	(78036),
	(78037),
	(78038),
	(78039),
	(78040),
	(78041),
	(78042),
	(78043),
	(78044),
	(78045),
	(78046),
	(78047),
	(78048),
	(78049),
	(78050),
	(78051),
	(78052),
	(78053),
	(78054),
	(78055),
	(78056),
	(78057),
	(78058),
	(78059),
	(78060),
	(78061),
	(78062),
	(78063),
	(78064),
	(78065),
	(78066),
	(78067),
	(78068),
	(78069),
	(78070),
	(78071),
	(78072),
	(78073),
	(78074),
	(78075),
	(78076),
	(78077),
	(78078),
	(78079),
	(78080),
	(78081),
	(78082),
	(78083),
	(78084),
	(78085),
	(78086),
	(78087),
	(78088),
	(78089),
	(78090),
	(78091),
	(78092),
	(78093),
	(78094),
	(78095),
	(78096),
	(78097),
	(78098),
	(78099),
	(78100),
	(78101),
	(78102),
	(78103),
	(78104),
	(78105),
	(78106),
	(78107),
	(78108),
	(78109),
	(78110),
	(78111),
	(78112),
	(78113),
	(78114),
	(78115),
	(78116),
	(78117),
	(78118),
	(78119),
	(78120),
	(78121),
	(78122),
	(78123),
	(78124),
	(78125),
	(78126),
	(78127),
	(78128),
	(78129),
	(78130),
	(78131),
	(78132),
	(78133),
	(78134),
	(78135),
	(78136),
	(78137),
	(78138),
	(78139),
	(78140),
	(78141),
	(78142),
	(78143),
	(78144),
	(78145),
	(78146),
	(78147),
	(78148),
	(78149),
	(78150),
	(78151),
	(78152),
	(78153),
	(78154),
	(78155),
	(78156),
	(78157),
	(78158),
	(78159),
	(78160),
	(78161),
	(78162),
	(78163),
	(78164),
	(78165),
	(78166),
	(78167),
	(78168),
	(78169),
	(78170),
	(78171),
	(78172),
	(78173),
	(78174),
	(78175),
	(78176),
	(78177),
	(78178),
	(78179),
	(78180),
	(78181),
	(78182),
	(78183),
	(78184),
	(78185),
	(78186),
	(78187),
	(78188),
	(78189),
	(78190),
	(78191),
	(78192),
	(78193),
	(78194),
	(78195),
	(78196),
	(78197),
	(78198),
	(78199),
	(78200),
	(78201),
	(78202),
	(78203),
	(78204),
	(78205),
	(78206),
	(78207),
	(78208),
	(78209),
	(78210),
	(78211),
	(78212),
	(78213),
	(78214),
	(78215),
	(78216),
	(78217),
	(78218),
	(78219),
	(78220),
	(78221),
	(78222),
	(78223),
	(78224),
	(78225),
	(78226),
	(78227),
	(78228),
	(78229),
	(78230),
	(78231),
	(78232),
	(78233),
	(78234),
	(78235),
	(78236),
	(78237),
	(78238),
	(78239),
	(78240),
	(78241),
	(78242),
	(78243),
	(78244),
	(78245),
	(78246),
	(78247),
	(78248),
	(78249),
	(78250),
	(78251),
	(78252),
	(78253),
	(78254),
	(78255),
	(78256),
	(78257),
	(78258),
	(78259),
	(78260),
	(78261),
	(78262),
	(78263),
	(78264),
	(78265),
	(78266),
	(78267),
	(78268),
	(78269),
	(78270),
	(78271),
	(78272),
	(78273),
	(78274),
	(78275),
	(78276),
	(78277),
	(78278),
	(78279),
	(78280),
	(78281),
	(78282),
	(78283),
	(78284),
	(78285),
	(78286),
	(78287),
	(78288),
	(78289),
	(78290),
	(78291),
	(78292),
	(78293),
	(78294),
	(78295),
	(78296),
	(78297),
	(78298),
	(78299),
	(78300),
	(78301),
	(78302),
	(78303),
	(78304),
	(78305),
	(78306),
	(78307),
	(78308),
	(78309),
	(78310),
	(78311),
	(78312),
	(78313),
	(78314),
	(78315),
	(78316),
	(78317),
	(78318),
	(78319),
	(78320),
	(78321),
	(78322),
	(78323),
	(78324),
	(78325),
	(78326),
	(78327),
	(78328),
	(78329),
	(78330),
	(78331),
	(78332),
	(78333),
	(78334),
	(78335),
	(78336),
	(78337),
	(78338),
	(78339),
	(78340),
	(78341),
	(78342),
	(78343),
	(78344),
	(78345),
	(78346),
	(78347),
	(78348),
	(78349),
	(78350),
	(78351),
	(78352),
	(78353),
	(78354),
	(78355),
	(78356),
	(78357),
	(78358),
	(78359),
	(78360),
	(78361),
	(78362),
	(78363),
	(78364),
	(78365),
	(78366),
	(78367),
	(78368),
	(78369),
	(78370),
	(78371),
	(78372),
	(78373),
	(78374),
	(78375),
	(78376),
	(78377),
	(78378),
	(78379),
	(78380),
	(78381),
	(78382),
	(78383),
	(78384),
	(78385),
	(78386),
	(78387),
	(78388),
	(78389),
	(78390),
	(78391),
	(78392),
	(78393),
	(78394),
	(78395),
	(78396),
	(78397),
	(78398),
	(78399),
	(78400),
	(78401),
	(78402),
	(78403),
	(78404),
	(78405),
	(78406),
	(78407),
	(78408),
	(78409),
	(78410),
	(78411),
	(78412),
	(78413),
	(78414),
	(78415),
	(78416),
	(78417),
	(78418),
	(78419),
	(78420),
	(78421),
	(78422),
	(78423),
	(78424),
	(78425),
	(78426),
	(78427),
	(78428),
	(78429),
	(78430),
	(78431),
	(78432),
	(78433),
	(78434),
	(78435),
	(78436),
	(78437),
	(78438),
	(78439),
	(78440),
	(78441),
	(78442),
	(78443),
	(78444),
	(78445),
	(78446),
	(78447),
	(78448),
	(78449),
	(78450),
	(78451),
	(78452),
	(78453),
	(78454),
	(78455),
	(78456),
	(78457),
	(78458),
	(78459),
	(78460),
	(78461),
	(78462),
	(78463),
	(78464),
	(78465),
	(78466),
	(78467),
	(78468),
	(78469),
	(78470),
	(78471),
	(78472),
	(78473),
	(78474),
	(78475),
	(78476),
	(78477),
	(78478),
	(78479),
	(78480),
	(78481),
	(78482),
	(78483),
	(78484),
	(78485),
	(78486),
	(78487),
	(78488),
	(78489),
	(78490),
	(78491),
	(78492),
	(78493),
	(78494),
	(78495),
	(78496),
	(78497),
	(78498),
	(78499),
	(78500),
	(78501),
	(78502),
	(78503),
	(78504),
	(78505),
	(78506),
	(78507),
	(78508),
	(78509),
	(78510),
	(78511),
	(78512),
	(78513),
	(78514),
	(78515),
	(78516),
	(78517),
	(78518),
	(78519),
	(78520),
	(78521),
	(78522),
	(78523),
	(78524),
	(78525),
	(78526),
	(78527),
	(78528),
	(78529),
	(78530),
	(78531),
	(78532),
	(78533),
	(78534),
	(78535),
	(78536),
	(78537),
	(78538),
	(78539),
	(78540),
	(78541),
	(78542),
	(78543),
	(78544),
	(78545),
	(78546),
	(78547),
	(78548),
	(78549),
	(78550),
	(78551),
	(78552),
	(78553),
	(78554),
	(78555),
	(78556),
	(78557),
	(78558),
	(78559),
	(78560),
	(78561),
	(78562),
	(78563),
	(78564),
	(78565),
	(78566),
	(78567),
	(78568),
	(78569),
	(78570),
	(78571),
	(78572),
	(78573),
	(78574),
	(78575),
	(78576),
	(78577),
	(78578),
	(78579),
	(78580),
	(78581),
	(78582),
	(78583),
	(78584),
	(78585),
	(78586),
	(78587),
	(78588),
	(78589),
	(78590),
	(78591),
	(78592),
	(78593),
	(78594),
	(78595),
	(78596),
	(78597),
	(78598),
	(78599),
	(78600),
	(78601),
	(78602),
	(78603),
	(78604),
	(78605),
	(78606),
	(78607),
	(78608),
	(78609),
	(78610),
	(78611),
	(78612),
	(78613),
	(78614),
	(78615),
	(78616),
	(78617),
	(78618),
	(78619),
	(78620),
	(78621),
	(78622),
	(78623),
	(78624),
	(78625),
	(78626),
	(78627),
	(78628),
	(78629),
	(78630),
	(78631),
	(78632),
	(78633),
	(78634),
	(78635),
	(78636),
	(78637),
	(78638),
	(78639),
	(78640),
	(78641),
	(78642),
	(78643),
	(78644),
	(78645),
	(78646),
	(78647),
	(78648),
	(78649),
	(78650),
	(78651),
	(78652),
	(78653),
	(78654),
	(78655),
	(78656),
	(78657),
	(78658),
	(78659),
	(78660),
	(78661),
	(78662),
	(78663),
	(78664),
	(78665),
	(78666),
	(78667),
	(78668),
	(78669),
	(78670),
	(78671),
	(78672),
	(78673),
	(78674),
	(78675),
	(78676),
	(78677),
	(78678),
	(78679),
	(78680),
	(78681),
	(78682),
	(78683),
	(78684),
	(78685),
	(78686),
	(78687),
	(78688),
	(78689),
	(78690),
	(78691),
	(78692),
	(78693),
	(78694),
	(78695),
	(78696),
	(78697),
	(78698),
	(78699),
	(78700),
	(78701),
	(78702),
	(78703),
	(78704),
	(78705),
	(78706),
	(78707),
	(78708),
	(78709),
	(78710),
	(78711),
	(78712),
	(78713),
	(78714),
	(78715),
	(78716),
	(78717),
	(78718),
	(78719),
	(78720),
	(78721),
	(78722),
	(78723),
	(78724),
	(78725),
	(78726),
	(78727),
	(78728),
	(78729),
	(78730),
	(78731),
	(78732),
	(78733),
	(78734),
	(78735),
	(78736),
	(78737),
	(78738),
	(78739),
	(78740),
	(78741),
	(78742),
	(78743),
	(78744),
	(78745),
	(78746),
	(78747),
	(78748),
	(78749),
	(78750),
	(78751),
	(78752),
	(78753),
	(78754),
	(78755),
	(78756),
	(78757),
	(78758),
	(78759),
	(78760),
	(78761),
	(78762),
	(78763),
	(78764),
	(78765),
	(78766),
	(78767),
	(78768),
	(78769),
	(78770),
	(78771),
	(78772),
	(78773),
	(78774),
	(78775),
	(78776),
	(78777),
	(78778),
	(78779),
	(78780),
	(78781),
	(78782),
	(78783),
	(78784),
	(78785),
	(78786),
	(78787),
	(78788),
	(78789),
	(78790),
	(78791),
	(78792),
	(78793),
	(78794),
	(78795),
	(78796),
	(78797),
	(78798),
	(78799),
	(78800),
	(78801),
	(78802),
	(78803),
	(78804),
	(78805),
	(78806),
	(78807),
	(78808),
	(78809),
	(78810),
	(78811),
	(78812),
	(78813),
	(78814),
	(78815),
	(78816),
	(78817),
	(78818),
	(78819),
	(78820),
	(78821),
	(78822),
	(78823),
	(78824),
	(78825),
	(78826),
	(78827),
	(78828),
	(78829),
	(78830),
	(78831),
	(78832),
	(78833),
	(78834),
	(78835),
	(78836),
	(78837),
	(78838),
	(78839),
	(78840),
	(78841),
	(78842),
	(78843),
	(78844),
	(78845),
	(78846),
	(78847),
	(78848),
	(78849),
	(78850),
	(78851),
	(78852),
	(78853),
	(78854),
	(78855),
	(78856),
	(78857),
	(78858),
	(78859),
	(78860),
	(78861),
	(78862),
	(78863),
	(78864),
	(78865),
	(78866),
	(78867),
	(78868),
	(78869),
	(78870),
	(78871),
	(78872),
	(78873),
	(78874),
	(78875),
	(78876),
	(78877),
	(78878),
	(78879),
	(78880),
	(78881),
	(78882),
	(78883),
	(78884),
	(78885),
	(78886),
	(78887),
	(78888),
	(78889),
	(78890),
	(78891),
	(78892),
	(78893),
	(78894),
	(78895),
	(78896),
	(78897),
	(78898),
	(78899),
	(78900),
	(78901),
	(78902),
	(78903),
	(78904),
	(78905),
	(78906),
	(78907),
	(78908),
	(78909),
	(78910),
	(78911),
	(78912),
	(78913),
	(78914),
	(78915),
	(78916),
	(78917),
	(78918),
	(78919),
	(78920),
	(78921),
	(78922),
	(78923),
	(78924),
	(78925),
	(78926),
	(78927),
	(78928),
	(78929),
	(78930),
	(78931),
	(78932),
	(78933),
	(78934),
	(78935),
	(78936),
	(78937),
	(78938),
	(78939),
	(78940),
	(78941),
	(78942),
	(78943),
	(78944),
	(78945),
	(78946),
	(78947),
	(78948),
	(78949),
	(78950),
	(78951),
	(78952),
	(78953),
	(78954),
	(78955),
	(78956),
	(78957),
	(78958),
	(78959),
	(78960),
	(78961),
	(78962),
	(78963),
	(78964),
	(78965),
	(78966),
	(78967),
	(78968),
	(78969),
	(78970),
	(78971),
	(78972),
	(78973),
	(78974),
	(78975),
	(78976),
	(78977),
	(78978),
	(78979),
	(78980),
	(78981),
	(78982),
	(78983),
	(78984),
	(78985),
	(78986),
	(78987),
	(78988),
	(78989),
	(78990),
	(78991),
	(78992),
	(78993),
	(78994),
	(78995),
	(78996),
	(78997),
	(78998),
	(78999),
	(79000),
	(79001),
	(79002),
	(79003),
	(79004),
	(79005),
	(79006),
	(79007),
	(79008),
	(79009),
	(79010),
	(79011),
	(79012),
	(79013),
	(79014),
	(79015),
	(79016),
	(79017),
	(79018),
	(79019),
	(79020),
	(79021),
	(79022),
	(79023),
	(79024),
	(79025),
	(79026),
	(79027),
	(79028),
	(79029),
	(79030),
	(79031),
	(79032),
	(79033),
	(79034),
	(79035),
	(79036),
	(79037),
	(79038),
	(79039),
	(79040),
	(79041),
	(79042),
	(79043),
	(79044),
	(79045),
	(79046),
	(79047),
	(79048),
	(79049),
	(79050),
	(79051),
	(79052),
	(79053),
	(79054),
	(79055),
	(79056),
	(79057),
	(79058),
	(79059),
	(79060),
	(79061),
	(79062),
	(79063),
	(79064),
	(79065),
	(79066),
	(79067),
	(79068),
	(79069),
	(79070),
	(79071),
	(79072),
	(79073),
	(79074),
	(79075),
	(79076),
	(79077),
	(79078),
	(79079),
	(79080),
	(79081),
	(79082),
	(79083),
	(79084),
	(79085),
	(79086),
	(79087),
	(79088),
	(79089),
	(79090),
	(79091),
	(79092),
	(79093),
	(79094),
	(79095),
	(79096),
	(79097),
	(79098),
	(79099),
	(79100),
	(79101),
	(79102),
	(79103),
	(79104),
	(79105),
	(79106),
	(79107),
	(79108),
	(79109),
	(79110),
	(79111),
	(79112),
	(79113),
	(79114),
	(79115),
	(79116),
	(79117),
	(79118),
	(79119),
	(79120),
	(79121),
	(79122),
	(79123),
	(79124),
	(79125),
	(79126),
	(79127),
	(79128),
	(79129),
	(79130),
	(79131),
	(79132),
	(79133),
	(79134),
	(79135),
	(79136),
	(79137),
	(79138),
	(79139),
	(79140),
	(79141),
	(79142),
	(79143),
	(79144),
	(79145),
	(79146),
	(79147),
	(79148),
	(79149),
	(79150),
	(79151),
	(79152),
	(79153),
	(79154),
	(79155),
	(79156),
	(79157),
	(79158),
	(79159),
	(79160),
	(79161),
	(79162),
	(79163),
	(79164),
	(79165),
	(79166),
	(79167),
	(79168),
	(79169),
	(79170),
	(79171),
	(79172),
	(79173),
	(79174),
	(79175),
	(79176),
	(79177),
	(79178),
	(79179),
	(79180),
	(79181),
	(79182),
	(79183),
	(79184),
	(79185),
	(79186),
	(79187),
	(79188),
	(79189),
	(79190),
	(79191),
	(79192),
	(79193),
	(79194),
	(79195),
	(79196),
	(79197),
	(79198),
	(79199),
	(79200),
	(79201),
	(79202),
	(79203),
	(79204),
	(79205),
	(79206),
	(79207),
	(79208),
	(79209),
	(79210),
	(79211),
	(79212),
	(79213),
	(79214),
	(79215),
	(79216),
	(79217),
	(79218),
	(79219),
	(79220),
	(79221),
	(79222),
	(79223),
	(79224),
	(79225),
	(79226),
	(79227),
	(79228),
	(79229),
	(79230),
	(79231),
	(79232),
	(79233),
	(79234),
	(79235),
	(79236),
	(79237),
	(79238),
	(79239),
	(79240),
	(79241),
	(79242),
	(79243),
	(79244),
	(79245),
	(79246),
	(79247),
	(79248),
	(79249),
	(79250),
	(79251),
	(79252),
	(79253),
	(79254),
	(79255),
	(79256),
	(79257),
	(79258),
	(79259),
	(79260),
	(79261),
	(79262),
	(79263),
	(79264),
	(79265),
	(79266),
	(79267),
	(79268),
	(79269),
	(79270),
	(79271),
	(79272),
	(79273),
	(79274),
	(79275),
	(79276),
	(79277),
	(79278),
	(79279),
	(79280),
	(79281),
	(79282),
	(79283),
	(79284),
	(79285),
	(79286),
	(79287),
	(79288),
	(79289),
	(79290),
	(79291),
	(79292),
	(79293),
	(79294),
	(79295),
	(79296),
	(79297),
	(79298),
	(79299),
	(79300),
	(79301),
	(79302),
	(79303),
	(79304),
	(79305),
	(79306),
	(79307),
	(79308),
	(79309),
	(79310),
	(79311),
	(79312),
	(79313),
	(79314),
	(79315),
	(79316),
	(79317),
	(79318),
	(79319),
	(79320),
	(79321),
	(79322),
	(79323),
	(79324),
	(79325),
	(79326),
	(79327),
	(79328),
	(79329),
	(79330),
	(79331),
	(79332),
	(79333),
	(79334),
	(79335),
	(79336),
	(79337),
	(79338),
	(79339),
	(79340),
	(79341),
	(79342),
	(79343),
	(79344),
	(79345),
	(79346),
	(79347),
	(79348),
	(79349),
	(79350),
	(79351),
	(79352),
	(79353),
	(79354),
	(79355),
	(79356),
	(79357),
	(79358),
	(79359),
	(79360),
	(79361),
	(79362),
	(79363),
	(79364),
	(79365),
	(79366),
	(79367),
	(79368),
	(79369),
	(79370),
	(79371),
	(79372),
	(79373),
	(79374),
	(79375),
	(79376),
	(79377),
	(79378),
	(79379),
	(79380),
	(79381),
	(79382),
	(79383),
	(79384),
	(79385),
	(79386),
	(79387),
	(79388),
	(79389),
	(79390),
	(79391),
	(79392),
	(79393),
	(79394),
	(79395),
	(79396),
	(79397),
	(79398),
	(79399),
	(79400),
	(79401),
	(79402),
	(79403),
	(79404),
	(79405),
	(79406),
	(79407),
	(79408),
	(79409),
	(79410),
	(79411),
	(79412),
	(79413),
	(79414),
	(79415),
	(79416),
	(79417),
	(79418),
	(79419),
	(79420),
	(79421),
	(79422),
	(79423),
	(79424),
	(79425),
	(79426),
	(79427),
	(79428),
	(79429),
	(79430),
	(79431),
	(79432),
	(79433),
	(79434),
	(79435),
	(79436),
	(79437),
	(79438),
	(79439),
	(79440),
	(79441),
	(79442),
	(79443),
	(79444),
	(79445),
	(79446),
	(79447),
	(79448),
	(79449),
	(79450),
	(79451),
	(79452),
	(79453),
	(79454),
	(79455),
	(79456),
	(79457),
	(79458),
	(79459),
	(79460),
	(79461),
	(79462),
	(79463),
	(79464),
	(79465),
	(79466),
	(79467),
	(79468),
	(79469),
	(79470),
	(79471),
	(79472),
	(79473),
	(79474),
	(79475),
	(79476),
	(79477),
	(79478),
	(79479),
	(79480),
	(79481),
	(79482),
	(79483),
	(79484),
	(79485),
	(79486),
	(79487),
	(79488),
	(79489),
	(79490),
	(79491),
	(79492),
	(79493),
	(79494),
	(79495),
	(79496),
	(79497),
	(79498),
	(79499),
	(79500),
	(79501),
	(79502),
	(79503),
	(79504),
	(79505),
	(79506),
	(79507),
	(79508),
	(79509),
	(79510),
	(79511),
	(79512),
	(79513),
	(79514),
	(79515),
	(79516),
	(79517),
	(79518),
	(79519),
	(79520),
	(79521),
	(79522),
	(79523),
	(79524),
	(79525),
	(79526),
	(79527),
	(79528),
	(79529),
	(79530),
	(79531),
	(79532),
	(79533),
	(79534),
	(79535),
	(79536),
	(79537),
	(79538),
	(79539),
	(79540),
	(79541),
	(79542),
	(79543),
	(79544),
	(79545),
	(79546),
	(79547),
	(79548),
	(79549),
	(79550),
	(79551),
	(79552),
	(79553),
	(79554),
	(79555),
	(79556),
	(79557),
	(79558),
	(79559),
	(79560),
	(79561),
	(79562),
	(79563),
	(79564),
	(79565),
	(79566),
	(79567),
	(79568),
	(79569),
	(79570),
	(79571),
	(79572),
	(79573),
	(79574),
	(79575),
	(79576),
	(79577),
	(79578),
	(79579),
	(79580),
	(79581),
	(79582),
	(79583),
	(79584),
	(79585),
	(79586),
	(79587),
	(79588),
	(79589),
	(79590),
	(79591),
	(79592),
	(79593),
	(79594),
	(79595),
	(79596),
	(79597),
	(79598),
	(79599),
	(79600),
	(79601),
	(79602),
	(79603),
	(79604),
	(79605),
	(79606),
	(79607),
	(79608),
	(79609),
	(79610),
	(79611),
	(79612),
	(79613),
	(79614),
	(79615),
	(79616),
	(79617),
	(79618),
	(79619),
	(79620),
	(79621),
	(79622),
	(79623),
	(79624),
	(79625),
	(79626),
	(79627),
	(79628),
	(79629),
	(79630),
	(79631),
	(79632),
	(79633),
	(79634),
	(79635),
	(79636),
	(79637),
	(79638),
	(79639),
	(79640),
	(79641),
	(79642),
	(79643),
	(79644),
	(79645),
	(79646),
	(79647),
	(79648),
	(79649),
	(79650),
	(79651),
	(79652),
	(79653),
	(79654),
	(79655),
	(79656),
	(79657),
	(79658),
	(79659),
	(79660),
	(79661),
	(79662),
	(79663),
	(79664),
	(79665),
	(79666),
	(79667),
	(79668),
	(79669),
	(79670),
	(79671),
	(79672),
	(79673),
	(79674),
	(79675),
	(79676),
	(79677),
	(79678),
	(79679),
	(79680),
	(79681),
	(79682),
	(79683),
	(79684),
	(79685),
	(79686),
	(79687),
	(79688),
	(79689),
	(79690),
	(79691),
	(79692),
	(79693),
	(79694),
	(79695),
	(79696),
	(79697),
	(79698),
	(79699),
	(79700),
	(79701),
	(79702),
	(79703),
	(79704),
	(79705),
	(79706),
	(79707),
	(79708),
	(79709),
	(79710),
	(79711),
	(79712),
	(79713),
	(79714),
	(79715),
	(79716),
	(79717),
	(79718),
	(79719),
	(79720),
	(79721),
	(79722),
	(79723),
	(79724),
	(79725),
	(79726),
	(79727),
	(79728),
	(79729),
	(79730),
	(79731),
	(79732),
	(79733),
	(79734),
	(79735),
	(79736),
	(79737),
	(79738),
	(79739),
	(79740),
	(79741),
	(79742),
	(79743),
	(79744),
	(79745),
	(79746),
	(79747),
	(79748),
	(79749),
	(79750),
	(79751),
	(79752),
	(79753),
	(79754),
	(79755),
	(79756),
	(79757),
	(79758),
	(79759),
	(79760),
	(79761),
	(79762),
	(79763),
	(79764),
	(79765),
	(79766),
	(79767),
	(79768),
	(79769),
	(79770),
	(79771),
	(79772),
	(79773),
	(79774),
	(79775),
	(79776),
	(79777),
	(79778),
	(79779),
	(79780),
	(79781),
	(79782),
	(79783),
	(79784),
	(79785),
	(79786),
	(79787),
	(79788),
	(79789),
	(79790),
	(79791),
	(79792),
	(79793),
	(79794),
	(79795),
	(79796),
	(79797),
	(79798),
	(79799),
	(79800),
	(79801),
	(79802),
	(79803),
	(79804),
	(79805),
	(79806),
	(79807),
	(79808),
	(79809),
	(79810),
	(79811),
	(79812),
	(79813),
	(79814),
	(79815),
	(79816),
	(79817),
	(79818),
	(79819),
	(79820),
	(79821),
	(79822),
	(79823),
	(79824),
	(79825),
	(79826),
	(79827),
	(79828),
	(79829),
	(79830),
	(79831),
	(79832),
	(79833),
	(79834),
	(79835),
	(79836),
	(79837),
	(79838),
	(79839),
	(79840),
	(79841),
	(79842),
	(79843),
	(79844),
	(79845),
	(79846),
	(79847),
	(79848),
	(79849),
	(79850),
	(79851),
	(79852),
	(79853),
	(79854),
	(79855),
	(79856),
	(79857),
	(79858),
	(79859),
	(79860),
	(79861),
	(79862),
	(79863),
	(79864),
	(79865),
	(79866),
	(79867),
	(79868),
	(79869),
	(79870),
	(79871),
	(79872),
	(79873),
	(79874),
	(79875),
	(79876),
	(79877),
	(79878),
	(79879),
	(79880),
	(79881),
	(79882),
	(79883),
	(79884),
	(79885),
	(79886),
	(79887),
	(79888),
	(79889),
	(79890),
	(79891),
	(79892),
	(79893),
	(79894),
	(79895),
	(79896),
	(79897),
	(79898),
	(79899),
	(79900),
	(79901),
	(79902),
	(79903),
	(79904),
	(79905),
	(79906),
	(79907),
	(79908),
	(79909),
	(79910),
	(79911),
	(79912),
	(79913),
	(79914),
	(79915),
	(79916),
	(79917),
	(79918),
	(79919),
	(79920),
	(79921),
	(79922),
	(79923),
	(79924),
	(79925),
	(79926),
	(79927),
	(79928),
	(79929),
	(79930),
	(79931),
	(79932),
	(79933),
	(79934),
	(79935),
	(79936),
	(79937),
	(79938),
	(79939),
	(79940),
	(79941),
	(79942),
	(79943),
	(79944),
	(79945),
	(79946),
	(79947),
	(79948),
	(79949),
	(79950),
	(79951),
	(79952),
	(79953),
	(79954),
	(79955),
	(79956),
	(79957),
	(79958),
	(79959),
	(79960),
	(79961),
	(79962),
	(79963),
	(79964),
	(79965),
	(79966),
	(79967),
	(79968),
	(79969),
	(79970),
	(79971),
	(79972),
	(79973),
	(79974),
	(79975),
	(79976),
	(79977),
	(79978),
	(79979),
	(79980),
	(79981),
	(79982),
	(79983),
	(79984),
	(79985),
	(79986),
	(79987),
	(79988),
	(79989),
	(79990),
	(79991),
	(79992),
	(79993),
	(79994),
	(79995),
	(79996),
	(79997),
	(79998),
	(79999),
	(80000),
	(80001),
	(80002),
	(80003),
	(80004),
	(80005),
	(80006),
	(80007),
	(80008),
	(80009),
	(80010),
	(80011),
	(80012),
	(80013),
	(80014),
	(80015),
	(80016),
	(80017),
	(80018),
	(80019),
	(80020),
	(80021),
	(80022),
	(80023),
	(80024),
	(80025),
	(80026),
	(80027),
	(80028),
	(80029),
	(80030),
	(80031),
	(80032),
	(80033),
	(80034),
	(80035),
	(80036),
	(80037),
	(80038),
	(80039),
	(80040),
	(80041),
	(80042),
	(80043),
	(80044),
	(80045),
	(80046),
	(80047),
	(80048),
	(80049),
	(80050),
	(80051),
	(80052),
	(80053),
	(80054),
	(80055),
	(80056),
	(80057),
	(80058),
	(80059),
	(80060),
	(80061),
	(80062),
	(80063),
	(80064),
	(80065),
	(80066),
	(80067),
	(80068),
	(80069),
	(80070),
	(80071),
	(80072),
	(80073),
	(80074),
	(80075),
	(80076),
	(80077),
	(80078),
	(80079),
	(80080),
	(80081),
	(80082),
	(80083),
	(80084),
	(80085),
	(80086),
	(80087),
	(80088),
	(80089),
	(80090),
	(80091),
	(80092),
	(80093),
	(80094),
	(80095),
	(80096),
	(80097),
	(80098),
	(80099),
	(80100),
	(80101),
	(80102),
	(80103),
	(80104),
	(80105),
	(80106),
	(80107),
	(80108),
	(80109),
	(80110),
	(80111),
	(80112),
	(80113),
	(80114),
	(80115),
	(80116),
	(80117),
	(80118),
	(80119),
	(80120),
	(80121),
	(80122),
	(80123),
	(80124),
	(80125),
	(80126),
	(80127),
	(80128),
	(80129),
	(80130),
	(80131),
	(80132),
	(80133),
	(80134),
	(80135),
	(80136),
	(80137),
	(80138),
	(80139),
	(80140),
	(80141),
	(80142),
	(80143),
	(80144),
	(80145),
	(80146),
	(80147),
	(80148),
	(80149),
	(80150),
	(80151),
	(80152),
	(80153),
	(80154),
	(80155),
	(80156),
	(80157),
	(80158),
	(80159),
	(80160),
	(80161),
	(80162),
	(80163),
	(80164),
	(80165),
	(80166),
	(80167),
	(80168),
	(80169),
	(80170),
	(80171),
	(80172),
	(80173),
	(80174),
	(80175),
	(80176),
	(80177),
	(80178),
	(80179),
	(80180),
	(80181),
	(80182),
	(80183),
	(80184),
	(80185),
	(80186),
	(80187),
	(80188),
	(80189),
	(80190),
	(80191),
	(80192),
	(80193),
	(80194),
	(80195),
	(80196),
	(80197),
	(80198),
	(80199),
	(80200),
	(80201),
	(80202),
	(80203),
	(80204),
	(80205),
	(80206),
	(80207),
	(80208),
	(80209),
	(80210),
	(80211),
	(80212),
	(80213),
	(80214),
	(80215),
	(80216),
	(80217),
	(80218),
	(80219),
	(80220),
	(80221),
	(80222),
	(80223),
	(80224),
	(80225),
	(80226),
	(80227),
	(80228),
	(80229),
	(80230),
	(80231),
	(80232),
	(80233),
	(80234),
	(80235),
	(80236),
	(80237),
	(80238),
	(80239),
	(80240),
	(80241),
	(80242),
	(80243),
	(80244),
	(80245),
	(80246),
	(80247),
	(80248),
	(80249),
	(80250),
	(80251),
	(80252),
	(80253),
	(80254),
	(80255),
	(80256),
	(80257),
	(80258),
	(80259),
	(80260),
	(80261),
	(80262),
	(80263),
	(80264),
	(80265),
	(80266),
	(80267),
	(80268),
	(80269),
	(80270),
	(80271),
	(80272),
	(80273),
	(80274),
	(80275),
	(80276),
	(80277),
	(80278),
	(80279),
	(80280),
	(80281),
	(80282),
	(80283),
	(80284),
	(80285),
	(80286),
	(80287),
	(80288),
	(80289),
	(80290),
	(80291),
	(80292),
	(80293),
	(80294),
	(80295),
	(80296),
	(80297),
	(80298),
	(80299),
	(80300),
	(80301),
	(80302),
	(80303),
	(80304),
	(80305),
	(80306),
	(80307),
	(80308),
	(80309),
	(80310),
	(80311),
	(80312),
	(80313),
	(80314),
	(80315),
	(80316),
	(80317),
	(80318),
	(80319),
	(80320),
	(80321),
	(80322),
	(80323),
	(80324),
	(80325),
	(80326),
	(80327),
	(80328),
	(80329),
	(80330),
	(80331),
	(80332),
	(80333),
	(80334),
	(80335),
	(80336),
	(80337),
	(80338),
	(80339),
	(80340),
	(80341),
	(80342),
	(80343),
	(80344),
	(80345),
	(80346),
	(80347),
	(80348),
	(80349),
	(80350),
	(80351),
	(80352),
	(80353),
	(80354),
	(80355),
	(80356),
	(80357),
	(80358),
	(80359),
	(80360),
	(80361),
	(80362),
	(80363),
	(80364),
	(80365),
	(80366),
	(80367),
	(80368),
	(80369),
	(80370),
	(80371),
	(80372),
	(80373),
	(80374),
	(80375),
	(80376),
	(80377),
	(80378),
	(80379),
	(80380),
	(80381),
	(80382),
	(80383),
	(80384),
	(80385),
	(80386),
	(80387),
	(80388),
	(80389),
	(80390),
	(80391),
	(80392),
	(80393),
	(80394),
	(80395),
	(80396),
	(80397),
	(80398),
	(80399),
	(80400),
	(80401),
	(80402),
	(80403),
	(80404),
	(80405),
	(80406),
	(80407),
	(80408),
	(80409),
	(80410),
	(80411),
	(80412),
	(80413),
	(80414),
	(80415),
	(80416),
	(80417),
	(80418),
	(80419),
	(80420),
	(80421),
	(80422),
	(80423),
	(80424),
	(80425),
	(80426),
	(80427),
	(80428),
	(80429),
	(80430),
	(80431),
	(80432),
	(80433),
	(80434),
	(80435),
	(80436),
	(80437),
	(80438),
	(80439),
	(80440),
	(80441),
	(80442),
	(80443),
	(80444),
	(80445),
	(80446),
	(80447),
	(80448),
	(80449),
	(80450),
	(80451),
	(80452),
	(80453),
	(80454),
	(80455),
	(80456),
	(80457),
	(80458),
	(80459),
	(80460),
	(80461),
	(80462),
	(80463),
	(80464),
	(80465),
	(80466),
	(80467),
	(80468),
	(80469),
	(80470),
	(80471),
	(80472),
	(80473),
	(80474),
	(80475),
	(80476),
	(80477),
	(80478),
	(80479),
	(80480),
	(80481),
	(80482),
	(80483),
	(80484),
	(80485),
	(80486),
	(80487),
	(80488),
	(80489),
	(80490),
	(80491),
	(80492),
	(80493),
	(80494),
	(80495),
	(80496),
	(80497),
	(80498),
	(80499),
	(80500),
	(80501),
	(80502),
	(80503),
	(80504),
	(80505),
	(80506),
	(80507),
	(80508),
	(80509),
	(80510),
	(80511),
	(80512),
	(80513),
	(80514),
	(80515),
	(80516),
	(80517),
	(80518),
	(80519),
	(80520),
	(80521),
	(80522),
	(80523),
	(80524),
	(80525),
	(80526),
	(80527),
	(80528),
	(80529),
	(80530),
	(80531),
	(80532),
	(80533),
	(80534),
	(80535),
	(80536),
	(80537),
	(80538),
	(80539),
	(80540),
	(80541),
	(80542),
	(80543),
	(80544),
	(80545),
	(80546),
	(80547),
	(80548),
	(80549),
	(80550),
	(80551),
	(80552),
	(80553),
	(80554),
	(80555),
	(80556),
	(80557),
	(80558),
	(80559),
	(80560),
	(80561),
	(80562),
	(80563),
	(80564),
	(80565),
	(80566),
	(80567),
	(80568),
	(80569),
	(80570),
	(80571),
	(80572),
	(80573),
	(80574),
	(80575),
	(80576),
	(80577),
	(80578),
	(80579),
	(80580),
	(80581),
	(80582),
	(80583),
	(80584),
	(80585),
	(80586),
	(80587),
	(80588),
	(80589),
	(80590),
	(80591),
	(80592),
	(80593),
	(80594),
	(80595),
	(80596),
	(80597),
	(80598),
	(80599),
	(80600),
	(80601),
	(80602),
	(80603),
	(80604),
	(80605),
	(80606),
	(80607),
	(80608),
	(80609),
	(80610),
	(80611),
	(80612),
	(80613),
	(80614),
	(80615),
	(80616),
	(80617),
	(80618),
	(80619),
	(80620),
	(80621),
	(80622),
	(80623),
	(80624),
	(80625),
	(80626),
	(80627),
	(80628),
	(80629),
	(80630),
	(80631),
	(80632),
	(80633),
	(80634),
	(80635),
	(80636),
	(80637),
	(80638),
	(80639),
	(80640),
	(80641),
	(80642),
	(80643),
	(80644),
	(80645),
	(80646),
	(80647),
	(80648),
	(80649),
	(80650),
	(80651),
	(80652),
	(80653),
	(80654),
	(80655),
	(80656),
	(80657),
	(80658),
	(80659),
	(80660),
	(80661),
	(80662),
	(80663),
	(80664),
	(80665),
	(80666),
	(80667),
	(80668),
	(80669),
	(80670),
	(80671),
	(80672),
	(80673),
	(80674),
	(80675),
	(80676),
	(80677),
	(80678),
	(80679),
	(80680),
	(80681),
	(80682),
	(80683),
	(80684),
	(80685),
	(80686),
	(80687),
	(80688),
	(80689),
	(80690),
	(80691),
	(80692),
	(80693),
	(80694),
	(80695),
	(80696),
	(80697),
	(80698),
	(80699),
	(80700),
	(80701),
	(80702),
	(80703),
	(80704),
	(80705),
	(80706),
	(80707),
	(80708),
	(80709),
	(80710),
	(80711),
	(80712),
	(80713),
	(80714),
	(80715),
	(80716),
	(80717),
	(80718),
	(80719),
	(80720),
	(80721),
	(80722),
	(80723),
	(80724),
	(80725),
	(80726),
	(80727),
	(80728),
	(80729),
	(80730),
	(80731),
	(80732),
	(80733),
	(80734),
	(80735),
	(80736),
	(80737),
	(80738),
	(80739),
	(80740),
	(80741),
	(80742),
	(80743),
	(80744),
	(80745),
	(80746),
	(80747),
	(80748),
	(80749),
	(80750),
	(80751),
	(80752),
	(80753),
	(80754),
	(80755),
	(80756),
	(80757),
	(80758),
	(80759),
	(80760),
	(80761),
	(80762),
	(80763),
	(80764),
	(80765),
	(80766),
	(80767),
	(80768),
	(80769),
	(80770),
	(80771),
	(80772),
	(80773),
	(80774),
	(80775),
	(80776),
	(80777),
	(80778),
	(80779),
	(80780),
	(80781),
	(80782),
	(80783),
	(80784),
	(80785),
	(80786),
	(80787),
	(80788),
	(80789),
	(80790),
	(80791),
	(80792),
	(80793),
	(80794),
	(80795),
	(80796),
	(80797),
	(80798),
	(80799),
	(80800),
	(80801),
	(80802),
	(80803),
	(80804),
	(80805),
	(80806),
	(80807),
	(80808),
	(80809),
	(80810),
	(80811),
	(80812),
	(80813),
	(80814),
	(80815),
	(80816),
	(80817),
	(80818),
	(80819),
	(80820),
	(80821),
	(80822),
	(80823),
	(80824),
	(80825),
	(80826),
	(80827),
	(80828),
	(80829),
	(80830),
	(80831),
	(80832),
	(80833),
	(80834),
	(80835),
	(80836),
	(80837),
	(80838),
	(80839),
	(80840),
	(80841),
	(80842),
	(80843),
	(80844),
	(80845),
	(80846),
	(80847),
	(80848),
	(80849),
	(80850),
	(80851),
	(80852),
	(80853),
	(80854),
	(80855),
	(80856),
	(80857),
	(80858),
	(80859),
	(80860),
	(80861),
	(80862),
	(80863),
	(80864),
	(80865),
	(80866),
	(80867),
	(80868),
	(80869),
	(80870),
	(80871),
	(80872),
	(80873),
	(80874),
	(80875),
	(80876),
	(80877),
	(80878),
	(80879),
	(80880),
	(80881),
	(80882),
	(80883),
	(80884),
	(80885),
	(80886),
	(80887),
	(80888),
	(80889),
	(80890),
	(80891),
	(80892),
	(80893),
	(80894),
	(80895),
	(80896),
	(80897),
	(80898),
	(80899),
	(80900),
	(80901),
	(80902),
	(80903),
	(80904),
	(80905),
	(80906),
	(80907),
	(80908),
	(80909),
	(80910),
	(80911),
	(80912),
	(80913),
	(80914),
	(80915),
	(80916),
	(80917),
	(80918),
	(80919),
	(80920),
	(80921),
	(80922),
	(80923),
	(80924),
	(80925),
	(80926),
	(80927),
	(80928),
	(80929),
	(80930),
	(80931),
	(80932),
	(80933),
	(80934),
	(80935),
	(80936),
	(80937),
	(80938),
	(80939),
	(80940),
	(80941),
	(80942),
	(80943),
	(80944),
	(80945),
	(80946),
	(80947),
	(80948),
	(80949),
	(80950),
	(80951),
	(80952),
	(80953),
	(80954),
	(80955),
	(80956),
	(80957),
	(80958),
	(80959),
	(80960),
	(80961),
	(80962),
	(80963),
	(80964),
	(80965),
	(80966),
	(80967),
	(80968),
	(80969),
	(80970),
	(80971),
	(80972),
	(80973),
	(80974),
	(80975),
	(80976),
	(80977),
	(80978),
	(80979),
	(80980),
	(80981),
	(80982),
	(80983),
	(80984),
	(80985),
	(80986),
	(80987),
	(80988),
	(80989),
	(80990),
	(80991),
	(80992),
	(80993),
	(80994),
	(80995),
	(80996),
	(80997),
	(80998),
	(80999),
	(81000),
	(81001),
	(81002),
	(81003),
	(81004),
	(81005),
	(81006),
	(81007),
	(81008),
	(81009),
	(81010),
	(81011),
	(81012),
	(81013),
	(81014),
	(81015),
	(81016),
	(81017),
	(81018),
	(81019),
	(81020),
	(81021),
	(81022),
	(81023),
	(81024),
	(81025),
	(81026),
	(81027),
	(81028),
	(81029),
	(81030),
	(81031),
	(81032),
	(81033),
	(81034),
	(81035),
	(81036),
	(81037),
	(81038),
	(81039),
	(81040),
	(81041),
	(81042),
	(81043),
	(81044),
	(81045),
	(81046),
	(81047),
	(81048),
	(81049),
	(81050),
	(81051),
	(81052),
	(81053),
	(81054),
	(81055),
	(81056),
	(81057),
	(81058),
	(81059),
	(81060),
	(81061),
	(81062),
	(81063),
	(81064),
	(81065),
	(81066),
	(81067),
	(81068),
	(81069),
	(81070),
	(81071),
	(81072),
	(81073),
	(81074),
	(81075),
	(81076),
	(81077),
	(81078),
	(81079),
	(81080),
	(81081),
	(81082),
	(81083),
	(81084),
	(81085),
	(81086),
	(81087),
	(81088),
	(81089),
	(81090),
	(81091),
	(81092),
	(81093),
	(81094),
	(81095),
	(81096),
	(81097),
	(81098),
	(81099),
	(81100),
	(81101),
	(81102),
	(81103),
	(81104),
	(81105),
	(81106),
	(81107),
	(81108),
	(81109),
	(81110),
	(81111),
	(81112),
	(81113),
	(81114),
	(81115),
	(81116),
	(81117),
	(81118),
	(81119),
	(81120),
	(81121),
	(81122),
	(81123),
	(81124),
	(81125),
	(81126),
	(81127),
	(81128),
	(81129),
	(81130),
	(81131),
	(81132),
	(81133),
	(81134),
	(81135),
	(81136),
	(81137),
	(81138),
	(81139),
	(81140),
	(81141),
	(81142),
	(81143),
	(81144),
	(81145),
	(81146),
	(81147),
	(81148),
	(81149),
	(81150),
	(81151),
	(81152),
	(81153),
	(81154),
	(81155),
	(81156),
	(81157),
	(81158),
	(81159),
	(81160),
	(81161),
	(81162),
	(81163),
	(81164),
	(81165),
	(81166),
	(81167),
	(81168),
	(81169),
	(81170),
	(81171),
	(81172),
	(81173),
	(81174),
	(81175),
	(81176),
	(81177),
	(81178),
	(81179),
	(81180),
	(81181),
	(81182),
	(81183),
	(81184),
	(81185),
	(81186),
	(81187),
	(81188),
	(81189),
	(81190),
	(81191),
	(81192),
	(81193),
	(81194),
	(81195),
	(81196),
	(81197),
	(81198),
	(81199),
	(81200),
	(81201),
	(81202),
	(81203),
	(81204),
	(81205),
	(81206),
	(81207),
	(81208),
	(81209),
	(81210),
	(81211),
	(81212),
	(81213),
	(81214),
	(81215),
	(81216),
	(81217),
	(81218),
	(81219),
	(81220),
	(81221),
	(81222),
	(81223),
	(81224),
	(81225),
	(81226),
	(81227),
	(81228),
	(81229),
	(81230),
	(81231),
	(81232),
	(81233),
	(81234),
	(81235),
	(81236),
	(81237),
	(81238),
	(81239),
	(81240),
	(81241),
	(81242),
	(81243),
	(81244),
	(81245),
	(81246),
	(81247),
	(81248),
	(81249),
	(81250),
	(81251),
	(81252),
	(81253),
	(81254),
	(81255),
	(81256),
	(81257),
	(81258),
	(81259),
	(81260),
	(81261),
	(81262),
	(81263),
	(81264),
	(81265),
	(81266),
	(81267),
	(81268),
	(81269),
	(81270),
	(81271),
	(81272),
	(81273),
	(81274),
	(81275),
	(81276),
	(81277),
	(81278),
	(81279),
	(81280),
	(81281),
	(81282),
	(81283),
	(81284),
	(81285),
	(81286),
	(81287),
	(81288),
	(81289),
	(81290),
	(81291),
	(81292),
	(81293),
	(81294),
	(81295),
	(81296),
	(81297),
	(81298),
	(81299),
	(81300),
	(81301),
	(81302),
	(81303),
	(81304),
	(81305),
	(81306),
	(81307),
	(81308),
	(81309),
	(81310),
	(81311),
	(81312),
	(81313),
	(81314),
	(81315),
	(81316),
	(81317),
	(81318),
	(81319),
	(81320),
	(81321),
	(81322),
	(81323),
	(81324),
	(81325),
	(81326),
	(81327),
	(81328),
	(81329),
	(81330),
	(81331),
	(81332),
	(81333),
	(81334),
	(81335),
	(81336),
	(81337),
	(81338),
	(81339),
	(81340),
	(81341),
	(81342),
	(81343),
	(81344),
	(81345),
	(81346),
	(81347),
	(81348),
	(81349),
	(81350),
	(81351),
	(81352),
	(81353),
	(81354),
	(81355),
	(81356),
	(81357),
	(81358),
	(81359),
	(81360),
	(81361),
	(81362),
	(81363),
	(81364),
	(81365),
	(81366),
	(81367),
	(81368),
	(81369),
	(81370),
	(81371),
	(81372),
	(81373),
	(81374),
	(81375),
	(81376),
	(81377),
	(81378),
	(81379),
	(81380),
	(81381),
	(81382),
	(81383),
	(81384),
	(81385),
	(81386),
	(81387),
	(81388),
	(81389),
	(81390),
	(81391),
	(81392),
	(81393),
	(81394),
	(81395),
	(81396),
	(81397),
	(81398),
	(81399),
	(81400),
	(81401),
	(81402),
	(81403),
	(81404),
	(81405),
	(81406),
	(81407),
	(81408),
	(81409),
	(81410),
	(81411),
	(81412),
	(81413),
	(81414),
	(81415),
	(81416),
	(81417),
	(81418),
	(81419),
	(81420),
	(81421),
	(81422),
	(81423),
	(81424),
	(81425),
	(81426),
	(81427),
	(81428),
	(81429),
	(81430),
	(81431),
	(81432),
	(81433),
	(81434),
	(81435),
	(81436),
	(81437),
	(81438),
	(81439),
	(81440),
	(81441),
	(81442),
	(81443),
	(81444),
	(81445),
	(81446),
	(81447),
	(81448),
	(81449),
	(81450),
	(81451),
	(81452),
	(81453),
	(81454),
	(81455),
	(81456),
	(81457),
	(81458),
	(81459),
	(81460),
	(81461),
	(81462),
	(81463),
	(81464),
	(81465),
	(81466),
	(81467),
	(81468),
	(81469),
	(81470),
	(81471),
	(81472),
	(81473),
	(81474),
	(81475),
	(81476),
	(81477),
	(81478),
	(81479),
	(81480),
	(81481),
	(81482),
	(81483),
	(81484),
	(81485),
	(81486),
	(81487),
	(81488),
	(81489),
	(81490),
	(81491),
	(81492),
	(81493),
	(81494),
	(81495),
	(81496),
	(81497),
	(81498),
	(81499),
	(81500),
	(81501),
	(81502),
	(81503),
	(81504),
	(81505),
	(81506),
	(81507),
	(81508),
	(81509),
	(81510),
	(81511),
	(81512),
	(81513),
	(81514),
	(81515),
	(81516),
	(81517),
	(81518),
	(81519),
	(81520),
	(81521),
	(81522),
	(81523),
	(81524),
	(81525),
	(81526),
	(81527),
	(81528),
	(81529),
	(81530),
	(81531),
	(81532),
	(81533),
	(81534),
	(81535),
	(81536),
	(81537),
	(81538),
	(81539),
	(81540),
	(81541),
	(81542),
	(81543),
	(81544),
	(81545),
	(81546),
	(81547),
	(81548),
	(81549),
	(81550),
	(81551),
	(81552),
	(81553),
	(81554),
	(81555),
	(81556),
	(81557),
	(81558),
	(81559),
	(81560),
	(81561),
	(81562),
	(81563),
	(81564),
	(81565),
	(81566),
	(81567),
	(81568),
	(81569),
	(81570),
	(81571),
	(81572),
	(81573),
	(81574),
	(81575),
	(81576),
	(81577),
	(81578),
	(81579),
	(81580),
	(81581),
	(81582),
	(81583),
	(81584),
	(81585),
	(81586),
	(81587),
	(81588),
	(81589),
	(81590),
	(81591),
	(81592),
	(81593),
	(81594),
	(81595),
	(81596),
	(81597),
	(81598),
	(81599),
	(81600),
	(81601),
	(81602),
	(81603),
	(81604),
	(81605),
	(81606),
	(81607),
	(81608),
	(81609),
	(81610),
	(81611),
	(81612),
	(81613),
	(81614),
	(81615),
	(81616),
	(81617),
	(81618),
	(81619),
	(81620),
	(81621),
	(81622),
	(81623),
	(81624),
	(81625),
	(81626),
	(81627),
	(81628),
	(81629),
	(81630),
	(81631),
	(81632),
	(81633),
	(81634),
	(81635),
	(81636),
	(81637),
	(81638),
	(81639),
	(81640),
	(81641),
	(81642),
	(81643),
	(81644),
	(81645),
	(81646),
	(81647),
	(81648),
	(81649),
	(81650),
	(81651),
	(81652),
	(81653),
	(81654),
	(81655),
	(81656),
	(81657),
	(81658),
	(81659),
	(81660),
	(81661),
	(81662),
	(81663),
	(81664),
	(81665),
	(81666),
	(81667),
	(81668),
	(81669),
	(81670),
	(81671),
	(81672),
	(81673),
	(81674),
	(81675),
	(81676),
	(81677),
	(81678),
	(81679),
	(81680),
	(81681),
	(81682),
	(81683),
	(81684),
	(81685),
	(81686),
	(81687),
	(81688),
	(81689),
	(81690),
	(81691),
	(81692),
	(81693),
	(81694),
	(81695),
	(81696),
	(81697),
	(81698),
	(81699),
	(81700),
	(81701),
	(81702),
	(81703),
	(81704),
	(81705),
	(81706),
	(81707),
	(81708),
	(81709),
	(81710),
	(81711),
	(81712),
	(81713),
	(81714),
	(81715),
	(81716),
	(81717),
	(81718),
	(81719),
	(81720),
	(81721),
	(81722),
	(81723),
	(81724),
	(81725),
	(81726),
	(81727),
	(81728),
	(81729),
	(81730),
	(81731),
	(81732),
	(81733),
	(81734),
	(81735),
	(81736),
	(81737),
	(81738),
	(81739),
	(81740),
	(81741),
	(81742),
	(81743),
	(81744),
	(81745),
	(81746),
	(81747),
	(81748),
	(81749),
	(81750),
	(81751),
	(81752),
	(81753),
	(81754),
	(81755),
	(81756),
	(81757),
	(81758),
	(81759),
	(81760),
	(81761),
	(81762),
	(81763),
	(81764),
	(81765),
	(81766),
	(81767),
	(81768),
	(81769),
	(81770),
	(81771),
	(81772),
	(81773),
	(81774),
	(81775),
	(81776),
	(81777),
	(81778),
	(81779),
	(81780),
	(81781),
	(81782),
	(81783),
	(81784),
	(81785),
	(81786),
	(81787),
	(81788),
	(81789),
	(81790),
	(81791),
	(81792),
	(81793),
	(81794),
	(81795),
	(81796),
	(81797),
	(81798),
	(81799),
	(81800),
	(81801),
	(81802),
	(81803),
	(81804),
	(81805),
	(81806),
	(81807),
	(81808),
	(81809),
	(81810),
	(81811),
	(81812),
	(81813),
	(81814),
	(81815),
	(81816),
	(81817),
	(81818),
	(81819),
	(81820),
	(81821),
	(81822),
	(81823),
	(81824),
	(81825),
	(81826),
	(81827),
	(81828),
	(81829),
	(81830),
	(81831),
	(81832),
	(81833),
	(81834),
	(81835),
	(81836),
	(81837),
	(81838),
	(81839),
	(81840),
	(81841),
	(81842),
	(81843),
	(81844),
	(81845),
	(81846),
	(81847),
	(81848),
	(81849),
	(81850),
	(81851),
	(81852),
	(81853),
	(81854),
	(81855),
	(81856),
	(81857),
	(81858),
	(81859),
	(81860),
	(81861),
	(81862),
	(81863),
	(81864),
	(81865),
	(81866),
	(81867),
	(81868),
	(81869),
	(81870),
	(81871),
	(81872),
	(81873),
	(81874),
	(81875),
	(81876),
	(81877),
	(81878),
	(81879),
	(81880),
	(81881),
	(81882),
	(81883),
	(81884),
	(81885),
	(81886),
	(81887),
	(81888),
	(81889),
	(81890),
	(81891),
	(81892),
	(81893),
	(81894),
	(81895),
	(81896),
	(81897),
	(81898),
	(81899),
	(81900),
	(81901),
	(81902),
	(81903),
	(81904),
	(81905),
	(81906),
	(81907),
	(81908),
	(81909),
	(81910),
	(81911),
	(81912),
	(81913),
	(81914),
	(81915),
	(81916),
	(81917),
	(81918),
	(81919),
	(81920),
	(81921),
	(81922),
	(81923),
	(81924),
	(81925),
	(81926),
	(81927),
	(81928),
	(81929),
	(81930),
	(81931),
	(81932),
	(81933),
	(81934),
	(81935),
	(81936),
	(81937),
	(81938),
	(81939),
	(81940),
	(81941),
	(81942),
	(81943),
	(81944),
	(81945),
	(81946),
	(81947),
	(81948),
	(81949),
	(81950),
	(81951),
	(81952),
	(81953),
	(81954),
	(81955),
	(81956),
	(81957),
	(81958),
	(81959),
	(81960),
	(81961),
	(81962),
	(81963),
	(81964),
	(81965),
	(81966),
	(81967),
	(81968),
	(81969),
	(81970),
	(81971),
	(81972),
	(81973),
	(81974),
	(81975),
	(81976),
	(81977),
	(81978),
	(81979),
	(81980),
	(81981),
	(81982),
	(81983),
	(81984),
	(81985),
	(81986),
	(81987),
	(81988),
	(81989),
	(81990),
	(81991),
	(81992),
	(81993),
	(81994),
	(81995),
	(81996),
	(81997),
	(81998),
	(81999),
	(82000),
	(82001),
	(82002),
	(82003),
	(82004),
	(82005),
	(82006),
	(82007),
	(82008),
	(82009),
	(82010),
	(82011),
	(82012),
	(82013),
	(82014),
	(82015),
	(82016),
	(82017),
	(82018),
	(82019),
	(82020),
	(82021),
	(82022),
	(82023),
	(82024),
	(82025),
	(82026),
	(82027),
	(82028),
	(82029),
	(82030),
	(82031),
	(82032),
	(82033),
	(82034),
	(82035),
	(82036),
	(82037),
	(82038),
	(82039),
	(82040),
	(82041),
	(82042),
	(82043),
	(82044),
	(82045),
	(82046),
	(82047),
	(82048),
	(82049),
	(82050),
	(82051),
	(82052),
	(82053),
	(82054),
	(82055),
	(82056),
	(82057),
	(82058),
	(82059),
	(82060),
	(82061),
	(82062),
	(82063),
	(82064),
	(82065),
	(82066),
	(82067),
	(82068),
	(82069),
	(82070),
	(82071),
	(82072),
	(82073),
	(82074),
	(82075),
	(82076),
	(82077),
	(82078),
	(82079),
	(82080),
	(82081),
	(82082),
	(82083),
	(82084),
	(82085),
	(82086),
	(82087),
	(82088),
	(82089),
	(82090),
	(82091),
	(82092),
	(82093),
	(82094),
	(82095),
	(82096),
	(82097),
	(82098),
	(82099),
	(82100),
	(82101),
	(82102),
	(82103),
	(82104),
	(82105),
	(82106),
	(82107),
	(82108),
	(82109),
	(82110),
	(82111),
	(82112),
	(82113),
	(82114),
	(82115),
	(82116),
	(82117),
	(82118),
	(82119),
	(82120),
	(82121),
	(82122),
	(82123),
	(82124),
	(82125),
	(82126),
	(82127),
	(82128),
	(82129),
	(82130),
	(82131),
	(82132),
	(82133),
	(82134),
	(82135),
	(82136),
	(82137),
	(82138),
	(82139),
	(82140),
	(82141),
	(82142),
	(82143),
	(82144),
	(82145),
	(82146),
	(82147),
	(82148),
	(82149),
	(82150),
	(82151),
	(82152),
	(82153),
	(82154),
	(82155),
	(82156),
	(82157),
	(82158),
	(82159),
	(82160),
	(82161),
	(82162),
	(82163),
	(82164),
	(82165),
	(82166),
	(82167),
	(82168),
	(82169),
	(82170),
	(82171),
	(82172),
	(82173),
	(82174),
	(82175),
	(82176),
	(82177),
	(82178),
	(82179),
	(82180),
	(82181),
	(82182),
	(82183),
	(82184),
	(82185),
	(82186),
	(82187),
	(82188),
	(82189),
	(82190),
	(82191),
	(82192),
	(82193),
	(82194),
	(82195),
	(82196),
	(82197),
	(82198),
	(82199),
	(82200),
	(82201),
	(82202),
	(82203),
	(82204),
	(82205),
	(82206),
	(82207),
	(82208),
	(82209),
	(82210),
	(82211),
	(82212),
	(82213),
	(82214),
	(82215),
	(82216),
	(82217),
	(82218),
	(82219),
	(82220),
	(82221),
	(82222),
	(82223),
	(82224),
	(82225),
	(82226),
	(82227),
	(82228),
	(82229),
	(82230),
	(82231),
	(82232),
	(82233),
	(82234),
	(82235),
	(82236),
	(82237),
	(82238),
	(82239),
	(82240),
	(82241),
	(82242),
	(82243),
	(82244),
	(82245),
	(82246),
	(82247),
	(82248),
	(82249),
	(82250),
	(82251),
	(82252),
	(82253),
	(82254),
	(82255),
	(82256),
	(82257),
	(82258),
	(82259),
	(82260),
	(82261),
	(82262),
	(82263),
	(82264),
	(82265),
	(82266),
	(82267),
	(82268),
	(82269),
	(82270),
	(82271),
	(82272),
	(82273),
	(82274),
	(82275),
	(82276),
	(82277),
	(82278),
	(82279),
	(82280),
	(82281),
	(82282),
	(82283),
	(82284),
	(82285),
	(82286),
	(82287),
	(82288),
	(82289),
	(82290),
	(82291),
	(82292),
	(82293),
	(82294),
	(82295),
	(82296),
	(82297),
	(82298),
	(82299),
	(82300),
	(82301),
	(82302),
	(82303),
	(82304),
	(82305),
	(82306),
	(82307),
	(82308),
	(82309),
	(82310),
	(82311),
	(82312),
	(82313),
	(82314),
	(82315),
	(82316),
	(82317),
	(82318),
	(82319),
	(82320),
	(82321),
	(82322),
	(82323),
	(82324),
	(82325),
	(82326),
	(82327),
	(82328),
	(82329),
	(82330),
	(82331),
	(82332),
	(82333),
	(82334),
	(82335),
	(82336),
	(82337),
	(82338),
	(82339),
	(82340),
	(82341),
	(82342),
	(82343),
	(82344),
	(82345),
	(82346),
	(82347),
	(82348),
	(82349),
	(82350),
	(82351),
	(82352),
	(82353),
	(82354),
	(82355),
	(82356),
	(82357),
	(82358),
	(82359),
	(82360),
	(82361),
	(82362),
	(82363),
	(82364),
	(82365),
	(82366),
	(82367),
	(82368),
	(82369),
	(82370),
	(82371),
	(82372),
	(82373),
	(82374),
	(82375),
	(82376),
	(82377),
	(82378),
	(82379),
	(82380),
	(82381),
	(82382),
	(82383),
	(82384),
	(82385),
	(82386),
	(82387),
	(82388),
	(82389),
	(82390),
	(82391),
	(82392),
	(82393),
	(82394),
	(82395),
	(82396),
	(82397),
	(82398),
	(82399),
	(82400),
	(82401),
	(82402),
	(82403),
	(82404),
	(82405),
	(82406),
	(82407),
	(82408),
	(82409),
	(82410),
	(82411),
	(82412),
	(82413),
	(82414),
	(82415),
	(82416),
	(82417),
	(82418),
	(82419),
	(82420),
	(82421),
	(82422),
	(82423),
	(82424),
	(82425),
	(82426),
	(82427),
	(82428),
	(82429),
	(82430),
	(82431),
	(82432),
	(82433),
	(82434),
	(82435),
	(82436),
	(82437),
	(82438),
	(82439),
	(82440),
	(82441),
	(82442),
	(82443),
	(82444),
	(82445),
	(82446),
	(82447),
	(82448),
	(82449),
	(82450),
	(82451),
	(82452),
	(82453),
	(82454),
	(82455),
	(82456),
	(82457),
	(82458),
	(82459),
	(82460),
	(82461),
	(82462),
	(82463),
	(82464),
	(82465),
	(82466),
	(82467),
	(82468),
	(82469),
	(82470),
	(82471),
	(82472),
	(82473),
	(82474),
	(82475),
	(82476),
	(82477),
	(82478),
	(82479),
	(82480),
	(82481),
	(82482),
	(82483),
	(82484),
	(82485),
	(82486),
	(82487),
	(82488),
	(82489),
	(82490),
	(82491),
	(82492),
	(82493),
	(82494),
	(82495),
	(82496),
	(82497),
	(82498),
	(82499),
	(82500),
	(82501),
	(82502),
	(82503),
	(82504),
	(82505),
	(82506),
	(82507),
	(82508),
	(82509),
	(82510),
	(82511),
	(82512),
	(82513),
	(82514),
	(82515),
	(82516),
	(82517),
	(82518),
	(82519),
	(82520),
	(82521),
	(82522),
	(82523),
	(82524),
	(82525),
	(82526),
	(82527),
	(82528),
	(82529),
	(82530),
	(82531),
	(82532),
	(82533),
	(82534),
	(82535),
	(82536),
	(82537),
	(82538),
	(82539),
	(82540),
	(82541),
	(82542),
	(82543),
	(82544),
	(82545),
	(82546),
	(82547),
	(82548),
	(82549),
	(82550),
	(82551),
	(82552),
	(82553),
	(82554),
	(82555),
	(82556),
	(82557),
	(82558),
	(82559),
	(82560),
	(82561),
	(82562),
	(82563),
	(82564),
	(82565),
	(82566),
	(82567),
	(82568),
	(82569),
	(82570),
	(82571),
	(82572),
	(82573),
	(82574),
	(82575),
	(82576),
	(82577),
	(82578),
	(82579),
	(82580),
	(82581),
	(82582),
	(82583),
	(82584),
	(82585),
	(82586),
	(82587),
	(82588),
	(82589),
	(82590),
	(82591),
	(82592),
	(82593),
	(82594),
	(82595),
	(82596),
	(82597),
	(82598),
	(82599),
	(82600),
	(82601),
	(82602),
	(82603),
	(82604),
	(82605),
	(82606),
	(82607),
	(82608),
	(82609),
	(82610),
	(82611),
	(82612),
	(82613),
	(82614),
	(82615),
	(82616),
	(82617),
	(82618),
	(82619),
	(82620),
	(82621),
	(82622),
	(82623),
	(82624),
	(82625),
	(82626),
	(82627),
	(82628),
	(82629),
	(82630),
	(82631),
	(82632),
	(82633),
	(82634),
	(82635),
	(82636),
	(82637),
	(82638),
	(82639),
	(82640),
	(82641),
	(82642),
	(82643),
	(82644),
	(82645),
	(82646),
	(82647),
	(82648),
	(82649),
	(82650),
	(82651),
	(82652),
	(82653),
	(82654),
	(82655),
	(82656),
	(82657),
	(82658),
	(82659),
	(82660),
	(82661),
	(82662),
	(82663),
	(82664),
	(82665),
	(82666),
	(82667),
	(82668),
	(82669),
	(82670),
	(82671),
	(82672),
	(82673),
	(82674),
	(82675),
	(82676),
	(82677),
	(82678),
	(82679),
	(82680),
	(82681),
	(82682),
	(82683),
	(82684),
	(82685),
	(82686),
	(82687),
	(82688),
	(82689),
	(82690),
	(82691),
	(82692),
	(82693),
	(82694),
	(82695),
	(82696),
	(82697),
	(82698),
	(82699),
	(82700),
	(82701),
	(82702),
	(82703),
	(82704),
	(82705),
	(82706),
	(82707),
	(82708),
	(82709),
	(82710),
	(82711),
	(82712),
	(82713),
	(82714),
	(82715),
	(82716),
	(82717),
	(82718),
	(82719),
	(82720),
	(82721),
	(82722),
	(82723),
	(82724),
	(82725),
	(82726),
	(82727),
	(82728),
	(82729),
	(82730),
	(82731),
	(82732),
	(82733),
	(82734),
	(82735),
	(82736),
	(82737),
	(82738),
	(82739),
	(82740),
	(82741),
	(82742),
	(82743),
	(82744),
	(82745),
	(82746),
	(82747),
	(82748),
	(82749),
	(82750),
	(82751),
	(82752),
	(82753),
	(82754),
	(82755),
	(82756),
	(82757),
	(82758),
	(82759),
	(82760),
	(82761),
	(82762),
	(82763),
	(82764),
	(82765),
	(82766),
	(82767),
	(82768),
	(82769),
	(82770),
	(82771),
	(82772),
	(82773),
	(82774),
	(82775),
	(82776),
	(82777),
	(82778),
	(82779),
	(82780),
	(82781),
	(82782),
	(82783),
	(82784),
	(82785),
	(82786),
	(82787),
	(82788),
	(82789),
	(82790),
	(82791),
	(82792),
	(82793),
	(82794),
	(82795),
	(82796),
	(82797),
	(82798),
	(82799),
	(82800),
	(82801),
	(82802),
	(82803),
	(82804),
	(82805),
	(82806),
	(82807),
	(82808),
	(82809),
	(82810),
	(82811),
	(82812),
	(82813),
	(82814),
	(82815),
	(82816),
	(82817),
	(82818),
	(82819),
	(82820),
	(82821),
	(82822),
	(82823),
	(82824),
	(82825),
	(82826),
	(82827),
	(82828),
	(82829),
	(82830),
	(82831),
	(82832),
	(82833),
	(82834),
	(82835),
	(82836),
	(82837),
	(82838),
	(82839),
	(82840),
	(82841),
	(82842),
	(82843),
	(82844),
	(82845),
	(82846),
	(82847),
	(82848),
	(82849),
	(82850),
	(82851),
	(82852),
	(82853),
	(82854),
	(82855),
	(82856),
	(82857),
	(82858),
	(82859),
	(82860),
	(82861),
	(82862),
	(82863),
	(82864),
	(82865),
	(82866),
	(82867),
	(82868),
	(82869),
	(82870),
	(82871),
	(82872),
	(82873),
	(82874),
	(82875),
	(82876),
	(82877),
	(82878),
	(82879),
	(82880),
	(82881),
	(82882),
	(82883),
	(82884),
	(82885),
	(82886),
	(82887),
	(82888),
	(82889),
	(82890),
	(82891),
	(82892),
	(82893),
	(82894),
	(82895),
	(82896),
	(82897),
	(82898),
	(82899),
	(82900),
	(82901),
	(82902),
	(82903),
	(82904),
	(82905),
	(82906),
	(82907),
	(82908),
	(82909),
	(82910),
	(82911),
	(82912),
	(82913),
	(82914),
	(82915),
	(82916),
	(82917),
	(82918),
	(82919),
	(82920),
	(82921),
	(82922),
	(82923),
	(82924),
	(82925),
	(82926),
	(82927),
	(82928),
	(82929),
	(82930),
	(82931),
	(82932),
	(82933),
	(82934),
	(82935),
	(82936),
	(82937),
	(82938),
	(82939),
	(82940),
	(82941),
	(82942),
	(82943),
	(82944),
	(82945),
	(82946),
	(82947),
	(82948),
	(82949),
	(82950),
	(82951),
	(82952),
	(82953),
	(82954),
	(82955),
	(82956),
	(82957),
	(82958),
	(82959),
	(82960),
	(82961),
	(82962),
	(82963),
	(82964),
	(82965),
	(82966),
	(82967),
	(82968),
	(82969),
	(82970),
	(82971),
	(82972),
	(82973),
	(82974),
	(82975),
	(82976),
	(82977),
	(82978),
	(82979),
	(82980),
	(82981),
	(82982),
	(82983),
	(82984),
	(82985),
	(82986),
	(82987),
	(82988),
	(82989),
	(82990),
	(82991),
	(82992),
	(82993),
	(82994),
	(82995),
	(82996),
	(82997),
	(82998),
	(82999),
	(83000),
	(83001),
	(83002),
	(83003),
	(83004),
	(83005),
	(83006),
	(83007),
	(83008),
	(83009),
	(83010),
	(83011),
	(83012),
	(83013),
	(83014),
	(83015),
	(83016),
	(83017),
	(83018),
	(83019),
	(83020),
	(83021),
	(83022),
	(83023),
	(83024),
	(83025),
	(83026),
	(83027),
	(83028),
	(83029),
	(83030),
	(83031),
	(83032),
	(83033),
	(83034),
	(83035),
	(83036),
	(83037),
	(83038),
	(83039),
	(83040),
	(83041),
	(83042),
	(83043),
	(83044),
	(83045),
	(83046),
	(83047),
	(83048),
	(83049),
	(83050),
	(83051),
	(83052),
	(83053),
	(83054),
	(83055),
	(83056),
	(83057),
	(83058),
	(83059),
	(83060),
	(83061),
	(83062),
	(83063),
	(83064),
	(83065),
	(83066),
	(83067),
	(83068),
	(83069),
	(83070),
	(83071),
	(83072),
	(83073),
	(83074),
	(83075),
	(83076),
	(83077),
	(83078),
	(83079),
	(83080),
	(83081),
	(83082),
	(83083),
	(83084),
	(83085),
	(83086),
	(83087),
	(83088),
	(83089),
	(83090),
	(83091),
	(83092),
	(83093),
	(83094),
	(83095),
	(83096),
	(83097),
	(83098),
	(83099),
	(83100),
	(83101),
	(83102),
	(83103),
	(83104),
	(83105),
	(83106),
	(83107),
	(83108),
	(83109),
	(83110),
	(83111),
	(83112),
	(83113),
	(83114),
	(83115),
	(83116),
	(83117),
	(83118),
	(83119),
	(83120),
	(83121),
	(83122),
	(83123),
	(83124),
	(83125),
	(83126),
	(83127),
	(83128),
	(83129),
	(83130),
	(83131),
	(83132),
	(83133),
	(83134),
	(83135),
	(83136),
	(83137),
	(83138),
	(83139),
	(83140),
	(83141),
	(83142),
	(83143),
	(83144),
	(83145),
	(83146),
	(83147),
	(83148),
	(83149),
	(83150),
	(83151),
	(83152),
	(83153),
	(83154),
	(83155),
	(83156),
	(83157),
	(83158),
	(83159),
	(83160),
	(83161),
	(83162),
	(83163),
	(83164),
	(83165),
	(83166),
	(83167),
	(83168),
	(83169),
	(83170),
	(83171),
	(83172),
	(83173),
	(83174),
	(83175),
	(83176),
	(83177),
	(83178),
	(83179),
	(83180),
	(83181),
	(83182),
	(83183),
	(83184),
	(83185),
	(83186),
	(83187),
	(83188),
	(83189),
	(83190),
	(83191),
	(83192),
	(83193),
	(83194),
	(83195),
	(83196),
	(83197),
	(83198),
	(83199),
	(83200),
	(83201),
	(83202),
	(83203),
	(83204),
	(83205),
	(83206),
	(83207),
	(83208),
	(83209),
	(83210),
	(83211),
	(83212),
	(83213),
	(83214),
	(83215),
	(83216),
	(83217),
	(83218),
	(83219),
	(83220),
	(83221),
	(83222),
	(83223),
	(83224),
	(83225),
	(83226),
	(83227),
	(83228),
	(83229),
	(83230),
	(83231),
	(83232),
	(83233),
	(83234),
	(83235),
	(83236),
	(83237),
	(83238),
	(83239),
	(83240),
	(83241),
	(83242),
	(83243),
	(83244),
	(83245),
	(83246),
	(83247),
	(83248),
	(83249),
	(83250),
	(83251),
	(83252),
	(83253),
	(83254),
	(83255),
	(83256),
	(83257),
	(83258),
	(83259),
	(83260),
	(83261),
	(83262),
	(83263),
	(83264),
	(83265),
	(83266),
	(83267),
	(83268),
	(83269),
	(83270),
	(83271),
	(83272),
	(83273),
	(83274),
	(83275),
	(83276),
	(83277),
	(83278),
	(83279),
	(83280),
	(83281),
	(83282),
	(83283),
	(83284),
	(83285),
	(83286),
	(83287),
	(83288),
	(83289),
	(83290),
	(83291),
	(83292),
	(83293),
	(83294),
	(83295),
	(83296),
	(83297),
	(83298),
	(83299),
	(83300),
	(83301),
	(83302),
	(83303),
	(83304),
	(83305),
	(83306),
	(83307),
	(83308),
	(83309),
	(83310),
	(83311),
	(83312),
	(83313),
	(83314),
	(83315),
	(83316),
	(83317),
	(83318),
	(83319),
	(83320),
	(83321),
	(83322),
	(83323),
	(83324),
	(83325),
	(83326),
	(83327),
	(83328),
	(83329),
	(83330),
	(83331),
	(83332),
	(83333),
	(83334),
	(83335),
	(83336),
	(83337),
	(83338),
	(83339),
	(83340),
	(83341),
	(83342),
	(83343),
	(83344),
	(83345),
	(83346),
	(83347),
	(83348),
	(83349),
	(83350),
	(83351),
	(83352),
	(83353),
	(83354),
	(83355),
	(83356),
	(83357),
	(83358),
	(83359),
	(83360),
	(83361),
	(83362),
	(83363),
	(83364),
	(83365),
	(83366),
	(83367),
	(83368),
	(83369),
	(83370),
	(83371),
	(83372),
	(83373),
	(83374),
	(83375),
	(83376),
	(83377),
	(83378),
	(83379),
	(83380),
	(83381),
	(83382),
	(83383),
	(83384),
	(83385),
	(83386),
	(83387),
	(83388),
	(83389),
	(83390),
	(83391),
	(83392),
	(83393),
	(83394),
	(83395),
	(83396),
	(83397),
	(83398),
	(83399),
	(83400),
	(83401),
	(83402),
	(83403),
	(83404),
	(83405),
	(83406),
	(83407),
	(83408),
	(83409),
	(83410),
	(83411),
	(83412),
	(83413),
	(83414),
	(83415),
	(83416),
	(83417),
	(83418),
	(83419),
	(83420),
	(83421),
	(83422),
	(83423),
	(83424),
	(83425),
	(83426),
	(83427),
	(83428),
	(83429),
	(83430),
	(83431),
	(83432),
	(83433),
	(83434),
	(83435),
	(83436),
	(83437),
	(83438),
	(83439),
	(83440),
	(83441),
	(83442),
	(83443),
	(83444),
	(83445),
	(83446),
	(83447),
	(83448),
	(83449),
	(83450),
	(83451),
	(83452),
	(83453),
	(83454),
	(83455),
	(83456),
	(83457),
	(83458),
	(83459),
	(83460),
	(83461),
	(83462),
	(83463),
	(83464),
	(83465),
	(83466),
	(83467),
	(83468),
	(83469),
	(83470),
	(83471),
	(83472),
	(83473),
	(83474),
	(83475),
	(83476),
	(83477),
	(83478),
	(83479),
	(83480),
	(83481),
	(83482),
	(83483),
	(83484),
	(83485),
	(83486),
	(83487),
	(83488),
	(83489),
	(83490),
	(83491),
	(83492),
	(83493),
	(83494),
	(83495),
	(83496),
	(83497),
	(83498),
	(83499),
	(83500),
	(83501),
	(83502),
	(83503),
	(83504),
	(83505),
	(83506),
	(83507),
	(83508),
	(83509),
	(83510),
	(83511),
	(83512),
	(83513),
	(83514),
	(83515),
	(83516),
	(83517),
	(83518),
	(83519),
	(83520),
	(83521),
	(83522),
	(83523),
	(83524),
	(83525),
	(83526),
	(83527),
	(83528),
	(83529),
	(83530),
	(83531),
	(83532),
	(83533),
	(83534),
	(83535),
	(83536),
	(83537),
	(83538),
	(83539),
	(83540),
	(83541),
	(83542),
	(83543),
	(83544),
	(83545),
	(83546),
	(83547),
	(83548),
	(83549),
	(83550),
	(83551),
	(83552),
	(83553),
	(83554),
	(83555),
	(83556),
	(83557),
	(83558),
	(83559),
	(83560),
	(83561),
	(83562),
	(83563),
	(83564),
	(83565),
	(83566),
	(83567),
	(83568),
	(83569),
	(83570),
	(83571),
	(83572),
	(83573),
	(83574),
	(83575),
	(83576),
	(83577),
	(83578),
	(83579),
	(83580),
	(83581),
	(83582),
	(83583),
	(83584),
	(83585),
	(83586),
	(83587),
	(83588),
	(83589),
	(83590),
	(83591),
	(83592),
	(83593),
	(83594),
	(83595),
	(83596),
	(83597),
	(83598),
	(83599),
	(83600),
	(83601),
	(83602),
	(83603),
	(83604),
	(83605),
	(83606),
	(83607),
	(83608),
	(83609),
	(83610),
	(83611),
	(83612),
	(83613),
	(83614),
	(83615),
	(83616),
	(83617),
	(83618),
	(83619),
	(83620),
	(83621),
	(83622),
	(83623),
	(83624),
	(83625),
	(83626),
	(83627),
	(83628),
	(83629),
	(83630),
	(83631),
	(83632),
	(83633),
	(83634),
	(83635),
	(83636),
	(83637),
	(83638),
	(83639),
	(83640),
	(83641),
	(83642),
	(83643),
	(83644),
	(83645),
	(83646),
	(83647),
	(83648),
	(83649),
	(83650),
	(83651),
	(83652),
	(83653),
	(83654),
	(83655),
	(83656),
	(83657),
	(83658),
	(83659),
	(83660),
	(83661),
	(83662),
	(83663),
	(83664),
	(83665),
	(83666),
	(83667),
	(83668),
	(83669),
	(83670),
	(83671),
	(83672),
	(83673),
	(83674),
	(83675),
	(83676),
	(83677),
	(83678),
	(83679),
	(83680),
	(83681),
	(83682),
	(83683),
	(83684),
	(83685),
	(83686),
	(83687),
	(83688),
	(83689),
	(83690),
	(83691),
	(83692),
	(83693),
	(83694),
	(83695),
	(83696),
	(83697),
	(83698),
	(83699),
	(83700),
	(83701),
	(83702),
	(83703),
	(83704),
	(83705),
	(83706),
	(83707),
	(83708),
	(83709),
	(83710),
	(83711),
	(83712),
	(83713),
	(83714),
	(83715),
	(83716),
	(83717),
	(83718),
	(83719),
	(83720),
	(83721),
	(83722),
	(83723),
	(83724),
	(83725),
	(83726),
	(83727),
	(83728),
	(83729),
	(83730),
	(83731),
	(83732),
	(83733),
	(83734),
	(83735),
	(83736),
	(83737),
	(83738),
	(83739),
	(83740),
	(83741),
	(83742),
	(83743),
	(83744),
	(83745),
	(83746),
	(83747),
	(83748),
	(83749),
	(83750),
	(83751),
	(83752),
	(83753),
	(83754),
	(83755),
	(83756),
	(83757),
	(83758),
	(83759),
	(83760),
	(83761),
	(83762),
	(83763),
	(83764),
	(83765),
	(83766),
	(83767),
	(83768),
	(83769),
	(83770),
	(83771),
	(83772),
	(83773),
	(83774),
	(83775),
	(83776),
	(83777),
	(83778),
	(83779),
	(83780),
	(83781),
	(83782),
	(83783),
	(83784),
	(83785),
	(83786),
	(83787),
	(83788),
	(83789),
	(83790),
	(83791),
	(83792),
	(83793),
	(83794),
	(83795),
	(83796),
	(83797),
	(83798),
	(83799),
	(83800),
	(83801),
	(83802),
	(83803),
	(83804),
	(83805),
	(83806),
	(83807),
	(83808),
	(83809),
	(83810),
	(83811),
	(83812),
	(83813),
	(83814),
	(83815),
	(83816),
	(83817),
	(83818),
	(83819),
	(83820),
	(83821),
	(83822),
	(83823),
	(83824),
	(83825),
	(83826),
	(83827),
	(83828),
	(83829),
	(83830),
	(83831),
	(83832),
	(83833),
	(83834),
	(83835),
	(83836),
	(83837),
	(83838),
	(83839),
	(83840),
	(83841),
	(83842),
	(83843),
	(83844),
	(83845),
	(83846),
	(83847),
	(83848),
	(83849),
	(83850),
	(83851),
	(83852),
	(83853),
	(83854),
	(83855),
	(83856),
	(83857),
	(83858),
	(83859),
	(83860),
	(83861),
	(83862),
	(83863),
	(83864),
	(83865),
	(83866),
	(83867),
	(83868),
	(83869),
	(83870),
	(83871),
	(83872),
	(83873),
	(83874),
	(83875),
	(83876),
	(83877),
	(83878),
	(83879),
	(83880),
	(83881),
	(83882),
	(83883),
	(83884),
	(83885),
	(83886),
	(83887),
	(83888),
	(83889),
	(83890),
	(83891),
	(83892),
	(83893),
	(83894),
	(83895),
	(83896),
	(83897),
	(83898),
	(83899),
	(83900),
	(83901),
	(83902),
	(83903),
	(83904),
	(83905),
	(83906),
	(83907),
	(83908),
	(83909),
	(83910),
	(83911),
	(83912),
	(83913),
	(83914),
	(83915),
	(83916),
	(83917),
	(83918),
	(83919),
	(83920),
	(83921),
	(83922),
	(83923),
	(83924),
	(83925),
	(83926),
	(83927),
	(83928),
	(83929),
	(83930),
	(83931),
	(83932),
	(83933),
	(83934),
	(83935),
	(83936),
	(83937),
	(83938),
	(83939),
	(83940),
	(83941),
	(83942),
	(83943),
	(83944),
	(83945),
	(83946),
	(83947),
	(83948),
	(83949),
	(83950),
	(83951),
	(83952),
	(83953),
	(83954),
	(83955),
	(83956),
	(83957),
	(83958),
	(83959),
	(83960),
	(83961),
	(83962),
	(83963),
	(83964),
	(83965),
	(83966),
	(83967),
	(83968),
	(83969),
	(83970),
	(83971),
	(83972),
	(83973),
	(83974),
	(83975),
	(83976),
	(83977),
	(83978),
	(83979),
	(83980),
	(83981),
	(83982),
	(83983),
	(83984),
	(83985),
	(83986),
	(83987),
	(83988),
	(83989),
	(83990),
	(83991),
	(83992),
	(83993),
	(83994),
	(83995),
	(83996),
	(83997),
	(83998),
	(83999),
	(84000),
	(84001),
	(84002),
	(84003),
	(84004),
	(84005),
	(84006),
	(84007),
	(84008),
	(84009),
	(84010),
	(84011),
	(84012),
	(84013),
	(84014),
	(84015),
	(84016),
	(84017),
	(84018),
	(84019),
	(84020),
	(84021),
	(84022),
	(84023),
	(84024),
	(84025),
	(84026),
	(84027),
	(84028),
	(84029),
	(84030),
	(84031),
	(84032),
	(84033),
	(84034),
	(84035),
	(84036),
	(84037),
	(84038),
	(84039),
	(84040),
	(84041),
	(84042),
	(84043),
	(84044),
	(84045),
	(84046),
	(84047),
	(84048),
	(84049),
	(84050),
	(84051),
	(84052),
	(84053),
	(84054),
	(84055),
	(84056),
	(84057),
	(84058),
	(84059),
	(84060),
	(84061),
	(84062),
	(84063),
	(84064),
	(84065),
	(84066),
	(84067),
	(84068),
	(84069),
	(84070),
	(84071),
	(84072),
	(84073),
	(84074),
	(84075),
	(84076),
	(84077),
	(84078),
	(84079),
	(84080),
	(84081),
	(84082),
	(84083),
	(84084),
	(84085),
	(84086),
	(84087),
	(84088),
	(84089),
	(84090),
	(84091),
	(84092),
	(84093),
	(84094),
	(84095),
	(84096),
	(84097),
	(84098),
	(84099),
	(84100),
	(84101),
	(84102),
	(84103),
	(84104),
	(84105),
	(84106),
	(84107),
	(84108),
	(84109),
	(84110),
	(84111),
	(84112),
	(84113),
	(84114),
	(84115),
	(84116),
	(84117),
	(84118),
	(84119),
	(84120),
	(84121),
	(84122),
	(84123),
	(84124),
	(84125),
	(84126),
	(84127),
	(84128),
	(84129),
	(84130),
	(84131),
	(84132),
	(84133),
	(84134),
	(84135),
	(84136),
	(84137),
	(84138),
	(84139),
	(84140),
	(84141),
	(84142),
	(84143),
	(84144),
	(84145),
	(84146),
	(84147),
	(84148),
	(84149),
	(84150),
	(84151),
	(84152),
	(84153),
	(84154),
	(84155),
	(84156),
	(84157),
	(84158),
	(84159),
	(84160),
	(84161),
	(84162),
	(84163),
	(84164),
	(84165),
	(84166),
	(84167),
	(84168),
	(84169),
	(84170),
	(84171),
	(84172),
	(84173),
	(84174),
	(84175),
	(84176),
	(84177),
	(84178),
	(84179),
	(84180),
	(84181),
	(84182),
	(84183),
	(84184),
	(84185),
	(84186),
	(84187),
	(84188),
	(84189),
	(84190),
	(84191),
	(84192),
	(84193),
	(84194),
	(84195),
	(84196),
	(84197),
	(84198),
	(84199),
	(84200),
	(84201),
	(84202),
	(84203),
	(84204),
	(84205),
	(84206),
	(84207),
	(84208),
	(84209),
	(84210),
	(84211),
	(84212),
	(84213),
	(84214),
	(84215),
	(84216),
	(84217),
	(84218),
	(84219),
	(84220),
	(84221),
	(84222),
	(84223),
	(84224),
	(84225),
	(84226),
	(84227),
	(84228),
	(84229),
	(84230),
	(84231),
	(84232),
	(84233),
	(84234),
	(84235),
	(84236),
	(84237),
	(84238),
	(84239),
	(84240),
	(84241),
	(84242),
	(84243),
	(84244),
	(84245),
	(84246),
	(84247),
	(84248),
	(84249),
	(84250),
	(84251),
	(84252),
	(84253),
	(84254),
	(84255),
	(84256),
	(84257),
	(84258),
	(84259),
	(84260),
	(84261),
	(84262),
	(84263),
	(84264),
	(84265),
	(84266),
	(84267),
	(84268),
	(84269),
	(84270),
	(84271),
	(84272),
	(84273),
	(84274),
	(84275),
	(84276),
	(84277),
	(84278),
	(84279),
	(84280),
	(84281),
	(84282),
	(84283),
	(84284),
	(84285),
	(84286),
	(84287),
	(84288),
	(84289),
	(84290),
	(84291),
	(84292),
	(84293),
	(84294),
	(84295),
	(84296),
	(84297),
	(84298),
	(84299),
	(84300),
	(84301),
	(84302),
	(84303),
	(84304),
	(84305),
	(84306),
	(84307),
	(84308),
	(84309),
	(84310),
	(84311),
	(84312),
	(84313),
	(84314),
	(84315),
	(84316),
	(84317),
	(84318),
	(84319),
	(84320),
	(84321),
	(84322),
	(84323),
	(84324),
	(84325),
	(84326),
	(84327),
	(84328),
	(84329),
	(84330),
	(84331),
	(84332),
	(84333),
	(84334),
	(84335),
	(84336),
	(84337),
	(84338),
	(84339),
	(84340),
	(84341),
	(84342),
	(84343),
	(84344),
	(84345),
	(84346),
	(84347),
	(84348),
	(84349),
	(84350),
	(84351),
	(84352),
	(84353),
	(84354),
	(84355),
	(84356),
	(84357),
	(84358),
	(84359),
	(84360),
	(84361),
	(84362),
	(84363),
	(84364),
	(84365),
	(84366),
	(84367),
	(84368),
	(84369),
	(84370),
	(84371),
	(84372),
	(84373),
	(84374),
	(84375),
	(84376),
	(84377),
	(84378),
	(84379),
	(84380),
	(84381),
	(84382),
	(84383),
	(84384),
	(84385),
	(84386),
	(84387),
	(84388),
	(84389),
	(84390),
	(84391),
	(84392),
	(84393),
	(84394),
	(84395),
	(84396),
	(84397),
	(84398),
	(84399),
	(84400),
	(84401),
	(84402),
	(84403),
	(84404),
	(84405),
	(84406),
	(84407),
	(84408),
	(84409),
	(84410),
	(84411),
	(84412),
	(84413),
	(84414),
	(84415),
	(84416),
	(84417),
	(84418),
	(84419),
	(84420),
	(84421),
	(84422),
	(84423),
	(84424),
	(84425),
	(84426),
	(84427),
	(84428),
	(84429),
	(84430),
	(84431),
	(84432),
	(84433),
	(84434),
	(84435),
	(84436),
	(84437),
	(84438),
	(84439),
	(84440),
	(84441),
	(84442),
	(84443),
	(84444),
	(84445),
	(84446),
	(84447),
	(84448),
	(84449),
	(84450),
	(84451),
	(84452),
	(84453),
	(84454),
	(84455),
	(84456),
	(84457),
	(84458),
	(84459),
	(84460),
	(84461),
	(84462),
	(84463),
	(84464),
	(84465),
	(84466),
	(84467),
	(84468),
	(84469),
	(84470),
	(84471),
	(84472),
	(84473),
	(84474),
	(84475),
	(84476),
	(84477),
	(84478),
	(84479),
	(84480),
	(84481),
	(84482),
	(84483),
	(84484),
	(84485),
	(84486),
	(84487),
	(84488),
	(84489),
	(84490),
	(84491),
	(84492),
	(84493),
	(84494),
	(84495),
	(84496),
	(84497),
	(84498),
	(84499),
	(84500),
	(84501),
	(84502),
	(84503),
	(84504),
	(84505),
	(84506),
	(84507),
	(84508),
	(84509),
	(84510),
	(84511),
	(84512),
	(84513),
	(84514),
	(84515),
	(84516),
	(84517),
	(84518),
	(84519),
	(84520),
	(84521),
	(84522),
	(84523),
	(84524),
	(84525),
	(84526),
	(84527),
	(84528),
	(84529),
	(84530),
	(84531),
	(84532),
	(84533),
	(84534),
	(84535),
	(84536),
	(84537),
	(84538),
	(84539),
	(84540),
	(84541),
	(84542),
	(84543),
	(84544),
	(84545),
	(84546),
	(84547),
	(84548),
	(84549),
	(84550),
	(84551),
	(84552),
	(84553),
	(84554),
	(84555),
	(84556),
	(84557),
	(84558),
	(84559),
	(84560),
	(84561),
	(84562),
	(84563),
	(84564),
	(84565),
	(84566),
	(84567),
	(84568),
	(84569),
	(84570),
	(84571),
	(84572),
	(84573),
	(84574),
	(84575),
	(84576),
	(84577),
	(84578),
	(84579),
	(84580),
	(84581),
	(84582),
	(84583),
	(84584),
	(84585),
	(84586),
	(84587),
	(84588),
	(84589),
	(84590),
	(84591),
	(84592),
	(84593),
	(84594),
	(84595),
	(84596),
	(84597),
	(84598),
	(84599),
	(84600),
	(84601),
	(84602),
	(84603),
	(84604),
	(84605),
	(84606),
	(84607),
	(84608),
	(84609),
	(84610),
	(84611),
	(84612),
	(84613),
	(84614),
	(84615),
	(84616),
	(84617),
	(84618),
	(84619),
	(84620),
	(84621),
	(84622),
	(84623),
	(84624),
	(84625),
	(84626),
	(84627),
	(84628),
	(84629),
	(84630),
	(84631),
	(84632),
	(84633),
	(84634),
	(84635),
	(84636),
	(84637),
	(84638),
	(84639),
	(84640),
	(84641),
	(84642),
	(84643),
	(84644),
	(84645),
	(84646),
	(84647),
	(84648),
	(84649),
	(84650),
	(84651),
	(84652),
	(84653),
	(84654),
	(84655),
	(84656),
	(84657),
	(84658),
	(84659),
	(84660),
	(84661),
	(84662),
	(84663),
	(84664),
	(84665),
	(84666),
	(84667),
	(84668),
	(84669),
	(84670),
	(84671),
	(84672),
	(84673),
	(84674),
	(84675),
	(84676),
	(84677),
	(84678),
	(84679),
	(84680),
	(84681),
	(84682),
	(84683),
	(84684),
	(84685),
	(84686),
	(84687),
	(84688),
	(84689),
	(84690),
	(84691),
	(84692),
	(84693),
	(84694),
	(84695),
	(84696),
	(84697),
	(84698),
	(84699),
	(84700),
	(84701),
	(84702),
	(84703),
	(84704),
	(84705),
	(84706),
	(84707),
	(84708),
	(84709),
	(84710),
	(84711),
	(84712),
	(84713),
	(84714),
	(84715),
	(84716),
	(84717),
	(84718),
	(84719),
	(84720),
	(84721),
	(84722),
	(84723),
	(84724),
	(84725),
	(84726),
	(84727),
	(84728),
	(84729),
	(84730),
	(84731),
	(84732),
	(84733),
	(84734),
	(84735),
	(84736),
	(84737),
	(84738),
	(84739),
	(84740),
	(84741),
	(84742),
	(84743),
	(84744),
	(84745),
	(84746),
	(84747),
	(84748),
	(84749),
	(84750),
	(84751),
	(84752),
	(84753),
	(84754),
	(84755),
	(84756),
	(84757),
	(84758),
	(84759),
	(84760),
	(84761),
	(84762),
	(84763),
	(84764),
	(84765),
	(84766),
	(84767),
	(84768),
	(84769),
	(84770),
	(84771),
	(84772),
	(84773),
	(84774),
	(84775),
	(84776),
	(84777),
	(84778),
	(84779),
	(84780),
	(84781),
	(84782),
	(84783),
	(84784),
	(84785),
	(84786),
	(84787),
	(84788),
	(84789),
	(84790),
	(84791),
	(84792),
	(84793),
	(84794),
	(84795),
	(84796),
	(84797),
	(84798),
	(84799),
	(84800),
	(84801),
	(84802),
	(84803),
	(84804),
	(84805),
	(84806),
	(84807),
	(84808),
	(84809),
	(84810),
	(84811),
	(84812),
	(84813),
	(84814),
	(84815),
	(84816),
	(84817),
	(84818),
	(84819),
	(84820),
	(84821),
	(84822),
	(84823),
	(84824),
	(84825),
	(84826),
	(84827),
	(84828),
	(84829),
	(84830),
	(84831),
	(84832),
	(84833),
	(84834),
	(84835),
	(84836),
	(84837),
	(84838),
	(84839),
	(84840),
	(84841),
	(84842),
	(84843),
	(84844),
	(84845),
	(84846),
	(84847),
	(84848),
	(84849),
	(84850),
	(84851),
	(84852),
	(84853),
	(84854),
	(84855),
	(84856),
	(84857),
	(84858),
	(84859),
	(84860),
	(84861),
	(84862),
	(84863),
	(84864),
	(84865),
	(84866),
	(84867),
	(84868),
	(84869),
	(84870),
	(84871),
	(84872),
	(84873),
	(84874),
	(84875),
	(84876),
	(84877),
	(84878),
	(84879),
	(84880),
	(84881),
	(84882),
	(84883),
	(84884),
	(84885),
	(84886),
	(84887),
	(84888),
	(84889),
	(84890),
	(84891),
	(84892),
	(84893),
	(84894),
	(84895),
	(84896),
	(84897),
	(84898),
	(84899),
	(84900),
	(84901),
	(84902),
	(84903),
	(84904),
	(84905),
	(84906),
	(84907),
	(84908),
	(84909),
	(84910),
	(84911),
	(84912),
	(84913),
	(84914),
	(84915),
	(84916),
	(84917),
	(84918),
	(84919),
	(84920),
	(84921),
	(84922),
	(84923),
	(84924),
	(84925),
	(84926),
	(84927),
	(84928),
	(84929),
	(84930),
	(84931),
	(84932),
	(84933),
	(84934),
	(84935),
	(84936),
	(84937),
	(84938),
	(84939),
	(84940),
	(84941),
	(84942),
	(84943),
	(84944),
	(84945),
	(84946),
	(84947),
	(84948),
	(84949),
	(84950),
	(84951),
	(84952),
	(84953),
	(84954),
	(84955),
	(84956),
	(84957),
	(84958),
	(84959),
	(84960),
	(84961),
	(84962),
	(84963),
	(84964),
	(84965),
	(84966),
	(84967),
	(84968),
	(84969),
	(84970),
	(84971),
	(84972),
	(84973),
	(84974),
	(84975),
	(84976),
	(84977),
	(84978),
	(84979),
	(84980),
	(84981),
	(84982),
	(84983),
	(84984),
	(84985),
	(84986),
	(84987),
	(84988),
	(84989),
	(84990),
	(84991),
	(84992),
	(84993),
	(84994),
	(84995),
	(84996),
	(84997),
	(84998),
	(84999),
	(85000),
	(85001),
	(85002),
	(85003),
	(85004),
	(85005),
	(85006),
	(85007),
	(85008),
	(85009),
	(85010),
	(85011),
	(85012),
	(85013),
	(85014),
	(85015),
	(85016),
	(85017),
	(85018),
	(85019),
	(85020),
	(85021),
	(85022),
	(85023),
	(85024),
	(85025),
	(85026),
	(85027),
	(85028),
	(85029),
	(85030),
	(85031),
	(85032),
	(85033),
	(85034),
	(85035),
	(85036),
	(85037),
	(85038),
	(85039),
	(85040),
	(85041),
	(85042),
	(85043),
	(85044),
	(85045),
	(85046),
	(85047),
	(85048),
	(85049),
	(85050),
	(85051),
	(85052),
	(85053),
	(85054),
	(85055),
	(85056),
	(85057),
	(85058),
	(85059),
	(85060),
	(85061),
	(85062),
	(85063),
	(85064),
	(85065),
	(85066),
	(85067),
	(85068),
	(85069),
	(85070),
	(85071),
	(85072),
	(85073),
	(85074),
	(85075),
	(85076),
	(85077),
	(85078),
	(85079),
	(85080),
	(85081),
	(85082),
	(85083),
	(85084),
	(85085),
	(85086),
	(85087),
	(85088),
	(85089),
	(85090),
	(85091),
	(85092),
	(85093),
	(85094),
	(85095),
	(85096),
	(85097),
	(85098),
	(85099),
	(85100),
	(85101),
	(85102),
	(85103),
	(85104),
	(85105),
	(85106),
	(85107),
	(85108),
	(85109),
	(85110),
	(85111),
	(85112),
	(85113),
	(85114),
	(85115),
	(85116),
	(85117),
	(85118),
	(85119),
	(85120),
	(85121),
	(85122),
	(85123),
	(85124),
	(85125),
	(85126),
	(85127),
	(85128),
	(85129),
	(85130),
	(85131),
	(85132),
	(85133),
	(85134),
	(85135),
	(85136),
	(85137),
	(85138),
	(85139),
	(85140),
	(85141),
	(85142),
	(85143),
	(85144),
	(85145),
	(85146),
	(85147),
	(85148),
	(85149),
	(85150),
	(85151),
	(85152),
	(85153),
	(85154),
	(85155),
	(85156),
	(85157),
	(85158),
	(85159),
	(85160),
	(85161),
	(85162),
	(85163),
	(85164),
	(85165),
	(85166),
	(85167),
	(85168),
	(85169),
	(85170),
	(85171),
	(85172),
	(85173),
	(85174),
	(85175),
	(85176),
	(85177),
	(85178),
	(85179),
	(85180),
	(85181),
	(85182),
	(85183),
	(85184),
	(85185),
	(85186),
	(85187),
	(85188),
	(85189),
	(85190),
	(85191),
	(85192),
	(85193),
	(85194),
	(85195),
	(85196),
	(85197),
	(85198),
	(85199),
	(85200),
	(85201),
	(85202),
	(85203),
	(85204),
	(85205),
	(85206),
	(85207),
	(85208),
	(85209),
	(85210),
	(85211),
	(85212),
	(85213),
	(85214),
	(85215),
	(85216),
	(85217),
	(85218),
	(85219),
	(85220),
	(85221),
	(85222),
	(85223),
	(85224),
	(85225),
	(85226),
	(85227),
	(85228),
	(85229),
	(85230),
	(85231),
	(85232),
	(85233),
	(85234),
	(85235),
	(85236),
	(85237),
	(85238),
	(85239),
	(85240),
	(85241),
	(85242),
	(85243),
	(85244),
	(85245),
	(85246),
	(85247),
	(85248),
	(85249),
	(85250),
	(85251),
	(85252),
	(85253),
	(85254),
	(85255),
	(85256),
	(85257),
	(85258),
	(85259),
	(85260),
	(85261),
	(85262),
	(85263),
	(85264),
	(85265),
	(85266),
	(85267),
	(85268),
	(85269),
	(85270),
	(85271),
	(85272),
	(85273),
	(85274),
	(85275),
	(85276),
	(85277),
	(85278),
	(85279),
	(85280),
	(85281),
	(85282),
	(85283),
	(85284),
	(85285),
	(85286),
	(85287),
	(85288),
	(85289),
	(85290),
	(85291),
	(85292),
	(85293),
	(85294),
	(85295),
	(85296),
	(85297),
	(85298),
	(85299),
	(85300),
	(85301),
	(85302),
	(85303),
	(85304),
	(85305),
	(85306),
	(85307),
	(85308),
	(85309),
	(85310),
	(85311),
	(85312),
	(85313),
	(85314),
	(85315),
	(85316),
	(85317),
	(85318),
	(85319),
	(85320),
	(85321),
	(85322),
	(85323),
	(85324),
	(85325),
	(85326),
	(85327),
	(85328),
	(85329),
	(85330),
	(85331),
	(85332),
	(85333),
	(85334),
	(85335),
	(85336),
	(85337),
	(85338),
	(85339),
	(85340),
	(85341),
	(85342),
	(85343),
	(85344),
	(85345),
	(85346),
	(85347),
	(85348),
	(85349),
	(85350),
	(85351),
	(85352),
	(85353),
	(85354),
	(85355),
	(85356),
	(85357),
	(85358),
	(85359),
	(85360),
	(85361),
	(85362),
	(85363),
	(85364),
	(85365),
	(85366),
	(85367),
	(85368),
	(85369),
	(85370),
	(85371),
	(85372),
	(85373),
	(85374),
	(85375),
	(85376),
	(85377),
	(85378),
	(85379),
	(85380),
	(85381),
	(85382),
	(85383),
	(85384),
	(85385),
	(85386),
	(85387),
	(85388),
	(85389),
	(85390),
	(85391),
	(85392),
	(85393),
	(85394),
	(85395),
	(85396),
	(85397),
	(85398),
	(85399),
	(85400),
	(85401),
	(85402),
	(85403),
	(85404),
	(85405),
	(85406),
	(85407),
	(85408),
	(85409),
	(85410),
	(85411),
	(85412),
	(85413),
	(85414),
	(85415),
	(85416),
	(85417),
	(85418),
	(85419),
	(85420),
	(85421),
	(85422),
	(85423),
	(85424),
	(85425),
	(85426),
	(85427),
	(85428),
	(85429),
	(85430),
	(85431),
	(85432),
	(85433),
	(85434),
	(85435),
	(85436),
	(85437),
	(85438),
	(85439),
	(85440),
	(85441),
	(85442),
	(85443),
	(85444),
	(85445),
	(85446),
	(85447),
	(85448),
	(85449),
	(85450),
	(85451),
	(85452),
	(85453),
	(85454),
	(85455),
	(85456),
	(85457),
	(85458),
	(85459),
	(85460),
	(85461),
	(85462),
	(85463),
	(85464),
	(85465),
	(85466),
	(85467),
	(85468),
	(85469),
	(85470),
	(85471),
	(85472),
	(85473),
	(85474),
	(85475),
	(85476),
	(85477),
	(85478),
	(85479),
	(85480),
	(85481),
	(85482),
	(85483),
	(85484),
	(85485),
	(85486),
	(85487),
	(85488),
	(85489),
	(85490),
	(85491),
	(85492),
	(85493),
	(85494),
	(85495),
	(85496),
	(85497),
	(85498),
	(85499),
	(85500),
	(85501),
	(85502),
	(85503),
	(85504),
	(85505),
	(85506),
	(85507),
	(85508),
	(85509),
	(85510),
	(85511),
	(85512),
	(85513),
	(85514),
	(85515),
	(85516),
	(85517),
	(85518),
	(85519),
	(85520),
	(85521),
	(85522),
	(85523),
	(85524),
	(85525),
	(85526),
	(85527),
	(85528),
	(85529),
	(85530),
	(85531),
	(85532),
	(85533),
	(85534),
	(85535),
	(85536),
	(85537),
	(85538),
	(85539),
	(85540),
	(85541),
	(85542),
	(85543),
	(85544),
	(85545),
	(85546),
	(85547),
	(85548),
	(85549),
	(85550),
	(85551),
	(85552),
	(85553),
	(85554),
	(85555),
	(85556),
	(85557),
	(85558),
	(85559),
	(85560),
	(85561),
	(85562),
	(85563),
	(85564),
	(85565),
	(85566),
	(85567),
	(85568),
	(85569),
	(85570),
	(85571),
	(85572),
	(85573),
	(85574),
	(85575),
	(85576),
	(85577),
	(85578),
	(85579),
	(85580),
	(85581),
	(85582),
	(85583),
	(85584),
	(85585),
	(85586),
	(85587),
	(85588),
	(85589),
	(85590),
	(85591),
	(85592),
	(85593),
	(85594),
	(85595),
	(85596),
	(85597),
	(85598),
	(85599),
	(85600),
	(85601),
	(85602),
	(85603),
	(85604),
	(85605),
	(85606),
	(85607),
	(85608),
	(85609),
	(85610),
	(85611),
	(85612),
	(85613),
	(85614),
	(85615),
	(85616),
	(85617),
	(85618),
	(85619),
	(85620),
	(85621),
	(85622),
	(85623),
	(85624),
	(85625),
	(85626),
	(85627),
	(85628),
	(85629),
	(85630),
	(85631),
	(85632),
	(85633),
	(85634),
	(85635),
	(85636),
	(85637),
	(85638),
	(85639),
	(85640),
	(85641),
	(85642),
	(85643),
	(85644),
	(85645),
	(85646),
	(85647),
	(85648),
	(85649),
	(85650),
	(85651),
	(85652),
	(85653),
	(85654),
	(85655),
	(85656),
	(85657),
	(85658),
	(85659),
	(85660),
	(85661),
	(85662),
	(85663),
	(85664),
	(85665),
	(85666),
	(85667),
	(85668),
	(85669),
	(85670),
	(85671),
	(85672),
	(85673),
	(85674),
	(85675),
	(85676),
	(85677),
	(85678),
	(85679),
	(85680),
	(85681),
	(85682),
	(85683),
	(85684),
	(85685),
	(85686),
	(85687),
	(85688),
	(85689),
	(85690),
	(85691),
	(85692),
	(85693),
	(85694),
	(85695),
	(85696),
	(85697),
	(85698),
	(85699),
	(85700),
	(85701),
	(85702),
	(85703),
	(85704),
	(85705),
	(85706),
	(85707),
	(85708),
	(85709),
	(85710),
	(85711),
	(85712),
	(85713),
	(85714),
	(85715),
	(85716),
	(85717),
	(85718),
	(85719),
	(85720),
	(85721),
	(85722),
	(85723),
	(85724),
	(85725),
	(85726),
	(85727),
	(85728),
	(85729),
	(85730),
	(85731),
	(85732),
	(85733),
	(85734),
	(85735),
	(85736),
	(85737),
	(85738),
	(85739),
	(85740),
	(85741),
	(85742),
	(85743),
	(85744),
	(85745),
	(85746),
	(85747),
	(85748),
	(85749),
	(85750),
	(85751),
	(85752),
	(85753),
	(85754),
	(85755),
	(85756),
	(85757),
	(85758),
	(85759),
	(85760),
	(85761),
	(85762),
	(85763),
	(85764),
	(85765),
	(85766),
	(85767),
	(85768),
	(85769),
	(85770),
	(85771),
	(85772),
	(85773),
	(85774),
	(85775),
	(85776),
	(85777),
	(85778),
	(85779),
	(85780),
	(85781),
	(85782),
	(85783),
	(85784),
	(85785),
	(85786),
	(85787),
	(85788),
	(85789),
	(85790),
	(85791),
	(85792),
	(85793),
	(85794),
	(85795),
	(85796),
	(85797),
	(85798),
	(85799),
	(85800),
	(85801),
	(85802),
	(85803),
	(85804),
	(85805),
	(85806),
	(85807),
	(85808),
	(85809),
	(85810),
	(85811),
	(85812),
	(85813),
	(85814),
	(85815),
	(85816),
	(85817),
	(85818),
	(85819),
	(85820),
	(85821),
	(85822),
	(85823),
	(85824),
	(85825),
	(85826),
	(85827),
	(85828),
	(85829),
	(85830),
	(85831),
	(85832),
	(85833),
	(85834),
	(85835),
	(85836),
	(85837),
	(85838),
	(85839),
	(85840),
	(85841),
	(85842),
	(85843),
	(85844),
	(85845),
	(85846),
	(85847),
	(85848),
	(85849),
	(85850),
	(85851),
	(85852),
	(85853),
	(85854),
	(85855),
	(85856),
	(85857),
	(85858),
	(85859),
	(85860),
	(85861),
	(85862),
	(85863),
	(85864),
	(85865),
	(85866),
	(85867),
	(85868),
	(85869),
	(85870),
	(85871),
	(85872),
	(85873),
	(85874),
	(85875),
	(85876),
	(85877),
	(85878),
	(85879),
	(85880),
	(85881),
	(85882),
	(85883),
	(85884),
	(85885),
	(85886),
	(85887),
	(85888),
	(85889),
	(85890),
	(85891),
	(85892),
	(85893),
	(85894),
	(85895),
	(85896),
	(85897),
	(85898),
	(85899),
	(85900),
	(85901),
	(85902),
	(85903),
	(85904),
	(85905),
	(85906),
	(85907),
	(85908),
	(85909),
	(85910),
	(85911),
	(85912),
	(85913),
	(85914),
	(85915),
	(85916),
	(85917),
	(85918),
	(85919),
	(85920),
	(85921),
	(85922),
	(85923),
	(85924),
	(85925),
	(85926),
	(85927),
	(85928),
	(85929),
	(85930),
	(85931),
	(85932),
	(85933),
	(85934),
	(85935),
	(85936),
	(85937),
	(85938),
	(85939),
	(85940),
	(85941),
	(85942),
	(85943),
	(85944),
	(85945),
	(85946),
	(85947),
	(85948),
	(85949),
	(85950),
	(85951),
	(85952),
	(85953),
	(85954),
	(85955),
	(85956),
	(85957),
	(85958),
	(85959),
	(85960),
	(85961),
	(85962),
	(85963),
	(85964),
	(85965),
	(85966),
	(85967),
	(85968),
	(85969),
	(85970),
	(85971),
	(85972),
	(85973),
	(85974),
	(85975),
	(85976),
	(85977),
	(85978),
	(85979),
	(85980),
	(85981),
	(85982),
	(85983),
	(85984),
	(85985),
	(85986),
	(85987),
	(85988),
	(85989),
	(85990),
	(85991),
	(85992),
	(85993),
	(85994),
	(85995),
	(85996),
	(85997),
	(85998),
	(85999),
	(86000),
	(86001),
	(86002),
	(86003),
	(86004),
	(86005),
	(86006),
	(86007),
	(86008),
	(86009),
	(86010),
	(86011),
	(86012),
	(86013),
	(86014),
	(86015),
	(86016),
	(86017),
	(86018),
	(86019),
	(86020),
	(86021),
	(86022),
	(86023),
	(86024),
	(86025),
	(86026),
	(86027),
	(86028),
	(86029),
	(86030),
	(86031),
	(86032),
	(86033),
	(86034),
	(86035),
	(86036),
	(86037),
	(86038),
	(86039),
	(86040),
	(86041),
	(86042),
	(86043),
	(86044),
	(86045),
	(86046),
	(86047),
	(86048),
	(86049),
	(86050),
	(86051),
	(86052),
	(86053),
	(86054),
	(86055),
	(86056),
	(86057),
	(86058),
	(86059),
	(86060),
	(86061),
	(86062),
	(86063),
	(86064),
	(86065),
	(86066),
	(86067),
	(86068),
	(86069),
	(86070),
	(86071),
	(86072),
	(86073),
	(86074),
	(86075),
	(86076),
	(86077),
	(86078),
	(86079),
	(86080),
	(86081),
	(86082),
	(86083),
	(86084),
	(86085),
	(86086),
	(86087),
	(86088),
	(86089),
	(86090),
	(86091),
	(86092),
	(86093),
	(86094),
	(86095),
	(86096),
	(86097),
	(86098),
	(86099),
	(86100),
	(86101),
	(86102),
	(86103),
	(86104),
	(86105),
	(86106),
	(86107),
	(86108),
	(86109),
	(86110),
	(86111),
	(86112),
	(86113),
	(86114),
	(86115),
	(86116),
	(86117),
	(86118),
	(86119),
	(86120),
	(86121),
	(86122),
	(86123),
	(86124),
	(86125),
	(86126),
	(86127),
	(86128),
	(86129),
	(86130),
	(86131),
	(86132),
	(86133),
	(86134),
	(86135),
	(86136),
	(86137),
	(86138),
	(86139),
	(86140),
	(86141),
	(86142),
	(86143),
	(86144),
	(86145),
	(86146),
	(86147),
	(86148),
	(86149),
	(86150),
	(86151),
	(86152),
	(86153),
	(86154),
	(86155),
	(86156),
	(86157),
	(86158),
	(86159),
	(86160),
	(86161),
	(86162),
	(86163),
	(86164),
	(86165),
	(86166),
	(86167),
	(86168),
	(86169),
	(86170),
	(86171),
	(86172),
	(86173),
	(86174),
	(86175),
	(86176),
	(86177),
	(86178),
	(86179),
	(86180),
	(86181),
	(86182),
	(86183),
	(86184),
	(86185),
	(86186),
	(86187),
	(86188),
	(86189),
	(86190),
	(86191),
	(86192),
	(86193),
	(86194),
	(86195),
	(86196),
	(86197),
	(86198),
	(86199),
	(86200),
	(86201),
	(86202),
	(86203),
	(86204),
	(86205),
	(86206),
	(86207),
	(86208),
	(86209),
	(86210),
	(86211),
	(86212),
	(86213),
	(86214),
	(86215),
	(86216),
	(86217),
	(86218),
	(86219),
	(86220),
	(86221),
	(86222),
	(86223),
	(86224),
	(86225),
	(86226),
	(86227),
	(86228),
	(86229),
	(86230),
	(86231),
	(86232),
	(86233),
	(86234),
	(86235),
	(86236),
	(86237),
	(86238),
	(86239),
	(86240),
	(86241),
	(86242),
	(86243),
	(86244),
	(86245),
	(86246),
	(86247),
	(86248),
	(86249),
	(86250),
	(86251),
	(86252),
	(86253),
	(86254),
	(86255),
	(86256),
	(86257),
	(86258),
	(86259),
	(86260),
	(86261),
	(86262),
	(86263),
	(86264),
	(86265),
	(86266),
	(86267),
	(86268),
	(86269),
	(86270),
	(86271),
	(86272),
	(86273),
	(86274),
	(86275),
	(86276),
	(86277),
	(86278),
	(86279),
	(86280),
	(86281),
	(86282),
	(86283),
	(86284),
	(86285),
	(86286),
	(86287),
	(86288),
	(86289),
	(86290),
	(86291),
	(86292),
	(86293),
	(86294),
	(86295),
	(86296),
	(86297),
	(86298),
	(86299),
	(86300),
	(86301),
	(86302),
	(86303),
	(86304),
	(86305),
	(86306),
	(86307),
	(86308),
	(86309),
	(86310),
	(86311),
	(86312),
	(86313),
	(86314),
	(86315),
	(86316),
	(86317),
	(86318),
	(86319),
	(86320),
	(86321),
	(86322),
	(86323),
	(86324),
	(86325),
	(86326),
	(86327),
	(86328),
	(86329),
	(86330),
	(86331),
	(86332),
	(86333),
	(86334),
	(86335),
	(86336),
	(86337),
	(86338),
	(86339),
	(86340),
	(86341),
	(86342),
	(86343),
	(86344),
	(86345),
	(86346),
	(86347),
	(86348),
	(86349),
	(86350),
	(86351),
	(86352),
	(86353),
	(86354),
	(86355),
	(86356),
	(86357),
	(86358),
	(86359),
	(86360),
	(86361),
	(86362),
	(86363),
	(86364),
	(86365),
	(86366),
	(86367),
	(86368),
	(86369),
	(86370),
	(86371),
	(86372),
	(86373),
	(86374),
	(86375),
	(86376),
	(86377),
	(86378),
	(86379),
	(86380),
	(86381),
	(86382),
	(86383),
	(86384),
	(86385),
	(86386),
	(86387),
	(86388),
	(86389),
	(86390),
	(86391),
	(86392),
	(86393),
	(86394),
	(86395),
	(86396),
	(86397),
	(86398),
	(86399),
	(86400);
/*!40000 ALTER TABLE `iger` ENABLE KEYS */;

-- Dumping structure for table emcor.item_type
CREATE TABLE IF NOT EXISTS `item_type` (
  `item_type_id` int(10) unsigned NOT NULL COMMENT 'Katalogo elementų tipo identifikatorius',
  `item_type_code` varchar(250) COLLATE utf8_bin NOT NULL COMMENT 'Katalogo elementų tipo kodas',
  `item_type_name` varchar(250) COLLATE utf8_bin NOT NULL COMMENT 'Katalogo elementų tipo pavadinimas',
  PRIMARY KEY (`item_type_id`),
  UNIQUE KEY `item_type_code_u` (`item_type_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Katalogo elementų tipai';

-- Dumping data for table emcor.item_type: ~3 rows (approximately)
/*!40000 ALTER TABLE `item_type` DISABLE KEYS */;
INSERT INTO `item_type` (`item_type_id`, `item_type_code`, `item_type_name`) VALUES
	(1, 'LOAD_PROFILE', 'Apkrovos profilis'),
	(2, 'POWER_QUALITY', 'Elektros kokybė'),
	(3, 'READING', 'Parodymai');
/*!40000 ALTER TABLE `item_type` ENABLE KEYS */;

-- Dumping structure for table emcor.lc
CREATE TABLE IF NOT EXISTS `lc` (
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  `lc_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis kad uždrausti keitimai',
  PRIMARY KEY (`gr_id`),
  CONSTRAINT `lc_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.lc: ~0 rows (approximately)
/*!40000 ALTER TABLE `lc` DISABLE KEYS */;
/*!40000 ALTER TABLE `lc` ENABLE KEYS */;

-- Dumping structure for table emcor.license
CREATE TABLE IF NOT EXISTS `license` (
  `customer_name` varchar(250) COLLATE utf8_bin NOT NULL,
  `point_limit` int(10) unsigned DEFAULT NULL,
  `expiration` datetime DEFAULT NULL,
  `license_key` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `license_key2` varchar(120) COLLATE utf8_bin DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Programinės įrangos licenzija';

-- Dumping data for table emcor.license: ~0 rows (approximately)
/*!40000 ALTER TABLE `license` DISABLE KEYS */;
INSERT INTO `license` (`customer_name`, `point_limit`, `expiration`, `license_key`, `license_key2`) VALUES
	('„Lietuvos energijos gamyba“, AB', 560, NULL, '1210504643', 'ACBBB3956BE3A14F');
/*!40000 ALTER TABLE `license` ENABLE KEYS */;

-- Dumping structure for table emcor.lm
CREATE TABLE IF NOT EXISTS `lm` (
  `lm_id` smallint(5) unsigned NOT NULL COMMENT 'Paieškos prietaisų konfigūraciniuose parametruose metodo identifikatorius',
  `lm_code` varchar(80) COLLATE utf8_bin NOT NULL COMMENT 'Paieškos prietaisų konfigūraciniuose parametruose metodo kodas',
  PRIMARY KEY (`lm_id`),
  UNIQUE KEY `lm_code_u` (`lm_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Paieškos prietaisų konfigūraciniuose parametruose metodai';

-- Dumping data for table emcor.lm: ~24 rows (approximately)
/*!40000 ALTER TABLE `lm` DISABLE KEYS */;
INSERT INTO `lm` (`lm_id`, `lm_code`) VALUES
	(13, 'CATALOG>>getV(W4)~md>existsENr(W1)>P1>getENr(W2)>getV(W3)'),
	(20, 'CATALOG>P1>aggf_id'),
	(21, 'CATALOG>P1>aggf_id>getV(W1)~aggs_cnt'),
	(17, 'CATALOG>P1>md>P2>aggf>P3>attr>getV(W2)~aggs_cnt>getV(W3)~attr>existsENr(W1)'),
	(9, 'CATALOG>P1>md>existsENr(W1)'),
	(6, 'CATALOG>P1>md>existsENr(W1)>getENr(W2,Secondary47)>getV(W3,Ind1)'),
	(4, 'CATALOG>P1>md>getENr(W1)'),
	(11, 'CATALOG>P1>md>getENr(W1)>getV(W2)'),
	(23, 'CATALOG>P1~item_code'),
	(24, 'CATALOG>P1~item_code>getV(W1)~md_cnt'),
	(3, 'CATALOG>P2>md>existsENr(W1)>P1>getENr(W2)>getV(W3)'),
	(19, 'CATALOG>W2~aggs>W1~P1>P2~item_code'),
	(16, 'CATALOG>existsENr(W1)'),
	(2, 'CATALOG>getENr(W1)>getV(W2)'),
	(10, 'CATALOG>getV(W2)~md>existsENr(W1)'),
	(14, 'CATALOG>getV(W2)~md>getENr(W1)'),
	(22, 'CATALOG>getV(W2,Ind1)~md>existsENr(W1,Ind1)'),
	(12, 'CATALOG>getV(W3)~md>getENr(W1)>getV(W2)'),
	(15, 'CATALOG>getV(W4)~md>existsENr(W1)>getENr(W2,Secondary47)>getV(W3,Ind1)'),
	(18, 'P1>existsENr(W1)'),
	(5, 'P1>getENr(W1)>getV(W2)'),
	(8, 'P2>ID>P1>getENr(W1)>getV(W2)'),
	(7, 'P2>Ind1>P1>getENr(W1)>getV(W2)'),
	(1, 'getV(W1)');
/*!40000 ALTER TABLE `lm` ENABLE KEYS */;

-- Dumping structure for table emcor.lp
CREATE TABLE IF NOT EXISTS `lp` (
  `lp_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Ryšio prioritetų profilio identifikatorius',
  `lp_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ryšio prioritetų profilio pavadinimas',
  PRIMARY KEY (`lp_id`),
  UNIQUE KEY `lp_name_u` (`lp_name`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ryšio prioritetų profiliai';

-- Dumping data for table emcor.lp: ~0 rows (approximately)
/*!40000 ALTER TABLE `lp` DISABLE KEYS */;
INSERT INTO `lp` (`lp_id`, `lp_name`) VALUES
	(1, 'Standartinis');
/*!40000 ALTER TABLE `lp` ENABLE KEYS */;

-- Dumping structure for table emcor.lpty
CREATE TABLE IF NOT EXISTS `lpty` (
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `lpty_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybių tipo identifikatorius',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  `lpty_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Ryšio modulių savybių kodas',
  `lpty_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ryšio modulių savybės pavadinimas',
  `lpty_tm` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'TM savybės požymis',
  `lpty_default` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Savybės reikšmė pagal nutylėjimą',
  `lpty_das` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Ryšio modulių savybės naudojimo surinkimo serveryje požymis',
  `lpty_secured` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Ryšio modulių savybės reikšmės slėpimo su žvaigždutėm požymis',
  `parent_lpty_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Ryšio modulių tėvinės savybės identifikatorius',
  PRIMARY KEY (`lpty_id`),
  UNIQUE KEY `lpty_name_u` (`lpty_name`),
  KEY `lpty_code_i` (`lpty_code`),
  KEY `lpty_enum_i` (`enum_id`),
  KEY `lpty_lpty_type_i` (`lpty_type_id`),
  KEY `lpty_parent_lpty_fk` (`parent_lpty_id`),
  CONSTRAINT `lpty_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`),
  CONSTRAINT `lpty_lpty_type_fk` FOREIGN KEY (`lpty_type_id`) REFERENCES `lpty_type` (`lpty_type_id`),
  CONSTRAINT `lpty_parent_lpty_fk` FOREIGN KEY (`parent_lpty_id`) REFERENCES `lpty` (`lpty_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Galimų ryšio modulių savybių sąrašas';

-- Dumping data for table emcor.lpty: ~474 rows (approximately)
/*!40000 ALTER TABLE `lpty` DISABLE KEYS */;
INSERT INTO `lpty` (`lpty_id`, `lpty_type_id`, `enum_id`, `lpty_code`, `lpty_name`, `lpty_tm`, `lpty_default`, `lpty_das`, `lpty_secured`, `parent_lpty_id`) VALUES
	(1, 2, NULL, 'Addr', 'IP adresas', 1, NULL, 1, 0, NULL),
	(2, 2, NULL, 'Port', 'IP prievadas', 1, NULL, 1, 0, NULL),
	(3, 2, NULL, 'Port', 'COM prievadas', 1, NULL, 1, 0, NULL),
	(4, 2, 8, 'BaudRate', 'COM greitis', 1, NULL, 1, 0, NULL),
	(5, 2, NULL, 'Addr', 'Telefono numeris', 1, NULL, 1, 0, NULL),
	(6, 2, 9, 'IP_Kind', 'IP protokolas', 1, 'TCP', 1, 0, NULL),
	(7, 1, NULL, 'User', 'Įrenginio prisijungimo vardas', 0, NULL, 1, 0, NULL),
	(8, 1, NULL, 'Password', 'Įrenginio prisijungimo slaptažodis', 0, NULL, 1, 1, NULL),
	(9, 1, NULL, 'Path', 'Maršrutas iki duomenų', 0, NULL, 1, 0, NULL),
	(10, 1, NULL, 'Controller', 'Valdiklio ID', 0, NULL, 1, 0, NULL),
	(11, 4, NULL, 'TimeOutMSec', 'Taimautas milisekundėmis', 0, NULL, 1, 0, NULL),
	(12, 4, NULL, 'RepeatRequest', 'Pakartojimų skaičius nesėkmingo ryšio atveju', 0, NULL, 1, 0, NULL),
	(13, 3, NULL, 'User', 'Šaltinio prisijungimo vardas', 0, NULL, 1, 0, NULL),
	(14, 3, NULL, 'Password', 'Šaltinio prisijungimo slaptažodis', 0, NULL, 1, 1, NULL),
	(15, 3, NULL, 'MaxChannels', 'Maksimalus sukonfigūruotų kanalų skaičius', 0, NULL, 1, 0, NULL),
	(16, 3, NULL, 'MaxDiscrChannels', 'Maksimalus sukonfigūruotų diskretinių kanalų skaičius', 0, NULL, 1, 0, NULL),
	(17, 4, 1, 'Protocol', 'Papildomai nurodomas protokolas', 0, NULL, 1, 0, NULL),
	(18, 5, NULL, 'Channel', 'Kanalo numeris', 0, NULL, 1, 0, NULL),
	(20, 3, NULL, 'DeviceVersion', 'Įrenginio versija', 0, NULL, 1, 0, NULL),
	(21, 5, NULL, 'Address', 'Duomenų adresas', 0, NULL, 1, 0, NULL),
	(22, 4, NULL, 'UseRS485', 'RS485 panaudojimas', 0, NULL, 1, 0, NULL),
	(23, 5, NULL, 'DataWaitTimeout', 'Duomenu siuntimo timeoutas', 0, NULL, 1, 0, NULL),
	(24, 3, NULL, 'AddrUpper', 'Viršutinis adresas', 0, NULL, 1, 0, NULL),
	(25, 3, NULL, 'AddrLower', 'Apatinis adresas', 0, NULL, 1, 0, NULL),
	(26, 3, NULL, 'AddrSource', 'Šaltinio adresas', 0, NULL, 1, 0, NULL),
	(27, 3, NULL, 'ShortIntPeriod', 'Didelio dažnio integravimo periodas [sec]', 0, NULL, 1, 0, NULL),
	(28, 3, NULL, 'MainIntPeriod', 'Integravimo periodas [sec]', 0, NULL, 1, 0, NULL),
	(29, 3, NULL, 'CacheTimeout', 'Kešo galiojimo laikas', 0, NULL, 1, 0, NULL),
	(30, 5, NULL, 'AsduAddr', 'Asdu adresas', 0, NULL, 1, 0, NULL),
	(31, 5, NULL, 'ParamAddr', 'Parametro adresas', 0, NULL, 1, 0, NULL),
	(32, 3, NULL, 'FirstAddr', 'Pirmas adresas', 0, NULL, 1, 0, NULL),
	(34, 3, NULL, 'System', 'Matavimo sistema skaitiklyje', 0, NULL, 1, 0, NULL),
	(35, 3, NULL, 'CommHour', 'Komercine valanda', 0, NULL, 1, 0, NULL),
	(36, 5, NULL, 'FileName', 'Failo pavadinimas', 0, NULL, 1, 0, NULL),
	(37, 5, NULL, 'ProfileNr', 'Profilio numeris', 0, NULL, 1, 0, NULL),
	(38, 3, NULL, 'Corrector', 'Korektoriaus nr.', 0, NULL, 1, 0, NULL),
	(39, 2, 2, 'StopBits', 'Sustojimo bitai', 1, NULL, 1, 0, NULL),
	(40, 2, NULL, 'DataBits', 'Duomenų bitai', 1, NULL, 1, 0, NULL),
	(41, 2, 4, 'Parity', 'Lyginumas', 1, NULL, 1, 0, NULL),
	(42, 2, 5, 'HwHandshake', 'HwHandshake', 1, NULL, 1, 0, NULL),
	(43, 2, 6, 'SwHandshake', 'SwHandshake', 1, NULL, 1, 0, NULL),
	(44, 2, 7, 'RTSToggle', 'RTSToggle', 1, NULL, 1, 0, NULL),
	(45, 2, NULL, 'PredString', 'Modemo inicializacijos eilutė', 1, NULL, 1, 0, NULL),
	(46, 2, NULL, 'Connect_TimeOut', 'Susijungimo time-out', 1, '60000', 1, 0, NULL),
	(47, 4, NULL, 'Con_B_Opt', 'Susijungti prieš optimizaciją', 1, NULL, 1, 0, NULL),
	(48, 2, NULL, 'RAS_Name', 'RAS vardas', 1, NULL, 1, 0, NULL),
	(49, 2, NULL, 'RAS_IPPort', 'RAS IP prievadas', 1, NULL, 1, 0, NULL),
	(61, 3, NULL, 'Address', 'Adresas', 0, NULL, 1, 0, NULL),
	(81, 2, 41, 'SetDTR', 'DTR nustatymas', 1, 'On', 1, 0, NULL),
	(82, 2, 41, 'SetRTS', 'RTS nustatymas', 1, 'On', 1, 0, NULL),
	(101, 3, 61, 'Measuring', 'Matavimų tipas', 0, NULL, 1, 0, NULL),
	(102, 3, NULL, 'DataWaitTimeout', 'Užklaustų nekešuotų duomenų laukimo laikas [sec]', 0, '30', 1, 0, NULL),
	(103, 4, 366, 'TestMode', 'Technologinės informacijos išvedimas', 1, NULL, 1, 0, NULL),
	(104, 3, 83, 'Voltage', 'Nominali įtampa', 0, NULL, 1, 0, NULL),
	(105, 3, NULL, 'TypeCode', 'Tipo kodas', 0, NULL, 1, 0, NULL),
	(106, 5, NULL, 'Data_Code_Virt', 'Virtualus duomenų kodas', 0, NULL, 1, 0, NULL),
	(107, 5, NULL, 'Index', 'Indeksas', 0, '1', 1, 0, NULL),
	(108, 3, NULL, 'Sleep', 'Pauzė prieš ryšio pradžią, ms', 0, NULL, 1, 0, NULL),
	(109, 3, NULL, 'U_Kf', 'Įtampos transformacijos koeficientas', 0, NULL, 1, 0, NULL),
	(110, 3, NULL, 'I_Kf', 'Srovės transformacijos koeficientas', 0, NULL, 1, 0, NULL),
	(111, 3, NULL, 'PQ_Resolution', 'Skiriamoji geba', 0, NULL, 1, 0, NULL),
	(112, 3, 82, 'Direct_Connection', 'Tiesioginis jungimas', 0, NULL, 1, 0, NULL),
	(113, 4, NULL, 'BaudRate2', 'Ryšio linijos greitis 2', 0, NULL, 1, 0, NULL),
	(114, 2, 92, 'UseTransport', 'Transporto tipo panaudojimas', 1, 'Normal', 1, 0, NULL),
	(117, 4, NULL, 'PacketLen', 'Paketo ilgis', 0, NULL, 1, 0, NULL),
	(119, 3, NULL, 'ADP', 'AEAS identifikatorius', 0, NULL, 1, 0, NULL),
	(120, 3, NULL, 'Level', 'Prieigos lygis', 0, NULL, 1, 0, NULL),
	(121, 4, NULL, 'PageLen', 'Puslapio ilgis', 0, NULL, 1, 0, NULL),
	(122, 4, 116, 'PointDataRead', 'Matavimų archyvų nuskaitymo metodas', 0, NULL, 1, 0, NULL),
	(123, 3, NULL, 'Manufacturer', 'Prietaiso modelis', 0, NULL, 1, 0, NULL),
	(124, 3, NULL, 'Gateway', 'GSM modemo portas', 0, NULL, 1, 0, NULL),
	(125, 3, NULL, 'Controller', 'Šaltinio valdiklio ID', 0, NULL, 1, 0, NULL),
	(126, 3, NULL, 'Path', 'Maršrutas', 0, NULL, 1, 0, NULL),
	(128, 1, NULL, 'Address', 'Įrenginio adresas', 0, NULL, 1, 0, NULL),
	(129, 5, NULL, 'Specific_Data_Discretion', 'Naudojama specifinė duomenų diskretiškumo reikšmė [sec]', 0, NULL, 1, 0, NULL),
	(130, 5, NULL, 'Function', 'Funkcija', 0, NULL, 1, 0, NULL),
	(131, 1, NULL, 'DBConnectionString', 'Prisijungimo prie DB eilutė', 0, NULL, 1, 0, NULL),
	(132, 3, NULL, 'DBConnectionString', 'Prisijungimo prie DB eilutė, nurodoma šaltiniui', 0, NULL, 1, 0, NULL),
	(133, 1, NULL, 'DBProvider', 'Prisijungimo prie DB tiekėjas', 0, NULL, 1, 0, NULL),
	(134, 3, NULL, 'DBProvider', 'Prisijungimo prie DB tiekėjas, nurodomas šaltiniui', 0, NULL, 1, 0, NULL),
	(135, 1, NULL, 'DBDataSource', 'DB resurso vardas', 0, NULL, 1, 0, NULL),
	(136, 3, NULL, 'DBDataSource', 'DB resurso vardas, nurodomas šaltiniui', 0, NULL, 1, 0, NULL),
	(137, 1, NULL, 'DBUser', 'DB vartotojo vardas', 0, NULL, 1, 0, NULL),
	(138, 3, NULL, 'DBUser', 'DB vartotojo vardas, nurodomas šaltiniui', 0, NULL, 1, 0, NULL),
	(139, 1, NULL, 'DBPassword', 'DB vartotojo slaptažodis', 0, NULL, 1, 1, NULL),
	(140, 3, NULL, 'DBPassword', 'DB vartotojo slaptažodis, nurodomas šaltiniui', 0, NULL, 1, 1, NULL),
	(141, 1, NULL, 'DBIntegratedSecurity', 'DB numatyta sauga', 0, NULL, 1, 0, NULL),
	(142, 3, NULL, 'DBIntegratedSecurity', 'DB numatyta sauga, nurodoma šaltiniui', 0, NULL, 1, 0, NULL),
	(143, 1, NULL, 'DBPersistSecurityInfo', 'DB saugumo informacijos išlaikymo požymis', 0, NULL, 1, 0, NULL),
	(144, 3, NULL, 'DBPersistSecurityInfo', 'DB saugumo informacijos išlaikymo požymis, nurodomas šaltiniui', 0, NULL, 1, 0, NULL),
	(145, 1, NULL, 'DBInitialCatalog', 'DB pradinis katalogas', 0, NULL, 1, 0, NULL),
	(146, 3, NULL, 'DBInitialCatalog', 'DB pradinis katalogas, nurodomas šaltiniui', 0, NULL, 1, 0, NULL),
	(147, 5, NULL, 'MeasPoint', 'Matavimo vieta (ID_MeasurementPlace)', 0, NULL, 1, 0, NULL),
	(148, 5, NULL, 'MeasType', 'Matavimo rezultatų tipas (ID_ResultType)', 0, NULL, 1, 0, NULL),
	(149, 5, 82, 'Compress', 'Duomenų suspaudimas', 0, '0', 1, 0, NULL),
	(150, 5, 82, 'Cache', 'Duomenys iš kešo', 0, '0', 1, 0, NULL),
	(151, 3, 811, 'AUTO_ADD_NEW_LINES_FOR_GENERATION', 'Automatiškai įtraukti naujus generuojamus matavimus', 0, '0', 1, 0, NULL),
	(152, 5, NULL, 'JournalID', 'Žurnalo identifikatorius', 0, '0', 1, 0, NULL),
	(153, 3, NULL, 'U_Kf', 'Energijos ir galios koeficientas U', 0, '0', 1, 0, NULL),
	(154, 3, NULL, 'I_Kf', 'Energijos ir galios koeficientas I', 0, '0', 1, 0, NULL),
	(155, 3, NULL, 'PQ_Resolution', 'Koeficientas PQ', 0, '0', 1, 0, NULL),
	(156, 4, NULL, 'SendDelay', 'Uždelsimas prieš siunčiant sekantį užklausimą, ms', 0, '0', 1, 0, NULL),
	(157, 4, NULL, 'LoginDelay', 'Uždelsimas prieš siunčiant antrą login užklausą, ms', 0, '0', 1, 0, NULL),
	(158, 5, NULL, 'DeviceType', 'Realaus prietaiso tipas', 0, NULL, 1, 0, NULL),
	(159, 5, NULL, 'MaxLoadStart1', 'Maksimalios apkrovos pirmo intervalo pradžia', 0, '0', 1, 0, NULL),
	(160, 5, NULL, 'MaxLoadEnd1', 'Maksimalios apkrovos pirmo intervalo pabaiga', 0, '0', 1, 0, NULL),
	(161, 5, NULL, 'MaxLoadStart2', 'Maksimalios apkrovos antro intervalo pradžia', 0, '0', 1, 0, NULL),
	(162, 5, NULL, 'MaxLoadEnd2', 'Maksimalios apkrovos antro intervalo pabaiga', 0, '0', 1, 0, NULL),
	(163, 1, NULL, 'DeviceVersion', 'Nuskaitymo taško įrenginio versija', 0, NULL, 1, 0, NULL),
	(164, 5, NULL, 'Min', 'Minimalus laikų skirtumas, reikalaujantis korekcijos, sek', 0, '0', 1, 0, NULL),
	(165, 5, NULL, 'Max', 'Maksimalus laikų skirtumas, reikalaujantis korekcijos, sek', 0, '0', 1, 0, NULL),
	(166, 3, NULL, 'DataSetDirectory', 'ClientDataSet formato bylų katalogas', 0, NULL, 1, 0, NULL),
	(167, 3, NULL, 'FileMask', 'Bylos vardo kaukė', 0, NULL, 1, 0, NULL),
	(168, 3, NULL, 'FileDateMask', 'Datos kaukė bylos varde', 0, NULL, 1, 0, NULL),
	(169, 5, NULL, 'POINTNAME', 'Taško vardas', 0, NULL, 1, 0, NULL),
	(170, 3, NULL, 'WhMask', 'WhMask', 0, NULL, 1, 0, NULL),
	(171, 3, NULL, 'BaudRate', 'Ryšio su skaitikliu greitis', 0, NULL, 1, 0, NULL),
	(172, 3, NULL, 'Meter_Address', 'Galutinio prietaiso adresas', 0, NULL, 1, 0, NULL),
	(173, 3, NULL, 'Meter_AddrSource', 'Galutinio prietaiso USPD objekto adresas', 0, NULL, 1, 0, NULL),
	(174, 3, NULL, 'Meter_DeviceVersion', 'Galutinio prietaiso versija', 0, NULL, 1, 0, NULL),
	(175, 3, NULL, 'Meter_MainIntPeriod', 'Galutinio prietaiso integravimo periodas', 0, NULL, 1, 0, NULL),
	(176, 3, NULL, 'Meter_U_Kf', 'Galutinio prietaiso energijos ir galios koeficientas U', 0, NULL, 1, 0, NULL),
	(177, 3, NULL, 'Meter_I_Kf', 'Galutinio prietaiso energijos ir galios koeficientas I', 0, NULL, 1, 0, NULL),
	(178, 3, NULL, 'Meter_PQ_Resolution', 'Galutinio prietaiso koeficientas PQ', 0, NULL, 1, 0, NULL),
	(179, 2, NULL, 'UseRAS', 'RAS panaudojimas', 1, NULL, 1, 0, NULL),
	(180, 5, 461, 'HalfHourSum', 'Imti duomenis iš ', 0, NULL, 1, 0, NULL),
	(183, 3, 466, 'SubDirs', 'Subkatalogų struktūros pateikimas', 0, NULL, 1, 0, NULL),
	(184, 5, 466, 'SubDirs', 'Subkatalogų struktūros pateikimas', 0, NULL, 1, 0, NULL),
	(185, 5, NULL, 'FileMask', 'Bylos vardo kaukė', 0, NULL, 1, 0, NULL),
	(186, 5, NULL, 'FileDateMask', 'Datos kaukė bylos varde', 0, NULL, 1, 0, NULL),
	(187, 5, NULL, 'MeasPoint', 'Matavimo taško kodas', 0, NULL, 1, 0, NULL),
	(188, 3, 82, 'Compress', 'Duomenų suspaudimas HTTP protokolui', 0, NULL, 1, 0, NULL),
	(189, 3, NULL, 'RunOn', 'OPC serverio kompiuterio vardas', 0, NULL, 1, 0, NULL),
	(190, 3, NULL, 'OPCServer', 'OPC serverio vardas', 0, NULL, 1, 0, NULL),
	(191, 3, NULL, 'OPCPrefix', 'OPC šaltinio elementų prefiksas', 0, NULL, 1, 0, NULL),
	(192, 3, NULL, 'RefreshRate', 'Atnaujinimo intervalas, ms (RefreshRate)', 0, NULL, 1, 0, NULL),
	(193, 3, NULL, 'DeadBand_FON', 'Nejautrumo sritis (DeadBand)', 0, NULL, 1, 0, NULL),
	(194, 5, NULL, 'OPCItem', 'OPC elementas (item)', 0, NULL, 1, 0, NULL),
	(195, 5, NULL, 'FON_Save', 'Archyvuoti duomenis', 0, NULL, 1, 0, NULL),
	(196, 4, NULL, 'ControllerTimeout', 'Prieigos taško atsakymo laukimo laikas, s', 0, NULL, 1, 0, NULL),
	(197, 4, NULL, 'PacketCount', 'Paketų kiekis', 0, NULL, 1, 0, NULL),
	(198, 3, NULL, 'UserId', 'Šaltinio prisijungimo identifikatorius', 0, NULL, 1, 0, NULL),
	(199, 3, NULL, 'BeforeBoudInMSec', 'Duomenys neimami iki jų diskretiškumo ribos likus nurodytam laikui, ms', 0, NULL, 1, 0, NULL),
	(200, 3, NULL, 'TimeOutifBoudInMSec', 'Uždelsimo laikas jei pasiekta duomenų keitimo laiko riba, ms', 0, NULL, 1, 0, NULL),
	(201, 3, NULL, 'SendErrorifBoud', 'Jei pasiekta duomenų keitimo laiko riba - siųsti', 0, NULL, 1, 0, NULL),
	(202, 5, NULL, 'ProfileLength', 'Profilio ilgis', 0, NULL, 1, 0, NULL),
	(203, 4, NULL, 'ChannelTrafficTimeOut', 'Kanalo pranešimų srauto laukimo laikas, s', 0, NULL, 1, 0, NULL),
	(204, 4, NULL, 'InterCharacterTimeOut', 'Sekančio simbolio pranešimo sraute laukimo laikas, s', 0, NULL, 1, 0, NULL),
	(205, 4, NULL, 'ResponseTimeOut', 'Atsakymo laukimo laikas, s', 0, NULL, 1, 0, NULL),
	(206, 4, NULL, 'NbrRetries', 'Pakartojimų kiekis', 0, NULL, 1, 0, NULL),
	(207, 3, NULL, 'Retranslator_Nr', 'Retransliatoriaus numeris', 0, NULL, 1, 0, NULL),
	(208, 1, NULL, 'APC_Nr', 'APC-GPRS adapterio numeris', 0, NULL, 1, 0, NULL),
	(209, 3, NULL, 'APC_Nr', 'APC-GPRS adapterio numeris', 0, NULL, 1, 0, NULL),
	(210, 3, NULL, 'Power', 'Galia ryšiui', 0, NULL, 1, 0, NULL),
	(211, 3, NULL, 'RadioChannel', 'Radiosignalo numeris', 0, NULL, 1, 0, NULL),
	(212, 1, NULL, 'Delta', 'Papildomų įrašų kiekis dėl RTC-numetimų', 0, NULL, 1, 0, NULL),
	(213, 3, NULL, 'Delta', 'Papildomų įrašų kiekis dėl RTC-numetimų', 0, NULL, 1, 0, NULL),
	(214, 1, NULL, 'PacketLen', 'Paketo ilgis', 0, NULL, 1, 0, NULL),
	(215, 3, NULL, 'PacketLen', 'Paketo ilgis30', 0, NULL, 1, 0, NULL),
	(216, 1, NULL, 'Local_IP', 'Lokalus IP adresas', 1, NULL, 1, 0, NULL),
	(217, 3, NULL, 'Local_IP', 'Lokalus IP adresas', 1, NULL, 1, 0, NULL),
	(218, 1, NULL, 'Local_Port', 'Lokalus IP prievadas', 1, NULL, 1, 0, NULL),
	(219, 3, NULL, 'Local_Port', 'Lokalus IP prievadas', 1, NULL, 1, 0, NULL),
	(220, 3, NULL, 'InitSleep', 'Uždelsimas po porto inicializacijos baito (0x99) išsiuntimo', 0, NULL, 1, 0, NULL),
	(221, 3, NULL, 'LoginRepeat', 'Prisijungimo kartojimų skaičius', 0, NULL, 1, 0, NULL),
	(222, 3, NULL, 'MBUS_FCB_Byte', 'Frame Count-Bit naudojimas (MBUS)', 0, NULL, 1, 0, NULL),
	(223, 5, NULL, 'Value', 'Reikšmė', 0, NULL, 1, 0, NULL),
	(224, 5, NULL, 'TS', 'Signalo numeris', 0, NULL, 1, 0, NULL),
	(225, 3, NULL, 'OptoPort', 'Duomenų perdavimas per optinį IR portą', 0, NULL, 1, 0, NULL),
	(226, 3, NULL, 'DeviceType', 'Prietaiso tipas', 0, NULL, 1, 0, NULL),
	(227, 5, NULL, 'MaxCorrectionWait', 'Maksimalus sinchronizavo momento laukimo laikas', 0, NULL, 1, 0, NULL),
	(228, 3, NULL, 'Password2', 'Antro lygmens slaptažodis', 0, NULL, 1, 1, NULL),
	(229, 5, NULL, 'SummerTime', 'Vasaros laiko perdavimas', 0, NULL, 1, 0, NULL),
	(230, 3, 539, 'ThreeWire', 'Tinklo tipas', 0, NULL, 1, 0, NULL),
	(231, 3, 82, 'IgnoreDevTime', 'Ar ignoruoti prietaiso laiką', 0, NULL, 1, 0, NULL),
	(232, 5, NULL, 'MeterNumber', 'Įrenginio numeris', 0, NULL, 1, 0, NULL),
	(233, 5, NULL, 'DeviceVersion', 'Įrenginio versija', 0, NULL, 1, 0, NULL),
	(234, 5, NULL, 'U_Kf', 'Įtampos transformacijos koeficientas', 0, NULL, 1, 0, NULL),
	(235, 5, NULL, 'I_Kf', 'Srovės transformacijos koeficientas', 0, NULL, 1, 0, NULL),
	(236, 5, NULL, 'PQ_Resolution', 'Koeficientas PQ', 0, NULL, 1, 0, NULL),
	(237, 5, 82, 'Direct_Connection', 'Tiesioginis jungimas', 0, NULL, 1, 0, NULL),
	(238, 5, NULL, 'TAB', 'Užklausos parametras 1', 0, NULL, 1, 0, NULL),
	(239, 5, NULL, 'IDX0', 'Užklausos parametras 2', 0, NULL, 1, 0, NULL),
	(240, 5, NULL, 'IDX1', 'Užklausos parametras 3', 0, NULL, 1, 0, NULL),
	(241, 3, NULL, 'StoredData', 'Duomenys iš buferio', 0, NULL, 1, 0, NULL),
	(242, 3, NULL, 'RemotePort', 'Keisti šliuzo porto nustatymus', 0, NULL, 1, 0, NULL),
	(243, 3, NULL, 'LoginTimeout', 'Uždelsimas prieš siunčiant antrą login užklausą, ms', 0, NULL, 1, 0, NULL),
	(244, 3, NULL, 'AddInc', 'Prieaugio reikšmę', 0, NULL, 1, 0, NULL),
	(245, 3, NULL, 'RemoteTimeout', 'Keisti time-out nustatymus', 0, NULL, 1, 0, NULL),
	(246, 3, NULL, 'RemoteBaudRate', 'GSM šliuzo COM greitis', 0, NULL, 1, 0, NULL),
	(247, 3, NULL, 'RemoteDataBits', 'GSM šliuzo duomenų bitai', 0, NULL, 1, 0, NULL),
	(248, 3, NULL, 'RemoteParity', 'GSM šliuzo lyginumas', 0, NULL, 1, 0, NULL),
	(249, 3, NULL, 'RemoteStopBits', 'GSM šliuzo sustojimo bitai', 0, NULL, 1, 0, NULL),
	(250, 3, NULL, 'Round', 'Ženklų skaičius po kablelio, duomenų apvalinimui', 0, NULL, 1, 0, NULL),
	(251, 3, NULL, 'DataFormat', 'DataSet duomenų perdavimo formatas', 0, NULL, 1, 0, NULL),
	(252, 2, NULL, 'Connect_TimeOut', 'IP susijungimo time-out, ms', 1, '20000', 1, 0, NULL),
	(253, 3, NULL, 'ResourceID', 'MeterAccess resurso identifikatorius', 0, NULL, 1, 0, NULL),
	(254, 4, NULL, 'RequestDelay', 'Užklausinėjimo dažnumas sekundėmis', 0, NULL, 1, 0, NULL),
	(255, 5, NULL, 'MeterID', 'Skaitiklio identifikatorius WEB servisui', 0, NULL, 1, 0, NULL),
	(256, 5, NULL, 'ObisCode', 'Duomenų identifikatorius (OBIS kodas)', 0, NULL, 1, 0, NULL),
	(257, 5, NULL, 'ClassID', 'Duomenų tipo (klasės) identifikatorius', 0, NULL, 1, 0, NULL),
	(258, 5, NULL, 'AttributeID', 'Klasės atributo identifikatorius WEB servisui', 0, NULL, 1, 0, NULL),
	(259, 5, NULL, 'Scaler', 'Daugiklis kablelio pozicijai', 0, NULL, 1, 0, NULL),
	(260, 5, NULL, 'ShortName', 'Objekto trumpasis adresas HEX formatu', 0, NULL, 1, 0, NULL),
	(261, 3, NULL, 'Interface', 'Interfeiso tipas', 0, NULL, 1, 0, NULL),
	(262, 3, NULL, 'Channel', 'Šilumos įvadas', 0, NULL, 1, 0, NULL),
	(263, 3, NULL, 'RsrcFactoryAddr', 'Resource Factory WEB serviso adresas', 0, NULL, 1, 0, NULL),
	(264, 3, NULL, 'RsrcOperationAddr', 'Resource Operation WEB serviso adresas', 0, NULL, 1, 0, NULL),
	(265, 3, NULL, 'Protocol', 'Ryšio protokolas', 0, NULL, 1, 0, NULL),
	(266, 2, NULL, 'TID', 'Unikalus ryšio prietaiso/kanalo identifikatorius', 1, NULL, 1, 0, NULL),
	(267, 2, 586, 'Proxy', 'Prisijungimo parametrai', 1, '<FN>STProxyPI.dll</FN><Ver>1.0</Ver><Par Mode="T-T" ADS="55" TO="2000"/>', 1, 0, NULL),
	(268, 3, NULL, 'DeviceID', 'Skaitiklio indeksas', 0, NULL, 1, 0, NULL),
	(269, 5, NULL, 'PowerFailureLogSn', 'Maitinimų dingimo žurnalo trumpasis adresas', 0, NULL, 1, 0, NULL),
	(270, 5, NULL, 'PhaseChangeLogSn', 'Fazių pasikeitimų žurnalo trumpasis adresas', 0, NULL, 1, 0, NULL),
	(271, 5, NULL, 'OverVoltageLogSn', 'Viršįtampio žurnalo trumpasis adresas', 0, NULL, 1, 0, NULL),
	(272, 5, NULL, 'UnderVoltageLogSn', 'Sumažintosios įtampos žurnalo trumpasis adresas', 0, NULL, 1, 0, NULL),
	(273, 5, NULL, 'PowerOverLimitLogSn', 'Galios limitų viršijimų žurnalo trumpasis adresas', 0, NULL, 1, 0, NULL),
	(274, 5, NULL, 'ReverseCurrentLogSn', 'Atgalinės srovės žurnalo trumpasis adresas', 0, NULL, 1, 0, NULL),
	(275, 5, NULL, 'OverCurrentLogSn', 'Antsrovio žurnalo trumpasis adresas', 0, NULL, 1, 0, NULL),
	(276, 5, NULL, 'MagneticInfluenceLogSn', 'Magnetinio poveikio žurnalo trumpasis adresas', 0, NULL, 1, 0, NULL),
	(277, 5, NULL, 'MainCoverOpenLogSn', 'Pagrindinio apdangalų atidarymo žurnalo trumpasis adresas', 0, NULL, 1, 0, NULL),
	(278, 5, NULL, 'CableCoverOpenLogSn', 'Kabelio apdangalų atidarymo žurnalo trumpasis adresas', 0, NULL, 1, 0, NULL),
	(279, 5, NULL, 'ClockSettingLogSn', 'Laiko nustatymų žurnalo trumpasis adresas', 0, NULL, 1, 0, NULL),
	(280, 5, NULL, 'ParameterizationLogSn', 'Parametrizacijos žurnalo trumpasis adresas', 0, NULL, 1, 0, NULL),
	(281, 5, NULL, 'ErrorLogSn', 'Klaidų žurnalo trumpasis adresas', 0, NULL, 1, 0, NULL),
	(282, 3, NULL, 'BaudRate2', 'Ryšio linijos greitis po perjungimo', 0, NULL, 1, 0, NULL),
	(283, 3, NULL, 'ConnectVia', 'Prietaiso tipas, per kurį yra rišamasi prie skaitiklio', 0, NULL, 1, 0, NULL),
	(284, 5, NULL, 'DeviceNumber', 'Prietaiso numeris', 0, NULL, 1, 0, NULL),
	(285, 5, NULL, 'TypeCode', 'Prietaiso tipo kodas', 0, NULL, 1, 0, NULL),
	(286, 5, NULL, 'ChannelClassID', 'Profilio kanalo duomenų tipo (klasės) identifikatorius', 0, NULL, 1, 0, NULL),
	(287, 5, NULL, 'ChannelAttributeID', 'Profilio kanalo klasės atributo identifikatorius', 0, NULL, 1, 0, NULL),
	(288, 5, NULL, 'StandardEventLog', 'Standartinis įvykių žurnalas OBIS', 0, NULL, 1, 0, NULL),
	(289, 5, NULL, 'FraudEventLog', 'Pažeidimų aptikimo įvykių žurnalas OBIS', 0, NULL, 1, 0, NULL),
	(290, 5, NULL, 'ControlEventLog', 'Relių kontrolės įvykių žurnalas OBIS', 0, NULL, 1, 0, NULL),
	(291, 5, NULL, 'ExtraEventLog', 'Extra įvykių žurnalas OBIS', 0, NULL, 1, 0, NULL),
	(292, 3, NULL, 'ClockShortName', '"Laikrodžio" objekto trumpasis adresas', 0, NULL, 1, 0, NULL),
	(293, 3, NULL, 'MaxMetersInRequest', 'Maksimalus skaitiklių kiekis viename MeterAccess resurse', 0, NULL, 1, 0, NULL),
	(294, 3, NULL, 'CheckMeterNr', 'Skaitiklių numerių ryšio kanaluose tikrinimas', 0, NULL, 1, 0, NULL),
	(295, 5, NULL, 'StopKadr', 'Stop kadrų profilio naudojimas', 0, NULL, 1, 0, NULL),
	(296, 4, NULL, 'TimeOutMSec_USPD_164_01', 'Taimautas milisekundėmis, nurodomas šaltiniui', 0, NULL, 1, 0, NULL),
	(297, 4, NULL, 'RepeatRequest_USPD_164_01', 'Pakartojimų skaičius nesėkmingo ryšio atveju, nurodomas šaltiniui', 0, NULL, 1, 0, NULL),
	(298, 3, NULL, 'Address_USPD_164_01', 'Adresas, nurodomas šaltiniui', 0, NULL, 1, 0, NULL),
	(299, 3, NULL, 'ADP_USPD_164_01', 'AEAS identifikatorius, nurodomas šaltiniui', 0, NULL, 1, 0, NULL),
	(300, 3, NULL, 'User_USPD_164_01', 'Šaltinio prisijungimo vardas, nurodomas šaltiniui', 0, NULL, 1, 0, NULL),
	(301, 3, NULL, 'Password_USPD_164_01', 'Šaltinio prisijungimo slaptažodis, nurodomas šaltiniui', 0, NULL, 1, 1, NULL),
	(302, 3, NULL, 'TypeCode_USPD_164_01', 'Tipo kodas, nurodomas šaltiniui', 0, NULL, 1, 0, NULL),
	(303, 3, NULL, 'DeviceVersion_USPD_164_01', 'Įrenginio versija, nurodoma šaltiniui', 0, NULL, 1, 0, NULL),
	(304, 3, NULL, 'Interface_USPD_164_01', 'Interfeiso tipas, nurodomas šaltiniui', 0, NULL, 1, 0, NULL),
	(305, 4, NULL, 'ControllerTimeout_USPD_164_01', 'Prieigos taško atsakymo laukimo laikas, s, nurodomas šaltiniui', 0, NULL, 1, 0, NULL),
	(308, 1, NULL, 'Address_USPD_164_01', 'Adresas', 0, NULL, 1, 0, NULL),
	(309, 1, NULL, 'ADP_USPD_164_01', 'AEAS identifikatorius', 0, NULL, 1, 0, NULL),
	(310, 1, NULL, 'User_USPD_164_01', 'Šaltinio prisijungimo vardas', 0, NULL, 1, 0, NULL),
	(311, 1, NULL, 'Password_USPD_164_01', 'Šaltinio prisijungimo slaptažodis', 0, NULL, 1, 1, NULL),
	(313, 1, NULL, 'DeviceVersion_USPD_164_01', 'Įrenginio versija', 0, NULL, 1, 0, NULL),
	(314, 1, NULL, 'Interface_USPD_164_01', 'Interfeiso tipas', 0, NULL, 1, 0, NULL),
	(316, 3, NULL, 'TMAddOn', 'TMAddOn', 1, NULL, 1, 0, NULL),
	(317, 3, NULL, 'Password1', 'Šaltinio prisijungimo slaptažodis 1', 0, NULL, 1, 1, NULL),
	(318, 3, NULL, 'Password2', 'Šaltinio prisijungimo slaptažodis 2', 0, NULL, 1, 1, NULL),
	(319, 4, NULL, 'LoginTimeout', 'Atskiras laukimo laikas ryšio pradžiai', 0, NULL, 1, 0, NULL),
	(320, 4, NULL, 'LoginRepeat', 'Atskiras pakartojimų kiekis ryšio pradžiai', 0, NULL, 1, 0, NULL),
	(321, 5, NULL, 'DeviceID', 'Prietaiso identifikatorius', 0, NULL, 1, 0, NULL),
	(322, 5, NULL, 'ParamID', 'Apskaitos kanalo identifikatorius', 0, NULL, 1, 0, NULL),
	(323, 5, NULL, 'System', 'Matavimo sistema skaitiklyje', 0, NULL, 1, 0, NULL),
	(324, 5, NULL, 'ParamSystemName', 'Sisteminis kanalo pavadinimas (kodas)', 0, NULL, 0, 0, NULL),
	(325, 5, NULL, 'ParamDescription', 'Kanalo aprašymas', 0, NULL, 0, 0, NULL),
	(326, 5, NULL, 'ParamUnits', 'Matavimo vienetai', 0, NULL, 0, 0, NULL),
	(327, 3, NULL, 'PointNamePrefix', 'Taško pavadinimo priešdėlis', 0, NULL, 0, 0, NULL),
	(328, 3, NULL, 'PointNameEndix', 'Taško pavadinimo pabaiga', 0, NULL, 0, 0, NULL),
	(329, 5, NULL, 'Kind', 'Archyvo tipas', 0, NULL, 1, 0, NULL),
	(330, 5, NULL, 'Interface', 'Interfeiso indeksas', 0, NULL, 1, 0, NULL),
	(331, 5, NULL, 'Phase', 'Fazės numeris', 0, NULL, 1, 0, NULL),
	(332, 3, NULL, 'Port', 'Portas', 0, NULL, 1, 0, NULL),
	(333, 4, NULL, 'Connect_TimeOut', 'Pirmo atsakymo laukimo timeout, ms', 0, NULL, 1, 0, NULL),
	(334, 5, NULL, 'DBParam', 'DB parametras', 0, NULL, 1, 0, NULL),
	(335, 5, NULL, 'DBParam2', 'DB parametras 2', 0, NULL, 1, 0, NULL),
	(336, 5, NULL, 'RelayLogSn', 'Relių žurnalo trumpasis adresas', 0, NULL, 1, 0, NULL),
	(337, 3, NULL, 'OptimizationByDT', 'Optimizavimas pagal laiką', 0, NULL, 1, 0, NULL),
	(338, 5, NULL, 'Forecast', 'Prognozuojami duomenys', 0, NULL, 1, 0, NULL),
	(339, 5, NULL, 'ShortName', 'Objekto trumpasis adresas HEX formatu įrašymui', 0, NULL, 0, 0, NULL),
	(340, 2, NULL, 'PhoneNr', 'Telefono numeris', 0, NULL, 0, 0, NULL),
	(341, 3, NULL, 'DeviceNumber', 'Skaitiklio numeris', 0, NULL, 0, 0, NULL),
	(342, 3, NULL, 'Scalermom', 'Daugiklis kablelio pozicijai momentiniams', 0, NULL, 1, 0, NULL),
	(343, 3, NULL, 'Scaler', 'Daugiklis kablelio pozicijai', 0, NULL, 1, 0, NULL),
	(344, 3, NULL, 'Password3', 'Šaltinio prisijungimo slaptažodis 3', 0, NULL, 1, 1, NULL),
	(345, 3, NULL, 'AdapterAddr', 'Adapterio adresas', 0, NULL, 1, 0, NULL),
	(346, 3, NULL, 'PacketCRC', 'Nuskaityti paketo CRC', 0, NULL, 1, 0, NULL),
	(347, 3, NULL, 'DataCRC', 'Nuskaityti paketo duomenų CRC', 0, NULL, 1, 0, NULL),
	(348, 5, NULL, 'ProfileLength', 'Paros duomenų profilio ilgis', 0, NULL, 1, 0, NULL),
	(349, 5, NULL, 'ProfileLength', 'Mėnesinių duomenų profilio ilgis', 0, NULL, 1, 0, NULL),
	(350, 5, NULL, 'ProfileLength', 'Valandinių duomenų profilio ilgis', 0, NULL, 1, 0, NULL),
	(351, 5, NULL, 'ProfileLength', 'Pusvalandinių duomenų profilio ilgis', 0, NULL, 1, 0, NULL),
	(352, 5, NULL, 'ProfileLength', 'Minutinių duomenų profilio ilgis', 0, NULL, 1, 0, NULL),
	(353, 4, NULL, 'DataWaitTimeout', 'Duomenų laukimo laikas, s', 0, NULL, 1, 0, NULL),
	(354, 3, NULL, 'ParityEmulation', 'Lyginumo emuliacija', 0, NULL, 1, 0, NULL),
	(355, 5, NULL, 'SOURCE_RP', 'Duomenys iš ataskaitos', 0, NULL, 0, 0, NULL),
	(356, 3, NULL, 'ManagerAddr', 'Koncentratoriaus parametrų/valdymo WEB serviso adresas', 0, NULL, 1, 0, NULL),
	(357, 3, NULL, 'FloatByteOrder', 'Float skaičiaus baitų išdėstymo seka', 0, NULL, 1, 0, NULL),
	(358, 2, NULL, 'Link_Channel', 'Link_Channel', 1, NULL, 1, 0, NULL),
	(359, 2, NULL, 'UsePhone', 'UsePhone', 1, NULL, 1, 0, NULL),
	(360, 5, NULL, 'TimeChannel', 'Papildomos laiko žymės kanalas', 0, NULL, 1, 0, NULL),
	(361, 5, NULL, 'WithTime', 'TimeChannel laiko žymės naudojamas', 0, NULL, 1, 0, NULL),
	(363, 3, NULL, 'SubscriptionAddr', 'Įvykių prenumeratos WEB serviso adresas', 0, NULL, 1, 0, NULL),
	(364, 3, NULL, 'EventSinkAddr', 'Įvykių gavėjo WEB serviso adresas', 0, NULL, 1, 0, NULL),
	(365, 5, NULL, 'PowerFailureLogObis', 'Maitinimų dingimo žurnalo OBIS kodas', 0, NULL, 1, 0, NULL),
	(366, 5, NULL, 'PhaseChangeLogObis', 'Fazių pasikeitimų žurnalo OBIS kodas', 0, NULL, 1, 0, NULL),
	(367, 5, NULL, 'OverVoltageLogObis', 'Viršįtampio žurnalo OBIS kodas', 0, NULL, 1, 0, NULL),
	(368, 5, NULL, 'UnderVoltageLogObis', 'Sumažintosios įtampos žurnalo OBIS kodas', 0, NULL, 1, 0, NULL),
	(369, 5, NULL, 'PowerOverLimitLogObis', 'Galios limitų viršijimų žurnalo OBIS kodas', 0, NULL, 1, 0, NULL),
	(370, 5, NULL, 'ReverseCurrentLogObis', 'Atgalinės srovės žurnalo OBIS kodas', 0, NULL, 1, 0, NULL),
	(371, 5, NULL, 'OverCurrentLogObis', 'Antsrovio žurnalo OBIS kodas', 0, NULL, 1, 0, NULL),
	(372, 5, NULL, 'MagneticInfluenceLogObis', 'Magnetinio poveikio žurnalo OBIS kodas', 0, NULL, 1, 0, NULL),
	(373, 5, NULL, 'MainCoverOpenLogObis', 'Pagrindinio apdangal? atidarymo žurnalo OBIS kodas', 0, NULL, 1, 0, NULL),
	(374, 5, NULL, 'CableCoverOpenLogObis', 'Kabelio apdangal? atidarymo žurnalo OBIS kodas', 0, NULL, 1, 0, NULL),
	(375, 5, NULL, 'ClockSettingLogObis', 'Laiko nustatymų žurnalo OBIS kodas', 0, NULL, 1, 0, NULL),
	(376, 5, NULL, 'ParameterizationLogObis', 'Parametrizacijos žurnalo OBIS kodas', 0, NULL, 1, 0, NULL),
	(377, 5, NULL, 'ErrorLogObis', 'Klaidų žurnalo OBIS kodas', 0, NULL, 1, 0, NULL),
	(378, 5, NULL, 'RelayLogObis', 'Relių žurnalo OBIS kodas', 0, NULL, 1, 0, NULL),
	(379, 3, NULL, 'ReadIntervalsCount', 'Profilio intervalų kiekis per vieną užklausą', 0, NULL, 1, 0, NULL),
	(380, 3, NULL, 'BadCRC_asNormal', 'Duomenų statuso keitimas į normalų su klaidingu CRC profilio atsakyme', 0, NULL, 1, 0, NULL),
	(381, 3, NULL, 'DelayAfterSessionMSec', 'Pauzė po 1107 protokolo sesijos užbaigimo pasiuntimo komandos', 0, NULL, 1, 0, NULL),
	(382, 5, NULL, 'PipelineName', 'Vamzdyno pavadinimas', 0, NULL, 1, 0, NULL),
	(383, 3, NULL, 'Online', 'Duomenų nuskaitymo režimas', 0, NULL, 1, 0, NULL),
	(384, 5, NULL, 'PointCode', 'Prietaiso kodas', 0, NULL, 1, 0, NULL),
	(385, 5, NULL, 'Partial', 'Dalinių reikšmių nuskaitymas', 0, NULL, 1, 0, NULL),
	(386, 5, NULL, 'MeterID', 'Skaitiklio eilės numeris koncentratoriuje', 0, NULL, 1, 0, NULL),
	(387, 5, 82, 'Multistep', 'Naudoti daugiažingsnių užduočių metodą', 0, NULL, 0, 0, NULL),
	(388, 3, NULL, 'DeviceNumber_KSPD_5', 'KSPD numeris', 0, NULL, 1, 0, NULL),
	(389, 3, NULL, 'Port_KSPD_5', 'KSPD portas', 0, NULL, 1, 0, NULL),
	(390, 3, NULL, 'BaudRate_KSPD_5', 'KSPD ryšio greitis', 0, NULL, 1, 0, NULL),
	(391, 5, NULL, 'ObisCodeForCurrent', 'Duomenų identifikatorius WEB servisui Online rėžime', 0, NULL, 1, 0, NULL),
	(392, 5, NULL, 'ClassIDForCurrent', 'Duomenų tipo (klasės) identifikatorius WEB servisui Online rėžime', 0, NULL, 1, 0, NULL),
	(393, 5, NULL, 'AttributeIDForCurrent', 'Klasės atributo identifikatorius WEB servisui Online rėžime', 0, NULL, 1, 0, NULL),
	(394, 3, NULL, 'ProtocolFileName', 'Protokolo failo pavadinimas be praplėtimo', 0, NULL, 1, 0, NULL),
	(395, 3, NULL, 'DeviceFileName', 'Įrenginio failo pavadinimas be praplėtimo', 0, NULL, 1, 0, NULL),
	(396, 3, NULL, 'ChannelFileName', 'Ryšio kanalo failo pavadinimas be praplėtimo', 0, NULL, 1, 0, NULL),
	(397, 3, NULL, 'NetADP', 'Kompiuterio potinklio adresas', 0, NULL, 1, 0, NULL),
	(398, 3, NULL, 'NetAddress', 'Objekto adresas', 0, NULL, 1, 0, NULL),
	(399, 3, NULL, 'Identifier', 'Identifikatorius', 0, NULL, 1, 0, NULL),
	(400, 3, NULL, 'User2', 'Antras šaltinio prisijungimo vardas', 0, NULL, 1, 0, NULL),
	(401, 3, NULL, 'User3', 'Trečias šaltinio prisijungimo vardas', 0, NULL, 1, 0, NULL),
	(402, 3, NULL, 'CloseSessionTimeOut', 'Sesijos time-out', 0, NULL, 1, 0, NULL),
	(403, 5, NULL, 'IndexCurrent', 'Einamųjų duomenų indeksas', 0, NULL, 1, 0, NULL),
	(404, 5, NULL, 'RequestDelay', 'Užklausinėjimo dažnumas sekundėmis, vykdant daugiažingsnes užduotis', 0, NULL, 1, 0, NULL),
	(405, 5, NULL, 'ExpirationDuration', 'Daugiažingsnės užduoties maksimali vykdymo trukmė minutėmis', 0, NULL, 0, 0, NULL),
	(406, 3, 82, 'DeviceInDaylight', 'Prietaiso darbo žiemos/vasaros laiku požymis', 0, NULL, 1, 0, NULL),
	(407, 3, NULL, 'CanId', 'Protokolo CAN adresas', 0, NULL, 1, 0, NULL),
	(408, 5, NULL, 'GroupNr', 'Aritmetinė kanalų suma su ženklu', 0, NULL, 1, 0, NULL),
	(409, 3, NULL, 'DeviceID', 'Koncentratoriaus identifikatorius', 0, NULL, 1, 0, NULL),
	(410, 3, NULL, 'ReadFractionalPart', 'Nuskaitymo nefiksuotos kaupiamosios suminės, dienos, mėnesio energijų tikslumas', 0, NULL, 1, 0, NULL),
	(411, 3, NULL, 'MeterPassword', 'Slaptažodis, naudojamas tik parametrų įrašymui (datą ir laiką, impulsų koeficientus, valdyti reles) į skaitiklį', 0, NULL, 1, 1, NULL),
	(412, 3, 82, 'UseRetranslation', 'Naudoti retransliavimą', 0, NULL, 1, 0, NULL),
	(413, 3, NULL, 'Retranslator1', 'Retransliatorius numeris 1', 0, NULL, 1, 0, NULL),
	(414, 3, NULL, 'Retranslator2', 'Retransliatorius numeris 2', 0, NULL, 1, 0, NULL),
	(415, 3, NULL, 'Retranslator3', 'Retransliatorius numeris 3', 0, NULL, 1, 0, NULL),
	(416, 3, NULL, 'Retranslator4', 'Retransliatorius numeris 4', 0, NULL, 1, 0, NULL),
	(417, 3, NULL, 'Con_B_Opt', 'Con_B_Opt', 1, NULL, 1, 0, NULL),
	(418, 3, NULL, 'MeterNumber', 'Skaitiklio adresas PLC tinkle', 0, NULL, 1, 0, NULL),
	(419, 3, NULL, 'EscCRCMode', 'Esc/CRC protokolo palaikymas', 0, NULL, 1, 0, NULL),
	(420, 5, NULL, 'GroupNr', 'Grupės numeris', 0, NULL, 1, 0, NULL),
	(421, 5, NULL, 'Channel', 'Kanalo numeris', 0, NULL, 1, 0, NULL),
	(422, 5, NULL, 'GroupNr', 'Grupės numeris', 0, NULL, 1, 0, NULL),
	(423, 5, NULL, 'Imp', 'Impulsų kiekio išdavimas', 0, NULL, 1, 0, NULL),
	(424, 3, NULL, 'RetDevTime', 'Prietaiso laiko grąžinimas', 0, NULL, 1, 0, NULL),
	(425, 5, NULL, 'IndexTariff', 'Tarifo indeksas', 0, NULL, 1, 0, NULL),
	(426, 5, NULL, 'DataType', 'Registro duomenų tipas', 0, NULL, 1, 0, NULL),
	(427, 3, NULL, 'Password', 'Trečio lygmens slaptažodis', 0, NULL, 1, 1, NULL),
	(428, 3, NULL, 'Password2', 'Ketvirto lygmens slaptažodis', 0, NULL, 1, 1, NULL),
	(429, 3, NULL, 'PLCTimeRWMethod', 'Prietaiso laiko nuskaitymo metodas', 0, NULL, 1, 0, NULL),
	(430, 3, NULL, 'DeviceAlarm_GUID', 'Priimti apdorojimui iš prietaiso gaunamus aliarmus', 0, NULL, 1, 0, NULL),
	(431, 5, NULL, 'ObisCode', 'Duomenų identifikatorius (OBIS kodas) įrašymui', 0, NULL, 0, 0, NULL),
	(432, 3, NULL, 'Multiplier', 'Daugiklis visiems rodmenims, išskyrus momentinius', 0, NULL, 0, 0, NULL),
	(433, 3, NULL, 'Address_Energomera', 'Tarpinio įrenginio adresas', 0, NULL, 1, 0, NULL),
	(434, 3, NULL, 'User_Energomera', 'Tarpinio įrenginio vartotojo vardas', 0, NULL, 1, 0, NULL),
	(435, 3, NULL, 'Password_Energomera', 'Tarpinio įrenginio vartotojo slaptažodis', 0, NULL, 1, 1, NULL),
	(436, 3, NULL, 'CloseSessionTimeOut_Energomera', 'Tarpinio įrenginio sesijos time-out', 0, NULL, 1, 0, NULL),
	(437, 5, NULL, 'Index', 'Indeksas įrašymui', 0, NULL, 0, 0, NULL),
	(438, 5, NULL, 'ValueID', 'ValueID', 0, NULL, 1, 0, NULL),
	(439, 5, NULL, 'GroupID', 'GroupID', 0, NULL, 1, 0, NULL),
	(440, 5, NULL, 'Config', 'Config', 0, NULL, 1, 0, NULL),
	(441, 5, NULL, 'Password', 'Elemento prisijungimo slaptažodis', 0, NULL, 1, 1, NULL),
	(442, 3, NULL, 'DecoderGUID', 'Dekoderis - COM serveris', 0, NULL, 1, 0, NULL),
	(443, 3, NULL, 'CheckSumEndianness', 'Kontrolinės sumos baitų tvarka', 0, NULL, 1, 0, NULL),
	(444, 5, NULL, 'ValueBytes', 'Kiek baitų užima reikšmė', 0, NULL, 1, 0, NULL),
	(445, 5, NULL, 'MBDataType', 'Modbus duomenų tipas', 0, NULL, 1, 0, NULL),
	(446, 5, NULL, 'Endianness', 'Baitų tvarka', 0, NULL, 1, 0, NULL),
	(447, 5, NULL, 'StatusBytes', 'Statusui skirtų baitų kiekis', 0, NULL, 1, 0, NULL),
	(448, 5, NULL, 'StatusOffs', 'Poslinkis atmintyje, kokiu laikomas matavimo statusas', 0, NULL, 1, 0, NULL),
	(449, 4, NULL, 't0', 'Connection establishment timeout, s', 0, NULL, 0, 0, NULL),
	(450, 4, NULL, 't1', 'Response timeout, s', 0, NULL, 0, 0, NULL),
	(451, 4, NULL, 't2', 'Acknowledgement timeout, s', 0, NULL, 0, 0, NULL),
	(452, 4, NULL, 't3', 'Test frame interval, s', 0, NULL, 0, 0, NULL),
	(453, 4, NULL, 'k', 'Window k', 0, NULL, 0, 0, NULL),
	(454, 4, NULL, 'w', 'Window w', 0, NULL, 0, 0, NULL),
	(455, 3, NULL, 'COT_Size', 'Cause of transmission size in bytes', 0, NULL, 0, 0, NULL),
	(456, 3, NULL, 'ASDU_Size', 'Common ASDU address size in bytes', 0, NULL, 0, 0, NULL),
	(457, 3, NULL, 'IOA_Size', 'Information object address size in bytes', 0, NULL, 0, 0, NULL),
	(458, 3, NULL, 'AsduAddr', 'Common ASDU address', 0, NULL, 1, 0, NULL),
	(459, 3, NULL, 'Originator', 'Originator address', 0, NULL, 0, 0, NULL),
	(460, 3, NULL, 'Interrogation', 'Interrogation period in seconds', 0, NULL, 0, 0, NULL),
	(461, 1, 889, 'COT_Size', 'Cause of transmission size in bytes', 0, '2', 0, 0, NULL),
	(462, 1, 889, 'ASDU_Size', 'Common ASDU address size in bytes', 0, '2', 0, 0, NULL),
	(463, 1, 890, 'IOA_Size', 'Information object address size in bytes', 0, '3', 0, 0, NULL),
	(464, 5, NULL, 'ASDU', 'Application Service Data Unit', 0, NULL, 1, 0, NULL),
	(465, 5, NULL, 'IOA', 'Information object address', 0, NULL, 1, 0, NULL),
	(466, 5, NULL, 'DeadBand', 'Nejautrumo riba', 0, NULL, 0, 0, NULL),
	(467, 3, NULL, 'AddressingType', 'Loginių Modbus adresų naudojimas', 0, NULL, 1, 0, NULL),
	(468, 3, NULL, 'HasCalibration', 'HasCalibration', 0, NULL, 1, 0, NULL),
	(469, 3, NULL, 'EvenOrOddCalibration', 'EvenOrOddCalibration', 0, NULL, 1, 0, NULL),
	(470, 3, NULL, 'TranspMsgReceiveTimeout', 'Skaidraus režimo laukimo taimautas', 0, NULL, 1, 0, NULL),
	(471, 3, NULL, 'MainStationAddress', 'Pagrindinės stoties adresas', 0, NULL, 1, 0, NULL),
	(472, 5, NULL, 'MainStationAddress', 'Pagrindinės stoties adresas', 0, NULL, 1, 0, NULL),
	(473, 3, NULL, 'DaylightStartHour', 'Perėjimo į žiemos laiką valanda', 0, NULL, 1, 0, NULL),
	(474, 5, NULL, 'ShortNameForCurrent', 'Einamosios reikšmės objekto trumpasis adresas', 0, NULL, 1, 0, NULL),
	(475, 5, NULL, 'ClassIDForCurrent', 'Einamosios reikšmės duomenų tipo (klasės) identifikatorius', 0, NULL, 1, 0, NULL),
	(476, 3, NULL, 'MeterConstant', 'Skaitiklio konstanta', 0, NULL, 1, 0, NULL),
	(477, 3, NULL, 'SecurityLevel', 'Saugumo lygmuo', 0, NULL, 1, 0, NULL),
	(478, 4, 82, 'SendLinkTest', 'LinkTest paketo siuntimas prieš pirmąją užklausą', 0, NULL, 1, 0, NULL),
	(479, 3, NULL, 'SendDelay', 'Uždelsimas prieš siunčiant sekantį užklausimą, ms', 0, NULL, 1, 0, NULL),
	(480, 5, NULL, 'FirmwareEventLog', 'Vidinės programinės įrangos įvykių žurnalas', 0, NULL, 1, 0, NULL),
	(481, 5, NULL, 'FailureEventLog', 'Dingimų įvykių žurnalas', 0, NULL, 1, 0, NULL),
	(482, 5, NULL, 'DemandEventLog', 'Galios įvykių žurnalas', 0, NULL, 1, 0, NULL),
	(483, 5, NULL, 'CommonEventLog', 'Įeinančių parametrų įvykių žurnalas', 0, NULL, 1, 0, NULL),
	(484, 5, NULL, 'ClockSyncEventLog', 'Laikrodžio sinchronizavimo įvykių žurnalas', 0, NULL, 1, 0, NULL),
	(485, 5, NULL, 'QualityEventLog', 'Kokybės įvykių žurnalas', 0, NULL, 1, 0, NULL),
	(486, 3, NULL, 'MeterNumber', 'Skaitiklių numeriai', 0, NULL, 1, 0, NULL),
	(487, 3, NULL, 'DestinationID', 'Gavėjo ID', 0, NULL, 1, 0, NULL),
	(488, 3, NULL, 'SourceID', 'Siuntėjo ID', 0, NULL, 1, 0, NULL),
	(489, 5, NULL, 'MeterNumber', 'Skaitiklių numeriai', 0, NULL, 1, 0, NULL),
	(490, 5, NULL, 'WithTime', 'Laiko žymės naudojimas', 0, NULL, 1, 0, NULL),
	(491, 5, NULL, 'ObisCode', 'Duomenų identifikatorius', 0, NULL, 1, 0, NULL),
	(492, 3, NULL, 'Password', 'Pirmo lygmens slaptažodis', 0, NULL, 1, 1, NULL),
	(493, 3, NULL, 'Password2', 'Antro lygmens slaptažodis', 0, NULL, 1, 0, NULL),
	(494, 3, NULL, 'Password3', 'Trečio lygmens slaptažodis', 0, NULL, 1, 0, NULL),
	(495, 3, NULL, 'ReadStatus', 'Papildomai nuskaityti duomenų statusus', 0, NULL, 1, 0, NULL),
	(496, 3, NULL, 'ProxyAddress', 'Tarpinio serverio adresas ir portas', 0, NULL, 1, 0, NULL),
	(497, 5, NULL, 'StatusRule', 'Duomenų statuso dekodavimo taisyklė', 0, NULL, 1, 0, NULL),
	(498, 3, 82, 'CheckChannel', 'Tikrinti, ar nuskaitomi iš laisvai programuojamų kanalų matavimai atitinka skaitiklio kanalų konfigūraciją', 0, '0', 1, 0, NULL),
	(499, 3, 934, 'Controller', 'Prietaiso tipas (kontroleris ar skaitiklis)', 0, '0', 1, 0, NULL),
	(500, 3, 82, 'IgnoreFrameError', 'Ignoruoti Frame Error portui', 0, NULL, 0, 0, NULL),
	(501, 3, NULL, 'ClockAddress', 'Pirmas laikrodžio registras (metų registras)', 0, NULL, 1, 0, NULL),
	(502, 3, 949, 'Function', 'Nuskaitymo funkcija', 0, NULL, 1, 0, NULL),
	(503, 4, 957, 'DType', 'Duomenų gražinimo režimas', 0, NULL, 1, 0, NULL),
	(504, 3, NULL, 'MinOrMoreMetersInRequest', 'Minimalus skaitiklių kiekis per vieną užklausimą', 0, NULL, 1, 0, NULL),
	(505, 4, NULL, 'Compress', 'Duomenų suspaudimas', 0, NULL, 1, 0, NULL),
	(506, 4, NULL, 'UdpHeader', 'Paketo priekyje pridėti 32 nulius (UDP header)', 0, NULL, 1, 0, NULL),
	(507, 3, NULL, 'Version376_2', 'Data frame 376.2 versijos palaikymas', 0, NULL, 1, 0, NULL),
	(508, 5, NULL, 'ObjectID', 'Objekto identifikatorius', 0, NULL, 1, 0, NULL),
	(509, 3, NULL, 'Address1_MIT_5000_MG', 'Adresas 1. Administrative division code A1', 0, NULL, 1, 0, NULL),
	(510, 3, NULL, 'Address2_MIT_5000_MG', 'Adresas 2. Terminal Address A2', 0, NULL, 1, 0, NULL),
	(511, 3, NULL, 'Address3_MIT_5000_MG', 'Adresas 3. Master station address', 0, NULL, 1, 0, NULL),
	(512, 3, 967, 'UseGroupAddress_MIT_5000_MG', 'Group address mark A2', 0, '0', 1, 0, NULL),
	(513, 3, 968, 'Port_MIT_5000_MG', 'porto numeris, per kurį užtikrintas kontrolerio ryšis su skaitikliu', 0, '1', 1, 0, NULL),
	(514, 3, 969, 'BaudRate_MIT_5000_MG', 'Ryšio su skaitikliu greitis per MIT 5000 MG', 0, '2400', 1, 0, NULL),
	(515, 3, 970, 'StopBits_MIT_5000_MG', 'Stop bitai ryšiui su skaitikliu', 0, '1', 1, 0, NULL),
	(516, 3, 971, 'HasCalibration_MIT_5000_MG', 'Žymė ryšiui su skaitikliu', 0, '1', 1, 0, NULL),
	(517, 3, 972, 'EvenOrOddCalibration_MIT_5000_MG', 'Lygiškumas ryšiui su skaitikliu', 0, '0', 1, 0, NULL),
	(518, 3, 973, 'DataBits_MIT_5000_MG', 'Duomenų bitai ryšui su skaitikliu', 0, '8', 1, 0, NULL),
	(519, 3, NULL, 'TimeOutMSec_MIT_5000_MG', 'Uždėlsimo laikas', 0, '60000', 1, 0, NULL),
	(520, 3, NULL, 'ByteTimeOut_MIT_5000_MG', 'Vieno baito uždelsimo laikas', 0, '100', 1, 0, NULL),
	(521, 3, NULL, 'Endianness', 'Float skaičiaus baitų išdėstymo seka šaltiniui', 0, NULL, 1, 0, NULL),
	(522, 5, NULL, 'Function', 'Parametro kodas', 0, NULL, 1, 0, NULL),
	(523, 5, NULL, 'WithCurrentValue', 'WithCurrentValue', 0, NULL, 1, 0, NULL),
	(524, 5, NULL, 'ML', 'ML', 0, NULL, 1, 0, NULL),
	(525, 5, NULL, 'Data_Code_61968', 'Data_Code_61968', 0, NULL, 1, 0, NULL),
	(526, 3, NULL, 'Address1', 'Adresas 1. Administrative division code A1', 0, NULL, 1, 0, NULL),
	(527, 3, NULL, 'Address2', 'Adresas 2. Terminal Address A2', 0, NULL, 1, 0, NULL),
	(528, 3, NULL, 'Address3', 'Adresas 3. Master station address', 0, NULL, 1, 0, NULL),
	(529, 3, NULL, 'UseGroupAddress', 'Ryšiui per MIT 5000 MG. Group address mark A2', 0, NULL, 1, 0, NULL),
	(530, 5, NULL, 'Terminal', 'Ryšiui per skaitiklį ar terminalą', 0, NULL, 1, 0, NULL),
	(531, 3, NULL, 'ProtocolVer', 'Protokolo versija', 0, NULL, 1, 0, NULL),
	(532, 3, 82, 'CheckDeviceNumber', 'Tikrinti gamyklinį prietaiso numerį', 0, '1', 1, 0, NULL),
	(533, 5, NULL, 'SensorChannel', 'Jutiklio kanalas', 0, NULL, 1, 0, NULL),
	(534, 5, NULL, 'Channel', 'Korektoriaus numeris', 0, NULL, 1, 0, NULL),
	(535, 5, NULL, 'Round', 'Ženklų skaičius po kablelio, duomenų apvalinimui', 0, NULL, 1, 0, NULL);
/*!40000 ALTER TABLE `lpty` ENABLE KEYS */;

-- Dumping structure for table emcor.lpty_type
CREATE TABLE IF NOT EXISTS `lpty_type` (
  `lpty_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybių tipo identifikatorius',
  `lpty_type_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Ryšio modulių savybių tipo kodas',
  `lpty_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ryšio modulių savybių tipo pavadinimas',
  PRIMARY KEY (`lpty_type_id`),
  UNIQUE KEY `lpty_type_code_u` (`lpty_type_code`),
  UNIQUE KEY `lpty_type_name_u` (`lpty_type_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ryšio modulių savybių tipai';

-- Dumping data for table emcor.lpty_type: ~5 rows (approximately)
/*!40000 ALTER TABLE `lpty_type` DISABLE KEYS */;
INSERT INTO `lpty_type` (`lpty_type_id`, `lpty_type_code`, `lpty_type_name`) VALUES
	(1, 'DP_LPTY', 'Data point properties'),
	(2, 'PH_LPTY', 'Path properties'),
	(3, 'SRC_LPTY', 'Source properties'),
	(4, 'SP_LPTY', 'Source path properties'),
	(5, 'SE_LPTY', 'Source element properties');
/*!40000 ALTER TABLE `lpty_type` ENABLE KEYS */;

-- Dumping structure for table emcor.lp_data
CREATE TABLE IF NOT EXISTS `lp_data` (
  `lp_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio prioritetų profilio identifikatorius',
  `lp_priority` smallint(5) unsigned NOT NULL COMMENT 'Ryšio prioritetas',
  `dp_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taškų tipo identifikatorius',
  `ph_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius',
  `dl_type_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų išdėstymo tipo identifikatorius',
  PRIMARY KEY (`lp_id`,`lp_priority`),
  UNIQUE KEY `lp_data_ak` (`dl_type_id`,`dp_type_id`,`ph_type_id`,`lp_id`),
  KEY `lp_data_dp_type_i` (`dp_type_id`),
  KEY `lp_data_ph_type_i` (`ph_type_id`),
  CONSTRAINT `lp_data_dl_type_fk` FOREIGN KEY (`dl_type_id`) REFERENCES `dl_type` (`dl_type_id`),
  CONSTRAINT `lp_data_dp_type_fk` FOREIGN KEY (`dp_type_id`) REFERENCES `dp_type` (`dp_type_id`),
  CONSTRAINT `lp_data_lp_fk` FOREIGN KEY (`lp_id`) REFERENCES `lp` (`lp_id`) ON DELETE CASCADE,
  CONSTRAINT `lp_data_ph_type_fk` FOREIGN KEY (`ph_type_id`) REFERENCES `ph_type` (`ph_type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Ryšio prioritetų profilių duomenys';

-- Dumping data for table emcor.lp_data: ~6 rows (approximately)
/*!40000 ALTER TABLE `lp_data` DISABLE KEYS */;
INSERT INTO `lp_data` (`lp_id`, `lp_priority`, `dp_type_id`, `ph_type_id`, `dl_type_id`) VALUES
	(1, 9, 1, 1, 1),
	(1, 1, 1, 3, 1),
	(1, 4, 1, 7, 1),
	(1, 6, 1, 11, 1),
	(1, 3, 1, 1, 2),
	(1, 2, 1, 3, 2);
/*!40000 ALTER TABLE `lp_data` ENABLE KEYS */;

-- Dumping structure for table emcor.ltc
CREATE TABLE IF NOT EXISTS `ltc` (
  `ltc_id` tinyint(3) unsigned NOT NULL COMMENT 'Tiesinės transformacijos koeficiento ID',
  `ltc_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Tiesinės transformacijos koeficiento kodas',
  `ltc_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Tiesinės transformacijos koeficiento pavadinimas',
  `ltc_default` tinyint(3) unsigned NOT NULL COMMENT 'Tiesinės transformacijos koeficiento reikšmė pagal nutylėjimą',
  PRIMARY KEY (`ltc_id`),
  UNIQUE KEY `ltc_code_u` (`ltc_code`),
  UNIQUE KEY `ltc_name_u` (`ltc_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Tiesinės transformacijos koeficientai';

-- Dumping data for table emcor.ltc: ~3 rows (approximately)
/*!40000 ALTER TABLE `ltc` DISABLE KEYS */;
INSERT INTO `ltc` (`ltc_id`, `ltc_code`, `ltc_name`, `ltc_default`) VALUES
	(1, 'A_NOM', 'Daugiklio skaitiklis', 1),
	(2, 'A_DENOM', 'Daugiklio vardiklis', 1),
	(3, 'B', 'Dėmuo', 0);
/*!40000 ALTER TABLE `ltc` ENABLE KEYS */;

-- Dumping structure for table emcor.ltl
CREATE TABLE IF NOT EXISTS `ltl` (
  `req_type_code` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Užklausų tipo kodas',
  `rodo_id` int(10) unsigned NOT NULL COMMENT 'Užsakymo ID',
  `sch_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Tvarkaraščio identifikatorius',
  `sch_time` datetime DEFAULT NULL COMMENT 'Tvarkaraščio suveikimo laikas',
  `schi_nr` smallint(5) unsigned DEFAULT NULL COMMENT 'Paprasto tvarkaraščio numeris',
  PRIMARY KEY (`rodo_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ryšio užduočių eilė';

-- Dumping data for table emcor.ltl: ~0 rows (approximately)
/*!40000 ALTER TABLE `ltl` DISABLE KEYS */;
/*!40000 ALTER TABLE `ltl` ENABLE KEYS */;

-- Dumping structure for table emcor.ltl_das
CREATE TABLE IF NOT EXISTS `ltl_das` (
  `rodo_id` int(10) unsigned NOT NULL COMMENT 'Užsakymo ID',
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  `db_time` datetime DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  PRIMARY KEY (`rodo_id`,`das_id`),
  KEY `ltl_das_das_fk` (`das_id`),
  CONSTRAINT `ltl_das_das_fk` FOREIGN KEY (`das_id`) REFERENCES `das` (`das_id`) ON DELETE CASCADE,
  CONSTRAINT `ltl_das_ltl_fk` FOREIGN KEY (`rodo_id`) REFERENCES `ltl` (`rodo_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų surinkimo serverių nuskaitytos ryšio užduočių eilės užduotys';

-- Dumping data for table emcor.ltl_das: ~0 rows (approximately)
/*!40000 ALTER TABLE `ltl_das` DISABLE KEYS */;
/*!40000 ALTER TABLE `ltl_das` ENABLE KEYS */;

-- Dumping structure for table emcor.ma
CREATE TABLE IF NOT EXISTS `ma` (
  `ma_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Monitoringo priskyrimo identifikatorius',
  `verge_id` smallint(5) unsigned NOT NULL COMMENT 'Kraštinės ID',
  `ma_ab` tinyint(1) NOT NULL COMMENT 'Požymis, ar naudoti tiesinę transformaciją išeities rodiklio reikšmei',
  `ma_a_nom` float DEFAULT NULL COMMENT 'Tiesinės transformacijos daugiklio skaitiklis',
  `ma_a_denom` float DEFAULT NULL COMMENT 'Tiesinės transformacijos daugiklio vardiklis',
  `ma_b` double DEFAULT NULL COMMENT 'Tiesinės transformacijos dėmuo',
  `ma_enabled` tinyint(1) NOT NULL COMMENT 'Monitoringo priskyrimo naudojimo požymis',
  `ma_show` tinyint(1) NOT NULL COMMENT 'Priskirtos kraštinės atvaizdavimo požymis',
  `ma_auto_check` tinyint(1) NOT NULL COMMENT 'Požymis, ar automatiškai tikrinti rodiklių atitikimą nurodytuose perioduose',
  `ma_report_exceeding` tinyint(1) DEFAULT NULL COMMENT 'Požymis, ar tikrinama dėl viršijimo (ar dėl nusileidimo)',
  `ma_lag` mediumint(8) unsigned DEFAULT NULL COMMENT 'Monitoringo priskyrimo poslinkis laike',
  `ma_lag_per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Monitoringo priskyrimo poslinkio periodo identifikatorius',
  `ma_auto_null_act` tinyint(3) unsigned NOT NULL DEFAULT 0 COMMENT 'Požymis, ar automatiškai priskirti nulinį aktą neatitikimo atveju',
  `ma_auto_ccs` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Požymis, ar automatiškai priskirti nekomercinių duomenų statusą neatitikimo atveju',
  PRIMARY KEY (`ma_id`),
  KEY `ma_verge_i` (`verge_id`),
  KEY `ma_lag_per_fk` (`ma_lag_per_id`),
  CONSTRAINT `ma_lag_per_fk` FOREIGN KEY (`ma_lag_per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `ma_verge_fk` FOREIGN KEY (`verge_id`) REFERENCES `verge` (`verge_id`) ON DELETE CASCADE,
  CONSTRAINT `MA_LAG_PER_ID_NOT_NULL_CHK` CHECK (`ma_lag` is null or `ma_lag_per_id` is not null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Monitoringo priskyrimai';

-- Dumping data for table emcor.ma: ~0 rows (approximately)
/*!40000 ALTER TABLE `ma` DISABLE KEYS */;
/*!40000 ALTER TABLE `ma` ENABLE KEYS */;

-- Dumping structure for table emcor.map
CREATE TABLE IF NOT EXISTS `map` (
  `map_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Monitoringo priskyrimo automatinio tikrinimo periodo ID',
  `ma_id` int(10) unsigned NOT NULL COMMENT 'Monitoringo priskyrimo identifikatorius',
  `bt` datetime NOT NULL COMMENT 'Periodo pradžia',
  `et` datetime DEFAULT NULL COMMENT 'Periodo pabaiga',
  `map_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Monitoringo priskyrimo automatinio tikrinimo periodui požymis',
  PRIMARY KEY (`map_id`),
  UNIQUE KEY `map_ma_u` (`ma_id`,`bt`),
  CONSTRAINT `map_ma_fk` FOREIGN KEY (`ma_id`) REFERENCES `ma` (`ma_id`) ON DELETE CASCADE,
  CONSTRAINT `MAP_INVALID_PERIOD_CHK` CHECK (`bt` is null or `et` is null or `bt` < `et`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Monitoringo priskyrimų automatinio tikrinimo periodai';

-- Dumping data for table emcor.map: ~0 rows (approximately)
/*!40000 ALTER TABLE `map` DISABLE KEYS */;
/*!40000 ALTER TABLE `map` ENABLE KEYS */;

-- Dumping structure for table emcor.map_data
CREATE TABLE IF NOT EXISTS `map_data` (
  `map_id` int(10) unsigned NOT NULL COMMENT 'Monitoringo priskyrimo automatinio tikrinimo periodo ID',
  `mt_time` datetime NOT NULL COMMENT 'Tikrintas rodiklių duomenų laikas',
  `mt_success` tinyint(1) NOT NULL COMMENT 'Rodiklių atitikimo požymis',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `target_val` double DEFAULT NULL COMMENT 'Paskirties rodiklio reikšmė sulyginimo metu',
  `source_val` double DEFAULT NULL COMMENT 'Palyginamojo agregavimo segmento rodiklio reikšmė',
  `tstatus` tinyint(3) unsigned DEFAULT NULL COMMENT 'Rodiklio neatitikimo statusas',
  PRIMARY KEY (`map_id`,`mt_time`),
  KEY `map_data_db_time_i` (`db_time`),
  KEY `map_data_mt_success_i` (`mt_success`,`mt_time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Monitoringo priskyrimų automatinio tikrinimo rezultatai'
 PARTITION BY RANGE (
    to_days(mt_time))
(PARTITION par_201708 VALUES LESS THAN (736751) ENGINE = InnoDB,
 PARTITION par_201709 VALUES LESS THAN (736758) ENGINE = InnoDB,
 PARTITION par_201710 VALUES LESS THAN (736765) ENGINE = InnoDB);

-- Dumping data for table emcor.map_data: ~3 rows (approximately)
/*!40000 ALTER TABLE `map_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `map_data` ENABLE KEYS */;

-- Dumping structure for table emcor.map_h
CREATE TABLE IF NOT EXISTS `map_h` (
  `map_id` int(10) unsigned NOT NULL COMMENT 'Monitoringo priskyrimo automatinio tikrinimo periodo ID',
  `map_h_bound` datetime NOT NULL COMMENT 'Monitoringo priskyrimo automatinio tikrinimo periodo laiko žymė, nurodanti tikrinti tik vėlesnes rodiklių reikšmes',
  PRIMARY KEY (`map_id`),
  CONSTRAINT `map_h_map_fk` FOREIGN KEY (`map_id`) REFERENCES `map` (`map_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Monitoringo priskyrimų automatinio tikrinimo periodų žymės';

-- Dumping data for table emcor.map_h: ~0 rows (approximately)
/*!40000 ALTER TABLE `map_h` DISABLE KEYS */;
/*!40000 ALTER TABLE `map_h` ENABLE KEYS */;

-- Dumping structure for table emcor.mcc
CREATE TABLE IF NOT EXISTS `mcc` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `mcc_t` datetime NOT NULL COMMENT 'Matavimo taške sumontuoto matavimo prietaiso konfigūracijos pakeitimo laikas',
  `md_cnt` mediumint(8) unsigned DEFAULT NULL COMMENT 'Nurodyto diskretiškumo intervalų kiekis paroje',
  `coef_u_numerator` double DEFAULT NULL COMMENT 'Įtampos transformacijos koeficiento skaitiklis',
  `coef_u_denominator` double DEFAULT NULL COMMENT 'Įtampos transformacijos koeficiento vardiklis',
  `coef_i_numerator` double DEFAULT NULL COMMENT 'Srovės transformacijos koeficiento skaitiklis',
  `coef_i_denominator` double DEFAULT NULL COMMENT 'Srovės transformacijos koeficiento vardiklis',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Matavimo taške sumontuoto matavimo prietaiso konfiguracijos pakeitimo įrašymo data',
  `pl_dl` tinyint(1) DEFAULT NULL COMMENT 'Rodmenų numetimo požymis',
  PRIMARY KEY (`point_id`,`mcc_t`),
  CONSTRAINT `mcc_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškuose sumontuotų matavimo prietaisų konfigūracijos pakeitimai';

-- Dumping data for table emcor.mcc: ~0 rows (approximately)
/*!40000 ALTER TABLE `mcc` DISABLE KEYS */;
/*!40000 ALTER TABLE `mcc` ENABLE KEYS */;

-- Dumping structure for table emcor.md
CREATE TABLE IF NOT EXISTS `md` (
  `md_id` smallint(5) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Matavimo diskretiškumo identifikatorius',
  `per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Periodo identifikatorius',
  `md_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Matavimų diskretiškumo kodas',
  `md_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Matavimų diskretiškumo pavadinimas',
  `md_int_value` mediumint(8) unsigned DEFAULT NULL COMMENT 'Diskretiškumo intervalo reikšmė',
  `aggs_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  `md_cnt` mediumint(8) unsigned DEFAULT NULL COMMENT 'Nurodyto diskretiškumo intervalų kiekis paroje',
  PRIMARY KEY (`md_id`),
  UNIQUE KEY `md_code_u` (`md_code`),
  UNIQUE KEY `md_name_u` (`md_name`),
  KEY `md_aggs_type_i` (`aggs_type_id`),
  KEY `md_per_i` (`per_id`),
  CONSTRAINT `md_aggs_type_fk` FOREIGN KEY (`aggs_type_id`) REFERENCES `aggs_type` (`aggs_type_id`),
  CONSTRAINT `md_per_fk` FOREIGN KEY (`per_id`) REFERENCES `per` (`per_id`)
) ENGINE=InnoDB AUTO_INCREMENT=20 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimų diskretiškumas';

-- Dumping data for table emcor.md: ~19 rows (approximately)
/*!40000 ALTER TABLE `md` DISABLE KEYS */;
INSERT INTO `md` (`md_id`, `per_id`, `md_code`, `md_name`, `md_int_value`, `aggs_type_id`, `md_cnt`) VALUES
	(1, 2, '1_MIN', 'Minutiniai', 1, 1, 1440),
	(2, 2, '2_MIN', '2 minučių', 2, 1, 720),
	(3, 2, '30_MIN', 'Pusvalandiniai', 30, 2, 48),
	(4, 3, 'HOUR', 'Valandiniai', 1, 2, 24),
	(5, 4, 'DAY', 'Paros', 1, 3, 1),
	(6, 5, 'MONTH', 'Mėnesiniai', 1, 4, 1),
	(7, NULL, 'INSTANT', 'Momentiniai', NULL, 6, NULL),
	(8, 2, '3_MIN', '3 minučių', 3, 1, 480),
	(9, 2, '4_MIN', '4 minučių', 4, 1, 360),
	(10, 2, '5_MIN', '5 minučių', 5, 1, 288),
	(11, 2, '10_MIN', '10 minučių', 10, 1, 144),
	(12, 2, '15_MIN', '15 minučių', 15, 2, 96),
	(13, 2, '20_MIN', '20 minučių', 20, 2, 72),
	(14, 1, '3_SEC', '3 sekundžių', 3, 7, 28800),
	(15, 1, '5_SEC', '5 sekundžių', 5, 7, 17280),
	(16, 1, '10_SEC', '10 sekundžių', 10, 7, 8640),
	(17, 1, '15_SEC', '15 sekundžių', 15, 7, 5760),
	(18, 1, '20_SEC', '20 sekundžių', 20, 7, 4320),
	(19, 1, '30_SEC', '30 sekundžių', 30, 7, 2880);
/*!40000 ALTER TABLE `md` ENABLE KEYS */;

-- Dumping structure for table emcor.mdl
CREATE TABLE IF NOT EXISTS `mdl` (
  `mdl_id` smallint(5) unsigned NOT NULL COMMENT 'Modulio identifikatorius',
  `mdl_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Modulio kodas',
  `mdl_name` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Modulio pavadinimas',
  `mdl_guid` varchar(50) COLLATE utf8_bin DEFAULT NULL COMMENT 'Modulio GUID',
  `mdl_ip` varchar(30) COLLATE utf8_bin DEFAULT NULL COMMENT 'Modulio alerto IP adresas',
  `mdl_port` varchar(10) COLLATE utf8_bin DEFAULT NULL COMMENT 'Modulio alerto IP portas',
  PRIMARY KEY (`mdl_id`),
  UNIQUE KEY `mdl_guid_u` (`mdl_guid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Sistemos moduliai';

-- Dumping data for table emcor.mdl: ~28 rows (approximately)
/*!40000 ALTER TABLE `mdl` DISABLE KEYS */;
INSERT INTO `mdl` (`mdl_id`, `mdl_code`, `mdl_name`, `mdl_guid`, `mdl_ip`, `mdl_port`) VALUES
	(1, 'STLine', 'STLine', '{CAE7F91E-F842-4B96-B4F5-DE0C57A18724}', '127.0.0.1', '6788'),
	(3, 'ORACLE', 'ORACLE', NULL, NULL, NULL),
	(4, 'STGate', 'STGate', '{A4A10EEF-0FAA-4E7E-8FA7-4ADE3A43C020}', NULL, NULL),
	(5, 'STStore', 'STStore', NULL, NULL, NULL),
	(6, 'STXMLDB', 'STXMLDB', NULL, NULL, NULL),
	(7, 'STAlert', 'STAlert', '{21584A6D-778A-482B-A23E-F235AFC5ED9A}', NULL, NULL),
	(8, 'STLink', 'STLink', NULL, NULL, NULL),
	(9, 'STDataSnapServer', 'STDataSnapServer', NULL, NULL, NULL),
	(10, 'STLink.Transport', 'STLink.Transport', NULL, NULL, NULL),
	(11, 'STLink.Driver', 'STLink.Driver', NULL, NULL, NULL),
	(12, 'STLink.Manager', 'STLink.Manager', NULL, NULL, NULL),
	(13, 'STDriver', 'STDriver', NULL, NULL, NULL),
	(14, 'STSCADA', 'STSCADA', NULL, NULL, NULL),
	(15, 'STDistributor', 'STDistributor', NULL, NULL, NULL),
	(16, 'STReportManager', 'STReportManager', '{1E3098E2-EDD5-4E88-987B-1493DB26C86F}', NULL, NULL),
	(17, 'STWS', 'STExport WEB service', '{D6B05BDF-EAE7-4C06-9939-CB9D45088E38}', NULL, NULL),
	(18, 'STImport_21', 'STImport_21', NULL, NULL, NULL),
	(19, 'STFolderMonitor', 'STFolderMonitor', NULL, NULL, NULL),
	(20, 'STDataInput', 'STDataInput', '{3EC307C1-9060-4A59-B7EE-B6F4C9EADAB1}', NULL, NULL),
	(21, 'STIPListener', 'STIPListener', NULL, NULL, NULL),
	(22, 'STPowerRecomm', 'STPowerRecomm', '{0D05725B-2516-4EFD-9DBB-5ED64BFD658A}', NULL, NULL),
	(23, 'STXMLDB_SCADA', 'STXMLDB_SCADA', NULL, NULL, NULL),
	(24, 'ST61968System', 'ST61968System', NULL, NULL, NULL),
	(25, 'STWSDLMSEvents', 'STWSDLMSEvents', NULL, NULL, NULL),
	(26, 'STTicketManager', 'STTicketManager', '{E7882104-3719-4929-82B5-343187727507}', NULL, NULL),
	(27, 'STDataSnapService', 'STDataSnapService', NULL, NULL, NULL),
	(28, 'STTicket', 'STTicket', NULL, NULL, NULL),
	(34, 'STIEC_60870_5_10x_DCA', 'STIEC_60870_5_10x_DCA', '{90CFFA0A-1B16-4ED8-AE17-58738FB98809}', NULL, NULL);
/*!40000 ALTER TABLE `mdl` ENABLE KEYS */;

-- Dumping structure for table emcor.mdl_alert
CREATE TABLE IF NOT EXISTS `mdl_alert` (
  `mdl_id` smallint(5) unsigned NOT NULL COMMENT 'Modulio identifikatorius',
  `alertname` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Alert vardas',
  `mdl_alert_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Alert naudojimo požymis',
  `from_db` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar alert yra iš DB',
  `to_betweenmsec` mediumint(8) unsigned DEFAULT NULL,
  `to_overallsec` mediumint(8) unsigned DEFAULT NULL,
  `grouped` tinyint(1) DEFAULT NULL,
  PRIMARY KEY (`mdl_id`,`alertname`),
  CONSTRAINT `mdl_alert_mdl_fk` FOREIGN KEY (`mdl_id`) REFERENCES `mdl` (`mdl_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Modulių informavimo konfigūracija';

-- Dumping data for table emcor.mdl_alert: ~32 rows (approximately)
/*!40000 ALTER TABLE `mdl_alert` DISABLE KEYS */;
INSERT INTO `mdl_alert` (`mdl_id`, `alertname`, `mdl_alert_enabled`, `from_db`, `to_betweenmsec`, `to_overallsec`, `grouped`) VALUES
	(1, 'BACKGROUND', 1, 0, NULL, NULL, NULL),
	(1, 'CFG_CLIST', 1, 1, NULL, NULL, NULL),
	(1, 'CFG_DAS_SEP', 1, 1, NULL, NULL, NULL),
	(1, 'CFG_LPTY', 1, 1, NULL, NULL, NULL),
	(1, 'CFG_PH', 1, 1, NULL, NULL, NULL),
	(1, 'CFG_SCH', 1, 1, NULL, NULL, NULL),
	(1, 'FullDB_Info', 1, 0, NULL, NULL, NULL),
	(1, 'HOLES', 1, 0, NULL, NULL, NULL),
	(1, 'LTL', 1, 1, NULL, NULL, NULL),
	(1, 'REALTIME', 1, 0, NULL, NULL, NULL),
	(1, 'RECENT_HOLES', 1, 0, NULL, NULL, NULL),
	(1, 'SERVER_OPERATION', 1, 0, NULL, NULL, NULL),
	(1, 'SRCACL', 1, 1, NULL, NULL, NULL),
	(1, 'TASK_4LINK', 1, 1, NULL, NULL, NULL),
	(1, 'UTL', 1, 1, NULL, NULL, NULL),
	(1, 'WRITE_AUTO', 1, 0, NULL, NULL, NULL),
	(4, 'SHOW_End', 1, 0, NULL, NULL, NULL),
	(7, 'MDL_ALERT', 1, 1, NULL, NULL, NULL),
	(16, 'CFG_RP', 1, 1, 2000, 15, NULL),
	(16, 'EVA_BGA', 0, 1, NULL, NULL, NULL),
	(16, 'EVA_RPA', 1, 1, NULL, NULL, NULL),
	(16, 'EXP_BACKGROUND', 1, 0, NULL, NULL, NULL),
	(16, 'EXP_HOLES', 1, 0, NULL, NULL, NULL),
	(16, 'REPORT', 1, 0, NULL, NULL, NULL),
	(16, 'XF_RPT_ALERT', 0, 1, NULL, NULL, NULL),
	(17, 'CFG_XF', 1, 1, 5000, 20, NULL),
	(17, 'EXP_BACKGROUND', 1, 0, NULL, NULL, NULL),
	(17, 'EXP_HOLES', 1, 0, NULL, NULL, NULL),
	(20, 'CFG_OPC', 1, 1, NULL, NULL, NULL),
	(22, 'POBJ_DS_CHANGE', 1, 1, NULL, NULL, NULL),
	(26, 'CFG_MULTISTEP', 0, 1, NULL, NULL, NULL),
	(34, 'CFG_104', 1, 1, NULL, NULL, NULL);
/*!40000 ALTER TABLE `mdl_alert` ENABLE KEYS */;

-- Dumping structure for table emcor.meter
CREATE TABLE IF NOT EXISTS `meter` (
  `meter_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Matavimo priemonės identifikatorius',
  `meter_type_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimo priemonių tipo identifikatorius',
  `made` date DEFAULT NULL COMMENT 'Pagaminimo data',
  `expl_start` datetime DEFAULT NULL COMMENT 'Eksploatacijos pradžia',
  `meter_number` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo priemonės numeris',
  `meter_class` varchar(9) COLLATE utf8_bin DEFAULT NULL COMMENT 'Skaitiklio tikslumo klasė',
  PRIMARY KEY (`meter_id`),
  UNIQUE KEY `meter_number_u` (`meter_number`,`meter_type_id`),
  KEY `meter_meter_type_i` (`meter_type_id`),
  CONSTRAINT `meter_meter_type_fk` FOREIGN KEY (`meter_type_id`) REFERENCES `meter_type` (`meter_type_id`),
  CONSTRAINT `EXPL_START_DATA_CHECK` CHECK (`made` is null or `made` is not null and `expl_start` >= `made`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimo prietaisai';

-- Dumping data for table emcor.meter: ~0 rows (approximately)
/*!40000 ALTER TABLE `meter` DISABLE KEYS */;
/*!40000 ALTER TABLE `meter` ENABLE KEYS */;

-- Dumping structure for table emcor.meter_mpty
CREATE TABLE IF NOT EXISTS `meter_mpty` (
  `meter_id` int(10) unsigned NOT NULL COMMENT 'Matavimo priemonės identifikatorius',
  `mpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo priemonių savybės identifikatorius',
  `mpty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo priemonės savybės reikšmė',
  PRIMARY KEY (`meter_id`,`mpty_id`),
  KEY `meter_mpty_mpty_i` (`mpty_id`),
  CONSTRAINT `meter_mpty_meter_fk` FOREIGN KEY (`meter_id`) REFERENCES `meter` (`meter_id`) ON DELETE CASCADE,
  CONSTRAINT `meter_mpty_mpty_fk` FOREIGN KEY (`mpty_id`) REFERENCES `mpty` (`mpty_id`),
  CONSTRAINT `METER_MPTY_SYMBOL_CHECK` CHECK (nullif(regexp_replace(`mpty_value`,'([[:print:]])+',''),'') is null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimo prietaisų savybės';

-- Dumping data for table emcor.meter_mpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `meter_mpty` DISABLE KEYS */;
/*!40000 ALTER TABLE `meter_mpty` ENABLE KEYS */;

-- Dumping structure for table emcor.meter_type
CREATE TABLE IF NOT EXISTS `meter_type` (
  `meter_type_id` smallint(5) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Matavimo priemonių tipo identifikatorius',
  `meter_type_name` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo priemonių tipo pavadinimas',
  `meter_type_producer` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Matavimo priemonių tipo gamintojas',
  PRIMARY KEY (`meter_type_id`),
  UNIQUE KEY `meter_type_name_u` (`meter_type_name`)
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimo prietaisų tipai';

-- Dumping data for table emcor.meter_type: ~4 rows (approximately)
/*!40000 ALTER TABLE `meter_type` DISABLE KEYS */;
INSERT INTO `meter_type` (`meter_type_id`, `meter_type_name`, `meter_type_producer`) VALUES
	(1, 'EPQS', 'Elgama'),
	(2, 'EPQM', 'Elgama'),
	(3, 'LZQM', 'Elgama'),
	(4, 'LZKM', 'Elgama');
/*!40000 ALTER TABLE `meter_type` ENABLE KEYS */;

-- Dumping structure for table emcor.meter_type_mpty
CREATE TABLE IF NOT EXISTS `meter_type_mpty` (
  `meter_type_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimo priemonių tipo identifikatorius',
  `mpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo priemonių savybės identifikatorius',
  PRIMARY KEY (`meter_type_id`,`mpty_id`),
  KEY `meter_type_mpty_mpty_i` (`mpty_id`),
  CONSTRAINT `meter_type_mpty_meter_type_fk` FOREIGN KEY (`meter_type_id`) REFERENCES `meter_type` (`meter_type_id`) ON DELETE CASCADE,
  CONSTRAINT `meter_type_mpty_mpty_fk` FOREIGN KEY (`mpty_id`) REFERENCES `mpty` (`mpty_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo priemonių savybės pagal matavimo priemonių tipus';

-- Dumping data for table emcor.meter_type_mpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `meter_type_mpty` DISABLE KEYS */;
/*!40000 ALTER TABLE `meter_type_mpty` ENABLE KEYS */;

-- Dumping structure for table emcor.ml
CREATE TABLE IF NOT EXISTS `ml` (
  `ml_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo linijos identifikatorius',
  `ms_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimo identifikatorius',
  `dir_id` tinyint(4) NOT NULL COMMENT 'Krypties identifikatorius',
  `aggs_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo segmento identifikatorius',
  `aggf_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo funkcijos identifikatorius',
  `tff_id` tinyint(3) unsigned NOT NULL COMMENT 'Tarifo identifikatorius',
  `eu_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo vienetų identifikatorius',
  `md_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimo diskretiškumo identifikatorius',
  `msf_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimo su agregavimo funkcija ID',
  `obis` varchar(30) COLLATE utf8_bin DEFAULT NULL COMMENT 'Kodas OBIS',
  `ml_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo linijos pavadinimas',
  `stobis` mediumint(8) DEFAULT NULL COMMENT 'Kodas STOBIS',
  `aggs_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  `ml_custom_code` varchar(100) COLLATE utf8_bin DEFAULT NULL COMMENT 'Matavimo linijai nustatytas kodas',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  PRIMARY KEY (`ml_id`),
  UNIQUE KEY `ml_name_u` (`ml_name`),
  UNIQUE KEY `ml_u` (`ms_id`,`dir_id`,`aggs_id`,`aggf_id`,`tff_id`,`md_id`),
  KEY `ml_aggf_i` (`aggf_id`),
  KEY `ml_aggs_i` (`aggs_id`),
  KEY `ml_aggs_type_i` (`aggs_type_id`),
  KEY `ml_dir_i` (`dir_id`),
  KEY `ml_enum_i` (`enum_id`),
  KEY `ml_eu_i` (`eu_id`),
  KEY `ml_md_i` (`md_id`),
  KEY `ml_msf_i` (`msf_id`),
  KEY `ml_tff_i` (`tff_id`),
  CONSTRAINT `ml_aggf_fk` FOREIGN KEY (`aggf_id`) REFERENCES `aggf` (`aggf_id`),
  CONSTRAINT `ml_aggs_fk` FOREIGN KEY (`aggs_id`) REFERENCES `aggs` (`aggs_id`),
  CONSTRAINT `ml_dir_fk` FOREIGN KEY (`dir_id`) REFERENCES `dir` (`dir_id`),
  CONSTRAINT `ml_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`),
  CONSTRAINT `ml_eu_fk` FOREIGN KEY (`eu_id`) REFERENCES `eu` (`eu_id`),
  CONSTRAINT `ml_md_fk` FOREIGN KEY (`md_id`) REFERENCES `md` (`md_id`),
  CONSTRAINT `ml_ms_fk` FOREIGN KEY (`ms_id`) REFERENCES `ms` (`ms_id`),
  CONSTRAINT `ml_msf_fk` FOREIGN KEY (`msf_id`) REFERENCES `msf` (`msf_id`),
  CONSTRAINT `ml_tff_fk` FOREIGN KEY (`tff_id`) REFERENCES `tff` (`tff_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimai';

-- Dumping data for table emcor.ml: ~12 150 rows (approximately)
/*!40000 ALTER TABLE `ml` DISABLE KEYS */;
INSERT INTO `ml` (`ml_id`, `ms_id`, `dir_id`, `aggs_id`, `aggf_id`, `tff_id`, `eu_id`, `md_id`, `msf_id`, `obis`, `ml_name`, `stobis`, `aggs_type_id`, `ml_custom_code`, `enum_id`) VALUES
	(1, 1, 1, 8, 2, 1, 2, 7, 14, '1.0.1.8.0.1', 'Suminė A+ energija pagal 1 tarifą', 1, 5, NULL, NULL),
	(2, 1, 2, 8, 2, 1, 2, 7, 14, '1.0.2.8.0.1', 'Suminė A- energija pagal 1 tarifą', 2, 5, NULL, NULL),
	(3, 3, 1, 8, 2, 1, 4, 7, 15, '1.0.3.8.0.1', 'Suminė R+ energija pagal 1 tarifą', 3, 5, NULL, NULL),
	(4, 3, 2, 8, 2, 1, 4, 7, 15, '1.0.4.8.0.1', 'Suminė R- energija pagal 1 tarifą', 4, 5, NULL, NULL),
	(5, 1, 1, 8, 2, 2, 2, 7, 14, '1.0.1.8.0.2', 'Suminė A+ energija pagal 2 tarifą', 5, 5, NULL, NULL),
	(6, 1, 2, 8, 2, 2, 2, 7, 14, '1.0.2.8.0.2', 'Suminė A- energija pagal 2 tarifą', 6, 5, NULL, NULL),
	(7, 3, 1, 8, 2, 2, 4, 7, 15, '1.0.3.8.0.2', 'Suminė R+ energija pagal 2 tarifą', 7, 5, NULL, NULL),
	(8, 3, 2, 8, 2, 2, 4, 7, 15, '1.0.4.8.0.2', 'Suminė R- energija pagal 2 tarifą', 8, 5, NULL, NULL),
	(9, 1, 1, 8, 2, 3, 2, 7, 14, '1.0.1.8.0.3', 'Suminė A+ energija pagal 3 tarifą', 9, 5, NULL, NULL),
	(10, 1, 2, 8, 2, 3, 2, 7, 14, '1.0.2.8.0.3', 'Suminė A- energija pagal 3 tarifą', 10, 5, NULL, NULL),
	(11, 3, 1, 8, 2, 3, 4, 7, 15, '1.0.3.8.0.3', 'Suminė R+ energija pagal 3 tarifą', 11, 5, NULL, NULL),
	(12, 3, 2, 8, 2, 3, 4, 7, 15, '1.0.4.8.0.3', 'Suminė R- energija pagal 3 tarifą', 12, 5, NULL, NULL),
	(13, 1, 1, 8, 2, 4, 2, 7, 14, '1.0.1.8.0.4', 'Suminė A+ energija pagal 4 tarifą', 13, 5, NULL, NULL),
	(14, 1, 2, 8, 2, 4, 2, 7, 14, '1.0.2.8.0.4', 'Suminė A- energija pagal 4 tarifą', 14, 5, NULL, NULL),
	(15, 3, 1, 8, 2, 4, 4, 7, 15, '1.0.3.8.0.4', 'Suminė R+ energija pagal 4 tarifą', 15, 5, NULL, NULL),
	(16, 3, 2, 8, 2, 4, 4, 7, 15, '1.0.4.8.0.4', 'Suminė R- energija pagal 4 tarifą', 16, 5, NULL, NULL),
	(17, 1, 1, 6, 2, 1, 2, 6, 14, '1.0.1.9.0.1', 'A+ energija pagal 1 tarifą per mėnesį', 17, 4, NULL, NULL),
	(18, 1, 2, 6, 2, 1, 2, 6, 14, '1.0.2.9.0.1', 'A- energija pagal 1 tarifą per mėnesį', 18, 4, NULL, NULL),
	(19, 3, 1, 6, 2, 1, 4, 6, 15, '1.0.3.9.0.1', 'R+ energija pagal 1 tarifą per mėnesį', 19, 4, NULL, NULL),
	(20, 3, 2, 6, 2, 1, 4, 6, 15, '1.0.4.9.0.1', 'R- energija pagal 1 tarifą per mėnesį', 20, 4, NULL, NULL),
	(21, 1, 1, 6, 2, 2, 2, 6, 14, '1.0.1.9.0.2', 'A+ energija pagal 2 tarifą per mėnesį', 21, 4, NULL, NULL),
	(22, 1, 2, 6, 2, 2, 2, 6, 14, '1.0.2.9.0.2', 'A- energija pagal 2 tarifą per mėnesį', 22, 4, NULL, NULL),
	(23, 3, 1, 6, 2, 2, 4, 6, 15, '1.0.3.9.0.2', 'R+ energija pagal 2 tarifą per mėnesį', 23, 4, NULL, NULL),
	(24, 3, 2, 6, 2, 2, 4, 6, 15, '1.0.4.9.0.2', 'R- energija pagal 2 tarifą per mėnesį', 24, 4, NULL, NULL),
	(25, 1, 1, 6, 2, 3, 2, 6, 14, '1.0.1.9.0.3', 'A+ energija pagal 3 tarifą per mėnesį', 25, 4, NULL, NULL),
	(26, 1, 2, 6, 2, 3, 2, 6, 14, '1.0.2.9.0.3', 'A- energija pagal 3 tarifą per mėnesį', 26, 4, NULL, NULL),
	(27, 3, 1, 6, 2, 3, 4, 6, 15, '1.0.3.9.0.3', 'R+ energija pagal 3 tarifą per mėnesį', 27, 4, NULL, NULL),
	(28, 3, 2, 6, 2, 3, 4, 6, 15, '1.0.4.9.0.3', 'R- energija pagal 3 tarifą per mėnesį', 28, 4, NULL, NULL),
	(29, 1, 1, 6, 2, 4, 2, 6, 14, '1.0.1.9.0.4', 'A+ energija pagal 4 tarifą per mėnesį', 29, 4, NULL, NULL),
	(30, 1, 2, 6, 2, 4, 2, 6, 14, '1.0.2.9.0.4', 'A- energija pagal 4 tarifą per mėnesį', 30, 4, NULL, NULL),
	(31, 3, 1, 6, 2, 4, 4, 6, 15, '1.0.3.9.0.4', 'R+ energija pagal 4 tarifą per mėnesį', 31, 4, NULL, NULL),
	(32, 3, 2, 6, 2, 4, 4, 6, 15, '1.0.4.9.0.4', 'R- energija pagal 4 tarifą per mėnesį', 32, 4, NULL, NULL),
	(33, 1, 1, 5, 2, 1, 2, 5, 14, '1.0.1.10.0.1', 'A+ energija pagal 1 tarifą per parą', 33, 3, NULL, NULL),
	(34, 1, 2, 5, 2, 1, 2, 5, 14, '1.0.2.10.0.1', 'A- energija pagal 1 tarifą per parą', 34, 3, NULL, NULL),
	(35, 3, 1, 5, 2, 1, 4, 5, 15, '1.0.3.10.0.1', 'R+ energija pagal 1 tarifą per parą', 35, 3, NULL, NULL),
	(36, 3, 2, 5, 2, 1, 4, 5, 15, '1.0.4.10.0.1', 'R- energija pagal 1 tarifą per parą', 36, 3, NULL, NULL),
	(37, 1, 1, 5, 2, 2, 2, 5, 14, '1.0.1.10.0.2', 'A+ energija pagal 2 tarifą per parą', 37, 3, NULL, NULL),
	(38, 1, 2, 5, 2, 2, 2, 5, 14, '1.0.2.10.0.2', 'A- energija pagal 2 tarifą per parą', 38, 3, NULL, NULL),
	(39, 3, 1, 5, 2, 2, 4, 5, 15, '1.0.3.10.0.2', 'R+ energija pagal 2 tarifą per parą', 39, 3, NULL, NULL),
	(40, 3, 2, 5, 2, 2, 4, 5, 15, '1.0.4.10.0.2', 'R- energija pagal 2 tarifą per parą', 40, 3, NULL, NULL),
	(41, 1, 1, 5, 2, 3, 2, 5, 14, '1.0.1.10.0.3', 'A+ energija pagal 3 tarifą per parą', 41, 3, NULL, NULL),
	(42, 1, 2, 5, 2, 3, 2, 5, 14, '1.0.2.10.0.3', 'A- energija pagal 3 tarifą per parą', 42, 3, NULL, NULL),
	(43, 3, 1, 5, 2, 3, 4, 5, 15, '1.0.3.10.0.3', 'R+ energija pagal 3 tarifą per parą', 43, 3, NULL, NULL),
	(44, 3, 2, 5, 2, 3, 4, 5, 15, '1.0.4.10.0.3', 'R- energija pagal 3 tarifą per parą', 44, 3, NULL, NULL),
	(45, 1, 1, 5, 2, 4, 2, 5, 14, '1.0.1.10.0.4', 'A+ energija pagal 4 tarifą per parą', 45, 3, NULL, NULL),
	(46, 1, 2, 5, 2, 4, 2, 5, 14, '1.0.2.10.0.4', 'A- energija pagal 4 tarifą per parą', 46, 3, NULL, NULL),
	(47, 3, 1, 5, 2, 4, 4, 5, 15, '1.0.3.10.0.4', 'R+ energija pagal 4 tarifą per parą', 47, 3, NULL, NULL),
	(48, 3, 2, 5, 2, 4, 4, 5, 15, '1.0.4.10.0.4', 'R- energija pagal 4 tarifą per parą', 48, 3, NULL, NULL),
	(49, 1, 1, 3, 3, 0, 1, 3, 13, '1.0.1.29.0.0', 'Vidutinė P+ galia per 30 minučių', 49, 2, NULL, NULL),
	(50, 1, 2, 3, 3, 0, 1, 3, 13, '1.0.2.29.0.0', 'Vidutinė P- galia per 30 minučių', 50, 2, NULL, NULL),
	(51, 3, 1, 3, 3, 0, 3, 3, 16, '1.0.3.29.0.0', 'Vidutinė Q+ galia per 30 minučių', 51, 2, NULL, NULL),
	(52, 3, 2, 3, 3, 0, 3, 3, 16, '1.0.4.29.0.0', 'Vidutinė Q- galia per 30 minučių', 52, 2, NULL, NULL),
	(53, 5, 0, 7, 1, 0, 5, 7, 17, NULL, 'Momentinis srovės stiprumas L1 fazėje', 53, 6, NULL, NULL),
	(54, 6, 0, 7, 1, 0, 6, 7, 18, NULL, 'Momentinė įtampa L1 fazėje', 54, 6, NULL, NULL),
	(55, 7, 0, 7, 1, 0, 5, 7, 19, NULL, 'Momentinis srovės stiprumas L2 fazėje', 55, 6, NULL, NULL),
	(56, 8, 0, 7, 1, 0, 6, 7, 20, NULL, 'Momentinė įtampa L2 fazėje', 56, 6, NULL, NULL),
	(57, 9, 0, 7, 1, 0, 5, 7, 21, NULL, 'Momentinis srovės stiprumas L3 fazėje', 57, 6, NULL, NULL),
	(58, 10, 0, 7, 1, 0, 6, 7, 22, NULL, 'Momentinė įtampa L3 fazėje', 58, 6, NULL, NULL),
	(59, 11, 0, 7, 1, 0, 6, 7, 23, NULL, 'Momentinė linijinė įtampa L1 fazėje', 59, 6, NULL, NULL),
	(60, 12, 0, 7, 1, 0, 6, 7, 24, NULL, 'Momentinė linijinė įtampa L2 fazėje', 60, 6, NULL, NULL),
	(61, 13, 0, 7, 1, 0, 6, 7, 25, NULL, 'Momentinė linijinė įtampa L3 fazėje', 61, 6, NULL, NULL),
	(62, 14, 0, 7, 1, 0, 1, 7, 26, NULL, 'Momentinė aktyvinė galia L1 fazėje', 62, 6, NULL, NULL),
	(63, 15, 0, 7, 1, 0, 1, 7, 27, NULL, 'Momentinė aktyvinė galia L2 fazėje', 63, 6, NULL, NULL),
	(64, 16, 0, 7, 1, 0, 1, 7, 28, NULL, 'Momentinė aktyvinė galia L3 fazėje', 64, 6, NULL, NULL),
	(65, 17, 0, 7, 1, 0, 3, 7, 29, NULL, 'Momentinė reaktyvinė galia L1 fazėje', 65, 6, NULL, NULL),
	(66, 18, 0, 7, 1, 0, 3, 7, 30, NULL, 'Momentinė reaktyvinė galia L2 fazėje', 66, 6, NULL, NULL),
	(67, 19, 0, 7, 1, 0, 3, 7, 31, NULL, 'Momentinė reaktyvinė galia L3 fazėje', 67, 6, NULL, NULL),
	(68, 20, 0, 7, 1, 0, 7, 7, 32, NULL, 'Momentinė pilnoji galia L1 fazėje', 68, 6, NULL, NULL),
	(69, 21, 0, 7, 1, 0, 7, 7, 33, NULL, 'Momentinė pilnoji galia L2 fazėje', 69, 6, NULL, NULL),
	(70, 22, 0, 7, 1, 0, 7, 7, 34, NULL, 'Momentinė pilnoji galia L3 fazėje', 70, 6, NULL, NULL),
	(71, 23, 0, 7, 1, 0, 0, 7, 35, NULL, 'Momentinė cos(fi) reikšmė L1 fazėje', 71, 6, NULL, NULL),
	(72, 24, 0, 7, 1, 0, 0, 7, 36, NULL, 'Momentinė cos(fi) reikšmė L2 fazėje', 72, 6, NULL, NULL),
	(73, 25, 0, 7, 1, 0, 0, 7, 37, NULL, 'Momentinė cos(fi) reikšmė L3 fazėje', 73, 6, NULL, NULL),
	(74, 26, 0, 7, 1, 0, 0, 7, 38, NULL, 'Momentinis kvadrantas L1 fazėje', 74, 6, NULL, NULL),
	(75, 27, 0, 7, 1, 0, 0, 7, 39, NULL, 'Momentinis kvadrantas L2 fazėje', 75, 6, NULL, NULL),
	(76, 28, 0, 7, 1, 0, 0, 7, 40, NULL, 'Momentinis kvadrantas L3 fazėje', 76, 6, NULL, NULL),
	(77, 29, 0, 7, 1, 0, 5, 7, 41, NULL, 'Momentinis srovės stiprumas', 77, 6, NULL, NULL),
	(78, 30, 0, 7, 1, 0, 6, 7, 42, NULL, 'Momentinė įtampa', 78, 6, NULL, NULL),
	(79, 31, 0, 7, 1, 0, 6, 7, 43, NULL, 'Momentinė linijinė įtampa', 79, 6, NULL, NULL),
	(80, 1, 0, 7, 1, 0, 1, 7, 13, NULL, 'Momentinė aktyvinė galia', 80, 6, NULL, NULL),
	(81, 3, 0, 7, 1, 0, 3, 7, 16, NULL, 'Momentinė reaktyvinė galia', 81, 6, NULL, NULL),
	(82, 34, 0, 7, 1, 0, 7, 7, 44, NULL, 'Momentinė pilnoji galia', 82, 6, NULL, NULL),
	(83, 35, 0, 7, 1, 0, 0, 7, 46, NULL, 'Momentinė cos(fi) reikšmė', 83, 6, NULL, NULL),
	(84, 36, 0, 7, 1, 0, 0, 7, 47, NULL, 'Momentinis kvadrantas', 84, 6, NULL, NULL),
	(85, 37, 0, 7, 1, 0, 8, 7, 48, NULL, 'Momentinis dažnis', 85, 6, NULL, NULL),
	(86, 38, 0, 7, 1, 0, 0, 7, 49, NULL, 'Momentinė fazių seka', 86, 6, NULL, NULL),
	(87, 39, 0, 4, 3, 0, 36, 4, 1, NULL, 'Vidutinis dujų koreguotos masės debitas per valandą', 1135, 2, NULL, NULL),
	(88, 39, 0, 5, 2, 0, 35, 5, 2, NULL, 'Dujų koreguotos masės kiekis per parą', 1130, 3, NULL, NULL),
	(89, 39, 0, 5, 3, 0, 36, 5, 1, NULL, 'Vidutinis dujų koreguotos masės debitas per parą', 1135, 3, NULL, NULL),
	(90, 39, 0, 6, 2, 0, 35, 6, 2, NULL, 'Dujų koreguotos masės kiekis per mėnesį', 1130, 4, NULL, NULL),
	(91, 39, 0, 6, 3, 0, 36, 6, 1, NULL, 'Vidutinis dujų koreguotos masės debitas per mėnesį', 1135, 4, NULL, NULL),
	(92, 39, 0, 7, 1, 0, 36, 7, 1, NULL, 'Momentinis dujų koreguotos masės debitas', 1111, 6, NULL, NULL),
	(93, 40, 0, 4, 3, 0, 32, 4, 3, NULL, 'Vidutinis dujų koreguoto tūrio debitas per valandą', 1137, 2, NULL, NULL),
	(94, 40, 0, 5, 2, 0, 31, 5, 4, NULL, 'Dujų koreguoto tūrio kiekis per parą', 1131, 3, NULL, NULL),
	(95, 40, 0, 5, 3, 0, 32, 5, 3, NULL, 'Vidutinis dujų koreguoto tūrio debitas per parą', 1137, 3, NULL, NULL),
	(96, 40, 0, 6, 2, 0, 31, 6, 4, NULL, 'Dujų koreguoto tūrio kiekis per mėnesį', 1131, 4, NULL, NULL),
	(97, 40, 0, 6, 3, 0, 32, 6, 3, NULL, 'Vidutinis dujų koreguoto tūrio debitas per mėnesį', 1137, 4, NULL, NULL),
	(98, 40, 0, 7, 1, 0, 32, 7, 3, NULL, 'Momentinis dujų koreguoto tūrio debitas', 1113, 6, NULL, NULL),
	(99, 41, 0, 4, 3, 0, 36, 4, 5, NULL, 'Vidutinis dujų masės debitas per valandą', 1134, 2, NULL, NULL),
	(100, 41, 0, 5, 2, 0, 35, 5, 6, NULL, 'Dujų masės kiekis per parą', 1128, 3, NULL, NULL),
	(101, 41, 0, 5, 3, 0, 36, 5, 5, NULL, 'Vidutinis dujų masės debitas per parą', 1134, 3, NULL, NULL),
	(102, 41, 0, 6, 2, 0, 35, 6, 6, NULL, 'Dujų masės kiekis per mėnesį', 1128, 4, NULL, NULL),
	(103, 41, 0, 6, 3, 0, 36, 6, 5, NULL, 'Vidutinis dujų masės debitas per mėnesį', 1134, 4, NULL, NULL),
	(104, 41, 0, 7, 1, 0, 36, 7, 5, NULL, 'Momentinis dujų masės debitas', 1106, 6, NULL, NULL),
	(105, 42, 0, 4, 3, 0, 28, 4, 7, NULL, 'Vidutinis dujų slėgis per valandą', 1138, 2, NULL, NULL),
	(106, 42, 0, 5, 3, 0, 28, 5, 7, NULL, 'Vidutinis dujų slėgis per parą', 1138, 3, NULL, NULL),
	(107, 42, 0, 6, 3, 0, 28, 6, 7, NULL, 'Vidutinis dujų slėgis per mėnesį', 1138, 4, NULL, NULL),
	(108, 42, 0, 7, 1, 0, 28, 7, 7, NULL, 'Momentinis dujų slėgis', 1104, 6, NULL, NULL),
	(109, 43, 0, 4, 3, 0, 33, 4, 8, NULL, 'Vidutinė dujų šilumos galia per valandą', 1132, 2, NULL, NULL),
	(110, 43, 0, 5, 2, 0, 34, 5, 9, NULL, 'Dujų šilumos kiekis per parą', 1127, 3, NULL, NULL),
	(111, 43, 0, 5, 3, 0, 33, 5, 8, NULL, 'Vidutinė dujų šilumos galia per parą', 1132, 3, NULL, NULL),
	(112, 43, 0, 6, 2, 0, 34, 6, 9, NULL, 'Dujų šilumos kiekis per mėnesį', 1127, 4, NULL, NULL),
	(113, 43, 0, 6, 3, 0, 33, 6, 8, NULL, 'Vidutinė dujų šilumos galia per mėnesį', 1132, 4, NULL, NULL),
	(114, 43, 0, 7, 1, 0, 33, 7, 8, NULL, 'Momentinė dujų šilumos galia', 1102, 6, NULL, NULL),
	(115, 44, 0, 4, 3, 0, 27, 4, 10, NULL, 'Vidutinė dujų temperatūra per valandą', 1133, 2, NULL, NULL),
	(116, 44, 0, 5, 3, 0, 27, 5, 10, NULL, 'Vidutinė dujų temperatūra per parą', 1133, 3, NULL, NULL),
	(117, 44, 0, 6, 3, 0, 27, 6, 10, NULL, 'Vidutinė dujų temperatūra per mėnesį', 1133, 4, NULL, NULL),
	(118, 44, 0, 7, 1, 0, 27, 7, 10, NULL, 'Momentinė dujų temperatūra', 1103, 6, NULL, NULL),
	(119, 45, 0, 4, 3, 0, 32, 4, 11, NULL, 'Vidutinis dujų tūrio debitas per valandą', 1136, 2, NULL, NULL),
	(120, 45, 0, 5, 2, 0, 31, 5, 12, NULL, 'Dujų tūrio kiekis per parą', 1129, 3, NULL, NULL),
	(121, 45, 0, 5, 3, 0, 32, 5, 11, NULL, 'Vidutinis dujų tūrio debitas per parą', 1136, 3, NULL, NULL),
	(122, 45, 0, 6, 2, 0, 31, 6, 12, NULL, 'Dujų tūrio kiekis per mėnesį', 1129, 4, NULL, NULL),
	(123, 45, 0, 6, 3, 0, 32, 6, 11, NULL, 'Vidutinis dujų tūrio debitas per mėnesį', 1136, 4, NULL, NULL),
	(124, 45, 0, 7, 1, 0, 32, 7, 11, NULL, 'Momentinis dujų tūrio debitas', 1108, 6, NULL, NULL),
	(125, 46, 0, 4, 3, 0, 27, 4, 55, NULL, 'Vidutinė oro temperatūra per valandą', 1302, 2, NULL, NULL),
	(126, 46, 0, 5, 3, 0, 27, 5, 55, NULL, 'Vidutinė oro temperatūra per parą', 1302, 3, NULL, NULL),
	(127, 46, 0, 6, 3, 0, 27, 6, 55, NULL, 'Vidutinė oro temperatūra per mėnesį', 1302, 4, NULL, NULL),
	(128, 46, 0, 7, 1, 0, 27, 7, 55, NULL, 'Momentinė oro temperatūra', 1300, 6, NULL, NULL),
	(129, 47, 0, 4, 3, 0, 30, 4, 61, NULL, 'Vidutinis šalčio slėgis per valandą', 1004, 2, NULL, NULL),
	(130, 47, 1, 4, 3, 0, 30, 4, 61, NULL, 'Vidutinis tiekiamo šalčio slėgis per valandą', 1004, 2, NULL, NULL),
	(131, 47, 2, 4, 3, 0, 30, 4, 61, NULL, 'Vidutinis grįžtamo šalčio slėgis per valandą', 1004, 2, NULL, NULL),
	(132, 47, 3, 4, 3, 0, 30, 4, 61, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio slėgio skirtumas per valandą', 1004, 2, NULL, NULL),
	(133, 47, 0, 5, 3, 0, 30, 5, 61, NULL, 'Vidutinis šalčio slėgis per parą', 1004, 3, NULL, NULL),
	(134, 47, 1, 5, 3, 0, 30, 5, 61, NULL, 'Vidutinis tiekiamo šalčio slėgis per parą', 1004, 3, NULL, NULL),
	(135, 47, 2, 5, 3, 0, 30, 5, 61, NULL, 'Vidutinis grįžtamo šalčio slėgis per parą', 1004, 3, NULL, NULL),
	(136, 47, 3, 5, 3, 0, 30, 5, 61, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio slėgio skirtumas per parą', 1004, 3, NULL, NULL),
	(137, 47, 0, 6, 3, 0, 30, 6, 61, NULL, 'Vidutinis šalčio slėgis per mėnesį', 1004, 4, NULL, NULL),
	(138, 47, 1, 6, 3, 0, 30, 6, 61, NULL, 'Vidutinis tiekiamo šalčio slėgis per mėnesį', 1004, 4, NULL, NULL),
	(139, 47, 2, 6, 3, 0, 30, 6, 61, NULL, 'Vidutinis grįžtamo šalčio slėgis per mėnesį', 1004, 4, NULL, NULL),
	(140, 47, 3, 6, 3, 0, 30, 6, 61, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio slėgio skirtumas per mėnesį', 1004, 4, NULL, NULL),
	(141, 47, 0, 7, 1, 0, 30, 7, 61, NULL, 'Momentinis šalčio slėgis', 1004, 6, NULL, NULL),
	(142, 47, 1, 7, 1, 0, 30, 7, 61, NULL, 'Momentinis tiekiamo šalčio slėgis', 1004, 6, NULL, NULL),
	(143, 47, 2, 7, 1, 0, 30, 7, 61, NULL, 'Momentinis grįžtamo šalčio slėgis', 1004, 6, NULL, NULL),
	(144, 47, 3, 7, 1, 0, 30, 7, 61, NULL, 'Momentinis tiekiamo ir grįžtamo šalčio slėgio skirtumas', 1004, 6, NULL, NULL),
	(145, 48, 0, 4, 3, 0, 1, 4, 63, NULL, 'Vidutinė šalčio galia per valandą', 1002, 2, NULL, NULL),
	(146, 48, 1, 4, 3, 0, 1, 4, 63, NULL, 'Vidutinė tiekiamo šalčio galia per valandą', 1002, 2, NULL, NULL),
	(147, 48, 2, 4, 3, 0, 1, 4, 63, NULL, 'Vidutinė grįžtamo šalčio galia per valandą', 1002, 2, NULL, NULL),
	(148, 48, 3, 4, 3, 0, 1, 4, 63, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio šilumos galios skirtumas per valandą', 1002, 2, NULL, NULL),
	(149, 48, 0, 5, 2, 0, 2, 5, 62, NULL, 'Šalčio energija per parą', 1001, 3, NULL, NULL),
	(150, 48, 1, 5, 2, 0, 2, 5, 62, NULL, 'Tiekiamo šalčio energija per parą', 1001, 3, NULL, NULL),
	(151, 48, 2, 5, 2, 0, 2, 5, 62, NULL, 'Grįžtamo šalčio energija per parą', 1001, 3, NULL, NULL),
	(152, 48, 3, 5, 2, 0, 2, 5, 62, NULL, 'Tiekiamo ir grįžtamo šalčio šilumos kiekių skirtumas per parą', 1001, 3, NULL, NULL),
	(153, 48, 0, 5, 3, 0, 1, 5, 63, NULL, 'Vidutinė šalčio galia per parą', 1002, 3, NULL, NULL),
	(154, 48, 1, 5, 3, 0, 1, 5, 63, NULL, 'Vidutinė tiekiamo šalčio galia per parą', 1002, 3, NULL, NULL),
	(155, 48, 2, 5, 3, 0, 1, 5, 63, NULL, 'Vidutinė grįžtamo šalčio galia per parą', 1002, 3, NULL, NULL),
	(156, 48, 3, 5, 3, 0, 1, 5, 63, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio šilumos galios skirtumas per parą', 1002, 3, NULL, NULL),
	(157, 48, 0, 6, 2, 0, 2, 6, 62, NULL, 'Šalčio energija per mėnesį', 1001, 4, NULL, NULL),
	(158, 48, 1, 6, 2, 0, 2, 6, 62, NULL, 'Tiekiamo šalčio energija per mėnesį', 1001, 4, NULL, NULL),
	(159, 48, 2, 6, 2, 0, 2, 6, 62, NULL, 'Grįžtamo šalčio energija per mėnesį', 1001, 4, NULL, NULL),
	(160, 48, 3, 6, 2, 0, 2, 6, 62, NULL, 'Tiekiamo ir grįžtamo šalčio šilumos kiekių skirtumas per mėnesį', 1001, 4, NULL, NULL),
	(161, 48, 0, 6, 3, 0, 1, 6, 63, NULL, 'Vidutinė šalčio galia per mėnesį', 1002, 4, NULL, NULL),
	(162, 48, 1, 6, 3, 0, 1, 6, 63, NULL, 'Vidutinė tiekiamo šalčio galia per mėnesį', 1002, 4, NULL, NULL),
	(163, 48, 2, 6, 3, 0, 1, 6, 63, NULL, 'Vidutinė grįžtamo šalčio galia per mėnesį', 1002, 4, NULL, NULL),
	(164, 48, 3, 6, 3, 0, 1, 6, 63, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio šilumos galios skirtumas per mėnesį', 1002, 4, NULL, NULL),
	(165, 48, 0, 7, 1, 0, 1, 7, 63, NULL, 'Momentinė šalčio galia', 1002, 6, NULL, NULL),
	(166, 48, 1, 7, 1, 0, 1, 7, 63, NULL, 'Momentinė tiekiamo šalčio galia', 1002, 6, NULL, NULL),
	(167, 48, 2, 7, 1, 0, 1, 7, 63, NULL, 'Momentinė grįžtamo šalčio galia', 1002, 6, NULL, NULL),
	(168, 48, 3, 7, 1, 0, 1, 7, 63, NULL, 'Momentinis tiekiamo ir grįžtamo šalčio šilumos galių skirtumas', 1002, 6, NULL, NULL),
	(169, 49, 0, 4, 3, 0, 27, 4, 64, NULL, 'Vidutinė šalčio temperatūra per valandą', 1003, 2, NULL, NULL),
	(170, 49, 1, 4, 3, 0, 27, 4, 64, NULL, 'Vidutinė tiekiamo šalčio temperatūra per valandą', 1003, 2, NULL, NULL),
	(171, 49, 2, 4, 3, 0, 27, 4, 64, NULL, 'Vidutinė grįžtamo šalčio temperatūra per valandą', 1008, 2, NULL, NULL),
	(172, 49, 3, 4, 3, 0, 27, 4, 64, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio temperatūrų skirtumas per valandą', 1009, 2, NULL, NULL),
	(173, 49, 0, 5, 3, 0, 27, 5, 64, NULL, 'Vidutinė šalčio temperatūra per parą', 1003, 3, NULL, NULL),
	(174, 49, 1, 5, 3, 0, 27, 5, 64, NULL, 'Vidutinė tiekiamo šalčio temperatūra per parą', 1003, 3, NULL, NULL),
	(175, 49, 2, 5, 3, 0, 27, 5, 64, NULL, 'Vidutinė grįžtamo šalčio temperatūra per parą', 1008, 3, NULL, NULL),
	(176, 49, 3, 5, 3, 0, 27, 5, 64, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio temperatūrų skirtumas per parą', 1009, 3, NULL, NULL),
	(177, 49, 0, 6, 3, 0, 27, 6, 64, NULL, 'Vidutinė šalčio temperatūra per mėnesį', 1003, 4, NULL, NULL),
	(178, 49, 1, 6, 3, 0, 27, 6, 64, NULL, 'Vidutinė tiekiamo šalčio temperatūra per mėnesį', 1003, 4, NULL, NULL),
	(179, 49, 2, 6, 3, 0, 27, 6, 64, NULL, 'Vidutinė grįžtamo šalčio temperatūra per mėnesį', 1008, 4, NULL, NULL),
	(180, 49, 3, 6, 3, 0, 27, 6, 64, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio temperatūrų skirtumas per mėnesį', 1009, 4, NULL, NULL),
	(181, 49, 0, 7, 1, 0, 27, 7, 64, NULL, 'Momentinė šalčio temperatūra', 1003, 6, NULL, NULL),
	(182, 49, 1, 7, 1, 0, 27, 7, 64, NULL, 'Momentinė tiekiamo šalčio temperatūra', 1003, 6, NULL, NULL),
	(183, 49, 2, 7, 1, 0, 27, 7, 64, NULL, 'Momentinė grįžtamo šalčio temperatūra', 1008, 6, NULL, NULL),
	(184, 49, 3, 7, 1, 0, 27, 7, 64, NULL, 'Momentinis tiekiamo ir grįžtamo šalčio temperatūrų skirtumas', 1009, 6, NULL, NULL),
	(185, 50, 0, 4, 3, 0, 32, 4, 65, NULL, 'Vidutinis šalčio tūrio debitas per valandą', 1011, 2, NULL, NULL),
	(186, 50, 1, 4, 3, 0, 32, 4, 65, NULL, 'Vidutinis tiekiamo šalčio tūrio debitas per valandą', 1011, 2, NULL, NULL),
	(187, 50, 2, 4, 3, 0, 32, 4, 65, NULL, 'Vidutinis grįžtamo šalčio tūrio debitas per valandą', 1011, 2, NULL, NULL),
	(188, 50, 3, 4, 3, 0, 32, 4, 65, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio tūrio debito skirtumas per valandą', 1011, 2, NULL, NULL),
	(189, 50, 0, 5, 2, 0, 31, 5, 66, NULL, 'Šalčio tūrio kiekis per parą', 1010, 3, NULL, NULL),
	(190, 50, 1, 5, 2, 0, 31, 5, 66, NULL, 'Tiekiamo šalčio tūrio kiekis per parą', 1010, 3, NULL, NULL),
	(191, 50, 2, 5, 2, 0, 31, 5, 66, NULL, 'Grįžtamo šalčio tūrio kiekis per parą', 1010, 3, NULL, NULL),
	(192, 50, 3, 5, 2, 0, 31, 5, 66, NULL, 'Tiekiamo ir grįžtamo šalčio tūrio kiekių skirtumas per parą', 1010, 3, NULL, NULL),
	(193, 50, 0, 5, 3, 0, 32, 5, 65, NULL, 'Vidutinis šalčio tūrio debitas per parą', 1011, 3, NULL, NULL),
	(194, 50, 1, 5, 3, 0, 32, 5, 65, NULL, 'Vidutinis tiekiamo šalčio tūrio debitas per parą', 1011, 3, NULL, NULL),
	(195, 50, 2, 5, 3, 0, 32, 5, 65, NULL, 'Vidutinis grįžtamo šalčio tūrio debitas per parą', 1011, 3, NULL, NULL),
	(196, 50, 3, 5, 3, 0, 32, 5, 65, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio tūrio debito skirtumas per parą', 1011, 3, NULL, NULL),
	(197, 50, 0, 6, 2, 0, 31, 6, 66, NULL, 'Šalčio tūrio kiekis per mėnesį', 1010, 4, NULL, NULL),
	(198, 50, 1, 6, 2, 0, 31, 6, 66, NULL, 'Tiekiamo šalčio tūrio kiekis per mėnesį', 1010, 4, NULL, NULL),
	(199, 50, 2, 6, 2, 0, 31, 6, 66, NULL, 'Grįžtamo šalčio tūrio kiekis per mėnesį', 1010, 4, NULL, NULL),
	(200, 50, 3, 6, 2, 0, 31, 6, 66, NULL, 'Tiekiamo ir grįžtamo šalčio tūrio kiekių skirtumas per mėnesį', 1010, 4, NULL, NULL),
	(201, 50, 0, 6, 3, 0, 32, 6, 65, NULL, 'Vidutinis šalčio tūrio debitas per mėnesį', 1011, 4, NULL, NULL),
	(202, 50, 1, 6, 3, 0, 32, 6, 65, NULL, 'Vidutinis tiekiamo šalčio tūrio debitas per mėnesį', 1011, 4, NULL, NULL),
	(203, 50, 2, 6, 3, 0, 32, 6, 65, NULL, 'Vidutinis grįžtamo šalčio tūrio debitas per mėnesį', 1011, 4, NULL, NULL),
	(204, 50, 3, 6, 3, 0, 32, 6, 65, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio tūrio debito skirtumas per mėnesį', 1011, 4, NULL, NULL),
	(205, 50, 0, 7, 1, 0, 32, 7, 65, NULL, 'Momentinis šalčio tūrio debitas', 1011, 6, NULL, NULL),
	(206, 50, 1, 7, 1, 0, 32, 7, 65, NULL, 'Momentinis tiekiamo šalčio tūrio debitas', 1011, 6, NULL, NULL),
	(207, 50, 2, 7, 1, 0, 32, 7, 65, NULL, 'Momentinis grįžtamo šalčio tūrio debitas', 1011, 6, NULL, NULL),
	(208, 50, 3, 7, 1, 0, 32, 7, 65, NULL, 'Momentinis tiekiamo ir grįžtamo šalčio tūrio debito skirtumas', 1011, 6, NULL, NULL),
	(209, 51, 0, 4, 3, 0, 36, 4, 67, NULL, 'Vidutinis šilumnešio masės debitas per valandą', 1715, 2, NULL, NULL),
	(210, 51, 1, 4, 3, 0, 36, 4, 67, NULL, 'Vidutinis tiekiamo šilumnešio masės debitas per valandą', 1006, 2, NULL, NULL),
	(211, 51, 2, 4, 3, 0, 36, 4, 67, NULL, 'Vidutinis grįžtamo šilumnešio masės debitas per valandą', 1732, 2, NULL, NULL),
	(212, 51, 3, 4, 3, 0, 36, 4, 67, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio masės debito skirtumas per valandą', 1006, 2, NULL, NULL),
	(213, 51, 0, 5, 2, 0, 35, 5, 68, NULL, 'Šilumnešio masės kiekis per parą', 1065, 3, NULL, NULL),
	(214, 51, 1, 5, 2, 0, 35, 5, 68, NULL, 'Tiekiamo šilumnešio masės kiekis per parą', 1065, 3, NULL, NULL),
	(215, 51, 2, 5, 2, 0, 35, 5, 68, NULL, 'Grįžtamo šilumnešio masės kiekis per parą', 1077, 3, NULL, NULL),
	(216, 51, 3, 5, 2, 0, 35, 5, 68, NULL, 'Tiekiamo ir grįžtamo šilumnešio masės kiekių skirtumas per parą', 1088, 3, NULL, NULL),
	(217, 51, 0, 5, 3, 0, 36, 5, 67, NULL, 'Vidutinis šilumnešio masės debitas per parą', 1715, 3, NULL, NULL),
	(218, 51, 1, 5, 3, 0, 36, 5, 67, NULL, 'Vidutinis tiekiamo šilumnešio masės debitas per parą', 1006, 3, NULL, NULL),
	(219, 51, 2, 5, 3, 0, 36, 5, 67, NULL, 'Vidutinis grįžtamo šilumnešio masės debitas per parą', 1732, 3, NULL, NULL),
	(220, 51, 3, 5, 3, 0, 36, 5, 67, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio masės debito skirtumas per parą', 1006, 3, NULL, NULL),
	(221, 51, 0, 6, 2, 0, 35, 6, 68, NULL, 'Šilumnešio masės kiekis per mėnesį', 1065, 4, NULL, NULL),
	(222, 51, 1, 6, 2, 0, 35, 6, 68, NULL, 'Tiekiamo šilumnešio masės kiekis per mėnesį', 1065, 4, NULL, NULL),
	(223, 51, 2, 6, 2, 0, 35, 6, 68, NULL, 'Grįžtamo šilumnešio masės kiekis per mėnesį', 1077, 4, NULL, NULL),
	(224, 51, 3, 6, 2, 0, 35, 6, 68, NULL, 'Tiekiamo ir grįžtamo šilumnešio masės kiekių skirtumas per mėnesį', 1088, 4, NULL, NULL),
	(225, 51, 0, 6, 3, 0, 36, 6, 67, NULL, 'Vidutinis šilumnešio masės debitas per mėnesį', 1715, 4, NULL, NULL),
	(226, 51, 1, 6, 3, 0, 36, 6, 67, NULL, 'Vidutinis tiekiamo šilumnešio masės debitas per mėnesį', 1006, 4, NULL, NULL),
	(227, 51, 2, 6, 3, 0, 36, 6, 67, NULL, 'Vidutinis grįžtamo šilumnešio masės debitas per mėnesį', 1732, 4, NULL, NULL),
	(228, 51, 3, 6, 3, 0, 36, 6, 67, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio masės debito skirtumas per mėnesį', 1006, 4, NULL, NULL),
	(229, 51, 0, 7, 1, 0, 36, 7, 67, NULL, 'Momentinis šilumnešio masės debitas', 1006, 6, NULL, NULL),
	(230, 51, 1, 7, 1, 0, 36, 7, 67, NULL, 'Momentinis tiekiamo šilumnešio masės debitas', 1006, 6, NULL, NULL),
	(231, 51, 2, 7, 1, 0, 36, 7, 67, NULL, 'Momentinis grįžtamo šilumnešio masės debitas', 1025, 6, NULL, NULL),
	(232, 51, 3, 7, 1, 0, 36, 7, 67, NULL, 'Momentinis tiekiamo ir grįžtamo šilumnešio masės debito skirtumas', 1042, 6, NULL, NULL),
	(233, 52, 0, 4, 3, 0, 28, 4, 69, NULL, 'Vidutinis šilumnešio slėgis per valandą', 1068, 2, NULL, NULL),
	(234, 52, 1, 4, 3, 0, 28, 4, 69, NULL, 'Vidutinis tiekiamo šilumnešio slėgis per valandą', 1068, 2, NULL, NULL),
	(235, 52, 2, 4, 3, 0, 28, 4, 69, NULL, 'Vidutinis grįžtamo šilumnešio slėgis per valandą', 1080, 2, NULL, NULL),
	(236, 52, 3, 4, 3, 0, 28, 4, 69, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio slėgių skirtumas per valandą', 1068, 2, NULL, NULL),
	(237, 52, 0, 5, 3, 0, 28, 5, 69, NULL, 'Vidutinis šilumnešio slėgis per parą', 1068, 3, NULL, NULL),
	(238, 52, 1, 5, 3, 0, 28, 5, 69, NULL, 'Vidutinis tiekiamo šilumnešio slėgis per parą', 1068, 3, NULL, NULL),
	(239, 52, 2, 5, 3, 0, 28, 5, 69, NULL, 'Vidutinis grįžtamo šilumnešio slėgis per parą', 1080, 3, NULL, NULL),
	(240, 52, 3, 5, 3, 0, 28, 5, 69, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio slėgių skirtumas per parą', 1068, 3, NULL, NULL),
	(241, 52, 0, 6, 3, 0, 28, 6, 69, NULL, 'Vidutinis šilumnešio slėgis per mėnesį', 1068, 4, NULL, NULL),
	(242, 52, 1, 6, 3, 0, 28, 6, 69, NULL, 'Vidutinis tiekiamo šilumnešio slėgis per mėnesį', 1068, 4, NULL, NULL),
	(243, 52, 2, 6, 3, 0, 28, 6, 69, NULL, 'Vidutinis grįžtamo šilumnešio slėgis per mėnesį', 1080, 4, NULL, NULL),
	(244, 52, 3, 6, 3, 0, 28, 6, 69, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio slėgių skirtumas per mėnesį', 1068, 4, NULL, NULL),
	(245, 52, 0, 7, 1, 0, 28, 7, 69, NULL, 'Momentinis šilumnešio slėgis', 1004, 6, NULL, NULL),
	(246, 52, 1, 7, 1, 0, 28, 7, 69, NULL, 'Momentinis tiekiamo šilumnešio slėgis', 1004, 6, NULL, NULL),
	(247, 52, 2, 7, 1, 0, 28, 7, 69, NULL, 'Momentinis grįžtamo šilumnešio slėgis', 1021, 6, NULL, NULL),
	(248, 52, 3, 7, 1, 0, 28, 7, 69, NULL, 'Momentinis tiekiamo ir grįžtamo šilumnešio slėgių skirtumas', 1068, 6, NULL, NULL),
	(249, 53, 0, 4, 3, 0, 1, 4, 70, NULL, 'Vidutinė šilumnešio šilumos galia per valandą', 1716, 2, NULL, NULL),
	(250, 53, 1, 4, 3, 0, 1, 4, 70, NULL, 'Vidutinė tiekiamo šilumnešio šilumos galia per valandą', 1002, 2, NULL, NULL),
	(251, 53, 2, 4, 3, 0, 1, 4, 70, NULL, 'Vidutinė grįžtamo šilumnešio šilumos galia per valandą', 1728, 2, NULL, NULL),
	(252, 53, 3, 4, 3, 0, 1, 4, 70, NULL, 'Vidutinė sunaudota šilumnešio šilumos galia per valandą', 1002, 2, NULL, NULL),
	(253, 53, 0, 5, 2, 0, 2, 5, 71, NULL, 'Šilumnešio šilumos kiekis per parą', 1064, 3, NULL, NULL),
	(254, 53, 1, 5, 2, 0, 2, 5, 71, NULL, 'Tiekiamo šilumnešio šilumos kiekis per parą', 1064, 3, NULL, NULL),
	(255, 53, 2, 5, 2, 0, 2, 5, 71, NULL, 'Grįžtamo šilumnešio šilumos kiekis per parą', 1076, 3, NULL, NULL),
	(256, 53, 3, 5, 2, 0, 2, 5, 71, NULL, 'Sunaudotos šilumnešio šilumos kiekis per parą', 1719, 3, NULL, NULL),
	(257, 53, 0, 5, 3, 0, 1, 5, 70, NULL, 'Vidutinė šilumnešio šilumos galia per parą', 1716, 3, NULL, NULL),
	(258, 53, 1, 5, 3, 0, 1, 5, 70, NULL, 'Vidutinė tiekiamo šilumnešio šilumos galia per parą', 1002, 3, NULL, NULL),
	(259, 53, 2, 5, 3, 0, 1, 5, 70, NULL, 'Vidutinė grįžtamo šilumnešio šilumos galia per parą', 1728, 3, NULL, NULL),
	(260, 53, 3, 5, 3, 0, 1, 5, 70, NULL, 'Vidutinė sunaudota šilumnešio šilumos galia per parą', 1002, 3, NULL, NULL),
	(261, 53, 0, 6, 2, 0, 2, 6, 71, NULL, 'Šilumnešio šilumos kiekis per mėnesį', 1064, 4, NULL, NULL),
	(262, 53, 1, 6, 2, 0, 2, 6, 71, NULL, 'Tiekiamo šilumnešio šilumos kiekis per mėnesį', 1064, 4, NULL, NULL),
	(263, 53, 2, 6, 2, 0, 2, 6, 71, NULL, 'Grįžtamo šilumnešio šilumos kiekis per mėnesį', 1076, 4, NULL, NULL),
	(264, 53, 3, 6, 2, 0, 2, 6, 71, NULL, 'Sunaudotos šilumnešio šilumos kiekis per mėnesį', 1719, 4, NULL, NULL),
	(265, 53, 0, 6, 3, 0, 1, 6, 70, NULL, 'Vidutinė šilumnešio šilumos galia per mėnesį', 1716, 4, NULL, NULL),
	(266, 53, 1, 6, 3, 0, 1, 6, 70, NULL, 'Vidutinė tiekiamo šilumnešio šilumos galia per mėnesį', 1002, 4, NULL, NULL),
	(267, 53, 2, 6, 3, 0, 1, 6, 70, NULL, 'Vidutinė grįžtamo šilumnešio šilumos galia per mėnesį', 1728, 4, NULL, NULL),
	(268, 53, 3, 6, 3, 0, 1, 6, 70, NULL, 'Vidutinė sunaudota šilumnešio šilumos galia per mėnesį', 1002, 4, NULL, NULL),
	(269, 53, 0, 7, 1, 0, 1, 7, 70, NULL, 'Momentinė šilumnešio šilumos galia', 1002, 6, NULL, NULL),
	(270, 53, 1, 7, 1, 0, 1, 7, 70, NULL, 'Momentinė tiekiamo šilumnešio šilumos galia', 1002, 6, NULL, NULL),
	(271, 53, 2, 7, 1, 0, 1, 7, 70, NULL, 'Momentinė grįžtamo šilumnešio šilumos galia', 1020, 6, NULL, NULL),
	(272, 53, 3, 7, 1, 0, 1, 7, 70, NULL, 'Momentinė sunaudota šilumnešio šilumos galia', 1043, 6, NULL, NULL),
	(273, 54, 0, 4, 3, 0, 27, 4, 72, NULL, 'Vidutinė šilumnešio temperatūra per valandą', 1067, 2, NULL, NULL),
	(274, 54, 1, 4, 3, 0, 27, 4, 72, NULL, 'Vidutinė tiekiamo šilumnešio temperatūra per valandą', 1067, 2, NULL, NULL),
	(275, 54, 2, 4, 3, 0, 27, 4, 72, NULL, 'Vidutinė grįžtamo šilumnešio temperatūra per valandą', 1079, 2, NULL, NULL),
	(276, 54, 3, 4, 3, 0, 27, 4, 72, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas per valandą', 1090, 2, NULL, NULL),
	(277, 54, 0, 5, 3, 0, 27, 5, 72, NULL, 'Vidutinė šilumnešio temperatūra per parą', 1067, 3, NULL, NULL),
	(278, 54, 1, 5, 3, 0, 27, 5, 72, NULL, 'Vidutinė tiekiamo šilumnešio temperatūra per parą', 1067, 3, NULL, NULL),
	(279, 54, 2, 5, 3, 0, 27, 5, 72, NULL, 'Vidutinė grįžtamo šilumnešio temperatūra per parą', 1079, 3, NULL, NULL),
	(280, 54, 3, 5, 3, 0, 27, 5, 72, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas per parą', 1090, 3, NULL, NULL),
	(281, 54, 0, 6, 3, 0, 27, 6, 72, NULL, 'Vidutinė šilumnešio temperatūra per mėnesį', 1067, 4, NULL, NULL),
	(282, 54, 1, 6, 3, 0, 27, 6, 72, NULL, 'Vidutinė tiekiamo šilumnešio temperatūra per mėnesį', 1067, 4, NULL, NULL),
	(283, 54, 2, 6, 3, 0, 27, 6, 72, NULL, 'Vidutinė grįžtamo šilumnešio temperatūra per mėnesį', 1079, 4, NULL, NULL),
	(284, 54, 3, 6, 3, 0, 27, 6, 72, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas per mėnesį', 1090, 4, NULL, NULL),
	(285, 54, 0, 7, 1, 0, 27, 7, 72, NULL, 'Momentinė šilumnešio temperatūra', 1003, 6, NULL, NULL),
	(286, 54, 1, 7, 1, 0, 27, 7, 72, NULL, 'Momentinė tiekiamo šilumnešio temperatūra', 1003, 6, NULL, NULL),
	(287, 54, 2, 7, 1, 0, 27, 7, 72, NULL, 'Momentinė grįžtamo šilumnešio temperatūra', 1008, 6, NULL, NULL),
	(288, 54, 3, 7, 1, 0, 27, 7, 72, NULL, 'Momentinis tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas', 1009, 6, NULL, NULL),
	(289, 55, 0, 4, 3, 0, 32, 4, 73, NULL, 'Vidutinis šilumnešio tūrio debitas per valandą', 1714, 2, NULL, NULL),
	(290, 55, 1, 4, 3, 0, 32, 4, 73, NULL, 'Vidutinis tiekiamo šilumnešio tūrio debitas per valandą', 1714, 2, NULL, NULL),
	(291, 55, 2, 4, 3, 0, 32, 4, 73, NULL, 'Vidutinis grįžtamo šilumnešio tūrio debitas per valandą', 1730, 2, NULL, NULL),
	(292, 55, 3, 4, 3, 0, 32, 4, 73, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio tūrio debito skirtumas per valandą', 1011, 2, NULL, NULL),
	(293, 55, 0, 5, 2, 0, 31, 5, 74, NULL, 'Šilumnešio tūrio kiekis per parą', 1066, 3, NULL, NULL),
	(294, 55, 1, 5, 2, 0, 31, 5, 74, NULL, 'Tiekiamo šilumnešio tūrio kiekis per parą', 1066, 3, NULL, NULL),
	(295, 55, 2, 5, 2, 0, 31, 5, 74, NULL, 'Grįžtamo šilumnešio tūrio kiekis per parą', 1078, 3, NULL, NULL),
	(296, 55, 3, 5, 2, 0, 31, 5, 74, NULL, 'Tiekiamo ir grįžtamo šilumnešio tūrio kiekių skirtumas per parą', 1737, 3, NULL, NULL),
	(297, 55, 0, 5, 3, 0, 32, 5, 73, NULL, 'Vidutinis šilumnešio tūrio debitas per parą', 1714, 3, NULL, NULL),
	(298, 55, 1, 5, 3, 0, 32, 5, 73, NULL, 'Vidutinis tiekiamo šilumnešio tūrio debitas per parą', 1714, 3, NULL, NULL),
	(299, 55, 2, 5, 3, 0, 32, 5, 73, NULL, 'Vidutinis grįžtamo šilumnešio tūrio debitas per parą', 1730, 3, NULL, NULL),
	(300, 55, 3, 5, 3, 0, 32, 5, 73, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio tūrio debito skirtumas per parą', 1011, 3, NULL, NULL),
	(301, 55, 0, 6, 2, 0, 31, 6, 74, NULL, 'Šilumnešio tūrio kiekis per mėnesį', 1066, 4, NULL, NULL),
	(302, 55, 1, 6, 2, 0, 31, 6, 74, NULL, 'Tiekiamo šilumnešio tūrio kiekis per mėnesį', 1066, 4, NULL, NULL),
	(303, 55, 2, 6, 2, 0, 31, 6, 74, NULL, 'Grįžtamo šilumnešio tūrio kiekis per mėnesį', 1078, 4, NULL, NULL),
	(304, 55, 3, 6, 2, 0, 31, 6, 74, NULL, 'Tiekiamo ir grįžtamo šilumnešio tūrio kiekių skirtumas per mėnesį', 1737, 4, NULL, NULL),
	(305, 55, 0, 6, 3, 0, 32, 6, 73, NULL, 'Vidutinis šilumnešio tūrio debitas per mėnesį', 1714, 4, NULL, NULL),
	(306, 55, 1, 6, 3, 0, 32, 6, 73, NULL, 'Vidutinis tiekiamo šilumnešio tūrio debitas per mėnesį', 1714, 4, NULL, NULL),
	(307, 55, 2, 6, 3, 0, 32, 6, 73, NULL, 'Vidutinis grįžtamo šilumnešio tūrio debitas per mėnesį', 1730, 4, NULL, NULL),
	(308, 55, 3, 6, 3, 0, 32, 6, 73, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio tūrio debito skirtumas per mėnesį', 1011, 4, NULL, NULL),
	(309, 55, 0, 7, 1, 0, 32, 7, 73, NULL, 'Momentinis šilumnešio tūrio debitas', 1011, 6, NULL, NULL),
	(310, 55, 1, 7, 1, 0, 32, 7, 73, NULL, 'Momentinis tiekiamo šilumnešio tūrio debitas', 1011, 6, NULL, NULL),
	(311, 55, 2, 7, 1, 0, 32, 7, 73, NULL, 'Momentinis grįžtamo šilumnešio tūrio debitas', 1023, 6, NULL, NULL),
	(312, 55, 3, 7, 1, 0, 32, 7, 73, NULL, 'Momentinis tiekiamo ir grįžtamo šilumnešio tūrio debito skirtumas', 1011, 6, NULL, NULL),
	(313, 56, 0, 4, 3, 0, 33, 4, 57, NULL, 'Vidutinė šalto vandens šilumos galia per valandą', 1232, 2, NULL, NULL),
	(314, 56, 1, 4, 3, 0, 33, 4, 57, NULL, 'Vidutinė tiekiamo šalto vandens šilumos galia per valandą', 1232, 2, NULL, NULL),
	(315, 56, 2, 4, 3, 0, 33, 4, 57, NULL, 'Vidutinė grįžtamo šalto vandens šilumos galia per valandą', 1234, 2, NULL, NULL),
	(316, 56, 3, 4, 3, 0, 33, 4, 57, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens šilumos galių skirtumas per valandą', 1236, 2, NULL, NULL),
	(317, 56, 0, 5, 2, 0, 34, 5, 56, NULL, 'Šalto vandens šilumos kiekis per parą', 1212, 3, NULL, NULL),
	(318, 56, 1, 5, 2, 0, 34, 5, 56, NULL, 'Tiekiamo šalto vandens šilumos kiekis per parą', 1212, 3, NULL, NULL),
	(319, 56, 2, 5, 2, 0, 34, 5, 56, NULL, 'Grįžtamo šalto vandens šilumos kiekis per parą', 1238, 3, NULL, NULL),
	(320, 56, 3, 5, 2, 0, 34, 5, 56, NULL, 'Tiekiamo ir grįžtamo šalto vandens šilumos kiekių skirtumas per parą', 1240, 3, NULL, NULL),
	(321, 56, 0, 5, 3, 0, 33, 5, 57, NULL, 'Vidutinė šalto vandens šilumos galia per parą', 1232, 3, NULL, NULL),
	(322, 56, 1, 5, 3, 0, 33, 5, 57, NULL, 'Vidutinė tiekiamo šalto vandens šilumos galia per parą', 1232, 3, NULL, NULL),
	(323, 56, 2, 5, 3, 0, 33, 5, 57, NULL, 'Vidutinė grįžtamo šalto vandens šilumos galia per parą', 1234, 3, NULL, NULL),
	(324, 56, 3, 5, 3, 0, 33, 5, 57, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens šilumos galių skirtumas per parą', 1236, 3, NULL, NULL),
	(325, 56, 0, 6, 2, 0, 34, 6, 56, NULL, 'Šalto vandens šilumos kiekis per mėnesį', 1212, 4, NULL, NULL),
	(326, 56, 1, 6, 2, 0, 34, 6, 56, NULL, 'Tiekiamo šalto vandens šilumos kiekis per mėnesį', 1212, 4, NULL, NULL),
	(327, 56, 2, 6, 2, 0, 34, 6, 56, NULL, 'Grįžtamo šalto vandens šilumos kiekis per mėnesį', 1238, 4, NULL, NULL),
	(328, 56, 3, 6, 2, 0, 34, 6, 56, NULL, 'Tiekiamo ir grįžtamo šalto vandens šilumos kiekių skirtumas per mėnesį', 1240, 4, NULL, NULL),
	(329, 56, 0, 6, 3, 0, 33, 6, 57, NULL, 'Vidutinė šalto vandens šilumos galia per mėnesį', 1232, 4, NULL, NULL),
	(330, 56, 1, 6, 3, 0, 33, 6, 57, NULL, 'Vidutinė tiekiamo šalto vandens šilumos galia per mėnesį', 1232, 4, NULL, NULL),
	(331, 56, 2, 6, 3, 0, 33, 6, 57, NULL, 'Vidutinė grįžtamo šalto vandens šilumos galia per mėnesį', 1234, 4, NULL, NULL),
	(332, 56, 3, 6, 3, 0, 33, 6, 57, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens šilumos galių skirtumas per mėnesį', 1236, 4, NULL, NULL),
	(333, 56, 0, 7, 1, 0, 33, 7, 57, NULL, 'Momentinė šalto vandens šilumos galia', 1206, 6, NULL, NULL),
	(334, 56, 1, 7, 1, 0, 33, 7, 57, NULL, 'Momentinė tiekiamo šalto vandens šilumos galia', 1206, 6, NULL, NULL),
	(335, 56, 2, 7, 1, 0, 33, 7, 57, NULL, 'Momentinė grįžtamo šalto vandens šilumos galia', 1233, 6, NULL, NULL),
	(336, 56, 3, 7, 1, 0, 33, 7, 57, NULL, 'Momentinis tiekiamo ir grįžtamo šalto vandens šilumos galių skirtumas', 1235, 6, NULL, NULL),
	(337, 57, 0, 4, 3, 0, 27, 4, 58, NULL, 'Vidutinė šalto vandens temperatūra per valandą', 1215, 2, NULL, NULL),
	(338, 57, 1, 4, 3, 0, 27, 4, 58, NULL, 'Vidutinė tiekiamo šalto vandens temperatūra per valandą', 1215, 2, NULL, NULL),
	(339, 57, 2, 4, 3, 0, 27, 4, 58, NULL, 'Vidutinė grįžtamo šalto vandens temperatūra per valandą', 1256, 2, NULL, NULL),
	(340, 57, 3, 4, 3, 0, 27, 4, 58, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens temperatūrų skirtumas per valandą', 1257, 2, NULL, NULL),
	(341, 57, 0, 5, 3, 0, 27, 5, 58, NULL, 'Vidutinė šalto vandens temperatūra per parą', 1215, 3, NULL, NULL),
	(342, 57, 1, 5, 3, 0, 27, 5, 58, NULL, 'Vidutinė tiekiamo šalto vandens temperatūra per parą', 1215, 3, NULL, NULL),
	(343, 57, 2, 5, 3, 0, 27, 5, 58, NULL, 'Vidutinė grįžtamo šalto vandens temperatūra per parą', 1256, 3, NULL, NULL),
	(344, 57, 3, 5, 3, 0, 27, 5, 58, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens temperatūrų skirtumas per parą', 1257, 3, NULL, NULL),
	(345, 57, 0, 6, 3, 0, 27, 6, 58, NULL, 'Vidutinė šalto vandens temperatūra per mėnesį', 1215, 4, NULL, NULL),
	(346, 57, 1, 6, 3, 0, 27, 6, 58, NULL, 'Vidutinė tiekiamo šalto vandens temperatūra per mėnesį', 1215, 4, NULL, NULL),
	(347, 57, 2, 6, 3, 0, 27, 6, 58, NULL, 'Vidutinė grįžtamo šalto vandens temperatūra per mėnesį', 1256, 4, NULL, NULL),
	(348, 57, 3, 6, 3, 0, 27, 6, 58, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens temperatūrų skirtumas per mėnesį', 1257, 4, NULL, NULL),
	(349, 57, 0, 7, 1, 0, 27, 7, 58, NULL, 'Momentinė šalto vandens temperatūra', 1203, 6, NULL, NULL),
	(350, 57, 1, 7, 1, 0, 27, 7, 58, NULL, 'Momentinė tiekiamo šalto vandens temperatūra', 1203, 6, NULL, NULL),
	(351, 57, 2, 7, 1, 0, 27, 7, 58, NULL, 'Momentinė grįžtamo šalto vandens temperatūra', 1207, 6, NULL, NULL),
	(352, 57, 3, 7, 1, 0, 27, 7, 58, NULL, 'Momentinis tiekiamo ir grįžtamo šalto vandens temperatūrų skirtumas', 1208, 6, NULL, NULL),
	(353, 58, 0, 4, 3, 0, 32, 4, 60, NULL, 'Vidutinis šalto vandens tūrio debitas per valandą', 1260, 2, NULL, NULL),
	(354, 58, 1, 4, 3, 0, 32, 4, 60, NULL, 'Vidutinis tiekiamo šalto vandens tūrio debitas per valandą', 1260, 2, NULL, NULL),
	(355, 58, 2, 4, 3, 0, 32, 4, 60, NULL, 'Vidutinis grįžtamo šalto vandens tūrio debitas per valandą', 1262, 2, NULL, NULL),
	(356, 58, 3, 4, 3, 0, 32, 4, 60, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens tūrio debito skirtumas per valandą', 1260, 2, NULL, NULL),
	(357, 58, 0, 5, 2, 0, 31, 5, 59, NULL, 'Šalto vandens tūrio kiekis per parą', 1214, 3, NULL, NULL),
	(358, 58, 1, 5, 2, 0, 31, 5, 59, NULL, 'Tiekiamo šalto vandens tūrio kiekis per parą', 1214, 3, NULL, NULL),
	(359, 58, 2, 5, 2, 0, 31, 5, 59, NULL, 'Grįžtamo šalto vandens tūrio kiekis per parą', 1259, 3, NULL, NULL),
	(360, 58, 3, 5, 2, 0, 31, 5, 59, NULL, 'Tiekiamo ir grįžtamo šalto vandens tūrio kiekių skirtumas per parą', 1214, 3, NULL, NULL),
	(361, 58, 0, 5, 3, 0, 32, 5, 60, NULL, 'Vidutinis šalto vandens tūrio debitas per parą', 1260, 3, NULL, NULL),
	(362, 58, 1, 5, 3, 0, 32, 5, 60, NULL, 'Vidutinis tiekiamo šalto vandens tūrio debitas per parą', 1260, 3, NULL, NULL),
	(363, 58, 2, 5, 3, 0, 32, 5, 60, NULL, 'Vidutinis grįžtamo šalto vandens tūrio debitas per parą', 1262, 3, NULL, NULL),
	(364, 58, 3, 5, 3, 0, 32, 5, 60, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens tūrio debito skirtumas per parą', 1260, 3, NULL, NULL),
	(365, 58, 0, 6, 2, 0, 31, 6, 59, NULL, 'Šalto vandens tūrio kiekis per mėnesį', 1214, 4, NULL, NULL),
	(366, 58, 1, 6, 2, 0, 31, 6, 59, NULL, 'Tiekiamo šalto vandens tūrio kiekis per mėnesį', 1214, 4, NULL, NULL),
	(367, 58, 2, 6, 2, 0, 31, 6, 59, NULL, 'Grįžtamo šalto vandens tūrio kiekis per mėnesį', 1259, 4, NULL, NULL),
	(368, 58, 3, 6, 2, 0, 31, 6, 59, NULL, 'Tiekiamo ir grįžtamo šalto vandens tūrio kiekių skirtumas per mėnesį', 1214, 4, NULL, NULL),
	(369, 58, 0, 6, 3, 0, 32, 6, 60, NULL, 'Vidutinis šalto vandens tūrio debitas per mėnesį', 1260, 4, NULL, NULL),
	(370, 58, 1, 6, 3, 0, 32, 6, 60, NULL, 'Vidutinis tiekiamo šalto vandens tūrio debitas per mėnesį', 1260, 4, NULL, NULL),
	(371, 58, 2, 6, 3, 0, 32, 6, 60, NULL, 'Vidutinis grįžtamo šalto vandens tūrio debitas per mėnesį', 1262, 4, NULL, NULL),
	(372, 58, 3, 6, 3, 0, 32, 6, 60, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens tūrio debito skirtumas per mėnesį', 1260, 4, NULL, NULL),
	(373, 58, 0, 7, 1, 0, 32, 7, 60, NULL, 'Momentinis šalto vandens tūrio debitas', 1202, 6, NULL, NULL),
	(374, 58, 1, 7, 1, 0, 32, 7, 60, NULL, 'Momentinis tiekiamo šalto vandens tūrio debitas', 1202, 6, NULL, NULL),
	(375, 58, 2, 7, 1, 0, 32, 7, 60, NULL, 'Momentinis grįžtamo šalto vandens tūrio debitas', 1261, 6, NULL, NULL),
	(376, 58, 3, 7, 1, 0, 32, 7, 60, NULL, 'Momentinis tiekiamo ir grįžtamo šalto vandens tūrio debito skirtumas', 1202, 6, NULL, NULL),
	(377, 1, 1, 4, 3, 0, 1, 4, 13, '1.0.1.29.0.0', 'Vidutinė P+ galia per valandą', 49, 2, NULL, NULL),
	(378, 1, 2, 4, 3, 0, 1, 4, 13, '1.0.2.29.0.0', 'Vidutinė P- galia per valandą', 50, 2, NULL, NULL),
	(379, 3, 1, 4, 3, 0, 3, 4, 16, '1.0.3.29.0.0', 'Vidutinė Q+ galia per valandą', 51, 2, NULL, NULL),
	(380, 3, 2, 4, 3, 0, 3, 4, 16, '1.0.4.29.0.0', 'Vidutinė Q- galia per valandą', 52, 2, NULL, NULL),
	(381, 1, 1, 6, 2, 0, 2, 6, 14, NULL, 'A+ energija per mėnesį', 120, 4, NULL, NULL),
	(382, 1, 2, 6, 2, 0, 2, 6, 14, NULL, 'A- energija per mėnesį', 121, 4, NULL, NULL),
	(383, 3, 1, 6, 2, 0, 4, 6, 15, NULL, 'R+ energija per mėnesį', 122, 4, NULL, NULL),
	(384, 3, 2, 6, 2, 0, 4, 6, 15, NULL, 'R- energija per mėnesį', 123, 4, NULL, NULL),
	(385, 1, 1, 5, 2, 0, 2, 5, 14, NULL, 'A+ energija per parą', 126, 3, NULL, NULL),
	(386, 1, 2, 5, 2, 0, 2, 5, 14, NULL, 'A- energija per parą', 127, 3, NULL, NULL),
	(387, 3, 1, 5, 2, 0, 4, 5, 15, NULL, 'R+ energija per parą', 128, 3, NULL, NULL),
	(388, 3, 2, 5, 2, 0, 4, 5, 15, NULL, 'R- energija per parą', 129, 3, NULL, NULL),
	(389, 1, 1, 5, 3, 0, 1, 5, 13, NULL, 'Vidutinė P+ galia per parą', 49, 3, NULL, NULL),
	(390, 1, 2, 5, 3, 0, 1, 5, 13, NULL, 'Vidutinė P- galia per parą', 50, 3, NULL, NULL),
	(391, 3, 1, 5, 3, 0, 3, 5, 16, NULL, 'Vidutinė Q+ galia per parą', 51, 3, NULL, NULL),
	(392, 3, 2, 5, 3, 0, 3, 5, 16, NULL, 'Vidutinė Q- galia per parą', 52, 3, NULL, NULL),
	(393, 39, 0, 1, 2, 0, 35, 1, 2, NULL, 'Dujų koreguotos masės kiekis per minutę', 1130, 1, NULL, NULL),
	(394, 39, 0, 1, 3, 0, 36, 1, 1, NULL, 'Vidutinis dujų koreguotos masės debitas per minutę', 1135, 1, NULL, NULL),
	(395, 40, 0, 1, 2, 0, 31, 1, 4, NULL, 'Dujų koreguoto tūrio kiekis per minutę', 1131, 1, NULL, NULL),
	(396, 40, 0, 1, 3, 0, 32, 1, 3, NULL, 'Vidutinis dujų koreguoto tūrio debitas per minutę', 1137, 1, NULL, NULL),
	(397, 41, 0, 1, 2, 0, 35, 1, 6, NULL, 'Dujų masės kiekis per minutę', 1128, 1, NULL, NULL),
	(398, 41, 0, 1, 3, 0, 36, 1, 5, NULL, 'Vidutinis dujų masės debitas per minutę', 1134, 1, NULL, NULL),
	(399, 42, 0, 1, 3, 0, 28, 1, 7, NULL, 'Vidutinis dujų slėgis per minutę', 1138, 1, NULL, NULL),
	(400, 43, 0, 1, 2, 0, 34, 1, 9, NULL, 'Dujų šilumos kiekis per minutę', 1127, 1, NULL, NULL),
	(401, 43, 0, 1, 3, 0, 33, 1, 8, NULL, 'Vidutinė dujų šilumos galia per minutę', 1132, 1, NULL, NULL),
	(402, 44, 0, 1, 3, 0, 27, 1, 10, NULL, 'Vidutinė dujų temperatūra per minutę', 1133, 1, NULL, NULL),
	(403, 45, 0, 1, 2, 0, 31, 1, 12, NULL, 'Dujų tūrio kiekis per minutę', 1129, 1, NULL, NULL),
	(404, 45, 0, 1, 3, 0, 32, 1, 11, NULL, 'Vidutinis dujų tūrio debitas per minutę', 1136, 1, NULL, NULL),
	(405, 46, 0, 1, 3, 0, 27, 1, 55, NULL, 'Vidutinė oro temperatūra per minutę', 1302, 1, NULL, NULL),
	(406, 47, 0, 1, 3, 0, 30, 1, 61, NULL, 'Vidutinis šalčio slėgis per minutę', 1004, 1, NULL, NULL),
	(407, 47, 1, 1, 3, 0, 30, 1, 61, NULL, 'Vidutinis tiekiamo šalčio slėgis per minutę', 1004, 1, NULL, NULL),
	(408, 47, 2, 1, 3, 0, 30, 1, 61, NULL, 'Vidutinis grįžtamo šalčio slėgis per minutę', 1004, 1, NULL, NULL),
	(409, 47, 3, 1, 3, 0, 30, 1, 61, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio slėgio skirtumas per minutę', 1004, 1, NULL, NULL),
	(410, 48, 0, 1, 2, 0, 2, 1, 62, NULL, 'Šalčio energija per minutę', 1001, 1, NULL, NULL),
	(411, 48, 1, 1, 2, 0, 2, 1, 62, NULL, 'Tiekiamo šalčio energija per minutę', 1001, 1, NULL, NULL),
	(412, 48, 2, 1, 2, 0, 2, 1, 62, NULL, 'Grįžtamo šalčio energija per minutę', 1001, 1, NULL, NULL),
	(413, 48, 3, 1, 2, 0, 2, 1, 62, NULL, 'Tiekiamo ir grįžtamo šalčio šilumos kiekių skirtumas per minutę', 1001, 1, NULL, NULL),
	(414, 48, 0, 1, 3, 0, 1, 1, 63, NULL, 'Vidutinė šalčio galia per minutę', 1002, 1, NULL, NULL),
	(415, 48, 1, 1, 3, 0, 1, 1, 63, NULL, 'Vidutinė tiekiamo šalčio galia per minutę', 1002, 1, NULL, NULL),
	(416, 48, 2, 1, 3, 0, 1, 1, 63, NULL, 'Vidutinė grįžtamo šalčio galia per minutę', 1002, 1, NULL, NULL),
	(417, 48, 3, 1, 3, 0, 1, 1, 63, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio šilumos galios skirtumas per minutę', 1002, 1, NULL, NULL),
	(418, 49, 0, 1, 3, 0, 27, 1, 64, NULL, 'Vidutinė šalčio temperatūra per minutę', 1003, 1, NULL, NULL),
	(419, 49, 1, 1, 3, 0, 27, 1, 64, NULL, 'Vidutinė tiekiamo šalčio temperatūra per minutę', 1003, 1, NULL, NULL),
	(420, 49, 2, 1, 3, 0, 27, 1, 64, NULL, 'Vidutinė grįžtamo šalčio temperatūra per minutę', 1008, 1, NULL, NULL),
	(421, 49, 3, 1, 3, 0, 27, 1, 64, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio temperatūrų skirtumas per minutę', 1009, 1, NULL, NULL),
	(422, 50, 0, 1, 2, 0, 31, 1, 66, NULL, 'Šalčio tūrio kiekis per minutę', 1010, 1, NULL, NULL),
	(423, 50, 1, 1, 2, 0, 31, 1, 66, NULL, 'Tiekiamo šalčio tūrio kiekis per minutę', 1010, 1, NULL, NULL),
	(424, 50, 2, 1, 2, 0, 31, 1, 66, NULL, 'Grįžtamo šalčio tūrio kiekis per minutę', 1010, 1, NULL, NULL),
	(425, 50, 3, 1, 2, 0, 31, 1, 66, NULL, 'Tiekiamo ir grįžtamo šalčio tūrio kiekių skirtumas per minutę', 1010, 1, NULL, NULL),
	(426, 50, 0, 1, 3, 0, 32, 1, 65, NULL, 'Vidutinis šalčio tūrio debitas per minutę', 1011, 1, NULL, NULL),
	(427, 50, 1, 1, 3, 0, 32, 1, 65, NULL, 'Vidutinis tiekiamo šalčio tūrio debitas per minutę', 1011, 1, NULL, NULL),
	(428, 50, 2, 1, 3, 0, 32, 1, 65, NULL, 'Vidutinis grįžtamo šalčio tūrio debitas per minutę', 1011, 1, NULL, NULL),
	(429, 50, 3, 1, 3, 0, 32, 1, 65, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio tūrio debito skirtumas per minutę', 1011, 1, NULL, NULL),
	(430, 51, 0, 1, 2, 0, 35, 1, 68, NULL, 'Šilumnešio masės kiekis per minutę', 1065, 1, NULL, NULL),
	(431, 51, 1, 1, 2, 0, 35, 1, 68, NULL, 'Tiekiamo šilumnešio masės kiekis per minutę', 1065, 1, NULL, NULL),
	(432, 51, 2, 1, 2, 0, 35, 1, 68, NULL, 'Grįžtamo šilumnešio masės kiekis per minutę', 1077, 1, NULL, NULL),
	(433, 51, 3, 1, 2, 0, 35, 1, 68, NULL, 'Tiekiamo ir grįžtamo šilumnešio masės kiekių skirtumas per minutę', 1088, 1, NULL, NULL),
	(434, 51, 0, 1, 3, 0, 36, 1, 67, NULL, 'Vidutinis šilumnešio masės debitas per minutę', 1715, 1, NULL, NULL),
	(435, 51, 1, 1, 3, 0, 36, 1, 67, NULL, 'Vidutinis tiekiamo šilumnešio masės debitas per minutę', 1006, 1, NULL, NULL),
	(436, 51, 2, 1, 3, 0, 36, 1, 67, NULL, 'Vidutinis grįžtamo šilumnešio masės debitas per minutę', 1732, 1, NULL, NULL),
	(437, 51, 3, 1, 3, 0, 36, 1, 67, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio masės debito skirtumas per minutę', 1006, 1, NULL, NULL),
	(438, 52, 0, 1, 3, 0, 28, 1, 69, NULL, 'Vidutinis šilumnešio slėgis per minutę', 1068, 1, NULL, NULL),
	(439, 52, 1, 1, 3, 0, 28, 1, 69, NULL, 'Vidutinis tiekiamo šilumnešio slėgis per minutę', 1068, 1, NULL, NULL),
	(440, 52, 2, 1, 3, 0, 28, 1, 69, NULL, 'Vidutinis grįžtamo šilumnešio slėgis per minutę', 1080, 1, NULL, NULL),
	(441, 52, 3, 1, 3, 0, 28, 1, 69, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio slėgių skirtumas per minutę', 1068, 1, NULL, NULL),
	(442, 53, 0, 1, 2, 0, 2, 1, 71, NULL, 'Šilumnešio šilumos kiekis per minutę', 1064, 1, NULL, NULL),
	(443, 53, 1, 1, 2, 0, 2, 1, 71, NULL, 'Tiekiamo šilumnešio šilumos kiekis per minutę', 1064, 1, NULL, NULL),
	(444, 53, 2, 1, 2, 0, 2, 1, 71, NULL, 'Grįžtamo šilumnešio šilumos kiekis per minutę', 1076, 1, NULL, NULL),
	(445, 53, 3, 1, 2, 0, 2, 1, 71, NULL, 'Sunaudotos šilumnešio šilumos kiekis per minutę', 1719, 1, NULL, NULL),
	(446, 53, 0, 1, 3, 0, 1, 1, 70, NULL, 'Vidutinė šilumnešio šilumos galia per minutę', 1716, 1, NULL, NULL),
	(447, 53, 1, 1, 3, 0, 1, 1, 70, NULL, 'Vidutinė tiekiamo šilumnešio šilumos galia per minutę', 1002, 1, NULL, NULL),
	(448, 53, 2, 1, 3, 0, 1, 1, 70, NULL, 'Vidutinė grįžtamo šilumnešio šilumos galia per minutę', 1728, 1, NULL, NULL),
	(449, 53, 3, 1, 3, 0, 1, 1, 70, NULL, 'Vidutinė sunaudota šilumnešio šilumos galia per minutę', 1002, 1, NULL, NULL),
	(450, 58, 0, 1, 2, 0, 31, 1, 59, NULL, 'Šalto vandens tūrio kiekis per minutę', 1214, 1, NULL, NULL),
	(451, 58, 1, 1, 2, 0, 31, 1, 59, NULL, 'Tiekiamo šalto vandens tūrio kiekis per minutę', 1214, 1, NULL, NULL),
	(452, 58, 2, 1, 2, 0, 31, 1, 59, NULL, 'Grįžtamo šalto vandens tūrio kiekis per minutę', 1259, 1, NULL, NULL),
	(453, 58, 3, 1, 2, 0, 31, 1, 59, NULL, 'Tiekiamo ir grįžtamo šalto vandens tūrio kiekių skirtumas per minutę', 1214, 1, NULL, NULL),
	(454, 58, 0, 1, 3, 0, 32, 1, 60, NULL, 'Vidutinis šalto vandens tūrio debitas per minutę', 1260, 1, NULL, NULL),
	(455, 58, 1, 1, 3, 0, 32, 1, 60, NULL, 'Vidutinis tiekiamo šalto vandens tūrio debitas per minutę', 1260, 1, NULL, NULL),
	(456, 58, 2, 1, 3, 0, 32, 1, 60, NULL, 'Vidutinis grįžtamo šalto vandens tūrio debitas per minutę', 1262, 1, NULL, NULL),
	(457, 58, 3, 1, 3, 0, 32, 1, 60, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens tūrio debito skirtumas per minutę', 1260, 1, NULL, NULL),
	(458, 1, 1, 1, 2, 0, 2, 1, 14, NULL, 'A+ energija per minutę', 709, 1, NULL, NULL),
	(459, 1, 2, 1, 2, 0, 2, 1, 14, NULL, 'A- energija per minutę', 710, 1, NULL, NULL),
	(460, 3, 1, 1, 2, 0, 4, 1, 15, NULL, 'R+ energija per minutę', 711, 1, NULL, NULL),
	(461, 3, 2, 1, 2, 0, 4, 1, 15, NULL, 'R- energija per minutę', 712, 1, NULL, NULL),
	(462, 1, 1, 1, 3, 0, 1, 1, 13, '1.0.1.29.0.0', 'Vidutinė P+ galia per minutę', 49, 1, NULL, NULL),
	(463, 1, 2, 1, 3, 0, 1, 1, 13, '1.0.2.29.0.0', 'Vidutinė P- galia per minutę', 50, 1, NULL, NULL),
	(464, 3, 1, 1, 3, 0, 3, 1, 16, '1.0.3.29.0.0', 'Vidutinė Q+ galia per minutę', 51, 1, NULL, NULL),
	(465, 3, 2, 1, 3, 0, 3, 1, 16, '1.0.4.29.0.0', 'Vidutinė Q- galia per minutę', 52, 1, NULL, NULL),
	(466, 54, 0, 1, 3, 0, 27, 1, 72, NULL, 'Vidutinė šilumnešio temperatūra per minutę', 1067, 1, NULL, NULL),
	(467, 54, 1, 1, 3, 0, 27, 1, 72, NULL, 'Vidutinė tiekiamo šilumnešio temperatūra per minutę', 1067, 1, NULL, NULL),
	(468, 54, 2, 1, 3, 0, 27, 1, 72, NULL, 'Vidutinė grįžtamo šilumnešio temperatūra per minutę', 1079, 1, NULL, NULL),
	(469, 54, 3, 1, 3, 0, 27, 1, 72, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas per minutę', 1090, 1, NULL, NULL),
	(470, 55, 0, 1, 2, 0, 31, 1, 74, NULL, 'Šilumnešio tūrio kiekis per minutę', 1066, 1, NULL, NULL),
	(471, 55, 1, 1, 2, 0, 31, 1, 74, NULL, 'Tiekiamo šilumnešio tūrio kiekis per minutę', 1066, 1, NULL, NULL),
	(472, 55, 2, 1, 2, 0, 31, 1, 74, NULL, 'Grįžtamo šilumnešio tūrio kiekis per minutę', 1078, 1, NULL, NULL),
	(473, 55, 3, 1, 2, 0, 31, 1, 74, NULL, 'Tiekiamo ir grįžtamo šilumnešio tūrio kiekių skirtumas per minutę', 1737, 1, NULL, NULL),
	(474, 55, 0, 1, 3, 0, 32, 1, 73, NULL, 'Vidutinis šilumnešio tūrio debitas per minutę', 1714, 1, NULL, NULL),
	(475, 55, 1, 1, 3, 0, 32, 1, 73, NULL, 'Vidutinis tiekiamo šilumnešio tūrio debitas per minutę', 1714, 1, NULL, NULL),
	(476, 55, 2, 1, 3, 0, 32, 1, 73, NULL, 'Vidutinis grįžtamo šilumnešio tūrio debitas per minutę', 1730, 1, NULL, NULL),
	(477, 55, 3, 1, 3, 0, 32, 1, 73, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio tūrio debito skirtumas per minutę', 1011, 1, NULL, NULL),
	(478, 56, 0, 1, 2, 0, 34, 1, 56, NULL, 'Šalto vandens šilumos kiekis per minutę', 1212, 1, NULL, NULL),
	(479, 56, 1, 1, 2, 0, 34, 1, 56, NULL, 'Tiekiamo šalto vandens šilumos kiekis per minutę', 1212, 1, NULL, NULL),
	(480, 56, 2, 1, 2, 0, 34, 1, 56, NULL, 'Grįžtamo šalto vandens šilumos kiekis per minutę', 1238, 1, NULL, NULL),
	(481, 56, 3, 1, 2, 0, 34, 1, 56, NULL, 'Tiekiamo ir grįžtamo šalto vandens šilumos kiekių skirtumas per minutę', 1240, 1, NULL, NULL),
	(482, 56, 0, 1, 3, 0, 33, 1, 57, NULL, 'Vidutinė šalto vandens šilumos galia per minutę', 1232, 1, NULL, NULL),
	(483, 56, 1, 1, 3, 0, 33, 1, 57, NULL, 'Vidutinė tiekiamo šalto vandens šilumos galia per minutę', 1232, 1, NULL, NULL),
	(484, 56, 2, 1, 3, 0, 33, 1, 57, NULL, 'Vidutinė grįžtamo šalto vandens šilumos galia per minutę', 1234, 1, NULL, NULL),
	(485, 56, 3, 1, 3, 0, 33, 1, 57, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens šilumos galių skirtumas per minutę', 1236, 1, NULL, NULL),
	(486, 57, 0, 1, 3, 0, 27, 1, 58, NULL, 'Vidutinė šalto vandens temperatūra per minutę', 1215, 1, NULL, NULL),
	(487, 57, 1, 1, 3, 0, 27, 1, 58, NULL, 'Vidutinė tiekiamo šalto vandens temperatūra per minutę', 1215, 1, NULL, NULL),
	(488, 57, 2, 1, 3, 0, 27, 1, 58, NULL, 'Vidutinė grįžtamo šalto vandens temperatūra per minutę', 1256, 1, NULL, NULL),
	(489, 57, 3, 1, 3, 0, 27, 1, 58, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens temperatūrų skirtumas per minutę', 1257, 1, NULL, NULL),
	(490, 39, 0, 2, 2, 0, 35, 2, 2, NULL, 'Dujų koreguotos masės kiekis per 2 minutes', 1130, 1, NULL, NULL),
	(491, 39, 0, 2, 3, 0, 36, 2, 1, NULL, 'Vidutinis dujų koreguotos masės debitas per 2 minutes', 1135, 1, NULL, NULL),
	(492, 40, 0, 2, 2, 0, 31, 2, 4, NULL, 'Dujų koreguoto tūrio kiekis per 2 minutes', 1131, 1, NULL, NULL),
	(493, 40, 0, 2, 3, 0, 32, 2, 3, NULL, 'Vidutinis dujų koreguoto tūrio debitas per 2 minutes', 1137, 1, NULL, NULL),
	(494, 41, 0, 2, 2, 0, 35, 2, 6, NULL, 'Dujų masės kiekis per 2 minutes', 1128, 1, NULL, NULL),
	(495, 41, 0, 2, 3, 0, 36, 2, 5, NULL, 'Vidutinis dujų masės debitas per 2 minutes', 1134, 1, NULL, NULL),
	(496, 42, 0, 2, 3, 0, 28, 2, 7, NULL, 'Vidutinis dujų slėgis per 2 minutes', 1138, 1, NULL, NULL),
	(497, 43, 0, 2, 2, 0, 34, 2, 9, NULL, 'Dujų šilumos kiekis per 2 minutes', 1127, 1, NULL, NULL),
	(498, 43, 0, 2, 3, 0, 33, 2, 8, NULL, 'Vidutinė dujų šilumos galia per 2 minutes', 1132, 1, NULL, NULL),
	(499, 44, 0, 2, 3, 0, 27, 2, 10, NULL, 'Vidutinė dujų temperatūra per 2 minutes', 1133, 1, NULL, NULL),
	(500, 45, 0, 2, 2, 0, 31, 2, 12, NULL, 'Dujų tūrio kiekis per 2 minutes', 1129, 1, NULL, NULL),
	(501, 45, 0, 2, 3, 0, 32, 2, 11, NULL, 'Vidutinis dujų tūrio debitas per 2 minutes', 1136, 1, NULL, NULL),
	(502, 46, 0, 2, 3, 0, 27, 2, 55, NULL, 'Vidutinė oro temperatūra per 2 minutes', 1302, 1, NULL, NULL),
	(503, 47, 0, 2, 3, 0, 30, 2, 61, NULL, 'Vidutinis šalčio slėgis per 2 minutes', 1004, 1, NULL, NULL),
	(504, 47, 1, 2, 3, 0, 30, 2, 61, NULL, 'Vidutinis tiekiamo šalčio slėgis per 2 minutes', 1004, 1, NULL, NULL),
	(505, 47, 2, 2, 3, 0, 30, 2, 61, NULL, 'Vidutinis grįžtamo šalčio slėgis per 2 minutes', 1004, 1, NULL, NULL),
	(506, 47, 3, 2, 3, 0, 30, 2, 61, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio slėgio skirtumas per 2 minutes', 1004, 1, NULL, NULL),
	(507, 48, 0, 2, 2, 0, 2, 2, 62, NULL, 'Šalčio energija per 2 minutes', 1001, 1, NULL, NULL),
	(508, 48, 1, 2, 2, 0, 2, 2, 62, NULL, 'Tiekiamo šalčio energija per 2 minutes', 1001, 1, NULL, NULL),
	(509, 48, 2, 2, 2, 0, 2, 2, 62, NULL, 'Grįžtamo šalčio energija per 2 minutes', 1001, 1, NULL, NULL),
	(510, 48, 3, 2, 2, 0, 2, 2, 62, NULL, 'Tiekiamo ir grįžtamo šalčio šilumos kiekių skirtumas per 2 minutes', 1001, 1, NULL, NULL),
	(511, 48, 0, 2, 3, 0, 1, 2, 63, NULL, 'Vidutinė šalčio galia per 2 minutes', 1002, 1, NULL, NULL),
	(512, 48, 1, 2, 3, 0, 1, 2, 63, NULL, 'Vidutinė tiekiamo šalčio galia per 2 minutes', 1002, 1, NULL, NULL),
	(513, 48, 2, 2, 3, 0, 1, 2, 63, NULL, 'Vidutinė grįžtamo šalčio galia per 2 minutes', 1002, 1, NULL, NULL),
	(514, 48, 3, 2, 3, 0, 1, 2, 63, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio šilumos galios skirtumas per 2 minutes', 1002, 1, NULL, NULL),
	(515, 49, 0, 2, 3, 0, 27, 2, 64, NULL, 'Vidutinė šalčio temperatūra per 2 minutes', 1003, 1, NULL, NULL),
	(516, 49, 1, 2, 3, 0, 27, 2, 64, NULL, 'Vidutinė tiekiamo šalčio temperatūra per 2 minutes', 1003, 1, NULL, NULL),
	(517, 49, 2, 2, 3, 0, 27, 2, 64, NULL, 'Vidutinė grįžtamo šalčio temperatūra per 2 minutes', 1008, 1, NULL, NULL),
	(518, 49, 3, 2, 3, 0, 27, 2, 64, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio temperatūrų skirtumas per 2 minutes', 1009, 1, NULL, NULL),
	(519, 50, 0, 2, 2, 0, 31, 2, 66, NULL, 'Šalčio tūrio kiekis per 2 minutes', 1010, 1, NULL, NULL),
	(520, 50, 1, 2, 2, 0, 31, 2, 66, NULL, 'Tiekiamo šalčio tūrio kiekis per 2 minutes', 1010, 1, NULL, NULL),
	(521, 50, 2, 2, 2, 0, 31, 2, 66, NULL, 'Grįžtamo šalčio tūrio kiekis per 2 minutes', 1010, 1, NULL, NULL),
	(522, 50, 3, 2, 2, 0, 31, 2, 66, NULL, 'Tiekiamo ir grįžtamo šalčio tūrio kiekių skirtumas per 2 minutes', 1010, 1, NULL, NULL),
	(523, 50, 0, 2, 3, 0, 32, 2, 65, NULL, 'Vidutinis šalčio tūrio debitas per 2 minutes', 1011, 1, NULL, NULL),
	(524, 50, 1, 2, 3, 0, 32, 2, 65, NULL, 'Vidutinis tiekiamo šalčio tūrio debitas per 2 minutes', 1011, 1, NULL, NULL),
	(525, 50, 2, 2, 3, 0, 32, 2, 65, NULL, 'Vidutinis grįžtamo šalčio tūrio debitas per 2 minutes', 1011, 1, NULL, NULL),
	(526, 50, 3, 2, 3, 0, 32, 2, 65, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio tūrio debito skirtumas per 2 minutes', 1011, 1, NULL, NULL),
	(527, 51, 0, 2, 2, 0, 35, 2, 68, NULL, 'Šilumnešio masės kiekis per 2 minutes', 1065, 1, NULL, NULL),
	(528, 51, 1, 2, 2, 0, 35, 2, 68, NULL, 'Tiekiamo šilumnešio masės kiekis per 2 minutes', 1065, 1, NULL, NULL),
	(529, 51, 2, 2, 2, 0, 35, 2, 68, NULL, 'Grįžtamo šilumnešio masės kiekis per 2 minutes', 1077, 1, NULL, NULL),
	(530, 51, 3, 2, 2, 0, 35, 2, 68, NULL, 'Tiekiamo ir grįžtamo šilumnešio masės kiekių skirtumas per 2 minutes', 1088, 1, NULL, NULL),
	(531, 51, 0, 2, 3, 0, 36, 2, 67, NULL, 'Vidutinis šilumnešio masės debitas per 2 minutes', 1715, 1, NULL, NULL),
	(532, 51, 1, 2, 3, 0, 36, 2, 67, NULL, 'Vidutinis tiekiamo šilumnešio masės debitas per 2 minutes', 1006, 1, NULL, NULL),
	(533, 51, 2, 2, 3, 0, 36, 2, 67, NULL, 'Vidutinis grįžtamo šilumnešio masės debitas per 2 minutes', 1732, 1, NULL, NULL),
	(534, 51, 3, 2, 3, 0, 36, 2, 67, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio masės debito skirtumas per 2 minutes', 1006, 1, NULL, NULL),
	(535, 52, 0, 2, 3, 0, 28, 2, 69, NULL, 'Vidutinis šilumnešio slėgis per 2 minutes', 1068, 1, NULL, NULL),
	(536, 52, 1, 2, 3, 0, 28, 2, 69, NULL, 'Vidutinis tiekiamo šilumnešio slėgis per 2 minutes', 1068, 1, NULL, NULL),
	(537, 52, 2, 2, 3, 0, 28, 2, 69, NULL, 'Vidutinis grįžtamo šilumnešio slėgis per 2 minutes', 1080, 1, NULL, NULL),
	(538, 52, 3, 2, 3, 0, 28, 2, 69, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio slėgių skirtumas per 2 minutes', 1068, 1, NULL, NULL),
	(539, 53, 0, 2, 2, 0, 2, 2, 71, NULL, 'Šilumnešio šilumos kiekis per 2 minutes', 1064, 1, NULL, NULL),
	(540, 53, 1, 2, 2, 0, 2, 2, 71, NULL, 'Tiekiamo šilumnešio šilumos kiekis per 2 minutes', 1064, 1, NULL, NULL),
	(541, 53, 2, 2, 2, 0, 2, 2, 71, NULL, 'Grįžtamo šilumnešio šilumos kiekis per 2 minutes', 1076, 1, NULL, NULL),
	(542, 53, 3, 2, 2, 0, 2, 2, 71, NULL, 'Sunaudotos šilumnešio šilumos kiekis per 2 minutes', 1719, 1, NULL, NULL),
	(543, 53, 0, 2, 3, 0, 1, 2, 70, NULL, 'Vidutinė šilumnešio šilumos galia per 2 minutes', 1716, 1, NULL, NULL),
	(544, 53, 1, 2, 3, 0, 1, 2, 70, NULL, 'Vidutinė tiekiamo šilumnešio šilumos galia per 2 minutes', 1002, 1, NULL, NULL),
	(545, 53, 2, 2, 3, 0, 1, 2, 70, NULL, 'Vidutinė grįžtamo šilumnešio šilumos galia per 2 minutes', 1728, 1, NULL, NULL),
	(546, 53, 3, 2, 3, 0, 1, 2, 70, NULL, 'Vidutinė sunaudota šilumnešio šilumos galia per 2 minutes', 1002, 1, NULL, NULL),
	(547, 58, 0, 2, 2, 0, 31, 2, 59, NULL, 'Šalto vandens tūrio kiekis per 2 minutes', 1214, 1, NULL, NULL),
	(548, 58, 1, 2, 2, 0, 31, 2, 59, NULL, 'Tiekiamo šalto vandens tūrio kiekis per 2 minutes', 1214, 1, NULL, NULL),
	(549, 58, 2, 2, 2, 0, 31, 2, 59, NULL, 'Grįžtamo šalto vandens tūrio kiekis per 2 minutes', 1259, 1, NULL, NULL),
	(550, 58, 3, 2, 2, 0, 31, 2, 59, NULL, 'Tiekiamo ir grįžtamo šalto vandens tūrio kiekių skirtumas per 2 minutes', 1214, 1, NULL, NULL),
	(551, 58, 0, 2, 3, 0, 32, 2, 60, NULL, 'Vidutinis šalto vandens tūrio debitas per 2 minutes', 1260, 1, NULL, NULL),
	(552, 58, 1, 2, 3, 0, 32, 2, 60, NULL, 'Vidutinis tiekiamo šalto vandens tūrio debitas per 2 minutes', 1260, 1, NULL, NULL),
	(553, 58, 2, 2, 3, 0, 32, 2, 60, NULL, 'Vidutinis grįžtamo šalto vandens tūrio debitas per 2 minutes', 1262, 1, NULL, NULL),
	(554, 58, 3, 2, 3, 0, 32, 2, 60, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens tūrio debito skirtumas per 2 minutes', 1260, 1, NULL, NULL),
	(555, 1, 1, 2, 2, 0, 2, 2, 14, NULL, 'A+ energija per 2 minutes', 709, 1, NULL, NULL),
	(556, 1, 2, 2, 2, 0, 2, 2, 14, NULL, 'A- energija per 2 minutes', 710, 1, NULL, NULL),
	(557, 3, 1, 2, 2, 0, 4, 2, 15, NULL, 'R+ energija per 2 minutes', 711, 1, NULL, NULL),
	(558, 3, 2, 2, 2, 0, 4, 2, 15, NULL, 'R- energija per 2 minutes', 712, 1, NULL, NULL),
	(559, 1, 1, 2, 3, 0, 1, 2, 13, '1.0.1.29.0.0', 'Vidutinė P+ galia per 2 minutes', 49, 1, NULL, NULL),
	(560, 1, 2, 2, 3, 0, 1, 2, 13, '1.0.2.29.0.0', 'Vidutinė P- galia per 2 minutes', 50, 1, NULL, NULL),
	(561, 3, 1, 2, 3, 0, 3, 2, 16, '1.0.3.29.0.0', 'Vidutinė Q+ galia per 2 minutes', 51, 1, NULL, NULL),
	(562, 3, 2, 2, 3, 0, 3, 2, 16, '1.0.4.29.0.0', 'Vidutinė Q- galia per 2 minutes', 52, 1, NULL, NULL),
	(563, 54, 0, 2, 3, 0, 27, 2, 72, NULL, 'Vidutinė šilumnešio temperatūra per 2 minutes', 1067, 1, NULL, NULL),
	(564, 54, 1, 2, 3, 0, 27, 2, 72, NULL, 'Vidutinė tiekiamo šilumnešio temperatūra per 2 minutes', 1067, 1, NULL, NULL),
	(565, 54, 2, 2, 3, 0, 27, 2, 72, NULL, 'Vidutinė grįžtamo šilumnešio temperatūra per 2 minutes', 1079, 1, NULL, NULL),
	(566, 54, 3, 2, 3, 0, 27, 2, 72, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas per 2 minutes', 1090, 1, NULL, NULL),
	(567, 55, 0, 2, 2, 0, 31, 2, 74, NULL, 'Šilumnešio tūrio kiekis per 2 minutes', 1066, 1, NULL, NULL),
	(568, 55, 1, 2, 2, 0, 31, 2, 74, NULL, 'Tiekiamo šilumnešio tūrio kiekis per 2 minutes', 1066, 1, NULL, NULL),
	(569, 55, 2, 2, 2, 0, 31, 2, 74, NULL, 'Grįžtamo šilumnešio tūrio kiekis per 2 minutes', 1078, 1, NULL, NULL),
	(570, 55, 3, 2, 2, 0, 31, 2, 74, NULL, 'Tiekiamo ir grįžtamo šilumnešio tūrio kiekių skirtumas per 2 minutes', 1737, 1, NULL, NULL),
	(571, 55, 0, 2, 3, 0, 32, 2, 73, NULL, 'Vidutinis šilumnešio tūrio debitas per 2 minutes', 1714, 1, NULL, NULL),
	(572, 55, 1, 2, 3, 0, 32, 2, 73, NULL, 'Vidutinis tiekiamo šilumnešio tūrio debitas per 2 minutes', 1714, 1, NULL, NULL),
	(573, 55, 2, 2, 3, 0, 32, 2, 73, NULL, 'Vidutinis grįžtamo šilumnešio tūrio debitas per 2 minutes', 1730, 1, NULL, NULL),
	(574, 55, 3, 2, 3, 0, 32, 2, 73, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio tūrio debito skirtumas per 2 minutes', 1011, 1, NULL, NULL),
	(575, 56, 0, 2, 2, 0, 34, 2, 56, NULL, 'Šalto vandens šilumos kiekis per 2 minutes', 1212, 1, NULL, NULL),
	(576, 56, 1, 2, 2, 0, 34, 2, 56, NULL, 'Tiekiamo šalto vandens šilumos kiekis per 2 minutes', 1212, 1, NULL, NULL),
	(577, 56, 2, 2, 2, 0, 34, 2, 56, NULL, 'Grįžtamo šalto vandens šilumos kiekis per 2 minutes', 1238, 1, NULL, NULL),
	(578, 56, 3, 2, 2, 0, 34, 2, 56, NULL, 'Tiekiamo ir grįžtamo šalto vandens šilumos kiekių skirtumas per 2 minutes', 1240, 1, NULL, NULL),
	(579, 56, 0, 2, 3, 0, 33, 2, 57, NULL, 'Vidutinė šalto vandens šilumos galia per 2 minutes', 1232, 1, NULL, NULL),
	(580, 56, 1, 2, 3, 0, 33, 2, 57, NULL, 'Vidutinė tiekiamo šalto vandens šilumos galia per 2 minutes', 1232, 1, NULL, NULL),
	(581, 56, 2, 2, 3, 0, 33, 2, 57, NULL, 'Vidutinė grįžtamo šalto vandens šilumos galia per 2 minutes', 1234, 1, NULL, NULL),
	(582, 56, 3, 2, 3, 0, 33, 2, 57, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens šilumos galių skirtumas per 2 minutes', 1236, 1, NULL, NULL),
	(583, 57, 0, 2, 3, 0, 27, 2, 58, NULL, 'Vidutinė šalto vandens temperatūra per 2 minutes', 1215, 1, NULL, NULL),
	(584, 57, 1, 2, 3, 0, 27, 2, 58, NULL, 'Vidutinė tiekiamo šalto vandens temperatūra per 2 minutes', 1215, 1, NULL, NULL),
	(585, 57, 2, 2, 3, 0, 27, 2, 58, NULL, 'Vidutinė grįžtamo šalto vandens temperatūra per 2 minutes', 1256, 1, NULL, NULL),
	(586, 57, 3, 2, 3, 0, 27, 2, 58, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens temperatūrų skirtumas per 2 minutes', 1257, 1, NULL, NULL),
	(587, 39, 0, 9, 2, 0, 35, 8, 2, NULL, 'Dujų koreguotos masės kiekis per 3 minutes', 1130, 1, NULL, NULL),
	(588, 39, 0, 9, 3, 0, 36, 8, 1, NULL, 'Vidutinis dujų koreguotos masės debitas per 3 minutes', 1135, 1, NULL, NULL),
	(589, 40, 0, 9, 2, 0, 31, 8, 4, NULL, 'Dujų koreguoto tūrio kiekis per 3 minutes', 1131, 1, NULL, NULL),
	(590, 40, 0, 9, 3, 0, 32, 8, 3, NULL, 'Vidutinis dujų koreguoto tūrio debitas per 3 minutes', 1137, 1, NULL, NULL),
	(591, 41, 0, 9, 2, 0, 35, 8, 6, NULL, 'Dujų masės kiekis per 3 minutes', 1128, 1, NULL, NULL),
	(592, 41, 0, 9, 3, 0, 36, 8, 5, NULL, 'Vidutinis dujų masės debitas per 3 minutes', 1134, 1, NULL, NULL),
	(593, 42, 0, 9, 3, 0, 28, 8, 7, NULL, 'Vidutinis dujų slėgis per 3 minutes', 1138, 1, NULL, NULL),
	(594, 43, 0, 9, 2, 0, 34, 8, 9, NULL, 'Dujų šilumos kiekis per 3 minutes', 1127, 1, NULL, NULL),
	(595, 43, 0, 9, 3, 0, 33, 8, 8, NULL, 'Vidutinė dujų šilumos galia per 3 minutes', 1132, 1, NULL, NULL),
	(596, 44, 0, 9, 3, 0, 27, 8, 10, NULL, 'Vidutinė dujų temperatūra per 3 minutes', 1133, 1, NULL, NULL),
	(597, 45, 0, 9, 2, 0, 31, 8, 12, NULL, 'Dujų tūrio kiekis per 3 minutes', 1129, 1, NULL, NULL),
	(598, 45, 0, 9, 3, 0, 32, 8, 11, NULL, 'Vidutinis dujų tūrio debitas per 3 minutes', 1136, 1, NULL, NULL),
	(599, 46, 0, 9, 3, 0, 27, 8, 55, NULL, 'Vidutinė oro temperatūra per 3 minutes', 1302, 1, NULL, NULL),
	(600, 47, 0, 9, 3, 0, 30, 8, 61, NULL, 'Vidutinis šalčio slėgis per 3 minutes', 1004, 1, NULL, NULL),
	(601, 47, 1, 9, 3, 0, 30, 8, 61, NULL, 'Vidutinis tiekiamo šalčio slėgis per 3 minutes', 1004, 1, NULL, NULL),
	(602, 47, 2, 9, 3, 0, 30, 8, 61, NULL, 'Vidutinis grįžtamo šalčio slėgis per 3 minutes', 1004, 1, NULL, NULL),
	(603, 47, 3, 9, 3, 0, 30, 8, 61, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio slėgio skirtumas per 3 minutes', 1004, 1, NULL, NULL),
	(604, 48, 0, 9, 2, 0, 2, 8, 62, NULL, 'Šalčio energija per 3 minutes', 1001, 1, NULL, NULL),
	(605, 48, 1, 9, 2, 0, 2, 8, 62, NULL, 'Tiekiamo šalčio energija per 3 minutes', 1001, 1, NULL, NULL),
	(606, 48, 2, 9, 2, 0, 2, 8, 62, NULL, 'Grįžtamo šalčio energija per 3 minutes', 1001, 1, NULL, NULL),
	(607, 48, 3, 9, 2, 0, 2, 8, 62, NULL, 'Tiekiamo ir grįžtamo šalčio šilumos kiekių skirtumas per 3 minutes', 1001, 1, NULL, NULL),
	(608, 48, 0, 9, 3, 0, 1, 8, 63, NULL, 'Vidutinė šalčio galia per 3 minutes', 1002, 1, NULL, NULL),
	(609, 48, 1, 9, 3, 0, 1, 8, 63, NULL, 'Vidutinė tiekiamo šalčio galia per 3 minutes', 1002, 1, NULL, NULL),
	(610, 48, 2, 9, 3, 0, 1, 8, 63, NULL, 'Vidutinė grįžtamo šalčio galia per 3 minutes', 1002, 1, NULL, NULL),
	(611, 48, 3, 9, 3, 0, 1, 8, 63, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio šilumos galios skirtumas per 3 minutes', 1002, 1, NULL, NULL),
	(612, 49, 0, 9, 3, 0, 27, 8, 64, NULL, 'Vidutinė šalčio temperatūra per 3 minutes', 1003, 1, NULL, NULL),
	(613, 49, 1, 9, 3, 0, 27, 8, 64, NULL, 'Vidutinė tiekiamo šalčio temperatūra per 3 minutes', 1003, 1, NULL, NULL),
	(614, 49, 2, 9, 3, 0, 27, 8, 64, NULL, 'Vidutinė grįžtamo šalčio temperatūra per 3 minutes', 1008, 1, NULL, NULL),
	(615, 49, 3, 9, 3, 0, 27, 8, 64, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio temperatūrų skirtumas per 3 minutes', 1009, 1, NULL, NULL),
	(616, 50, 0, 9, 2, 0, 31, 8, 66, NULL, 'Šalčio tūrio kiekis per 3 minutes', 1010, 1, NULL, NULL),
	(617, 50, 1, 9, 2, 0, 31, 8, 66, NULL, 'Tiekiamo šalčio tūrio kiekis per 3 minutes', 1010, 1, NULL, NULL),
	(618, 50, 2, 9, 2, 0, 31, 8, 66, NULL, 'Grįžtamo šalčio tūrio kiekis per 3 minutes', 1010, 1, NULL, NULL),
	(619, 50, 3, 9, 2, 0, 31, 8, 66, NULL, 'Tiekiamo ir grįžtamo šalčio tūrio kiekių skirtumas per 3 minutes', 1010, 1, NULL, NULL),
	(620, 50, 0, 9, 3, 0, 32, 8, 65, NULL, 'Vidutinis šalčio tūrio debitas per 3 minutes', 1011, 1, NULL, NULL),
	(621, 50, 1, 9, 3, 0, 32, 8, 65, NULL, 'Vidutinis tiekiamo šalčio tūrio debitas per 3 minutes', 1011, 1, NULL, NULL),
	(622, 50, 2, 9, 3, 0, 32, 8, 65, NULL, 'Vidutinis grįžtamo šalčio tūrio debitas per 3 minutes', 1011, 1, NULL, NULL),
	(623, 50, 3, 9, 3, 0, 32, 8, 65, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio tūrio debito skirtumas per 3 minutes', 1011, 1, NULL, NULL),
	(624, 51, 0, 9, 2, 0, 35, 8, 68, NULL, 'Šilumnešio masės kiekis per 3 minutes', 1065, 1, NULL, NULL),
	(625, 51, 1, 9, 2, 0, 35, 8, 68, NULL, 'Tiekiamo šilumnešio masės kiekis per 3 minutes', 1065, 1, NULL, NULL),
	(626, 51, 2, 9, 2, 0, 35, 8, 68, NULL, 'Grįžtamo šilumnešio masės kiekis per 3 minutes', 1077, 1, NULL, NULL),
	(627, 51, 3, 9, 2, 0, 35, 8, 68, NULL, 'Tiekiamo ir grįžtamo šilumnešio masės kiekių skirtumas per 3 minutes', 1088, 1, NULL, NULL),
	(628, 51, 0, 9, 3, 0, 36, 8, 67, NULL, 'Vidutinis šilumnešio masės debitas per 3 minutes', 1715, 1, NULL, NULL),
	(629, 51, 1, 9, 3, 0, 36, 8, 67, NULL, 'Vidutinis tiekiamo šilumnešio masės debitas per 3 minutes', 1006, 1, NULL, NULL),
	(630, 51, 2, 9, 3, 0, 36, 8, 67, NULL, 'Vidutinis grįžtamo šilumnešio masės debitas per 3 minutes', 1732, 1, NULL, NULL),
	(631, 51, 3, 9, 3, 0, 36, 8, 67, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio masės debito skirtumas per 3 minutes', 1006, 1, NULL, NULL),
	(632, 52, 0, 9, 3, 0, 28, 8, 69, NULL, 'Vidutinis šilumnešio slėgis per 3 minutes', 1068, 1, NULL, NULL),
	(633, 52, 1, 9, 3, 0, 28, 8, 69, NULL, 'Vidutinis tiekiamo šilumnešio slėgis per 3 minutes', 1068, 1, NULL, NULL),
	(634, 52, 2, 9, 3, 0, 28, 8, 69, NULL, 'Vidutinis grįžtamo šilumnešio slėgis per 3 minutes', 1080, 1, NULL, NULL),
	(635, 52, 3, 9, 3, 0, 28, 8, 69, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio slėgių skirtumas per 3 minutes', 1068, 1, NULL, NULL),
	(636, 53, 0, 9, 2, 0, 2, 8, 71, NULL, 'Šilumnešio šilumos kiekis per 3 minutes', 1064, 1, NULL, NULL),
	(637, 53, 1, 9, 2, 0, 2, 8, 71, NULL, 'Tiekiamo šilumnešio šilumos kiekis per 3 minutes', 1064, 1, NULL, NULL),
	(638, 53, 2, 9, 2, 0, 2, 8, 71, NULL, 'Grįžtamo šilumnešio šilumos kiekis per 3 minutes', 1076, 1, NULL, NULL),
	(639, 53, 3, 9, 2, 0, 2, 8, 71, NULL, 'Sunaudotos šilumnešio šilumos kiekis per 3 minutes', 1719, 1, NULL, NULL),
	(640, 53, 0, 9, 3, 0, 1, 8, 70, NULL, 'Vidutinė šilumnešio šilumos galia per 3 minutes', 1716, 1, NULL, NULL),
	(641, 53, 1, 9, 3, 0, 1, 8, 70, NULL, 'Vidutinė tiekiamo šilumnešio šilumos galia per 3 minutes', 1002, 1, NULL, NULL),
	(642, 53, 2, 9, 3, 0, 1, 8, 70, NULL, 'Vidutinė grįžtamo šilumnešio šilumos galia per 3 minutes', 1728, 1, NULL, NULL),
	(643, 53, 3, 9, 3, 0, 1, 8, 70, NULL, 'Vidutinė sunaudota šilumnešio šilumos galia per 3 minutes', 1002, 1, NULL, NULL),
	(644, 58, 0, 9, 2, 0, 31, 8, 59, NULL, 'Šalto vandens tūrio kiekis per 3 minutes', 1214, 1, NULL, NULL),
	(645, 58, 1, 9, 2, 0, 31, 8, 59, NULL, 'Tiekiamo šalto vandens tūrio kiekis per 3 minutes', 1214, 1, NULL, NULL),
	(646, 58, 2, 9, 2, 0, 31, 8, 59, NULL, 'Grįžtamo šalto vandens tūrio kiekis per 3 minutes', 1259, 1, NULL, NULL),
	(647, 58, 3, 9, 2, 0, 31, 8, 59, NULL, 'Tiekiamo ir grįžtamo šalto vandens tūrio kiekių skirtumas per 3 minutes', 1214, 1, NULL, NULL),
	(648, 58, 0, 9, 3, 0, 32, 8, 60, NULL, 'Vidutinis šalto vandens tūrio debitas per 3 minutes', 1260, 1, NULL, NULL),
	(649, 58, 1, 9, 3, 0, 32, 8, 60, NULL, 'Vidutinis tiekiamo šalto vandens tūrio debitas per 3 minutes', 1260, 1, NULL, NULL),
	(650, 58, 2, 9, 3, 0, 32, 8, 60, NULL, 'Vidutinis grįžtamo šalto vandens tūrio debitas per 3 minutes', 1262, 1, NULL, NULL),
	(651, 58, 3, 9, 3, 0, 32, 8, 60, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens tūrio debito skirtumas per 3 minutes', 1260, 1, NULL, NULL),
	(652, 1, 1, 9, 2, 0, 2, 8, 14, NULL, 'A+ energija per 3 minutes', 709, 1, NULL, NULL),
	(653, 1, 2, 9, 2, 0, 2, 8, 14, NULL, 'A- energija per 3 minutes', 710, 1, NULL, NULL),
	(654, 3, 1, 9, 2, 0, 4, 8, 15, NULL, 'R+ energija per 3 minutes', 711, 1, NULL, NULL),
	(655, 3, 2, 9, 2, 0, 4, 8, 15, NULL, 'R- energija per 3 minutes', 712, 1, NULL, NULL),
	(656, 1, 1, 9, 3, 0, 1, 8, 13, '1.0.1.29.0.0', 'Vidutinė P+ galia per 3 minutes', 49, 1, NULL, NULL),
	(657, 1, 2, 9, 3, 0, 1, 8, 13, '1.0.2.29.0.0', 'Vidutinė P- galia per 3 minutes', 50, 1, NULL, NULL),
	(658, 3, 1, 9, 3, 0, 3, 8, 16, '1.0.3.29.0.0', 'Vidutinė Q+ galia per 3 minutes', 51, 1, NULL, NULL),
	(659, 3, 2, 9, 3, 0, 3, 8, 16, '1.0.4.29.0.0', 'Vidutinė Q- galia per 3 minutes', 52, 1, NULL, NULL),
	(660, 54, 0, 9, 3, 0, 27, 8, 72, NULL, 'Vidutinė šilumnešio temperatūra per 3 minutes', 1067, 1, NULL, NULL),
	(661, 54, 1, 9, 3, 0, 27, 8, 72, NULL, 'Vidutinė tiekiamo šilumnešio temperatūra per 3 minutes', 1067, 1, NULL, NULL),
	(662, 54, 2, 9, 3, 0, 27, 8, 72, NULL, 'Vidutinė grįžtamo šilumnešio temperatūra per 3 minutes', 1079, 1, NULL, NULL),
	(663, 54, 3, 9, 3, 0, 27, 8, 72, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas per 3 minutes', 1090, 1, NULL, NULL),
	(664, 55, 0, 9, 2, 0, 31, 8, 74, NULL, 'Šilumnešio tūrio kiekis per 3 minutes', 1066, 1, NULL, NULL),
	(665, 55, 1, 9, 2, 0, 31, 8, 74, NULL, 'Tiekiamo šilumnešio tūrio kiekis per 3 minutes', 1066, 1, NULL, NULL),
	(666, 55, 2, 9, 2, 0, 31, 8, 74, NULL, 'Grįžtamo šilumnešio tūrio kiekis per 3 minutes', 1078, 1, NULL, NULL),
	(667, 55, 3, 9, 2, 0, 31, 8, 74, NULL, 'Tiekiamo ir grįžtamo šilumnešio tūrio kiekių skirtumas per 3 minutes', 1737, 1, NULL, NULL),
	(668, 55, 0, 9, 3, 0, 32, 8, 73, NULL, 'Vidutinis šilumnešio tūrio debitas per 3 minutes', 1714, 1, NULL, NULL),
	(669, 55, 1, 9, 3, 0, 32, 8, 73, NULL, 'Vidutinis tiekiamo šilumnešio tūrio debitas per 3 minutes', 1714, 1, NULL, NULL),
	(670, 55, 2, 9, 3, 0, 32, 8, 73, NULL, 'Vidutinis grįžtamo šilumnešio tūrio debitas per 3 minutes', 1730, 1, NULL, NULL),
	(671, 55, 3, 9, 3, 0, 32, 8, 73, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio tūrio debito skirtumas per 3 minutes', 1011, 1, NULL, NULL),
	(672, 56, 0, 9, 2, 0, 34, 8, 56, NULL, 'Šalto vandens šilumos kiekis per 3 minutes', 1212, 1, NULL, NULL),
	(673, 56, 1, 9, 2, 0, 34, 8, 56, NULL, 'Tiekiamo šalto vandens šilumos kiekis per 3 minutes', 1212, 1, NULL, NULL),
	(674, 56, 2, 9, 2, 0, 34, 8, 56, NULL, 'Grįžtamo šalto vandens šilumos kiekis per 3 minutes', 1238, 1, NULL, NULL),
	(675, 56, 3, 9, 2, 0, 34, 8, 56, NULL, 'Tiekiamo ir grįžtamo šalto vandens šilumos kiekių skirtumas per 3 minutes', 1240, 1, NULL, NULL),
	(676, 56, 0, 9, 3, 0, 33, 8, 57, NULL, 'Vidutinė šalto vandens šilumos galia per 3 minutes', 1232, 1, NULL, NULL),
	(677, 56, 1, 9, 3, 0, 33, 8, 57, NULL, 'Vidutinė tiekiamo šalto vandens šilumos galia per 3 minutes', 1232, 1, NULL, NULL),
	(678, 56, 2, 9, 3, 0, 33, 8, 57, NULL, 'Vidutinė grįžtamo šalto vandens šilumos galia per 3 minutes', 1234, 1, NULL, NULL),
	(679, 56, 3, 9, 3, 0, 33, 8, 57, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens šilumos galių skirtumas per 3 minutes', 1236, 1, NULL, NULL),
	(680, 57, 0, 9, 3, 0, 27, 8, 58, NULL, 'Vidutinė šalto vandens temperatūra per 3 minutes', 1215, 1, NULL, NULL),
	(681, 57, 1, 9, 3, 0, 27, 8, 58, NULL, 'Vidutinė tiekiamo šalto vandens temperatūra per 3 minutes', 1215, 1, NULL, NULL),
	(682, 57, 2, 9, 3, 0, 27, 8, 58, NULL, 'Vidutinė grįžtamo šalto vandens temperatūra per 3 minutes', 1256, 1, NULL, NULL),
	(683, 57, 3, 9, 3, 0, 27, 8, 58, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens temperatūrų skirtumas per 3 minutes', 1257, 1, NULL, NULL),
	(684, 39, 0, 10, 2, 0, 35, 9, 2, NULL, 'Dujų koreguotos masės kiekis per 4 minutes', 1130, 1, NULL, NULL),
	(685, 39, 0, 10, 3, 0, 36, 9, 1, NULL, 'Vidutinis dujų koreguotos masės debitas per 4 minutes', 1135, 1, NULL, NULL),
	(686, 40, 0, 10, 2, 0, 31, 9, 4, NULL, 'Dujų koreguoto tūrio kiekis per 4 minutes', 1131, 1, NULL, NULL),
	(687, 40, 0, 10, 3, 0, 32, 9, 3, NULL, 'Vidutinis dujų koreguoto tūrio debitas per 4 minutes', 1137, 1, NULL, NULL),
	(688, 41, 0, 10, 2, 0, 35, 9, 6, NULL, 'Dujų masės kiekis per 4 minutes', 1128, 1, NULL, NULL),
	(689, 41, 0, 10, 3, 0, 36, 9, 5, NULL, 'Vidutinis dujų masės debitas per 4 minutes', 1134, 1, NULL, NULL),
	(690, 42, 0, 10, 3, 0, 28, 9, 7, NULL, 'Vidutinis dujų slėgis per 4 minutes', 1138, 1, NULL, NULL),
	(691, 43, 0, 10, 2, 0, 34, 9, 9, NULL, 'Dujų šilumos kiekis per 4 minutes', 1127, 1, NULL, NULL),
	(692, 43, 0, 10, 3, 0, 33, 9, 8, NULL, 'Vidutinė dujų šilumos galia per 4 minutes', 1132, 1, NULL, NULL),
	(693, 44, 0, 10, 3, 0, 27, 9, 10, NULL, 'Vidutinė dujų temperatūra per 4 minutes', 1133, 1, NULL, NULL),
	(694, 45, 0, 10, 2, 0, 31, 9, 12, NULL, 'Dujų tūrio kiekis per 4 minutes', 1129, 1, NULL, NULL),
	(695, 45, 0, 10, 3, 0, 32, 9, 11, NULL, 'Vidutinis dujų tūrio debitas per 4 minutes', 1136, 1, NULL, NULL),
	(696, 46, 0, 10, 3, 0, 27, 9, 55, NULL, 'Vidutinė oro temperatūra per 4 minutes', 1302, 1, NULL, NULL),
	(697, 47, 0, 10, 3, 0, 30, 9, 61, NULL, 'Vidutinis šalčio slėgis per 4 minutes', 1004, 1, NULL, NULL),
	(698, 47, 1, 10, 3, 0, 30, 9, 61, NULL, 'Vidutinis tiekiamo šalčio slėgis per 4 minutes', 1004, 1, NULL, NULL),
	(699, 47, 2, 10, 3, 0, 30, 9, 61, NULL, 'Vidutinis grįžtamo šalčio slėgis per 4 minutes', 1004, 1, NULL, NULL),
	(700, 47, 3, 10, 3, 0, 30, 9, 61, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio slėgio skirtumas per 4 minutes', 1004, 1, NULL, NULL),
	(701, 48, 0, 10, 2, 0, 2, 9, 62, NULL, 'Šalčio energija per 4 minutes', 1001, 1, NULL, NULL),
	(702, 48, 1, 10, 2, 0, 2, 9, 62, NULL, 'Tiekiamo šalčio energija per 4 minutes', 1001, 1, NULL, NULL),
	(703, 48, 2, 10, 2, 0, 2, 9, 62, NULL, 'Grįžtamo šalčio energija per 4 minutes', 1001, 1, NULL, NULL),
	(704, 48, 3, 10, 2, 0, 2, 9, 62, NULL, 'Tiekiamo ir grįžtamo šalčio šilumos kiekių skirtumas per 4 minutes', 1001, 1, NULL, NULL),
	(705, 48, 0, 10, 3, 0, 1, 9, 63, NULL, 'Vidutinė šalčio galia per 4 minutes', 1002, 1, NULL, NULL),
	(706, 48, 1, 10, 3, 0, 1, 9, 63, NULL, 'Vidutinė tiekiamo šalčio galia per 4 minutes', 1002, 1, NULL, NULL),
	(707, 48, 2, 10, 3, 0, 1, 9, 63, NULL, 'Vidutinė grįžtamo šalčio galia per 4 minutes', 1002, 1, NULL, NULL),
	(708, 48, 3, 10, 3, 0, 1, 9, 63, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio šilumos galios skirtumas per 4 minutes', 1002, 1, NULL, NULL),
	(709, 49, 0, 10, 3, 0, 27, 9, 64, NULL, 'Vidutinė šalčio temperatūra per 4 minutes', 1003, 1, NULL, NULL),
	(710, 49, 1, 10, 3, 0, 27, 9, 64, NULL, 'Vidutinė tiekiamo šalčio temperatūra per 4 minutes', 1003, 1, NULL, NULL),
	(711, 49, 2, 10, 3, 0, 27, 9, 64, NULL, 'Vidutinė grįžtamo šalčio temperatūra per 4 minutes', 1008, 1, NULL, NULL),
	(712, 49, 3, 10, 3, 0, 27, 9, 64, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio temperatūrų skirtumas per 4 minutes', 1009, 1, NULL, NULL),
	(713, 50, 0, 10, 2, 0, 31, 9, 66, NULL, 'Šalčio tūrio kiekis per 4 minutes', 1010, 1, NULL, NULL),
	(714, 50, 1, 10, 2, 0, 31, 9, 66, NULL, 'Tiekiamo šalčio tūrio kiekis per 4 minutes', 1010, 1, NULL, NULL),
	(715, 50, 2, 10, 2, 0, 31, 9, 66, NULL, 'Grįžtamo šalčio tūrio kiekis per 4 minutes', 1010, 1, NULL, NULL),
	(716, 50, 3, 10, 2, 0, 31, 9, 66, NULL, 'Tiekiamo ir grįžtamo šalčio tūrio kiekių skirtumas per 4 minutes', 1010, 1, NULL, NULL),
	(717, 50, 0, 10, 3, 0, 32, 9, 65, NULL, 'Vidutinis šalčio tūrio debitas per 4 minutes', 1011, 1, NULL, NULL),
	(718, 50, 1, 10, 3, 0, 32, 9, 65, NULL, 'Vidutinis tiekiamo šalčio tūrio debitas per 4 minutes', 1011, 1, NULL, NULL),
	(719, 50, 2, 10, 3, 0, 32, 9, 65, NULL, 'Vidutinis grįžtamo šalčio tūrio debitas per 4 minutes', 1011, 1, NULL, NULL),
	(720, 50, 3, 10, 3, 0, 32, 9, 65, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio tūrio debito skirtumas per 4 minutes', 1011, 1, NULL, NULL),
	(721, 51, 0, 10, 2, 0, 35, 9, 68, NULL, 'Šilumnešio masės kiekis per 4 minutes', 1065, 1, NULL, NULL),
	(722, 51, 1, 10, 2, 0, 35, 9, 68, NULL, 'Tiekiamo šilumnešio masės kiekis per 4 minutes', 1065, 1, NULL, NULL),
	(723, 51, 2, 10, 2, 0, 35, 9, 68, NULL, 'Grįžtamo šilumnešio masės kiekis per 4 minutes', 1077, 1, NULL, NULL),
	(724, 51, 3, 10, 2, 0, 35, 9, 68, NULL, 'Tiekiamo ir grįžtamo šilumnešio masės kiekių skirtumas per 4 minutes', 1088, 1, NULL, NULL),
	(725, 51, 0, 10, 3, 0, 36, 9, 67, NULL, 'Vidutinis šilumnešio masės debitas per 4 minutes', 1715, 1, NULL, NULL),
	(726, 51, 1, 10, 3, 0, 36, 9, 67, NULL, 'Vidutinis tiekiamo šilumnešio masės debitas per 4 minutes', 1006, 1, NULL, NULL),
	(727, 51, 2, 10, 3, 0, 36, 9, 67, NULL, 'Vidutinis grįžtamo šilumnešio masės debitas per 4 minutes', 1732, 1, NULL, NULL),
	(728, 51, 3, 10, 3, 0, 36, 9, 67, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio masės debito skirtumas per 4 minutes', 1006, 1, NULL, NULL),
	(729, 52, 0, 10, 3, 0, 28, 9, 69, NULL, 'Vidutinis šilumnešio slėgis per 4 minutes', 1068, 1, NULL, NULL),
	(730, 52, 1, 10, 3, 0, 28, 9, 69, NULL, 'Vidutinis tiekiamo šilumnešio slėgis per 4 minutes', 1068, 1, NULL, NULL),
	(731, 52, 2, 10, 3, 0, 28, 9, 69, NULL, 'Vidutinis grįžtamo šilumnešio slėgis per 4 minutes', 1080, 1, NULL, NULL),
	(732, 52, 3, 10, 3, 0, 28, 9, 69, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio slėgių skirtumas per 4 minutes', 1068, 1, NULL, NULL),
	(733, 53, 0, 10, 2, 0, 2, 9, 71, NULL, 'Šilumnešio šilumos kiekis per 4 minutes', 1064, 1, NULL, NULL),
	(734, 53, 1, 10, 2, 0, 2, 9, 71, NULL, 'Tiekiamo šilumnešio šilumos kiekis per 4 minutes', 1064, 1, NULL, NULL),
	(735, 53, 2, 10, 2, 0, 2, 9, 71, NULL, 'Grįžtamo šilumnešio šilumos kiekis per 4 minutes', 1076, 1, NULL, NULL),
	(736, 53, 3, 10, 2, 0, 2, 9, 71, NULL, 'Sunaudotos šilumnešio šilumos kiekis per 4 minutes', 1719, 1, NULL, NULL),
	(737, 53, 0, 10, 3, 0, 1, 9, 70, NULL, 'Vidutinė šilumnešio šilumos galia per 4 minutes', 1716, 1, NULL, NULL),
	(738, 53, 1, 10, 3, 0, 1, 9, 70, NULL, 'Vidutinė tiekiamo šilumnešio šilumos galia per 4 minutes', 1002, 1, NULL, NULL),
	(739, 53, 2, 10, 3, 0, 1, 9, 70, NULL, 'Vidutinė grįžtamo šilumnešio šilumos galia per 4 minutes', 1728, 1, NULL, NULL),
	(740, 53, 3, 10, 3, 0, 1, 9, 70, NULL, 'Vidutinė sunaudota šilumnešio šilumos galia per 4 minutes', 1002, 1, NULL, NULL),
	(741, 58, 0, 10, 2, 0, 31, 9, 59, NULL, 'Šalto vandens tūrio kiekis per 4 minutes', 1214, 1, NULL, NULL),
	(742, 58, 1, 10, 2, 0, 31, 9, 59, NULL, 'Tiekiamo šalto vandens tūrio kiekis per 4 minutes', 1214, 1, NULL, NULL),
	(743, 58, 2, 10, 2, 0, 31, 9, 59, NULL, 'Grįžtamo šalto vandens tūrio kiekis per 4 minutes', 1259, 1, NULL, NULL),
	(744, 58, 3, 10, 2, 0, 31, 9, 59, NULL, 'Tiekiamo ir grįžtamo šalto vandens tūrio kiekių skirtumas per 4 minutes', 1214, 1, NULL, NULL),
	(745, 58, 0, 10, 3, 0, 32, 9, 60, NULL, 'Vidutinis šalto vandens tūrio debitas per 4 minutes', 1260, 1, NULL, NULL),
	(746, 58, 1, 10, 3, 0, 32, 9, 60, NULL, 'Vidutinis tiekiamo šalto vandens tūrio debitas per 4 minutes', 1260, 1, NULL, NULL),
	(747, 58, 2, 10, 3, 0, 32, 9, 60, NULL, 'Vidutinis grįžtamo šalto vandens tūrio debitas per 4 minutes', 1262, 1, NULL, NULL),
	(748, 58, 3, 10, 3, 0, 32, 9, 60, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens tūrio debito skirtumas per 4 minutes', 1260, 1, NULL, NULL),
	(749, 1, 1, 10, 2, 0, 2, 9, 14, NULL, 'A+ energija per 4 minutes', 709, 1, NULL, NULL),
	(750, 1, 2, 10, 2, 0, 2, 9, 14, NULL, 'A- energija per 4 minutes', 710, 1, NULL, NULL),
	(751, 3, 1, 10, 2, 0, 4, 9, 15, NULL, 'R+ energija per 4 minutes', 711, 1, NULL, NULL),
	(752, 3, 2, 10, 2, 0, 4, 9, 15, NULL, 'R- energija per 4 minutes', 712, 1, NULL, NULL),
	(753, 1, 1, 10, 3, 0, 1, 9, 13, '1.0.1.29.0.0', 'Vidutinė P+ galia per 4 minutes', 49, 1, NULL, NULL),
	(754, 1, 2, 10, 3, 0, 1, 9, 13, '1.0.2.29.0.0', 'Vidutinė P- galia per 4 minutes', 50, 1, NULL, NULL),
	(755, 3, 1, 10, 3, 0, 3, 9, 16, '1.0.3.29.0.0', 'Vidutinė Q+ galia per 4 minutes', 51, 1, NULL, NULL),
	(756, 3, 2, 10, 3, 0, 3, 9, 16, '1.0.4.29.0.0', 'Vidutinė Q- galia per 4 minutes', 52, 1, NULL, NULL),
	(757, 54, 0, 10, 3, 0, 27, 9, 72, NULL, 'Vidutinė šilumnešio temperatūra per 4 minutes', 1067, 1, NULL, NULL),
	(758, 54, 1, 10, 3, 0, 27, 9, 72, NULL, 'Vidutinė tiekiamo šilumnešio temperatūra per 4 minutes', 1067, 1, NULL, NULL),
	(759, 54, 2, 10, 3, 0, 27, 9, 72, NULL, 'Vidutinė grįžtamo šilumnešio temperatūra per 4 minutes', 1079, 1, NULL, NULL),
	(760, 54, 3, 10, 3, 0, 27, 9, 72, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas per 4 minutes', 1090, 1, NULL, NULL),
	(761, 55, 0, 10, 2, 0, 31, 9, 74, NULL, 'Šilumnešio tūrio kiekis per 4 minutes', 1066, 1, NULL, NULL),
	(762, 55, 1, 10, 2, 0, 31, 9, 74, NULL, 'Tiekiamo šilumnešio tūrio kiekis per 4 minutes', 1066, 1, NULL, NULL),
	(763, 55, 2, 10, 2, 0, 31, 9, 74, NULL, 'Grįžtamo šilumnešio tūrio kiekis per 4 minutes', 1078, 1, NULL, NULL),
	(764, 55, 3, 10, 2, 0, 31, 9, 74, NULL, 'Tiekiamo ir grįžtamo šilumnešio tūrio kiekių skirtumas per 4 minutes', 1737, 1, NULL, NULL),
	(765, 55, 0, 10, 3, 0, 32, 9, 73, NULL, 'Vidutinis šilumnešio tūrio debitas per 4 minutes', 1714, 1, NULL, NULL),
	(766, 55, 1, 10, 3, 0, 32, 9, 73, NULL, 'Vidutinis tiekiamo šilumnešio tūrio debitas per 4 minutes', 1714, 1, NULL, NULL),
	(767, 55, 2, 10, 3, 0, 32, 9, 73, NULL, 'Vidutinis grįžtamo šilumnešio tūrio debitas per 4 minutes', 1730, 1, NULL, NULL),
	(768, 55, 3, 10, 3, 0, 32, 9, 73, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio tūrio debito skirtumas per 4 minutes', 1011, 1, NULL, NULL),
	(769, 56, 0, 10, 2, 0, 34, 9, 56, NULL, 'Šalto vandens šilumos kiekis per 4 minutes', 1212, 1, NULL, NULL),
	(770, 56, 1, 10, 2, 0, 34, 9, 56, NULL, 'Tiekiamo šalto vandens šilumos kiekis per 4 minutes', 1212, 1, NULL, NULL),
	(771, 56, 2, 10, 2, 0, 34, 9, 56, NULL, 'Grįžtamo šalto vandens šilumos kiekis per 4 minutes', 1238, 1, NULL, NULL),
	(772, 56, 3, 10, 2, 0, 34, 9, 56, NULL, 'Tiekiamo ir grįžtamo šalto vandens šilumos kiekių skirtumas per 4 minutes', 1240, 1, NULL, NULL),
	(773, 56, 0, 10, 3, 0, 33, 9, 57, NULL, 'Vidutinė šalto vandens šilumos galia per 4 minutes', 1232, 1, NULL, NULL),
	(774, 56, 1, 10, 3, 0, 33, 9, 57, NULL, 'Vidutinė tiekiamo šalto vandens šilumos galia per 4 minutes', 1232, 1, NULL, NULL),
	(775, 56, 2, 10, 3, 0, 33, 9, 57, NULL, 'Vidutinė grįžtamo šalto vandens šilumos galia per 4 minutes', 1234, 1, NULL, NULL),
	(776, 56, 3, 10, 3, 0, 33, 9, 57, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens šilumos galių skirtumas per 4 minutes', 1236, 1, NULL, NULL),
	(777, 57, 0, 10, 3, 0, 27, 9, 58, NULL, 'Vidutinė šalto vandens temperatūra per 4 minutes', 1215, 1, NULL, NULL),
	(778, 57, 1, 10, 3, 0, 27, 9, 58, NULL, 'Vidutinė tiekiamo šalto vandens temperatūra per 4 minutes', 1215, 1, NULL, NULL),
	(779, 57, 2, 10, 3, 0, 27, 9, 58, NULL, 'Vidutinė grįžtamo šalto vandens temperatūra per 4 minutes', 1256, 1, NULL, NULL),
	(780, 57, 3, 10, 3, 0, 27, 9, 58, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens temperatūrų skirtumas per 4 minutes', 1257, 1, NULL, NULL),
	(781, 39, 0, 11, 2, 0, 35, 10, 2, NULL, 'Dujų koreguotos masės kiekis per 5 minutes', 1130, 1, NULL, NULL),
	(782, 39, 0, 11, 3, 0, 36, 10, 1, NULL, 'Vidutinis dujų koreguotos masės debitas per 5 minutes', 1135, 1, NULL, NULL),
	(783, 40, 0, 11, 2, 0, 31, 10, 4, NULL, 'Dujų koreguoto tūrio kiekis per 5 minutes', 1131, 1, NULL, NULL),
	(784, 40, 0, 11, 3, 0, 32, 10, 3, NULL, 'Vidutinis dujų koreguoto tūrio debitas per 5 minutes', 1137, 1, NULL, NULL),
	(785, 41, 0, 11, 2, 0, 35, 10, 6, NULL, 'Dujų masės kiekis per 5 minutes', 1128, 1, NULL, NULL),
	(786, 41, 0, 11, 3, 0, 36, 10, 5, NULL, 'Vidutinis dujų masės debitas per 5 minutes', 1134, 1, NULL, NULL),
	(787, 42, 0, 11, 3, 0, 28, 10, 7, NULL, 'Vidutinis dujų slėgis per 5 minutes', 1138, 1, NULL, NULL),
	(788, 43, 0, 11, 2, 0, 34, 10, 9, NULL, 'Dujų šilumos kiekis per 5 minutes', 1127, 1, NULL, NULL),
	(789, 43, 0, 11, 3, 0, 33, 10, 8, NULL, 'Vidutinė dujų šilumos galia per 5 minutes', 1132, 1, NULL, NULL),
	(790, 44, 0, 11, 3, 0, 27, 10, 10, NULL, 'Vidutinė dujų temperatūra per 5 minutes', 1133, 1, NULL, NULL),
	(791, 45, 0, 11, 2, 0, 31, 10, 12, NULL, 'Dujų tūrio kiekis per 5 minutes', 1129, 1, NULL, NULL),
	(792, 45, 0, 11, 3, 0, 32, 10, 11, NULL, 'Vidutinis dujų tūrio debitas per 5 minutes', 1136, 1, NULL, NULL),
	(793, 46, 0, 11, 3, 0, 27, 10, 55, NULL, 'Vidutinė oro temperatūra per 5 minutes', 1302, 1, NULL, NULL),
	(794, 47, 0, 11, 3, 0, 30, 10, 61, NULL, 'Vidutinis šalčio slėgis per 5 minutes', 1004, 1, NULL, NULL),
	(795, 47, 1, 11, 3, 0, 30, 10, 61, NULL, 'Vidutinis tiekiamo šalčio slėgis per 5 minutes', 1004, 1, NULL, NULL),
	(796, 47, 2, 11, 3, 0, 30, 10, 61, NULL, 'Vidutinis grįžtamo šalčio slėgis per 5 minutes', 1004, 1, NULL, NULL),
	(797, 47, 3, 11, 3, 0, 30, 10, 61, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio slėgio skirtumas per 5 minutes', 1004, 1, NULL, NULL),
	(798, 48, 0, 11, 2, 0, 2, 10, 62, NULL, 'Šalčio energija per 5 minutes', 1001, 1, NULL, NULL),
	(799, 48, 1, 11, 2, 0, 2, 10, 62, NULL, 'Tiekiamo šalčio energija per 5 minutes', 1001, 1, NULL, NULL),
	(800, 48, 2, 11, 2, 0, 2, 10, 62, NULL, 'Grįžtamo šalčio energija per 5 minutes', 1001, 1, NULL, NULL),
	(801, 48, 3, 11, 2, 0, 2, 10, 62, NULL, 'Tiekiamo ir grįžtamo šalčio šilumos kiekių skirtumas per 5 minutes', 1001, 1, NULL, NULL),
	(802, 48, 0, 11, 3, 0, 1, 10, 63, NULL, 'Vidutinė šalčio galia per 5 minutes', 1002, 1, NULL, NULL),
	(803, 48, 1, 11, 3, 0, 1, 10, 63, NULL, 'Vidutinė tiekiamo šalčio galia per 5 minutes', 1002, 1, NULL, NULL),
	(804, 48, 2, 11, 3, 0, 1, 10, 63, NULL, 'Vidutinė grįžtamo šalčio galia per 5 minutes', 1002, 1, NULL, NULL),
	(805, 48, 3, 11, 3, 0, 1, 10, 63, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio šilumos galios skirtumas per 5 minutes', 1002, 1, NULL, NULL),
	(806, 49, 0, 11, 3, 0, 27, 10, 64, NULL, 'Vidutinė šalčio temperatūra per 5 minutes', 1003, 1, NULL, NULL),
	(807, 49, 1, 11, 3, 0, 27, 10, 64, NULL, 'Vidutinė tiekiamo šalčio temperatūra per 5 minutes', 1003, 1, NULL, NULL),
	(808, 49, 2, 11, 3, 0, 27, 10, 64, NULL, 'Vidutinė grįžtamo šalčio temperatūra per 5 minutes', 1008, 1, NULL, NULL),
	(809, 49, 3, 11, 3, 0, 27, 10, 64, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio temperatūrų skirtumas per 5 minutes', 1009, 1, NULL, NULL),
	(810, 50, 0, 11, 2, 0, 31, 10, 66, NULL, 'Šalčio tūrio kiekis per 5 minutes', 1010, 1, NULL, NULL),
	(811, 50, 1, 11, 2, 0, 31, 10, 66, NULL, 'Tiekiamo šalčio tūrio kiekis per 5 minutes', 1010, 1, NULL, NULL),
	(812, 50, 2, 11, 2, 0, 31, 10, 66, NULL, 'Grįžtamo šalčio tūrio kiekis per 5 minutes', 1010, 1, NULL, NULL),
	(813, 50, 3, 11, 2, 0, 31, 10, 66, NULL, 'Tiekiamo ir grįžtamo šalčio tūrio kiekių skirtumas per 5 minutes', 1010, 1, NULL, NULL),
	(814, 50, 0, 11, 3, 0, 32, 10, 65, NULL, 'Vidutinis šalčio tūrio debitas per 5 minutes', 1011, 1, NULL, NULL),
	(815, 50, 1, 11, 3, 0, 32, 10, 65, NULL, 'Vidutinis tiekiamo šalčio tūrio debitas per 5 minutes', 1011, 1, NULL, NULL),
	(816, 50, 2, 11, 3, 0, 32, 10, 65, NULL, 'Vidutinis grįžtamo šalčio tūrio debitas per 5 minutes', 1011, 1, NULL, NULL),
	(817, 50, 3, 11, 3, 0, 32, 10, 65, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio tūrio debito skirtumas per 5 minutes', 1011, 1, NULL, NULL),
	(818, 51, 0, 11, 2, 0, 35, 10, 68, NULL, 'Šilumnešio masės kiekis per 5 minutes', 1065, 1, NULL, NULL),
	(819, 51, 1, 11, 2, 0, 35, 10, 68, NULL, 'Tiekiamo šilumnešio masės kiekis per 5 minutes', 1065, 1, NULL, NULL),
	(820, 51, 2, 11, 2, 0, 35, 10, 68, NULL, 'Grįžtamo šilumnešio masės kiekis per 5 minutes', 1077, 1, NULL, NULL),
	(821, 51, 3, 11, 2, 0, 35, 10, 68, NULL, 'Tiekiamo ir grįžtamo šilumnešio masės kiekių skirtumas per 5 minutes', 1088, 1, NULL, NULL),
	(822, 51, 0, 11, 3, 0, 36, 10, 67, NULL, 'Vidutinis šilumnešio masės debitas per 5 minutes', 1715, 1, NULL, NULL),
	(823, 51, 1, 11, 3, 0, 36, 10, 67, NULL, 'Vidutinis tiekiamo šilumnešio masės debitas per 5 minutes', 1006, 1, NULL, NULL),
	(824, 51, 2, 11, 3, 0, 36, 10, 67, NULL, 'Vidutinis grįžtamo šilumnešio masės debitas per 5 minutes', 1732, 1, NULL, NULL),
	(825, 51, 3, 11, 3, 0, 36, 10, 67, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio masės debito skirtumas per 5 minutes', 1006, 1, NULL, NULL),
	(826, 52, 0, 11, 3, 0, 28, 10, 69, NULL, 'Vidutinis šilumnešio slėgis per 5 minutes', 1068, 1, NULL, NULL),
	(827, 52, 1, 11, 3, 0, 28, 10, 69, NULL, 'Vidutinis tiekiamo šilumnešio slėgis per 5 minutes', 1068, 1, NULL, NULL),
	(828, 52, 2, 11, 3, 0, 28, 10, 69, NULL, 'Vidutinis grįžtamo šilumnešio slėgis per 5 minutes', 1080, 1, NULL, NULL),
	(829, 52, 3, 11, 3, 0, 28, 10, 69, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio slėgių skirtumas per 5 minutes', 1068, 1, NULL, NULL),
	(830, 53, 0, 11, 2, 0, 2, 10, 71, NULL, 'Šilumnešio šilumos kiekis per 5 minutes', 1064, 1, NULL, NULL),
	(831, 53, 1, 11, 2, 0, 2, 10, 71, NULL, 'Tiekiamo šilumnešio šilumos kiekis per 5 minutes', 1064, 1, NULL, NULL),
	(832, 53, 2, 11, 2, 0, 2, 10, 71, NULL, 'Grįžtamo šilumnešio šilumos kiekis per 5 minutes', 1076, 1, NULL, NULL),
	(833, 53, 3, 11, 2, 0, 2, 10, 71, NULL, 'Sunaudotos šilumnešio šilumos kiekis per 5 minutes', 1719, 1, NULL, NULL),
	(834, 53, 0, 11, 3, 0, 1, 10, 70, NULL, 'Vidutinė šilumnešio šilumos galia per 5 minutes', 1716, 1, NULL, NULL),
	(835, 53, 1, 11, 3, 0, 1, 10, 70, NULL, 'Vidutinė tiekiamo šilumnešio šilumos galia per 5 minutes', 1002, 1, NULL, NULL),
	(836, 53, 2, 11, 3, 0, 1, 10, 70, NULL, 'Vidutinė grįžtamo šilumnešio šilumos galia per 5 minutes', 1728, 1, NULL, NULL),
	(837, 53, 3, 11, 3, 0, 1, 10, 70, NULL, 'Vidutinė sunaudota šilumnešio šilumos galia per 5 minutes', 1002, 1, NULL, NULL),
	(838, 58, 0, 11, 2, 0, 31, 10, 59, NULL, 'Šalto vandens tūrio kiekis per 5 minutes', 1214, 1, NULL, NULL),
	(839, 58, 1, 11, 2, 0, 31, 10, 59, NULL, 'Tiekiamo šalto vandens tūrio kiekis per 5 minutes', 1214, 1, NULL, NULL),
	(840, 58, 2, 11, 2, 0, 31, 10, 59, NULL, 'Grįžtamo šalto vandens tūrio kiekis per 5 minutes', 1259, 1, NULL, NULL),
	(841, 58, 3, 11, 2, 0, 31, 10, 59, NULL, 'Tiekiamo ir grįžtamo šalto vandens tūrio kiekių skirtumas per 5 minutes', 1214, 1, NULL, NULL),
	(842, 58, 0, 11, 3, 0, 32, 10, 60, NULL, 'Vidutinis šalto vandens tūrio debitas per 5 minutes', 1260, 1, NULL, NULL),
	(843, 58, 1, 11, 3, 0, 32, 10, 60, NULL, 'Vidutinis tiekiamo šalto vandens tūrio debitas per 5 minutes', 1260, 1, NULL, NULL),
	(844, 58, 2, 11, 3, 0, 32, 10, 60, NULL, 'Vidutinis grįžtamo šalto vandens tūrio debitas per 5 minutes', 1262, 1, NULL, NULL),
	(845, 58, 3, 11, 3, 0, 32, 10, 60, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens tūrio debito skirtumas per 5 minutes', 1260, 1, NULL, NULL),
	(846, 1, 1, 11, 2, 0, 2, 10, 14, NULL, 'A+ energija per 5 minutes', 709, 1, NULL, NULL),
	(847, 1, 2, 11, 2, 0, 2, 10, 14, NULL, 'A- energija per 5 minutes', 710, 1, NULL, NULL),
	(848, 3, 1, 11, 2, 0, 4, 10, 15, NULL, 'R+ energija per 5 minutes', 711, 1, NULL, NULL),
	(849, 3, 2, 11, 2, 0, 4, 10, 15, NULL, 'R- energija per 5 minutes', 712, 1, NULL, NULL),
	(850, 1, 1, 11, 3, 0, 1, 10, 13, '1.0.1.29.0.0', 'Vidutinė P+ galia per 5 minutes', 49, 1, NULL, NULL),
	(851, 1, 2, 11, 3, 0, 1, 10, 13, '1.0.2.29.0.0', 'Vidutinė P- galia per 5 minutes', 50, 1, NULL, NULL),
	(852, 3, 1, 11, 3, 0, 3, 10, 16, '1.0.3.29.0.0', 'Vidutinė Q+ galia per 5 minutes', 51, 1, NULL, NULL),
	(853, 3, 2, 11, 3, 0, 3, 10, 16, '1.0.4.29.0.0', 'Vidutinė Q- galia per 5 minutes', 52, 1, NULL, NULL),
	(854, 54, 0, 11, 3, 0, 27, 10, 72, NULL, 'Vidutinė šilumnešio temperatūra per 5 minutes', 1067, 1, NULL, NULL),
	(855, 54, 1, 11, 3, 0, 27, 10, 72, NULL, 'Vidutinė tiekiamo šilumnešio temperatūra per 5 minutes', 1067, 1, NULL, NULL),
	(856, 54, 2, 11, 3, 0, 27, 10, 72, NULL, 'Vidutinė grįžtamo šilumnešio temperatūra per 5 minutes', 1079, 1, NULL, NULL),
	(857, 54, 3, 11, 3, 0, 27, 10, 72, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas per 5 minutes', 1090, 1, NULL, NULL),
	(858, 55, 0, 11, 2, 0, 31, 10, 74, NULL, 'Šilumnešio tūrio kiekis per 5 minutes', 1066, 1, NULL, NULL),
	(859, 55, 1, 11, 2, 0, 31, 10, 74, NULL, 'Tiekiamo šilumnešio tūrio kiekis per 5 minutes', 1066, 1, NULL, NULL),
	(860, 55, 2, 11, 2, 0, 31, 10, 74, NULL, 'Grįžtamo šilumnešio tūrio kiekis per 5 minutes', 1078, 1, NULL, NULL),
	(861, 55, 3, 11, 2, 0, 31, 10, 74, NULL, 'Tiekiamo ir grįžtamo šilumnešio tūrio kiekių skirtumas per 5 minutes', 1737, 1, NULL, NULL),
	(862, 55, 0, 11, 3, 0, 32, 10, 73, NULL, 'Vidutinis šilumnešio tūrio debitas per 5 minutes', 1714, 1, NULL, NULL),
	(863, 55, 1, 11, 3, 0, 32, 10, 73, NULL, 'Vidutinis tiekiamo šilumnešio tūrio debitas per 5 minutes', 1714, 1, NULL, NULL),
	(864, 55, 2, 11, 3, 0, 32, 10, 73, NULL, 'Vidutinis grįžtamo šilumnešio tūrio debitas per 5 minutes', 1730, 1, NULL, NULL),
	(865, 55, 3, 11, 3, 0, 32, 10, 73, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio tūrio debito skirtumas per 5 minutes', 1011, 1, NULL, NULL),
	(866, 56, 0, 11, 2, 0, 34, 10, 56, NULL, 'Šalto vandens šilumos kiekis per 5 minutes', 1212, 1, NULL, NULL),
	(867, 56, 1, 11, 2, 0, 34, 10, 56, NULL, 'Tiekiamo šalto vandens šilumos kiekis per 5 minutes', 1212, 1, NULL, NULL),
	(868, 56, 2, 11, 2, 0, 34, 10, 56, NULL, 'Grįžtamo šalto vandens šilumos kiekis per 5 minutes', 1238, 1, NULL, NULL),
	(869, 56, 3, 11, 2, 0, 34, 10, 56, NULL, 'Tiekiamo ir grįžtamo šalto vandens šilumos kiekių skirtumas per 5 minutes', 1240, 1, NULL, NULL),
	(870, 56, 0, 11, 3, 0, 33, 10, 57, NULL, 'Vidutinė šalto vandens šilumos galia per 5 minutes', 1232, 1, NULL, NULL),
	(871, 56, 1, 11, 3, 0, 33, 10, 57, NULL, 'Vidutinė tiekiamo šalto vandens šilumos galia per 5 minutes', 1232, 1, NULL, NULL),
	(872, 56, 2, 11, 3, 0, 33, 10, 57, NULL, 'Vidutinė grįžtamo šalto vandens šilumos galia per 5 minutes', 1234, 1, NULL, NULL),
	(873, 56, 3, 11, 3, 0, 33, 10, 57, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens šilumos galių skirtumas per 5 minutes', 1236, 1, NULL, NULL),
	(874, 57, 0, 11, 3, 0, 27, 10, 58, NULL, 'Vidutinė šalto vandens temperatūra per 5 minutes', 1215, 1, NULL, NULL),
	(875, 57, 1, 11, 3, 0, 27, 10, 58, NULL, 'Vidutinė tiekiamo šalto vandens temperatūra per 5 minutes', 1215, 1, NULL, NULL),
	(876, 57, 2, 11, 3, 0, 27, 10, 58, NULL, 'Vidutinė grįžtamo šalto vandens temperatūra per 5 minutes', 1256, 1, NULL, NULL),
	(877, 57, 3, 11, 3, 0, 27, 10, 58, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens temperatūrų skirtumas per 5 minutes', 1257, 1, NULL, NULL),
	(878, 39, 0, 12, 2, 0, 35, 11, 2, NULL, 'Dujų koreguotos masės kiekis per 10 minučių', 1130, 1, NULL, NULL),
	(879, 39, 0, 12, 3, 0, 36, 11, 1, NULL, 'Vidutinis dujų koreguotos masės debitas per 10 minučių', 1135, 1, NULL, NULL),
	(880, 40, 0, 12, 2, 0, 31, 11, 4, NULL, 'Dujų koreguoto tūrio kiekis per 10 minučių', 1131, 1, NULL, NULL),
	(881, 40, 0, 12, 3, 0, 32, 11, 3, NULL, 'Vidutinis dujų koreguoto tūrio debitas per 10 minučių', 1137, 1, NULL, NULL),
	(882, 41, 0, 12, 2, 0, 35, 11, 6, NULL, 'Dujų masės kiekis per 10 minučių', 1128, 1, NULL, NULL),
	(883, 41, 0, 12, 3, 0, 36, 11, 5, NULL, 'Vidutinis dujų masės debitas per 10 minučių', 1134, 1, NULL, NULL),
	(884, 42, 0, 12, 3, 0, 28, 11, 7, NULL, 'Vidutinis dujų slėgis per 10 minučių', 1138, 1, NULL, NULL),
	(885, 43, 0, 12, 2, 0, 34, 11, 9, NULL, 'Dujų šilumos kiekis per 10 minučių', 1127, 1, NULL, NULL),
	(886, 43, 0, 12, 3, 0, 33, 11, 8, NULL, 'Vidutinė dujų šilumos galia per 10 minučių', 1132, 1, NULL, NULL),
	(887, 44, 0, 12, 3, 0, 27, 11, 10, NULL, 'Vidutinė dujų temperatūra per 10 minučių', 1133, 1, NULL, NULL),
	(888, 45, 0, 12, 2, 0, 31, 11, 12, NULL, 'Dujų tūrio kiekis per 10 minučių', 1129, 1, NULL, NULL),
	(889, 45, 0, 12, 3, 0, 32, 11, 11, NULL, 'Vidutinis dujų tūrio debitas per 10 minučių', 1136, 1, NULL, NULL),
	(890, 46, 0, 12, 3, 0, 27, 11, 55, NULL, 'Vidutinė oro temperatūra per 10 minučių', 1302, 1, NULL, NULL),
	(891, 47, 0, 12, 3, 0, 30, 11, 61, NULL, 'Vidutinis šalčio slėgis per 10 minučių', 1004, 1, NULL, NULL),
	(892, 47, 1, 12, 3, 0, 30, 11, 61, NULL, 'Vidutinis tiekiamo šalčio slėgis per 10 minučių', 1004, 1, NULL, NULL),
	(893, 47, 2, 12, 3, 0, 30, 11, 61, NULL, 'Vidutinis grįžtamo šalčio slėgis per 10 minučių', 1004, 1, NULL, NULL),
	(894, 47, 3, 12, 3, 0, 30, 11, 61, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio slėgio skirtumas per 10 minučių', 1004, 1, NULL, NULL),
	(895, 48, 0, 12, 2, 0, 2, 11, 62, NULL, 'Šalčio energija per 10 minučių', 1001, 1, NULL, NULL),
	(896, 48, 1, 12, 2, 0, 2, 11, 62, NULL, 'Tiekiamo šalčio energija per 10 minučių', 1001, 1, NULL, NULL),
	(897, 48, 2, 12, 2, 0, 2, 11, 62, NULL, 'Grįžtamo šalčio energija per 10 minučių', 1001, 1, NULL, NULL),
	(898, 48, 3, 12, 2, 0, 2, 11, 62, NULL, 'Tiekiamo ir grįžtamo šalčio šilumos kiekių skirtumas per 10 minučių', 1001, 1, NULL, NULL),
	(899, 48, 0, 12, 3, 0, 1, 11, 63, NULL, 'Vidutinė šalčio galia per 10 minučių', 1002, 1, NULL, NULL),
	(900, 48, 1, 12, 3, 0, 1, 11, 63, NULL, 'Vidutinė tiekiamo šalčio galia per 10 minučių', 1002, 1, NULL, NULL),
	(901, 48, 2, 12, 3, 0, 1, 11, 63, NULL, 'Vidutinė grįžtamo šalčio galia per 10 minučių', 1002, 1, NULL, NULL),
	(902, 48, 3, 12, 3, 0, 1, 11, 63, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio šilumos galios skirtumas per 10 minučių', 1002, 1, NULL, NULL),
	(903, 49, 0, 12, 3, 0, 27, 11, 64, NULL, 'Vidutinė šalčio temperatūra per 10 minučių', 1003, 1, NULL, NULL),
	(904, 49, 1, 12, 3, 0, 27, 11, 64, NULL, 'Vidutinė tiekiamo šalčio temperatūra per 10 minučių', 1003, 1, NULL, NULL),
	(905, 49, 2, 12, 3, 0, 27, 11, 64, NULL, 'Vidutinė grįžtamo šalčio temperatūra per 10 minučių', 1008, 1, NULL, NULL),
	(906, 49, 3, 12, 3, 0, 27, 11, 64, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio temperatūrų skirtumas per 10 minučių', 1009, 1, NULL, NULL),
	(907, 50, 0, 12, 2, 0, 31, 11, 66, NULL, 'Šalčio tūrio kiekis per 10 minučių', 1010, 1, NULL, NULL),
	(908, 50, 1, 12, 2, 0, 31, 11, 66, NULL, 'Tiekiamo šalčio tūrio kiekis per 10 minučių', 1010, 1, NULL, NULL),
	(909, 50, 2, 12, 2, 0, 31, 11, 66, NULL, 'Grįžtamo šalčio tūrio kiekis per 10 minučių', 1010, 1, NULL, NULL),
	(910, 50, 3, 12, 2, 0, 31, 11, 66, NULL, 'Tiekiamo ir grįžtamo šalčio tūrio kiekių skirtumas per 10 minučių', 1010, 1, NULL, NULL),
	(911, 50, 0, 12, 3, 0, 32, 11, 65, NULL, 'Vidutinis šalčio tūrio debitas per 10 minučių', 1011, 1, NULL, NULL),
	(912, 50, 1, 12, 3, 0, 32, 11, 65, NULL, 'Vidutinis tiekiamo šalčio tūrio debitas per 10 minučių', 1011, 1, NULL, NULL),
	(913, 50, 2, 12, 3, 0, 32, 11, 65, NULL, 'Vidutinis grįžtamo šalčio tūrio debitas per 10 minučių', 1011, 1, NULL, NULL),
	(914, 50, 3, 12, 3, 0, 32, 11, 65, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio tūrio debito skirtumas per 10 minučių', 1011, 1, NULL, NULL),
	(915, 51, 0, 12, 2, 0, 35, 11, 68, NULL, 'Šilumnešio masės kiekis per 10 minučių', 1065, 1, NULL, NULL),
	(916, 51, 1, 12, 2, 0, 35, 11, 68, NULL, 'Tiekiamo šilumnešio masės kiekis per 10 minučių', 1065, 1, NULL, NULL),
	(917, 51, 2, 12, 2, 0, 35, 11, 68, NULL, 'Grįžtamo šilumnešio masės kiekis per 10 minučių', 1077, 1, NULL, NULL),
	(918, 51, 3, 12, 2, 0, 35, 11, 68, NULL, 'Tiekiamo ir grįžtamo šilumnešio masės kiekių skirtumas per 10 minučių', 1088, 1, NULL, NULL),
	(919, 51, 0, 12, 3, 0, 36, 11, 67, NULL, 'Vidutinis šilumnešio masės debitas per 10 minučių', 1715, 1, NULL, NULL),
	(920, 51, 1, 12, 3, 0, 36, 11, 67, NULL, 'Vidutinis tiekiamo šilumnešio masės debitas per 10 minučių', 1006, 1, NULL, NULL),
	(921, 51, 2, 12, 3, 0, 36, 11, 67, NULL, 'Vidutinis grįžtamo šilumnešio masės debitas per 10 minučių', 1732, 1, NULL, NULL),
	(922, 51, 3, 12, 3, 0, 36, 11, 67, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio masės debito skirtumas per 10 minučių', 1006, 1, NULL, NULL),
	(923, 52, 0, 12, 3, 0, 28, 11, 69, NULL, 'Vidutinis šilumnešio slėgis per 10 minučių', 1068, 1, NULL, NULL),
	(924, 52, 1, 12, 3, 0, 28, 11, 69, NULL, 'Vidutinis tiekiamo šilumnešio slėgis per 10 minučių', 1068, 1, NULL, NULL),
	(925, 52, 2, 12, 3, 0, 28, 11, 69, NULL, 'Vidutinis grįžtamo šilumnešio slėgis per 10 minučių', 1080, 1, NULL, NULL),
	(926, 52, 3, 12, 3, 0, 28, 11, 69, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio slėgių skirtumas per 10 minučių', 1068, 1, NULL, NULL),
	(927, 53, 0, 12, 2, 0, 2, 11, 71, NULL, 'Šilumnešio šilumos kiekis per 10 minučių', 1064, 1, NULL, NULL),
	(928, 53, 1, 12, 2, 0, 2, 11, 71, NULL, 'Tiekiamo šilumnešio šilumos kiekis per 10 minučių', 1064, 1, NULL, NULL),
	(929, 53, 2, 12, 2, 0, 2, 11, 71, NULL, 'Grįžtamo šilumnešio šilumos kiekis per 10 minučių', 1076, 1, NULL, NULL),
	(930, 53, 3, 12, 2, 0, 2, 11, 71, NULL, 'Sunaudotos šilumnešio šilumos kiekis per 10 minučių', 1719, 1, NULL, NULL),
	(931, 53, 0, 12, 3, 0, 1, 11, 70, NULL, 'Vidutinė šilumnešio šilumos galia per 10 minučių', 1716, 1, NULL, NULL),
	(932, 53, 1, 12, 3, 0, 1, 11, 70, NULL, 'Vidutinė tiekiamo šilumnešio šilumos galia per 10 minučių', 1002, 1, NULL, NULL),
	(933, 53, 2, 12, 3, 0, 1, 11, 70, NULL, 'Vidutinė grįžtamo šilumnešio šilumos galia per 10 minučių', 1728, 1, NULL, NULL),
	(934, 53, 3, 12, 3, 0, 1, 11, 70, NULL, 'Vidutinė sunaudota šilumnešio šilumos galia per 10 minučių', 1002, 1, NULL, NULL),
	(935, 58, 0, 12, 2, 0, 31, 11, 59, NULL, 'Šalto vandens tūrio kiekis per 10 minučių', 1214, 1, NULL, NULL),
	(936, 58, 1, 12, 2, 0, 31, 11, 59, NULL, 'Tiekiamo šalto vandens tūrio kiekis per 10 minučių', 1214, 1, NULL, NULL),
	(937, 58, 2, 12, 2, 0, 31, 11, 59, NULL, 'Grįžtamo šalto vandens tūrio kiekis per 10 minučių', 1259, 1, NULL, NULL),
	(938, 58, 3, 12, 2, 0, 31, 11, 59, NULL, 'Tiekiamo ir grįžtamo šalto vandens tūrio kiekių skirtumas per 10 minučių', 1214, 1, NULL, NULL),
	(939, 58, 0, 12, 3, 0, 32, 11, 60, NULL, 'Vidutinis šalto vandens tūrio debitas per 10 minučių', 1260, 1, NULL, NULL),
	(940, 58, 1, 12, 3, 0, 32, 11, 60, NULL, 'Vidutinis tiekiamo šalto vandens tūrio debitas per 10 minučių', 1260, 1, NULL, NULL),
	(941, 58, 2, 12, 3, 0, 32, 11, 60, NULL, 'Vidutinis grįžtamo šalto vandens tūrio debitas per 10 minučių', 1262, 1, NULL, NULL),
	(942, 58, 3, 12, 3, 0, 32, 11, 60, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens tūrio debito skirtumas per 10 minučių', 1260, 1, NULL, NULL),
	(943, 1, 1, 12, 2, 0, 2, 11, 14, NULL, 'A+ energija per 10 minučių', 709, 1, NULL, NULL),
	(944, 1, 2, 12, 2, 0, 2, 11, 14, NULL, 'A- energija per 10 minučių', 710, 1, NULL, NULL),
	(945, 3, 1, 12, 2, 0, 4, 11, 15, NULL, 'R+ energija per 10 minučių', 711, 1, NULL, NULL),
	(946, 3, 2, 12, 2, 0, 4, 11, 15, NULL, 'R- energija per 10 minučių', 712, 1, NULL, NULL),
	(947, 1, 1, 12, 3, 0, 1, 11, 13, '1.0.1.29.0.0', 'Vidutinė P+ galia per 10 minučių', 49, 1, NULL, NULL),
	(948, 1, 2, 12, 3, 0, 1, 11, 13, '1.0.2.29.0.0', 'Vidutinė P- galia per 10 minučių', 50, 1, NULL, NULL),
	(949, 3, 1, 12, 3, 0, 3, 11, 16, '1.0.3.29.0.0', 'Vidutinė Q+ galia per 10 minučių', 51, 1, NULL, NULL),
	(950, 3, 2, 12, 3, 0, 3, 11, 16, '1.0.4.29.0.0', 'Vidutinė Q- galia per 10 minučių', 52, 1, NULL, NULL),
	(951, 54, 0, 12, 3, 0, 27, 11, 72, NULL, 'Vidutinė šilumnešio temperatūra per 10 minučių', 1067, 1, NULL, NULL),
	(952, 54, 1, 12, 3, 0, 27, 11, 72, NULL, 'Vidutinė tiekiamo šilumnešio temperatūra per 10 minučių', 1067, 1, NULL, NULL),
	(953, 54, 2, 12, 3, 0, 27, 11, 72, NULL, 'Vidutinė grįžtamo šilumnešio temperatūra per 10 minučių', 1079, 1, NULL, NULL),
	(954, 54, 3, 12, 3, 0, 27, 11, 72, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas per 10 minučių', 1090, 1, NULL, NULL),
	(955, 55, 0, 12, 2, 0, 31, 11, 74, NULL, 'Šilumnešio tūrio kiekis per 10 minučių', 1066, 1, NULL, NULL),
	(956, 55, 1, 12, 2, 0, 31, 11, 74, NULL, 'Tiekiamo šilumnešio tūrio kiekis per 10 minučių', 1066, 1, NULL, NULL),
	(957, 55, 2, 12, 2, 0, 31, 11, 74, NULL, 'Grįžtamo šilumnešio tūrio kiekis per 10 minučių', 1078, 1, NULL, NULL),
	(958, 55, 3, 12, 2, 0, 31, 11, 74, NULL, 'Tiekiamo ir grįžtamo šilumnešio tūrio kiekių skirtumas per 10 minučių', 1737, 1, NULL, NULL),
	(959, 55, 0, 12, 3, 0, 32, 11, 73, NULL, 'Vidutinis šilumnešio tūrio debitas per 10 minučių', 1714, 1, NULL, NULL),
	(960, 55, 1, 12, 3, 0, 32, 11, 73, NULL, 'Vidutinis tiekiamo šilumnešio tūrio debitas per 10 minučių', 1714, 1, NULL, NULL),
	(961, 55, 2, 12, 3, 0, 32, 11, 73, NULL, 'Vidutinis grįžtamo šilumnešio tūrio debitas per 10 minučių', 1730, 1, NULL, NULL),
	(962, 55, 3, 12, 3, 0, 32, 11, 73, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio tūrio debito skirtumas per 10 minučių', 1011, 1, NULL, NULL),
	(963, 56, 0, 12, 2, 0, 34, 11, 56, NULL, 'Šalto vandens šilumos kiekis per 10 minučių', 1212, 1, NULL, NULL),
	(964, 56, 1, 12, 2, 0, 34, 11, 56, NULL, 'Tiekiamo šalto vandens šilumos kiekis per 10 minučių', 1212, 1, NULL, NULL),
	(965, 56, 2, 12, 2, 0, 34, 11, 56, NULL, 'Grįžtamo šalto vandens šilumos kiekis per 10 minučių', 1238, 1, NULL, NULL),
	(966, 56, 3, 12, 2, 0, 34, 11, 56, NULL, 'Tiekiamo ir grįžtamo šalto vandens šilumos kiekių skirtumas per 10 minučių', 1240, 1, NULL, NULL),
	(967, 56, 0, 12, 3, 0, 33, 11, 57, NULL, 'Vidutinė šalto vandens šilumos galia per 10 minučių', 1232, 1, NULL, NULL),
	(968, 56, 1, 12, 3, 0, 33, 11, 57, NULL, 'Vidutinė tiekiamo šalto vandens šilumos galia per 10 minučių', 1232, 1, NULL, NULL),
	(969, 56, 2, 12, 3, 0, 33, 11, 57, NULL, 'Vidutinė grįžtamo šalto vandens šilumos galia per 10 minučių', 1234, 1, NULL, NULL),
	(970, 56, 3, 12, 3, 0, 33, 11, 57, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens šilumos galių skirtumas per 10 minučių', 1236, 1, NULL, NULL),
	(971, 57, 0, 12, 3, 0, 27, 11, 58, NULL, 'Vidutinė šalto vandens temperatūra per 10 minučių', 1215, 1, NULL, NULL),
	(972, 57, 1, 12, 3, 0, 27, 11, 58, NULL, 'Vidutinė tiekiamo šalto vandens temperatūra per 10 minučių', 1215, 1, NULL, NULL),
	(973, 57, 2, 12, 3, 0, 27, 11, 58, NULL, 'Vidutinė grįžtamo šalto vandens temperatūra per 10 minučių', 1256, 1, NULL, NULL),
	(974, 57, 3, 12, 3, 0, 27, 11, 58, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens temperatūrų skirtumas per 10 minučių', 1257, 1, NULL, NULL),
	(975, 39, 0, 13, 2, 0, 35, 12, 2, NULL, 'Dujų koreguotos masės kiekis per 15 minučių', 1130, 2, NULL, NULL),
	(976, 39, 0, 13, 3, 0, 36, 12, 1, NULL, 'Vidutinis dujų koreguotos masės debitas per 15 minučių', 1135, 2, NULL, NULL),
	(977, 40, 0, 13, 2, 0, 31, 12, 4, NULL, 'Dujų koreguoto tūrio kiekis per 15 minučių', 1131, 2, NULL, NULL),
	(978, 40, 0, 13, 3, 0, 32, 12, 3, NULL, 'Vidutinis dujų koreguoto tūrio debitas per 15 minučių', 1137, 2, NULL, NULL),
	(979, 41, 0, 13, 2, 0, 35, 12, 6, NULL, 'Dujų masės kiekis per 15 minučių', 1128, 2, NULL, NULL),
	(980, 41, 0, 13, 3, 0, 36, 12, 5, NULL, 'Vidutinis dujų masės debitas per 15 minučių', 1134, 2, NULL, NULL),
	(981, 42, 0, 13, 3, 0, 28, 12, 7, NULL, 'Vidutinis dujų slėgis per 15 minučių', 1138, 2, NULL, NULL),
	(982, 43, 0, 13, 2, 0, 34, 12, 9, NULL, 'Dujų šilumos kiekis per 15 minučių', 1127, 2, NULL, NULL),
	(983, 43, 0, 13, 3, 0, 33, 12, 8, NULL, 'Vidutinė dujų šilumos galia per 15 minučių', 1132, 2, NULL, NULL),
	(984, 44, 0, 13, 3, 0, 27, 12, 10, NULL, 'Vidutinė dujų temperatūra per 15 minučių', 1133, 2, NULL, NULL),
	(985, 45, 0, 13, 2, 0, 31, 12, 12, NULL, 'Dujų tūrio kiekis per 15 minučių', 1129, 2, NULL, NULL),
	(986, 45, 0, 13, 3, 0, 32, 12, 11, NULL, 'Vidutinis dujų tūrio debitas per 15 minučių', 1136, 2, NULL, NULL),
	(987, 46, 0, 13, 3, 0, 27, 12, 55, NULL, 'Vidutinė oro temperatūra per 15 minučių', 1302, 2, NULL, NULL),
	(988, 47, 0, 13, 3, 0, 30, 12, 61, NULL, 'Vidutinis šalčio slėgis per 15 minučių', 1004, 2, NULL, NULL),
	(989, 47, 1, 13, 3, 0, 30, 12, 61, NULL, 'Vidutinis tiekiamo šalčio slėgis per 15 minučių', 1004, 2, NULL, NULL),
	(990, 47, 2, 13, 3, 0, 30, 12, 61, NULL, 'Vidutinis grįžtamo šalčio slėgis per 15 minučių', 1004, 2, NULL, NULL),
	(991, 47, 3, 13, 3, 0, 30, 12, 61, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio slėgio skirtumas per 15 minučių', 1004, 2, NULL, NULL),
	(992, 48, 0, 13, 2, 0, 2, 12, 62, NULL, 'Šalčio energija per 15 minučių', 1001, 2, NULL, NULL),
	(993, 48, 1, 13, 2, 0, 2, 12, 62, NULL, 'Tiekiamo šalčio energija per 15 minučių', 1001, 2, NULL, NULL),
	(994, 48, 2, 13, 2, 0, 2, 12, 62, NULL, 'Grįžtamo šalčio energija per 15 minučių', 1001, 2, NULL, NULL),
	(995, 48, 3, 13, 2, 0, 2, 12, 62, NULL, 'Tiekiamo ir grįžtamo šalčio šilumos kiekių skirtumas per 15 minučių', 1001, 2, NULL, NULL),
	(996, 48, 0, 13, 3, 0, 1, 12, 63, NULL, 'Vidutinė šalčio galia per 15 minučių', 1002, 2, NULL, NULL),
	(997, 48, 1, 13, 3, 0, 1, 12, 63, NULL, 'Vidutinė tiekiamo šalčio galia per 15 minučių', 1002, 2, NULL, NULL),
	(998, 48, 2, 13, 3, 0, 1, 12, 63, NULL, 'Vidutinė grįžtamo šalčio galia per 15 minučių', 1002, 2, NULL, NULL),
	(999, 48, 3, 13, 3, 0, 1, 12, 63, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio šilumos galios skirtumas per 15 minučių', 1002, 2, NULL, NULL),
	(1000, 49, 0, 13, 3, 0, 27, 12, 64, NULL, 'Vidutinė šalčio temperatūra per 15 minučių', 1003, 2, NULL, NULL),
	(1001, 49, 1, 13, 3, 0, 27, 12, 64, NULL, 'Vidutinė tiekiamo šalčio temperatūra per 15 minučių', 1003, 2, NULL, NULL),
	(1002, 49, 2, 13, 3, 0, 27, 12, 64, NULL, 'Vidutinė grįžtamo šalčio temperatūra per 15 minučių', 1008, 2, NULL, NULL),
	(1003, 49, 3, 13, 3, 0, 27, 12, 64, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio temperatūrų skirtumas per 15 minučių', 1009, 2, NULL, NULL),
	(1004, 50, 0, 13, 2, 0, 31, 12, 66, NULL, 'Šalčio tūrio kiekis per 15 minučių', 1010, 2, NULL, NULL),
	(1005, 50, 1, 13, 2, 0, 31, 12, 66, NULL, 'Tiekiamo šalčio tūrio kiekis per 15 minučių', 1010, 2, NULL, NULL),
	(1006, 50, 2, 13, 2, 0, 31, 12, 66, NULL, 'Grįžtamo šalčio tūrio kiekis per 15 minučių', 1010, 2, NULL, NULL),
	(1007, 50, 3, 13, 2, 0, 31, 12, 66, NULL, 'Tiekiamo ir grįžtamo šalčio tūrio kiekių skirtumas per 15 minučių', 1010, 2, NULL, NULL),
	(1008, 50, 0, 13, 3, 0, 32, 12, 65, NULL, 'Vidutinis šalčio tūrio debitas per 15 minučių', 1011, 2, NULL, NULL),
	(1009, 50, 1, 13, 3, 0, 32, 12, 65, NULL, 'Vidutinis tiekiamo šalčio tūrio debitas per 15 minučių', 1011, 2, NULL, NULL),
	(1010, 50, 2, 13, 3, 0, 32, 12, 65, NULL, 'Vidutinis grįžtamo šalčio tūrio debitas per 15 minučių', 1011, 2, NULL, NULL),
	(1011, 50, 3, 13, 3, 0, 32, 12, 65, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio tūrio debito skirtumas per 15 minučių', 1011, 2, NULL, NULL),
	(1012, 51, 0, 13, 2, 0, 35, 12, 68, NULL, 'Šilumnešio masės kiekis per 15 minučių', 1065, 2, NULL, NULL),
	(1013, 51, 1, 13, 2, 0, 35, 12, 68, NULL, 'Tiekiamo šilumnešio masės kiekis per 15 minučių', 1065, 2, NULL, NULL),
	(1014, 51, 2, 13, 2, 0, 35, 12, 68, NULL, 'Grįžtamo šilumnešio masės kiekis per 15 minučių', 1077, 2, NULL, NULL),
	(1015, 51, 3, 13, 2, 0, 35, 12, 68, NULL, 'Tiekiamo ir grįžtamo šilumnešio masės kiekių skirtumas per 15 minučių', 1088, 2, NULL, NULL),
	(1016, 51, 0, 13, 3, 0, 36, 12, 67, NULL, 'Vidutinis šilumnešio masės debitas per 15 minučių', 1715, 2, NULL, NULL),
	(1017, 51, 1, 13, 3, 0, 36, 12, 67, NULL, 'Vidutinis tiekiamo šilumnešio masės debitas per 15 minučių', 1006, 2, NULL, NULL),
	(1018, 51, 2, 13, 3, 0, 36, 12, 67, NULL, 'Vidutinis grįžtamo šilumnešio masės debitas per 15 minučių', 1732, 2, NULL, NULL),
	(1019, 51, 3, 13, 3, 0, 36, 12, 67, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio masės debito skirtumas per 15 minučių', 1006, 2, NULL, NULL),
	(1020, 52, 0, 13, 3, 0, 28, 12, 69, NULL, 'Vidutinis šilumnešio slėgis per 15 minučių', 1068, 2, NULL, NULL),
	(1021, 52, 1, 13, 3, 0, 28, 12, 69, NULL, 'Vidutinis tiekiamo šilumnešio slėgis per 15 minučių', 1068, 2, NULL, NULL),
	(1022, 52, 2, 13, 3, 0, 28, 12, 69, NULL, 'Vidutinis grįžtamo šilumnešio slėgis per 15 minučių', 1080, 2, NULL, NULL),
	(1023, 52, 3, 13, 3, 0, 28, 12, 69, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio slėgių skirtumas per 15 minučių', 1068, 2, NULL, NULL),
	(1024, 53, 0, 13, 2, 0, 2, 12, 71, NULL, 'Šilumnešio šilumos kiekis per 15 minučių', 1064, 2, NULL, NULL),
	(1025, 53, 1, 13, 2, 0, 2, 12, 71, NULL, 'Tiekiamo šilumnešio šilumos kiekis per 15 minučių', 1064, 2, NULL, NULL),
	(1026, 53, 2, 13, 2, 0, 2, 12, 71, NULL, 'Grįžtamo šilumnešio šilumos kiekis per 15 minučių', 1076, 2, NULL, NULL),
	(1027, 53, 3, 13, 2, 0, 2, 12, 71, NULL, 'Sunaudotos šilumnešio šilumos kiekis per 15 minučių', 1719, 2, NULL, NULL),
	(1028, 53, 0, 13, 3, 0, 1, 12, 70, NULL, 'Vidutinė šilumnešio šilumos galia per 15 minučių', 1716, 2, NULL, NULL),
	(1029, 53, 1, 13, 3, 0, 1, 12, 70, NULL, 'Vidutinė tiekiamo šilumnešio šilumos galia per 15 minučių', 1002, 2, NULL, NULL),
	(1030, 53, 2, 13, 3, 0, 1, 12, 70, NULL, 'Vidutinė grįžtamo šilumnešio šilumos galia per 15 minučių', 1728, 2, NULL, NULL),
	(1031, 53, 3, 13, 3, 0, 1, 12, 70, NULL, 'Vidutinė sunaudota šilumnešio šilumos galia per 15 minučių', 1002, 2, NULL, NULL),
	(1032, 58, 0, 13, 2, 0, 31, 12, 59, NULL, 'Šalto vandens tūrio kiekis per 15 minučių', 1214, 2, NULL, NULL),
	(1033, 58, 1, 13, 2, 0, 31, 12, 59, NULL, 'Tiekiamo šalto vandens tūrio kiekis per 15 minučių', 1214, 2, NULL, NULL),
	(1034, 58, 2, 13, 2, 0, 31, 12, 59, NULL, 'Grįžtamo šalto vandens tūrio kiekis per 15 minučių', 1259, 2, NULL, NULL),
	(1035, 58, 3, 13, 2, 0, 31, 12, 59, NULL, 'Tiekiamo ir grįžtamo šalto vandens tūrio kiekių skirtumas per 15 minučių', 1214, 2, NULL, NULL),
	(1036, 58, 0, 13, 3, 0, 32, 12, 60, NULL, 'Vidutinis šalto vandens tūrio debitas per 15 minučių', 1260, 2, NULL, NULL),
	(1037, 58, 1, 13, 3, 0, 32, 12, 60, NULL, 'Vidutinis tiekiamo šalto vandens tūrio debitas per 15 minučių', 1260, 2, NULL, NULL),
	(1038, 58, 2, 13, 3, 0, 32, 12, 60, NULL, 'Vidutinis grįžtamo šalto vandens tūrio debitas per 15 minučių', 1262, 2, NULL, NULL),
	(1039, 58, 3, 13, 3, 0, 32, 12, 60, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens tūrio debito skirtumas per 15 minučių', 1260, 2, NULL, NULL),
	(1040, 1, 1, 13, 2, 0, 2, 12, 14, NULL, 'A+ energija per 15 minučių', 709, 2, NULL, NULL),
	(1041, 1, 2, 13, 2, 0, 2, 12, 14, NULL, 'A- energija per 15 minučių', 710, 2, NULL, NULL),
	(1042, 3, 1, 13, 2, 0, 4, 12, 15, NULL, 'R+ energija per 15 minučių', 711, 2, NULL, NULL),
	(1043, 3, 2, 13, 2, 0, 4, 12, 15, NULL, 'R- energija per 15 minučių', 712, 2, NULL, NULL),
	(1044, 1, 1, 13, 3, 0, 1, 12, 13, '1.0.1.29.0.0', 'Vidutinė P+ galia per 15 minučių', 49, 2, NULL, NULL),
	(1045, 1, 2, 13, 3, 0, 1, 12, 13, '1.0.2.29.0.0', 'Vidutinė P- galia per 15 minučių', 50, 2, NULL, NULL),
	(1046, 3, 1, 13, 3, 0, 3, 12, 16, '1.0.3.29.0.0', 'Vidutinė Q+ galia per 15 minučių', 51, 2, NULL, NULL),
	(1047, 3, 2, 13, 3, 0, 3, 12, 16, '1.0.4.29.0.0', 'Vidutinė Q- galia per 15 minučių', 52, 2, NULL, NULL),
	(1048, 54, 0, 13, 3, 0, 27, 12, 72, NULL, 'Vidutinė šilumnešio temperatūra per 15 minučių', 1067, 2, NULL, NULL),
	(1049, 54, 1, 13, 3, 0, 27, 12, 72, NULL, 'Vidutinė tiekiamo šilumnešio temperatūra per 15 minučių', 1067, 2, NULL, NULL),
	(1050, 54, 2, 13, 3, 0, 27, 12, 72, NULL, 'Vidutinė grįžtamo šilumnešio temperatūra per 15 minučių', 1079, 2, NULL, NULL),
	(1051, 54, 3, 13, 3, 0, 27, 12, 72, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas per 15 minučių', 1090, 2, NULL, NULL),
	(1052, 55, 0, 13, 2, 0, 31, 12, 74, NULL, 'Šilumnešio tūrio kiekis per 15 minučių', 1066, 2, NULL, NULL),
	(1053, 55, 1, 13, 2, 0, 31, 12, 74, NULL, 'Tiekiamo šilumnešio tūrio kiekis per 15 minučių', 1066, 2, NULL, NULL),
	(1054, 55, 2, 13, 2, 0, 31, 12, 74, NULL, 'Grįžtamo šilumnešio tūrio kiekis per 15 minučių', 1078, 2, NULL, NULL),
	(1055, 55, 3, 13, 2, 0, 31, 12, 74, NULL, 'Tiekiamo ir grįžtamo šilumnešio tūrio kiekių skirtumas per 15 minučių', 1737, 2, NULL, NULL),
	(1056, 55, 0, 13, 3, 0, 32, 12, 73, NULL, 'Vidutinis šilumnešio tūrio debitas per 15 minučių', 1714, 2, NULL, NULL),
	(1057, 55, 1, 13, 3, 0, 32, 12, 73, NULL, 'Vidutinis tiekiamo šilumnešio tūrio debitas per 15 minučių', 1714, 2, NULL, NULL),
	(1058, 55, 2, 13, 3, 0, 32, 12, 73, NULL, 'Vidutinis grįžtamo šilumnešio tūrio debitas per 15 minučių', 1730, 2, NULL, NULL),
	(1059, 55, 3, 13, 3, 0, 32, 12, 73, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio tūrio debito skirtumas per 15 minučių', 1011, 2, NULL, NULL),
	(1060, 56, 0, 13, 2, 0, 34, 12, 56, NULL, 'Šalto vandens šilumos kiekis per 15 minučių', 1212, 2, NULL, NULL),
	(1061, 56, 1, 13, 2, 0, 34, 12, 56, NULL, 'Tiekiamo šalto vandens šilumos kiekis per 15 minučių', 1212, 2, NULL, NULL),
	(1062, 56, 2, 13, 2, 0, 34, 12, 56, NULL, 'Grįžtamo šalto vandens šilumos kiekis per 15 minučių', 1238, 2, NULL, NULL),
	(1063, 56, 3, 13, 2, 0, 34, 12, 56, NULL, 'Tiekiamo ir grįžtamo šalto vandens šilumos kiekių skirtumas per 15 minučių', 1240, 2, NULL, NULL),
	(1064, 56, 0, 13, 3, 0, 33, 12, 57, NULL, 'Vidutinė šalto vandens šilumos galia per 15 minučių', 1232, 2, NULL, NULL),
	(1065, 56, 1, 13, 3, 0, 33, 12, 57, NULL, 'Vidutinė tiekiamo šalto vandens šilumos galia per 15 minučių', 1232, 2, NULL, NULL),
	(1066, 56, 2, 13, 3, 0, 33, 12, 57, NULL, 'Vidutinė grįžtamo šalto vandens šilumos galia per 15 minučių', 1234, 2, NULL, NULL),
	(1067, 56, 3, 13, 3, 0, 33, 12, 57, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens šilumos galių skirtumas per 15 minučių', 1236, 2, NULL, NULL),
	(1068, 57, 0, 13, 3, 0, 27, 12, 58, NULL, 'Vidutinė šalto vandens temperatūra per 15 minučių', 1215, 2, NULL, NULL),
	(1069, 57, 1, 13, 3, 0, 27, 12, 58, NULL, 'Vidutinė tiekiamo šalto vandens temperatūra per 15 minučių', 1215, 2, NULL, NULL),
	(1070, 57, 2, 13, 3, 0, 27, 12, 58, NULL, 'Vidutinė grįžtamo šalto vandens temperatūra per 15 minučių', 1256, 2, NULL, NULL),
	(1071, 57, 3, 13, 3, 0, 27, 12, 58, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens temperatūrų skirtumas per 15 minučių', 1257, 2, NULL, NULL),
	(1072, 39, 0, 14, 2, 0, 35, 13, 2, NULL, 'Dujų koreguotos masės kiekis per 20 minučių', 1130, 2, NULL, NULL),
	(1073, 39, 0, 14, 3, 0, 36, 13, 1, NULL, 'Vidutinis dujų koreguotos masės debitas per 20 minučių', 1135, 2, NULL, NULL),
	(1074, 40, 0, 14, 2, 0, 31, 13, 4, NULL, 'Dujų koreguoto tūrio kiekis per 20 minučių', 1131, 2, NULL, NULL),
	(1075, 40, 0, 14, 3, 0, 32, 13, 3, NULL, 'Vidutinis dujų koreguoto tūrio debitas per 20 minučių', 1137, 2, NULL, NULL),
	(1076, 41, 0, 14, 2, 0, 35, 13, 6, NULL, 'Dujų masės kiekis per 20 minučių', 1128, 2, NULL, NULL),
	(1077, 41, 0, 14, 3, 0, 36, 13, 5, NULL, 'Vidutinis dujų masės debitas per 20 minučių', 1134, 2, NULL, NULL),
	(1078, 42, 0, 14, 3, 0, 28, 13, 7, NULL, 'Vidutinis dujų slėgis per 20 minučių', 1138, 2, NULL, NULL),
	(1079, 43, 0, 14, 2, 0, 34, 13, 9, NULL, 'Dujų šilumos kiekis per 20 minučių', 1127, 2, NULL, NULL),
	(1080, 43, 0, 14, 3, 0, 33, 13, 8, NULL, 'Vidutinė dujų šilumos galia per 20 minučių', 1132, 2, NULL, NULL),
	(1081, 44, 0, 14, 3, 0, 27, 13, 10, NULL, 'Vidutinė dujų temperatūra per 20 minučių', 1133, 2, NULL, NULL),
	(1082, 45, 0, 14, 2, 0, 31, 13, 12, NULL, 'Dujų tūrio kiekis per 20 minučių', 1129, 2, NULL, NULL),
	(1083, 45, 0, 14, 3, 0, 32, 13, 11, NULL, 'Vidutinis dujų tūrio debitas per 20 minučių', 1136, 2, NULL, NULL),
	(1084, 46, 0, 14, 3, 0, 27, 13, 55, NULL, 'Vidutinė oro temperatūra per 20 minučių', 1302, 2, NULL, NULL),
	(1085, 47, 0, 14, 3, 0, 30, 13, 61, NULL, 'Vidutinis šalčio slėgis per 20 minučių', 1004, 2, NULL, NULL),
	(1086, 47, 1, 14, 3, 0, 30, 13, 61, NULL, 'Vidutinis tiekiamo šalčio slėgis per 20 minučių', 1004, 2, NULL, NULL),
	(1087, 47, 2, 14, 3, 0, 30, 13, 61, NULL, 'Vidutinis grįžtamo šalčio slėgis per 20 minučių', 1004, 2, NULL, NULL),
	(1088, 47, 3, 14, 3, 0, 30, 13, 61, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio slėgio skirtumas per 20 minučių', 1004, 2, NULL, NULL),
	(1089, 48, 0, 14, 2, 0, 2, 13, 62, NULL, 'Šalčio energija per 20 minučių', 1001, 2, NULL, NULL),
	(1090, 48, 1, 14, 2, 0, 2, 13, 62, NULL, 'Tiekiamo šalčio energija per 20 minučių', 1001, 2, NULL, NULL),
	(1091, 48, 2, 14, 2, 0, 2, 13, 62, NULL, 'Grįžtamo šalčio energija per 20 minučių', 1001, 2, NULL, NULL),
	(1092, 48, 3, 14, 2, 0, 2, 13, 62, NULL, 'Tiekiamo ir grįžtamo šalčio šilumos kiekių skirtumas per 20 minučių', 1001, 2, NULL, NULL),
	(1093, 48, 0, 14, 3, 0, 1, 13, 63, NULL, 'Vidutinė šalčio galia per 20 minučių', 1002, 2, NULL, NULL),
	(1094, 48, 1, 14, 3, 0, 1, 13, 63, NULL, 'Vidutinė tiekiamo šalčio galia per 20 minučių', 1002, 2, NULL, NULL),
	(1095, 48, 2, 14, 3, 0, 1, 13, 63, NULL, 'Vidutinė grįžtamo šalčio galia per 20 minučių', 1002, 2, NULL, NULL),
	(1096, 48, 3, 14, 3, 0, 1, 13, 63, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio šilumos galios skirtumas per 20 minučių', 1002, 2, NULL, NULL),
	(1097, 49, 0, 14, 3, 0, 27, 13, 64, NULL, 'Vidutinė šalčio temperatūra per 20 minučių', 1003, 2, NULL, NULL),
	(1098, 49, 1, 14, 3, 0, 27, 13, 64, NULL, 'Vidutinė tiekiamo šalčio temperatūra per 20 minučių', 1003, 2, NULL, NULL),
	(1099, 49, 2, 14, 3, 0, 27, 13, 64, NULL, 'Vidutinė grįžtamo šalčio temperatūra per 20 minučių', 1008, 2, NULL, NULL),
	(1100, 49, 3, 14, 3, 0, 27, 13, 64, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio temperatūrų skirtumas per 20 minučių', 1009, 2, NULL, NULL),
	(1101, 50, 0, 14, 2, 0, 31, 13, 66, NULL, 'Šalčio tūrio kiekis per 20 minučių', 1010, 2, NULL, NULL),
	(1102, 50, 1, 14, 2, 0, 31, 13, 66, NULL, 'Tiekiamo šalčio tūrio kiekis per 20 minučių', 1010, 2, NULL, NULL),
	(1103, 50, 2, 14, 2, 0, 31, 13, 66, NULL, 'Grįžtamo šalčio tūrio kiekis per 20 minučių', 1010, 2, NULL, NULL),
	(1104, 50, 3, 14, 2, 0, 31, 13, 66, NULL, 'Tiekiamo ir grįžtamo šalčio tūrio kiekių skirtumas per 20 minučių', 1010, 2, NULL, NULL),
	(1105, 50, 0, 14, 3, 0, 32, 13, 65, NULL, 'Vidutinis šalčio tūrio debitas per 20 minučių', 1011, 2, NULL, NULL),
	(1106, 50, 1, 14, 3, 0, 32, 13, 65, NULL, 'Vidutinis tiekiamo šalčio tūrio debitas per 20 minučių', 1011, 2, NULL, NULL),
	(1107, 50, 2, 14, 3, 0, 32, 13, 65, NULL, 'Vidutinis grįžtamo šalčio tūrio debitas per 20 minučių', 1011, 2, NULL, NULL),
	(1108, 50, 3, 14, 3, 0, 32, 13, 65, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio tūrio debito skirtumas per 20 minučių', 1011, 2, NULL, NULL),
	(1109, 51, 0, 14, 2, 0, 35, 13, 68, NULL, 'Šilumnešio masės kiekis per 20 minučių', 1065, 2, NULL, NULL),
	(1110, 51, 1, 14, 2, 0, 35, 13, 68, NULL, 'Tiekiamo šilumnešio masės kiekis per 20 minučių', 1065, 2, NULL, NULL),
	(1111, 51, 2, 14, 2, 0, 35, 13, 68, NULL, 'Grįžtamo šilumnešio masės kiekis per 20 minučių', 1077, 2, NULL, NULL),
	(1112, 51, 3, 14, 2, 0, 35, 13, 68, NULL, 'Tiekiamo ir grįžtamo šilumnešio masės kiekių skirtumas per 20 minučių', 1088, 2, NULL, NULL),
	(1113, 51, 0, 14, 3, 0, 36, 13, 67, NULL, 'Vidutinis šilumnešio masės debitas per 20 minučių', 1715, 2, NULL, NULL),
	(1114, 51, 1, 14, 3, 0, 36, 13, 67, NULL, 'Vidutinis tiekiamo šilumnešio masės debitas per 20 minučių', 1006, 2, NULL, NULL),
	(1115, 51, 2, 14, 3, 0, 36, 13, 67, NULL, 'Vidutinis grįžtamo šilumnešio masės debitas per 20 minučių', 1732, 2, NULL, NULL),
	(1116, 51, 3, 14, 3, 0, 36, 13, 67, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio masės debito skirtumas per 20 minučių', 1006, 2, NULL, NULL),
	(1117, 52, 0, 14, 3, 0, 28, 13, 69, NULL, 'Vidutinis šilumnešio slėgis per 20 minučių', 1068, 2, NULL, NULL),
	(1118, 52, 1, 14, 3, 0, 28, 13, 69, NULL, 'Vidutinis tiekiamo šilumnešio slėgis per 20 minučių', 1068, 2, NULL, NULL),
	(1119, 52, 2, 14, 3, 0, 28, 13, 69, NULL, 'Vidutinis grįžtamo šilumnešio slėgis per 20 minučių', 1080, 2, NULL, NULL),
	(1120, 52, 3, 14, 3, 0, 28, 13, 69, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio slėgių skirtumas per 20 minučių', 1068, 2, NULL, NULL),
	(1121, 53, 0, 14, 2, 0, 2, 13, 71, NULL, 'Šilumnešio šilumos kiekis per 20 minučių', 1064, 2, NULL, NULL),
	(1122, 53, 1, 14, 2, 0, 2, 13, 71, NULL, 'Tiekiamo šilumnešio šilumos kiekis per 20 minučių', 1064, 2, NULL, NULL),
	(1123, 53, 2, 14, 2, 0, 2, 13, 71, NULL, 'Grįžtamo šilumnešio šilumos kiekis per 20 minučių', 1076, 2, NULL, NULL),
	(1124, 53, 3, 14, 2, 0, 2, 13, 71, NULL, 'Sunaudotos šilumnešio šilumos kiekis per 20 minučių', 1719, 2, NULL, NULL),
	(1125, 53, 0, 14, 3, 0, 1, 13, 70, NULL, 'Vidutinė šilumnešio šilumos galia per 20 minučių', 1716, 2, NULL, NULL),
	(1126, 53, 1, 14, 3, 0, 1, 13, 70, NULL, 'Vidutinė tiekiamo šilumnešio šilumos galia per 20 minučių', 1002, 2, NULL, NULL),
	(1127, 53, 2, 14, 3, 0, 1, 13, 70, NULL, 'Vidutinė grįžtamo šilumnešio šilumos galia per 20 minučių', 1728, 2, NULL, NULL),
	(1128, 53, 3, 14, 3, 0, 1, 13, 70, NULL, 'Vidutinė sunaudota šilumnešio šilumos galia per 20 minučių', 1002, 2, NULL, NULL),
	(1129, 58, 0, 14, 2, 0, 31, 13, 59, NULL, 'Šalto vandens tūrio kiekis per 20 minučių', 1214, 2, NULL, NULL),
	(1130, 58, 1, 14, 2, 0, 31, 13, 59, NULL, 'Tiekiamo šalto vandens tūrio kiekis per 20 minučių', 1214, 2, NULL, NULL),
	(1131, 58, 2, 14, 2, 0, 31, 13, 59, NULL, 'Grįžtamo šalto vandens tūrio kiekis per 20 minučių', 1259, 2, NULL, NULL),
	(1132, 58, 3, 14, 2, 0, 31, 13, 59, NULL, 'Tiekiamo ir grįžtamo šalto vandens tūrio kiekių skirtumas per 20 minučių', 1214, 2, NULL, NULL),
	(1133, 58, 0, 14, 3, 0, 32, 13, 60, NULL, 'Vidutinis šalto vandens tūrio debitas per 20 minučių', 1260, 2, NULL, NULL),
	(1134, 58, 1, 14, 3, 0, 32, 13, 60, NULL, 'Vidutinis tiekiamo šalto vandens tūrio debitas per 20 minučių', 1260, 2, NULL, NULL),
	(1135, 58, 2, 14, 3, 0, 32, 13, 60, NULL, 'Vidutinis grįžtamo šalto vandens tūrio debitas per 20 minučių', 1262, 2, NULL, NULL),
	(1136, 58, 3, 14, 3, 0, 32, 13, 60, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens tūrio debito skirtumas per 20 minučių', 1260, 2, NULL, NULL),
	(1137, 1, 1, 14, 2, 0, 2, 13, 14, NULL, 'A+ energija per 20 minučių', 709, 2, NULL, NULL),
	(1138, 1, 2, 14, 2, 0, 2, 13, 14, NULL, 'A- energija per 20 minučių', 710, 2, NULL, NULL),
	(1139, 3, 1, 14, 2, 0, 4, 13, 15, NULL, 'R+ energija per 20 minučių', 711, 2, NULL, NULL),
	(1140, 3, 2, 14, 2, 0, 4, 13, 15, NULL, 'R- energija per 20 minučių', 712, 2, NULL, NULL),
	(1141, 1, 1, 14, 3, 0, 1, 13, 13, '1.0.1.29.0.0', 'Vidutinė P+ galia per 20 minučių', 49, 2, NULL, NULL),
	(1142, 1, 2, 14, 3, 0, 1, 13, 13, '1.0.2.29.0.0', 'Vidutinė P- galia per 20 minučių', 50, 2, NULL, NULL),
	(1143, 3, 1, 14, 3, 0, 3, 13, 16, '1.0.3.29.0.0', 'Vidutinė Q+ galia per 20 minučių', 51, 2, NULL, NULL),
	(1144, 3, 2, 14, 3, 0, 3, 13, 16, '1.0.4.29.0.0', 'Vidutinė Q- galia per 20 minučių', 52, 2, NULL, NULL),
	(1145, 54, 0, 14, 3, 0, 27, 13, 72, NULL, 'Vidutinė šilumnešio temperatūra per 20 minučių', 1067, 2, NULL, NULL),
	(1146, 54, 1, 14, 3, 0, 27, 13, 72, NULL, 'Vidutinė tiekiamo šilumnešio temperatūra per 20 minučių', 1067, 2, NULL, NULL),
	(1147, 54, 2, 14, 3, 0, 27, 13, 72, NULL, 'Vidutinė grįžtamo šilumnešio temperatūra per 20 minučių', 1079, 2, NULL, NULL),
	(1148, 54, 3, 14, 3, 0, 27, 13, 72, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas per 20 minučių', 1090, 2, NULL, NULL),
	(1149, 55, 0, 14, 2, 0, 31, 13, 74, NULL, 'Šilumnešio tūrio kiekis per 20 minučių', 1066, 2, NULL, NULL),
	(1150, 55, 1, 14, 2, 0, 31, 13, 74, NULL, 'Tiekiamo šilumnešio tūrio kiekis per 20 minučių', 1066, 2, NULL, NULL),
	(1151, 55, 2, 14, 2, 0, 31, 13, 74, NULL, 'Grįžtamo šilumnešio tūrio kiekis per 20 minučių', 1078, 2, NULL, NULL),
	(1152, 55, 3, 14, 2, 0, 31, 13, 74, NULL, 'Tiekiamo ir grįžtamo šilumnešio tūrio kiekių skirtumas per 20 minučių', 1737, 2, NULL, NULL),
	(1153, 55, 0, 14, 3, 0, 32, 13, 73, NULL, 'Vidutinis šilumnešio tūrio debitas per 20 minučių', 1714, 2, NULL, NULL),
	(1154, 55, 1, 14, 3, 0, 32, 13, 73, NULL, 'Vidutinis tiekiamo šilumnešio tūrio debitas per 20 minučių', 1714, 2, NULL, NULL),
	(1155, 55, 2, 14, 3, 0, 32, 13, 73, NULL, 'Vidutinis grįžtamo šilumnešio tūrio debitas per 20 minučių', 1730, 2, NULL, NULL),
	(1156, 55, 3, 14, 3, 0, 32, 13, 73, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio tūrio debito skirtumas per 20 minučių', 1011, 2, NULL, NULL),
	(1157, 56, 0, 14, 2, 0, 34, 13, 56, NULL, 'Šalto vandens šilumos kiekis per 20 minučių', 1212, 2, NULL, NULL),
	(1158, 56, 1, 14, 2, 0, 34, 13, 56, NULL, 'Tiekiamo šalto vandens šilumos kiekis per 20 minučių', 1212, 2, NULL, NULL),
	(1159, 56, 2, 14, 2, 0, 34, 13, 56, NULL, 'Grįžtamo šalto vandens šilumos kiekis per 20 minučių', 1238, 2, NULL, NULL),
	(1160, 56, 3, 14, 2, 0, 34, 13, 56, NULL, 'Tiekiamo ir grįžtamo šalto vandens šilumos kiekių skirtumas per 20 minučių', 1240, 2, NULL, NULL),
	(1161, 56, 0, 14, 3, 0, 33, 13, 57, NULL, 'Vidutinė šalto vandens šilumos galia per 20 minučių', 1232, 2, NULL, NULL),
	(1162, 56, 1, 14, 3, 0, 33, 13, 57, NULL, 'Vidutinė tiekiamo šalto vandens šilumos galia per 20 minučių', 1232, 2, NULL, NULL),
	(1163, 56, 2, 14, 3, 0, 33, 13, 57, NULL, 'Vidutinė grįžtamo šalto vandens šilumos galia per 20 minučių', 1234, 2, NULL, NULL),
	(1164, 56, 3, 14, 3, 0, 33, 13, 57, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens šilumos galių skirtumas per 20 minučių', 1236, 2, NULL, NULL),
	(1165, 57, 0, 14, 3, 0, 27, 13, 58, NULL, 'Vidutinė šalto vandens temperatūra per 20 minučių', 1215, 2, NULL, NULL),
	(1166, 57, 1, 14, 3, 0, 27, 13, 58, NULL, 'Vidutinė tiekiamo šalto vandens temperatūra per 20 minučių', 1215, 2, NULL, NULL),
	(1167, 57, 2, 14, 3, 0, 27, 13, 58, NULL, 'Vidutinė grįžtamo šalto vandens temperatūra per 20 minučių', 1256, 2, NULL, NULL),
	(1168, 57, 3, 14, 3, 0, 27, 13, 58, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens temperatūrų skirtumas per 20 minučių', 1257, 2, NULL, NULL),
	(1169, 39, 0, 3, 2, 0, 35, 3, 2, NULL, 'Dujų koreguotos masės kiekis per 30 minučių', 1130, 2, NULL, NULL),
	(1170, 39, 0, 3, 3, 0, 36, 3, 1, NULL, 'Vidutinis dujų koreguotos masės debitas per 30 minučių', 1135, 2, NULL, NULL),
	(1171, 40, 0, 3, 2, 0, 31, 3, 4, NULL, 'Dujų koreguoto tūrio kiekis per 30 minučių', 1131, 2, NULL, NULL),
	(1172, 40, 0, 3, 3, 0, 32, 3, 3, NULL, 'Vidutinis dujų koreguoto tūrio debitas per 30 minučių', 1137, 2, NULL, NULL),
	(1173, 41, 0, 3, 2, 0, 35, 3, 6, NULL, 'Dujų masės kiekis per 30 minučių', 1128, 2, NULL, NULL),
	(1174, 41, 0, 3, 3, 0, 36, 3, 5, NULL, 'Vidutinis dujų masės debitas per 30 minučių', 1134, 2, NULL, NULL),
	(1175, 42, 0, 3, 3, 0, 28, 3, 7, NULL, 'Vidutinis dujų slėgis per 30 minučių', 1138, 2, NULL, NULL),
	(1176, 43, 0, 3, 2, 0, 34, 3, 9, NULL, 'Dujų šilumos kiekis per 30 minučių', 1127, 2, NULL, NULL),
	(1177, 43, 0, 3, 3, 0, 33, 3, 8, NULL, 'Vidutinė dujų šilumos galia per 30 minučių', 1132, 2, NULL, NULL),
	(1178, 44, 0, 3, 3, 0, 27, 3, 10, NULL, 'Vidutinė dujų temperatūra per 30 minučių', 1133, 2, NULL, NULL),
	(1179, 45, 0, 3, 2, 0, 31, 3, 12, NULL, 'Dujų tūrio kiekis per 30 minučių', 1129, 2, NULL, NULL),
	(1180, 45, 0, 3, 3, 0, 32, 3, 11, NULL, 'Vidutinis dujų tūrio debitas per 30 minučių', 1136, 2, NULL, NULL),
	(1181, 46, 0, 3, 3, 0, 27, 3, 55, NULL, 'Vidutinė oro temperatūra per 30 minučių', 1302, 2, NULL, NULL),
	(1182, 47, 0, 3, 3, 0, 30, 3, 61, NULL, 'Vidutinis šalčio slėgis per 30 minučių', 1004, 2, NULL, NULL),
	(1183, 47, 1, 3, 3, 0, 30, 3, 61, NULL, 'Vidutinis tiekiamo šalčio slėgis per 30 minučių', 1004, 2, NULL, NULL),
	(1184, 47, 2, 3, 3, 0, 30, 3, 61, NULL, 'Vidutinis grįžtamo šalčio slėgis per 30 minučių', 1004, 2, NULL, NULL),
	(1185, 47, 3, 3, 3, 0, 30, 3, 61, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio slėgio skirtumas per 30 minučių', 1004, 2, NULL, NULL),
	(1186, 48, 0, 3, 2, 0, 2, 3, 62, NULL, 'Šalčio energija per 30 minučių', 1001, 2, NULL, NULL),
	(1187, 48, 1, 3, 2, 0, 2, 3, 62, NULL, 'Tiekiamo šalčio energija per 30 minučių', 1001, 2, NULL, NULL),
	(1188, 48, 2, 3, 2, 0, 2, 3, 62, NULL, 'Grįžtamo šalčio energija per 30 minučių', 1001, 2, NULL, NULL),
	(1189, 48, 3, 3, 2, 0, 2, 3, 62, NULL, 'Tiekiamo ir grįžtamo šalčio šilumos kiekių skirtumas per 30 minučių', 1001, 2, NULL, NULL),
	(1190, 48, 0, 3, 3, 0, 1, 3, 63, NULL, 'Vidutinė šalčio galia per 30 minučių', 1002, 2, NULL, NULL),
	(1191, 48, 1, 3, 3, 0, 1, 3, 63, NULL, 'Vidutinė tiekiamo šalčio galia per 30 minučių', 1002, 2, NULL, NULL),
	(1192, 48, 2, 3, 3, 0, 1, 3, 63, NULL, 'Vidutinė grįžtamo šalčio galia per 30 minučių', 1002, 2, NULL, NULL),
	(1193, 48, 3, 3, 3, 0, 1, 3, 63, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio šilumos galios skirtumas per 30 minučių', 1002, 2, NULL, NULL),
	(1194, 49, 0, 3, 3, 0, 27, 3, 64, NULL, 'Vidutinė šalčio temperatūra per 30 minučių', 1003, 2, NULL, NULL),
	(1195, 49, 1, 3, 3, 0, 27, 3, 64, NULL, 'Vidutinė tiekiamo šalčio temperatūra per 30 minučių', 1003, 2, NULL, NULL),
	(1196, 49, 2, 3, 3, 0, 27, 3, 64, NULL, 'Vidutinė grįžtamo šalčio temperatūra per 30 minučių', 1008, 2, NULL, NULL),
	(1197, 49, 3, 3, 3, 0, 27, 3, 64, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio temperatūrų skirtumas per 30 minučių', 1009, 2, NULL, NULL),
	(1198, 50, 0, 3, 2, 0, 31, 3, 66, NULL, 'Šalčio tūrio kiekis per 30 minučių', 1010, 2, NULL, NULL),
	(1199, 50, 1, 3, 2, 0, 31, 3, 66, NULL, 'Tiekiamo šalčio tūrio kiekis per 30 minučių', 1010, 2, NULL, NULL),
	(1200, 50, 2, 3, 2, 0, 31, 3, 66, NULL, 'Grįžtamo šalčio tūrio kiekis per 30 minučių', 1010, 2, NULL, NULL),
	(1201, 50, 3, 3, 2, 0, 31, 3, 66, NULL, 'Tiekiamo ir grįžtamo šalčio tūrio kiekių skirtumas per 30 minučių', 1010, 2, NULL, NULL),
	(1202, 50, 0, 3, 3, 0, 32, 3, 65, NULL, 'Vidutinis šalčio tūrio debitas per 30 minučių', 1011, 2, NULL, NULL),
	(1203, 50, 1, 3, 3, 0, 32, 3, 65, NULL, 'Vidutinis tiekiamo šalčio tūrio debitas per 30 minučių', 1011, 2, NULL, NULL),
	(1204, 50, 2, 3, 3, 0, 32, 3, 65, NULL, 'Vidutinis grįžtamo šalčio tūrio debitas per 30 minučių', 1011, 2, NULL, NULL),
	(1205, 50, 3, 3, 3, 0, 32, 3, 65, NULL, 'Vidutinis tiekiamo ir grįžtamo šalčio tūrio debito skirtumas per 30 minučių', 1011, 2, NULL, NULL),
	(1206, 51, 0, 3, 2, 0, 35, 3, 68, NULL, 'Šilumnešio masės kiekis per 30 minučių', 1065, 2, NULL, NULL),
	(1207, 51, 1, 3, 2, 0, 35, 3, 68, NULL, 'Tiekiamo šilumnešio masės kiekis per 30 minučių', 1065, 2, NULL, NULL),
	(1208, 51, 2, 3, 2, 0, 35, 3, 68, NULL, 'Grįžtamo šilumnešio masės kiekis per 30 minučių', 1077, 2, NULL, NULL),
	(1209, 51, 3, 3, 2, 0, 35, 3, 68, NULL, 'Tiekiamo ir grįžtamo šilumnešio masės kiekių skirtumas per 30 minučių', 1088, 2, NULL, NULL),
	(1210, 51, 0, 3, 3, 0, 36, 3, 67, NULL, 'Vidutinis šilumnešio masės debitas per 30 minučių', 1715, 2, NULL, NULL),
	(1211, 51, 1, 3, 3, 0, 36, 3, 67, NULL, 'Vidutinis tiekiamo šilumnešio masės debitas per 30 minučių', 1006, 2, NULL, NULL),
	(1212, 51, 2, 3, 3, 0, 36, 3, 67, NULL, 'Vidutinis grįžtamo šilumnešio masės debitas per 30 minučių', 1732, 2, NULL, NULL),
	(1213, 51, 3, 3, 3, 0, 36, 3, 67, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio masės debito skirtumas per 30 minučių', 1006, 2, NULL, NULL),
	(1214, 52, 0, 3, 3, 0, 28, 3, 69, NULL, 'Vidutinis šilumnešio slėgis per 30 minučių', 1068, 2, NULL, NULL),
	(1215, 52, 1, 3, 3, 0, 28, 3, 69, NULL, 'Vidutinis tiekiamo šilumnešio slėgis per 30 minučių', 1068, 2, NULL, NULL),
	(1216, 52, 2, 3, 3, 0, 28, 3, 69, NULL, 'Vidutinis grįžtamo šilumnešio slėgis per 30 minučių', 1080, 2, NULL, NULL),
	(1217, 52, 3, 3, 3, 0, 28, 3, 69, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio slėgių skirtumas per 30 minučių', 1068, 2, NULL, NULL),
	(1218, 53, 0, 3, 2, 0, 2, 3, 71, NULL, 'Šilumnešio šilumos kiekis per 30 minučių', 1064, 2, NULL, NULL),
	(1219, 53, 1, 3, 2, 0, 2, 3, 71, NULL, 'Tiekiamo šilumnešio šilumos kiekis per 30 minučių', 1064, 2, NULL, NULL),
	(1220, 53, 2, 3, 2, 0, 2, 3, 71, NULL, 'Grįžtamo šilumnešio šilumos kiekis per 30 minučių', 1076, 2, NULL, NULL),
	(1221, 53, 3, 3, 2, 0, 2, 3, 71, NULL, 'Sunaudotos šilumnešio šilumos kiekis per 30 minučių', 1719, 2, NULL, NULL),
	(1222, 53, 0, 3, 3, 0, 1, 3, 70, NULL, 'Vidutinė šilumnešio šilumos galia per 30 minučių', 1716, 2, NULL, NULL),
	(1223, 53, 1, 3, 3, 0, 1, 3, 70, NULL, 'Vidutinė tiekiamo šilumnešio šilumos galia per 30 minučių', 1002, 2, NULL, NULL),
	(1224, 53, 2, 3, 3, 0, 1, 3, 70, NULL, 'Vidutinė grįžtamo šilumnešio šilumos galia per 30 minučių', 1728, 2, NULL, NULL),
	(1225, 53, 3, 3, 3, 0, 1, 3, 70, NULL, 'Vidutinė sunaudota šilumnešio šilumos galia per 30 minučių', 1002, 2, NULL, NULL),
	(1226, 58, 0, 3, 2, 0, 31, 3, 59, NULL, 'Šalto vandens tūrio kiekis per 30 minučių', 1214, 2, NULL, NULL),
	(1227, 58, 1, 3, 2, 0, 31, 3, 59, NULL, 'Tiekiamo šalto vandens tūrio kiekis per 30 minučių', 1214, 2, NULL, NULL),
	(1228, 58, 2, 3, 2, 0, 31, 3, 59, NULL, 'Grįžtamo šalto vandens tūrio kiekis per 30 minučių', 1259, 2, NULL, NULL),
	(1229, 58, 3, 3, 2, 0, 31, 3, 59, NULL, 'Tiekiamo ir grįžtamo šalto vandens tūrio kiekių skirtumas per 30 minučių', 1214, 2, NULL, NULL),
	(1230, 58, 0, 3, 3, 0, 32, 3, 60, NULL, 'Vidutinis šalto vandens tūrio debitas per 30 minučių', 1260, 2, NULL, NULL),
	(1231, 58, 1, 3, 3, 0, 32, 3, 60, NULL, 'Vidutinis tiekiamo šalto vandens tūrio debitas per 30 minučių', 1260, 2, NULL, NULL),
	(1232, 58, 2, 3, 3, 0, 32, 3, 60, NULL, 'Vidutinis grįžtamo šalto vandens tūrio debitas per 30 minučių', 1262, 2, NULL, NULL),
	(1233, 58, 3, 3, 3, 0, 32, 3, 60, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens tūrio debito skirtumas per 30 minučių', 1260, 2, NULL, NULL),
	(1234, 1, 1, 3, 2, 0, 2, 3, 14, NULL, 'A+ energija per 30 minučių', 709, 2, NULL, NULL),
	(1235, 1, 2, 3, 2, 0, 2, 3, 14, NULL, 'A- energija per 30 minučių', 710, 2, NULL, NULL),
	(1236, 3, 1, 3, 2, 0, 4, 3, 15, NULL, 'R+ energija per 30 minučių', 711, 2, NULL, NULL),
	(1237, 3, 2, 3, 2, 0, 4, 3, 15, NULL, 'R- energija per 30 minučių', 712, 2, NULL, NULL),
	(1238, 54, 0, 3, 3, 0, 27, 3, 72, NULL, 'Vidutinė šilumnešio temperatūra per 30 minučių', 1067, 2, NULL, NULL),
	(1239, 54, 1, 3, 3, 0, 27, 3, 72, NULL, 'Vidutinė tiekiamo šilumnešio temperatūra per 30 minučių', 1067, 2, NULL, NULL),
	(1240, 54, 2, 3, 3, 0, 27, 3, 72, NULL, 'Vidutinė grįžtamo šilumnešio temperatūra per 30 minučių', 1079, 2, NULL, NULL),
	(1241, 54, 3, 3, 3, 0, 27, 3, 72, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas per 30 minučių', 1090, 2, NULL, NULL),
	(1242, 55, 0, 3, 2, 0, 31, 3, 74, NULL, 'Šilumnešio tūrio kiekis per 30 minučių', 1066, 2, NULL, NULL),
	(1243, 55, 1, 3, 2, 0, 31, 3, 74, NULL, 'Tiekiamo šilumnešio tūrio kiekis per 30 minučių', 1066, 2, NULL, NULL),
	(1244, 55, 2, 3, 2, 0, 31, 3, 74, NULL, 'Grįžtamo šilumnešio tūrio kiekis per 30 minučių', 1078, 2, NULL, NULL),
	(1245, 55, 3, 3, 2, 0, 31, 3, 74, NULL, 'Tiekiamo ir grįžtamo šilumnešio tūrio kiekių skirtumas per 30 minučių', 1737, 2, NULL, NULL),
	(1246, 55, 0, 3, 3, 0, 32, 3, 73, NULL, 'Vidutinis šilumnešio tūrio debitas per 30 minučių', 1714, 2, NULL, NULL),
	(1247, 55, 1, 3, 3, 0, 32, 3, 73, NULL, 'Vidutinis tiekiamo šilumnešio tūrio debitas per 30 minučių', 1714, 2, NULL, NULL),
	(1248, 55, 2, 3, 3, 0, 32, 3, 73, NULL, 'Vidutinis grįžtamo šilumnešio tūrio debitas per 30 minučių', 1730, 2, NULL, NULL),
	(1249, 55, 3, 3, 3, 0, 32, 3, 73, NULL, 'Vidutinis tiekiamo ir grįžtamo šilumnešio tūrio debito skirtumas per 30 minučių', 1011, 2, NULL, NULL),
	(1250, 56, 0, 3, 2, 0, 34, 3, 56, NULL, 'Šalto vandens šilumos kiekis per 30 minučių', 1212, 2, NULL, NULL),
	(1251, 56, 1, 3, 2, 0, 34, 3, 56, NULL, 'Tiekiamo šalto vandens šilumos kiekis per 30 minučių', 1212, 2, NULL, NULL),
	(1252, 56, 2, 3, 2, 0, 34, 3, 56, NULL, 'Grįžtamo šalto vandens šilumos kiekis per 30 minučių', 1238, 2, NULL, NULL),
	(1253, 56, 3, 3, 2, 0, 34, 3, 56, NULL, 'Tiekiamo ir grįžtamo šalto vandens šilumos kiekių skirtumas per 30 minučių', 1240, 2, NULL, NULL),
	(1254, 56, 0, 3, 3, 0, 33, 3, 57, NULL, 'Vidutinė šalto vandens šilumos galia per 30 minučių', 1232, 2, NULL, NULL),
	(1255, 56, 1, 3, 3, 0, 33, 3, 57, NULL, 'Vidutinė tiekiamo šalto vandens šilumos galia per 30 minučių', 1232, 2, NULL, NULL),
	(1256, 56, 2, 3, 3, 0, 33, 3, 57, NULL, 'Vidutinė grįžtamo šalto vandens šilumos galia per 30 minučių', 1234, 2, NULL, NULL),
	(1257, 56, 3, 3, 3, 0, 33, 3, 57, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens šilumos galių skirtumas per 30 minučių', 1236, 2, NULL, NULL),
	(1258, 57, 0, 3, 3, 0, 27, 3, 58, NULL, 'Vidutinė šalto vandens temperatūra per 30 minučių', 1215, 2, NULL, NULL),
	(1259, 57, 1, 3, 3, 0, 27, 3, 58, NULL, 'Vidutinė tiekiamo šalto vandens temperatūra per 30 minučių', 1215, 2, NULL, NULL),
	(1260, 57, 2, 3, 3, 0, 27, 3, 58, NULL, 'Vidutinė grįžtamo šalto vandens temperatūra per 30 minučių', 1256, 2, NULL, NULL),
	(1261, 57, 3, 3, 3, 0, 27, 3, 58, NULL, 'Vidutinis tiekiamo ir grįžtamo šalto vandens temperatūrų skirtumas per 30 minučių', 1257, 2, NULL, NULL),
	(1262, 61, 1, 3, 2, 0, 31, 3, 53, NULL, 'Tiekiamo karšto vandens tūrio kiekis per 30 minučių', 1214, 2, NULL, NULL),
	(1263, 61, 2, 3, 2, 0, 31, 3, 53, NULL, 'Grįžtamo karšto vandens tūrio kiekis per 30 minučių', 1259, 2, NULL, NULL),
	(1264, 61, 3, 3, 2, 0, 31, 3, 53, NULL, 'Tiekiamo ir grįžtamo karšto vandens tūrio kiekių skirtumas per 30 minučių', 1214, 2, NULL, NULL),
	(1265, 61, 0, 3, 3, 0, 32, 3, 54, NULL, 'Vidutinis karšto vandens tūrio debitas per 30 minučių', 1260, 2, NULL, NULL),
	(1266, 61, 1, 3, 3, 0, 32, 3, 54, NULL, 'Vidutinis tiekiamo karšto vandens tūrio debitas per 30 minučių', 1260, 2, NULL, NULL),
	(1267, 61, 2, 3, 3, 0, 32, 3, 54, NULL, 'Vidutinis grįžtamo karšto vandens tūrio debitas per 30 minučių', 1262, 2, NULL, NULL),
	(1268, 61, 3, 3, 3, 0, 32, 3, 54, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens tūrio debito skirtumas per 30 minučių', 1260, 2, NULL, NULL),
	(1269, 59, 0, 3, 2, 0, 34, 3, 51, NULL, 'Karšto vandens šilumos kiekis per 30 minučių', 1212, 2, NULL, NULL),
	(1270, 59, 1, 3, 2, 0, 34, 3, 51, NULL, 'Tiekiamo karšto vandens šilumos kiekis per 30 minučių', 1212, 2, NULL, NULL),
	(1271, 59, 2, 3, 2, 0, 34, 3, 51, NULL, 'Grįžtamo karšto vandens šilumos kiekis per 30 minučių', 1238, 2, NULL, NULL),
	(1272, 59, 3, 3, 2, 0, 34, 3, 51, NULL, 'Sunaudotos karšto vandens šilumos kiekis per 30 minučių', 1240, 2, NULL, NULL),
	(1273, 59, 0, 3, 3, 0, 33, 3, 50, NULL, 'Vidutinė karšto vandens šilumos galia per 30 minučių', 1232, 2, NULL, NULL),
	(1274, 59, 1, 3, 3, 0, 33, 3, 50, NULL, 'Vidutinė tiekiamo karšto vandens šilumos galia per 30 minučių', 1232, 2, NULL, NULL),
	(1275, 59, 2, 3, 3, 0, 33, 3, 50, NULL, 'Vidutinė grįžtamo karšto vandens šilumos galia per 30 minučių', 1234, 2, NULL, NULL),
	(1276, 59, 3, 3, 3, 0, 33, 3, 50, NULL, 'Vidutinė sunaudota karšto vandens šilumos galia per 30 minučių', 1236, 2, NULL, NULL),
	(1277, 60, 0, 3, 3, 0, 27, 3, 52, NULL, 'Vidutinė karšto vandens temperatūra per 30 minučių', 1215, 2, NULL, NULL),
	(1278, 60, 1, 3, 3, 0, 27, 3, 52, NULL, 'Vidutinė tiekiamo karšto vandens temperatūra per 30 minučių', 1215, 2, NULL, NULL),
	(1279, 60, 2, 3, 3, 0, 27, 3, 52, NULL, 'Vidutinė grįžtamo karšto vandens temperatūra per 30 minučių', 1256, 2, NULL, NULL),
	(1280, 60, 3, 3, 3, 0, 27, 3, 52, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens temperatūrų skirtumas per 30 minučių', 1257, 2, NULL, NULL),
	(1281, 42, 3, 4, 3, 0, 28, 4, 7, NULL, 'Vidutinis tiekiamų ir grįžtamų dujų slėgių skirtumas per valandą', 1109, 2, NULL, NULL),
	(1282, 42, 3, 5, 3, 0, 28, 5, 7, NULL, 'Vidutinis tiekiamų ir grįžtamų dujų slėgių skirtumas per parą', 1109, 3, NULL, NULL),
	(1283, 42, 3, 6, 3, 0, 28, 6, 7, NULL, 'Vidutinis tiekiamų ir grįžtamų dujų slėgių skirtumas per mėnesį', 1109, 4, NULL, NULL),
	(1284, 42, 3, 7, 1, 0, 28, 7, 7, NULL, 'Momentinis tiekiamų ir grįžtamų dujų slėgių skirtumas', 1109, 6, NULL, NULL),
	(1285, 42, 3, 1, 3, 0, 28, 1, 7, NULL, 'Vidutinis tiekiamų ir grįžtamų dujų slėgių skirtumas per minutę', 1109, 1, NULL, NULL),
	(1286, 42, 3, 2, 3, 0, 28, 2, 7, NULL, 'Vidutinis tiekiamų ir grįžtamų dujų slėgių skirtumas per 2 minutes', 1109, 1, NULL, NULL),
	(1287, 42, 3, 9, 3, 0, 28, 8, 7, NULL, 'Vidutinis tiekiamų ir grįžtamų dujų slėgių skirtumas per 3 minutes', 1109, 1, NULL, NULL),
	(1288, 42, 3, 10, 3, 0, 28, 9, 7, NULL, 'Vidutinis tiekiamų ir grįžtamų dujų slėgių skirtumas per 4 minutes', 1109, 1, NULL, NULL),
	(1289, 42, 3, 11, 3, 0, 28, 10, 7, NULL, 'Vidutinis tiekiamų ir grįžtamų dujų slėgių skirtumas per 5 minutes', 1109, 1, NULL, NULL),
	(1290, 42, 3, 12, 3, 0, 28, 11, 7, NULL, 'Vidutinis tiekiamų ir grįžtamų dujų slėgių skirtumas per 10 minučių', 1109, 1, NULL, NULL),
	(1291, 42, 3, 13, 3, 0, 28, 12, 7, NULL, 'Vidutinis tiekiamų ir grįžtamų dujų slėgių skirtumas per 15 minučių', 1109, 2, NULL, NULL),
	(1292, 42, 3, 14, 3, 0, 28, 13, 7, NULL, 'Vidutinis tiekiamų ir grįžtamų dujų slėgių skirtumas per 20 minučių', 1109, 2, NULL, NULL),
	(1293, 42, 3, 3, 3, 0, 28, 3, 7, NULL, 'Vidutinis tiekiamų ir grįžtamų dujų slėgių skirtumas per 30 minučių', 1109, 2, NULL, NULL),
	(1294, 3, 5, 4, 3, 0, 3, 4, 16, NULL, 'Vidutinė Q1 galia per valandą', 210, 2, NULL, NULL),
	(1295, 3, 5, 6, 2, 0, 4, 6, 15, NULL, 'R1 energija per mėnesį', 314, 4, NULL, NULL),
	(1296, 3, 5, 5, 2, 0, 4, 5, 15, NULL, 'R1 energija per parą', 318, 3, NULL, NULL),
	(1297, 3, 5, 5, 3, 0, 3, 5, 16, NULL, 'Vidutinė Q1 galia per parą', 210, 3, NULL, NULL),
	(1298, 3, 5, 8, 2, 1, 4, 7, 15, NULL, 'Suminė R1 energija pagal 1 tarifą', 138, 5, NULL, NULL),
	(1299, 3, 5, 8, 2, 2, 4, 7, 15, NULL, 'Suminė R1 energija pagal 2 tarifą', 144, 5, NULL, NULL),
	(1300, 3, 5, 8, 2, 3, 4, 7, 15, NULL, 'Suminė R1 energija pagal 3 tarifą', 150, 5, NULL, NULL),
	(1301, 3, 5, 8, 2, 4, 4, 7, 15, NULL, 'Suminė R1 energija pagal 4 tarifą', 156, 5, NULL, NULL),
	(1302, 3, 5, 6, 2, 1, 4, 6, 15, NULL, 'R1 energija pagal 1 tarifą per mėnesį', 162, 4, NULL, NULL),
	(1303, 3, 5, 6, 2, 2, 4, 6, 15, NULL, 'R1 energija pagal 2 tarifą per mėnesį', 168, 4, NULL, NULL),
	(1304, 3, 5, 6, 2, 3, 4, 6, 15, NULL, 'R1 energija pagal 3 tarifą per mėnesį', 174, 4, NULL, NULL),
	(1305, 3, 5, 6, 2, 4, 4, 6, 15, NULL, 'R1 energija pagal 4 tarifą per mėnesį', 180, 4, NULL, NULL),
	(1306, 3, 5, 5, 2, 1, 4, 5, 15, NULL, 'R1 energija pagal 1 tarifą per parą', 186, 3, NULL, NULL),
	(1307, 3, 5, 5, 2, 2, 4, 5, 15, NULL, 'R1 energija pagal 2 tarifą per parą', 192, 3, NULL, NULL),
	(1308, 3, 5, 5, 2, 3, 4, 5, 15, NULL, 'R1 energija pagal 3 tarifą per parą', 198, 3, NULL, NULL),
	(1309, 3, 5, 5, 2, 4, 4, 5, 15, NULL, 'R1 energija pagal 4 tarifą per parą', 204, 3, NULL, NULL),
	(1310, 3, 5, 3, 3, 0, 3, 3, 16, NULL, 'Vidutinė Q1 galia per 30 minučių', 210, 2, NULL, NULL),
	(1311, 3, 5, 14, 2, 0, 4, 13, 15, NULL, 'R1 energija per 20 minučių', 713, 2, NULL, NULL),
	(1312, 3, 5, 14, 3, 0, 3, 13, 16, NULL, 'Vidutinė Q1 galia per 20 minučių', 210, 2, NULL, NULL),
	(1313, 3, 5, 1, 2, 0, 4, 1, 15, NULL, 'R1 energija per minutę', 713, 1, NULL, NULL),
	(1314, 3, 5, 1, 3, 0, 3, 1, 16, NULL, 'Vidutinė Q1 galia per minutę', 210, 1, NULL, NULL),
	(1315, 3, 5, 2, 2, 0, 4, 2, 15, NULL, 'R1 energija per 2 minutes', 713, 1, NULL, NULL),
	(1316, 3, 5, 2, 3, 0, 3, 2, 16, NULL, 'Vidutinė Q1 galia per 2 minutes', 210, 1, NULL, NULL),
	(1317, 3, 5, 9, 2, 0, 4, 8, 15, NULL, 'R1 energija per 3 minutes', 713, 1, NULL, NULL),
	(1318, 3, 5, 9, 3, 0, 3, 8, 16, NULL, 'Vidutinė Q1 galia per 3 minutes', 210, 1, NULL, NULL),
	(1319, 3, 5, 10, 2, 0, 4, 9, 15, NULL, 'R1 energija per 4 minutes', 713, 1, NULL, NULL),
	(1320, 3, 5, 10, 3, 0, 3, 9, 16, NULL, 'Vidutinė Q1 galia per 4 minutes', 210, 1, NULL, NULL),
	(1321, 3, 5, 11, 2, 0, 4, 10, 15, NULL, 'R1 energija per 5 minutes', 713, 1, NULL, NULL),
	(1322, 3, 5, 11, 3, 0, 3, 10, 16, NULL, 'Vidutinė Q1 galia per 5 minutes', 210, 1, NULL, NULL),
	(1323, 3, 5, 12, 2, 0, 4, 11, 15, NULL, 'R1 energija per 10 minučių', 713, 1, NULL, NULL),
	(1324, 3, 5, 12, 3, 0, 3, 11, 16, NULL, 'Vidutinė Q1 galia per 10 minučių', 210, 1, NULL, NULL),
	(1325, 3, 5, 13, 2, 0, 4, 12, 15, NULL, 'R1 energija per 15 minučių', 713, 2, NULL, NULL),
	(1326, 3, 5, 13, 3, 0, 3, 12, 16, NULL, 'Vidutinė Q1 galia per 15 minučių', 210, 2, NULL, NULL),
	(1327, 3, 5, 3, 2, 0, 4, 3, 15, NULL, 'R1 energija per 30 minučių', 713, 2, NULL, NULL),
	(1328, 3, 6, 4, 3, 0, 3, 4, 16, NULL, 'Vidutinė Q2 galia per valandą', 211, 2, NULL, NULL),
	(1329, 3, 6, 6, 2, 0, 4, 6, 15, NULL, 'R2 energija per mėnesį', 315, 4, NULL, NULL),
	(1330, 3, 6, 5, 2, 0, 4, 5, 15, NULL, 'R2 energija per parą', 319, 3, NULL, NULL),
	(1331, 3, 6, 5, 3, 0, 3, 5, 16, NULL, 'Vidutinė Q2 galia per parą', 211, 3, NULL, NULL),
	(1332, 3, 6, 8, 2, 1, 4, 7, 15, NULL, 'Suminė R2 energija pagal 1 tarifą', 139, 5, NULL, NULL),
	(1333, 3, 6, 8, 2, 2, 4, 7, 15, NULL, 'Suminė R2 energija pagal 2 tarifą', 145, 5, NULL, NULL),
	(1334, 3, 6, 8, 2, 3, 4, 7, 15, NULL, 'Suminė R2 energija pagal 3 tarifą', 151, 5, NULL, NULL),
	(1335, 3, 6, 8, 2, 4, 4, 7, 15, NULL, 'Suminė R2 energija pagal 4 tarifą', 157, 5, NULL, NULL),
	(1336, 3, 6, 6, 2, 1, 4, 6, 15, NULL, 'R2 energija pagal 1 tarifą per mėnesį', 163, 4, NULL, NULL),
	(1337, 3, 6, 6, 2, 2, 4, 6, 15, NULL, 'R2 energija pagal 2 tarifą per mėnesį', 169, 4, NULL, NULL),
	(1338, 3, 6, 6, 2, 3, 4, 6, 15, NULL, 'R2 energija pagal 3 tarifą per mėnesį', 175, 4, NULL, NULL),
	(1339, 3, 6, 6, 2, 4, 4, 6, 15, NULL, 'R2 energija pagal 4 tarifą per mėnesį', 181, 4, NULL, NULL),
	(1340, 3, 6, 5, 2, 1, 4, 5, 15, NULL, 'R2 energija pagal 1 tarifą per parą', 187, 3, NULL, NULL),
	(1341, 3, 6, 5, 2, 2, 4, 5, 15, NULL, 'R2 energija pagal 2 tarifą per parą', 193, 3, NULL, NULL),
	(1342, 3, 6, 5, 2, 3, 4, 5, 15, NULL, 'R2 energija pagal 3 tarifą per parą', 199, 3, NULL, NULL),
	(1343, 3, 6, 5, 2, 4, 4, 5, 15, NULL, 'R2 energija pagal 4 tarifą per parą', 205, 3, NULL, NULL),
	(1344, 3, 6, 3, 3, 0, 3, 3, 16, NULL, 'Vidutinė Q2 galia per 30 minučių', 211, 2, NULL, NULL),
	(1345, 3, 6, 14, 2, 0, 4, 13, 15, NULL, 'R2 energija per 20 minučių', 714, 2, NULL, NULL),
	(1346, 3, 6, 14, 3, 0, 3, 13, 16, NULL, 'Vidutinė Q2 galia per 20 minučių', 211, 2, NULL, NULL),
	(1347, 3, 6, 1, 2, 0, 4, 1, 15, NULL, 'R2 energija per minutę', 714, 1, NULL, NULL),
	(1348, 3, 6, 1, 3, 0, 3, 1, 16, NULL, 'Vidutinė Q2 galia per minutę', 211, 1, NULL, NULL),
	(1349, 3, 6, 2, 2, 0, 4, 2, 15, NULL, 'R2 energija per 2 minutes', 714, 1, NULL, NULL),
	(1350, 3, 6, 2, 3, 0, 3, 2, 16, NULL, 'Vidutinė Q2 galia per 2 minutes', 211, 1, NULL, NULL),
	(1351, 3, 6, 9, 2, 0, 4, 8, 15, NULL, 'R2 energija per 3 minutes', 714, 1, NULL, NULL),
	(1352, 3, 6, 9, 3, 0, 3, 8, 16, NULL, 'Vidutinė Q2 galia per 3 minutes', 211, 1, NULL, NULL),
	(1353, 3, 6, 10, 2, 0, 4, 9, 15, NULL, 'R2 energija per 4 minutes', 714, 1, NULL, NULL),
	(1354, 3, 6, 10, 3, 0, 3, 9, 16, NULL, 'Vidutinė Q2 galia per 4 minutes', 211, 1, NULL, NULL),
	(1355, 3, 6, 11, 2, 0, 4, 10, 15, NULL, 'R2 energija per 5 minutes', 714, 1, NULL, NULL),
	(1356, 3, 6, 11, 3, 0, 3, 10, 16, NULL, 'Vidutinė Q2 galia per 5 minutes', 211, 1, NULL, NULL),
	(1357, 3, 6, 12, 2, 0, 4, 11, 15, NULL, 'R2 energija per 10 minučių', 714, 1, NULL, NULL),
	(1358, 3, 6, 12, 3, 0, 3, 11, 16, NULL, 'Vidutinė Q2 galia per 10 minučių', 211, 1, NULL, NULL),
	(1359, 3, 6, 13, 2, 0, 4, 12, 15, NULL, 'R2 energija per 15 minučių', 714, 2, NULL, NULL),
	(1360, 3, 6, 13, 3, 0, 3, 12, 16, NULL, 'Vidutinė Q2 galia per 15 minučių', 211, 2, NULL, NULL),
	(1361, 3, 6, 3, 2, 0, 4, 3, 15, NULL, 'R2 energija per 30 minučių', 714, 2, NULL, NULL),
	(1362, 3, 7, 4, 3, 0, 3, 4, 16, NULL, 'Vidutinė Q3 galia per valandą', 212, 2, NULL, NULL),
	(1363, 3, 7, 6, 2, 0, 4, 6, 15, NULL, 'R3 energija per mėnesį', 316, 4, NULL, NULL),
	(1364, 3, 7, 5, 2, 0, 4, 5, 15, NULL, 'R3 energija per parą', 320, 3, NULL, NULL),
	(1365, 3, 7, 5, 3, 0, 3, 5, 16, NULL, 'Vidutinė Q3 galia per parą', 212, 3, NULL, NULL),
	(1366, 3, 7, 8, 2, 1, 4, 7, 15, NULL, 'Suminė R3 energija pagal 1 tarifą', 140, 5, NULL, NULL),
	(1367, 3, 7, 8, 2, 2, 4, 7, 15, NULL, 'Suminė R3 energija pagal 2 tarifą', 146, 5, NULL, NULL),
	(1368, 3, 7, 8, 2, 3, 4, 7, 15, NULL, 'Suminė R3 energija pagal 3 tarifą', 152, 5, NULL, NULL),
	(1369, 3, 7, 8, 2, 4, 4, 7, 15, NULL, 'Suminė R3 energija pagal 4 tarifą', 158, 5, NULL, NULL),
	(1370, 3, 7, 6, 2, 1, 4, 6, 15, NULL, 'R3 energija pagal 1 tarifą per mėnesį', 164, 4, NULL, NULL),
	(1371, 3, 7, 6, 2, 2, 4, 6, 15, NULL, 'R3 energija pagal 2 tarifą per mėnesį', 170, 4, NULL, NULL),
	(1372, 3, 7, 6, 2, 3, 4, 6, 15, NULL, 'R3 energija pagal 3 tarifą per mėnesį', 176, 4, NULL, NULL),
	(1373, 3, 7, 6, 2, 4, 4, 6, 15, NULL, 'R3 energija pagal 4 tarifą per mėnesį', 182, 4, NULL, NULL),
	(1374, 3, 7, 5, 2, 1, 4, 5, 15, NULL, 'R3 energija pagal 1 tarifą per parą', 188, 3, NULL, NULL),
	(1375, 3, 7, 5, 2, 2, 4, 5, 15, NULL, 'R3 energija pagal 2 tarifą per parą', 194, 3, NULL, NULL),
	(1376, 3, 7, 5, 2, 3, 4, 5, 15, NULL, 'R3 energija pagal 3 tarifą per parą', 200, 3, NULL, NULL),
	(1377, 3, 7, 5, 2, 4, 4, 5, 15, NULL, 'R3 energija pagal 4 tarifą per parą', 206, 3, NULL, NULL),
	(1378, 3, 7, 3, 3, 0, 3, 3, 16, NULL, 'Vidutinė Q3 galia per 30 minučių', 212, 2, NULL, NULL),
	(1379, 3, 7, 14, 2, 0, 4, 13, 15, NULL, 'R3 energija per 20 minučių', 715, 2, NULL, NULL),
	(1380, 3, 7, 14, 3, 0, 3, 13, 16, NULL, 'Vidutinė Q3 galia per 20 minučių', 212, 2, NULL, NULL),
	(1381, 3, 7, 1, 2, 0, 4, 1, 15, NULL, 'R3 energija per minutę', 715, 1, NULL, NULL),
	(1382, 3, 7, 1, 3, 0, 3, 1, 16, NULL, 'Vidutinė Q3 galia per minutę', 212, 1, NULL, NULL),
	(1383, 3, 7, 2, 2, 0, 4, 2, 15, NULL, 'R3 energija per 2 minutes', 715, 1, NULL, NULL),
	(1384, 3, 7, 2, 3, 0, 3, 2, 16, NULL, 'Vidutinė Q3 galia per 2 minutes', 212, 1, NULL, NULL),
	(1385, 3, 7, 9, 2, 0, 4, 8, 15, NULL, 'R3 energija per 3 minutes', 715, 1, NULL, NULL),
	(1386, 3, 7, 9, 3, 0, 3, 8, 16, NULL, 'Vidutinė Q3 galia per 3 minutes', 212, 1, NULL, NULL),
	(1387, 3, 7, 10, 2, 0, 4, 9, 15, NULL, 'R3 energija per 4 minutes', 715, 1, NULL, NULL),
	(1388, 3, 7, 10, 3, 0, 3, 9, 16, NULL, 'Vidutinė Q3 galia per 4 minutes', 212, 1, NULL, NULL),
	(1389, 3, 7, 11, 2, 0, 4, 10, 15, NULL, 'R3 energija per 5 minutes', 715, 1, NULL, NULL),
	(1390, 3, 7, 11, 3, 0, 3, 10, 16, NULL, 'Vidutinė Q3 galia per 5 minutes', 212, 1, NULL, NULL),
	(1391, 3, 7, 12, 2, 0, 4, 11, 15, NULL, 'R3 energija per 10 minučių', 715, 1, NULL, NULL),
	(1392, 3, 7, 12, 3, 0, 3, 11, 16, NULL, 'Vidutinė Q3 galia per 10 minučių', 212, 1, NULL, NULL),
	(1393, 3, 7, 13, 2, 0, 4, 12, 15, NULL, 'R3 energija per 15 minučių', 715, 2, NULL, NULL),
	(1394, 3, 7, 13, 3, 0, 3, 12, 16, NULL, 'Vidutinė Q3 galia per 15 minučių', 212, 2, NULL, NULL),
	(1395, 3, 7, 3, 2, 0, 4, 3, 15, NULL, 'R3 energija per 30 minučių', 715, 2, NULL, NULL),
	(1396, 3, 8, 4, 3, 0, 3, 4, 16, NULL, 'Vidutinė Q4 galia per valandą', 213, 2, NULL, NULL),
	(1397, 3, 8, 6, 2, 0, 4, 6, 15, NULL, 'R4 energija per mėnesį', 317, 4, NULL, NULL),
	(1398, 3, 8, 5, 2, 0, 4, 5, 15, NULL, 'R4 energija per parą', 321, 3, NULL, NULL),
	(1399, 3, 8, 5, 3, 0, 3, 5, 16, NULL, 'Vidutinė Q4 galia per parą', 213, 3, NULL, NULL),
	(1400, 3, 8, 8, 2, 1, 4, 7, 15, NULL, 'Suminė R4 energija pagal 1 tarifą', 141, 5, NULL, NULL),
	(1401, 3, 8, 8, 2, 2, 4, 7, 15, NULL, 'Suminė R4 energija pagal 2 tarifą', 147, 5, NULL, NULL),
	(1402, 3, 8, 8, 2, 3, 4, 7, 15, NULL, 'Suminė R4 energija pagal 3 tarifą', 153, 5, NULL, NULL),
	(1403, 3, 8, 8, 2, 4, 4, 7, 15, NULL, 'Suminė R4 energija pagal 4 tarifą', 159, 5, NULL, NULL),
	(1404, 3, 8, 6, 2, 1, 4, 6, 15, NULL, 'R4 energija pagal 1 tarifą per mėnesį', 165, 4, NULL, NULL),
	(1405, 3, 8, 6, 2, 2, 4, 6, 15, NULL, 'R4 energija pagal 2 tarifą per mėnesį', 171, 4, NULL, NULL),
	(1406, 3, 8, 6, 2, 3, 4, 6, 15, NULL, 'R4 energija pagal 3 tarifą per mėnesį', 177, 4, NULL, NULL),
	(1407, 3, 8, 6, 2, 4, 4, 6, 15, NULL, 'R4 energija pagal 4 tarifą per mėnesį', 183, 4, NULL, NULL),
	(1408, 3, 8, 5, 2, 1, 4, 5, 15, NULL, 'R4 energija pagal 1 tarifą per parą', 189, 3, NULL, NULL),
	(1409, 3, 8, 5, 2, 2, 4, 5, 15, NULL, 'R4 energija pagal 2 tarifą per parą', 195, 3, NULL, NULL),
	(1410, 3, 8, 5, 2, 3, 4, 5, 15, NULL, 'R4 energija pagal 3 tarifą per parą', 201, 3, NULL, NULL),
	(1411, 3, 8, 5, 2, 4, 4, 5, 15, NULL, 'R4 energija pagal 4 tarifą per parą', 207, 3, NULL, NULL),
	(1412, 3, 8, 3, 3, 0, 3, 3, 16, NULL, 'Vidutinė Q4 galia per 30 minučių', 213, 2, NULL, NULL),
	(1413, 3, 8, 14, 2, 0, 4, 13, 15, NULL, 'R4 energija per 20 minučių', 716, 2, NULL, NULL),
	(1414, 3, 8, 14, 3, 0, 3, 13, 16, NULL, 'Vidutinė Q4 galia per 20 minučių', 213, 2, NULL, NULL),
	(1415, 3, 8, 1, 2, 0, 4, 1, 15, NULL, 'R4 energija per minutę', 7156, 1, NULL, NULL),
	(1416, 3, 8, 1, 3, 0, 3, 1, 16, NULL, 'Vidutinė Q4 galia per minutę', 213, 1, NULL, NULL),
	(1417, 3, 8, 2, 2, 0, 4, 2, 15, NULL, 'R4 energija per 2 minutes', 7156, 1, NULL, NULL),
	(1418, 3, 8, 2, 3, 0, 3, 2, 16, NULL, 'Vidutinė Q4 galia per 2 minutes', 213, 1, NULL, NULL),
	(1419, 3, 8, 9, 2, 0, 4, 8, 15, NULL, 'R4 energija per 3 minutes', 7156, 1, NULL, NULL),
	(1420, 3, 8, 9, 3, 0, 3, 8, 16, NULL, 'Vidutinė Q4 galia per 3 minutes', 213, 1, NULL, NULL),
	(1421, 3, 8, 10, 2, 0, 4, 9, 15, NULL, 'R4 energija per 4 minutes', 7156, 1, NULL, NULL),
	(1422, 3, 8, 10, 3, 0, 3, 9, 16, NULL, 'Vidutinė Q4 galia per 4 minutes', 213, 1, NULL, NULL),
	(1423, 3, 8, 11, 2, 0, 4, 10, 15, NULL, 'R4 energija per 5 minutes', 7156, 1, NULL, NULL),
	(1424, 3, 8, 11, 3, 0, 3, 10, 16, NULL, 'Vidutinė Q4 galia per 5 minutes', 213, 1, NULL, NULL),
	(1425, 3, 8, 12, 2, 0, 4, 11, 15, NULL, 'R4 energija per 10 minučių', 7156, 1, NULL, NULL),
	(1426, 3, 8, 12, 3, 0, 3, 11, 16, NULL, 'Vidutinė Q4 galia per 10 minučių', 213, 1, NULL, NULL),
	(1427, 3, 8, 13, 2, 0, 4, 12, 15, NULL, 'R4 energija per 15 minučių', 716, 2, NULL, NULL),
	(1428, 3, 8, 13, 3, 0, 3, 12, 16, NULL, 'Vidutinė Q4 galia per 15 minučių', 213, 2, NULL, NULL),
	(1429, 3, 8, 3, 2, 0, 4, 3, 15, NULL, 'R4 energija per 30 minučių', 716, 2, NULL, NULL),
	(1430, 34, 1, 4, 3, 0, 7, 4, 44, NULL, 'Vidutinė S+ galia per valandą', 214, 2, NULL, NULL),
	(1431, 34, 2, 4, 3, 0, 7, 4, 44, NULL, 'Vidutinė S- galia per valandą', 215, 2, NULL, NULL),
	(1432, 34, 1, 6, 2, 0, 41, 6, 45, NULL, 'W+ energija per mėnesį', 124, 4, NULL, NULL),
	(1433, 34, 2, 6, 2, 0, 41, 6, 45, NULL, 'W- energija per mėnesį', 125, 4, NULL, NULL),
	(1434, 34, 1, 5, 2, 0, 41, 5, 45, NULL, 'W+ energija per parą', 130, 3, NULL, NULL),
	(1435, 34, 2, 5, 2, 0, 41, 5, 45, NULL, 'W- energija per parą', 131, 3, NULL, NULL),
	(1436, 34, 1, 5, 3, 0, 7, 5, 44, NULL, 'Vidutinė S+ galia per parą', 214, 3, NULL, NULL),
	(1437, 34, 2, 5, 3, 0, 7, 5, 44, NULL, 'Vidutinė S- galia per parą', 215, 3, NULL, NULL),
	(1438, 34, 1, 8, 2, 1, 41, 7, 45, NULL, 'Suminė W+ energija pagal 1 tarifą', 142, 5, NULL, NULL),
	(1439, 34, 2, 8, 2, 1, 41, 7, 45, NULL, 'Suminė W- energija pagal 1 tarifą', 143, 5, NULL, NULL),
	(1440, 34, 1, 8, 2, 2, 41, 7, 45, NULL, 'Suminė W+ energija pagal 2 tarifą', 148, 5, NULL, NULL),
	(1441, 34, 2, 8, 2, 2, 41, 7, 45, NULL, 'Suminė W- energija pagal 2 tarifą', 149, 5, NULL, NULL),
	(1442, 34, 1, 8, 2, 3, 41, 7, 45, NULL, 'Suminė W+ energija pagal 3 tarifą', 154, 5, NULL, NULL),
	(1443, 34, 2, 8, 2, 3, 41, 7, 45, NULL, 'Suminė W- energija pagal 3 tarifą', 155, 5, NULL, NULL),
	(1444, 34, 1, 8, 2, 4, 41, 7, 45, NULL, 'Suminė W+ energija pagal 4 tarifą', 160, 5, NULL, NULL),
	(1445, 34, 2, 8, 2, 4, 41, 7, 45, NULL, 'Suminė W- energija pagal 4 tarifą', 161, 5, NULL, NULL),
	(1446, 34, 1, 6, 2, 1, 41, 6, 45, NULL, 'W+ energija pagal 1 tarifą per mėnesį', 166, 4, NULL, NULL),
	(1447, 34, 2, 6, 2, 1, 41, 6, 45, NULL, 'W- energija pagal 1 tarifą per mėnesį', 167, 4, NULL, NULL),
	(1448, 34, 1, 6, 2, 2, 41, 6, 45, NULL, 'W+ energija pagal 2 tarifą per mėnesį', 172, 4, NULL, NULL),
	(1449, 34, 2, 6, 2, 2, 41, 6, 45, NULL, 'W- energija pagal 2 tarifą per mėnesį', 173, 4, NULL, NULL),
	(1450, 34, 1, 6, 2, 3, 41, 6, 45, NULL, 'W+ energija pagal 3 tarifą per mėnesį', 178, 4, NULL, NULL),
	(1451, 34, 2, 6, 2, 3, 41, 6, 45, NULL, 'W- energija pagal 3 tarifą per mėnesį', 179, 4, NULL, NULL),
	(1452, 34, 1, 6, 2, 4, 41, 6, 45, NULL, 'W+ energija pagal 4 tarifą per mėnesį', 184, 4, NULL, NULL),
	(1453, 34, 2, 6, 2, 4, 41, 6, 45, NULL, 'W- energija pagal 4 tarifą per mėnesį', 185, 4, NULL, NULL),
	(1454, 34, 1, 5, 2, 1, 41, 5, 45, NULL, 'W+ energija pagal 1 tarifą per parą', 190, 3, NULL, NULL),
	(1455, 34, 2, 5, 2, 1, 41, 5, 45, NULL, 'W- energija pagal 1 tarifą per parą', 191, 3, NULL, NULL),
	(1456, 34, 1, 5, 2, 2, 41, 5, 45, NULL, 'W+ energija pagal 2 tarifą per parą', 196, 3, NULL, NULL),
	(1457, 34, 2, 5, 2, 2, 41, 5, 45, NULL, 'W- energija pagal 2 tarifą per parą', 197, 3, NULL, NULL),
	(1458, 34, 1, 5, 2, 3, 41, 5, 45, NULL, 'W+ energija pagal 3 tarifą per parą', 202, 3, NULL, NULL),
	(1459, 34, 2, 5, 2, 3, 41, 5, 45, NULL, 'W- energija pagal 3 tarifą per parą', 203, 3, NULL, NULL),
	(1460, 34, 1, 5, 2, 4, 41, 5, 45, NULL, 'W+ energija pagal 4 tarifą per parą', 208, 3, NULL, NULL),
	(1461, 34, 2, 5, 2, 4, 41, 5, 45, NULL, 'W- energija pagal 4 tarifą per parą', 209, 3, NULL, NULL),
	(1462, 34, 1, 3, 3, 0, 7, 3, 44, NULL, 'Vidutinė S+ galia per 30 minučių', 214, 2, NULL, NULL),
	(1463, 34, 2, 3, 3, 0, 7, 3, 44, NULL, 'Vidutinė S- galia per 30 minučių', 215, 2, NULL, NULL),
	(1464, 34, 1, 14, 2, 0, 41, 13, 45, NULL, 'W+ energija per 20 minučių', 717, 2, NULL, NULL),
	(1465, 34, 2, 14, 2, 0, 41, 13, 45, NULL, 'W- energija per 20 minučių', 718, 2, NULL, NULL),
	(1466, 34, 1, 14, 3, 0, 7, 13, 44, NULL, 'Vidutinė S+ galia per 20 minučių', 214, 2, NULL, NULL),
	(1467, 34, 2, 14, 3, 0, 7, 13, 44, NULL, 'Vidutinė S- galia per 20 minučių', 215, 2, NULL, NULL),
	(1468, 34, 1, 1, 2, 0, 41, 1, 45, NULL, 'W+ energija per minutę', 717, 1, NULL, NULL),
	(1469, 34, 2, 1, 2, 0, 41, 1, 45, NULL, 'W- energija per minutę', 718, 1, NULL, NULL),
	(1470, 34, 1, 1, 3, 0, 7, 1, 44, NULL, 'Vidutinė S+ galia per minutę', 214, 1, NULL, NULL),
	(1471, 34, 2, 1, 3, 0, 7, 1, 44, NULL, 'Vidutinė S- galia per minutę', 215, 1, NULL, NULL),
	(1472, 34, 1, 2, 2, 0, 41, 2, 45, NULL, 'W+ energija per 2 minutes', 717, 1, NULL, NULL),
	(1473, 34, 2, 2, 2, 0, 41, 2, 45, NULL, 'W- energija per 2 minutes', 718, 1, NULL, NULL),
	(1474, 34, 1, 2, 3, 0, 7, 2, 44, NULL, 'Vidutinė S+ galia per 2 minutes', 214, 1, NULL, NULL),
	(1475, 34, 2, 2, 3, 0, 7, 2, 44, NULL, 'Vidutinė S- galia per 2 minutes', 215, 1, NULL, NULL),
	(1476, 34, 1, 9, 2, 0, 41, 8, 45, NULL, 'W+ energija per 3 minutes', 717, 1, NULL, NULL),
	(1477, 34, 2, 9, 2, 0, 41, 8, 45, NULL, 'W- energija per 3 minutes', 718, 1, NULL, NULL),
	(1478, 34, 1, 9, 3, 0, 7, 8, 44, NULL, 'Vidutinė S+ galia per 3 minutes', 214, 1, NULL, NULL),
	(1479, 34, 2, 9, 3, 0, 7, 8, 44, NULL, 'Vidutinė S- galia per 3 minutes', 215, 1, NULL, NULL),
	(1480, 34, 1, 10, 2, 0, 41, 9, 45, NULL, 'W+ energija per 4 minutes', 717, 1, NULL, NULL),
	(1481, 34, 2, 10, 2, 0, 41, 9, 45, NULL, 'W- energija per 4 minutes', 718, 1, NULL, NULL),
	(1482, 34, 1, 10, 3, 0, 7, 9, 44, NULL, 'Vidutinė S+ galia per 4 minutes', 214, 1, NULL, NULL),
	(1483, 34, 2, 10, 3, 0, 7, 9, 44, NULL, 'Vidutinė S- galia per 4 minutes', 215, 1, NULL, NULL),
	(1484, 34, 1, 11, 2, 0, 41, 10, 45, NULL, 'W+ energija per 5 minutes', 717, 1, NULL, NULL),
	(1485, 34, 2, 11, 2, 0, 41, 10, 45, NULL, 'W- energija per 5 minutes', 718, 1, NULL, NULL),
	(1486, 34, 1, 11, 3, 0, 7, 10, 44, NULL, 'Vidutinė S+ galia per 5 minutes', 214, 1, NULL, NULL),
	(1487, 34, 2, 11, 3, 0, 7, 10, 44, NULL, 'Vidutinė S- galia per 5 minutes', 215, 1, NULL, NULL),
	(1488, 34, 1, 12, 2, 0, 41, 11, 45, NULL, 'W+ energija per 10 minučių', 717, 1, NULL, NULL),
	(1489, 34, 2, 12, 2, 0, 41, 11, 45, NULL, 'W- energija per 10 minučių', 718, 1, NULL, NULL),
	(1490, 34, 1, 12, 3, 0, 7, 11, 44, NULL, 'Vidutinė S+ galia per 10 minučių', 214, 1, NULL, NULL),
	(1491, 34, 2, 12, 3, 0, 7, 11, 44, NULL, 'Vidutinė S- galia per 10 minučių', 215, 1, NULL, NULL),
	(1492, 34, 1, 13, 2, 0, 41, 12, 45, NULL, 'W+ energija per 15 minučių', 717, 2, NULL, NULL),
	(1493, 34, 2, 13, 2, 0, 41, 12, 45, NULL, 'W- energija per 15 minučių', 718, 2, NULL, NULL),
	(1494, 34, 1, 13, 3, 0, 7, 12, 44, NULL, 'Vidutinė S+ galia per 15 minučių', 214, 2, NULL, NULL),
	(1495, 34, 2, 13, 3, 0, 7, 12, 44, NULL, 'Vidutinė S- galia per 15 minučių', 215, 2, NULL, NULL),
	(1496, 34, 1, 3, 2, 0, 41, 3, 45, NULL, 'W+ energija per 30 minučių', 717, 2, NULL, NULL),
	(1497, 34, 2, 3, 2, 0, 41, 3, 45, NULL, 'W- energija per 30 minučių', 718, 2, NULL, NULL),
	(1498, 1, 1, 8, 2, 0, 2, 7, 14, NULL, 'Suminė A+ energija', 132, 5, NULL, NULL),
	(1499, 1, 2, 8, 2, 0, 2, 7, 14, NULL, 'Suminė A- energija', 133, 5, NULL, NULL),
	(1500, 3, 1, 8, 2, 0, 4, 7, 15, NULL, 'Suminė R+ energija', 134, 5, NULL, NULL),
	(1501, 3, 2, 8, 2, 0, 4, 7, 15, NULL, 'Suminė R- energija', 135, 5, NULL, NULL),
	(1502, 3, 5, 8, 2, 0, 4, 7, 15, NULL, 'Suminė R1 energija', 322, 5, NULL, NULL),
	(1503, 3, 6, 8, 2, 0, 4, 7, 15, NULL, 'Suminė R2 energija', 323, 5, NULL, NULL),
	(1504, 3, 7, 8, 2, 0, 4, 7, 15, NULL, 'Suminė R3 energija', 324, 5, NULL, NULL),
	(1505, 3, 8, 8, 2, 0, 4, 7, 15, NULL, 'Suminė R4 energija', 325, 5, NULL, NULL),
	(1506, 34, 1, 8, 2, 0, 41, 7, 45, NULL, 'Suminė W+ energija', 136, 5, NULL, NULL),
	(1507, 34, 2, 8, 2, 0, 41, 7, 45, NULL, 'Suminė W- energija', 137, 5, NULL, NULL),
	(1508, 60, 3, 7, 1, 0, 27, 7, 52, NULL, 'Momentinis tiekiamo ir grįžtamo karšto vandens temperatūrų skirtumas', 1208, 6, NULL, NULL),
	(1509, 61, 0, 4, 3, 0, 32, 4, 54, NULL, 'Vidutinis karšto vandens tūrio debitas per valandą', 1260, 2, NULL, NULL),
	(1510, 61, 1, 4, 3, 0, 32, 4, 54, NULL, 'Vidutinis tiekiamo karšto vandens tūrio debitas per valandą', 1260, 2, NULL, NULL),
	(1511, 61, 2, 4, 3, 0, 32, 4, 54, NULL, 'Vidutinis grįžtamo karšto vandens tūrio debitas per valandą', 1262, 2, NULL, NULL),
	(1512, 61, 3, 4, 3, 0, 32, 4, 54, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens tūrio debito skirtumas per valandą', 1260, 2, NULL, NULL),
	(1513, 61, 0, 5, 2, 0, 31, 5, 53, NULL, 'Karšto vandens tūrio kiekis per parą', 1214, 3, NULL, NULL),
	(1514, 61, 1, 5, 2, 0, 31, 5, 53, NULL, 'Tiekiamo karšto vandens tūrio kiekis per parą', 1214, 3, NULL, NULL),
	(1515, 61, 2, 5, 2, 0, 31, 5, 53, NULL, 'Grįžtamo karšto vandens tūrio kiekis per parą', 1259, 3, NULL, NULL),
	(1516, 61, 3, 5, 2, 0, 31, 5, 53, NULL, 'Tiekiamo ir grįžtamo karšto vandens tūrio kiekių skirtumas per parą', 1214, 3, NULL, NULL),
	(1517, 61, 0, 5, 3, 0, 32, 5, 54, NULL, 'Vidutinis karšto vandens tūrio debitas per parą', 1260, 3, NULL, NULL),
	(1518, 61, 1, 5, 3, 0, 32, 5, 54, NULL, 'Vidutinis tiekiamo karšto vandens tūrio debitas per parą', 1260, 3, NULL, NULL),
	(1519, 61, 2, 5, 3, 0, 32, 5, 54, NULL, 'Vidutinis grįžtamo karšto vandens tūrio debitas per parą', 1262, 3, NULL, NULL),
	(1520, 61, 3, 5, 3, 0, 32, 5, 54, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens tūrio debito skirtumas per parą', 1260, 3, NULL, NULL),
	(1521, 61, 0, 6, 2, 0, 31, 6, 53, NULL, 'Karšto vandens tūrio kiekis per mėnesį', 1214, 4, NULL, NULL),
	(1522, 61, 1, 6, 2, 0, 31, 6, 53, NULL, 'Tiekiamo karšto vandens tūrio kiekis per mėnesį', 1214, 4, NULL, NULL),
	(1523, 61, 2, 6, 2, 0, 31, 6, 53, NULL, 'Grįžtamo karšto vandens tūrio kiekis per mėnesį', 1259, 4, NULL, NULL),
	(1524, 61, 3, 6, 2, 0, 31, 6, 53, NULL, 'Tiekiamo ir grįžtamo karšto vandens tūrio kiekių skirtumas per mėnesį', 1214, 4, NULL, NULL),
	(1525, 61, 0, 6, 3, 0, 32, 6, 54, NULL, 'Vidutinis karšto vandens tūrio debitas per mėnesį', 1260, 4, NULL, NULL),
	(1526, 61, 1, 6, 3, 0, 32, 6, 54, NULL, 'Vidutinis tiekiamo karšto vandens tūrio debitas per mėnesį', 1260, 4, NULL, NULL),
	(1527, 61, 2, 6, 3, 0, 32, 6, 54, NULL, 'Vidutinis grįžtamo karšto vandens tūrio debitas per mėnesį', 1262, 4, NULL, NULL),
	(1528, 61, 3, 6, 3, 0, 32, 6, 54, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens tūrio debito skirtumas per mėnesį', 1260, 4, NULL, NULL),
	(1529, 61, 0, 7, 1, 0, 32, 7, 54, NULL, 'Momentinis karšto vandens tūrio debitas', 1202, 6, NULL, NULL),
	(1530, 61, 1, 7, 1, 0, 32, 7, 54, NULL, 'Momentinis tiekiamo karšto vandens tūrio debitas', 1202, 6, NULL, NULL),
	(1531, 61, 2, 7, 1, 0, 32, 7, 54, NULL, 'Momentinis grįžtamo karšto vandens tūrio debitas', 1261, 6, NULL, NULL),
	(1532, 61, 3, 7, 1, 0, 32, 7, 54, NULL, 'Momentinis tiekiamo ir grįžtamo karšto vandens tūrio debito skirtumas', 1202, 6, NULL, NULL),
	(1533, 61, 0, 14, 2, 0, 31, 13, 53, NULL, 'Karšto vandens tūrio kiekis per 20 minučių', 1214, 2, NULL, NULL),
	(1534, 61, 1, 14, 2, 0, 31, 13, 53, NULL, 'Tiekiamo karšto vandens tūrio kiekis per 20 minučių', 1214, 2, NULL, NULL),
	(1535, 61, 2, 14, 2, 0, 31, 13, 53, NULL, 'Grįžtamo karšto vandens tūrio kiekis per 20 minučių', 1259, 2, NULL, NULL),
	(1536, 61, 3, 14, 2, 0, 31, 13, 53, NULL, 'Tiekiamo ir grįžtamo karšto vandens tūrio kiekių skirtumas per 20 minučių', 1214, 2, NULL, NULL),
	(1537, 61, 0, 14, 3, 0, 32, 13, 54, NULL, 'Vidutinis karšto vandens tūrio debitas per 20 minučių', 1260, 2, NULL, NULL),
	(1538, 61, 1, 14, 3, 0, 32, 13, 54, NULL, 'Vidutinis tiekiamo karšto vandens tūrio debitas per 20 minučių', 1260, 2, NULL, NULL),
	(1539, 61, 2, 14, 3, 0, 32, 13, 54, NULL, 'Vidutinis grįžtamo karšto vandens tūrio debitas per 20 minučių', 1262, 2, NULL, NULL),
	(1540, 61, 3, 14, 3, 0, 32, 13, 54, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens tūrio debito skirtumas per 20 minučių', 1260, 2, NULL, NULL),
	(1541, 59, 0, 4, 3, 0, 33, 4, 50, NULL, 'Vidutinė karšto vandens šilumos galia per valandą', 1232, 2, NULL, NULL),
	(1542, 59, 1, 4, 3, 0, 33, 4, 50, NULL, 'Vidutinė tiekiamo karšto vandens šilumos galia per valandą', 1232, 2, NULL, NULL),
	(1543, 59, 2, 4, 3, 0, 33, 4, 50, NULL, 'Vidutinė grįžtamo karšto vandens šilumos galia per valandą', 1234, 2, NULL, NULL),
	(1544, 59, 3, 4, 3, 0, 33, 4, 50, NULL, 'Vidutinė sunaudota karšto vandens šilumos galia per valandą', 1236, 2, NULL, NULL),
	(1545, 59, 0, 5, 2, 0, 34, 5, 51, NULL, 'Karšto vandens šilumos kiekis per parą', 1212, 3, NULL, NULL),
	(1546, 59, 1, 5, 2, 0, 34, 5, 51, NULL, 'Tiekiamo karšto vandens šilumos kiekis per parą', 1212, 3, NULL, NULL),
	(1547, 59, 2, 5, 2, 0, 34, 5, 51, NULL, 'Grįžtamo karšto vandens šilumos kiekis per parą', 1238, 3, NULL, NULL),
	(1548, 59, 3, 5, 2, 0, 34, 5, 51, NULL, 'Sunaudotos karšto vandens šilumos kiekis per parą', 1240, 3, NULL, NULL),
	(1549, 59, 0, 5, 3, 0, 33, 5, 50, NULL, 'Vidutinė karšto vandens šilumos galia per parą', 1232, 3, NULL, NULL),
	(1550, 59, 1, 5, 3, 0, 33, 5, 50, NULL, 'Vidutinė tiekiamo karšto vandens šilumos galia per parą', 1232, 3, NULL, NULL),
	(1551, 59, 2, 5, 3, 0, 33, 5, 50, NULL, 'Vidutinė grįžtamo karšto vandens šilumos galia per parą', 1234, 3, NULL, NULL),
	(1552, 59, 3, 5, 3, 0, 33, 5, 50, NULL, 'Vidutinė sunaudota karšto vandens šilumos galia per parą', 1236, 3, NULL, NULL),
	(1553, 59, 0, 6, 2, 0, 34, 6, 51, NULL, 'Karšto vandens šilumos kiekis per mėnesį', 1212, 4, NULL, NULL),
	(1554, 59, 1, 6, 2, 0, 34, 6, 51, NULL, 'Tiekiamo karšto vandens šilumos kiekis per mėnesį', 1212, 4, NULL, NULL),
	(1555, 59, 2, 6, 2, 0, 34, 6, 51, NULL, 'Grįžtamo karšto vandens šilumos kiekis per mėnesį', 1238, 4, NULL, NULL),
	(1556, 59, 3, 6, 2, 0, 34, 6, 51, NULL, 'Sunaudotos karšto vandens šilumos kiekis per mėnesį', 1240, 4, NULL, NULL),
	(1557, 59, 0, 6, 3, 0, 33, 6, 50, NULL, 'Vidutinė karšto vandens šilumos galia per mėnesį', 1232, 4, NULL, NULL),
	(1558, 59, 1, 6, 3, 0, 33, 6, 50, NULL, 'Vidutinė tiekiamo karšto vandens šilumos galia per mėnesį', 1232, 4, NULL, NULL),
	(1559, 59, 2, 6, 3, 0, 33, 6, 50, NULL, 'Vidutinė grįžtamo karšto vandens šilumos galia per mėnesį', 1234, 4, NULL, NULL),
	(1560, 59, 3, 6, 3, 0, 33, 6, 50, NULL, 'Vidutinė sunaudota karšto vandens šilumos galia per mėnesį', 1236, 4, NULL, NULL),
	(1561, 59, 0, 7, 1, 0, 33, 7, 50, NULL, 'Momentinė karšto vandens šilumos galia', 1206, 6, NULL, NULL),
	(1562, 59, 1, 7, 1, 0, 33, 7, 50, NULL, 'Momentinė tiekiamo karšto vandens šilumos galia', 1206, 6, NULL, NULL),
	(1563, 59, 2, 7, 1, 0, 33, 7, 50, NULL, 'Momentinė grįžtamo karšto vandens šilumos galia', 1233, 6, NULL, NULL),
	(1564, 59, 3, 7, 1, 0, 33, 7, 50, NULL, 'Momentinė sunaudota karšto vandens šilumos galia', 1235, 6, NULL, NULL),
	(1565, 60, 0, 4, 3, 0, 27, 4, 52, NULL, 'Vidutinė karšto vandens temperatūra per valandą', 1215, 2, NULL, NULL),
	(1566, 60, 1, 4, 3, 0, 27, 4, 52, NULL, 'Vidutinė tiekiamo karšto vandens temperatūra per valandą', 1215, 2, NULL, NULL),
	(1567, 60, 2, 4, 3, 0, 27, 4, 52, NULL, 'Vidutinė grįžtamo karšto vandens temperatūra per valandą', 1256, 2, NULL, NULL),
	(1568, 60, 3, 4, 3, 0, 27, 4, 52, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens temperatūrų skirtumas per valandą', 1257, 2, NULL, NULL),
	(1569, 60, 0, 5, 3, 0, 27, 5, 52, NULL, 'Vidutinė karšto vandens temperatūra per parą', 1215, 3, NULL, NULL),
	(1570, 60, 1, 5, 3, 0, 27, 5, 52, NULL, 'Vidutinė tiekiamo karšto vandens temperatūra per parą', 1215, 3, NULL, NULL),
	(1571, 60, 2, 5, 3, 0, 27, 5, 52, NULL, 'Vidutinė grįžtamo karšto vandens temperatūra per parą', 1256, 3, NULL, NULL),
	(1572, 60, 3, 5, 3, 0, 27, 5, 52, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens temperatūrų skirtumas per parą', 1257, 3, NULL, NULL),
	(1573, 60, 0, 6, 3, 0, 27, 6, 52, NULL, 'Vidutinė karšto vandens temperatūra per mėnesį', 1215, 4, NULL, NULL),
	(1574, 60, 1, 6, 3, 0, 27, 6, 52, NULL, 'Vidutinė tiekiamo karšto vandens temperatūra per mėnesį', 1215, 4, NULL, NULL),
	(1575, 60, 2, 6, 3, 0, 27, 6, 52, NULL, 'Vidutinė grįžtamo karšto vandens temperatūra per mėnesį', 1256, 4, NULL, NULL),
	(1576, 60, 3, 6, 3, 0, 27, 6, 52, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens temperatūrų skirtumas per mėnesį', 1257, 4, NULL, NULL),
	(1577, 60, 0, 7, 1, 0, 27, 7, 52, NULL, 'Momentinė karšto vandens temperatūra', 1203, 6, NULL, NULL),
	(1578, 60, 1, 7, 1, 0, 27, 7, 52, NULL, 'Momentinė tiekiamo karšto vandens temperatūra', 1203, 6, NULL, NULL),
	(1579, 60, 2, 7, 1, 0, 27, 7, 52, NULL, 'Momentinė grįžtamo karšto vandens temperatūra', 1207, 6, NULL, NULL),
	(1580, 61, 0, 1, 2, 0, 31, 1, 53, NULL, 'Karšto vandens tūrio kiekis per minutę', 1214, 1, NULL, NULL),
	(1581, 61, 1, 1, 2, 0, 31, 1, 53, NULL, 'Tiekiamo karšto vandens tūrio kiekis per minutę', 1214, 1, NULL, NULL),
	(1582, 61, 2, 1, 2, 0, 31, 1, 53, NULL, 'Grįžtamo karšto vandens tūrio kiekis per minutę', 1259, 1, NULL, NULL),
	(1583, 61, 3, 1, 2, 0, 31, 1, 53, NULL, 'Tiekiamo ir grįžtamo karšto vandens tūrio kiekių skirtumas per minutę', 1214, 1, NULL, NULL),
	(1584, 61, 0, 1, 3, 0, 32, 1, 54, NULL, 'Vidutinis karšto vandens tūrio debitas per minutę', 1260, 1, NULL, NULL),
	(1585, 61, 1, 1, 3, 0, 32, 1, 54, NULL, 'Vidutinis tiekiamo karšto vandens tūrio debitas per minutę', 1260, 1, NULL, NULL),
	(1586, 61, 2, 1, 3, 0, 32, 1, 54, NULL, 'Vidutinis grįžtamo karšto vandens tūrio debitas per minutę', 1262, 1, NULL, NULL),
	(1587, 61, 3, 1, 3, 0, 32, 1, 54, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens tūrio debito skirtumas per minutę', 1260, 1, NULL, NULL),
	(1588, 59, 0, 1, 2, 0, 34, 1, 51, NULL, 'Karšto vandens šilumos kiekis per minutę', 1212, 1, NULL, NULL),
	(1589, 59, 1, 1, 2, 0, 34, 1, 51, NULL, 'Tiekiamo karšto vandens šilumos kiekis per minutę', 1212, 1, NULL, NULL),
	(1590, 59, 2, 1, 2, 0, 34, 1, 51, NULL, 'Grįžtamo karšto vandens šilumos kiekis per minutę', 1238, 1, NULL, NULL),
	(1591, 59, 3, 1, 2, 0, 34, 1, 51, NULL, 'Sunaudotos karšto vandens šilumos kiekis per minutę', 1240, 1, NULL, NULL),
	(1592, 59, 0, 1, 3, 0, 33, 1, 50, NULL, 'Vidutinė karšto vandens šilumos galia per minutę', 1232, 1, NULL, NULL),
	(1593, 59, 1, 1, 3, 0, 33, 1, 50, NULL, 'Vidutinė tiekiamo karšto vandens šilumos galia per minutę', 1232, 1, NULL, NULL),
	(1594, 59, 2, 1, 3, 0, 33, 1, 50, NULL, 'Vidutinė grįžtamo karšto vandens šilumos galia per minutę', 1234, 1, NULL, NULL),
	(1595, 59, 3, 1, 3, 0, 33, 1, 50, NULL, 'Vidutinė sunaudota karšto vandens šilumos galia per minutę', 1236, 1, NULL, NULL),
	(1596, 60, 0, 1, 3, 0, 27, 1, 52, NULL, 'Vidutinė karšto vandens temperatūra per minutę', 1215, 1, NULL, NULL),
	(1597, 60, 1, 1, 3, 0, 27, 1, 52, NULL, 'Vidutinė tiekiamo karšto vandens temperatūra per minutę', 1215, 1, NULL, NULL),
	(1598, 60, 2, 1, 3, 0, 27, 1, 52, NULL, 'Vidutinė grįžtamo karšto vandens temperatūra per minutę', 1256, 1, NULL, NULL),
	(1599, 60, 3, 1, 3, 0, 27, 1, 52, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens temperatūrų skirtumas per minutę', 1257, 1, NULL, NULL),
	(1600, 61, 0, 2, 2, 0, 31, 2, 53, NULL, 'Karšto vandens tūrio kiekis per 2 minutes', 1214, 1, NULL, NULL),
	(1601, 61, 1, 2, 2, 0, 31, 2, 53, NULL, 'Tiekiamo karšto vandens tūrio kiekis per 2 minutes', 1214, 1, NULL, NULL),
	(1602, 61, 2, 2, 2, 0, 31, 2, 53, NULL, 'Grįžtamo karšto vandens tūrio kiekis per 2 minutes', 1259, 1, NULL, NULL),
	(1603, 61, 3, 2, 2, 0, 31, 2, 53, NULL, 'Tiekiamo ir grįžtamo karšto vandens tūrio kiekių skirtumas per 2 minutes', 1214, 1, NULL, NULL),
	(1604, 61, 0, 2, 3, 0, 32, 2, 54, NULL, 'Vidutinis karšto vandens tūrio debitas per 2 minutes', 1260, 1, NULL, NULL),
	(1605, 61, 1, 2, 3, 0, 32, 2, 54, NULL, 'Vidutinis tiekiamo karšto vandens tūrio debitas per 2 minutes', 1260, 1, NULL, NULL),
	(1606, 61, 2, 2, 3, 0, 32, 2, 54, NULL, 'Vidutinis grįžtamo karšto vandens tūrio debitas per 2 minutes', 1262, 1, NULL, NULL),
	(1607, 61, 3, 2, 3, 0, 32, 2, 54, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens tūrio debito skirtumas per 2 minutes', 1260, 1, NULL, NULL),
	(1608, 59, 0, 2, 2, 0, 34, 2, 51, NULL, 'Karšto vandens šilumos kiekis per 2 minutes', 1212, 1, NULL, NULL),
	(1609, 59, 1, 2, 2, 0, 34, 2, 51, NULL, 'Tiekiamo karšto vandens šilumos kiekis per 2 minutes', 1212, 1, NULL, NULL),
	(1610, 59, 2, 2, 2, 0, 34, 2, 51, NULL, 'Grįžtamo karšto vandens šilumos kiekis per 2 minutes', 1238, 1, NULL, NULL),
	(1611, 59, 3, 2, 2, 0, 34, 2, 51, NULL, 'Sunaudotos karšto vandens šilumos kiekis per 2 minutes', 1240, 1, NULL, NULL),
	(1612, 59, 0, 2, 3, 0, 33, 2, 50, NULL, 'Vidutinė karšto vandens šilumos galia per 2 minutes', 1232, 1, NULL, NULL),
	(1613, 59, 1, 2, 3, 0, 33, 2, 50, NULL, 'Vidutinė tiekiamo karšto vandens šilumos galia per 2 minutes', 1232, 1, NULL, NULL),
	(1614, 59, 2, 2, 3, 0, 33, 2, 50, NULL, 'Vidutinė grįžtamo karšto vandens šilumos galia per 2 minutes', 1234, 1, NULL, NULL),
	(1615, 59, 3, 2, 3, 0, 33, 2, 50, NULL, 'Vidutinė sunaudota karšto vandens šilumos galia per 2 minutes', 1236, 1, NULL, NULL),
	(1616, 60, 0, 2, 3, 0, 27, 2, 52, NULL, 'Vidutinė karšto vandens temperatūra per 2 minutes', 1215, 1, NULL, NULL),
	(1617, 60, 1, 2, 3, 0, 27, 2, 52, NULL, 'Vidutinė tiekiamo karšto vandens temperatūra per 2 minutes', 1215, 1, NULL, NULL),
	(1618, 60, 2, 2, 3, 0, 27, 2, 52, NULL, 'Vidutinė grįžtamo karšto vandens temperatūra per 2 minutes', 1256, 1, NULL, NULL),
	(1619, 60, 3, 2, 3, 0, 27, 2, 52, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens temperatūrų skirtumas per 2 minutes', 1257, 1, NULL, NULL),
	(1620, 61, 0, 9, 2, 0, 31, 8, 53, NULL, 'Karšto vandens tūrio kiekis per 3 minutes', 1214, 1, NULL, NULL),
	(1621, 61, 1, 9, 2, 0, 31, 8, 53, NULL, 'Tiekiamo karšto vandens tūrio kiekis per 3 minutes', 1214, 1, NULL, NULL),
	(1622, 61, 2, 9, 2, 0, 31, 8, 53, NULL, 'Grįžtamo karšto vandens tūrio kiekis per 3 minutes', 1259, 1, NULL, NULL),
	(1623, 61, 3, 9, 2, 0, 31, 8, 53, NULL, 'Tiekiamo ir grįžtamo karšto vandens tūrio kiekių skirtumas per 3 minutes', 1214, 1, NULL, NULL),
	(1624, 61, 0, 9, 3, 0, 32, 8, 54, NULL, 'Vidutinis karšto vandens tūrio debitas per 3 minutes', 1260, 1, NULL, NULL),
	(1625, 61, 1, 9, 3, 0, 32, 8, 54, NULL, 'Vidutinis tiekiamo karšto vandens tūrio debitas per 3 minutes', 1260, 1, NULL, NULL),
	(1626, 61, 2, 9, 3, 0, 32, 8, 54, NULL, 'Vidutinis grįžtamo karšto vandens tūrio debitas per 3 minutes', 1262, 1, NULL, NULL),
	(1627, 61, 3, 9, 3, 0, 32, 8, 54, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens tūrio debito skirtumas per 3 minutes', 1260, 1, NULL, NULL),
	(1628, 59, 0, 9, 2, 0, 34, 8, 51, NULL, 'Karšto vandens šilumos kiekis per 3 minutes', 1212, 1, NULL, NULL),
	(1629, 59, 1, 9, 2, 0, 34, 8, 51, NULL, 'Tiekiamo karšto vandens šilumos kiekis per 3 minutes', 1212, 1, NULL, NULL),
	(1630, 59, 2, 9, 2, 0, 34, 8, 51, NULL, 'Grįžtamo karšto vandens šilumos kiekis per 3 minutes', 1238, 1, NULL, NULL),
	(1631, 59, 3, 9, 2, 0, 34, 8, 51, NULL, 'Sunaudotos karšto vandens šilumos kiekis per 3 minutes', 1240, 1, NULL, NULL),
	(1632, 59, 0, 9, 3, 0, 33, 8, 50, NULL, 'Vidutinė karšto vandens šilumos galia per 3 minutes', 1232, 1, NULL, NULL),
	(1633, 59, 1, 9, 3, 0, 33, 8, 50, NULL, 'Vidutinė tiekiamo karšto vandens šilumos galia per 3 minutes', 1232, 1, NULL, NULL),
	(1634, 59, 2, 9, 3, 0, 33, 8, 50, NULL, 'Vidutinė grįžtamo karšto vandens šilumos galia per 3 minutes', 1234, 1, NULL, NULL),
	(1635, 59, 3, 9, 3, 0, 33, 8, 50, NULL, 'Vidutinė sunaudota karšto vandens šilumos galia per 3 minutes', 1236, 1, NULL, NULL),
	(1636, 60, 0, 9, 3, 0, 27, 8, 52, NULL, 'Vidutinė karšto vandens temperatūra per 3 minutes', 1215, 1, NULL, NULL),
	(1637, 60, 1, 9, 3, 0, 27, 8, 52, NULL, 'Vidutinė tiekiamo karšto vandens temperatūra per 3 minutes', 1215, 1, NULL, NULL),
	(1638, 60, 2, 9, 3, 0, 27, 8, 52, NULL, 'Vidutinė grįžtamo karšto vandens temperatūra per 3 minutes', 1256, 1, NULL, NULL),
	(1639, 60, 3, 9, 3, 0, 27, 8, 52, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens temperatūrų skirtumas per 3 minutes', 1257, 1, NULL, NULL),
	(1640, 61, 0, 10, 2, 0, 31, 9, 53, NULL, 'Karšto vandens tūrio kiekis per 4 minutes', 1214, 1, NULL, NULL),
	(1641, 61, 1, 10, 2, 0, 31, 9, 53, NULL, 'Tiekiamo karšto vandens tūrio kiekis per 4 minutes', 1214, 1, NULL, NULL),
	(1642, 61, 2, 10, 2, 0, 31, 9, 53, NULL, 'Grįžtamo karšto vandens tūrio kiekis per 4 minutes', 1259, 1, NULL, NULL),
	(1643, 61, 3, 10, 2, 0, 31, 9, 53, NULL, 'Tiekiamo ir grįžtamo karšto vandens tūrio kiekių skirtumas per 4 minutes', 1214, 1, NULL, NULL),
	(1644, 61, 0, 10, 3, 0, 32, 9, 54, NULL, 'Vidutinis karšto vandens tūrio debitas per 4 minutes', 1260, 1, NULL, NULL),
	(1645, 61, 1, 10, 3, 0, 32, 9, 54, NULL, 'Vidutinis tiekiamo karšto vandens tūrio debitas per 4 minutes', 1260, 1, NULL, NULL),
	(1646, 61, 2, 10, 3, 0, 32, 9, 54, NULL, 'Vidutinis grįžtamo karšto vandens tūrio debitas per 4 minutes', 1262, 1, NULL, NULL),
	(1647, 61, 3, 10, 3, 0, 32, 9, 54, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens tūrio debito skirtumas per 4 minutes', 1260, 1, NULL, NULL),
	(1648, 59, 0, 10, 2, 0, 34, 9, 51, NULL, 'Karšto vandens šilumos kiekis per 4 minutes', 1212, 1, NULL, NULL),
	(1649, 59, 1, 10, 2, 0, 34, 9, 51, NULL, 'Tiekiamo karšto vandens šilumos kiekis per 4 minutes', 1212, 1, NULL, NULL),
	(1650, 59, 2, 10, 2, 0, 34, 9, 51, NULL, 'Grįžtamo karšto vandens šilumos kiekis per 4 minutes', 1238, 1, NULL, NULL),
	(1651, 59, 3, 10, 2, 0, 34, 9, 51, NULL, 'Sunaudotos karšto vandens šilumos kiekis per 4 minutes', 1240, 1, NULL, NULL),
	(1652, 59, 0, 10, 3, 0, 33, 9, 50, NULL, 'Vidutinė karšto vandens šilumos galia per 4 minutes', 1232, 1, NULL, NULL),
	(1653, 59, 1, 10, 3, 0, 33, 9, 50, NULL, 'Vidutinė tiekiamo karšto vandens šilumos galia per 4 minutes', 1232, 1, NULL, NULL),
	(1654, 59, 2, 10, 3, 0, 33, 9, 50, NULL, 'Vidutinė grįžtamo karšto vandens šilumos galia per 4 minutes', 1234, 1, NULL, NULL),
	(1655, 59, 3, 10, 3, 0, 33, 9, 50, NULL, 'Vidutinė sunaudota karšto vandens šilumos galia per 4 minutes', 1236, 1, NULL, NULL),
	(1656, 60, 0, 10, 3, 0, 27, 9, 52, NULL, 'Vidutinė karšto vandens temperatūra per 4 minutes', 1215, 1, NULL, NULL),
	(1657, 60, 1, 10, 3, 0, 27, 9, 52, NULL, 'Vidutinė tiekiamo karšto vandens temperatūra per 4 minutes', 1215, 1, NULL, NULL),
	(1658, 60, 2, 10, 3, 0, 27, 9, 52, NULL, 'Vidutinė grįžtamo karšto vandens temperatūra per 4 minutes', 1256, 1, NULL, NULL),
	(1659, 60, 3, 10, 3, 0, 27, 9, 52, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens temperatūrų skirtumas per 4 minutes', 1257, 1, NULL, NULL),
	(1660, 61, 0, 11, 2, 0, 31, 10, 53, NULL, 'Karšto vandens tūrio kiekis per 5 minutes', 1214, 1, NULL, NULL),
	(1661, 61, 1, 11, 2, 0, 31, 10, 53, NULL, 'Tiekiamo karšto vandens tūrio kiekis per 5 minutes', 1214, 1, NULL, NULL),
	(1662, 61, 2, 11, 2, 0, 31, 10, 53, NULL, 'Grįžtamo karšto vandens tūrio kiekis per 5 minutes', 1259, 1, NULL, NULL),
	(1663, 61, 3, 11, 2, 0, 31, 10, 53, NULL, 'Tiekiamo ir grįžtamo karšto vandens tūrio kiekių skirtumas per 5 minutes', 1214, 1, NULL, NULL),
	(1664, 61, 0, 11, 3, 0, 32, 10, 54, NULL, 'Vidutinis karšto vandens tūrio debitas per 5 minutes', 1260, 1, NULL, NULL),
	(1665, 61, 1, 11, 3, 0, 32, 10, 54, NULL, 'Vidutinis tiekiamo karšto vandens tūrio debitas per 5 minutes', 1260, 1, NULL, NULL),
	(1666, 61, 2, 11, 3, 0, 32, 10, 54, NULL, 'Vidutinis grįžtamo karšto vandens tūrio debitas per 5 minutes', 1262, 1, NULL, NULL),
	(1667, 61, 3, 11, 3, 0, 32, 10, 54, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens tūrio debito skirtumas per 5 minutes', 1260, 1, NULL, NULL),
	(1668, 59, 0, 11, 2, 0, 34, 10, 51, NULL, 'Karšto vandens šilumos kiekis per 5 minutes', 1212, 1, NULL, NULL),
	(1669, 59, 1, 11, 2, 0, 34, 10, 51, NULL, 'Tiekiamo karšto vandens šilumos kiekis per 5 minutes', 1212, 1, NULL, NULL),
	(1670, 59, 2, 11, 2, 0, 34, 10, 51, NULL, 'Grįžtamo karšto vandens šilumos kiekis per 5 minutes', 1238, 1, NULL, NULL),
	(1671, 59, 3, 11, 2, 0, 34, 10, 51, NULL, 'Sunaudotos karšto vandens šilumos kiekis per 5 minutes', 1240, 1, NULL, NULL),
	(1672, 59, 0, 11, 3, 0, 33, 10, 50, NULL, 'Vidutinė karšto vandens šilumos galia per 5 minutes', 1232, 1, NULL, NULL),
	(1673, 59, 1, 11, 3, 0, 33, 10, 50, NULL, 'Vidutinė tiekiamo karšto vandens šilumos galia per 5 minutes', 1232, 1, NULL, NULL),
	(1674, 59, 2, 11, 3, 0, 33, 10, 50, NULL, 'Vidutinė grįžtamo karšto vandens šilumos galia per 5 minutes', 1234, 1, NULL, NULL),
	(1675, 59, 3, 11, 3, 0, 33, 10, 50, NULL, 'Vidutinė sunaudota karšto vandens šilumos galia per 5 minutes', 1236, 1, NULL, NULL),
	(1676, 60, 0, 11, 3, 0, 27, 10, 52, NULL, 'Vidutinė karšto vandens temperatūra per 5 minutes', 1215, 1, NULL, NULL),
	(1677, 60, 1, 11, 3, 0, 27, 10, 52, NULL, 'Vidutinė tiekiamo karšto vandens temperatūra per 5 minutes', 1215, 1, NULL, NULL),
	(1678, 60, 2, 11, 3, 0, 27, 10, 52, NULL, 'Vidutinė grįžtamo karšto vandens temperatūra per 5 minutes', 1256, 1, NULL, NULL),
	(1679, 60, 3, 11, 3, 0, 27, 10, 52, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens temperatūrų skirtumas per 5 minutes', 1257, 1, NULL, NULL),
	(1680, 61, 0, 12, 2, 0, 31, 11, 53, NULL, 'Karšto vandens tūrio kiekis per 10 minučių', 1214, 1, NULL, NULL),
	(1681, 61, 1, 12, 2, 0, 31, 11, 53, NULL, 'Tiekiamo karšto vandens tūrio kiekis per 10 minučių', 1214, 1, NULL, NULL),
	(1682, 61, 2, 12, 2, 0, 31, 11, 53, NULL, 'Grįžtamo karšto vandens tūrio kiekis per 10 minučių', 1259, 1, NULL, NULL),
	(1683, 61, 3, 12, 2, 0, 31, 11, 53, NULL, 'Tiekiamo ir grįžtamo karšto vandens tūrio kiekių skirtumas per 10 minučių', 1214, 1, NULL, NULL),
	(1684, 61, 0, 12, 3, 0, 32, 11, 54, NULL, 'Vidutinis karšto vandens tūrio debitas per 10 minučių', 1260, 1, NULL, NULL),
	(1685, 61, 1, 12, 3, 0, 32, 11, 54, NULL, 'Vidutinis tiekiamo karšto vandens tūrio debitas per 10 minučių', 1260, 1, NULL, NULL),
	(1686, 61, 2, 12, 3, 0, 32, 11, 54, NULL, 'Vidutinis grįžtamo karšto vandens tūrio debitas per 10 minučių', 1262, 1, NULL, NULL),
	(1687, 61, 3, 12, 3, 0, 32, 11, 54, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens tūrio debito skirtumas per 10 minučių', 1260, 1, NULL, NULL),
	(1688, 59, 0, 12, 2, 0, 34, 11, 51, NULL, 'Karšto vandens šilumos kiekis per 10 minučių', 1212, 1, NULL, NULL),
	(1689, 59, 1, 12, 2, 0, 34, 11, 51, NULL, 'Tiekiamo karšto vandens šilumos kiekis per 10 minučių', 1212, 1, NULL, NULL),
	(1690, 59, 2, 12, 2, 0, 34, 11, 51, NULL, 'Grįžtamo karšto vandens šilumos kiekis per 10 minučių', 1238, 1, NULL, NULL),
	(1691, 59, 3, 12, 2, 0, 34, 11, 51, NULL, 'Sunaudotos karšto vandens šilumos kiekis per 10 minučių', 1240, 1, NULL, NULL),
	(1692, 59, 0, 12, 3, 0, 33, 11, 50, NULL, 'Vidutinė karšto vandens šilumos galia per 10 minučių', 1232, 1, NULL, NULL),
	(1693, 59, 1, 12, 3, 0, 33, 11, 50, NULL, 'Vidutinė tiekiamo karšto vandens šilumos galia per 10 minučių', 1232, 1, NULL, NULL),
	(1694, 59, 2, 12, 3, 0, 33, 11, 50, NULL, 'Vidutinė grįžtamo karšto vandens šilumos galia per 10 minučių', 1234, 1, NULL, NULL),
	(1695, 59, 3, 12, 3, 0, 33, 11, 50, NULL, 'Vidutinė sunaudota karšto vandens šilumos galia per 10 minučių', 1236, 1, NULL, NULL),
	(1696, 60, 0, 12, 3, 0, 27, 11, 52, NULL, 'Vidutinė karšto vandens temperatūra per 10 minučių', 1215, 1, NULL, NULL),
	(1697, 60, 1, 12, 3, 0, 27, 11, 52, NULL, 'Vidutinė tiekiamo karšto vandens temperatūra per 10 minučių', 1215, 1, NULL, NULL),
	(1698, 60, 2, 12, 3, 0, 27, 11, 52, NULL, 'Vidutinė grįžtamo karšto vandens temperatūra per 10 minučių', 1256, 1, NULL, NULL),
	(1699, 60, 3, 12, 3, 0, 27, 11, 52, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens temperatūrų skirtumas per 10 minučių', 1257, 1, NULL, NULL),
	(1700, 61, 0, 13, 2, 0, 31, 12, 53, NULL, 'Karšto vandens tūrio kiekis per 15 minučių', 1214, 2, NULL, NULL),
	(1701, 61, 1, 13, 2, 0, 31, 12, 53, NULL, 'Tiekiamo karšto vandens tūrio kiekis per 15 minučių', 1214, 2, NULL, NULL),
	(1702, 61, 2, 13, 2, 0, 31, 12, 53, NULL, 'Grįžtamo karšto vandens tūrio kiekis per 15 minučių', 1259, 2, NULL, NULL),
	(1703, 61, 3, 13, 2, 0, 31, 12, 53, NULL, 'Tiekiamo ir grįžtamo karšto vandens tūrio kiekių skirtumas per 15 minučių', 1214, 2, NULL, NULL),
	(1704, 61, 0, 13, 3, 0, 32, 12, 54, NULL, 'Vidutinis karšto vandens tūrio debitas per 15 minučių', 1260, 2, NULL, NULL),
	(1705, 61, 1, 13, 3, 0, 32, 12, 54, NULL, 'Vidutinis tiekiamo karšto vandens tūrio debitas per 15 minučių', 1260, 2, NULL, NULL),
	(1706, 61, 2, 13, 3, 0, 32, 12, 54, NULL, 'Vidutinis grįžtamo karšto vandens tūrio debitas per 15 minučių', 1262, 2, NULL, NULL),
	(1707, 61, 3, 13, 3, 0, 32, 12, 54, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens tūrio debito skirtumas per 15 minučių', 1260, 2, NULL, NULL),
	(1708, 59, 0, 13, 2, 0, 34, 12, 51, NULL, 'Karšto vandens šilumos kiekis per 15 minučių', 1212, 2, NULL, NULL),
	(1709, 59, 1, 13, 2, 0, 34, 12, 51, NULL, 'Tiekiamo karšto vandens šilumos kiekis per 15 minučių', 1212, 2, NULL, NULL),
	(1710, 59, 2, 13, 2, 0, 34, 12, 51, NULL, 'Grįžtamo karšto vandens šilumos kiekis per 15 minučių', 1238, 2, NULL, NULL),
	(1711, 59, 3, 13, 2, 0, 34, 12, 51, NULL, 'Sunaudotos karšto vandens šilumos kiekis per 15 minučių', 1240, 2, NULL, NULL),
	(1712, 59, 0, 13, 3, 0, 33, 12, 50, NULL, 'Vidutinė karšto vandens šilumos galia per 15 minučių', 1232, 2, NULL, NULL),
	(1713, 59, 1, 13, 3, 0, 33, 12, 50, NULL, 'Vidutinė tiekiamo karšto vandens šilumos galia per 15 minučių', 1232, 2, NULL, NULL),
	(1714, 59, 2, 13, 3, 0, 33, 12, 50, NULL, 'Vidutinė grįžtamo karšto vandens šilumos galia per 15 minučių', 1234, 2, NULL, NULL),
	(1715, 59, 3, 13, 3, 0, 33, 12, 50, NULL, 'Vidutinė sunaudota karšto vandens šilumos galia per 15 minučių', 1236, 2, NULL, NULL),
	(1716, 60, 0, 13, 3, 0, 27, 12, 52, NULL, 'Vidutinė karšto vandens temperatūra per 15 minučių', 1215, 2, NULL, NULL),
	(1717, 60, 1, 13, 3, 0, 27, 12, 52, NULL, 'Vidutinė tiekiamo karšto vandens temperatūra per 15 minučių', 1215, 2, NULL, NULL),
	(1718, 60, 2, 13, 3, 0, 27, 12, 52, NULL, 'Vidutinė grįžtamo karšto vandens temperatūra per 15 minučių', 1256, 2, NULL, NULL),
	(1719, 60, 3, 13, 3, 0, 27, 12, 52, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens temperatūrų skirtumas per 15 minučių', 1257, 2, NULL, NULL),
	(1720, 59, 0, 14, 2, 0, 34, 13, 51, NULL, 'Karšto vandens šilumos kiekis per 20 minučių', 1212, 2, NULL, NULL),
	(1721, 59, 1, 14, 2, 0, 34, 13, 51, NULL, 'Tiekiamo karšto vandens šilumos kiekis per 20 minučių', 1212, 2, NULL, NULL),
	(1722, 59, 2, 14, 2, 0, 34, 13, 51, NULL, 'Grįžtamo karšto vandens šilumos kiekis per 20 minučių', 1238, 2, NULL, NULL),
	(1723, 59, 3, 14, 2, 0, 34, 13, 51, NULL, 'Sunaudotos karšto vandens šilumos kiekis per 20 minučių', 1240, 2, NULL, NULL),
	(1724, 59, 0, 14, 3, 0, 33, 13, 50, NULL, 'Vidutinė karšto vandens šilumos galia per 20 minučių', 1232, 2, NULL, NULL),
	(1725, 59, 1, 14, 3, 0, 33, 13, 50, NULL, 'Vidutinė tiekiamo karšto vandens šilumos galia per 20 minučių', 1232, 2, NULL, NULL),
	(1726, 59, 2, 14, 3, 0, 33, 13, 50, NULL, 'Vidutinė grįžtamo karšto vandens šilumos galia per 20 minučių', 1234, 2, NULL, NULL),
	(1727, 59, 3, 14, 3, 0, 33, 13, 50, NULL, 'Vidutinė sunaudota karšto vandens šilumos galia per 20 minučių', 1236, 2, NULL, NULL),
	(1728, 60, 0, 14, 3, 0, 27, 13, 52, NULL, 'Vidutinė karšto vandens temperatūra per 20 minučių', 1215, 2, NULL, NULL),
	(1729, 60, 1, 14, 3, 0, 27, 13, 52, NULL, 'Vidutinė tiekiamo karšto vandens temperatūra per 20 minučių', 1215, 2, NULL, NULL),
	(1730, 60, 2, 14, 3, 0, 27, 13, 52, NULL, 'Vidutinė grįžtamo karšto vandens temperatūra per 20 minučių', 1256, 2, NULL, NULL),
	(1731, 60, 3, 14, 3, 0, 27, 13, 52, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens temperatūrų skirtumas per 20 minučių', 1257, 2, NULL, NULL),
	(1732, 61, 0, 3, 2, 0, 31, 3, 53, NULL, 'Karšto vandens tūrio kiekis per 30 minučių', 1214, 2, NULL, NULL),
	(1733, 55, 0, 8, 2, 0, 31, 7, 74, NULL, 'Suminis šilumnešio tūrio kiekis', 1010, 5, NULL, NULL),
	(1734, 55, 1, 8, 2, 0, 31, 7, 74, NULL, 'Suminis tiekiamo šilumnešio tūrio kiekis', 1010, 5, NULL, NULL),
	(1735, 55, 2, 8, 2, 0, 31, 7, 74, NULL, 'Suminis grįžtamo šilumnešio tūrio kiekis', 1022, 5, NULL, NULL),
	(1736, 53, 0, 8, 2, 0, 2, 7, 71, NULL, 'Suminis šilumnešio šilumos kiekis', 1001, 5, NULL, NULL),
	(1737, 53, 1, 8, 2, 0, 2, 7, 71, NULL, 'Suminis tiekiamo šilumnešio šilumos kiekis', 1001, 5, NULL, NULL),
	(1738, 53, 2, 8, 2, 0, 2, 7, 71, NULL, 'Suminis grįžtamo šilumnešio šilumos kiekis', 1019, 5, NULL, NULL),
	(1739, 51, 0, 8, 2, 0, 35, 7, 68, NULL, 'Suminis šilumnešio masės kiekis', 1005, 5, NULL, NULL),
	(1740, 51, 1, 8, 2, 0, 35, 7, 68, NULL, 'Suminis tiekiamo šilumnešio masės kiekis', 1005, 5, NULL, NULL),
	(1741, 51, 2, 8, 2, 0, 35, 7, 68, NULL, 'Suminis grįžtamo šilumnešio masės kiekis', 1024, 5, NULL, NULL),
	(1742, 50, 0, 8, 2, 0, 31, 7, 66, NULL, 'Suminis šalčio tūrio kiekis', 1010, 5, NULL, NULL),
	(1743, 50, 1, 8, 2, 0, 31, 7, 66, NULL, 'Suminis tiekiamo šalčio tūrio kiekis', 1010, 5, NULL, NULL),
	(1744, 50, 2, 8, 2, 0, 31, 7, 66, NULL, 'Suminis grįžtamo šalčio tūrio kiekis', 1010, 5, NULL, NULL),
	(1745, 48, 0, 8, 2, 0, 2, 7, 62, NULL, 'Suminė šalčio energija', 1001, 5, NULL, NULL),
	(1746, 48, 1, 8, 2, 0, 2, 7, 62, NULL, 'Suminė tiekiamo šalčio energija', 1001, 5, NULL, NULL),
	(1747, 48, 2, 8, 2, 0, 2, 7, 62, NULL, 'Suminė grįžtamo šalčio energija', 1001, 5, NULL, NULL),
	(1748, 58, 0, 8, 2, 0, 31, 7, 59, NULL, 'Suminis šalto vandens tūrio kiekis', 1201, 5, NULL, NULL),
	(1749, 58, 1, 8, 2, 0, 31, 7, 59, NULL, 'Suminis tiekiamo šalto vandens tūrio kiekis', 1201, 5, NULL, NULL),
	(1750, 58, 2, 8, 2, 0, 31, 7, 59, NULL, 'Suminis grįžtamo šalto vandens tūrio kiekis', 1258, 5, NULL, NULL),
	(1751, 56, 0, 8, 2, 0, 34, 7, 56, NULL, 'Suminis šalto vandens šilumos kiekis', 1205, 5, NULL, NULL),
	(1752, 56, 1, 8, 2, 0, 34, 7, 56, NULL, 'Suminis tiekiamo šalto vandens šilumos kiekis', 1205, 5, NULL, NULL),
	(1753, 56, 2, 8, 2, 0, 34, 7, 56, NULL, 'Suminis grįžtamo šalto vandens šilumos kiekis', 1237, 5, NULL, NULL),
	(1754, 61, 0, 8, 2, 0, 31, 7, 53, NULL, 'Suminis karšto vandens tūrio kiekis', 1201, 5, NULL, NULL),
	(1755, 61, 1, 8, 2, 0, 31, 7, 53, NULL, 'Suminis tiekiamo karšto vandens tūrio kiekis', 1201, 5, NULL, NULL),
	(1756, 61, 2, 8, 2, 0, 31, 7, 53, NULL, 'Suminis grįžtamo karšto vandens tūrio kiekis', 1258, 5, NULL, NULL),
	(1757, 59, 0, 8, 2, 0, 34, 7, 51, NULL, 'Suminis karšto vandens šilumos kiekis', 1205, 5, NULL, NULL),
	(1758, 59, 1, 8, 2, 0, 34, 7, 51, NULL, 'Suminis tiekiamo karšto vandens šilumos kiekis', 1205, 5, NULL, NULL),
	(1759, 59, 2, 8, 2, 0, 34, 7, 51, NULL, 'Suminis grįžtamo karšto vandens šilumos kiekis', 1237, 5, NULL, NULL),
	(1760, 45, 0, 8, 2, 0, 31, 7, 12, NULL, 'Suminis dujų tūrio kiekis', 1107, 5, NULL, NULL),
	(1761, 43, 0, 8, 2, 0, 34, 7, 9, NULL, 'Suminis dujų šilumos kiekis', 1101, 5, NULL, NULL),
	(1762, 41, 0, 8, 2, 0, 35, 7, 6, NULL, 'Suminis dujų masės kiekis', 1105, 5, NULL, NULL),
	(1763, 40, 0, 8, 2, 0, 31, 7, 4, NULL, 'Suminis dujų koreguoto tūrio kiekis', 1112, 5, NULL, NULL),
	(1764, 39, 0, 8, 2, 0, 35, 7, 2, NULL, 'Suminis dujų koreguotos masės kiekis', 1110, 5, NULL, NULL),
	(1765, 1, 1, 8, 2, 0, 2, 3, 14, NULL, 'Suminė A+ energija, fiksuojama kas 30 minučių', 132, 5, NULL, NULL),
	(1766, 1, 1, 8, 2, 4, 2, 12, 14, '1.0.1.8.0.4', 'Suminė A+ energija pagal 4 tarifą, fiksuojama kas 15 minučių', 13, 5, NULL, NULL),
	(1767, 1, 1, 8, 2, 3, 2, 3, 14, '1.0.1.8.0.3', 'Suminė A+ energija pagal 3 tarifą, fiksuojama kas 30 minučių', 9, 5, NULL, NULL),
	(1768, 1, 1, 8, 2, 2, 2, 3, 14, '1.0.1.8.0.2', 'Suminė A+ energija pagal 2 tarifą, fiksuojama kas 30 minučių', 5, 5, NULL, NULL),
	(1769, 1, 1, 8, 2, 1, 2, 3, 14, '1.0.1.8.0.1', 'Suminė A+ energija pagal 1 tarifą, fiksuojama kas 30 minučių', 1, 5, NULL, NULL),
	(1770, 1, 1, 8, 2, 0, 2, 13, 14, NULL, 'Suminė A+ energija, fiksuojama kas 20 minučių', 132, 5, NULL, NULL),
	(1771, 1, 1, 8, 2, 4, 2, 13, 14, '1.0.1.8.0.4', 'Suminė A+ energija pagal 4 tarifą, fiksuojama kas 20 minučių', 13, 5, NULL, NULL),
	(1772, 1, 1, 8, 2, 3, 2, 13, 14, '1.0.1.8.0.3', 'Suminė A+ energija pagal 3 tarifą, fiksuojama kas 20 minučių', 9, 5, NULL, NULL),
	(1773, 1, 1, 8, 2, 2, 2, 13, 14, '1.0.1.8.0.2', 'Suminė A+ energija pagal 2 tarifą, fiksuojama kas 20 minučių', 5, 5, NULL, NULL),
	(1774, 1, 1, 8, 2, 1, 2, 13, 14, '1.0.1.8.0.1', 'Suminė A+ energija pagal 1 tarifą, fiksuojama kas 20 minučių', 1, 5, NULL, NULL),
	(1775, 1, 1, 8, 2, 0, 2, 12, 14, NULL, 'Suminė A+ energija, fiksuojama kas 15 minučių', 132, 5, NULL, NULL),
	(1776, 1, 1, 8, 2, 4, 2, 3, 14, '1.0.1.8.0.4', 'Suminė A+ energija pagal 4 tarifą, fiksuojama kas 30 minučių', 13, 5, NULL, NULL),
	(1777, 1, 1, 8, 2, 3, 2, 12, 14, '1.0.1.8.0.3', 'Suminė A+ energija pagal 3 tarifą, fiksuojama kas 15 minučių', 9, 5, NULL, NULL),
	(1778, 1, 1, 8, 2, 2, 2, 12, 14, '1.0.1.8.0.2', 'Suminė A+ energija pagal 2 tarifą, fiksuojama kas 15 minučių', 5, 5, NULL, NULL),
	(1779, 1, 1, 8, 2, 1, 2, 12, 14, '1.0.1.8.0.1', 'Suminė A+ energija pagal 1 tarifą, fiksuojama kas 15 minučių', 1, 5, NULL, NULL),
	(1780, 1, 1, 8, 2, 0, 2, 4, 14, NULL, 'Suminė A+ energija, fiksuojama kas valandą', 132, 5, NULL, NULL),
	(1781, 1, 1, 8, 2, 4, 2, 4, 14, '1.0.1.8.0.4', 'Suminė A+ energija pagal 4 tarifą, fiksuojama kas valandą', 13, 5, NULL, NULL),
	(1782, 1, 1, 8, 2, 3, 2, 4, 14, '1.0.1.8.0.3', 'Suminė A+ energija pagal 3 tarifą, fiksuojama kas valandą', 9, 5, NULL, NULL),
	(1783, 1, 1, 8, 2, 2, 2, 4, 14, '1.0.1.8.0.2', 'Suminė A+ energija pagal 2 tarifą, fiksuojama kas valandą', 5, 5, NULL, NULL),
	(1784, 1, 1, 8, 2, 1, 2, 4, 14, '1.0.1.8.0.1', 'Suminė A+ energija pagal 1 tarifą, fiksuojama kas valandą', 1, 5, NULL, NULL),
	(1785, 1, 2, 8, 2, 0, 2, 13, 14, NULL, 'Suminė A- energija, fiksuojama kas 20 minučių', 133, 5, NULL, NULL),
	(1786, 1, 2, 8, 2, 1, 2, 3, 14, '1.0.2.8.0.1', 'Suminė A- energija pagal 1 tarifą, fiksuojama kas 30 minučių', 2, 5, NULL, NULL),
	(1787, 1, 2, 8, 2, 3, 2, 13, 14, '1.0.2.8.0.3', 'Suminė A- energija pagal 3 tarifą, fiksuojama kas 20 minučių', 10, 5, NULL, NULL),
	(1788, 1, 2, 8, 2, 2, 2, 13, 14, '1.0.2.8.0.2', 'Suminė A- energija pagal 2 tarifą, fiksuojama kas 20 minučių', 6, 5, NULL, NULL),
	(1789, 1, 2, 8, 2, 1, 2, 13, 14, '1.0.2.8.0.1', 'Suminė A- energija pagal 1 tarifą, fiksuojama kas 20 minučių', 2, 5, NULL, NULL),
	(1790, 1, 2, 8, 2, 0, 2, 4, 14, NULL, 'Suminė A- energija, fiksuojama kas valandą', 133, 5, NULL, NULL),
	(1791, 1, 2, 8, 2, 4, 2, 4, 14, '1.0.2.8.0.4', 'Suminė A- energija pagal 4 tarifą, fiksuojama kas valandą', 14, 5, NULL, NULL),
	(1792, 1, 2, 8, 2, 3, 2, 4, 14, '1.0.2.8.0.3', 'Suminė A- energija pagal 3 tarifą, fiksuojama kas valandą', 10, 5, NULL, NULL),
	(1793, 1, 2, 8, 2, 2, 2, 4, 14, '1.0.2.8.0.2', 'Suminė A- energija pagal 2 tarifą, fiksuojama kas valandą', 6, 5, NULL, NULL),
	(1794, 1, 2, 8, 2, 1, 2, 4, 14, '1.0.2.8.0.1', 'Suminė A- energija pagal 1 tarifą, fiksuojama kas valandą', 2, 5, NULL, NULL),
	(1795, 1, 2, 8, 2, 0, 2, 12, 14, NULL, 'Suminė A- energija, fiksuojama kas 15 minučių', 133, 5, NULL, NULL),
	(1796, 1, 2, 8, 2, 4, 2, 12, 14, '1.0.2.8.0.4', 'Suminė A- energija pagal 4 tarifą, fiksuojama kas 15 minučių', 14, 5, NULL, NULL),
	(1797, 1, 2, 8, 2, 3, 2, 12, 14, '1.0.2.8.0.3', 'Suminė A- energija pagal 3 tarifą, fiksuojama kas 15 minučių', 10, 5, NULL, NULL),
	(1798, 1, 2, 8, 2, 2, 2, 12, 14, '1.0.2.8.0.2', 'Suminė A- energija pagal 2 tarifą, fiksuojama kas 15 minučių', 6, 5, NULL, NULL),
	(1799, 1, 2, 8, 2, 1, 2, 12, 14, '1.0.2.8.0.1', 'Suminė A- energija pagal 1 tarifą, fiksuojama kas 15 minučių', 2, 5, NULL, NULL),
	(1800, 1, 2, 8, 2, 0, 2, 3, 14, NULL, 'Suminė A- energija, fiksuojama kas 30 minučių', 133, 5, NULL, NULL),
	(1801, 1, 2, 8, 2, 4, 2, 3, 14, '1.0.2.8.0.4', 'Suminė A- energija pagal 4 tarifą, fiksuojama kas 30 minučių', 14, 5, NULL, NULL),
	(1802, 1, 2, 8, 2, 3, 2, 3, 14, '1.0.2.8.0.3', 'Suminė A- energija pagal 3 tarifą, fiksuojama kas 30 minučių', 10, 5, NULL, NULL),
	(1803, 1, 2, 8, 2, 2, 2, 3, 14, '1.0.2.8.0.2', 'Suminė A- energija pagal 2 tarifą, fiksuojama kas 30 minučių', 6, 5, NULL, NULL),
	(1804, 1, 2, 8, 2, 4, 2, 13, 14, '1.0.2.8.0.4', 'Suminė A- energija pagal 4 tarifą, fiksuojama kas 20 minučių', 14, 5, NULL, NULL),
	(1805, 3, 1, 8, 2, 4, 4, 3, 15, '1.0.3.8.0.4', 'Suminė R+ energija pagal 4 tarifą, fiksuojama kas 30 minučių', 15, 5, NULL, NULL),
	(1806, 3, 1, 8, 2, 0, 4, 3, 15, NULL, 'Suminė R+ energija, fiksuojama kas 30 minučių', 134, 5, NULL, NULL),
	(1807, 3, 1, 8, 2, 2, 4, 3, 15, '1.0.3.8.0.2', 'Suminė R+ energija pagal 2 tarifą, fiksuojama kas 30 minučių', 7, 5, NULL, NULL),
	(1808, 3, 1, 8, 2, 1, 4, 3, 15, '1.0.3.8.0.1', 'Suminė R+ energija pagal 1 tarifą, fiksuojama kas 30 minučių', 3, 5, NULL, NULL),
	(1809, 3, 1, 8, 2, 0, 4, 13, 15, NULL, 'Suminė R+ energija, fiksuojama kas 20 minučių', 134, 5, NULL, NULL),
	(1810, 3, 1, 8, 2, 4, 4, 13, 15, '1.0.3.8.0.4', 'Suminė R+ energija pagal 4 tarifą, fiksuojama kas 20 minučių', 15, 5, NULL, NULL),
	(1811, 3, 1, 8, 2, 3, 4, 13, 15, '1.0.3.8.0.3', 'Suminė R+ energija pagal 3 tarifą, fiksuojama kas 20 minučių', 11, 5, NULL, NULL),
	(1812, 3, 1, 8, 2, 2, 4, 13, 15, '1.0.3.8.0.2', 'Suminė R+ energija pagal 2 tarifą, fiksuojama kas 20 minučių', 7, 5, NULL, NULL),
	(1813, 3, 1, 8, 2, 1, 4, 13, 15, '1.0.3.8.0.1', 'Suminė R+ energija pagal 1 tarifą, fiksuojama kas 20 minučių', 3, 5, NULL, NULL),
	(1814, 3, 1, 8, 2, 0, 4, 4, 15, NULL, 'Suminė R+ energija, fiksuojama kas valandą', 134, 5, NULL, NULL),
	(1815, 3, 1, 8, 2, 4, 4, 4, 15, '1.0.3.8.0.4', 'Suminė R+ energija pagal 4 tarifą, fiksuojama kas valandą', 15, 5, NULL, NULL),
	(1816, 3, 1, 8, 2, 3, 4, 4, 15, '1.0.3.8.0.3', 'Suminė R+ energija pagal 3 tarifą, fiksuojama kas valandą', 11, 5, NULL, NULL),
	(1817, 3, 1, 8, 2, 2, 4, 4, 15, '1.0.3.8.0.2', 'Suminė R+ energija pagal 2 tarifą, fiksuojama kas valandą', 7, 5, NULL, NULL),
	(1818, 3, 1, 8, 2, 1, 4, 4, 15, '1.0.3.8.0.1', 'Suminė R+ energija pagal 1 tarifą, fiksuojama kas valandą', 3, 5, NULL, NULL),
	(1819, 3, 1, 8, 2, 0, 4, 12, 15, NULL, 'Suminė R+ energija, fiksuojama kas 15 minučių', 134, 5, NULL, NULL),
	(1820, 3, 1, 8, 2, 4, 4, 12, 15, '1.0.3.8.0.4', 'Suminė R+ energija pagal 4 tarifą, fiksuojama kas 15 minučių', 15, 5, NULL, NULL),
	(1821, 3, 1, 8, 2, 3, 4, 12, 15, '1.0.3.8.0.3', 'Suminė R+ energija pagal 3 tarifą, fiksuojama kas 15 minučių', 11, 5, NULL, NULL),
	(1822, 3, 1, 8, 2, 2, 4, 12, 15, '1.0.3.8.0.2', 'Suminė R+ energija pagal 2 tarifą, fiksuojama kas 15 minučių', 7, 5, NULL, NULL),
	(1823, 3, 1, 8, 2, 1, 4, 12, 15, '1.0.3.8.0.1', 'Suminė R+ energija pagal 1 tarifą, fiksuojama kas 15 minučių', 3, 5, NULL, NULL),
	(1824, 3, 1, 8, 2, 3, 4, 3, 15, '1.0.3.8.0.3', 'Suminė R+ energija pagal 3 tarifą, fiksuojama kas 30 minučių', 11, 5, NULL, NULL),
	(1825, 3, 2, 8, 2, 4, 4, 13, 15, '1.0.4.8.0.4', 'Suminė R- energija pagal 4 tarifą, fiksuojama kas 20 minučių', 16, 5, NULL, NULL),
	(1826, 3, 2, 8, 2, 3, 4, 13, 15, '1.0.4.8.0.3', 'Suminė R- energija pagal 3 tarifą, fiksuojama kas 20 minučių', 12, 5, NULL, NULL),
	(1827, 3, 2, 8, 2, 2, 4, 13, 15, '1.0.4.8.0.2', 'Suminė R- energija pagal 2 tarifą, fiksuojama kas 20 minučių', 8, 5, NULL, NULL),
	(1828, 3, 2, 8, 2, 1, 4, 13, 15, '1.0.4.8.0.1', 'Suminė R- energija pagal 1 tarifą, fiksuojama kas 20 minučių', 4, 5, NULL, NULL),
	(1829, 3, 2, 8, 2, 0, 4, 12, 15, NULL, 'Suminė R- energija, fiksuojama kas 15 minučių', 135, 5, NULL, NULL),
	(1830, 3, 2, 8, 2, 4, 4, 12, 15, '1.0.4.8.0.4', 'Suminė R- energija pagal 4 tarifą, fiksuojama kas 15 minučių', 16, 5, NULL, NULL),
	(1831, 3, 2, 8, 2, 3, 4, 12, 15, '1.0.4.8.0.3', 'Suminė R- energija pagal 3 tarifą, fiksuojama kas 15 minučių', 12, 5, NULL, NULL),
	(1832, 3, 2, 8, 2, 2, 4, 12, 15, '1.0.4.8.0.2', 'Suminė R- energija pagal 2 tarifą, fiksuojama kas 15 minučių', 8, 5, NULL, NULL),
	(1833, 3, 2, 8, 2, 1, 4, 12, 15, '1.0.4.8.0.1', 'Suminė R- energija pagal 1 tarifą, fiksuojama kas 15 minučių', 4, 5, NULL, NULL),
	(1834, 3, 2, 8, 2, 0, 4, 13, 15, NULL, 'Suminė R- energija, fiksuojama kas 20 minučių', 135, 5, NULL, NULL),
	(1835, 3, 2, 8, 2, 4, 4, 4, 15, '1.0.4.8.0.4', 'Suminė R- energija pagal 4 tarifą, fiksuojama kas valandą', 16, 5, NULL, NULL),
	(1836, 3, 2, 8, 2, 3, 4, 4, 15, '1.0.4.8.0.3', 'Suminė R- energija pagal 3 tarifą, fiksuojama kas valandą', 12, 5, NULL, NULL),
	(1837, 3, 2, 8, 2, 2, 4, 4, 15, '1.0.4.8.0.2', 'Suminė R- energija pagal 2 tarifą, fiksuojama kas valandą', 8, 5, NULL, NULL),
	(1838, 3, 2, 8, 2, 1, 4, 4, 15, '1.0.4.8.0.1', 'Suminė R- energija pagal 1 tarifą, fiksuojama kas valandą', 4, 5, NULL, NULL),
	(1839, 3, 2, 8, 2, 0, 4, 3, 15, NULL, 'Suminė R- energija, fiksuojama kas 30 minučių', 135, 5, NULL, NULL),
	(1840, 3, 2, 8, 2, 4, 4, 3, 15, '1.0.4.8.0.4', 'Suminė R- energija pagal 4 tarifą, fiksuojama kas 30 minučių', 16, 5, NULL, NULL),
	(1841, 3, 2, 8, 2, 3, 4, 3, 15, '1.0.4.8.0.3', 'Suminė R- energija pagal 3 tarifą, fiksuojama kas 30 minučių', 12, 5, NULL, NULL),
	(1842, 3, 2, 8, 2, 2, 4, 3, 15, '1.0.4.8.0.2', 'Suminė R- energija pagal 2 tarifą, fiksuojama kas 30 minučių', 8, 5, NULL, NULL),
	(1843, 3, 2, 8, 2, 1, 4, 3, 15, '1.0.4.8.0.1', 'Suminė R- energija pagal 1 tarifą, fiksuojama kas 30 minučių', 4, 5, NULL, NULL),
	(1844, 3, 2, 8, 2, 0, 4, 4, 15, NULL, 'Suminė R- energija, fiksuojama kas valandą', 135, 5, NULL, NULL),
	(1845, 3, 5, 8, 2, 1, 4, 4, 15, NULL, 'Suminė R1 energija pagal 1 tarifą, fiksuojama kas valandą', 138, 5, NULL, NULL),
	(1846, 3, 5, 8, 2, 2, 4, 4, 15, NULL, 'Suminė R1 energija pagal 2 tarifą, fiksuojama kas valandą', 144, 5, NULL, NULL),
	(1847, 3, 5, 8, 2, 3, 4, 4, 15, NULL, 'Suminė R1 energija pagal 3 tarifą, fiksuojama kas valandą', 150, 5, NULL, NULL),
	(1848, 3, 5, 8, 2, 4, 4, 4, 15, NULL, 'Suminė R1 energija pagal 4 tarifą, fiksuojama kas valandą', 156, 5, NULL, NULL),
	(1849, 3, 5, 8, 2, 0, 4, 4, 15, NULL, 'Suminė R1 energija, fiksuojama kas valandą', 322, 5, NULL, NULL),
	(1850, 3, 5, 8, 2, 1, 4, 13, 15, NULL, 'Suminė R1 energija pagal 1 tarifą, fiksuojama kas 20 minučių', 138, 5, NULL, NULL),
	(1851, 3, 5, 8, 2, 2, 4, 13, 15, NULL, 'Suminė R1 energija pagal 2 tarifą, fiksuojama kas 20 minučių', 144, 5, NULL, NULL),
	(1852, 3, 5, 8, 2, 3, 4, 13, 15, NULL, 'Suminė R1 energija pagal 3 tarifą, fiksuojama kas 20 minučių', 150, 5, NULL, NULL),
	(1853, 3, 5, 8, 2, 4, 4, 13, 15, NULL, 'Suminė R1 energija pagal 4 tarifą, fiksuojama kas 20 minučių', 156, 5, NULL, NULL),
	(1854, 3, 5, 8, 2, 0, 4, 13, 15, NULL, 'Suminė R1 energija, fiksuojama kas 20 minučių', 322, 5, NULL, NULL),
	(1855, 3, 5, 8, 2, 1, 4, 12, 15, NULL, 'Suminė R1 energija pagal 1 tarifą, fiksuojama kas 15 minučių', 138, 5, NULL, NULL),
	(1856, 3, 5, 8, 2, 2, 4, 12, 15, NULL, 'Suminė R1 energija pagal 2 tarifą, fiksuojama kas 15 minučių', 144, 5, NULL, NULL),
	(1857, 3, 5, 8, 2, 3, 4, 12, 15, NULL, 'Suminė R1 energija pagal 3 tarifą, fiksuojama kas 15 minučių', 150, 5, NULL, NULL),
	(1858, 3, 5, 8, 2, 4, 4, 12, 15, NULL, 'Suminė R1 energija pagal 4 tarifą, fiksuojama kas 15 minučių', 156, 5, NULL, NULL),
	(1859, 3, 5, 8, 2, 0, 4, 12, 15, NULL, 'Suminė R1 energija, fiksuojama kas 15 minučių', 322, 5, NULL, NULL),
	(1860, 3, 5, 8, 2, 1, 4, 3, 15, NULL, 'Suminė R1 energija pagal 1 tarifą, fiksuojama kas 30 minučių', 138, 5, NULL, NULL),
	(1861, 3, 5, 8, 2, 2, 4, 3, 15, NULL, 'Suminė R1 energija pagal 2 tarifą, fiksuojama kas 30 minučių', 144, 5, NULL, NULL),
	(1862, 3, 5, 8, 2, 3, 4, 3, 15, NULL, 'Suminė R1 energija pagal 3 tarifą, fiksuojama kas 30 minučių', 150, 5, NULL, NULL),
	(1863, 3, 5, 8, 2, 4, 4, 3, 15, NULL, 'Suminė R1 energija pagal 4 tarifą, fiksuojama kas 30 minučių', 156, 5, NULL, NULL),
	(1864, 3, 5, 8, 2, 0, 4, 3, 15, NULL, 'Suminė R1 energija, fiksuojama kas 30 minučių', 322, 5, NULL, NULL),
	(1865, 3, 6, 8, 2, 1, 4, 4, 15, NULL, 'Suminė R2 energija pagal 1 tarifą, fiksuojama kas valandą', 139, 5, NULL, NULL),
	(1866, 3, 6, 8, 2, 3, 4, 12, 15, NULL, 'Suminė R2 energija pagal 3 tarifą, fiksuojama kas 15 minučių', 151, 5, NULL, NULL),
	(1867, 3, 6, 8, 2, 3, 4, 4, 15, NULL, 'Suminė R2 energija pagal 3 tarifą, fiksuojama kas valandą', 151, 5, NULL, NULL),
	(1868, 3, 6, 8, 2, 4, 4, 4, 15, NULL, 'Suminė R2 energija pagal 4 tarifą, fiksuojama kas valandą', 157, 5, NULL, NULL),
	(1869, 3, 6, 8, 2, 0, 4, 4, 15, NULL, 'Suminė R2 energija, fiksuojama kas valandą', 323, 5, NULL, NULL),
	(1870, 3, 6, 8, 2, 1, 4, 13, 15, NULL, 'Suminė R2 energija pagal 1 tarifą, fiksuojama kas 20 minučių', 139, 5, NULL, NULL),
	(1871, 3, 6, 8, 2, 2, 4, 13, 15, NULL, 'Suminė R2 energija pagal 2 tarifą, fiksuojama kas 20 minučių', 145, 5, NULL, NULL),
	(1872, 3, 6, 8, 2, 3, 4, 13, 15, NULL, 'Suminė R2 energija pagal 3 tarifą, fiksuojama kas 20 minučių', 151, 5, NULL, NULL),
	(1873, 3, 6, 8, 2, 4, 4, 13, 15, NULL, 'Suminė R2 energija pagal 4 tarifą, fiksuojama kas 20 minučių', 157, 5, NULL, NULL),
	(1874, 3, 6, 8, 2, 0, 4, 13, 15, NULL, 'Suminė R2 energija, fiksuojama kas 20 minučių', 323, 5, NULL, NULL),
	(1875, 3, 6, 8, 2, 1, 4, 12, 15, NULL, 'Suminė R2 energija pagal 1 tarifą, fiksuojama kas 15 minučių', 139, 5, NULL, NULL),
	(1876, 3, 6, 8, 2, 2, 4, 12, 15, NULL, 'Suminė R2 energija pagal 2 tarifą, fiksuojama kas 15 minučių', 145, 5, NULL, NULL),
	(1877, 3, 6, 8, 2, 0, 4, 3, 15, NULL, 'Suminė R2 energija, fiksuojama kas 30 minučių', 323, 5, NULL, NULL),
	(1878, 3, 6, 8, 2, 4, 4, 3, 15, NULL, 'Suminė R2 energija pagal 4 tarifą, fiksuojama kas 30 minučių', 157, 5, NULL, NULL),
	(1879, 3, 6, 8, 2, 3, 4, 3, 15, NULL, 'Suminė R2 energija pagal 3 tarifą, fiksuojama kas 30 minučių', 151, 5, NULL, NULL),
	(1880, 3, 6, 8, 2, 2, 4, 3, 15, NULL, 'Suminė R2 energija pagal 2 tarifą, fiksuojama kas 30 minučių', 145, 5, NULL, NULL),
	(1881, 3, 6, 8, 2, 1, 4, 3, 15, NULL, 'Suminė R2 energija pagal 1 tarifą, fiksuojama kas 30 minučių', 139, 5, NULL, NULL),
	(1882, 3, 6, 8, 2, 0, 4, 12, 15, NULL, 'Suminė R2 energija, fiksuojama kas 15 minučių', 323, 5, NULL, NULL),
	(1883, 3, 6, 8, 2, 4, 4, 12, 15, NULL, 'Suminė R2 energija pagal 4 tarifą, fiksuojama kas 15 minučių', 157, 5, NULL, NULL),
	(1884, 3, 6, 8, 2, 2, 4, 4, 15, NULL, 'Suminė R2 energija pagal 2 tarifą, fiksuojama kas valandą', 145, 5, NULL, NULL),
	(1885, 3, 7, 8, 2, 0, 4, 3, 15, NULL, 'Suminė R3 energija, fiksuojama kas 30 minučių', 324, 5, NULL, NULL),
	(1886, 3, 7, 8, 2, 4, 4, 3, 15, NULL, 'Suminė R3 energija pagal 4 tarifą, fiksuojama kas 30 minučių', 158, 5, NULL, NULL),
	(1887, 3, 7, 8, 2, 3, 4, 3, 15, NULL, 'Suminė R3 energija pagal 3 tarifą, fiksuojama kas 30 minučių', 152, 5, NULL, NULL),
	(1888, 3, 7, 8, 2, 2, 4, 3, 15, NULL, 'Suminė R3 energija pagal 2 tarifą, fiksuojama kas 30 minučių', 146, 5, NULL, NULL),
	(1889, 3, 7, 8, 2, 1, 4, 3, 15, NULL, 'Suminė R3 energija pagal 1 tarifą, fiksuojama kas 30 minučių', 140, 5, NULL, NULL),
	(1890, 3, 7, 8, 2, 0, 4, 12, 15, NULL, 'Suminė R3 energija, fiksuojama kas 15 minučių', 324, 5, NULL, NULL),
	(1891, 3, 7, 8, 2, 4, 4, 12, 15, NULL, 'Suminė R3 energija pagal 4 tarifą, fiksuojama kas 15 minučių', 158, 5, NULL, NULL),
	(1892, 3, 7, 8, 2, 3, 4, 12, 15, NULL, 'Suminė R3 energija pagal 3 tarifą, fiksuojama kas 15 minučių', 152, 5, NULL, NULL),
	(1893, 3, 7, 8, 2, 2, 4, 12, 15, NULL, 'Suminė R3 energija pagal 2 tarifą, fiksuojama kas 15 minučių', 146, 5, NULL, NULL),
	(1894, 3, 7, 8, 2, 1, 4, 12, 15, NULL, 'Suminė R3 energija pagal 1 tarifą, fiksuojama kas 15 minučių', 140, 5, NULL, NULL),
	(1895, 3, 7, 8, 2, 3, 4, 13, 15, NULL, 'Suminė R3 energija pagal 3 tarifą, fiksuojama kas 20 minučių', 152, 5, NULL, NULL),
	(1896, 3, 7, 8, 2, 4, 4, 13, 15, NULL, 'Suminė R3 energija pagal 4 tarifą, fiksuojama kas 20 minučių', 158, 5, NULL, NULL),
	(1897, 3, 7, 8, 2, 0, 4, 13, 15, NULL, 'Suminė R3 energija, fiksuojama kas 20 minučių', 324, 5, NULL, NULL),
	(1898, 3, 7, 8, 2, 2, 4, 13, 15, NULL, 'Suminė R3 energija pagal 2 tarifą, fiksuojama kas 20 minučių', 146, 5, NULL, NULL),
	(1899, 3, 7, 8, 2, 1, 4, 13, 15, NULL, 'Suminė R3 energija pagal 1 tarifą, fiksuojama kas 20 minučių', 140, 5, NULL, NULL),
	(1900, 3, 7, 8, 2, 0, 4, 4, 15, NULL, 'Suminė R3 energija, fiksuojama kas valandą', 324, 5, NULL, NULL),
	(1901, 3, 7, 8, 2, 4, 4, 4, 15, NULL, 'Suminė R3 energija pagal 4 tarifą, fiksuojama kas valandą', 158, 5, NULL, NULL),
	(1902, 3, 7, 8, 2, 3, 4, 4, 15, NULL, 'Suminė R3 energija pagal 3 tarifą, fiksuojama kas valandą', 152, 5, NULL, NULL),
	(1903, 3, 7, 8, 2, 2, 4, 4, 15, NULL, 'Suminė R3 energija pagal 2 tarifą, fiksuojama kas valandą', 146, 5, NULL, NULL),
	(1904, 3, 7, 8, 2, 1, 4, 4, 15, NULL, 'Suminė R3 energija pagal 1 tarifą, fiksuojama kas valandą', 140, 5, NULL, NULL),
	(1905, 3, 8, 8, 2, 2, 4, 12, 15, NULL, 'Suminė R4 energija pagal 2 tarifą, fiksuojama kas 15 minučių', 147, 5, NULL, NULL),
	(1906, 3, 8, 8, 2, 0, 4, 3, 15, NULL, 'Suminė R4 energija, fiksuojama kas 30 minučių', 325, 5, NULL, NULL),
	(1907, 3, 8, 8, 2, 0, 4, 13, 15, NULL, 'Suminė R4 energija, fiksuojama kas 20 minučių', 325, 5, NULL, NULL),
	(1908, 3, 8, 8, 2, 4, 4, 13, 15, NULL, 'Suminė R4 energija pagal 4 tarifą, fiksuojama kas 20 minučių', 159, 5, NULL, NULL),
	(1909, 3, 8, 8, 2, 3, 4, 13, 15, NULL, 'Suminė R4 energija pagal 3 tarifą, fiksuojama kas 20 minučių', 153, 5, NULL, NULL),
	(1910, 3, 8, 8, 2, 2, 4, 13, 15, NULL, 'Suminė R4 energija pagal 2 tarifą, fiksuojama kas 20 minučių', 147, 5, NULL, NULL),
	(1911, 3, 8, 8, 2, 1, 4, 13, 15, NULL, 'Suminė R4 energija pagal 1 tarifą, fiksuojama kas 20 minučių', 141, 5, NULL, NULL),
	(1912, 3, 8, 8, 2, 0, 4, 4, 15, NULL, 'Suminė R4 energija, fiksuojama kas valandą', 325, 5, NULL, NULL),
	(1913, 3, 8, 8, 2, 4, 4, 4, 15, NULL, 'Suminė R4 energija pagal 4 tarifą, fiksuojama kas valandą', 159, 5, NULL, NULL),
	(1914, 3, 8, 8, 2, 3, 4, 4, 15, NULL, 'Suminė R4 energija pagal 3 tarifą, fiksuojama kas valandą', 153, 5, NULL, NULL),
	(1915, 3, 8, 8, 2, 2, 4, 4, 15, NULL, 'Suminė R4 energija pagal 2 tarifą, fiksuojama kas valandą', 147, 5, NULL, NULL),
	(1916, 3, 8, 8, 2, 1, 4, 4, 15, NULL, 'Suminė R4 energija pagal 1 tarifą, fiksuojama kas valandą', 141, 5, NULL, NULL),
	(1917, 3, 8, 8, 2, 3, 4, 12, 15, NULL, 'Suminė R4 energija pagal 3 tarifą, fiksuojama kas 15 minučių', 153, 5, NULL, NULL),
	(1918, 3, 8, 8, 2, 4, 4, 12, 15, NULL, 'Suminė R4 energija pagal 4 tarifą, fiksuojama kas 15 minučių', 159, 5, NULL, NULL),
	(1919, 3, 8, 8, 2, 0, 4, 12, 15, NULL, 'Suminė R4 energija, fiksuojama kas 15 minučių', 325, 5, NULL, NULL),
	(1920, 3, 8, 8, 2, 1, 4, 3, 15, NULL, 'Suminė R4 energija pagal 1 tarifą, fiksuojama kas 30 minučių', 141, 5, NULL, NULL),
	(1921, 3, 8, 8, 2, 2, 4, 3, 15, NULL, 'Suminė R4 energija pagal 2 tarifą, fiksuojama kas 30 minučių', 147, 5, NULL, NULL),
	(1922, 3, 8, 8, 2, 3, 4, 3, 15, NULL, 'Suminė R4 energija pagal 3 tarifą, fiksuojama kas 30 minučių', 153, 5, NULL, NULL),
	(1923, 3, 8, 8, 2, 4, 4, 3, 15, NULL, 'Suminė R4 energija pagal 4 tarifą, fiksuojama kas 30 minučių', 159, 5, NULL, NULL),
	(1924, 3, 8, 8, 2, 1, 4, 12, 15, NULL, 'Suminė R4 energija pagal 1 tarifą, fiksuojama kas 15 minučių', 141, 5, NULL, NULL),
	(1925, 34, 1, 8, 2, 3, 41, 3, 45, NULL, 'Suminė W+ energija pagal 3 tarifą, fiksuojama kas 30 minučių', 154, 5, NULL, NULL),
	(1926, 34, 1, 8, 2, 2, 41, 3, 45, NULL, 'Suminė W+ energija pagal 2 tarifą, fiksuojama kas 30 minučių', 148, 5, NULL, NULL),
	(1927, 34, 1, 8, 2, 0, 41, 3, 45, NULL, 'Suminė W+ energija, fiksuojama kas 30 minučių', 136, 5, NULL, NULL),
	(1928, 34, 1, 8, 2, 4, 41, 3, 45, NULL, 'Suminė W+ energija pagal 4 tarifą, fiksuojama kas 30 minučių', 160, 5, NULL, NULL),
	(1929, 34, 1, 8, 2, 1, 41, 3, 45, NULL, 'Suminė W+ energija pagal 1 tarifą, fiksuojama kas 30 minučių', 142, 5, NULL, NULL),
	(1930, 34, 1, 8, 2, 0, 41, 12, 45, NULL, 'Suminė W+ energija, fiksuojama kas 15 minučių', 136, 5, NULL, NULL),
	(1931, 34, 1, 8, 2, 4, 41, 12, 45, NULL, 'Suminė W+ energija pagal 4 tarifą, fiksuojama kas 15 minučių', 160, 5, NULL, NULL),
	(1932, 34, 1, 8, 2, 3, 41, 12, 45, NULL, 'Suminė W+ energija pagal 3 tarifą, fiksuojama kas 15 minučių', 154, 5, NULL, NULL),
	(1933, 34, 1, 8, 2, 2, 41, 12, 45, NULL, 'Suminė W+ energija pagal 2 tarifą, fiksuojama kas 15 minučių', 148, 5, NULL, NULL),
	(1934, 34, 1, 8, 2, 1, 41, 12, 45, NULL, 'Suminė W+ energija pagal 1 tarifą, fiksuojama kas 15 minučių', 142, 5, NULL, NULL),
	(1935, 34, 1, 8, 2, 0, 41, 13, 45, NULL, 'Suminė W+ energija, fiksuojama kas 20 minučių', 136, 5, NULL, NULL),
	(1936, 34, 1, 8, 2, 4, 41, 13, 45, NULL, 'Suminė W+ energija pagal 4 tarifą, fiksuojama kas 20 minučių', 160, 5, NULL, NULL),
	(1937, 34, 1, 8, 2, 3, 41, 13, 45, NULL, 'Suminė W+ energija pagal 3 tarifą, fiksuojama kas 20 minučių', 154, 5, NULL, NULL),
	(1938, 34, 1, 8, 2, 2, 41, 13, 45, NULL, 'Suminė W+ energija pagal 2 tarifą, fiksuojama kas 20 minučių', 148, 5, NULL, NULL),
	(1939, 34, 1, 8, 2, 1, 41, 13, 45, NULL, 'Suminė W+ energija pagal 1 tarifą, fiksuojama kas 20 minučių', 142, 5, NULL, NULL),
	(1940, 34, 1, 8, 2, 0, 41, 4, 45, NULL, 'Suminė W+ energija, fiksuojama kas valandą', 136, 5, NULL, NULL),
	(1941, 34, 1, 8, 2, 4, 41, 4, 45, NULL, 'Suminė W+ energija pagal 4 tarifą, fiksuojama kas valandą', 160, 5, NULL, NULL),
	(1942, 34, 1, 8, 2, 3, 41, 4, 45, NULL, 'Suminė W+ energija pagal 3 tarifą, fiksuojama kas valandą', 154, 5, NULL, NULL),
	(1943, 34, 1, 8, 2, 2, 41, 4, 45, NULL, 'Suminė W+ energija pagal 2 tarifą, fiksuojama kas valandą', 148, 5, NULL, NULL),
	(1944, 34, 1, 8, 2, 1, 41, 4, 45, NULL, 'Suminė W+ energija pagal 1 tarifą, fiksuojama kas valandą', 142, 5, NULL, NULL),
	(1945, 34, 2, 8, 2, 3, 41, 12, 45, NULL, 'Suminė W- energija pagal 3 tarifą, fiksuojama kas 15 minučių', 155, 5, NULL, NULL),
	(1946, 34, 2, 8, 2, 1, 41, 3, 45, NULL, 'Suminė W- energija pagal 1 tarifą, fiksuojama kas 30 minučių', 143, 5, NULL, NULL),
	(1947, 34, 2, 8, 2, 0, 41, 12, 45, NULL, 'Suminė W- energija, fiksuojama kas 15 minučių', 137, 5, NULL, NULL),
	(1948, 34, 2, 8, 2, 2, 41, 12, 45, NULL, 'Suminė W- energija pagal 2 tarifą, fiksuojama kas 15 minučių', 149, 5, NULL, NULL),
	(1949, 34, 2, 8, 2, 1, 41, 12, 45, NULL, 'Suminė W- energija pagal 1 tarifą, fiksuojama kas 15 minučių', 143, 5, NULL, NULL),
	(1950, 34, 2, 8, 2, 0, 41, 4, 45, NULL, 'Suminė W- energija, fiksuojama kas valandą', 137, 5, NULL, NULL),
	(1951, 34, 2, 8, 2, 4, 41, 4, 45, NULL, 'Suminė W- energija pagal 4 tarifą, fiksuojama kas valandą', 161, 5, NULL, NULL),
	(1952, 34, 2, 8, 2, 3, 41, 4, 45, NULL, 'Suminė W- energija pagal 3 tarifą, fiksuojama kas valandą', 155, 5, NULL, NULL),
	(1953, 34, 2, 8, 2, 2, 41, 4, 45, NULL, 'Suminė W- energija pagal 2 tarifą, fiksuojama kas valandą', 149, 5, NULL, NULL),
	(1954, 34, 2, 8, 2, 1, 41, 4, 45, NULL, 'Suminė W- energija pagal 1 tarifą, fiksuojama kas valandą', 143, 5, NULL, NULL),
	(1955, 34, 2, 8, 2, 0, 41, 13, 45, NULL, 'Suminė W- energija, fiksuojama kas 20 minučių', 137, 5, NULL, NULL),
	(1956, 34, 2, 8, 2, 4, 41, 13, 45, NULL, 'Suminė W- energija pagal 4 tarifą, fiksuojama kas 20 minučių', 161, 5, NULL, NULL),
	(1957, 34, 2, 8, 2, 3, 41, 13, 45, NULL, 'Suminė W- energija pagal 3 tarifą, fiksuojama kas 20 minučių', 155, 5, NULL, NULL),
	(1958, 34, 2, 8, 2, 2, 41, 13, 45, NULL, 'Suminė W- energija pagal 2 tarifą, fiksuojama kas 20 minučių', 149, 5, NULL, NULL),
	(1959, 34, 2, 8, 2, 1, 41, 13, 45, NULL, 'Suminė W- energija pagal 1 tarifą, fiksuojama kas 20 minučių', 143, 5, NULL, NULL),
	(1960, 34, 2, 8, 2, 0, 41, 3, 45, NULL, 'Suminė W- energija, fiksuojama kas 30 minučių', 137, 5, NULL, NULL),
	(1961, 34, 2, 8, 2, 4, 41, 3, 45, NULL, 'Suminė W- energija pagal 4 tarifą, fiksuojama kas 30 minučių', 161, 5, NULL, NULL),
	(1962, 34, 2, 8, 2, 3, 41, 3, 45, NULL, 'Suminė W- energija pagal 3 tarifą, fiksuojama kas 30 minučių', 155, 5, NULL, NULL),
	(1963, 34, 2, 8, 2, 2, 41, 3, 45, NULL, 'Suminė W- energija pagal 2 tarifą, fiksuojama kas 30 minučių', 149, 5, NULL, NULL),
	(1964, 34, 2, 8, 2, 4, 41, 12, 45, NULL, 'Suminė W- energija pagal 4 tarifą, fiksuojama kas 15 minučių', 161, 5, NULL, NULL),
	(1965, 48, 0, 8, 2, 0, 2, 3, 62, NULL, 'Suminė šalčio energija, fiksuojama kas 30 minučių', 1001, 5, NULL, NULL),
	(1966, 48, 0, 8, 2, 0, 2, 4, 62, NULL, 'Suminė šalčio energija, fiksuojama kas valandą', 1001, 5, NULL, NULL),
	(1967, 48, 0, 8, 2, 0, 2, 12, 62, NULL, 'Suminė šalčio energija, fiksuojama kas 15 minučių', 1001, 5, NULL, NULL),
	(1968, 48, 0, 8, 2, 0, 2, 13, 62, NULL, 'Suminė šalčio energija, fiksuojama kas 20 minučių', 1001, 5, NULL, NULL),
	(1969, 48, 1, 8, 2, 0, 2, 3, 62, NULL, 'Suminė tiekiamo šalčio energija, fiksuojama kas 30 minučių', 1001, 5, NULL, NULL),
	(1970, 48, 1, 8, 2, 0, 2, 12, 62, NULL, 'Suminė tiekiamo šalčio energija, fiksuojama kas 15 minučių', 1001, 5, NULL, NULL),
	(1971, 48, 1, 8, 2, 0, 2, 4, 62, NULL, 'Suminė tiekiamo šalčio energija, fiksuojama kas valandą', 1001, 5, NULL, NULL),
	(1972, 48, 1, 8, 2, 0, 2, 13, 62, NULL, 'Suminė tiekiamo šalčio energija, fiksuojama kas 20 minučių', 1001, 5, NULL, NULL),
	(1973, 48, 2, 8, 2, 0, 2, 13, 62, NULL, 'Suminė grįžtamo šalčio energija, fiksuojama kas 20 minučių', 1001, 5, NULL, NULL),
	(1974, 48, 2, 8, 2, 0, 2, 3, 62, NULL, 'Suminė grįžtamo šalčio energija, fiksuojama kas 30 minučių', 1001, 5, NULL, NULL),
	(1975, 48, 2, 8, 2, 0, 2, 4, 62, NULL, 'Suminė grįžtamo šalčio energija, fiksuojama kas valandą', 1001, 5, NULL, NULL),
	(1976, 48, 2, 8, 2, 0, 2, 12, 62, NULL, 'Suminė grįžtamo šalčio energija, fiksuojama kas 15 minučių', 1001, 5, NULL, NULL),
	(1977, 50, 0, 8, 2, 0, 31, 4, 66, NULL, 'Suminis šalčio tūrio kiekis, fiksuojamas kas valandą', 1010, 5, NULL, NULL),
	(1978, 50, 0, 8, 2, 0, 31, 12, 66, NULL, 'Suminis šalčio tūrio kiekis, fiksuojamas kas 15 minučių', 1010, 5, NULL, NULL),
	(1979, 50, 0, 8, 2, 0, 31, 13, 66, NULL, 'Suminis šalčio tūrio kiekis, fiksuojamas kas 20 minučių', 1010, 5, NULL, NULL),
	(1980, 50, 0, 8, 2, 0, 31, 3, 66, NULL, 'Suminis šalčio tūrio kiekis, fiksuojamas kas 30 minučių', 1010, 5, NULL, NULL),
	(1981, 50, 1, 8, 2, 0, 31, 3, 66, NULL, 'Suminis tiekiamo šalčio tūrio kiekis, fiksuojamas kas 30 minučių', 1010, 5, NULL, NULL),
	(1982, 50, 1, 8, 2, 0, 31, 12, 66, NULL, 'Suminis tiekiamo šalčio tūrio kiekis, fiksuojamas kas 15 minučių', 1010, 5, NULL, NULL),
	(1983, 50, 1, 8, 2, 0, 31, 13, 66, NULL, 'Suminis tiekiamo šalčio tūrio kiekis, fiksuojamas kas 20 minučių', 1010, 5, NULL, NULL),
	(1984, 50, 1, 8, 2, 0, 31, 4, 66, NULL, 'Suminis tiekiamo šalčio tūrio kiekis, fiksuojamas kas valandą', 1010, 5, NULL, NULL),
	(1985, 50, 2, 8, 2, 0, 31, 13, 66, NULL, 'Suminis grįžtamo šalčio tūrio kiekis, fiksuojamas kas 20 minučių', 1010, 5, NULL, NULL),
	(1986, 50, 2, 8, 2, 0, 31, 3, 66, NULL, 'Suminis grįžtamo šalčio tūrio kiekis, fiksuojamas kas 30 minučių', 1010, 5, NULL, NULL),
	(1987, 50, 2, 8, 2, 0, 31, 4, 66, NULL, 'Suminis grįžtamo šalčio tūrio kiekis, fiksuojamas kas valandą', 1010, 5, NULL, NULL),
	(1988, 50, 2, 8, 2, 0, 31, 12, 66, NULL, 'Suminis grįžtamo šalčio tūrio kiekis, fiksuojamas kas 15 minučių', 1010, 5, NULL, NULL),
	(1989, 51, 0, 8, 2, 0, 35, 4, 68, NULL, 'Suminis šilumnešio masės kiekis, fiksuojamas kas valandą', 1005, 5, NULL, NULL),
	(1990, 51, 0, 8, 2, 0, 35, 12, 68, NULL, 'Suminis šilumnešio masės kiekis, fiksuojamas kas 15 minučių', 1005, 5, NULL, NULL),
	(1991, 51, 0, 8, 2, 0, 35, 13, 68, NULL, 'Suminis šilumnešio masės kiekis, fiksuojamas kas 20 minučių', 1005, 5, NULL, NULL),
	(1992, 51, 0, 8, 2, 0, 35, 3, 68, NULL, 'Suminis šilumnešio masės kiekis, fiksuojamas kas 30 minučių', 1005, 5, NULL, NULL),
	(1993, 51, 1, 8, 2, 0, 35, 3, 68, NULL, 'Suminis tiekiamo šilumnešio masės kiekis, fiksuojamas kas 30 minučių', 1005, 5, NULL, NULL),
	(1994, 51, 1, 8, 2, 0, 35, 4, 68, NULL, 'Suminis tiekiamo šilumnešio masės kiekis, fiksuojamas kas valandą', 1005, 5, NULL, NULL),
	(1995, 51, 1, 8, 2, 0, 35, 13, 68, NULL, 'Suminis tiekiamo šilumnešio masės kiekis, fiksuojamas kas 20 minučių', 1005, 5, NULL, NULL),
	(1996, 51, 1, 8, 2, 0, 35, 12, 68, NULL, 'Suminis tiekiamo šilumnešio masės kiekis, fiksuojamas kas 15 minučių', 1005, 5, NULL, NULL),
	(1997, 51, 2, 8, 2, 0, 35, 13, 68, NULL, 'Suminis grįžtamo šilumnešio masės kiekis, fiksuojamas kas 20 minučių', 1024, 5, NULL, NULL),
	(1998, 51, 2, 8, 2, 0, 35, 3, 68, NULL, 'Suminis grįžtamo šilumnešio masės kiekis, fiksuojamas kas 30 minučių', 1024, 5, NULL, NULL),
	(1999, 51, 2, 8, 2, 0, 35, 12, 68, NULL, 'Suminis grįžtamo šilumnešio masės kiekis, fiksuojamas kas 15 minučių', 1024, 5, NULL, NULL),
	(2000, 51, 2, 8, 2, 0, 35, 4, 68, NULL, 'Suminis grįžtamo šilumnešio masės kiekis, fiksuojamas kas valandą', 1024, 5, NULL, NULL),
	(2001, 53, 0, 8, 2, 0, 2, 3, 71, NULL, 'Suminis šilumnešio šilumos kiekis, fiksuojamas kas 30 minučių', 1001, 5, NULL, NULL),
	(2002, 53, 0, 8, 2, 0, 2, 12, 71, NULL, 'Suminis šilumnešio šilumos kiekis, fiksuojamas kas 15 minučių', 1001, 5, NULL, NULL),
	(2003, 53, 0, 8, 2, 0, 2, 4, 71, NULL, 'Suminis šilumnešio šilumos kiekis, fiksuojamas kas valandą', 1001, 5, NULL, NULL),
	(2004, 53, 0, 8, 2, 0, 2, 13, 71, NULL, 'Suminis šilumnešio šilumos kiekis, fiksuojamas kas 20 minučių', 1001, 5, NULL, NULL),
	(2005, 53, 1, 8, 2, 0, 2, 4, 71, NULL, 'Suminis tiekiamo šilumnešio šilumos kiekis, fiksuojamas kas valandą', 1001, 5, NULL, NULL),
	(2006, 53, 1, 8, 2, 0, 2, 12, 71, NULL, 'Suminis tiekiamo šilumnešio šilumos kiekis, fiksuojamas kas 15 minučių', 1001, 5, NULL, NULL),
	(2007, 53, 1, 8, 2, 0, 2, 3, 71, NULL, 'Suminis tiekiamo šilumnešio šilumos kiekis, fiksuojamas kas 30 minučių', 1001, 5, NULL, NULL),
	(2008, 53, 1, 8, 2, 0, 2, 13, 71, NULL, 'Suminis tiekiamo šilumnešio šilumos kiekis, fiksuojamas kas 20 minučių', 1001, 5, NULL, NULL),
	(2009, 53, 2, 8, 2, 0, 2, 4, 71, NULL, 'Suminis grįžtamo šilumnešio šilumos kiekis, fiksuojamas kas valandą', 1019, 5, NULL, NULL),
	(2010, 53, 2, 8, 2, 0, 2, 13, 71, NULL, 'Suminis grįžtamo šilumnešio šilumos kiekis, fiksuojamas kas 20 minučių', 1019, 5, NULL, NULL),
	(2011, 53, 2, 8, 2, 0, 2, 12, 71, NULL, 'Suminis grįžtamo šilumnešio šilumos kiekis, fiksuojamas kas 15 minučių', 1019, 5, NULL, NULL),
	(2012, 53, 2, 8, 2, 0, 2, 3, 71, NULL, 'Suminis grįžtamo šilumnešio šilumos kiekis, fiksuojamas kas 30 minučių', 1019, 5, NULL, NULL),
	(2013, 55, 0, 8, 2, 0, 31, 3, 74, NULL, 'Suminis šilumnešio tūrio kiekis, fiksuojamas kas 30 minučių', 1010, 5, NULL, NULL),
	(2014, 55, 0, 8, 2, 0, 31, 4, 74, NULL, 'Suminis šilumnešio tūrio kiekis, fiksuojamas kas valandą', 1010, 5, NULL, NULL),
	(2015, 55, 0, 8, 2, 0, 31, 13, 74, NULL, 'Suminis šilumnešio tūrio kiekis, fiksuojamas kas 20 minučių', 1010, 5, NULL, NULL),
	(2016, 55, 0, 8, 2, 0, 31, 12, 74, NULL, 'Suminis šilumnešio tūrio kiekis, fiksuojamas kas 15 minučių', 1010, 5, NULL, NULL),
	(2017, 55, 1, 8, 2, 0, 31, 13, 74, NULL, 'Suminis tiekiamo šilumnešio tūrio kiekis, fiksuojamas kas 20 minučių', 1010, 5, NULL, NULL),
	(2018, 55, 1, 8, 2, 0, 31, 12, 74, NULL, 'Suminis tiekiamo šilumnešio tūrio kiekis, fiksuojamas kas 15 minučių', 1010, 5, NULL, NULL),
	(2019, 55, 1, 8, 2, 0, 31, 4, 74, NULL, 'Suminis tiekiamo šilumnešio tūrio kiekis, fiksuojamas kas valandą', 1010, 5, NULL, NULL),
	(2020, 55, 1, 8, 2, 0, 31, 3, 74, NULL, 'Suminis tiekiamo šilumnešio tūrio kiekis, fiksuojamas kas 30 minučių', 1010, 5, NULL, NULL),
	(2021, 55, 2, 8, 2, 0, 31, 12, 74, NULL, 'Suminis grįžtamo šilumnešio tūrio kiekis, fiksuojamas kas 15 minučių', 1022, 5, NULL, NULL),
	(2022, 55, 2, 8, 2, 0, 31, 4, 74, NULL, 'Suminis grįžtamo šilumnešio tūrio kiekis, fiksuojamas kas valandą', 1022, 5, NULL, NULL),
	(2023, 55, 2, 8, 2, 0, 31, 3, 74, NULL, 'Suminis grįžtamo šilumnešio tūrio kiekis, fiksuojamas kas 30 minučių', 1022, 5, NULL, NULL),
	(2024, 55, 2, 8, 2, 0, 31, 13, 74, NULL, 'Suminis grįžtamo šilumnešio tūrio kiekis, fiksuojamas kas 20 minučių', 1022, 5, NULL, NULL),
	(2025, 39, 0, 8, 2, 0, 35, 3, 2, NULL, 'Suminis dujų koreguotos masės kiekis, fiksuojamas kas 30 minučių', 1110, 5, NULL, NULL),
	(2026, 39, 0, 8, 2, 0, 35, 12, 2, NULL, 'Suminis dujų koreguotos masės kiekis, fiksuojamas kas 15 minučių', 1110, 5, NULL, NULL),
	(2027, 39, 0, 8, 2, 0, 35, 13, 2, NULL, 'Suminis dujų koreguotos masės kiekis, fiksuojamas kas 20 minučių', 1110, 5, NULL, NULL),
	(2028, 39, 0, 8, 2, 0, 35, 4, 2, NULL, 'Suminis dujų koreguotos masės kiekis, fiksuojamas kas valandą', 1110, 5, NULL, NULL),
	(2029, 40, 0, 8, 2, 0, 31, 13, 4, NULL, 'Suminis dujų koreguoto tūrio kiekis, fiksuojamas kas 20 minučių', 1112, 5, NULL, NULL),
	(2030, 40, 0, 8, 2, 0, 31, 12, 4, NULL, 'Suminis dujų koreguoto tūrio kiekis, fiksuojamas kas 15 minučių', 1112, 5, NULL, NULL),
	(2031, 40, 0, 8, 2, 0, 31, 4, 4, NULL, 'Suminis dujų koreguoto tūrio kiekis, fiksuojamas kas valandą', 1112, 5, NULL, NULL),
	(2032, 40, 0, 8, 2, 0, 31, 3, 4, NULL, 'Suminis dujų koreguoto tūrio kiekis, fiksuojamas kas 30 minučių', 1112, 5, NULL, NULL),
	(2033, 41, 0, 8, 2, 0, 35, 3, 6, NULL, 'Suminis dujų masės kiekis, fiksuojamas kas 30 minučių', 1105, 5, NULL, NULL),
	(2034, 41, 0, 8, 2, 0, 35, 12, 6, NULL, 'Suminis dujų masės kiekis, fiksuojamas kas 15 minučių', 1105, 5, NULL, NULL),
	(2035, 41, 0, 8, 2, 0, 35, 13, 6, NULL, 'Suminis dujų masės kiekis, fiksuojamas kas 20 minučių', 1105, 5, NULL, NULL),
	(2036, 41, 0, 8, 2, 0, 35, 4, 6, NULL, 'Suminis dujų masės kiekis, fiksuojamas kas valandą', 1105, 5, NULL, NULL),
	(2037, 43, 0, 8, 2, 0, 34, 13, 9, NULL, 'Suminis dujų šilumos kiekis, fiksuojamas kas 20 minučių', 1101, 5, NULL, NULL),
	(2038, 43, 0, 8, 2, 0, 34, 12, 9, NULL, 'Suminis dujų šilumos kiekis, fiksuojamas kas 15 minučių', 1101, 5, NULL, NULL),
	(2039, 43, 0, 8, 2, 0, 34, 4, 9, NULL, 'Suminis dujų šilumos kiekis, fiksuojamas kas valandą', 1101, 5, NULL, NULL),
	(2040, 43, 0, 8, 2, 0, 34, 3, 9, NULL, 'Suminis dujų šilumos kiekis, fiksuojamas kas 30 minučių', 1101, 5, NULL, NULL),
	(2041, 45, 0, 8, 2, 0, 31, 12, 12, NULL, 'Suminis dujų tūrio kiekis, fiksuojamas kas 15 minučių', 1107, 5, NULL, NULL),
	(2042, 45, 0, 8, 2, 0, 31, 4, 12, NULL, 'Suminis dujų tūrio kiekis, fiksuojamas kas valandą', 1107, 5, NULL, NULL),
	(2043, 45, 0, 8, 2, 0, 31, 3, 12, NULL, 'Suminis dujų tūrio kiekis, fiksuojamas kas 30 minučių', 1107, 5, NULL, NULL),
	(2044, 45, 0, 8, 2, 0, 31, 13, 12, NULL, 'Suminis dujų tūrio kiekis, fiksuojamas kas 20 minučių', 1107, 5, NULL, NULL),
	(2045, 56, 0, 8, 2, 0, 34, 4, 56, NULL, 'Suminis šalto vandens šilumos kiekis, fiksuojamas kas valandą', 1205, 5, NULL, NULL),
	(2046, 56, 0, 8, 2, 0, 34, 3, 56, NULL, 'Suminis šalto vandens šilumos kiekis, fiksuojamas kas 30 minučių', 1205, 5, NULL, NULL),
	(2047, 56, 0, 8, 2, 0, 34, 13, 56, NULL, 'Suminis šalto vandens šilumos kiekis, fiksuojamas kas 20 minučių', 1205, 5, NULL, NULL),
	(2048, 56, 0, 8, 2, 0, 34, 12, 56, NULL, 'Suminis šalto vandens šilumos kiekis, fiksuojamas kas 15 minučių', 1205, 5, NULL, NULL),
	(2049, 56, 1, 8, 2, 0, 34, 4, 56, NULL, 'Suminis tiekiamo šalto vandens šilumos kiekis, fiksuojamas kas valandą', 1205, 5, NULL, NULL),
	(2050, 56, 1, 8, 2, 0, 34, 3, 56, NULL, 'Suminis tiekiamo šalto vandens šilumos kiekis, fiksuojamas kas 30 minučių', 1205, 5, NULL, NULL),
	(2051, 56, 1, 8, 2, 0, 34, 13, 56, NULL, 'Suminis tiekiamo šalto vandens šilumos kiekis, fiksuojamas kas 20 minučių', 1205, 5, NULL, NULL),
	(2052, 56, 1, 8, 2, 0, 34, 12, 56, NULL, 'Suminis tiekiamo šalto vandens šilumos kiekis, fiksuojamas kas 15 minučių', 1205, 5, NULL, NULL),
	(2053, 56, 2, 8, 2, 0, 34, 13, 56, NULL, 'Suminis grįžtamo šalto vandens šilumos kiekis, fiksuojamas kas 20 minučių', 1237, 5, NULL, NULL),
	(2054, 56, 2, 8, 2, 0, 34, 3, 56, NULL, 'Suminis grįžtamo šalto vandens šilumos kiekis, fiksuojamas kas 30 minučių', 1237, 5, NULL, NULL),
	(2055, 56, 2, 8, 2, 0, 34, 4, 56, NULL, 'Suminis grįžtamo šalto vandens šilumos kiekis, fiksuojamas kas valandą', 1237, 5, NULL, NULL),
	(2056, 56, 2, 8, 2, 0, 34, 12, 56, NULL, 'Suminis grįžtamo šalto vandens šilumos kiekis, fiksuojamas kas 15 minučių', 1237, 5, NULL, NULL),
	(2057, 58, 0, 8, 2, 0, 31, 13, 59, NULL, 'Suminis šalto vandens tūrio kiekis, fiksuojamas kas 20 minučių', 1201, 5, NULL, NULL),
	(2058, 58, 0, 8, 2, 0, 31, 4, 59, NULL, 'Suminis šalto vandens tūrio kiekis, fiksuojamas kas valandą', 1201, 5, NULL, NULL),
	(2059, 58, 0, 8, 2, 0, 31, 12, 59, NULL, 'Suminis šalto vandens tūrio kiekis, fiksuojamas kas 15 minučių', 1201, 5, NULL, NULL),
	(2060, 58, 0, 8, 2, 0, 31, 3, 59, NULL, 'Suminis šalto vandens tūrio kiekis, fiksuojamas kas 30 minučių', 1201, 5, NULL, NULL),
	(2061, 58, 1, 8, 2, 0, 31, 4, 59, NULL, 'Suminis tiekiamo šalto vandens tūrio kiekis, fiksuojamas kas valandą', 1201, 5, NULL, NULL),
	(2062, 58, 1, 8, 2, 0, 31, 3, 59, NULL, 'Suminis tiekiamo šalto vandens tūrio kiekis, fiksuojamas kas 30 minučių', 1201, 5, NULL, NULL),
	(2063, 58, 1, 8, 2, 0, 31, 12, 59, NULL, 'Suminis tiekiamo šalto vandens tūrio kiekis, fiksuojamas kas 15 minučių', 1201, 5, NULL, NULL),
	(2064, 58, 1, 8, 2, 0, 31, 13, 59, NULL, 'Suminis tiekiamo šalto vandens tūrio kiekis, fiksuojamas kas 20 minučių', 1201, 5, NULL, NULL),
	(2065, 58, 2, 8, 2, 0, 31, 12, 59, NULL, 'Suminis grįžtamo šalto vandens tūrio kiekis, fiksuojamas kas 15 minučių', 1258, 5, NULL, NULL),
	(2066, 58, 2, 8, 2, 0, 31, 4, 59, NULL, 'Suminis grįžtamo šalto vandens tūrio kiekis, fiksuojamas kas valandą', 1258, 5, NULL, NULL),
	(2067, 58, 2, 8, 2, 0, 31, 3, 59, NULL, 'Suminis grįžtamo šalto vandens tūrio kiekis, fiksuojamas kas 30 minučių', 1258, 5, NULL, NULL),
	(2068, 58, 2, 8, 2, 0, 31, 13, 59, NULL, 'Suminis grįžtamo šalto vandens tūrio kiekis, fiksuojamas kas 20 minučių', 1258, 5, NULL, NULL),
	(2069, 59, 0, 8, 2, 0, 34, 4, 51, NULL, 'Suminis karšto vandens šilumos kiekis, fiksuojamas kas valandą', 1205, 5, NULL, NULL),
	(2070, 59, 0, 8, 2, 0, 34, 13, 51, NULL, 'Suminis karšto vandens šilumos kiekis, fiksuojamas kas 20 minučių', 1205, 5, NULL, NULL),
	(2071, 59, 0, 8, 2, 0, 34, 3, 51, NULL, 'Suminis karšto vandens šilumos kiekis, fiksuojamas kas 30 minučių', 1205, 5, NULL, NULL),
	(2072, 59, 0, 8, 2, 0, 34, 12, 51, NULL, 'Suminis karšto vandens šilumos kiekis, fiksuojamas kas 15 minučių', 1205, 5, NULL, NULL),
	(2073, 59, 1, 8, 2, 0, 34, 3, 51, NULL, 'Suminis tiekiamo karšto vandens šilumos kiekis, fiksuojamas kas 30 minučių', 1205, 5, NULL, NULL),
	(2074, 59, 1, 8, 2, 0, 34, 13, 51, NULL, 'Suminis tiekiamo karšto vandens šilumos kiekis, fiksuojamas kas 20 minučių', 1205, 5, NULL, NULL),
	(2075, 59, 1, 8, 2, 0, 34, 12, 51, NULL, 'Suminis tiekiamo karšto vandens šilumos kiekis, fiksuojamas kas 15 minučių', 1205, 5, NULL, NULL),
	(2076, 59, 1, 8, 2, 0, 34, 4, 51, NULL, 'Suminis tiekiamo karšto vandens šilumos kiekis, fiksuojamas kas valandą', 1205, 5, NULL, NULL),
	(2077, 59, 2, 8, 2, 0, 34, 3, 51, NULL, 'Suminis grįžtamo karšto vandens šilumos kiekis, fiksuojamas kas 30 minučių', 1237, 5, NULL, NULL),
	(2078, 59, 2, 8, 2, 0, 34, 13, 51, NULL, 'Suminis grįžtamo karšto vandens šilumos kiekis, fiksuojamas kas 20 minučių', 1237, 5, NULL, NULL),
	(2079, 59, 2, 8, 2, 0, 34, 12, 51, NULL, 'Suminis grįžtamo karšto vandens šilumos kiekis, fiksuojamas kas 15 minučių', 1237, 5, NULL, NULL),
	(2080, 59, 2, 8, 2, 0, 34, 4, 51, NULL, 'Suminis grįžtamo karšto vandens šilumos kiekis, fiksuojamas kas valandą', 1237, 5, NULL, NULL),
	(2081, 61, 0, 8, 2, 0, 31, 4, 53, NULL, 'Suminis karšto vandens tūrio kiekis, fiksuojamas kas valandą', 1201, 5, NULL, NULL),
	(2082, 61, 0, 8, 2, 0, 31, 12, 53, NULL, 'Suminis karšto vandens tūrio kiekis, fiksuojamas kas 15 minučių', 1201, 5, NULL, NULL),
	(2083, 61, 0, 8, 2, 0, 31, 3, 53, NULL, 'Suminis karšto vandens tūrio kiekis, fiksuojamas kas 30 minučių', 1201, 5, NULL, NULL),
	(2084, 61, 0, 8, 2, 0, 31, 13, 53, NULL, 'Suminis karšto vandens tūrio kiekis, fiksuojamas kas 20 minučių', 1201, 5, NULL, NULL),
	(2085, 61, 1, 8, 2, 0, 31, 13, 53, NULL, 'Suminis tiekiamo karšto vandens tūrio kiekis, fiksuojamas kas 20 minučių', 1201, 5, NULL, NULL),
	(2086, 61, 1, 8, 2, 0, 31, 12, 53, NULL, 'Suminis tiekiamo karšto vandens tūrio kiekis, fiksuojamas kas 15 minučių', 1201, 5, NULL, NULL),
	(2087, 61, 1, 8, 2, 0, 31, 3, 53, NULL, 'Suminis tiekiamo karšto vandens tūrio kiekis, fiksuojamas kas 30 minučių', 1201, 5, NULL, NULL),
	(2088, 61, 1, 8, 2, 0, 31, 4, 53, NULL, 'Suminis tiekiamo karšto vandens tūrio kiekis, fiksuojamas kas valandą', 1201, 5, NULL, NULL),
	(2089, 61, 2, 8, 2, 0, 31, 3, 53, NULL, 'Suminis grįžtamo karšto vandens tūrio kiekis, fiksuojamas kas 30 minučių', 1258, 5, NULL, NULL),
	(2090, 61, 2, 8, 2, 0, 31, 4, 53, NULL, 'Suminis grįžtamo karšto vandens tūrio kiekis, fiksuojamas kas valandą', 1258, 5, NULL, NULL),
	(2091, 61, 2, 8, 2, 0, 31, 13, 53, NULL, 'Suminis grįžtamo karšto vandens tūrio kiekis, fiksuojamas kas 20 minučių', 1258, 5, NULL, NULL),
	(2092, 61, 2, 8, 2, 0, 31, 12, 53, NULL, 'Suminis grįžtamo karšto vandens tūrio kiekis, fiksuojamas kas 15 minučių', 1258, 5, NULL, NULL),
	(2093, 1, 1, 8, 2, 4, 2, 6, 14, '1.0.1.8.0.4', 'Suminė A+ energija pagal 4 tarifą, fiksuojama kas mėnesį', 13, 5, NULL, NULL),
	(2094, 1, 1, 8, 2, 1, 2, 5, 14, '1.0.1.8.0.1', 'Suminė A+ energija pagal 1 tarifą, fiksuojama kas parą', 1, 5, NULL, NULL),
	(2095, 1, 1, 8, 2, 0, 2, 6, 14, NULL, 'Suminė A+ energija, fiksuojama kas mėnesį', 132, 5, NULL, NULL),
	(2096, 1, 1, 8, 2, 4, 2, 5, 14, '1.0.1.8.0.4', 'Suminė A+ energija pagal 4 tarifą, fiksuojama kas parą', 13, 5, NULL, NULL),
	(2097, 1, 1, 8, 2, 0, 2, 5, 14, NULL, 'Suminė A+ energija, fiksuojama kas parą', 132, 5, NULL, NULL),
	(2098, 1, 1, 8, 2, 1, 2, 6, 14, '1.0.1.8.0.1', 'Suminė A+ energija pagal 1 tarifą, fiksuojama kas mėnesį', 1, 5, NULL, NULL),
	(2099, 1, 1, 8, 2, 3, 2, 5, 14, '1.0.1.8.0.3', 'Suminė A+ energija pagal 3 tarifą, fiksuojama kas parą', 9, 5, NULL, NULL),
	(2100, 1, 1, 8, 2, 2, 2, 5, 14, '1.0.1.8.0.2', 'Suminė A+ energija pagal 2 tarifą, fiksuojama kas parą', 5, 5, NULL, NULL),
	(2101, 1, 1, 8, 2, 3, 2, 6, 14, '1.0.1.8.0.3', 'Suminė A+ energija pagal 3 tarifą, fiksuojama kas mėnesį', 9, 5, NULL, NULL),
	(2102, 1, 1, 8, 2, 2, 2, 6, 14, '1.0.1.8.0.2', 'Suminė A+ energija pagal 2 tarifą, fiksuojama kas mėnesį', 5, 5, NULL, NULL),
	(2103, 1, 2, 8, 2, 3, 2, 6, 14, '1.0.2.8.0.3', 'Suminė A- energija pagal 3 tarifą, fiksuojama kas mėnesį', 10, 5, NULL, NULL),
	(2104, 1, 2, 8, 2, 2, 2, 6, 14, '1.0.2.8.0.2', 'Suminė A- energija pagal 2 tarifą, fiksuojama kas mėnesį', 6, 5, NULL, NULL),
	(2105, 1, 2, 8, 2, 1, 2, 6, 14, '1.0.2.8.0.1', 'Suminė A- energija pagal 1 tarifą, fiksuojama kas mėnesį', 2, 5, NULL, NULL),
	(2106, 1, 2, 8, 2, 0, 2, 5, 14, NULL, 'Suminė A- energija, fiksuojama kas parą', 133, 5, NULL, NULL),
	(2107, 1, 2, 8, 2, 0, 2, 6, 14, NULL, 'Suminė A- energija, fiksuojama kas mėnesį', 133, 5, NULL, NULL),
	(2108, 1, 2, 8, 2, 4, 2, 5, 14, '1.0.2.8.0.4', 'Suminė A- energija pagal 4 tarifą, fiksuojama kas parą', 14, 5, NULL, NULL),
	(2109, 1, 2, 8, 2, 3, 2, 5, 14, '1.0.2.8.0.3', 'Suminė A- energija pagal 3 tarifą, fiksuojama kas parą', 10, 5, NULL, NULL),
	(2110, 1, 2, 8, 2, 2, 2, 5, 14, '1.0.2.8.0.2', 'Suminė A- energija pagal 2 tarifą, fiksuojama kas parą', 6, 5, NULL, NULL),
	(2111, 1, 2, 8, 2, 1, 2, 5, 14, '1.0.2.8.0.1', 'Suminė A- energija pagal 1 tarifą, fiksuojama kas parą', 2, 5, NULL, NULL),
	(2112, 1, 2, 8, 2, 4, 2, 6, 14, '1.0.2.8.0.4', 'Suminė A- energija pagal 4 tarifą, fiksuojama kas mėnesį', 14, 5, NULL, NULL),
	(2113, 3, 1, 8, 2, 4, 4, 6, 15, '1.0.3.8.0.4', 'Suminė R+ energija pagal 4 tarifą, fiksuojama kas mėnesį', 15, 5, NULL, NULL),
	(2114, 3, 1, 8, 2, 0, 4, 5, 15, NULL, 'Suminė R+ energija, fiksuojama kas parą', 134, 5, NULL, NULL),
	(2115, 3, 1, 8, 2, 2, 4, 6, 15, '1.0.3.8.0.2', 'Suminė R+ energija pagal 2 tarifą, fiksuojama kas mėnesį', 7, 5, NULL, NULL),
	(2116, 3, 1, 8, 2, 0, 4, 6, 15, NULL, 'Suminė R+ energija, fiksuojama kas mėnesį', 134, 5, NULL, NULL),
	(2117, 3, 1, 8, 2, 2, 4, 5, 15, '1.0.3.8.0.2', 'Suminė R+ energija pagal 2 tarifą, fiksuojama kas parą', 7, 5, NULL, NULL),
	(2118, 3, 1, 8, 2, 1, 4, 6, 15, '1.0.3.8.0.1', 'Suminė R+ energija pagal 1 tarifą, fiksuojama kas mėnesį', 3, 5, NULL, NULL),
	(2119, 3, 1, 8, 2, 4, 4, 5, 15, '1.0.3.8.0.4', 'Suminė R+ energija pagal 4 tarifą, fiksuojama kas parą', 15, 5, NULL, NULL),
	(2120, 3, 1, 8, 2, 3, 4, 5, 15, '1.0.3.8.0.3', 'Suminė R+ energija pagal 3 tarifą, fiksuojama kas parą', 11, 5, NULL, NULL),
	(2121, 3, 1, 8, 2, 1, 4, 5, 15, '1.0.3.8.0.1', 'Suminė R+ energija pagal 1 tarifą, fiksuojama kas parą', 3, 5, NULL, NULL),
	(2122, 3, 1, 8, 2, 3, 4, 6, 15, '1.0.3.8.0.3', 'Suminė R+ energija pagal 3 tarifą, fiksuojama kas mėnesį', 11, 5, NULL, NULL),
	(2123, 3, 2, 8, 2, 4, 4, 5, 15, '1.0.4.8.0.4', 'Suminė R- energija pagal 4 tarifą, fiksuojama kas parą', 16, 5, NULL, NULL),
	(2124, 3, 2, 8, 2, 4, 4, 6, 15, '1.0.4.8.0.4', 'Suminė R- energija pagal 4 tarifą, fiksuojama kas mėnesį', 16, 5, NULL, NULL),
	(2125, 3, 2, 8, 2, 3, 4, 5, 15, '1.0.4.8.0.3', 'Suminė R- energija pagal 3 tarifą, fiksuojama kas parą', 12, 5, NULL, NULL),
	(2126, 3, 2, 8, 2, 1, 4, 5, 15, '1.0.4.8.0.1', 'Suminė R- energija pagal 1 tarifą, fiksuojama kas parą', 4, 5, NULL, NULL),
	(2127, 3, 2, 8, 2, 2, 4, 6, 15, '1.0.4.8.0.2', 'Suminė R- energija pagal 2 tarifą, fiksuojama kas mėnesį', 8, 5, NULL, NULL),
	(2128, 3, 2, 8, 2, 3, 4, 6, 15, '1.0.4.8.0.3', 'Suminė R- energija pagal 3 tarifą, fiksuojama kas mėnesį', 12, 5, NULL, NULL),
	(2129, 3, 2, 8, 2, 0, 4, 5, 15, NULL, 'Suminė R- energija, fiksuojama kas parą', 135, 5, NULL, NULL),
	(2130, 3, 2, 8, 2, 2, 4, 5, 15, '1.0.4.8.0.2', 'Suminė R- energija pagal 2 tarifą, fiksuojama kas parą', 8, 5, NULL, NULL),
	(2131, 3, 2, 8, 2, 0, 4, 6, 15, NULL, 'Suminė R- energija, fiksuojama kas mėnesį', 135, 5, NULL, NULL),
	(2132, 3, 2, 8, 2, 1, 4, 6, 15, '1.0.4.8.0.1', 'Suminė R- energija pagal 1 tarifą, fiksuojama kas mėnesį', 4, 5, NULL, NULL),
	(2133, 3, 5, 8, 2, 0, 4, 6, 15, NULL, 'Suminė R1 energija, fiksuojama kas mėnesį', 322, 5, NULL, NULL),
	(2134, 3, 5, 8, 2, 3, 4, 5, 15, NULL, 'Suminė R1 energija pagal 3 tarifą, fiksuojama kas parą', 150, 5, NULL, NULL),
	(2135, 3, 5, 8, 2, 2, 4, 5, 15, NULL, 'Suminė R1 energija pagal 2 tarifą, fiksuojama kas parą', 144, 5, NULL, NULL),
	(2136, 3, 5, 8, 2, 1, 4, 6, 15, NULL, 'Suminė R1 energija pagal 1 tarifą, fiksuojama kas mėnesį', 138, 5, NULL, NULL),
	(2137, 3, 5, 8, 2, 2, 4, 6, 15, NULL, 'Suminė R1 energija pagal 2 tarifą, fiksuojama kas mėnesį', 144, 5, NULL, NULL),
	(2138, 3, 5, 8, 2, 1, 4, 5, 15, NULL, 'Suminė R1 energija pagal 1 tarifą, fiksuojama kas parą', 138, 5, NULL, NULL),
	(2139, 3, 5, 8, 2, 4, 4, 6, 15, NULL, 'Suminė R1 energija pagal 4 tarifą, fiksuojama kas mėnesį', 156, 5, NULL, NULL),
	(2140, 3, 5, 8, 2, 3, 4, 6, 15, NULL, 'Suminė R1 energija pagal 3 tarifą, fiksuojama kas mėnesį', 150, 5, NULL, NULL),
	(2141, 3, 5, 8, 2, 0, 4, 5, 15, NULL, 'Suminė R1 energija, fiksuojama kas parą', 322, 5, NULL, NULL),
	(2142, 3, 5, 8, 2, 4, 4, 5, 15, NULL, 'Suminė R1 energija pagal 4 tarifą, fiksuojama kas parą', 156, 5, NULL, NULL),
	(2143, 3, 6, 8, 2, 1, 4, 6, 15, NULL, 'Suminė R2 energija pagal 1 tarifą, fiksuojama kas mėnesį', 139, 5, NULL, NULL),
	(2144, 3, 6, 8, 2, 2, 4, 6, 15, NULL, 'Suminė R2 energija pagal 2 tarifą, fiksuojama kas mėnesį', 145, 5, NULL, NULL),
	(2145, 3, 6, 8, 2, 0, 4, 5, 15, NULL, 'Suminė R2 energija, fiksuojama kas parą', 323, 5, NULL, NULL),
	(2146, 3, 6, 8, 2, 0, 4, 6, 15, NULL, 'Suminė R2 energija, fiksuojama kas mėnesį', 323, 5, NULL, NULL),
	(2147, 3, 6, 8, 2, 3, 4, 5, 15, NULL, 'Suminė R2 energija pagal 3 tarifą, fiksuojama kas parą', 151, 5, NULL, NULL),
	(2148, 3, 6, 8, 2, 4, 4, 5, 15, NULL, 'Suminė R2 energija pagal 4 tarifą, fiksuojama kas parą', 157, 5, NULL, NULL),
	(2149, 3, 6, 8, 2, 2, 4, 5, 15, NULL, 'Suminė R2 energija pagal 2 tarifą, fiksuojama kas parą', 145, 5, NULL, NULL),
	(2150, 3, 6, 8, 2, 1, 4, 5, 15, NULL, 'Suminė R2 energija pagal 1 tarifą, fiksuojama kas parą', 139, 5, NULL, NULL),
	(2151, 3, 6, 8, 2, 4, 4, 6, 15, NULL, 'Suminė R2 energija pagal 4 tarifą, fiksuojama kas mėnesį', 157, 5, NULL, NULL),
	(2152, 3, 6, 8, 2, 3, 4, 6, 15, NULL, 'Suminė R2 energija pagal 3 tarifą, fiksuojama kas mėnesį', 151, 5, NULL, NULL),
	(2153, 3, 7, 8, 2, 3, 4, 6, 15, NULL, 'Suminė R3 energija pagal 3 tarifą, fiksuojama kas mėnesį', 152, 5, NULL, NULL),
	(2154, 3, 7, 8, 2, 4, 4, 6, 15, NULL, 'Suminė R3 energija pagal 4 tarifą, fiksuojama kas mėnesį', 158, 5, NULL, NULL),
	(2155, 3, 7, 8, 2, 1, 4, 5, 15, NULL, 'Suminė R3 energija pagal 1 tarifą, fiksuojama kas parą', 140, 5, NULL, NULL),
	(2156, 3, 7, 8, 2, 2, 4, 5, 15, NULL, 'Suminė R3 energija pagal 2 tarifą, fiksuojama kas parą', 146, 5, NULL, NULL),
	(2157, 3, 7, 8, 2, 3, 4, 5, 15, NULL, 'Suminė R3 energija pagal 3 tarifą, fiksuojama kas parą', 152, 5, NULL, NULL),
	(2158, 3, 7, 8, 2, 4, 4, 5, 15, NULL, 'Suminė R3 energija pagal 4 tarifą, fiksuojama kas parą', 158, 5, NULL, NULL),
	(2159, 3, 7, 8, 2, 0, 4, 6, 15, NULL, 'Suminė R3 energija, fiksuojama kas mėnesį', 324, 5, NULL, NULL),
	(2160, 3, 7, 8, 2, 0, 4, 5, 15, NULL, 'Suminė R3 energija, fiksuojama kas parą', 324, 5, NULL, NULL),
	(2161, 3, 7, 8, 2, 1, 4, 6, 15, NULL, 'Suminė R3 energija pagal 1 tarifą, fiksuojama kas mėnesį', 140, 5, NULL, NULL),
	(2162, 3, 7, 8, 2, 2, 4, 6, 15, NULL, 'Suminė R3 energija pagal 2 tarifą, fiksuojama kas mėnesį', 146, 5, NULL, NULL),
	(2163, 3, 8, 8, 2, 0, 4, 6, 15, NULL, 'Suminė R4 energija, fiksuojama kas mėnesį', 325, 5, NULL, NULL),
	(2164, 3, 8, 8, 2, 0, 4, 5, 15, NULL, 'Suminė R4 energija, fiksuojama kas parą', 325, 5, NULL, NULL),
	(2165, 3, 8, 8, 2, 1, 4, 6, 15, NULL, 'Suminė R4 energija pagal 1 tarifą, fiksuojama kas mėnesį', 141, 5, NULL, NULL),
	(2166, 3, 8, 8, 2, 2, 4, 6, 15, NULL, 'Suminė R4 energija pagal 2 tarifą, fiksuojama kas mėnesį', 147, 5, NULL, NULL),
	(2167, 3, 8, 8, 2, 4, 4, 5, 15, NULL, 'Suminė R4 energija pagal 4 tarifą, fiksuojama kas parą', 159, 5, NULL, NULL),
	(2168, 3, 8, 8, 2, 4, 4, 6, 15, NULL, 'Suminė R4 energija pagal 4 tarifą, fiksuojama kas mėnesį', 159, 5, NULL, NULL),
	(2169, 3, 8, 8, 2, 1, 4, 5, 15, NULL, 'Suminė R4 energija pagal 1 tarifą, fiksuojama kas parą', 141, 5, NULL, NULL),
	(2170, 3, 8, 8, 2, 2, 4, 5, 15, NULL, 'Suminė R4 energija pagal 2 tarifą, fiksuojama kas parą', 147, 5, NULL, NULL),
	(2171, 3, 8, 8, 2, 3, 4, 5, 15, NULL, 'Suminė R4 energija pagal 3 tarifą, fiksuojama kas parą', 153, 5, NULL, NULL),
	(2172, 3, 8, 8, 2, 3, 4, 6, 15, NULL, 'Suminė R4 energija pagal 3 tarifą, fiksuojama kas mėnesį', 153, 5, NULL, NULL),
	(2173, 34, 1, 8, 2, 0, 41, 6, 45, NULL, 'Suminė W+ energija, fiksuojama kas mėnesį', 136, 5, NULL, NULL),
	(2174, 34, 1, 8, 2, 1, 41, 6, 45, NULL, 'Suminė W+ energija pagal 1 tarifą, fiksuojama kas mėnesį', 142, 5, NULL, NULL),
	(2175, 34, 1, 8, 2, 4, 41, 5, 45, NULL, 'Suminė W+ energija pagal 4 tarifą, fiksuojama kas parą', 160, 5, NULL, NULL),
	(2176, 34, 1, 8, 2, 3, 41, 5, 45, NULL, 'Suminė W+ energija pagal 3 tarifą, fiksuojama kas parą', 154, 5, NULL, NULL),
	(2177, 34, 1, 8, 2, 2, 41, 5, 45, NULL, 'Suminė W+ energija pagal 2 tarifą, fiksuojama kas parą', 148, 5, NULL, NULL),
	(2178, 34, 1, 8, 2, 1, 41, 5, 45, NULL, 'Suminė W+ energija pagal 1 tarifą, fiksuojama kas parą', 142, 5, NULL, NULL),
	(2179, 34, 1, 8, 2, 4, 41, 6, 45, NULL, 'Suminė W+ energija pagal 4 tarifą, fiksuojama kas mėnesį', 160, 5, NULL, NULL),
	(2180, 34, 1, 8, 2, 3, 41, 6, 45, NULL, 'Suminė W+ energija pagal 3 tarifą, fiksuojama kas mėnesį', 154, 5, NULL, NULL),
	(2181, 34, 1, 8, 2, 2, 41, 6, 45, NULL, 'Suminė W+ energija pagal 2 tarifą, fiksuojama kas mėnesį', 148, 5, NULL, NULL),
	(2182, 34, 1, 8, 2, 0, 41, 5, 45, NULL, 'Suminė W+ energija, fiksuojama kas parą', 136, 5, NULL, NULL),
	(2183, 34, 2, 8, 2, 3, 41, 5, 45, NULL, 'Suminė W- energija pagal 3 tarifą, fiksuojama kas parą', 155, 5, NULL, NULL),
	(2184, 34, 2, 8, 2, 3, 41, 6, 45, NULL, 'Suminė W- energija pagal 3 tarifą, fiksuojama kas mėnesį', 155, 5, NULL, NULL),
	(2185, 34, 2, 8, 2, 1, 41, 5, 45, NULL, 'Suminė W- energija pagal 1 tarifą, fiksuojama kas parą', 143, 5, NULL, NULL),
	(2186, 34, 2, 8, 2, 2, 41, 6, 45, NULL, 'Suminė W- energija pagal 2 tarifą, fiksuojama kas mėnesį', 149, 5, NULL, NULL),
	(2187, 34, 2, 8, 2, 0, 41, 6, 45, NULL, 'Suminė W- energija, fiksuojama kas mėnesį', 137, 5, NULL, NULL),
	(2188, 34, 2, 8, 2, 1, 41, 6, 45, NULL, 'Suminė W- energija pagal 1 tarifą, fiksuojama kas mėnesį', 143, 5, NULL, NULL),
	(2189, 34, 2, 8, 2, 4, 41, 5, 45, NULL, 'Suminė W- energija pagal 4 tarifą, fiksuojama kas parą', 161, 5, NULL, NULL),
	(2190, 34, 2, 8, 2, 0, 41, 5, 45, NULL, 'Suminė W- energija, fiksuojama kas parą', 137, 5, NULL, NULL),
	(2191, 34, 2, 8, 2, 4, 41, 6, 45, NULL, 'Suminė W- energija pagal 4 tarifą, fiksuojama kas mėnesį', 161, 5, NULL, NULL),
	(2192, 34, 2, 8, 2, 2, 41, 5, 45, NULL, 'Suminė W- energija pagal 2 tarifą, fiksuojama kas parą', 149, 5, NULL, NULL),
	(2193, 48, 0, 8, 2, 0, 2, 5, 62, NULL, 'Suminė šalčio energija, fiksuojama kas parą', 1001, 5, NULL, NULL),
	(2194, 48, 0, 8, 2, 0, 2, 6, 62, NULL, 'Suminė šalčio energija, fiksuojama kas mėnesį', 1001, 5, NULL, NULL),
	(2195, 48, 1, 8, 2, 0, 2, 6, 62, NULL, 'Suminė tiekiamo šalčio energija, fiksuojama kas mėnesį', 1001, 5, NULL, NULL),
	(2196, 48, 1, 8, 2, 0, 2, 5, 62, NULL, 'Suminė tiekiamo šalčio energija, fiksuojama kas parą', 1001, 5, NULL, NULL),
	(2197, 48, 2, 8, 2, 0, 2, 5, 62, NULL, 'Suminė grįžtamo šalčio energija, fiksuojama kas parą', 1001, 5, NULL, NULL),
	(2198, 48, 2, 8, 2, 0, 2, 6, 62, NULL, 'Suminė grįžtamo šalčio energija, fiksuojama kas mėnesį', 1001, 5, NULL, NULL),
	(2199, 50, 0, 8, 2, 0, 31, 5, 66, NULL, 'Suminis šalčio tūrio kiekis, fiksuojamas kas parą', 1010, 5, NULL, NULL),
	(2200, 50, 0, 8, 2, 0, 31, 6, 66, NULL, 'Suminis šalčio tūrio kiekis, fiksuojamas kas mėnesį', 1010, 5, NULL, NULL),
	(2201, 50, 1, 8, 2, 0, 31, 5, 66, NULL, 'Suminis tiekiamo šalčio tūrio kiekis, fiksuojamas kas parą', 1010, 5, NULL, NULL),
	(2202, 50, 1, 8, 2, 0, 31, 6, 66, NULL, 'Suminis tiekiamo šalčio tūrio kiekis, fiksuojamas kas mėnesį', 1010, 5, NULL, NULL),
	(2203, 50, 2, 8, 2, 0, 31, 5, 66, NULL, 'Suminis grįžtamo šalčio tūrio kiekis, fiksuojamas kas parą', 1010, 5, NULL, NULL),
	(2204, 50, 2, 8, 2, 0, 31, 6, 66, NULL, 'Suminis grįžtamo šalčio tūrio kiekis, fiksuojamas kas mėnesį', 1010, 5, NULL, NULL),
	(2205, 51, 0, 8, 2, 0, 35, 6, 68, NULL, 'Suminis šilumnešio masės kiekis, fiksuojamas kas mėnesį', 1005, 5, NULL, NULL),
	(2206, 51, 0, 8, 2, 0, 35, 5, 68, NULL, 'Suminis šilumnešio masės kiekis, fiksuojamas kas parą', 1005, 5, NULL, NULL),
	(2207, 51, 1, 8, 2, 0, 35, 5, 68, NULL, 'Suminis tiekiamo šilumnešio masės kiekis, fiksuojamas kas parą', 1005, 5, NULL, NULL),
	(2208, 51, 1, 8, 2, 0, 35, 6, 68, NULL, 'Suminis tiekiamo šilumnešio masės kiekis, fiksuojamas kas mėnesį', 1005, 5, NULL, NULL),
	(2209, 51, 2, 8, 2, 0, 35, 6, 68, NULL, 'Suminis grįžtamo šilumnešio masės kiekis, fiksuojamas kas mėnesį', 1024, 5, NULL, NULL),
	(2210, 51, 2, 8, 2, 0, 35, 5, 68, NULL, 'Suminis grįžtamo šilumnešio masės kiekis, fiksuojamas kas parą', 1024, 5, NULL, NULL),
	(2211, 53, 0, 8, 2, 0, 2, 6, 71, NULL, 'Suminis šilumnešio šilumos kiekis, fiksuojamas kas mėnesį', 1001, 5, NULL, NULL),
	(2212, 53, 0, 8, 2, 0, 2, 5, 71, NULL, 'Suminis šilumnešio šilumos kiekis, fiksuojamas kas parą', 1001, 5, NULL, NULL),
	(2213, 53, 1, 8, 2, 0, 2, 5, 71, NULL, 'Suminis tiekiamo šilumnešio šilumos kiekis, fiksuojamas kas parą', 1001, 5, NULL, NULL),
	(2214, 53, 1, 8, 2, 0, 2, 6, 71, NULL, 'Suminis tiekiamo šilumnešio šilumos kiekis, fiksuojamas kas mėnesį', 1001, 5, NULL, NULL),
	(2215, 53, 2, 8, 2, 0, 2, 5, 71, NULL, 'Suminis grįžtamo šilumnešio šilumos kiekis, fiksuojamas kas parą', 1019, 5, NULL, NULL),
	(2216, 53, 2, 8, 2, 0, 2, 6, 71, NULL, 'Suminis grįžtamo šilumnešio šilumos kiekis, fiksuojamas kas mėnesį', 1019, 5, NULL, NULL),
	(2217, 55, 0, 8, 2, 0, 31, 5, 74, NULL, 'Suminis šilumnešio tūrio kiekis, fiksuojamas kas parą', 1010, 5, NULL, NULL),
	(2218, 55, 0, 8, 2, 0, 31, 6, 74, NULL, 'Suminis šilumnešio tūrio kiekis, fiksuojamas kas mėnesį', 1010, 5, NULL, NULL),
	(2219, 55, 1, 8, 2, 0, 31, 5, 74, NULL, 'Suminis tiekiamo šilumnešio tūrio kiekis, fiksuojamas kas parą', 1010, 5, NULL, NULL),
	(2220, 55, 1, 8, 2, 0, 31, 6, 74, NULL, 'Suminis tiekiamo šilumnešio tūrio kiekis, fiksuojamas kas mėnesį', 1010, 5, NULL, NULL),
	(2221, 55, 2, 8, 2, 0, 31, 5, 74, NULL, 'Suminis grįžtamo šilumnešio tūrio kiekis, fiksuojamas kas parą', 1022, 5, NULL, NULL),
	(2222, 55, 2, 8, 2, 0, 31, 6, 74, NULL, 'Suminis grįžtamo šilumnešio tūrio kiekis, fiksuojamas kas mėnesį', 1022, 5, NULL, NULL),
	(2223, 39, 0, 8, 2, 0, 35, 5, 2, NULL, 'Suminis dujų koreguotos masės kiekis, fiksuojamas kas parą', 1110, 5, NULL, NULL),
	(2224, 39, 0, 8, 2, 0, 35, 6, 2, NULL, 'Suminis dujų koreguotos masės kiekis, fiksuojamas kas mėnesį', 1110, 5, NULL, NULL),
	(2225, 40, 0, 8, 2, 0, 31, 5, 4, NULL, 'Suminis dujų koreguoto tūrio kiekis, fiksuojamas kas parą', 1112, 5, NULL, NULL),
	(2226, 40, 0, 8, 2, 0, 31, 6, 4, NULL, 'Suminis dujų koreguoto tūrio kiekis, fiksuojamas kas mėnesį', 1112, 5, NULL, NULL),
	(2227, 41, 0, 8, 2, 0, 35, 5, 6, NULL, 'Suminis dujų masės kiekis, fiksuojamas kas parą', 1105, 5, NULL, NULL),
	(2228, 41, 0, 8, 2, 0, 35, 6, 6, NULL, 'Suminis dujų masės kiekis, fiksuojamas kas mėnesį', 1105, 5, NULL, NULL),
	(2229, 43, 0, 8, 2, 0, 34, 5, 9, NULL, 'Suminis dujų šilumos kiekis, fiksuojamas kas parą', 1101, 5, NULL, NULL),
	(2230, 43, 0, 8, 2, 0, 34, 6, 9, NULL, 'Suminis dujų šilumos kiekis, fiksuojamas kas mėnesį', 1101, 5, NULL, NULL),
	(2231, 45, 0, 8, 2, 0, 31, 5, 12, NULL, 'Suminis dujų tūrio kiekis, fiksuojamas kas parą', 1107, 5, NULL, NULL),
	(2232, 45, 0, 8, 2, 0, 31, 6, 12, NULL, 'Suminis dujų tūrio kiekis, fiksuojamas kas mėnesį', 1107, 5, NULL, NULL),
	(2233, 56, 0, 8, 2, 0, 34, 6, 56, NULL, 'Suminis šalto vandens šilumos kiekis, fiksuojamas kas mėnesį', 1205, 5, NULL, NULL),
	(2234, 56, 0, 8, 2, 0, 34, 5, 56, NULL, 'Suminis šalto vandens šilumos kiekis, fiksuojamas kas parą', 1205, 5, NULL, NULL),
	(2235, 56, 1, 8, 2, 0, 34, 5, 56, NULL, 'Suminis tiekiamo šalto vandens šilumos kiekis, fiksuojamas kas parą', 1205, 5, NULL, NULL),
	(2236, 56, 1, 8, 2, 0, 34, 6, 56, NULL, 'Suminis tiekiamo šalto vandens šilumos kiekis, fiksuojamas kas mėnesį', 1205, 5, NULL, NULL),
	(2237, 56, 2, 8, 2, 0, 34, 6, 56, NULL, 'Suminis grįžtamo šalto vandens šilumos kiekis, fiksuojamas kas mėnesį', 1237, 5, NULL, NULL),
	(2238, 56, 2, 8, 2, 0, 34, 5, 56, NULL, 'Suminis grįžtamo šalto vandens šilumos kiekis, fiksuojamas kas parą', 1237, 5, NULL, NULL),
	(2239, 58, 0, 8, 2, 0, 31, 6, 59, NULL, 'Suminis šalto vandens tūrio kiekis, fiksuojamas kas mėnesį', 1201, 5, NULL, NULL),
	(2240, 58, 0, 8, 2, 0, 31, 5, 59, NULL, 'Suminis šalto vandens tūrio kiekis, fiksuojamas kas parą', 1201, 5, NULL, NULL),
	(2241, 58, 1, 8, 2, 0, 31, 5, 59, NULL, 'Suminis tiekiamo šalto vandens tūrio kiekis, fiksuojamas kas parą', 1201, 5, NULL, NULL),
	(2242, 58, 1, 8, 2, 0, 31, 6, 59, NULL, 'Suminis tiekiamo šalto vandens tūrio kiekis, fiksuojamas kas mėnesį', 1201, 5, NULL, NULL),
	(2243, 58, 2, 8, 2, 0, 31, 5, 59, NULL, 'Suminis grįžtamo šalto vandens tūrio kiekis, fiksuojamas kas parą', 1258, 5, NULL, NULL),
	(2244, 58, 2, 8, 2, 0, 31, 6, 59, NULL, 'Suminis grįžtamo šalto vandens tūrio kiekis, fiksuojamas kas mėnesį', 1258, 5, NULL, NULL),
	(2245, 59, 0, 8, 2, 0, 34, 6, 51, NULL, 'Suminis karšto vandens šilumos kiekis, fiksuojamas kas mėnesį', 1205, 5, NULL, NULL),
	(2246, 59, 0, 8, 2, 0, 34, 5, 51, NULL, 'Suminis karšto vandens šilumos kiekis, fiksuojamas kas parą', 1205, 5, NULL, NULL),
	(2247, 59, 1, 8, 2, 0, 34, 6, 51, NULL, 'Suminis tiekiamo karšto vandens šilumos kiekis, fiksuojamas kas mėnesį', 1205, 5, NULL, NULL),
	(2248, 59, 1, 8, 2, 0, 34, 5, 51, NULL, 'Suminis tiekiamo karšto vandens šilumos kiekis, fiksuojamas kas parą', 1205, 5, NULL, NULL),
	(2249, 59, 2, 8, 2, 0, 34, 5, 51, NULL, 'Suminis grįžtamo karšto vandens šilumos kiekis, fiksuojamas kas parą', 1237, 5, NULL, NULL),
	(2250, 59, 2, 8, 2, 0, 34, 6, 51, NULL, 'Suminis grįžtamo karšto vandens šilumos kiekis, fiksuojamas kas mėnesį', 1237, 5, NULL, NULL),
	(2251, 61, 0, 8, 2, 0, 31, 5, 53, NULL, 'Suminis karšto vandens tūrio kiekis, fiksuojamas kas parą', 1201, 5, NULL, NULL),
	(2252, 61, 0, 8, 2, 0, 31, 6, 53, NULL, 'Suminis karšto vandens tūrio kiekis, fiksuojamas kas mėnesį', 1201, 5, NULL, NULL),
	(2253, 61, 1, 8, 2, 0, 31, 5, 53, NULL, 'Suminis tiekiamo karšto vandens tūrio kiekis, fiksuojamas kas parą', 1201, 5, NULL, NULL),
	(2254, 61, 1, 8, 2, 0, 31, 6, 53, NULL, 'Suminis tiekiamo karšto vandens tūrio kiekis, fiksuojamas kas mėnesį', 1201, 5, NULL, NULL),
	(2255, 61, 2, 8, 2, 0, 31, 5, 53, NULL, 'Suminis grįžtamo karšto vandens tūrio kiekis, fiksuojamas kas parą', 1258, 5, NULL, NULL),
	(2256, 61, 2, 8, 2, 0, 31, 6, 53, NULL, 'Suminis grįžtamo karšto vandens tūrio kiekis, fiksuojamas kas mėnesį', 1258, 5, NULL, NULL),
	(2257, 62, 0, 8, 2, 0, 29, 7, 75, NULL, 'Suminis šilumnešio skaitiklio darbo laikas', 1007, 5, NULL, NULL),
	(2258, 62, 0, 4, 2, 0, 29, 4, 75, NULL, 'Šilumnešio skaitiklio darbo laikas per valandą', 1018, 2, NULL, NULL),
	(2259, 62, 0, 5, 2, 0, 29, 5, 75, NULL, 'Šilumnešio skaitiklio darbo laikas per parą', 1018, 3, NULL, NULL),
	(2260, 62, 0, 6, 2, 0, 29, 6, 75, NULL, 'Šilumnešio skaitiklio darbo laikas per mėnesį', 1018, 4, NULL, NULL),
	(2261, 63, 0, 8, 2, 0, 29, 7, 76, NULL, 'Suminis šilumnešio skaitiklio nedarbo laikas', 1012, 5, NULL, NULL),
	(2262, 63, 0, 4, 2, 0, 29, 4, 76, NULL, 'Šilumnešio skaitiklio nedarbo laikas per valandą', 1091, 2, NULL, NULL),
	(2263, 63, 0, 5, 2, 0, 29, 5, 76, NULL, 'Šilumnešio skaitiklio nedarbo laikas per parą', 1091, 3, NULL, NULL),
	(2264, 63, 0, 6, 2, 0, 29, 6, 76, NULL, 'Šilumnešio skaitiklio nedarbo laikas per mėnesį', 1091, 4, NULL, NULL),
	(2265, 64, 0, 8, 2, 0, 29, 7, 77, NULL, 'Suminis šalto vandens skaitiklio darbo laikas', 1204, 5, NULL, NULL),
	(2266, 64, 0, 4, 2, 0, 29, 4, 77, NULL, 'Šalto vandens skaitiklio darbo laikas per valandą', 1268, 2, NULL, NULL),
	(2267, 64, 0, 5, 2, 0, 29, 5, 77, NULL, 'Šalto vandens skaitiklio darbo laikas per parą', 1268, 3, NULL, NULL),
	(2268, 64, 0, 6, 2, 0, 29, 6, 77, NULL, 'Šalto vandens skaitiklio darbo laikas per mėnesį', 1268, 4, NULL, NULL),
	(2269, 62, 0, 13, 2, 0, 29, 12, 75, NULL, 'Šilumnešio skaitiklio darbo laikas per 15 minučių', 1018, 2, NULL, NULL),
	(2270, 62, 0, 3, 2, 0, 29, 3, 75, NULL, 'Šilumnešio skaitiklio darbo laikas per 30 minučių', 1018, 2, NULL, NULL),
	(2271, 63, 0, 13, 2, 0, 29, 12, 76, NULL, 'Šilumnešio skaitiklio nedarbo laikas per 15 minučių', 1091, 2, NULL, NULL),
	(2272, 63, 0, 3, 2, 0, 29, 3, 76, NULL, 'Šilumnešio skaitiklio nedarbo laikas per 30 minučių', 1091, 2, NULL, NULL),
	(2273, 64, 0, 13, 2, 0, 29, 12, 77, NULL, 'Šalto vandens skaitiklio darbo laikas per 15 minučių', 1268, 2, NULL, NULL),
	(2274, 64, 0, 3, 2, 0, 29, 3, 77, NULL, 'Šalto vandens skaitiklio darbo laikas per 30 minučių', 1268, 2, NULL, NULL),
	(2275, 62, 0, 8, 2, 0, 29, 4, 75, NULL, 'Suminis šilumnešio skaitiklio darbo laikas, fiksuojamas kas valandą', 1007, 5, NULL, NULL),
	(2276, 62, 0, 8, 2, 0, 29, 3, 75, NULL, 'Suminis šilumnešio skaitiklio darbo laikas, fiksuojamas kas 30 minučių', 1007, 5, NULL, NULL),
	(2277, 62, 0, 8, 2, 0, 29, 12, 75, NULL, 'Suminis šilumnešio skaitiklio darbo laikas, fiksuojamas kas 15 minučių', 1007, 5, NULL, NULL),
	(2278, 63, 0, 8, 2, 0, 29, 12, 76, NULL, 'Suminis šilumnešio skaitiklio nedarbo laikas, fiksuojamas kas 15 minučių', 1012, 5, NULL, NULL),
	(2279, 63, 0, 8, 2, 0, 29, 3, 76, NULL, 'Suminis šilumnešio skaitiklio nedarbo laikas, fiksuojamas kas 30 minučių', 1012, 5, NULL, NULL),
	(2280, 63, 0, 8, 2, 0, 29, 4, 76, NULL, 'Suminis šilumnešio skaitiklio nedarbo laikas, fiksuojamas kas valandą', 1012, 5, NULL, NULL),
	(2281, 64, 0, 8, 2, 0, 29, 12, 77, NULL, 'Suminis šalto vandens skaitiklio darbo laikas, fiksuojamas kas 15 minučių', 1204, 5, NULL, NULL),
	(2282, 64, 0, 8, 2, 0, 29, 3, 77, NULL, 'Suminis šalto vandens skaitiklio darbo laikas, fiksuojamas kas 30 minučių', 1204, 5, NULL, NULL),
	(2283, 64, 0, 8, 2, 0, 29, 4, 77, NULL, 'Suminis šalto vandens skaitiklio darbo laikas, fiksuojamas kas valandą', 1204, 5, NULL, NULL),
	(2284, 62, 0, 8, 2, 0, 29, 5, 75, NULL, 'Suminis šilumnešio skaitiklio darbo laikas, fiksuojamas kas parą', 1007, 5, NULL, NULL),
	(2285, 62, 0, 8, 2, 0, 29, 6, 75, NULL, 'Suminis šilumnešio skaitiklio darbo laikas, fiksuojamas kas mėnesį', 1007, 5, NULL, NULL),
	(2286, 63, 0, 8, 2, 0, 29, 5, 76, NULL, 'Suminis šilumnešio skaitiklio nedarbo laikas, fiksuojamas kas parą', 1012, 5, NULL, NULL),
	(2287, 63, 0, 8, 2, 0, 29, 6, 76, NULL, 'Suminis šilumnešio skaitiklio nedarbo laikas, fiksuojamas kas mėnesį', 1012, 5, NULL, NULL),
	(2288, 64, 0, 8, 2, 0, 29, 5, 77, NULL, 'Suminis šalto vandens skaitiklio darbo laikas, fiksuojamas kas parą', 1204, 5, NULL, NULL),
	(2289, 64, 0, 8, 2, 0, 29, 6, 77, NULL, 'Suminis šalto vandens skaitiklio darbo laikas, fiksuojamas kas mėnesį', 1204, 5, NULL, NULL),
	(2290, 65, 0, 8, 2, 0, 29, 7, 78, NULL, 'Suminis karšto vandens skaitiklio darbo laikas', 1204, 5, NULL, NULL),
	(2291, 65, 0, 4, 2, 0, 29, 4, 78, NULL, 'Karšto vandens skaitiklio darbo laikas per valandą', 1268, 2, NULL, NULL),
	(2292, 65, 0, 5, 2, 0, 29, 5, 78, NULL, 'Karšto vandens skaitiklio darbo laikas per parą', 1268, 3, NULL, NULL),
	(2293, 65, 0, 6, 2, 0, 29, 6, 78, NULL, 'Karšto vandens skaitiklio darbo laikas per mėnesį', 1268, 4, NULL, NULL),
	(2294, 65, 0, 13, 2, 0, 29, 12, 78, NULL, 'Karšto vandens skaitiklio darbo laikas per 15 minučių', 1268, 2, NULL, NULL),
	(2295, 65, 0, 3, 2, 0, 29, 3, 78, NULL, 'Karšto vandens skaitiklio darbo laikas per 30 minučių', 1268, 2, NULL, NULL),
	(2296, 65, 0, 8, 2, 0, 29, 12, 78, NULL, 'Suminis karšto vandens skaitiklio darbo laikas, fiksuojamas kas 15 minučių', 1204, 5, NULL, NULL),
	(2297, 65, 0, 8, 2, 0, 29, 3, 78, NULL, 'Suminis karšto vandens skaitiklio darbo laikas, fiksuojamas kas 30 minučių', 1204, 5, NULL, NULL),
	(2298, 65, 0, 8, 2, 0, 29, 4, 78, NULL, 'Suminis karšto vandens skaitiklio darbo laikas, fiksuojamas kas valandą', 1204, 5, NULL, NULL),
	(2299, 65, 0, 8, 2, 0, 29, 5, 78, NULL, 'Suminis karšto vandens skaitiklio darbo laikas, fiksuojamas kas parą', 1204, 5, NULL, NULL),
	(2300, 65, 0, 8, 2, 0, 29, 6, 78, NULL, 'Suminis karšto vandens skaitiklio darbo laikas, fiksuojamas kas mėnesį', 1204, 5, NULL, NULL),
	(2301, 1, 1, 3, 4, 0, 1, 5, 13, NULL, 'Maksimali pusvalandinė P+ galia per parą', 394, 3, NULL, NULL),
	(2302, 1, 1, 3, 5, 0, 1, 5, 13, NULL, 'Minimali pusvalandinė P+ galia per parą', NULL, 3, NULL, NULL),
	(2303, 1, 1, 3, 4, 0, 1, 6, 13, NULL, 'Maksimali pusvalandinė P+ galia per mėnesį', 374, 4, NULL, NULL),
	(2304, 1, 1, 3, 5, 0, 1, 6, 13, NULL, 'Minimali pusvalandinė P+ galia per mėnesį', NULL, 4, NULL, NULL),
	(2305, 1, 1, 4, 4, 0, 1, 5, 13, NULL, 'Maksimali valandinė P+ galia per parą', 394, 3, NULL, NULL),
	(2306, 1, 1, 4, 5, 0, 1, 5, 13, NULL, 'Minimali valandinė P+ galia per parą', NULL, 3, NULL, NULL),
	(2307, 1, 1, 4, 4, 0, 1, 6, 13, NULL, 'Maksimali valandinė P+ galia per mėnesį', 374, 4, NULL, NULL),
	(2308, 1, 1, 4, 5, 0, 1, 6, 13, NULL, 'Minimali valandinė P+ galia per mėnesį', NULL, 4, NULL, NULL),
	(2309, 46, 0, 4, 4, 0, 27, 5, 55, NULL, 'Maksimali valandinė oro temperatūra per parą', NULL, 3, NULL, NULL),
	(2310, 46, 0, 4, 5, 0, 27, 5, 55, NULL, 'Minimali valandinė oro temperatūra per parą', NULL, 3, NULL, NULL),
	(2311, 46, 0, 4, 4, 0, 27, 6, 55, NULL, 'Maksimali valandinė oro temperatūra per mėnesį', NULL, 4, NULL, NULL),
	(2312, 46, 0, 4, 5, 0, 27, 6, 55, NULL, 'Minimali valandinė oro temperatūra per mėnesį', NULL, 4, NULL, NULL),
	(2313, 46, 0, 13, 4, 0, 27, 5, 55, NULL, 'Maksimali 15 minučių oro temperatūra per parą', NULL, 3, NULL, NULL),
	(2314, 46, 0, 13, 5, 0, 27, 5, 55, NULL, 'Minimali 15 minučių oro temperatūra per parą', NULL, 3, NULL, NULL),
	(2315, 46, 0, 13, 4, 0, 27, 6, 55, NULL, 'Maksimali 15 minučių oro temperatūra per mėnesį', NULL, 4, NULL, NULL),
	(2316, 46, 0, 13, 5, 0, 27, 6, 55, NULL, 'Minimali 15 minučių oro temperatūra per mėnesį', NULL, 4, NULL, NULL),
	(2317, 54, 1, 4, 4, 0, 27, 5, 72, NULL, 'Maksimali valandinė tiekiamo šilumnešio temperatūra per parą', NULL, 3, NULL, NULL),
	(2318, 54, 2, 4, 4, 0, 27, 5, 72, NULL, 'Maksimali valandinė grįžtamo šilumnešio temperatūra per parą', NULL, 3, NULL, NULL),
	(2319, 54, 3, 4, 4, 0, 27, 5, 72, NULL, 'Maksimalus valandinių tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas per parą', NULL, 3, NULL, NULL),
	(2320, 54, 1, 4, 5, 0, 27, 5, 72, NULL, 'Minimali valandinė tiekiamo šilumnešio temperatūra per parą', NULL, 3, NULL, NULL),
	(2321, 54, 2, 4, 5, 0, 27, 5, 72, NULL, 'Minimali valandinė grįžtamo šilumnešio temperatūra per parą', NULL, 3, NULL, NULL),
	(2322, 54, 3, 4, 5, 0, 27, 5, 72, NULL, 'Minimalus valandinių tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas per parą', NULL, 3, NULL, NULL),
	(2323, 54, 1, 4, 4, 0, 27, 6, 72, NULL, 'Maksimali valandinė tiekiamo šilumnešio temperatūra per mėnesį', NULL, 4, NULL, NULL),
	(2324, 54, 2, 4, 4, 0, 27, 6, 72, NULL, 'Maksimali valandinė grįžtamo šilumnešio temperatūra per mėnesį', NULL, 4, NULL, NULL),
	(2325, 54, 3, 4, 4, 0, 27, 6, 72, NULL, 'Maksimalus valandinių tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas per mėnesį', NULL, 4, NULL, NULL),
	(2326, 54, 1, 4, 5, 0, 27, 6, 72, NULL, 'Minimali valandinė tiekiamo šilumnešio temperatūra per mėnesį', NULL, 4, NULL, NULL),
	(2327, 54, 2, 4, 5, 0, 27, 6, 72, NULL, 'Minimali valandinė grįžtamo šilumnešio temperatūra per mėnesį', NULL, 4, NULL, NULL),
	(2328, 54, 3, 4, 5, 0, 27, 6, 72, NULL, 'Minimalus valandinių tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas per mėnesį', NULL, 4, NULL, NULL),
	(2329, 1, 1, 8, 2, 5, 2, 7, 14, '1.0.1.8.0.5', 'Suminė A+ energija pagal 5 tarifą', 274, 5, NULL, NULL),
	(2330, 1, 1, 8, 2, 6, 2, 7, 14, '1.0.1.8.0.6', 'Suminė A+ energija pagal 6 tarifą', 284, 5, NULL, NULL),
	(2331, 1, 1, 8, 2, 7, 2, 7, 14, '1.0.1.8.0.7', 'Suminė A+ energija pagal 7 tarifą', 294, 5, NULL, NULL),
	(2332, 1, 1, 8, 2, 8, 2, 7, 14, '1.0.1.8.0.8', 'Suminė A+ energija pagal 8 tarifą', 304, 5, NULL, NULL),
	(2333, 1, 2, 8, 2, 5, 2, 7, 14, '1.0.2.8.0.5', 'Suminė A- energija pagal 5 tarifą', 275, 5, NULL, NULL),
	(2334, 1, 2, 8, 2, 6, 2, 7, 14, '1.0.2.8.0.6', 'Suminė A- energija pagal 6 tarifą', 285, 5, NULL, NULL),
	(2335, 1, 2, 8, 2, 7, 2, 7, 14, '1.0.2.8.0.7', 'Suminė A- energija pagal 7 tarifą', 295, 5, NULL, NULL),
	(2336, 1, 2, 8, 2, 8, 2, 7, 14, '1.0.2.8.0.8', 'Suminė A- energija pagal 8 tarifą', 305, 5, NULL, NULL),
	(2337, 3, 1, 8, 2, 5, 4, 7, 15, '1.0.3.8.0.5', 'Suminė R+ energija pagal 5 tarifą', 276, 5, NULL, NULL),
	(2338, 3, 1, 8, 2, 6, 4, 7, 15, '1.0.3.8.0.6', 'Suminė R+ energija pagal 6 tarifą', 286, 5, NULL, NULL),
	(2339, 3, 1, 8, 2, 7, 4, 7, 15, '1.0.3.8.0.7', 'Suminė R+ energija pagal 7 tarifą', 296, 5, NULL, NULL),
	(2340, 3, 1, 8, 2, 8, 4, 7, 15, '1.0.3.8.0.8', 'Suminė R+ energija pagal 8 tarifą', 306, 5, NULL, NULL),
	(2341, 3, 2, 8, 2, 5, 4, 7, 15, '1.0.4.8.0.5', 'Suminė R- energija pagal 5 tarifą', 277, 5, NULL, NULL),
	(2342, 3, 2, 8, 2, 6, 4, 7, 15, '1.0.4.8.0.6', 'Suminė R- energija pagal 6 tarifą', 287, 5, NULL, NULL),
	(2343, 3, 2, 8, 2, 7, 4, 7, 15, '1.0.4.8.0.7', 'Suminė R- energija pagal 7 tarifą', 297, 5, NULL, NULL),
	(2344, 3, 2, 8, 2, 8, 4, 7, 15, '1.0.4.8.0.8', 'Suminė R- energija pagal 8 tarifą', 307, 5, NULL, NULL),
	(2345, 1, 1, 6, 2, 5, 2, 6, 14, '1.0.1.9.0.5', 'A+ energija pagal 5 tarifą per mėnesį', 226, 4, NULL, NULL),
	(2346, 1, 1, 6, 2, 6, 2, 6, 14, '1.0.1.9.0.6', 'A+ energija pagal 6 tarifą per mėnesį', 232, 4, NULL, NULL),
	(2347, 1, 1, 6, 2, 7, 2, 6, 14, '1.0.1.9.0.7', 'A+ energija pagal 7 tarifą per mėnesį', 238, 4, NULL, NULL),
	(2348, 1, 1, 6, 2, 8, 2, 6, 14, '1.0.1.9.0.8', 'A+ energija pagal 8 tarifą per mėnesį', 244, 4, NULL, NULL),
	(2349, 1, 2, 6, 2, 5, 2, 6, 14, '1.0.2.9.0.5', 'A- energija pagal 5 tarifą per mėnesį', 227, 4, NULL, NULL),
	(2350, 1, 2, 6, 2, 6, 2, 6, 14, '1.0.2.9.0.6', 'A- energija pagal 6 tarifą per mėnesį', 233, 4, NULL, NULL),
	(2351, 1, 2, 6, 2, 7, 2, 6, 14, '1.0.2.9.0.7', 'A- energija pagal 7 tarifą per mėnesį', 239, 4, NULL, NULL),
	(2352, 1, 2, 6, 2, 8, 2, 6, 14, '1.0.2.9.0.8', 'A- energija pagal 8 tarifą per mėnesį', 245, 4, NULL, NULL),
	(2353, 3, 1, 6, 2, 5, 4, 6, 15, '1.0.3.9.0.5', 'R+ energija pagal 5 tarifą per mėnesį', 228, 4, NULL, NULL),
	(2354, 3, 1, 6, 2, 6, 4, 6, 15, '1.0.3.9.0.6', 'R+ energija pagal 6 tarifą per mėnesį', 234, 4, NULL, NULL),
	(2355, 3, 1, 6, 2, 7, 4, 6, 15, '1.0.3.9.0.7', 'R+ energija pagal 7 tarifą per mėnesį', 240, 4, NULL, NULL),
	(2356, 3, 1, 6, 2, 8, 4, 6, 15, '1.0.3.9.0.8', 'R+ energija pagal 8 tarifą per mėnesį', 246, 4, NULL, NULL),
	(2357, 3, 2, 6, 2, 5, 4, 6, 15, '1.0.4.9.0.5', 'R- energija pagal 5 tarifą per mėnesį', 229, 4, NULL, NULL),
	(2358, 3, 2, 6, 2, 6, 4, 6, 15, '1.0.4.9.0.6', 'R- energija pagal 6 tarifą per mėnesį', 235, 4, NULL, NULL),
	(2359, 3, 2, 6, 2, 7, 4, 6, 15, '1.0.4.9.0.7', 'R- energija pagal 7 tarifą per mėnesį', 241, 4, NULL, NULL),
	(2360, 3, 2, 6, 2, 8, 4, 6, 15, '1.0.4.9.0.8', 'R- energija pagal 8 tarifą per mėnesį', 247, 4, NULL, NULL),
	(2361, 1, 1, 5, 2, 5, 2, 5, 14, '1.0.1.10.0.5', 'A+ energija pagal 5 tarifą per parą', 250, 3, NULL, NULL),
	(2362, 1, 1, 5, 2, 6, 2, 5, 14, '1.0.1.10.0.6', 'A+ energija pagal 6 tarifą per parą', 256, 3, NULL, NULL),
	(2363, 1, 1, 5, 2, 7, 2, 5, 14, '1.0.1.10.0.7', 'A+ energija pagal 7 tarifą per parą', 262, 3, NULL, NULL),
	(2364, 1, 1, 5, 2, 8, 2, 5, 14, '1.0.1.10.0.8', 'A+ energija pagal 8 tarifą per parą', 268, 3, NULL, NULL),
	(2365, 1, 2, 5, 2, 5, 2, 5, 14, '1.0.2.10.0.5', 'A- energija pagal 5 tarifą per parą', 251, 3, NULL, NULL),
	(2366, 1, 2, 5, 2, 6, 2, 5, 14, '1.0.2.10.0.6', 'A- energija pagal 6 tarifą per parą', 257, 3, NULL, NULL),
	(2367, 1, 2, 5, 2, 7, 2, 5, 14, '1.0.2.10.0.7', 'A- energija pagal 7 tarifą per parą', 263, 3, NULL, NULL),
	(2368, 1, 2, 5, 2, 8, 2, 5, 14, '1.0.2.10.0.8', 'A- energija pagal 8 tarifą per parą', 269, 3, NULL, NULL),
	(2369, 3, 1, 5, 2, 5, 4, 5, 15, '1.0.3.10.0.5', 'R+ energija pagal 5 tarifą per parą', 252, 3, NULL, NULL),
	(2370, 3, 1, 5, 2, 6, 4, 5, 15, '1.0.3.10.0.6', 'R+ energija pagal 6 tarifą per parą', 258, 3, NULL, NULL),
	(2371, 3, 1, 5, 2, 7, 4, 5, 15, '1.0.3.10.0.7', 'R+ energija pagal 7 tarifą per parą', 264, 3, NULL, NULL),
	(2372, 3, 1, 5, 2, 8, 4, 5, 15, '1.0.3.10.0.8', 'R+ energija pagal 8 tarifą per parą', 270, 3, NULL, NULL),
	(2373, 3, 2, 5, 2, 5, 4, 5, 15, '1.0.4.10.0.5', 'R- energija pagal 5 tarifą per parą', 253, 3, NULL, NULL),
	(2374, 3, 2, 5, 2, 6, 4, 5, 15, '1.0.4.10.0.6', 'R- energija pagal 6 tarifą per parą', 259, 3, NULL, NULL),
	(2375, 3, 2, 5, 2, 7, 4, 5, 15, '1.0.4.10.0.7', 'R- energija pagal 7 tarifą per parą', 265, 3, NULL, NULL),
	(2376, 3, 2, 5, 2, 8, 4, 5, 15, '1.0.4.10.0.8', 'R- energija pagal 8 tarifą per parą', 271, 3, NULL, NULL),
	(2377, 3, 5, 8, 2, 5, 4, 7, 15, NULL, 'Suminė R1 energija pagal 5 tarifą', 278, 5, NULL, NULL),
	(2378, 3, 5, 8, 2, 6, 4, 7, 15, NULL, 'Suminė R1 energija pagal 6 tarifą', 288, 5, NULL, NULL),
	(2379, 3, 5, 8, 2, 7, 4, 7, 15, NULL, 'Suminė R1 energija pagal 7 tarifą', 298, 5, NULL, NULL),
	(2380, 3, 5, 8, 2, 8, 4, 7, 15, NULL, 'Suminė R1 energija pagal 8 tarifą', 308, 5, NULL, NULL),
	(2381, 3, 5, 6, 2, 5, 4, 6, 15, NULL, 'R1 energija pagal 5 tarifą per mėnesį', 342, 4, NULL, NULL),
	(2382, 3, 5, 6, 2, 6, 4, 6, 15, NULL, 'R1 energija pagal 6 tarifą per mėnesį', 346, 4, NULL, NULL),
	(2383, 3, 5, 6, 2, 7, 4, 6, 15, NULL, 'R1 energija pagal 7 tarifą per mėnesį', 350, 4, NULL, NULL),
	(2384, 3, 5, 6, 2, 8, 4, 6, 15, NULL, 'R1 energija pagal 8 tarifą per mėnesį', 354, 4, NULL, NULL),
	(2385, 3, 5, 5, 2, 5, 4, 5, 15, NULL, 'R1 energija pagal 5 tarifą per parą', 326, 3, NULL, NULL),
	(2386, 3, 5, 5, 2, 6, 4, 5, 15, NULL, 'R1 energija pagal 6 tarifą per parą', 330, 3, NULL, NULL),
	(2387, 3, 5, 5, 2, 7, 4, 5, 15, NULL, 'R1 energija pagal 7 tarifą per parą', 334, 3, NULL, NULL),
	(2388, 3, 5, 5, 2, 8, 4, 5, 15, NULL, 'R1 energija pagal 8 tarifą per parą', 338, 3, NULL, NULL),
	(2389, 3, 6, 8, 2, 5, 4, 7, 15, NULL, 'Suminė R2 energija pagal 5 tarifą', 279, 5, NULL, NULL),
	(2390, 3, 6, 8, 2, 6, 4, 7, 15, NULL, 'Suminė R2 energija pagal 6 tarifą', 289, 5, NULL, NULL),
	(2391, 3, 6, 8, 2, 7, 4, 7, 15, NULL, 'Suminė R2 energija pagal 7 tarifą', 299, 5, NULL, NULL),
	(2392, 3, 6, 8, 2, 8, 4, 7, 15, NULL, 'Suminė R2 energija pagal 8 tarifą', 309, 5, NULL, NULL),
	(2393, 3, 6, 6, 2, 5, 4, 6, 15, NULL, 'R2 energija pagal 5 tarifą per mėnesį', 343, 4, NULL, NULL),
	(2394, 3, 6, 6, 2, 6, 4, 6, 15, NULL, 'R2 energija pagal 6 tarifą per mėnesį', 347, 4, NULL, NULL),
	(2395, 3, 6, 6, 2, 7, 4, 6, 15, NULL, 'R2 energija pagal 7 tarifą per mėnesį', 351, 4, NULL, NULL),
	(2396, 3, 6, 6, 2, 8, 4, 6, 15, NULL, 'R2 energija pagal 8 tarifą per mėnesį', 355, 4, NULL, NULL),
	(2397, 3, 6, 5, 2, 5, 4, 5, 15, NULL, 'R2 energija pagal 5 tarifą per parą', 327, 3, NULL, NULL),
	(2398, 3, 6, 5, 2, 6, 4, 5, 15, NULL, 'R2 energija pagal 6 tarifą per parą', 331, 3, NULL, NULL),
	(2399, 3, 6, 5, 2, 7, 4, 5, 15, NULL, 'R2 energija pagal 7 tarifą per parą', 335, 3, NULL, NULL),
	(2400, 3, 6, 5, 2, 8, 4, 5, 15, NULL, 'R2 energija pagal 8 tarifą per parą', 339, 3, NULL, NULL),
	(2401, 3, 7, 8, 2, 5, 4, 7, 15, NULL, 'Suminė R3 energija pagal 5 tarifą', 280, 5, NULL, NULL),
	(2402, 3, 7, 8, 2, 6, 4, 7, 15, NULL, 'Suminė R3 energija pagal 6 tarifą', 290, 5, NULL, NULL),
	(2403, 3, 7, 8, 2, 7, 4, 7, 15, NULL, 'Suminė R3 energija pagal 7 tarifą', 300, 5, NULL, NULL),
	(2404, 3, 7, 8, 2, 8, 4, 7, 15, NULL, 'Suminė R3 energija pagal 8 tarifą', 310, 5, NULL, NULL),
	(2405, 3, 7, 6, 2, 5, 4, 6, 15, NULL, 'R3 energija pagal 5 tarifą per mėnesį', 344, 4, NULL, NULL),
	(2406, 3, 7, 6, 2, 6, 4, 6, 15, NULL, 'R3 energija pagal 6 tarifą per mėnesį', 348, 4, NULL, NULL),
	(2407, 3, 7, 6, 2, 7, 4, 6, 15, NULL, 'R3 energija pagal 7 tarifą per mėnesį', 352, 4, NULL, NULL),
	(2408, 3, 7, 6, 2, 8, 4, 6, 15, NULL, 'R3 energija pagal 8 tarifą per mėnesį', 356, 4, NULL, NULL),
	(2409, 3, 7, 5, 2, 5, 4, 5, 15, NULL, 'R3 energija pagal 5 tarifą per parą', 328, 3, NULL, NULL),
	(2410, 3, 7, 5, 2, 6, 4, 5, 15, NULL, 'R3 energija pagal 6 tarifą per parą', 332, 3, NULL, NULL),
	(2411, 3, 7, 5, 2, 7, 4, 5, 15, NULL, 'R3 energija pagal 7 tarifą per parą', 336, 3, NULL, NULL),
	(2412, 3, 7, 5, 2, 8, 4, 5, 15, NULL, 'R3 energija pagal 8 tarifą per parą', 340, 3, NULL, NULL),
	(2413, 3, 8, 8, 2, 5, 4, 7, 15, NULL, 'Suminė R4 energija pagal 5 tarifą', 281, 5, NULL, NULL),
	(2414, 3, 8, 8, 2, 6, 4, 7, 15, NULL, 'Suminė R4 energija pagal 6 tarifą', 291, 5, NULL, NULL),
	(2415, 3, 8, 8, 2, 7, 4, 7, 15, NULL, 'Suminė R4 energija pagal 7 tarifą', 301, 5, NULL, NULL),
	(2416, 3, 8, 8, 2, 8, 4, 7, 15, NULL, 'Suminė R4 energija pagal 8 tarifą', 311, 5, NULL, NULL),
	(2417, 3, 8, 6, 2, 5, 4, 6, 15, NULL, 'R4 energija pagal 5 tarifą per mėnesį', 345, 4, NULL, NULL),
	(2418, 3, 8, 6, 2, 6, 4, 6, 15, NULL, 'R4 energija pagal 6 tarifą per mėnesį', 349, 4, NULL, NULL),
	(2419, 3, 8, 6, 2, 7, 4, 6, 15, NULL, 'R4 energija pagal 7 tarifą per mėnesį', 353, 4, NULL, NULL),
	(2420, 3, 8, 6, 2, 8, 4, 6, 15, NULL, 'R4 energija pagal 8 tarifą per mėnesį', 357, 4, NULL, NULL),
	(2421, 3, 8, 5, 2, 5, 4, 5, 15, NULL, 'R4 energija pagal 5 tarifą per parą', 329, 3, NULL, NULL),
	(2422, 3, 8, 5, 2, 6, 4, 5, 15, NULL, 'R4 energija pagal 6 tarifą per parą', 333, 3, NULL, NULL),
	(2423, 3, 8, 5, 2, 7, 4, 5, 15, NULL, 'R4 energija pagal 7 tarifą per parą', 337, 3, NULL, NULL),
	(2424, 3, 8, 5, 2, 8, 4, 5, 15, NULL, 'R4 energija pagal 8 tarifą per parą', 341, 3, NULL, NULL),
	(2425, 34, 1, 8, 2, 5, 41, 7, 45, NULL, 'Suminė W+ energija pagal 5 tarifą', 282, 5, NULL, NULL),
	(2426, 34, 1, 8, 2, 6, 41, 7, 45, NULL, 'Suminė W+ energija pagal 6 tarifą', 292, 5, NULL, NULL),
	(2427, 34, 1, 8, 2, 7, 41, 7, 45, NULL, 'Suminė W+ energija pagal 7 tarifą', 302, 5, NULL, NULL),
	(2428, 34, 1, 8, 2, 8, 41, 7, 45, NULL, 'Suminė W+ energija pagal 8 tarifą', 312, 5, NULL, NULL),
	(2429, 34, 2, 8, 2, 5, 41, 7, 45, NULL, 'Suminė W- energija pagal 5 tarifą', 283, 5, NULL, NULL),
	(2430, 34, 2, 8, 2, 6, 41, 7, 45, NULL, 'Suminė W- energija pagal 6 tarifą', 293, 5, NULL, NULL),
	(2431, 34, 2, 8, 2, 7, 41, 7, 45, NULL, 'Suminė W- energija pagal 7 tarifą', 303, 5, NULL, NULL),
	(2432, 34, 2, 8, 2, 8, 41, 7, 45, NULL, 'Suminė W- energija pagal 8 tarifą', 313, 5, NULL, NULL),
	(2433, 34, 1, 6, 2, 5, 41, 6, 45, NULL, 'W+ energija pagal 5 tarifą per mėnesį', 230, 4, NULL, NULL),
	(2434, 34, 1, 6, 2, 6, 41, 6, 45, NULL, 'W+ energija pagal 6 tarifą per mėnesį', 236, 4, NULL, NULL),
	(2435, 34, 1, 6, 2, 7, 41, 6, 45, NULL, 'W+ energija pagal 7 tarifą per mėnesį', 242, 4, NULL, NULL),
	(2436, 34, 1, 6, 2, 8, 41, 6, 45, NULL, 'W+ energija pagal 8 tarifą per mėnesį', 248, 4, NULL, NULL),
	(2437, 34, 2, 6, 2, 5, 41, 6, 45, NULL, 'W- energija pagal 5 tarifą per mėnesį', 231, 4, NULL, NULL),
	(2438, 34, 2, 6, 2, 6, 41, 6, 45, NULL, 'W- energija pagal 6 tarifą per mėnesį', 237, 4, NULL, NULL),
	(2439, 34, 2, 6, 2, 7, 41, 6, 45, NULL, 'W- energija pagal 7 tarifą per mėnesį', 243, 4, NULL, NULL),
	(2440, 34, 2, 6, 2, 8, 41, 6, 45, NULL, 'W- energija pagal 8 tarifą per mėnesį', 249, 4, NULL, NULL),
	(2441, 34, 1, 5, 2, 5, 41, 5, 45, NULL, 'W+ energija pagal 5 tarifą per parą', 254, 3, NULL, NULL),
	(2442, 34, 1, 5, 2, 6, 41, 5, 45, NULL, 'W+ energija pagal 6 tarifą per parą', 260, 3, NULL, NULL),
	(2443, 34, 1, 5, 2, 7, 41, 5, 45, NULL, 'W+ energija pagal 7 tarifą per parą', 266, 3, NULL, NULL),
	(2444, 34, 1, 5, 2, 8, 41, 5, 45, NULL, 'W+ energija pagal 8 tarifą per parą', 272, 3, NULL, NULL),
	(2445, 34, 2, 5, 2, 5, 41, 5, 45, NULL, 'W- energija pagal 5 tarifą per parą', 255, 3, NULL, NULL),
	(2446, 34, 2, 5, 2, 6, 41, 5, 45, NULL, 'W- energija pagal 6 tarifą per parą', 261, 3, NULL, NULL),
	(2447, 34, 2, 5, 2, 7, 41, 5, 45, NULL, 'W- energija pagal 7 tarifą per parą', 267, 3, NULL, NULL),
	(2448, 34, 2, 5, 2, 8, 41, 5, 45, NULL, 'W- energija pagal 8 tarifą per parą', 273, 3, NULL, NULL),
	(2449, 1, 1, 8, 2, 5, 2, 3, 14, '1.0.1.8.0.5', 'Suminė A+ energija pagal 5 tarifą, fiksuojama kas 30 minučių', 274, 5, NULL, NULL),
	(2450, 1, 1, 8, 2, 6, 2, 3, 14, '1.0.1.8.0.6', 'Suminė A+ energija pagal 6 tarifą, fiksuojama kas 30 minučių', 284, 5, NULL, NULL),
	(2451, 1, 1, 8, 2, 7, 2, 3, 14, '1.0.1.8.0.7', 'Suminė A+ energija pagal 7 tarifą, fiksuojama kas 30 minučių', 294, 5, NULL, NULL),
	(2452, 1, 1, 8, 2, 8, 2, 3, 14, '1.0.1.8.0.8', 'Suminė A+ energija pagal 8 tarifą, fiksuojama kas 30 minučių', 304, 5, NULL, NULL),
	(2453, 1, 1, 8, 2, 5, 2, 13, 14, '1.0.1.8.0.5', 'Suminė A+ energija pagal 5 tarifą, fiksuojama kas 20 minučių', 274, 5, NULL, NULL),
	(2454, 1, 1, 8, 2, 6, 2, 13, 14, '1.0.1.8.0.6', 'Suminė A+ energija pagal 6 tarifą, fiksuojama kas 20 minučių', 284, 5, NULL, NULL),
	(2455, 1, 1, 8, 2, 7, 2, 13, 14, '1.0.1.8.0.7', 'Suminė A+ energija pagal 7 tarifą, fiksuojama kas 20 minučių', 294, 5, NULL, NULL),
	(2456, 1, 1, 8, 2, 8, 2, 13, 14, '1.0.1.8.0.8', 'Suminė A+ energija pagal 8 tarifą, fiksuojama kas 20 minučių', 304, 5, NULL, NULL),
	(2457, 1, 1, 8, 2, 5, 2, 12, 14, '1.0.1.8.0.5', 'Suminė A+ energija pagal 5 tarifą, fiksuojama kas 15 minučių', 274, 5, NULL, NULL),
	(2458, 1, 1, 8, 2, 6, 2, 12, 14, '1.0.1.8.0.6', 'Suminė A+ energija pagal 6 tarifą, fiksuojama kas 15 minučių', 284, 5, NULL, NULL),
	(2459, 1, 1, 8, 2, 7, 2, 12, 14, '1.0.1.8.0.7', 'Suminė A+ energija pagal 7 tarifą, fiksuojama kas 15 minučių', 294, 5, NULL, NULL),
	(2460, 1, 1, 8, 2, 8, 2, 12, 14, '1.0.1.8.0.8', 'Suminė A+ energija pagal 8 tarifą, fiksuojama kas 15 minučių', 304, 5, NULL, NULL),
	(2461, 1, 1, 8, 2, 5, 2, 4, 14, '1.0.1.8.0.5', 'Suminė A+ energija pagal 5 tarifą, fiksuojama kas valandą', 274, 5, NULL, NULL),
	(2462, 1, 1, 8, 2, 6, 2, 4, 14, '1.0.1.8.0.6', 'Suminė A+ energija pagal 6 tarifą, fiksuojama kas valandą', 284, 5, NULL, NULL),
	(2463, 1, 1, 8, 2, 7, 2, 4, 14, '1.0.1.8.0.7', 'Suminė A+ energija pagal 7 tarifą, fiksuojama kas valandą', 294, 5, NULL, NULL),
	(2464, 1, 1, 8, 2, 8, 2, 4, 14, '1.0.1.8.0.8', 'Suminė A+ energija pagal 8 tarifą, fiksuojama kas valandą', 304, 5, NULL, NULL),
	(2465, 1, 2, 8, 2, 5, 2, 3, 14, '1.0.2.8.0.5', 'Suminė A- energija pagal 5 tarifą, fiksuojama kas 30 minučių', 275, 5, NULL, NULL),
	(2466, 1, 2, 8, 2, 6, 2, 3, 14, '1.0.2.8.0.6', 'Suminė A- energija pagal 6 tarifą, fiksuojama kas 30 minučių', 285, 5, NULL, NULL),
	(2467, 1, 2, 8, 2, 7, 2, 3, 14, '1.0.2.8.0.7', 'Suminė A- energija pagal 7 tarifą, fiksuojama kas 30 minučių', 295, 5, NULL, NULL),
	(2468, 1, 2, 8, 2, 8, 2, 3, 14, '1.0.2.8.0.8', 'Suminė A- energija pagal 8 tarifą, fiksuojama kas 30 minučių', 305, 5, NULL, NULL),
	(2469, 1, 2, 8, 2, 5, 2, 13, 14, '1.0.2.8.0.5', 'Suminė A- energija pagal 5 tarifą, fiksuojama kas 20 minučių', 275, 5, NULL, NULL),
	(2470, 1, 2, 8, 2, 6, 2, 13, 14, '1.0.2.8.0.6', 'Suminė A- energija pagal 6 tarifą, fiksuojama kas 20 minučių', 285, 5, NULL, NULL),
	(2471, 1, 2, 8, 2, 7, 2, 13, 14, '1.0.2.8.0.7', 'Suminė A- energija pagal 7 tarifą, fiksuojama kas 20 minučių', 295, 5, NULL, NULL),
	(2472, 1, 2, 8, 2, 8, 2, 13, 14, '1.0.2.8.0.8', 'Suminė A- energija pagal 8 tarifą, fiksuojama kas 20 minučių', 305, 5, NULL, NULL),
	(2473, 1, 2, 8, 2, 5, 2, 4, 14, '1.0.2.8.0.5', 'Suminė A- energija pagal 5 tarifą, fiksuojama kas valandą', 275, 5, NULL, NULL),
	(2474, 1, 2, 8, 2, 6, 2, 4, 14, '1.0.2.8.0.6', 'Suminė A- energija pagal 6 tarifą, fiksuojama kas valandą', 285, 5, NULL, NULL),
	(2475, 1, 2, 8, 2, 7, 2, 4, 14, '1.0.2.8.0.7', 'Suminė A- energija pagal 7 tarifą, fiksuojama kas valandą', 295, 5, NULL, NULL),
	(2476, 1, 2, 8, 2, 8, 2, 4, 14, '1.0.2.8.0.8', 'Suminė A- energija pagal 8 tarifą, fiksuojama kas valandą', 305, 5, NULL, NULL),
	(2477, 1, 2, 8, 2, 5, 2, 12, 14, '1.0.2.8.0.5', 'Suminė A- energija pagal 5 tarifą, fiksuojama kas 15 minučių', 275, 5, NULL, NULL),
	(2478, 1, 2, 8, 2, 6, 2, 12, 14, '1.0.2.8.0.6', 'Suminė A- energija pagal 6 tarifą, fiksuojama kas 15 minučių', 285, 5, NULL, NULL),
	(2479, 1, 2, 8, 2, 7, 2, 12, 14, '1.0.2.8.0.7', 'Suminė A- energija pagal 7 tarifą, fiksuojama kas 15 minučių', 295, 5, NULL, NULL),
	(2480, 1, 2, 8, 2, 8, 2, 12, 14, '1.0.2.8.0.8', 'Suminė A- energija pagal 8 tarifą, fiksuojama kas 15 minučių', 305, 5, NULL, NULL),
	(2481, 3, 1, 8, 2, 5, 4, 3, 15, '1.0.3.8.0.5', 'Suminė R+ energija pagal 5 tarifą, fiksuojama kas 30 minučių', 276, 5, NULL, NULL),
	(2482, 3, 1, 8, 2, 6, 4, 3, 15, '1.0.3.8.0.6', 'Suminė R+ energija pagal 6 tarifą, fiksuojama kas 30 minučių', 286, 5, NULL, NULL),
	(2483, 3, 1, 8, 2, 7, 4, 3, 15, '1.0.3.8.0.7', 'Suminė R+ energija pagal 7 tarifą, fiksuojama kas 30 minučių', 296, 5, NULL, NULL),
	(2484, 3, 1, 8, 2, 8, 4, 3, 15, '1.0.3.8.0.8', 'Suminė R+ energija pagal 8 tarifą, fiksuojama kas 30 minučių', 306, 5, NULL, NULL),
	(2485, 3, 1, 8, 2, 5, 4, 13, 15, '1.0.3.8.0.5', 'Suminė R+ energija pagal 5 tarifą, fiksuojama kas 20 minučių', 276, 5, NULL, NULL),
	(2486, 3, 1, 8, 2, 6, 4, 13, 15, '1.0.3.8.0.6', 'Suminė R+ energija pagal 6 tarifą, fiksuojama kas 20 minučių', 286, 5, NULL, NULL),
	(2487, 3, 1, 8, 2, 7, 4, 13, 15, '1.0.3.8.0.7', 'Suminė R+ energija pagal 7 tarifą, fiksuojama kas 20 minučių', 296, 5, NULL, NULL),
	(2488, 3, 1, 8, 2, 8, 4, 13, 15, '1.0.3.8.0.8', 'Suminė R+ energija pagal 8 tarifą, fiksuojama kas 20 minučių', 306, 5, NULL, NULL),
	(2489, 3, 1, 8, 2, 5, 4, 4, 15, '1.0.3.8.0.5', 'Suminė R+ energija pagal 5 tarifą, fiksuojama kas valandą', 276, 5, NULL, NULL),
	(2490, 3, 1, 8, 2, 6, 4, 4, 15, '1.0.3.8.0.6', 'Suminė R+ energija pagal 6 tarifą, fiksuojama kas valandą', 286, 5, NULL, NULL),
	(2491, 3, 1, 8, 2, 7, 4, 4, 15, '1.0.3.8.0.7', 'Suminė R+ energija pagal 7 tarifą, fiksuojama kas valandą', 296, 5, NULL, NULL),
	(2492, 3, 1, 8, 2, 8, 4, 4, 15, '1.0.3.8.0.8', 'Suminė R+ energija pagal 8 tarifą, fiksuojama kas valandą', 306, 5, NULL, NULL),
	(2493, 3, 1, 8, 2, 5, 4, 12, 15, '1.0.3.8.0.5', 'Suminė R+ energija pagal 5 tarifą, fiksuojama kas 15 minučių', 276, 5, NULL, NULL),
	(2494, 3, 1, 8, 2, 6, 4, 12, 15, '1.0.3.8.0.6', 'Suminė R+ energija pagal 6 tarifą, fiksuojama kas 15 minučių', 286, 5, NULL, NULL),
	(2495, 3, 1, 8, 2, 7, 4, 12, 15, '1.0.3.8.0.7', 'Suminė R+ energija pagal 7 tarifą, fiksuojama kas 15 minučių', 296, 5, NULL, NULL),
	(2496, 3, 1, 8, 2, 8, 4, 12, 15, '1.0.3.8.0.8', 'Suminė R+ energija pagal 8 tarifą, fiksuojama kas 15 minučių', 306, 5, NULL, NULL),
	(2497, 3, 2, 8, 2, 5, 4, 13, 15, '1.0.4.8.0.5', 'Suminė R- energija pagal 5 tarifą, fiksuojama kas 20 minučių', 277, 5, NULL, NULL),
	(2498, 3, 2, 8, 2, 6, 4, 13, 15, '1.0.4.8.0.6', 'Suminė R- energija pagal 6 tarifą, fiksuojama kas 20 minučių', 287, 5, NULL, NULL),
	(2499, 3, 2, 8, 2, 7, 4, 13, 15, '1.0.4.8.0.7', 'Suminė R- energija pagal 7 tarifą, fiksuojama kas 20 minučių', 297, 5, NULL, NULL),
	(2500, 3, 2, 8, 2, 8, 4, 13, 15, '1.0.4.8.0.8', 'Suminė R- energija pagal 8 tarifą, fiksuojama kas 20 minučių', 307, 5, NULL, NULL),
	(2501, 3, 2, 8, 2, 5, 4, 12, 15, '1.0.4.8.0.5', 'Suminė R- energija pagal 5 tarifą, fiksuojama kas 15 minučių', 277, 5, NULL, NULL),
	(2502, 3, 2, 8, 2, 6, 4, 12, 15, '1.0.4.8.0.6', 'Suminė R- energija pagal 6 tarifą, fiksuojama kas 15 minučių', 287, 5, NULL, NULL),
	(2503, 3, 2, 8, 2, 7, 4, 12, 15, '1.0.4.8.0.7', 'Suminė R- energija pagal 7 tarifą, fiksuojama kas 15 minučių', 297, 5, NULL, NULL),
	(2504, 3, 2, 8, 2, 8, 4, 12, 15, '1.0.4.8.0.8', 'Suminė R- energija pagal 8 tarifą, fiksuojama kas 15 minučių', 307, 5, NULL, NULL),
	(2505, 3, 2, 8, 2, 5, 4, 4, 15, '1.0.4.8.0.5', 'Suminė R- energija pagal 5 tarifą, fiksuojama kas valandą', 277, 5, NULL, NULL),
	(2506, 3, 2, 8, 2, 6, 4, 4, 15, '1.0.4.8.0.6', 'Suminė R- energija pagal 6 tarifą, fiksuojama kas valandą', 287, 5, NULL, NULL),
	(2507, 3, 2, 8, 2, 7, 4, 4, 15, '1.0.4.8.0.7', 'Suminė R- energija pagal 7 tarifą, fiksuojama kas valandą', 297, 5, NULL, NULL),
	(2508, 3, 2, 8, 2, 8, 4, 4, 15, '1.0.4.8.0.8', 'Suminė R- energija pagal 8 tarifą, fiksuojama kas valandą', 307, 5, NULL, NULL),
	(2509, 3, 2, 8, 2, 5, 4, 3, 15, '1.0.4.8.0.5', 'Suminė R- energija pagal 5 tarifą, fiksuojama kas 30 minučių', 277, 5, NULL, NULL),
	(2510, 3, 2, 8, 2, 6, 4, 3, 15, '1.0.4.8.0.6', 'Suminė R- energija pagal 6 tarifą, fiksuojama kas 30 minučių', 287, 5, NULL, NULL),
	(2511, 3, 2, 8, 2, 7, 4, 3, 15, '1.0.4.8.0.7', 'Suminė R- energija pagal 7 tarifą, fiksuojama kas 30 minučių', 297, 5, NULL, NULL),
	(2512, 3, 2, 8, 2, 8, 4, 3, 15, '1.0.4.8.0.8', 'Suminė R- energija pagal 8 tarifą, fiksuojama kas 30 minučių', 307, 5, NULL, NULL),
	(2513, 3, 5, 8, 2, 5, 4, 4, 15, NULL, 'Suminė R1 energija pagal 5 tarifą, fiksuojama kas valandą', 278, 5, NULL, NULL),
	(2514, 3, 5, 8, 2, 6, 4, 4, 15, NULL, 'Suminė R1 energija pagal 6 tarifą, fiksuojama kas valandą', 288, 5, NULL, NULL),
	(2515, 3, 5, 8, 2, 7, 4, 4, 15, NULL, 'Suminė R1 energija pagal 7 tarifą, fiksuojama kas valandą', 298, 5, NULL, NULL),
	(2516, 3, 5, 8, 2, 8, 4, 4, 15, NULL, 'Suminė R1 energija pagal 8 tarifą, fiksuojama kas valandą', 308, 5, NULL, NULL),
	(2517, 3, 5, 8, 2, 5, 4, 13, 15, NULL, 'Suminė R1 energija pagal 5 tarifą, fiksuojama kas 20 minučių', 278, 5, NULL, NULL),
	(2518, 3, 5, 8, 2, 6, 4, 13, 15, NULL, 'Suminė R1 energija pagal 6 tarifą, fiksuojama kas 20 minučių', 288, 5, NULL, NULL),
	(2519, 3, 5, 8, 2, 7, 4, 13, 15, NULL, 'Suminė R1 energija pagal 7 tarifą, fiksuojama kas 20 minučių', 298, 5, NULL, NULL),
	(2520, 3, 5, 8, 2, 8, 4, 13, 15, NULL, 'Suminė R1 energija pagal 8 tarifą, fiksuojama kas 20 minučių', 308, 5, NULL, NULL),
	(2521, 3, 5, 8, 2, 5, 4, 12, 15, NULL, 'Suminė R1 energija pagal 5 tarifą, fiksuojama kas 15 minučių', 278, 5, NULL, NULL),
	(2522, 3, 5, 8, 2, 6, 4, 12, 15, NULL, 'Suminė R1 energija pagal 6 tarifą, fiksuojama kas 15 minučių', 288, 5, NULL, NULL),
	(2523, 3, 5, 8, 2, 7, 4, 12, 15, NULL, 'Suminė R1 energija pagal 7 tarifą, fiksuojama kas 15 minučių', 298, 5, NULL, NULL),
	(2524, 3, 5, 8, 2, 8, 4, 12, 15, NULL, 'Suminė R1 energija pagal 8 tarifą, fiksuojama kas 15 minučių', 308, 5, NULL, NULL),
	(2525, 3, 5, 8, 2, 5, 4, 3, 15, NULL, 'Suminė R1 energija pagal 5 tarifą, fiksuojama kas 30 minučių', 278, 5, NULL, NULL),
	(2526, 3, 5, 8, 2, 6, 4, 3, 15, NULL, 'Suminė R1 energija pagal 6 tarifą, fiksuojama kas 30 minučių', 288, 5, NULL, NULL),
	(2527, 3, 5, 8, 2, 7, 4, 3, 15, NULL, 'Suminė R1 energija pagal 7 tarifą, fiksuojama kas 30 minučių', 298, 5, NULL, NULL),
	(2528, 3, 5, 8, 2, 8, 4, 3, 15, NULL, 'Suminė R1 energija pagal 8 tarifą, fiksuojama kas 30 minučių', 308, 5, NULL, NULL),
	(2529, 3, 6, 8, 2, 5, 4, 4, 15, NULL, 'Suminė R2 energija pagal 5 tarifą, fiksuojama kas valandą', 279, 5, NULL, NULL),
	(2530, 3, 6, 8, 2, 6, 4, 4, 15, NULL, 'Suminė R2 energija pagal 6 tarifą, fiksuojama kas valandą', 289, 5, NULL, NULL),
	(2531, 3, 6, 8, 2, 7, 4, 4, 15, NULL, 'Suminė R2 energija pagal 7 tarifą, fiksuojama kas valandą', 299, 5, NULL, NULL),
	(2532, 3, 6, 8, 2, 8, 4, 4, 15, NULL, 'Suminė R2 energija pagal 8 tarifą, fiksuojama kas valandą', 309, 5, NULL, NULL),
	(2533, 3, 6, 8, 2, 5, 4, 13, 15, NULL, 'Suminė R2 energija pagal 5 tarifą, fiksuojama kas 20 minučių', 279, 5, NULL, NULL),
	(2534, 3, 6, 8, 2, 6, 4, 13, 15, NULL, 'Suminė R2 energija pagal 6 tarifą, fiksuojama kas 20 minučių', 289, 5, NULL, NULL),
	(2535, 3, 6, 8, 2, 7, 4, 13, 15, NULL, 'Suminė R2 energija pagal 7 tarifą, fiksuojama kas 20 minučių', 299, 5, NULL, NULL),
	(2536, 3, 6, 8, 2, 8, 4, 13, 15, NULL, 'Suminė R2 energija pagal 8 tarifą, fiksuojama kas 20 minučių', 309, 5, NULL, NULL),
	(2537, 3, 6, 8, 2, 5, 4, 12, 15, NULL, 'Suminė R2 energija pagal 5 tarifą, fiksuojama kas 15 minučių', 279, 5, NULL, NULL),
	(2538, 3, 6, 8, 2, 6, 4, 12, 15, NULL, 'Suminė R2 energija pagal 6 tarifą, fiksuojama kas 15 minučių', 289, 5, NULL, NULL),
	(2539, 3, 6, 8, 2, 7, 4, 12, 15, NULL, 'Suminė R2 energija pagal 7 tarifą, fiksuojama kas 15 minučių', 299, 5, NULL, NULL),
	(2540, 3, 6, 8, 2, 8, 4, 12, 15, NULL, 'Suminė R2 energija pagal 8 tarifą, fiksuojama kas 15 minučių', 309, 5, NULL, NULL),
	(2541, 3, 6, 8, 2, 5, 4, 3, 15, NULL, 'Suminė R2 energija pagal 5 tarifą, fiksuojama kas 30 minučių', 279, 5, NULL, NULL),
	(2542, 3, 6, 8, 2, 6, 4, 3, 15, NULL, 'Suminė R2 energija pagal 6 tarifą, fiksuojama kas 30 minučių', 289, 5, NULL, NULL),
	(2543, 3, 6, 8, 2, 7, 4, 3, 15, NULL, 'Suminė R2 energija pagal 7 tarifą, fiksuojama kas 30 minučių', 299, 5, NULL, NULL),
	(2544, 3, 6, 8, 2, 8, 4, 3, 15, NULL, 'Suminė R2 energija pagal 8 tarifą, fiksuojama kas 30 minučių', 309, 5, NULL, NULL),
	(2545, 3, 7, 8, 2, 5, 4, 3, 15, NULL, 'Suminė R3 energija pagal 5 tarifą, fiksuojama kas 30 minučių', 280, 5, NULL, NULL),
	(2546, 3, 7, 8, 2, 6, 4, 3, 15, NULL, 'Suminė R3 energija pagal 6 tarifą, fiksuojama kas 30 minučių', 290, 5, NULL, NULL),
	(2547, 3, 7, 8, 2, 7, 4, 3, 15, NULL, 'Suminė R3 energija pagal 7 tarifą, fiksuojama kas 30 minučių', 300, 5, NULL, NULL),
	(2548, 3, 7, 8, 2, 8, 4, 3, 15, NULL, 'Suminė R3 energija pagal 8 tarifą, fiksuojama kas 30 minučių', 310, 5, NULL, NULL),
	(2549, 3, 7, 8, 2, 5, 4, 12, 15, NULL, 'Suminė R3 energija pagal 5 tarifą, fiksuojama kas 15 minučių', 280, 5, NULL, NULL),
	(2550, 3, 7, 8, 2, 6, 4, 12, 15, NULL, 'Suminė R3 energija pagal 6 tarifą, fiksuojama kas 15 minučių', 290, 5, NULL, NULL),
	(2551, 3, 7, 8, 2, 7, 4, 12, 15, NULL, 'Suminė R3 energija pagal 7 tarifą, fiksuojama kas 15 minučių', 300, 5, NULL, NULL),
	(2552, 3, 7, 8, 2, 8, 4, 12, 15, NULL, 'Suminė R3 energija pagal 8 tarifą, fiksuojama kas 15 minučių', 310, 5, NULL, NULL),
	(2553, 3, 7, 8, 2, 5, 4, 13, 15, NULL, 'Suminė R3 energija pagal 5 tarifą, fiksuojama kas 20 minučių', 280, 5, NULL, NULL),
	(2554, 3, 7, 8, 2, 6, 4, 13, 15, NULL, 'Suminė R3 energija pagal 6 tarifą, fiksuojama kas 20 minučių', 290, 5, NULL, NULL),
	(2555, 3, 7, 8, 2, 7, 4, 13, 15, NULL, 'Suminė R3 energija pagal 7 tarifą, fiksuojama kas 20 minučių', 300, 5, NULL, NULL),
	(2556, 3, 7, 8, 2, 8, 4, 13, 15, NULL, 'Suminė R3 energija pagal 8 tarifą, fiksuojama kas 20 minučių', 310, 5, NULL, NULL),
	(2557, 3, 7, 8, 2, 5, 4, 4, 15, NULL, 'Suminė R3 energija pagal 5 tarifą, fiksuojama kas valandą', 280, 5, NULL, NULL),
	(2558, 3, 7, 8, 2, 6, 4, 4, 15, NULL, 'Suminė R3 energija pagal 6 tarifą, fiksuojama kas valandą', 290, 5, NULL, NULL),
	(2559, 3, 7, 8, 2, 7, 4, 4, 15, NULL, 'Suminė R3 energija pagal 7 tarifą, fiksuojama kas valandą', 300, 5, NULL, NULL),
	(2560, 3, 7, 8, 2, 8, 4, 4, 15, NULL, 'Suminė R3 energija pagal 8 tarifą, fiksuojama kas valandą', 310, 5, NULL, NULL),
	(2561, 3, 8, 8, 2, 5, 4, 13, 15, NULL, 'Suminė R4 energija pagal 5 tarifą, fiksuojama kas 20 minučių', 281, 5, NULL, NULL),
	(2562, 3, 8, 8, 2, 6, 4, 13, 15, NULL, 'Suminė R4 energija pagal 6 tarifą, fiksuojama kas 20 minučių', 291, 5, NULL, NULL),
	(2563, 3, 8, 8, 2, 7, 4, 13, 15, NULL, 'Suminė R4 energija pagal 7 tarifą, fiksuojama kas 20 minučių', 301, 5, NULL, NULL),
	(2564, 3, 8, 8, 2, 8, 4, 13, 15, NULL, 'Suminė R4 energija pagal 8 tarifą, fiksuojama kas 20 minučių', 311, 5, NULL, NULL),
	(2565, 3, 8, 8, 2, 5, 4, 4, 15, NULL, 'Suminė R4 energija pagal 5 tarifą, fiksuojama kas valandą', 281, 5, NULL, NULL),
	(2566, 3, 8, 8, 2, 6, 4, 4, 15, NULL, 'Suminė R4 energija pagal 6 tarifą, fiksuojama kas valandą', 291, 5, NULL, NULL),
	(2567, 3, 8, 8, 2, 7, 4, 4, 15, NULL, 'Suminė R4 energija pagal 7 tarifą, fiksuojama kas valandą', 301, 5, NULL, NULL),
	(2568, 3, 8, 8, 2, 8, 4, 4, 15, NULL, 'Suminė R4 energija pagal 8 tarifą, fiksuojama kas valandą', 311, 5, NULL, NULL),
	(2569, 3, 8, 8, 2, 5, 4, 3, 15, NULL, 'Suminė R4 energija pagal 5 tarifą, fiksuojama kas 30 minučių', 281, 5, NULL, NULL),
	(2570, 3, 8, 8, 2, 6, 4, 3, 15, NULL, 'Suminė R4 energija pagal 6 tarifą, fiksuojama kas 30 minučių', 291, 5, NULL, NULL),
	(2571, 3, 8, 8, 2, 7, 4, 3, 15, NULL, 'Suminė R4 energija pagal 7 tarifą, fiksuojama kas 30 minučių', 301, 5, NULL, NULL),
	(2572, 3, 8, 8, 2, 8, 4, 3, 15, NULL, 'Suminė R4 energija pagal 8 tarifą, fiksuojama kas 30 minučių', 311, 5, NULL, NULL),
	(2573, 3, 8, 8, 2, 5, 4, 12, 15, NULL, 'Suminė R4 energija pagal 5 tarifą, fiksuojama kas 15 minučių', 281, 5, NULL, NULL),
	(2574, 3, 8, 8, 2, 6, 4, 12, 15, NULL, 'Suminė R4 energija pagal 6 tarifą, fiksuojama kas 15 minučių', 291, 5, NULL, NULL),
	(2575, 3, 8, 8, 2, 7, 4, 12, 15, NULL, 'Suminė R4 energija pagal 7 tarifą, fiksuojama kas 15 minučių', 301, 5, NULL, NULL),
	(2576, 3, 8, 8, 2, 8, 4, 12, 15, NULL, 'Suminė R4 energija pagal 8 tarifą, fiksuojama kas 15 minučių', 311, 5, NULL, NULL),
	(2577, 34, 1, 8, 2, 5, 41, 3, 45, NULL, 'Suminė W+ energija pagal 5 tarifą, fiksuojama kas 30 minučių', 282, 5, NULL, NULL),
	(2578, 34, 1, 8, 2, 6, 41, 3, 45, NULL, 'Suminė W+ energija pagal 6 tarifą, fiksuojama kas 30 minučių', 292, 5, NULL, NULL),
	(2579, 34, 1, 8, 2, 7, 41, 3, 45, NULL, 'Suminė W+ energija pagal 7 tarifą, fiksuojama kas 30 minučių', 302, 5, NULL, NULL),
	(2580, 34, 1, 8, 2, 8, 41, 3, 45, NULL, 'Suminė W+ energija pagal 8 tarifą, fiksuojama kas 30 minučių', 312, 5, NULL, NULL),
	(2581, 34, 1, 8, 2, 5, 41, 12, 45, NULL, 'Suminė W+ energija pagal 5 tarifą, fiksuojama kas 15 minučių', 282, 5, NULL, NULL),
	(2582, 34, 1, 8, 2, 6, 41, 12, 45, NULL, 'Suminė W+ energija pagal 6 tarifą, fiksuojama kas 15 minučių', 292, 5, NULL, NULL),
	(2583, 34, 1, 8, 2, 7, 41, 12, 45, NULL, 'Suminė W+ energija pagal 7 tarifą, fiksuojama kas 15 minučių', 302, 5, NULL, NULL),
	(2584, 34, 1, 8, 2, 8, 41, 12, 45, NULL, 'Suminė W+ energija pagal 8 tarifą, fiksuojama kas 15 minučių', 312, 5, NULL, NULL),
	(2585, 34, 1, 8, 2, 5, 41, 13, 45, NULL, 'Suminė W+ energija pagal 5 tarifą, fiksuojama kas 20 minučių', 282, 5, NULL, NULL),
	(2586, 34, 1, 8, 2, 6, 41, 13, 45, NULL, 'Suminė W+ energija pagal 6 tarifą, fiksuojama kas 20 minučių', 292, 5, NULL, NULL),
	(2587, 34, 1, 8, 2, 7, 41, 13, 45, NULL, 'Suminė W+ energija pagal 7 tarifą, fiksuojama kas 20 minučių', 302, 5, NULL, NULL),
	(2588, 34, 1, 8, 2, 8, 41, 13, 45, NULL, 'Suminė W+ energija pagal 8 tarifą, fiksuojama kas 20 minučių', 312, 5, NULL, NULL),
	(2589, 34, 1, 8, 2, 5, 41, 4, 45, NULL, 'Suminė W+ energija pagal 5 tarifą, fiksuojama kas valandą', 282, 5, NULL, NULL),
	(2590, 34, 1, 8, 2, 6, 41, 4, 45, NULL, 'Suminė W+ energija pagal 6 tarifą, fiksuojama kas valandą', 292, 5, NULL, NULL),
	(2591, 34, 1, 8, 2, 7, 41, 4, 45, NULL, 'Suminė W+ energija pagal 7 tarifą, fiksuojama kas valandą', 302, 5, NULL, NULL),
	(2592, 34, 1, 8, 2, 8, 41, 4, 45, NULL, 'Suminė W+ energija pagal 8 tarifą, fiksuojama kas valandą', 312, 5, NULL, NULL),
	(2593, 34, 2, 8, 2, 5, 41, 3, 45, NULL, 'Suminė W- energija pagal 5 tarifą, fiksuojama kas 30 minučių', 283, 5, NULL, NULL),
	(2594, 34, 2, 8, 2, 6, 41, 3, 45, NULL, 'Suminė W- energija pagal 6 tarifą, fiksuojama kas 30 minučių', 293, 5, NULL, NULL),
	(2595, 34, 2, 8, 2, 7, 41, 3, 45, NULL, 'Suminė W- energija pagal 7 tarifą, fiksuojama kas 30 minučių', 303, 5, NULL, NULL),
	(2596, 34, 2, 8, 2, 8, 41, 3, 45, NULL, 'Suminė W- energija pagal 8 tarifą, fiksuojama kas 30 minučių', 313, 5, NULL, NULL),
	(2597, 34, 2, 8, 2, 5, 41, 12, 45, NULL, 'Suminė W- energija pagal 5 tarifą, fiksuojama kas 15 minučių', 283, 5, NULL, NULL),
	(2598, 34, 2, 8, 2, 6, 41, 12, 45, NULL, 'Suminė W- energija pagal 6 tarifą, fiksuojama kas 15 minučių', 293, 5, NULL, NULL),
	(2599, 34, 2, 8, 2, 7, 41, 12, 45, NULL, 'Suminė W- energija pagal 7 tarifą, fiksuojama kas 15 minučių', 303, 5, NULL, NULL),
	(2600, 34, 2, 8, 2, 8, 41, 12, 45, NULL, 'Suminė W- energija pagal 8 tarifą, fiksuojama kas 15 minučių', 313, 5, NULL, NULL),
	(2601, 34, 2, 8, 2, 5, 41, 4, 45, NULL, 'Suminė W- energija pagal 5 tarifą, fiksuojama kas valandą', 283, 5, NULL, NULL),
	(2602, 34, 2, 8, 2, 6, 41, 4, 45, NULL, 'Suminė W- energija pagal 6 tarifą, fiksuojama kas valandą', 293, 5, NULL, NULL),
	(2603, 34, 2, 8, 2, 7, 41, 4, 45, NULL, 'Suminė W- energija pagal 7 tarifą, fiksuojama kas valandą', 303, 5, NULL, NULL),
	(2604, 34, 2, 8, 2, 8, 41, 4, 45, NULL, 'Suminė W- energija pagal 8 tarifą, fiksuojama kas valandą', 313, 5, NULL, NULL),
	(2605, 34, 2, 8, 2, 5, 41, 13, 45, NULL, 'Suminė W- energija pagal 5 tarifą, fiksuojama kas 20 minučių', 283, 5, NULL, NULL),
	(2606, 34, 2, 8, 2, 6, 41, 13, 45, NULL, 'Suminė W- energija pagal 6 tarifą, fiksuojama kas 20 minučių', 293, 5, NULL, NULL),
	(2607, 34, 2, 8, 2, 7, 41, 13, 45, NULL, 'Suminė W- energija pagal 7 tarifą, fiksuojama kas 20 minučių', 303, 5, NULL, NULL),
	(2608, 34, 2, 8, 2, 8, 41, 13, 45, NULL, 'Suminė W- energija pagal 8 tarifą, fiksuojama kas 20 minučių', 313, 5, NULL, NULL),
	(2609, 1, 1, 8, 2, 5, 2, 5, 14, '1.0.1.8.0.5', 'Suminė A+ energija pagal 5 tarifą, fiksuojama kas parą', 274, 5, NULL, NULL),
	(2610, 1, 1, 8, 2, 6, 2, 5, 14, '1.0.1.8.0.6', 'Suminė A+ energija pagal 6 tarifą, fiksuojama kas parą', 284, 5, NULL, NULL),
	(2611, 1, 1, 8, 2, 7, 2, 5, 14, '1.0.1.8.0.7', 'Suminė A+ energija pagal 7 tarifą, fiksuojama kas parą', 294, 5, NULL, NULL),
	(2612, 1, 1, 8, 2, 8, 2, 5, 14, '1.0.1.8.0.8', 'Suminė A+ energija pagal 8 tarifą, fiksuojama kas parą', 304, 5, NULL, NULL),
	(2613, 1, 1, 8, 2, 5, 2, 6, 14, '1.0.1.8.0.5', 'Suminė A+ energija pagal 5 tarifą, fiksuojama kas mėnesį', 274, 5, NULL, NULL),
	(2614, 1, 1, 8, 2, 6, 2, 6, 14, '1.0.1.8.0.6', 'Suminė A+ energija pagal 6 tarifą, fiksuojama kas mėnesį', 284, 5, NULL, NULL),
	(2615, 1, 1, 8, 2, 7, 2, 6, 14, '1.0.1.8.0.7', 'Suminė A+ energija pagal 7 tarifą, fiksuojama kas mėnesį', 294, 5, NULL, NULL),
	(2616, 1, 1, 8, 2, 8, 2, 6, 14, '1.0.1.8.0.8', 'Suminė A+ energija pagal 8 tarifą, fiksuojama kas mėnesį', 304, 5, NULL, NULL),
	(2617, 1, 2, 8, 2, 5, 2, 6, 14, '1.0.2.8.0.5', 'Suminė A- energija pagal 5 tarifą, fiksuojama kas mėnesį', 275, 5, NULL, NULL),
	(2618, 1, 2, 8, 2, 6, 2, 6, 14, '1.0.2.8.0.6', 'Suminė A- energija pagal 6 tarifą, fiksuojama kas mėnesį', 285, 5, NULL, NULL),
	(2619, 1, 2, 8, 2, 7, 2, 6, 14, '1.0.2.8.0.7', 'Suminė A- energija pagal 7 tarifą, fiksuojama kas mėnesį', 295, 5, NULL, NULL),
	(2620, 1, 2, 8, 2, 8, 2, 6, 14, '1.0.2.8.0.8', 'Suminė A- energija pagal 8 tarifą, fiksuojama kas mėnesį', 305, 5, NULL, NULL),
	(2621, 1, 2, 8, 2, 5, 2, 5, 14, '1.0.2.8.0.5', 'Suminė A- energija pagal 5 tarifą, fiksuojama kas parą', 275, 5, NULL, NULL),
	(2622, 1, 2, 8, 2, 6, 2, 5, 14, '1.0.2.8.0.6', 'Suminė A- energija pagal 6 tarifą, fiksuojama kas parą', 285, 5, NULL, NULL),
	(2623, 1, 2, 8, 2, 7, 2, 5, 14, '1.0.2.8.0.7', 'Suminė A- energija pagal 7 tarifą, fiksuojama kas parą', 295, 5, NULL, NULL),
	(2624, 1, 2, 8, 2, 8, 2, 5, 14, '1.0.2.8.0.8', 'Suminė A- energija pagal 8 tarifą, fiksuojama kas parą', 305, 5, NULL, NULL),
	(2625, 3, 1, 8, 2, 5, 4, 6, 15, '1.0.3.8.0.5', 'Suminė R+ energija pagal 5 tarifą, fiksuojama kas mėnesį', 276, 5, NULL, NULL),
	(2626, 3, 1, 8, 2, 6, 4, 6, 15, '1.0.3.8.0.6', 'Suminė R+ energija pagal 6 tarifą, fiksuojama kas mėnesį', 286, 5, NULL, NULL),
	(2627, 3, 1, 8, 2, 7, 4, 6, 15, '1.0.3.8.0.7', 'Suminė R+ energija pagal 7 tarifą, fiksuojama kas mėnesį', 296, 5, NULL, NULL),
	(2628, 3, 1, 8, 2, 8, 4, 6, 15, '1.0.3.8.0.8', 'Suminė R+ energija pagal 8 tarifą, fiksuojama kas mėnesį', 306, 5, NULL, NULL),
	(2629, 3, 1, 8, 2, 5, 4, 5, 15, '1.0.3.8.0.5', 'Suminė R+ energija pagal 5 tarifą, fiksuojama kas parą', 276, 5, NULL, NULL),
	(2630, 3, 1, 8, 2, 6, 4, 5, 15, '1.0.3.8.0.6', 'Suminė R+ energija pagal 6 tarifą, fiksuojama kas parą', 286, 5, NULL, NULL),
	(2631, 3, 1, 8, 2, 7, 4, 5, 15, '1.0.3.8.0.7', 'Suminė R+ energija pagal 7 tarifą, fiksuojama kas parą', 296, 5, NULL, NULL),
	(2632, 3, 1, 8, 2, 8, 4, 5, 15, '1.0.3.8.0.8', 'Suminė R+ energija pagal 8 tarifą, fiksuojama kas parą', 306, 5, NULL, NULL),
	(2633, 3, 2, 8, 2, 5, 4, 5, 15, '1.0.4.8.0.5', 'Suminė R- energija pagal 5 tarifą, fiksuojama kas parą', 277, 5, NULL, NULL),
	(2634, 3, 2, 8, 2, 6, 4, 5, 15, '1.0.4.8.0.6', 'Suminė R- energija pagal 6 tarifą, fiksuojama kas parą', 287, 5, NULL, NULL),
	(2635, 3, 2, 8, 2, 7, 4, 5, 15, '1.0.4.8.0.7', 'Suminė R- energija pagal 7 tarifą, fiksuojama kas parą', 297, 5, NULL, NULL),
	(2636, 3, 2, 8, 2, 8, 4, 5, 15, '1.0.4.8.0.8', 'Suminė R- energija pagal 8 tarifą, fiksuojama kas parą', 307, 5, NULL, NULL),
	(2637, 3, 2, 8, 2, 5, 4, 6, 15, '1.0.4.8.0.5', 'Suminė R- energija pagal 5 tarifą, fiksuojama kas mėnesį', 277, 5, NULL, NULL),
	(2638, 3, 2, 8, 2, 6, 4, 6, 15, '1.0.4.8.0.6', 'Suminė R- energija pagal 6 tarifą, fiksuojama kas mėnesį', 287, 5, NULL, NULL),
	(2639, 3, 2, 8, 2, 7, 4, 6, 15, '1.0.4.8.0.7', 'Suminė R- energija pagal 7 tarifą, fiksuojama kas mėnesį', 297, 5, NULL, NULL),
	(2640, 3, 2, 8, 2, 8, 4, 6, 15, '1.0.4.8.0.8', 'Suminė R- energija pagal 8 tarifą, fiksuojama kas mėnesį', 307, 5, NULL, NULL),
	(2641, 3, 5, 8, 2, 5, 4, 6, 15, NULL, 'Suminė R1 energija pagal 5 tarifą, fiksuojama kas mėnesį', 278, 5, NULL, NULL),
	(2642, 3, 5, 8, 2, 6, 4, 6, 15, NULL, 'Suminė R1 energija pagal 6 tarifą, fiksuojama kas mėnesį', 288, 5, NULL, NULL),
	(2643, 3, 5, 8, 2, 7, 4, 6, 15, NULL, 'Suminė R1 energija pagal 7 tarifą, fiksuojama kas mėnesį', 298, 5, NULL, NULL),
	(2644, 3, 5, 8, 2, 8, 4, 6, 15, NULL, 'Suminė R1 energija pagal 8 tarifą, fiksuojama kas mėnesį', 308, 5, NULL, NULL),
	(2645, 3, 5, 8, 2, 5, 4, 5, 15, NULL, 'Suminė R1 energija pagal 5 tarifą, fiksuojama kas parą', 278, 5, NULL, NULL),
	(2646, 3, 5, 8, 2, 6, 4, 5, 15, NULL, 'Suminė R1 energija pagal 6 tarifą, fiksuojama kas parą', 288, 5, NULL, NULL),
	(2647, 3, 5, 8, 2, 7, 4, 5, 15, NULL, 'Suminė R1 energija pagal 7 tarifą, fiksuojama kas parą', 298, 5, NULL, NULL),
	(2648, 3, 5, 8, 2, 8, 4, 5, 15, NULL, 'Suminė R1 energija pagal 8 tarifą, fiksuojama kas parą', 308, 5, NULL, NULL),
	(2649, 3, 6, 8, 2, 5, 4, 6, 15, NULL, 'Suminė R2 energija pagal 5 tarifą, fiksuojama kas mėnesį', 279, 5, NULL, NULL),
	(2650, 3, 6, 8, 2, 6, 4, 6, 15, NULL, 'Suminė R2 energija pagal 6 tarifą, fiksuojama kas mėnesį', 289, 5, NULL, NULL),
	(2651, 3, 6, 8, 2, 7, 4, 6, 15, NULL, 'Suminė R2 energija pagal 7 tarifą, fiksuojama kas mėnesį', 299, 5, NULL, NULL),
	(2652, 3, 6, 8, 2, 8, 4, 6, 15, NULL, 'Suminė R2 energija pagal 8 tarifą, fiksuojama kas mėnesį', 309, 5, NULL, NULL),
	(2653, 3, 6, 8, 2, 5, 4, 5, 15, NULL, 'Suminė R2 energija pagal 5 tarifą, fiksuojama kas parą', 279, 5, NULL, NULL),
	(2654, 3, 6, 8, 2, 6, 4, 5, 15, NULL, 'Suminė R2 energija pagal 6 tarifą, fiksuojama kas parą', 289, 5, NULL, NULL),
	(2655, 3, 6, 8, 2, 7, 4, 5, 15, NULL, 'Suminė R2 energija pagal 7 tarifą, fiksuojama kas parą', 299, 5, NULL, NULL),
	(2656, 3, 6, 8, 2, 8, 4, 5, 15, NULL, 'Suminė R2 energija pagal 8 tarifą, fiksuojama kas parą', 309, 5, NULL, NULL),
	(2657, 3, 7, 8, 2, 5, 4, 5, 15, NULL, 'Suminė R3 energija pagal 5 tarifą, fiksuojama kas parą', 280, 5, NULL, NULL),
	(2658, 3, 7, 8, 2, 6, 4, 5, 15, NULL, 'Suminė R3 energija pagal 6 tarifą, fiksuojama kas parą', 290, 5, NULL, NULL),
	(2659, 3, 7, 8, 2, 7, 4, 5, 15, NULL, 'Suminė R3 energija pagal 7 tarifą, fiksuojama kas parą', 300, 5, NULL, NULL),
	(2660, 3, 7, 8, 2, 8, 4, 5, 15, NULL, 'Suminė R3 energija pagal 8 tarifą, fiksuojama kas parą', 310, 5, NULL, NULL),
	(2661, 3, 7, 8, 2, 5, 4, 6, 15, NULL, 'Suminė R3 energija pagal 5 tarifą, fiksuojama kas mėnesį', 280, 5, NULL, NULL),
	(2662, 3, 7, 8, 2, 6, 4, 6, 15, NULL, 'Suminė R3 energija pagal 6 tarifą, fiksuojama kas mėnesį', 290, 5, NULL, NULL),
	(2663, 3, 7, 8, 2, 7, 4, 6, 15, NULL, 'Suminė R3 energija pagal 7 tarifą, fiksuojama kas mėnesį', 300, 5, NULL, NULL),
	(2664, 3, 7, 8, 2, 8, 4, 6, 15, NULL, 'Suminė R3 energija pagal 8 tarifą, fiksuojama kas mėnesį', 310, 5, NULL, NULL),
	(2665, 3, 8, 8, 2, 5, 4, 6, 15, NULL, 'Suminė R4 energija pagal 5 tarifą, fiksuojama kas mėnesį', 281, 5, NULL, NULL),
	(2666, 3, 8, 8, 2, 6, 4, 6, 15, NULL, 'Suminė R4 energija pagal 6 tarifą, fiksuojama kas mėnesį', 291, 5, NULL, NULL),
	(2667, 3, 8, 8, 2, 7, 4, 6, 15, NULL, 'Suminė R4 energija pagal 7 tarifą, fiksuojama kas mėnesį', 301, 5, NULL, NULL),
	(2668, 3, 8, 8, 2, 8, 4, 6, 15, NULL, 'Suminė R4 energija pagal 8 tarifą, fiksuojama kas mėnesį', 311, 5, NULL, NULL),
	(2669, 3, 8, 8, 2, 5, 4, 5, 15, NULL, 'Suminė R4 energija pagal 5 tarifą, fiksuojama kas parą', 281, 5, NULL, NULL),
	(2670, 3, 8, 8, 2, 6, 4, 5, 15, NULL, 'Suminė R4 energija pagal 6 tarifą, fiksuojama kas parą', 291, 5, NULL, NULL),
	(2671, 3, 8, 8, 2, 7, 4, 5, 15, NULL, 'Suminė R4 energija pagal 7 tarifą, fiksuojama kas parą', 301, 5, NULL, NULL),
	(2672, 3, 8, 8, 2, 8, 4, 5, 15, NULL, 'Suminė R4 energija pagal 8 tarifą, fiksuojama kas parą', 311, 5, NULL, NULL),
	(2673, 34, 1, 8, 2, 5, 41, 6, 45, NULL, 'Suminė W+ energija pagal 5 tarifą, fiksuojama kas mėnesį', 282, 5, NULL, NULL),
	(2674, 34, 1, 8, 2, 6, 41, 6, 45, NULL, 'Suminė W+ energija pagal 6 tarifą, fiksuojama kas mėnesį', 292, 5, NULL, NULL),
	(2675, 34, 1, 8, 2, 7, 41, 6, 45, NULL, 'Suminė W+ energija pagal 7 tarifą, fiksuojama kas mėnesį', 302, 5, NULL, NULL),
	(2676, 34, 1, 8, 2, 8, 41, 6, 45, NULL, 'Suminė W+ energija pagal 8 tarifą, fiksuojama kas mėnesį', 312, 5, NULL, NULL),
	(2677, 34, 1, 8, 2, 5, 41, 5, 45, NULL, 'Suminė W+ energija pagal 5 tarifą, fiksuojama kas parą', 282, 5, NULL, NULL),
	(2678, 34, 1, 8, 2, 6, 41, 5, 45, NULL, 'Suminė W+ energija pagal 6 tarifą, fiksuojama kas parą', 292, 5, NULL, NULL),
	(2679, 34, 1, 8, 2, 7, 41, 5, 45, NULL, 'Suminė W+ energija pagal 7 tarifą, fiksuojama kas parą', 302, 5, NULL, NULL),
	(2680, 34, 1, 8, 2, 8, 41, 5, 45, NULL, 'Suminė W+ energija pagal 8 tarifą, fiksuojama kas parą', 312, 5, NULL, NULL),
	(2681, 34, 2, 8, 2, 5, 41, 5, 45, NULL, 'Suminė W- energija pagal 5 tarifą, fiksuojama kas parą', 283, 5, NULL, NULL),
	(2682, 34, 2, 8, 2, 6, 41, 5, 45, NULL, 'Suminė W- energija pagal 6 tarifą, fiksuojama kas parą', 293, 5, NULL, NULL),
	(2683, 34, 2, 8, 2, 7, 41, 5, 45, NULL, 'Suminė W- energija pagal 7 tarifą, fiksuojama kas parą', 303, 5, NULL, NULL),
	(2684, 34, 2, 8, 2, 8, 41, 5, 45, NULL, 'Suminė W- energija pagal 8 tarifą, fiksuojama kas parą', 313, 5, NULL, NULL),
	(2685, 34, 2, 8, 2, 5, 41, 6, 45, NULL, 'Suminė W- energija pagal 5 tarifą, fiksuojama kas mėnesį', 283, 5, NULL, NULL),
	(2686, 34, 2, 8, 2, 6, 41, 6, 45, NULL, 'Suminė W- energija pagal 6 tarifą, fiksuojama kas mėnesį', 293, 5, NULL, NULL),
	(2687, 34, 2, 8, 2, 7, 41, 6, 45, NULL, 'Suminė W- energija pagal 7 tarifą, fiksuojama kas mėnesį', 303, 5, NULL, NULL),
	(2688, 34, 2, 8, 2, 8, 41, 6, 45, NULL, 'Suminė W- energija pagal 8 tarifą, fiksuojama kas mėnesį', 313, 5, NULL, NULL),
	(2689, 78, 0, 1, 3, 0, 8, 1, 91, NULL, 'Dažnio nukrypimas per minutę', 2300, 1, NULL, NULL),
	(2690, 79, 0, 1, 3, 0, 8, 1, 92, NULL, 'Dažnio nukrypimas L1 fazėje per minutę', 2301, 1, NULL, NULL),
	(2691, 82, 0, 1, 3, 0, 8, 1, 95, NULL, 'Dažnio nukrypimas L2 fazėje per minutę', 2302, 1, NULL, NULL),
	(2692, 85, 0, 1, 3, 0, 8, 1, 98, NULL, 'Dažnio nukrypimas L3 fazėje per minutę', 2303, 1, NULL, NULL),
	(2693, 120, 0, 1, 3, 0, 6, 1, 133, NULL, 'Susidaręs įtampos nukrypimas per minutę', 2304, 1, NULL, NULL),
	(2694, 121, 0, 1, 3, 0, 6, 1, 134, NULL, 'Susidaręs įtampos nukrypimas L1 fazėje per minutę', 2305, 1, NULL, NULL),
	(2695, 124, 0, 1, 3, 0, 6, 1, 137, NULL, 'Susidaręs įtampos nukrypimas L2 fazėje per minutę', 2306, 1, NULL, NULL),
	(2696, 127, 0, 1, 3, 0, 6, 1, 140, NULL, 'Susidaręs įtampos nukrypimas L3 fazėje per minutę', 2307, 1, NULL, NULL),
	(2697, 66, 0, 15, 3, 0, 9, 14, 79, NULL, 'Atvirkštinės sekos nesimetrijos koeficientas per 3 sekundes', 2308, 7, NULL, NULL),
	(2698, 69, 0, 15, 3, 0, 9, 14, 82, NULL, 'Nulinės sekos nesimetrijos koeficientas per 3 sekundes', 2309, 7, NULL, NULL),
	(2699, 111, 0, 15, 3, 0, 9, 14, 124, NULL, 'Sinusoidės iškreipimo koeficientas L1 fazėje per 3 sekundes', 2310, 7, NULL, NULL),
	(2700, 114, 0, 15, 3, 0, 9, 14, 127, NULL, 'Sinusoidės iškreipimo koeficientas L2 fazėje per 3 sekundes', 2311, 7, NULL, NULL),
	(2701, 117, 0, 15, 3, 0, 9, 14, 130, NULL, 'Sinusoidės iškreipimo koeficientas L3 fazėje per 3 sekundes', 2312, 7, NULL, NULL),
	(2702, 108, 0, 1, 3, 0, 6, 1, 121, NULL, 'Pagrindinės harmonikos dabartinė reikšmė L1 fazėje per minutę', 2313, 1, NULL, NULL),
	(2703, 109, 0, 1, 3, 0, 6, 1, 122, NULL, 'Pagrindinės harmonikos dabartinė reikšmė L2 fazėje per minutę', 2314, 1, NULL, NULL),
	(2704, 110, 0, 1, 3, 0, 6, 1, 123, NULL, 'Pagrindinės harmonikos dabartinė reikšmė L3 fazėje per minutę', 2315, 1, NULL, NULL),
	(2705, 90, 0, 1, 6, 0, 9, 1, 103, NULL, 'Įtampos 2-os harmonikos koeficientas L1 fazėje per minutę', 2316, 1, NULL, NULL),
	(2706, 93, 0, 1, 6, 0, 9, 1, 106, NULL, 'Įtampos 2-os harmonikos koeficientas L2 fazėje per minutę', 2317, 1, NULL, NULL),
	(2707, 96, 0, 1, 6, 0, 9, 1, 109, NULL, 'Įtampos 2-os harmonikos koeficientas L3 fazėje per minutę', 2318, 1, NULL, NULL),
	(2708, 90, 0, 1, 7, 0, 9, 1, 103, NULL, 'Įtampos 3-os harmonikos koeficientas L1 fazėje per minutę', 2319, 1, NULL, NULL),
	(2709, 93, 0, 1, 7, 0, 9, 1, 106, NULL, 'Įtampos 3-os harmonikos koeficientas L2 fazėje per minutę', 2320, 1, NULL, NULL),
	(2710, 96, 0, 1, 7, 0, 9, 1, 109, NULL, 'Įtampos 3-os harmonikos koeficientas L3 fazėje per minutę', 2321, 1, NULL, NULL),
	(2711, 90, 0, 1, 8, 0, 9, 1, 103, NULL, 'Įtampos 4-os harmonikos koeficientas L1 fazėje per minutę', 2322, 1, NULL, NULL),
	(2712, 93, 0, 1, 8, 0, 9, 1, 106, NULL, 'Įtampos 4-os harmonikos koeficientas L2 fazėje per minutę', 2323, 1, NULL, NULL),
	(2713, 96, 0, 1, 8, 0, 9, 1, 109, NULL, 'Įtampos 4-os harmonikos koeficientas L3 fazėje per minutę', 2324, 1, NULL, NULL),
	(2714, 90, 0, 1, 9, 0, 9, 1, 103, NULL, 'Įtampos 5-os harmonikos koeficientas L1 fazėje per minutę', 2325, 1, NULL, NULL),
	(2715, 93, 0, 1, 9, 0, 9, 1, 106, NULL, 'Įtampos 5-os harmonikos koeficientas L2 fazėje per minutę', 2326, 1, NULL, NULL),
	(2716, 96, 0, 1, 9, 0, 9, 1, 109, NULL, 'Įtampos 5-os harmonikos koeficientas L3 fazėje per minutę', 2327, 1, NULL, NULL),
	(2717, 90, 0, 1, 10, 0, 9, 1, 103, NULL, 'Įtampos 6-os harmonikos koeficientas L1 fazėje per minutę', 2328, 1, NULL, NULL),
	(2718, 93, 0, 1, 10, 0, 9, 1, 106, NULL, 'Įtampos 6-os harmonikos koeficientas L2 fazėje per minutę', 2329, 1, NULL, NULL),
	(2719, 96, 0, 1, 10, 0, 9, 1, 109, NULL, 'Įtampos 6-os harmonikos koeficientas L3 fazėje per minutę', 2330, 1, NULL, NULL),
	(2720, 90, 0, 1, 11, 0, 9, 1, 103, NULL, 'Įtampos 7-os harmonikos koeficientas L1 fazėje per minutę', 2331, 1, NULL, NULL),
	(2721, 93, 0, 1, 11, 0, 9, 1, 106, NULL, 'Įtampos 7-os harmonikos koeficientas L2 fazėje per minutę', 2332, 1, NULL, NULL),
	(2722, 96, 0, 1, 11, 0, 9, 1, 109, NULL, 'Įtampos 7-os harmonikos koeficientas L3 fazėje per minutę', 2333, 1, NULL, NULL),
	(2723, 90, 0, 1, 12, 0, 9, 1, 103, NULL, 'Įtampos 8-os harmonikos koeficientas L1 fazėje per minutę', 2334, 1, NULL, NULL),
	(2724, 93, 0, 1, 12, 0, 9, 1, 106, NULL, 'Įtampos 8-os harmonikos koeficientas L2 fazėje per minutę', 2335, 1, NULL, NULL),
	(2725, 96, 0, 1, 12, 0, 9, 1, 109, NULL, 'Įtampos 8-os harmonikos koeficientas L3 fazėje per minutę', 2336, 1, NULL, NULL),
	(2726, 90, 0, 1, 13, 0, 9, 1, 103, NULL, 'Įtampos 9-os harmonikos koeficientas L1 fazėje per minutę', 2337, 1, NULL, NULL),
	(2727, 93, 0, 1, 13, 0, 9, 1, 106, NULL, 'Įtampos 9-os harmonikos koeficientas L2 fazėje per minutę', 2338, 1, NULL, NULL),
	(2728, 96, 0, 1, 13, 0, 9, 1, 109, NULL, 'Įtampos 9-os harmonikos koeficientas L3 fazėje per minutę', 2339, 1, NULL, NULL),
	(2729, 90, 0, 1, 14, 0, 9, 1, 103, NULL, 'Įtampos 10-os harmonikos koeficientas L1 fazėje per minutę', 2340, 1, NULL, NULL),
	(2730, 93, 0, 1, 14, 0, 9, 1, 106, NULL, 'Įtampos 10-os harmonikos koeficientas L2 fazėje per minutę', 2341, 1, NULL, NULL),
	(2731, 96, 0, 1, 14, 0, 9, 1, 109, NULL, 'Įtampos 10-os harmonikos koeficientas L3 fazėje per minutę', 2342, 1, NULL, NULL),
	(2732, 90, 0, 1, 15, 0, 9, 1, 103, NULL, 'Įtampos 11-os harmonikos koeficientas L1 fazėje per minutę', 2343, 1, NULL, NULL),
	(2733, 93, 0, 1, 15, 0, 9, 1, 106, NULL, 'Įtampos 11-os harmonikos koeficientas L2 fazėje per minutę', 2344, 1, NULL, NULL),
	(2734, 96, 0, 1, 15, 0, 9, 1, 109, NULL, 'Įtampos 11-os harmonikos koeficientas L3 fazėje per minutę', 2345, 1, NULL, NULL),
	(2735, 90, 0, 1, 16, 0, 9, 1, 103, NULL, 'Įtampos 12-os harmonikos koeficientas L1 fazėje per minutę', 2346, 1, NULL, NULL),
	(2736, 93, 0, 1, 16, 0, 9, 1, 106, NULL, 'Įtampos 12-os harmonikos koeficientas L2 fazėje per minutę', 2347, 1, NULL, NULL),
	(2737, 96, 0, 1, 16, 0, 9, 1, 109, NULL, 'Įtampos 12-os harmonikos koeficientas L3 fazėje per minutę', 2348, 1, NULL, NULL),
	(2738, 90, 0, 1, 17, 0, 9, 1, 103, NULL, 'Įtampos 13-os harmonikos koeficientas L1 fazėje per minutę', 2349, 1, NULL, NULL),
	(2739, 93, 0, 1, 17, 0, 9, 1, 106, NULL, 'Įtampos 13-os harmonikos koeficientas L2 fazėje per minutę', 2350, 1, NULL, NULL),
	(2740, 96, 0, 1, 17, 0, 9, 1, 109, NULL, 'Įtampos 13-os harmonikos koeficientas L3 fazėje per minutę', 2351, 1, NULL, NULL),
	(2741, 90, 0, 1, 18, 0, 9, 1, 103, NULL, 'Įtampos 14-os harmonikos koeficientas L1 fazėje per minutę', 2352, 1, NULL, NULL),
	(2742, 93, 0, 1, 18, 0, 9, 1, 106, NULL, 'Įtampos 14-os harmonikos koeficientas L2 fazėje per minutę', 2353, 1, NULL, NULL),
	(2743, 96, 0, 1, 18, 0, 9, 1, 109, NULL, 'Įtampos 14-os harmonikos koeficientas L3 fazėje per minutę', 2354, 1, NULL, NULL),
	(2744, 90, 0, 1, 19, 0, 9, 1, 103, NULL, 'Įtampos 15-os harmonikos koeficientas L1 fazėje per minutę', 2355, 1, NULL, NULL),
	(2745, 93, 0, 1, 19, 0, 9, 1, 106, NULL, 'Įtampos 15-os harmonikos koeficientas L2 fazėje per minutę', 2356, 1, NULL, NULL),
	(2746, 96, 0, 1, 19, 0, 9, 1, 109, NULL, 'Įtampos 15-os harmonikos koeficientas L3 fazėje per minutę', 2357, 1, NULL, NULL),
	(2747, 90, 0, 1, 20, 0, 9, 1, 103, NULL, 'Įtampos 16-os harmonikos koeficientas L1 fazėje per minutę', 2358, 1, NULL, NULL),
	(2748, 93, 0, 1, 20, 0, 9, 1, 106, NULL, 'Įtampos 16-os harmonikos koeficientas L2 fazėje per minutę', 2359, 1, NULL, NULL),
	(2749, 96, 0, 1, 20, 0, 9, 1, 109, NULL, 'Įtampos 16-os harmonikos koeficientas L3 fazėje per minutę', 2360, 1, NULL, NULL),
	(2750, 90, 0, 1, 21, 0, 9, 1, 103, NULL, 'Įtampos 17-os harmonikos koeficientas L1 fazėje per minutę', 2361, 1, NULL, NULL),
	(2751, 93, 0, 1, 21, 0, 9, 1, 106, NULL, 'Įtampos 17-os harmonikos koeficientas L2 fazėje per minutę', 2362, 1, NULL, NULL),
	(2752, 96, 0, 1, 21, 0, 9, 1, 109, NULL, 'Įtampos 17-os harmonikos koeficientas L3 fazėje per minutę', 2363, 1, NULL, NULL),
	(2753, 90, 0, 1, 22, 0, 9, 1, 103, NULL, 'Įtampos 18-os harmonikos koeficientas L1 fazėje per minutę', 2364, 1, NULL, NULL),
	(2754, 93, 0, 1, 22, 0, 9, 1, 106, NULL, 'Įtampos 18-os harmonikos koeficientas L2 fazėje per minutę', 2365, 1, NULL, NULL),
	(2755, 96, 0, 1, 22, 0, 9, 1, 109, NULL, 'Įtampos 18-os harmonikos koeficientas L3 fazėje per minutę', 2366, 1, NULL, NULL),
	(2756, 90, 0, 1, 23, 0, 9, 1, 103, NULL, 'Įtampos 19-os harmonikos koeficientas L1 fazėje per minutę', 2367, 1, NULL, NULL),
	(2757, 93, 0, 1, 23, 0, 9, 1, 106, NULL, 'Įtampos 19-os harmonikos koeficientas L2 fazėje per minutę', 2368, 1, NULL, NULL),
	(2758, 96, 0, 1, 23, 0, 9, 1, 109, NULL, 'Įtampos 19-os harmonikos koeficientas L3 fazėje per minutę', 2369, 1, NULL, NULL),
	(2759, 90, 0, 1, 24, 0, 9, 1, 103, NULL, 'Įtampos 20-os harmonikos koeficientas L1 fazėje per minutę', 2370, 1, NULL, NULL),
	(2760, 93, 0, 1, 24, 0, 9, 1, 106, NULL, 'Įtampos 20-os harmonikos koeficientas L2 fazėje per minutę', 2371, 1, NULL, NULL),
	(2761, 96, 0, 1, 24, 0, 9, 1, 109, NULL, 'Įtampos 20-os harmonikos koeficientas L3 fazėje per minutę', 2372, 1, NULL, NULL),
	(2762, 90, 0, 1, 25, 0, 9, 1, 103, NULL, 'Įtampos 21-os harmonikos koeficientas L1 fazėje per minutę', 2373, 1, NULL, NULL),
	(2763, 93, 0, 1, 25, 0, 9, 1, 106, NULL, 'Įtampos 21-os harmonikos koeficientas L2 fazėje per minutę', 2374, 1, NULL, NULL),
	(2764, 96, 0, 1, 25, 0, 9, 1, 109, NULL, 'Įtampos 21-os harmonikos koeficientas L3 fazėje per minutę', 2375, 1, NULL, NULL),
	(2765, 90, 0, 1, 26, 0, 9, 1, 103, NULL, 'Įtampos 22-os harmonikos koeficientas L1 fazėje per minutę', 2376, 1, NULL, NULL),
	(2766, 93, 0, 1, 26, 0, 9, 1, 106, NULL, 'Įtampos 22-os harmonikos koeficientas L2 fazėje per minutę', 2377, 1, NULL, NULL),
	(2767, 96, 0, 1, 26, 0, 9, 1, 109, NULL, 'Įtampos 22-os harmonikos koeficientas L3 fazėje per minutę', 2378, 1, NULL, NULL),
	(2768, 90, 0, 1, 27, 0, 9, 1, 103, NULL, 'Įtampos 23-os harmonikos koeficientas L1 fazėje per minutę', 2379, 1, NULL, NULL),
	(2769, 93, 0, 1, 27, 0, 9, 1, 106, NULL, 'Įtampos 23-os harmonikos koeficientas L2 fazėje per minutę', 2380, 1, NULL, NULL),
	(2770, 96, 0, 1, 27, 0, 9, 1, 109, NULL, 'Įtampos 23-os harmonikos koeficientas L3 fazėje per minutę', 2381, 1, NULL, NULL),
	(2771, 90, 0, 1, 28, 0, 9, 1, 103, NULL, 'Įtampos 24-os harmonikos koeficientas L1 fazėje per minutę', 2382, 1, NULL, NULL),
	(2772, 93, 0, 1, 28, 0, 9, 1, 106, NULL, 'Įtampos 24-os harmonikos koeficientas L2 fazėje per minutę', 2383, 1, NULL, NULL),
	(2773, 96, 0, 1, 28, 0, 9, 1, 109, NULL, 'Įtampos 24-os harmonikos koeficientas L3 fazėje per minutę', 2384, 1, NULL, NULL),
	(2774, 90, 0, 1, 29, 0, 9, 1, 103, NULL, 'Įtampos 25-os harmonikos koeficientas L1 fazėje per minutę', 2385, 1, NULL, NULL),
	(2775, 93, 0, 1, 29, 0, 9, 1, 106, NULL, 'Įtampos 25-os harmonikos koeficientas L2 fazėje per minutę', 2386, 1, NULL, NULL),
	(2776, 96, 0, 1, 29, 0, 9, 1, 109, NULL, 'Įtampos 25-os harmonikos koeficientas L3 fazėje per minutę', 2387, 1, NULL, NULL),
	(2777, 90, 0, 1, 30, 0, 9, 1, 103, NULL, 'Įtampos 26-os harmonikos koeficientas L1 fazėje per minutę', 2388, 1, NULL, NULL),
	(2778, 93, 0, 1, 30, 0, 9, 1, 106, NULL, 'Įtampos 26-os harmonikos koeficientas L2 fazėje per minutę', 2389, 1, NULL, NULL),
	(2779, 96, 0, 1, 30, 0, 9, 1, 109, NULL, 'Įtampos 26-os harmonikos koeficientas L3 fazėje per minutę', 2390, 1, NULL, NULL),
	(2780, 90, 0, 1, 31, 0, 9, 1, 103, NULL, 'Įtampos 27-os harmonikos koeficientas L1 fazėje per minutę', 2391, 1, NULL, NULL),
	(2781, 93, 0, 1, 31, 0, 9, 1, 106, NULL, 'Įtampos 27-os harmonikos koeficientas L2 fazėje per minutę', 2392, 1, NULL, NULL),
	(2782, 96, 0, 1, 31, 0, 9, 1, 109, NULL, 'Įtampos 27-os harmonikos koeficientas L3 fazėje per minutę', 2393, 1, NULL, NULL),
	(2783, 90, 0, 1, 32, 0, 9, 1, 103, NULL, 'Įtampos 28-os harmonikos koeficientas L1 fazėje per minutę', 2394, 1, NULL, NULL),
	(2784, 93, 0, 1, 32, 0, 9, 1, 106, NULL, 'Įtampos 28-os harmonikos koeficientas L2 fazėje per minutę', 2395, 1, NULL, NULL),
	(2785, 96, 0, 1, 32, 0, 9, 1, 109, NULL, 'Įtampos 28-os harmonikos koeficientas L3 fazėje per minutę', 2396, 1, NULL, NULL),
	(2786, 90, 0, 1, 33, 0, 9, 1, 103, NULL, 'Įtampos 29-os harmonikos koeficientas L1 fazėje per minutę', 2397, 1, NULL, NULL),
	(2787, 93, 0, 1, 33, 0, 9, 1, 106, NULL, 'Įtampos 29-os harmonikos koeficientas L2 fazėje per minutę', 2398, 1, NULL, NULL),
	(2788, 96, 0, 1, 33, 0, 9, 1, 109, NULL, 'Įtampos 29-os harmonikos koeficientas L3 fazėje per minutę', 2399, 1, NULL, NULL),
	(2789, 90, 0, 1, 34, 0, 9, 1, 103, NULL, 'Įtampos 30-os harmonikos koeficientas L1 fazėje per minutę', 2400, 1, NULL, NULL),
	(2790, 93, 0, 1, 34, 0, 9, 1, 106, NULL, 'Įtampos 30-os harmonikos koeficientas L2 fazėje per minutę', 2401, 1, NULL, NULL),
	(2791, 96, 0, 1, 34, 0, 9, 1, 109, NULL, 'Įtampos 30-os harmonikos koeficientas L3 fazėje per minutę', 2402, 1, NULL, NULL),
	(2792, 90, 0, 1, 35, 0, 9, 1, 103, NULL, 'Įtampos 31-os harmonikos koeficientas L1 fazėje per minutę', 2403, 1, NULL, NULL),
	(2793, 93, 0, 1, 35, 0, 9, 1, 106, NULL, 'Įtampos 31-os harmonikos koeficientas L2 fazėje per minutę', 2404, 1, NULL, NULL),
	(2794, 96, 0, 1, 35, 0, 9, 1, 109, NULL, 'Įtampos 31-os harmonikos koeficientas L3 fazėje per minutę', 2405, 1, NULL, NULL),
	(2795, 90, 0, 1, 36, 0, 9, 1, 103, NULL, 'Įtampos 32-os harmonikos koeficientas L1 fazėje per minutę', 2406, 1, NULL, NULL),
	(2796, 93, 0, 1, 36, 0, 9, 1, 106, NULL, 'Įtampos 32-os harmonikos koeficientas L2 fazėje per minutę', 2407, 1, NULL, NULL),
	(2797, 96, 0, 1, 36, 0, 9, 1, 109, NULL, 'Įtampos 32-os harmonikos koeficientas L3 fazėje per minutę', 2408, 1, NULL, NULL),
	(2798, 90, 0, 1, 37, 0, 9, 1, 103, NULL, 'Įtampos 33-os harmonikos koeficientas L1 fazėje per minutę', 2409, 1, NULL, NULL),
	(2799, 93, 0, 1, 37, 0, 9, 1, 106, NULL, 'Įtampos 33-os harmonikos koeficientas L2 fazėje per minutę', 2410, 1, NULL, NULL),
	(2800, 96, 0, 1, 37, 0, 9, 1, 109, NULL, 'Įtampos 33-os harmonikos koeficientas L3 fazėje per minutę', 2411, 1, NULL, NULL),
	(2801, 90, 0, 1, 38, 0, 9, 1, 103, NULL, 'Įtampos 34-os harmonikos koeficientas L1 fazėje per minutę', 2412, 1, NULL, NULL),
	(2802, 93, 0, 1, 38, 0, 9, 1, 106, NULL, 'Įtampos 34-os harmonikos koeficientas L2 fazėje per minutę', 2413, 1, NULL, NULL),
	(2803, 96, 0, 1, 38, 0, 9, 1, 109, NULL, 'Įtampos 34-os harmonikos koeficientas L3 fazėje per minutę', 2414, 1, NULL, NULL),
	(2804, 90, 0, 1, 39, 0, 9, 1, 103, NULL, 'Įtampos 35-os harmonikos koeficientas L1 fazėje per minutę', 2415, 1, NULL, NULL),
	(2805, 93, 0, 1, 39, 0, 9, 1, 106, NULL, 'Įtampos 35-os harmonikos koeficientas L2 fazėje per minutę', 2416, 1, NULL, NULL),
	(2806, 96, 0, 1, 39, 0, 9, 1, 109, NULL, 'Įtampos 35-os harmonikos koeficientas L3 fazėje per minutę', 2417, 1, NULL, NULL),
	(2807, 90, 0, 1, 40, 0, 9, 1, 103, NULL, 'Įtampos 36-os harmonikos koeficientas L1 fazėje per minutę', 2418, 1, NULL, NULL),
	(2808, 93, 0, 1, 40, 0, 9, 1, 106, NULL, 'Įtampos 36-os harmonikos koeficientas L2 fazėje per minutę', 2419, 1, NULL, NULL),
	(2809, 96, 0, 1, 40, 0, 9, 1, 109, NULL, 'Įtampos 36-os harmonikos koeficientas L3 fazėje per minutę', 2420, 1, NULL, NULL),
	(2810, 90, 0, 1, 41, 0, 9, 1, 103, NULL, 'Įtampos 37-os harmonikos koeficientas L1 fazėje per minutę', 2421, 1, NULL, NULL),
	(2811, 93, 0, 1, 41, 0, 9, 1, 106, NULL, 'Įtampos 37-os harmonikos koeficientas L2 fazėje per minutę', 2422, 1, NULL, NULL),
	(2812, 96, 0, 1, 41, 0, 9, 1, 109, NULL, 'Įtampos 37-os harmonikos koeficientas L3 fazėje per minutę', 2423, 1, NULL, NULL),
	(2813, 90, 0, 1, 42, 0, 9, 1, 103, NULL, 'Įtampos 38-os harmonikos koeficientas L1 fazėje per minutę', 2424, 1, NULL, NULL),
	(2814, 93, 0, 1, 42, 0, 9, 1, 106, NULL, 'Įtampos 38-os harmonikos koeficientas L2 fazėje per minutę', 2425, 1, NULL, NULL),
	(2815, 96, 0, 1, 42, 0, 9, 1, 109, NULL, 'Įtampos 38-os harmonikos koeficientas L3 fazėje per minutę', 2426, 1, NULL, NULL),
	(2816, 90, 0, 1, 43, 0, 9, 1, 103, NULL, 'Įtampos 39-os harmonikos koeficientas L1 fazėje per minutę', 2427, 1, NULL, NULL),
	(2817, 93, 0, 1, 43, 0, 9, 1, 106, NULL, 'Įtampos 39-os harmonikos koeficientas L2 fazėje per minutę', 2428, 1, NULL, NULL),
	(2818, 96, 0, 1, 43, 0, 9, 1, 109, NULL, 'Įtampos 39-os harmonikos koeficientas L3 fazėje per minutę', 2429, 1, NULL, NULL),
	(2819, 90, 0, 1, 44, 0, 9, 1, 103, NULL, 'Įtampos 40-os harmonikos koeficientas L1 fazėje per minutę', 2430, 1, NULL, NULL),
	(2820, 93, 0, 1, 44, 0, 9, 1, 106, NULL, 'Įtampos 40-os harmonikos koeficientas L2 fazėje per minutę', 2431, 1, NULL, NULL),
	(2821, 96, 0, 1, 44, 0, 9, 1, 109, NULL, 'Įtampos 40-os harmonikos koeficientas L3 fazėje per minutę', 2432, 1, NULL, NULL),
	(2822, 72, 0, 1, 3, 0, 0, 1, 85, NULL, 'Trumpalaikė mirksėjimo dozė L1 fazėje per minutę', 2433, 1, NULL, NULL),
	(2823, 74, 0, 1, 3, 0, 0, 1, 87, NULL, 'Trumpalaikė mirksėjimo dozė L2 fazėje per minutę', 2434, 1, NULL, NULL),
	(2824, 76, 0, 1, 3, 0, 0, 1, 89, NULL, 'Trumpalaikė mirksėjimo dozė L3 fazėje per minutę', 2435, 1, NULL, NULL),
	(2825, 130, 0, 1, 3, 0, 9, 1, 143, NULL, 'Įtampos pakeitimų diapazono amplitudė L1 fazėje per minutę', 2436, 1, NULL, NULL),
	(2826, 132, 0, 1, 3, 0, 9, 1, 145, NULL, 'Įtampos pakeitimų diapazono amplitudė L2 fazėje per minutę', 2437, 1, NULL, NULL),
	(2827, 134, 0, 1, 3, 0, 9, 1, 147, NULL, 'Įtampos pakeitimų diapazono amplitudė L3 fazėje per minutę', 2438, 1, NULL, NULL),
	(2828, 136, 0, 1, 3, 0, 9, 1, 149, NULL, 'Įtampos pakeitimų diapazono kartojimų dažnis L1 fazėje per minutę', 2439, 1, NULL, NULL),
	(2829, 137, 0, 1, 3, 0, 9, 1, 150, NULL, 'Įtampos pakeitimų diapazono kartojimų dažnis L2 fazėje per minutę', 2440, 1, NULL, NULL),
	(2830, 138, 0, 1, 3, 0, 9, 1, 151, NULL, 'Įtampos pakeitimų diapazono kartojimų dažnis L3 fazėje per minutę', 2441, 1, NULL, NULL),
	(2831, 102, 0, 1, 3, 0, 0, 1, 115, NULL, 'Ilgalaikė mirksėjimo dozė L1 fazėje per minutę', 2442, 1, NULL, NULL),
	(2832, 104, 0, 1, 3, 0, 0, 1, 117, NULL, 'Ilgalaikė mirksėjimo dozė L2 fazėje per minutę', 2443, 1, NULL, NULL),
	(2833, 106, 0, 1, 3, 0, 0, 1, 119, NULL, 'Ilgalaikė mirksėjimo dozė L3 fazėje per minutę', 2444, 1, NULL, NULL),
	(2834, 99, 0, 15, 6, 0, 9, 14, 112, NULL, '02-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2445, 7, NULL, NULL),
	(2835, 99, 0, 15, 7, 0, 9, 14, 112, NULL, '03-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2446, 7, NULL, NULL),
	(2836, 99, 0, 15, 8, 0, 9, 14, 112, NULL, '04-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2447, 7, NULL, NULL),
	(2837, 99, 0, 15, 9, 0, 9, 14, 112, NULL, '05-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2448, 7, NULL, NULL),
	(2838, 99, 0, 15, 10, 0, 9, 14, 112, NULL, '06-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2449, 7, NULL, NULL),
	(2839, 99, 0, 15, 11, 0, 9, 14, 112, NULL, '07-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2450, 7, NULL, NULL),
	(2840, 99, 0, 15, 12, 0, 9, 14, 112, NULL, '08-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2451, 7, NULL, NULL),
	(2841, 99, 0, 15, 13, 0, 9, 14, 112, NULL, '09-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2452, 7, NULL, NULL),
	(2842, 99, 0, 15, 14, 0, 9, 14, 112, NULL, '10-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2453, 7, NULL, NULL),
	(2843, 99, 0, 15, 15, 0, 9, 14, 112, NULL, '11-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2454, 7, NULL, NULL),
	(2844, 99, 0, 15, 16, 0, 9, 14, 112, NULL, '12-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2455, 7, NULL, NULL),
	(2845, 99, 0, 15, 17, 0, 9, 14, 112, NULL, '13-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2456, 7, NULL, NULL),
	(2846, 99, 0, 15, 18, 0, 9, 14, 112, NULL, '14-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2457, 7, NULL, NULL),
	(2847, 99, 0, 15, 19, 0, 9, 14, 112, NULL, '15-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2458, 7, NULL, NULL),
	(2848, 99, 0, 15, 20, 0, 9, 14, 112, NULL, '16-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2459, 7, NULL, NULL),
	(2849, 99, 0, 15, 21, 0, 9, 14, 112, NULL, '17-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2460, 7, NULL, NULL),
	(2850, 99, 0, 15, 22, 0, 9, 14, 112, NULL, '18-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2461, 7, NULL, NULL),
	(2851, 99, 0, 15, 23, 0, 9, 14, 112, NULL, '19-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2462, 7, NULL, NULL),
	(2852, 99, 0, 15, 24, 0, 9, 14, 112, NULL, '20-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2463, 7, NULL, NULL),
	(2853, 99, 0, 15, 25, 0, 9, 14, 112, NULL, '21-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2464, 7, NULL, NULL),
	(2854, 99, 0, 15, 26, 0, 9, 14, 112, NULL, '22-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2465, 7, NULL, NULL),
	(2855, 99, 0, 15, 27, 0, 9, 14, 112, NULL, '23-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2466, 7, NULL, NULL),
	(2856, 99, 0, 15, 28, 0, 9, 14, 112, NULL, '24-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2467, 7, NULL, NULL),
	(2857, 99, 0, 15, 29, 0, 9, 14, 112, NULL, '25-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2468, 7, NULL, NULL),
	(2858, 99, 0, 15, 30, 0, 9, 14, 112, NULL, '26-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2469, 7, NULL, NULL),
	(2859, 99, 0, 15, 31, 0, 9, 14, 112, NULL, '27-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2470, 7, NULL, NULL),
	(2860, 99, 0, 15, 32, 0, 9, 14, 112, NULL, '28-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2471, 7, NULL, NULL),
	(2861, 99, 0, 15, 33, 0, 9, 14, 112, NULL, '29-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2472, 7, NULL, NULL),
	(2862, 99, 0, 15, 34, 0, 9, 14, 112, NULL, '30-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2473, 7, NULL, NULL),
	(2863, 99, 0, 15, 35, 0, 9, 14, 112, NULL, '31-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2474, 7, NULL, NULL),
	(2864, 99, 0, 15, 36, 0, 9, 14, 112, NULL, '32-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2475, 7, NULL, NULL),
	(2865, 99, 0, 15, 37, 0, 9, 14, 112, NULL, '33-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2476, 7, NULL, NULL),
	(2866, 99, 0, 15, 38, 0, 9, 14, 112, NULL, '34-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2477, 7, NULL, NULL),
	(2867, 99, 0, 15, 39, 0, 9, 14, 112, NULL, '35-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2478, 7, NULL, NULL),
	(2868, 99, 0, 15, 40, 0, 9, 14, 112, NULL, '36-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2479, 7, NULL, NULL),
	(2869, 99, 0, 15, 41, 0, 9, 14, 112, NULL, '37-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2480, 7, NULL, NULL),
	(2870, 99, 0, 15, 42, 0, 9, 14, 112, NULL, '38-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2481, 7, NULL, NULL),
	(2871, 99, 0, 15, 43, 0, 9, 14, 112, NULL, '39-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2482, 7, NULL, NULL),
	(2872, 99, 0, 15, 44, 0, 9, 14, 112, NULL, '40-os harmonikos koeficiento kokybė L1 fazėje per 3 sekundes', 2483, 7, NULL, NULL),
	(2873, 100, 0, 15, 6, 0, 9, 14, 113, NULL, '02-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2484, 7, NULL, NULL),
	(2874, 100, 0, 15, 7, 0, 9, 14, 113, NULL, '03-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2485, 7, NULL, NULL),
	(2875, 100, 0, 15, 8, 0, 9, 14, 113, NULL, '04-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2486, 7, NULL, NULL),
	(2876, 100, 0, 15, 9, 0, 9, 14, 113, NULL, '05-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2487, 7, NULL, NULL),
	(2877, 100, 0, 15, 10, 0, 9, 14, 113, NULL, '06-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2488, 7, NULL, NULL),
	(2878, 100, 0, 15, 11, 0, 9, 14, 113, NULL, '07-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2489, 7, NULL, NULL),
	(2879, 100, 0, 15, 12, 0, 9, 14, 113, NULL, '08-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2490, 7, NULL, NULL),
	(2880, 100, 0, 15, 13, 0, 9, 14, 113, NULL, '09-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2491, 7, NULL, NULL),
	(2881, 100, 0, 15, 14, 0, 9, 14, 113, NULL, '10-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2492, 7, NULL, NULL),
	(2882, 100, 0, 15, 15, 0, 9, 14, 113, NULL, '11-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2493, 7, NULL, NULL),
	(2883, 100, 0, 15, 16, 0, 9, 14, 113, NULL, '12-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2494, 7, NULL, NULL),
	(2884, 100, 0, 15, 17, 0, 9, 14, 113, NULL, '13-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2495, 7, NULL, NULL),
	(2885, 100, 0, 15, 18, 0, 9, 14, 113, NULL, '14-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2496, 7, NULL, NULL),
	(2886, 100, 0, 15, 19, 0, 9, 14, 113, NULL, '15-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2497, 7, NULL, NULL),
	(2887, 100, 0, 15, 20, 0, 9, 14, 113, NULL, '16-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2498, 7, NULL, NULL),
	(2888, 100, 0, 15, 21, 0, 9, 14, 113, NULL, '17-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2499, 7, NULL, NULL),
	(2889, 100, 0, 15, 22, 0, 9, 14, 113, NULL, '18-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2500, 7, NULL, NULL),
	(2890, 100, 0, 15, 23, 0, 9, 14, 113, NULL, '19-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2501, 7, NULL, NULL),
	(2891, 100, 0, 15, 24, 0, 9, 14, 113, NULL, '20-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2502, 7, NULL, NULL),
	(2892, 100, 0, 15, 25, 0, 9, 14, 113, NULL, '21-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2503, 7, NULL, NULL),
	(2893, 100, 0, 15, 26, 0, 9, 14, 113, NULL, '22-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2504, 7, NULL, NULL),
	(2894, 100, 0, 15, 27, 0, 9, 14, 113, NULL, '23-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2505, 7, NULL, NULL),
	(2895, 100, 0, 15, 28, 0, 9, 14, 113, NULL, '24-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2506, 7, NULL, NULL),
	(2896, 100, 0, 15, 29, 0, 9, 14, 113, NULL, '25-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2507, 7, NULL, NULL),
	(2897, 100, 0, 15, 30, 0, 9, 14, 113, NULL, '26-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2508, 7, NULL, NULL),
	(2898, 100, 0, 15, 31, 0, 9, 14, 113, NULL, '27-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2509, 7, NULL, NULL),
	(2899, 100, 0, 15, 32, 0, 9, 14, 113, NULL, '28-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2510, 7, NULL, NULL),
	(2900, 100, 0, 15, 33, 0, 9, 14, 113, NULL, '29-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2511, 7, NULL, NULL),
	(2901, 100, 0, 15, 34, 0, 9, 14, 113, NULL, '30-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2512, 7, NULL, NULL),
	(2902, 100, 0, 15, 35, 0, 9, 14, 113, NULL, '31-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2513, 7, NULL, NULL),
	(2903, 100, 0, 15, 36, 0, 9, 14, 113, NULL, '32-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2514, 7, NULL, NULL),
	(2904, 100, 0, 15, 37, 0, 9, 14, 113, NULL, '33-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2515, 7, NULL, NULL),
	(2905, 100, 0, 15, 38, 0, 9, 14, 113, NULL, '34-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2516, 7, NULL, NULL),
	(2906, 100, 0, 15, 39, 0, 9, 14, 113, NULL, '35-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2517, 7, NULL, NULL),
	(2907, 100, 0, 15, 40, 0, 9, 14, 113, NULL, '36-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2518, 7, NULL, NULL),
	(2908, 100, 0, 15, 41, 0, 9, 14, 113, NULL, '37-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2519, 7, NULL, NULL),
	(2909, 100, 0, 15, 42, 0, 9, 14, 113, NULL, '38-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2520, 7, NULL, NULL),
	(2910, 100, 0, 15, 43, 0, 9, 14, 113, NULL, '39-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2521, 7, NULL, NULL),
	(2911, 100, 0, 15, 44, 0, 9, 14, 113, NULL, '40-os harmonikos koeficiento kokybė L2 fazėje per 3 sekundes', 2522, 7, NULL, NULL),
	(2912, 101, 0, 15, 6, 0, 9, 14, 114, NULL, '02-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2523, 7, NULL, NULL),
	(2913, 101, 0, 15, 7, 0, 9, 14, 114, NULL, '03-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2524, 7, NULL, NULL),
	(2914, 101, 0, 15, 8, 0, 9, 14, 114, NULL, '04-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2525, 7, NULL, NULL),
	(2915, 101, 0, 15, 9, 0, 9, 14, 114, NULL, '05-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2526, 7, NULL, NULL),
	(2916, 101, 0, 15, 10, 0, 9, 14, 114, NULL, '06-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2527, 7, NULL, NULL),
	(2917, 101, 0, 15, 11, 0, 9, 14, 114, NULL, '07-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2528, 7, NULL, NULL),
	(2918, 101, 0, 15, 12, 0, 9, 14, 114, NULL, '08-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2529, 7, NULL, NULL),
	(2919, 101, 0, 15, 13, 0, 9, 14, 114, NULL, '09-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2530, 7, NULL, NULL),
	(2920, 101, 0, 15, 14, 0, 9, 14, 114, NULL, '10-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2531, 7, NULL, NULL),
	(2921, 101, 0, 15, 15, 0, 9, 14, 114, NULL, '11-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2532, 7, NULL, NULL),
	(2922, 101, 0, 15, 16, 0, 9, 14, 114, NULL, '12-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2533, 7, NULL, NULL),
	(2923, 101, 0, 15, 17, 0, 9, 14, 114, NULL, '13-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2534, 7, NULL, NULL),
	(2924, 101, 0, 15, 18, 0, 9, 14, 114, NULL, '14-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2535, 7, NULL, NULL),
	(2925, 101, 0, 15, 19, 0, 9, 14, 114, NULL, '15-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2536, 7, NULL, NULL),
	(2926, 101, 0, 15, 20, 0, 9, 14, 114, NULL, '16-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2537, 7, NULL, NULL),
	(2927, 101, 0, 15, 21, 0, 9, 14, 114, NULL, '17-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2538, 7, NULL, NULL),
	(2928, 101, 0, 15, 22, 0, 9, 14, 114, NULL, '18-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2539, 7, NULL, NULL),
	(2929, 101, 0, 15, 23, 0, 9, 14, 114, NULL, '19-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2540, 7, NULL, NULL),
	(2930, 101, 0, 15, 24, 0, 9, 14, 114, NULL, '20-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2541, 7, NULL, NULL),
	(2931, 101, 0, 15, 25, 0, 9, 14, 114, NULL, '21-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2542, 7, NULL, NULL),
	(2932, 101, 0, 15, 26, 0, 9, 14, 114, NULL, '22-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2543, 7, NULL, NULL),
	(2933, 101, 0, 15, 27, 0, 9, 14, 114, NULL, '23-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2544, 7, NULL, NULL),
	(2934, 101, 0, 15, 28, 0, 9, 14, 114, NULL, '24-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2545, 7, NULL, NULL),
	(2935, 101, 0, 15, 29, 0, 9, 14, 114, NULL, '25-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2546, 7, NULL, NULL),
	(2936, 101, 0, 15, 30, 0, 9, 14, 114, NULL, '26-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2547, 7, NULL, NULL),
	(2937, 101, 0, 15, 31, 0, 9, 14, 114, NULL, '27-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2548, 7, NULL, NULL),
	(2938, 101, 0, 15, 32, 0, 9, 14, 114, NULL, '28-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2549, 7, NULL, NULL),
	(2939, 101, 0, 15, 33, 0, 9, 14, 114, NULL, '29-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2550, 7, NULL, NULL),
	(2940, 101, 0, 15, 34, 0, 9, 14, 114, NULL, '30-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2551, 7, NULL, NULL),
	(2941, 101, 0, 15, 35, 0, 9, 14, 114, NULL, '31-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2552, 7, NULL, NULL),
	(2942, 101, 0, 15, 36, 0, 9, 14, 114, NULL, '32-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2553, 7, NULL, NULL),
	(2943, 101, 0, 15, 37, 0, 9, 14, 114, NULL, '33-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2554, 7, NULL, NULL),
	(2944, 101, 0, 15, 38, 0, 9, 14, 114, NULL, '34-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2555, 7, NULL, NULL),
	(2945, 101, 0, 15, 39, 0, 9, 14, 114, NULL, '35-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2556, 7, NULL, NULL),
	(2946, 101, 0, 15, 40, 0, 9, 14, 114, NULL, '36-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2557, 7, NULL, NULL),
	(2947, 101, 0, 15, 41, 0, 9, 14, 114, NULL, '37-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2558, 7, NULL, NULL),
	(2948, 101, 0, 15, 42, 0, 9, 14, 114, NULL, '38-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2559, 7, NULL, NULL),
	(2949, 101, 0, 15, 43, 0, 9, 14, 114, NULL, '39-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2560, 7, NULL, NULL),
	(2950, 101, 0, 15, 44, 0, 9, 14, 114, NULL, '40-os harmonikos koeficiento kokybė L3 fazėje per 3 sekundes', 2561, 7, NULL, NULL),
	(2951, 92, 0, 5, 6, 2, 9, 5, 105, NULL, '02-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2562, 3, NULL, NULL),
	(2952, 92, 0, 5, 7, 2, 9, 5, 105, NULL, '03-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2563, 3, NULL, NULL),
	(2953, 92, 0, 5, 8, 2, 9, 5, 105, NULL, '04-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2564, 3, NULL, NULL),
	(2954, 92, 0, 5, 9, 2, 9, 5, 105, NULL, '05-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2565, 3, NULL, NULL),
	(2955, 92, 0, 5, 10, 2, 9, 5, 105, NULL, '06-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2566, 3, NULL, NULL),
	(2956, 92, 0, 5, 11, 2, 9, 5, 105, NULL, '07-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2567, 3, NULL, NULL),
	(2957, 92, 0, 5, 12, 2, 9, 5, 105, NULL, '08-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2568, 3, NULL, NULL),
	(2958, 92, 0, 5, 13, 2, 9, 5, 105, NULL, '09-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2569, 3, NULL, NULL),
	(2959, 92, 0, 5, 14, 2, 9, 5, 105, NULL, '10-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2570, 3, NULL, NULL),
	(2960, 92, 0, 5, 15, 2, 9, 5, 105, NULL, '11-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2571, 3, NULL, NULL),
	(2961, 92, 0, 5, 16, 2, 9, 5, 105, NULL, '12-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2572, 3, NULL, NULL),
	(2962, 92, 0, 5, 17, 2, 9, 5, 105, NULL, '13-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2573, 3, NULL, NULL),
	(2963, 92, 0, 5, 18, 2, 9, 5, 105, NULL, '14-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2574, 3, NULL, NULL),
	(2964, 92, 0, 5, 19, 2, 9, 5, 105, NULL, '15-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2575, 3, NULL, NULL),
	(2965, 92, 0, 5, 20, 2, 9, 5, 105, NULL, '16-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2576, 3, NULL, NULL),
	(2966, 92, 0, 5, 21, 2, 9, 5, 105, NULL, '17-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2577, 3, NULL, NULL),
	(2967, 92, 0, 5, 22, 2, 9, 5, 105, NULL, '18-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2578, 3, NULL, NULL),
	(2968, 92, 0, 5, 23, 2, 9, 5, 105, NULL, '19-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2579, 3, NULL, NULL),
	(2969, 92, 0, 5, 24, 2, 9, 5, 105, NULL, '20-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2580, 3, NULL, NULL),
	(2970, 92, 0, 5, 25, 2, 9, 5, 105, NULL, '21-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2581, 3, NULL, NULL),
	(2971, 92, 0, 5, 26, 2, 9, 5, 105, NULL, '22-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2582, 3, NULL, NULL),
	(2972, 92, 0, 5, 27, 2, 9, 5, 105, NULL, '23-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2583, 3, NULL, NULL),
	(2973, 92, 0, 5, 28, 2, 9, 5, 105, NULL, '24-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2584, 3, NULL, NULL),
	(2974, 92, 0, 5, 29, 2, 9, 5, 105, NULL, '25-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2585, 3, NULL, NULL),
	(2975, 92, 0, 5, 30, 2, 9, 5, 105, NULL, '26-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2586, 3, NULL, NULL),
	(2976, 92, 0, 5, 31, 2, 9, 5, 105, NULL, '27-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2587, 3, NULL, NULL),
	(2977, 92, 0, 5, 32, 2, 9, 5, 105, NULL, '28-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2588, 3, NULL, NULL),
	(2978, 92, 0, 5, 33, 2, 9, 5, 105, NULL, '29-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2589, 3, NULL, NULL),
	(2979, 92, 0, 5, 34, 2, 9, 5, 105, NULL, '30-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2590, 3, NULL, NULL),
	(2980, 92, 0, 5, 35, 2, 9, 5, 105, NULL, '31-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2591, 3, NULL, NULL),
	(2981, 92, 0, 5, 36, 2, 9, 5, 105, NULL, '32-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2592, 3, NULL, NULL),
	(2982, 92, 0, 5, 37, 2, 9, 5, 105, NULL, '33-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2593, 3, NULL, NULL),
	(2983, 92, 0, 5, 38, 2, 9, 5, 105, NULL, '34-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2594, 3, NULL, NULL),
	(2984, 92, 0, 5, 39, 2, 9, 5, 105, NULL, '35-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2595, 3, NULL, NULL),
	(2985, 92, 0, 5, 40, 2, 9, 5, 105, NULL, '36-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2596, 3, NULL, NULL),
	(2986, 92, 0, 5, 41, 2, 9, 5, 105, NULL, '37-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2597, 3, NULL, NULL),
	(2987, 92, 0, 5, 42, 2, 9, 5, 105, NULL, '38-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2598, 3, NULL, NULL),
	(2988, 92, 0, 5, 43, 2, 9, 5, 105, NULL, '39-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2599, 3, NULL, NULL),
	(2989, 92, 0, 5, 44, 2, 9, 5, 105, NULL, '40-os harmonikos koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2600, 3, NULL, NULL),
	(2990, 95, 0, 5, 6, 2, 9, 5, 108, NULL, '02-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2601, 3, NULL, NULL),
	(2991, 95, 0, 5, 7, 2, 9, 5, 108, NULL, '03-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2602, 3, NULL, NULL),
	(2992, 95, 0, 5, 8, 2, 9, 5, 108, NULL, '04-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2603, 3, NULL, NULL),
	(2993, 95, 0, 5, 9, 2, 9, 5, 108, NULL, '05-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2604, 3, NULL, NULL),
	(2994, 95, 0, 5, 10, 2, 9, 5, 108, NULL, '06-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2605, 3, NULL, NULL),
	(2995, 95, 0, 5, 11, 2, 9, 5, 108, NULL, '07-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2606, 3, NULL, NULL),
	(2996, 95, 0, 5, 12, 2, 9, 5, 108, NULL, '08-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2607, 3, NULL, NULL),
	(2997, 95, 0, 5, 13, 2, 9, 5, 108, NULL, '09-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2608, 3, NULL, NULL),
	(2998, 95, 0, 5, 14, 2, 9, 5, 108, NULL, '10-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2609, 3, NULL, NULL),
	(2999, 95, 0, 5, 15, 2, 9, 5, 108, NULL, '11-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2610, 3, NULL, NULL),
	(3000, 95, 0, 5, 16, 2, 9, 5, 108, NULL, '12-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2611, 3, NULL, NULL),
	(3001, 95, 0, 5, 17, 2, 9, 5, 108, NULL, '13-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2612, 3, NULL, NULL),
	(3002, 95, 0, 5, 18, 2, 9, 5, 108, NULL, '14-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2613, 3, NULL, NULL),
	(3003, 95, 0, 5, 19, 2, 9, 5, 108, NULL, '15-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2614, 3, NULL, NULL),
	(3004, 95, 0, 5, 20, 2, 9, 5, 108, NULL, '16-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2615, 3, NULL, NULL),
	(3005, 95, 0, 5, 21, 2, 9, 5, 108, NULL, '17-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2616, 3, NULL, NULL),
	(3006, 95, 0, 5, 22, 2, 9, 5, 108, NULL, '18-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2617, 3, NULL, NULL),
	(3007, 95, 0, 5, 23, 2, 9, 5, 108, NULL, '19-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2618, 3, NULL, NULL),
	(3008, 95, 0, 5, 24, 2, 9, 5, 108, NULL, '20-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2619, 3, NULL, NULL),
	(3009, 95, 0, 5, 25, 2, 9, 5, 108, NULL, '21-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2620, 3, NULL, NULL),
	(3010, 95, 0, 5, 26, 2, 9, 5, 108, NULL, '22-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2621, 3, NULL, NULL),
	(3011, 95, 0, 5, 27, 2, 9, 5, 108, NULL, '23-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2622, 3, NULL, NULL),
	(3012, 95, 0, 5, 28, 2, 9, 5, 108, NULL, '24-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2623, 3, NULL, NULL),
	(3013, 95, 0, 5, 29, 2, 9, 5, 108, NULL, '25-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2624, 3, NULL, NULL),
	(3014, 95, 0, 5, 30, 2, 9, 5, 108, NULL, '26-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2625, 3, NULL, NULL),
	(3015, 95, 0, 5, 31, 2, 9, 5, 108, NULL, '27-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2626, 3, NULL, NULL),
	(3016, 95, 0, 5, 32, 2, 9, 5, 108, NULL, '28-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2627, 3, NULL, NULL),
	(3017, 95, 0, 5, 33, 2, 9, 5, 108, NULL, '29-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2628, 3, NULL, NULL),
	(3018, 95, 0, 5, 34, 2, 9, 5, 108, NULL, '30-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2629, 3, NULL, NULL),
	(3019, 95, 0, 5, 35, 2, 9, 5, 108, NULL, '31-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2630, 3, NULL, NULL),
	(3020, 95, 0, 5, 36, 2, 9, 5, 108, NULL, '32-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2631, 3, NULL, NULL),
	(3021, 95, 0, 5, 37, 2, 9, 5, 108, NULL, '33-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2632, 3, NULL, NULL),
	(3022, 95, 0, 5, 38, 2, 9, 5, 108, NULL, '34-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2633, 3, NULL, NULL),
	(3023, 95, 0, 5, 39, 2, 9, 5, 108, NULL, '35-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2634, 3, NULL, NULL),
	(3024, 95, 0, 5, 40, 2, 9, 5, 108, NULL, '36-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2635, 3, NULL, NULL),
	(3025, 95, 0, 5, 41, 2, 9, 5, 108, NULL, '37-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2636, 3, NULL, NULL),
	(3026, 95, 0, 5, 42, 2, 9, 5, 108, NULL, '38-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2637, 3, NULL, NULL),
	(3027, 95, 0, 5, 43, 2, 9, 5, 108, NULL, '39-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2638, 3, NULL, NULL),
	(3028, 95, 0, 5, 44, 2, 9, 5, 108, NULL, '40-os harmonikos koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2639, 3, NULL, NULL),
	(3029, 98, 0, 5, 6, 2, 9, 5, 111, NULL, '02-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2640, 3, NULL, NULL),
	(3030, 98, 0, 5, 7, 2, 9, 5, 111, NULL, '03-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2641, 3, NULL, NULL),
	(3031, 98, 0, 5, 8, 2, 9, 5, 111, NULL, '04-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2642, 3, NULL, NULL),
	(3032, 98, 0, 5, 9, 2, 9, 5, 111, NULL, '05-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2643, 3, NULL, NULL),
	(3033, 98, 0, 5, 10, 2, 9, 5, 111, NULL, '06-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2644, 3, NULL, NULL),
	(3034, 98, 0, 5, 11, 2, 9, 5, 111, NULL, '07-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2645, 3, NULL, NULL),
	(3035, 98, 0, 5, 12, 2, 9, 5, 111, NULL, '08-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2646, 3, NULL, NULL),
	(3036, 98, 0, 5, 13, 2, 9, 5, 111, NULL, '09-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2647, 3, NULL, NULL),
	(3037, 98, 0, 5, 14, 2, 9, 5, 111, NULL, '10-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2648, 3, NULL, NULL),
	(3038, 98, 0, 5, 15, 2, 9, 5, 111, NULL, '11-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2649, 3, NULL, NULL),
	(3039, 98, 0, 5, 16, 2, 9, 5, 111, NULL, '12-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2650, 3, NULL, NULL),
	(3040, 98, 0, 5, 17, 2, 9, 5, 111, NULL, '13-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2651, 3, NULL, NULL),
	(3041, 98, 0, 5, 18, 2, 9, 5, 111, NULL, '14-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2652, 3, NULL, NULL),
	(3042, 98, 0, 5, 19, 2, 9, 5, 111, NULL, '15-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2653, 3, NULL, NULL),
	(3043, 98, 0, 5, 20, 2, 9, 5, 111, NULL, '16-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2654, 3, NULL, NULL),
	(3044, 98, 0, 5, 21, 2, 9, 5, 111, NULL, '17-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2655, 3, NULL, NULL),
	(3045, 98, 0, 5, 22, 2, 9, 5, 111, NULL, '18-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2656, 3, NULL, NULL),
	(3046, 98, 0, 5, 23, 2, 9, 5, 111, NULL, '19-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2657, 3, NULL, NULL),
	(3047, 98, 0, 5, 24, 2, 9, 5, 111, NULL, '20-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2658, 3, NULL, NULL),
	(3048, 98, 0, 5, 25, 2, 9, 5, 111, NULL, '21-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2659, 3, NULL, NULL),
	(3049, 98, 0, 5, 26, 2, 9, 5, 111, NULL, '22-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2660, 3, NULL, NULL),
	(3050, 98, 0, 5, 27, 2, 9, 5, 111, NULL, '23-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2661, 3, NULL, NULL),
	(3051, 98, 0, 5, 28, 2, 9, 5, 111, NULL, '24-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2662, 3, NULL, NULL),
	(3052, 98, 0, 5, 29, 2, 9, 5, 111, NULL, '25-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2663, 3, NULL, NULL),
	(3053, 98, 0, 5, 30, 2, 9, 5, 111, NULL, '26-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2664, 3, NULL, NULL),
	(3054, 98, 0, 5, 31, 2, 9, 5, 111, NULL, '27-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2665, 3, NULL, NULL),
	(3055, 98, 0, 5, 32, 2, 9, 5, 111, NULL, '28-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2666, 3, NULL, NULL),
	(3056, 98, 0, 5, 33, 2, 9, 5, 111, NULL, '29-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2667, 3, NULL, NULL),
	(3057, 98, 0, 5, 34, 2, 9, 5, 111, NULL, '30-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2668, 3, NULL, NULL),
	(3058, 98, 0, 5, 35, 2, 9, 5, 111, NULL, '31-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2669, 3, NULL, NULL),
	(3059, 98, 0, 5, 36, 2, 9, 5, 111, NULL, '32-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2670, 3, NULL, NULL),
	(3060, 98, 0, 5, 37, 2, 9, 5, 111, NULL, '33-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2671, 3, NULL, NULL),
	(3061, 98, 0, 5, 38, 2, 9, 5, 111, NULL, '34-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2672, 3, NULL, NULL),
	(3062, 98, 0, 5, 39, 2, 9, 5, 111, NULL, '35-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2673, 3, NULL, NULL),
	(3063, 98, 0, 5, 40, 2, 9, 5, 111, NULL, '36-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2674, 3, NULL, NULL),
	(3064, 98, 0, 5, 41, 2, 9, 5, 111, NULL, '37-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2675, 3, NULL, NULL),
	(3065, 98, 0, 5, 42, 2, 9, 5, 111, NULL, '38-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2676, 3, NULL, NULL),
	(3066, 98, 0, 5, 43, 2, 9, 5, 111, NULL, '39-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2677, 3, NULL, NULL),
	(3067, 98, 0, 5, 44, 2, 9, 5, 111, NULL, '40-os harmonikos koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 2678, 3, NULL, NULL),
	(3068, 91, 0, 5, 6, 2, 9, 5, 104, NULL, '02-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2679, 3, NULL, NULL),
	(3069, 91, 0, 5, 7, 2, 9, 5, 104, NULL, '03-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2680, 3, NULL, NULL),
	(3070, 91, 0, 5, 8, 2, 9, 5, 104, NULL, '04-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2681, 3, NULL, NULL),
	(3071, 91, 0, 5, 9, 2, 9, 5, 104, NULL, '05-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2682, 3, NULL, NULL),
	(3072, 91, 0, 5, 10, 2, 9, 5, 104, NULL, '06-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2683, 3, NULL, NULL),
	(3073, 91, 0, 5, 11, 2, 9, 5, 104, NULL, '07-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2684, 3, NULL, NULL),
	(3074, 91, 0, 5, 12, 2, 9, 5, 104, NULL, '08-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2685, 3, NULL, NULL),
	(3075, 91, 0, 5, 13, 2, 9, 5, 104, NULL, '09-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2686, 3, NULL, NULL),
	(3076, 91, 0, 5, 14, 2, 9, 5, 104, NULL, '10-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2687, 3, NULL, NULL),
	(3077, 91, 0, 5, 15, 2, 9, 5, 104, NULL, '11-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2688, 3, NULL, NULL),
	(3078, 91, 0, 5, 16, 2, 9, 5, 104, NULL, '12-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2689, 3, NULL, NULL),
	(3079, 91, 0, 5, 17, 2, 9, 5, 104, NULL, '13-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2690, 3, NULL, NULL),
	(3080, 91, 0, 5, 18, 2, 9, 5, 104, NULL, '14-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2691, 3, NULL, NULL),
	(3081, 91, 0, 5, 19, 2, 9, 5, 104, NULL, '15-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2692, 3, NULL, NULL),
	(3082, 91, 0, 5, 20, 2, 9, 5, 104, NULL, '16-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2693, 3, NULL, NULL),
	(3083, 91, 0, 5, 21, 2, 9, 5, 104, NULL, '17-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2694, 3, NULL, NULL),
	(3084, 91, 0, 5, 22, 2, 9, 5, 104, NULL, '18-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2695, 3, NULL, NULL),
	(3085, 91, 0, 5, 23, 2, 9, 5, 104, NULL, '19-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2696, 3, NULL, NULL),
	(3086, 91, 0, 5, 24, 2, 9, 5, 104, NULL, '20-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2697, 3, NULL, NULL),
	(3087, 91, 0, 5, 25, 2, 9, 5, 104, NULL, '21-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2698, 3, NULL, NULL),
	(3088, 91, 0, 5, 26, 2, 9, 5, 104, NULL, '22-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2699, 3, NULL, NULL),
	(3089, 91, 0, 5, 27, 2, 9, 5, 104, NULL, '23-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2700, 3, NULL, NULL),
	(3090, 91, 0, 5, 28, 2, 9, 5, 104, NULL, '24-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2701, 3, NULL, NULL),
	(3091, 91, 0, 5, 29, 2, 9, 5, 104, NULL, '25-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2702, 3, NULL, NULL),
	(3092, 91, 0, 5, 30, 2, 9, 5, 104, NULL, '26-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2703, 3, NULL, NULL),
	(3093, 91, 0, 5, 31, 2, 9, 5, 104, NULL, '27-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2704, 3, NULL, NULL),
	(3094, 91, 0, 5, 32, 2, 9, 5, 104, NULL, '28-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2705, 3, NULL, NULL),
	(3095, 91, 0, 5, 33, 2, 9, 5, 104, NULL, '29-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2706, 3, NULL, NULL),
	(3096, 91, 0, 5, 34, 2, 9, 5, 104, NULL, '30-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2707, 3, NULL, NULL),
	(3097, 91, 0, 5, 35, 2, 9, 5, 104, NULL, '31-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2708, 3, NULL, NULL),
	(3098, 91, 0, 5, 36, 2, 9, 5, 104, NULL, '32-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2709, 3, NULL, NULL),
	(3099, 91, 0, 5, 37, 2, 9, 5, 104, NULL, '33-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2710, 3, NULL, NULL),
	(3100, 91, 0, 5, 38, 2, 9, 5, 104, NULL, '34-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2711, 3, NULL, NULL),
	(3101, 91, 0, 5, 39, 2, 9, 5, 104, NULL, '35-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2712, 3, NULL, NULL),
	(3102, 91, 0, 5, 40, 2, 9, 5, 104, NULL, '36-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2713, 3, NULL, NULL),
	(3103, 91, 0, 5, 41, 2, 9, 5, 104, NULL, '37-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2714, 3, NULL, NULL),
	(3104, 91, 0, 5, 42, 2, 9, 5, 104, NULL, '38-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2715, 3, NULL, NULL),
	(3105, 91, 0, 5, 43, 2, 9, 5, 104, NULL, '39-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2716, 3, NULL, NULL),
	(3106, 91, 0, 5, 44, 2, 9, 5, 104, NULL, '40-os harmonikos koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2717, 3, NULL, NULL),
	(3107, 94, 0, 5, 6, 2, 9, 5, 107, NULL, '02-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2718, 3, NULL, NULL),
	(3108, 94, 0, 5, 7, 2, 9, 5, 107, NULL, '03-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2719, 3, NULL, NULL),
	(3109, 94, 0, 5, 8, 2, 9, 5, 107, NULL, '04-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2720, 3, NULL, NULL),
	(3110, 94, 0, 5, 9, 2, 9, 5, 107, NULL, '05-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2721, 3, NULL, NULL),
	(3111, 94, 0, 5, 10, 2, 9, 5, 107, NULL, '06-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2722, 3, NULL, NULL),
	(3112, 94, 0, 5, 11, 2, 9, 5, 107, NULL, '07-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2723, 3, NULL, NULL),
	(3113, 94, 0, 5, 12, 2, 9, 5, 107, NULL, '08-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2724, 3, NULL, NULL),
	(3114, 94, 0, 5, 13, 2, 9, 5, 107, NULL, '09-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2725, 3, NULL, NULL),
	(3115, 94, 0, 5, 14, 2, 9, 5, 107, NULL, '10-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2726, 3, NULL, NULL),
	(3116, 94, 0, 5, 15, 2, 9, 5, 107, NULL, '11-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2727, 3, NULL, NULL),
	(3117, 94, 0, 5, 16, 2, 9, 5, 107, NULL, '12-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2728, 3, NULL, NULL),
	(3118, 94, 0, 5, 17, 2, 9, 5, 107, NULL, '13-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2729, 3, NULL, NULL),
	(3119, 94, 0, 5, 18, 2, 9, 5, 107, NULL, '14-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2730, 3, NULL, NULL),
	(3120, 94, 0, 5, 19, 2, 9, 5, 107, NULL, '15-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2731, 3, NULL, NULL),
	(3121, 94, 0, 5, 20, 2, 9, 5, 107, NULL, '16-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2732, 3, NULL, NULL),
	(3122, 94, 0, 5, 21, 2, 9, 5, 107, NULL, '17-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2733, 3, NULL, NULL),
	(3123, 94, 0, 5, 22, 2, 9, 5, 107, NULL, '18-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2734, 3, NULL, NULL),
	(3124, 94, 0, 5, 23, 2, 9, 5, 107, NULL, '19-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2735, 3, NULL, NULL),
	(3125, 94, 0, 5, 24, 2, 9, 5, 107, NULL, '20-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2736, 3, NULL, NULL),
	(3126, 94, 0, 5, 25, 2, 9, 5, 107, NULL, '21-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2737, 3, NULL, NULL),
	(3127, 94, 0, 5, 26, 2, 9, 5, 107, NULL, '22-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2738, 3, NULL, NULL),
	(3128, 94, 0, 5, 27, 2, 9, 5, 107, NULL, '23-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2739, 3, NULL, NULL),
	(3129, 94, 0, 5, 28, 2, 9, 5, 107, NULL, '24-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2740, 3, NULL, NULL),
	(3130, 94, 0, 5, 29, 2, 9, 5, 107, NULL, '25-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2741, 3, NULL, NULL),
	(3131, 94, 0, 5, 30, 2, 9, 5, 107, NULL, '26-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2742, 3, NULL, NULL),
	(3132, 94, 0, 5, 31, 2, 9, 5, 107, NULL, '27-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2743, 3, NULL, NULL),
	(3133, 94, 0, 5, 32, 2, 9, 5, 107, NULL, '28-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2744, 3, NULL, NULL),
	(3134, 94, 0, 5, 33, 2, 9, 5, 107, NULL, '29-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2745, 3, NULL, NULL),
	(3135, 94, 0, 5, 34, 2, 9, 5, 107, NULL, '30-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2746, 3, NULL, NULL),
	(3136, 94, 0, 5, 35, 2, 9, 5, 107, NULL, '31-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2747, 3, NULL, NULL),
	(3137, 94, 0, 5, 36, 2, 9, 5, 107, NULL, '32-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2748, 3, NULL, NULL),
	(3138, 94, 0, 5, 37, 2, 9, 5, 107, NULL, '33-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2749, 3, NULL, NULL),
	(3139, 94, 0, 5, 38, 2, 9, 5, 107, NULL, '34-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2750, 3, NULL, NULL),
	(3140, 94, 0, 5, 39, 2, 9, 5, 107, NULL, '35-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2751, 3, NULL, NULL),
	(3141, 94, 0, 5, 40, 2, 9, 5, 107, NULL, '36-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2752, 3, NULL, NULL),
	(3142, 94, 0, 5, 41, 2, 9, 5, 107, NULL, '37-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2753, 3, NULL, NULL),
	(3143, 94, 0, 5, 42, 2, 9, 5, 107, NULL, '38-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2754, 3, NULL, NULL),
	(3144, 94, 0, 5, 43, 2, 9, 5, 107, NULL, '39-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2755, 3, NULL, NULL),
	(3145, 94, 0, 5, 44, 2, 9, 5, 107, NULL, '40-os harmonikos koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2756, 3, NULL, NULL),
	(3146, 97, 0, 5, 6, 2, 9, 5, 110, NULL, '02-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2757, 3, NULL, NULL),
	(3147, 97, 0, 5, 7, 2, 9, 5, 110, NULL, '03-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2758, 3, NULL, NULL),
	(3148, 97, 0, 5, 8, 2, 9, 5, 110, NULL, '04-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2759, 3, NULL, NULL),
	(3149, 97, 0, 5, 9, 2, 9, 5, 110, NULL, '05-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2760, 3, NULL, NULL),
	(3150, 97, 0, 5, 10, 2, 9, 5, 110, NULL, '06-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2761, 3, NULL, NULL),
	(3151, 97, 0, 5, 11, 2, 9, 5, 110, NULL, '07-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2762, 3, NULL, NULL),
	(3152, 97, 0, 5, 12, 2, 9, 5, 110, NULL, '08-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2763, 3, NULL, NULL),
	(3153, 97, 0, 5, 13, 2, 9, 5, 110, NULL, '09-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2764, 3, NULL, NULL),
	(3154, 97, 0, 5, 14, 2, 9, 5, 110, NULL, '10-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2765, 3, NULL, NULL),
	(3155, 97, 0, 5, 15, 2, 9, 5, 110, NULL, '11-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2766, 3, NULL, NULL),
	(3156, 97, 0, 5, 16, 2, 9, 5, 110, NULL, '12-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2767, 3, NULL, NULL),
	(3157, 97, 0, 5, 17, 2, 9, 5, 110, NULL, '13-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2768, 3, NULL, NULL),
	(3158, 97, 0, 5, 18, 2, 9, 5, 110, NULL, '14-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2769, 3, NULL, NULL),
	(3159, 97, 0, 5, 19, 2, 9, 5, 110, NULL, '15-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2770, 3, NULL, NULL),
	(3160, 97, 0, 5, 20, 2, 9, 5, 110, NULL, '16-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2771, 3, NULL, NULL),
	(3161, 97, 0, 5, 21, 2, 9, 5, 110, NULL, '17-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2772, 3, NULL, NULL),
	(3162, 97, 0, 5, 22, 2, 9, 5, 110, NULL, '18-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2773, 3, NULL, NULL),
	(3163, 97, 0, 5, 23, 2, 9, 5, 110, NULL, '19-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2774, 3, NULL, NULL),
	(3164, 97, 0, 5, 24, 2, 9, 5, 110, NULL, '20-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2775, 3, NULL, NULL),
	(3165, 97, 0, 5, 25, 2, 9, 5, 110, NULL, '21-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2776, 3, NULL, NULL),
	(3166, 97, 0, 5, 26, 2, 9, 5, 110, NULL, '22-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2777, 3, NULL, NULL),
	(3167, 97, 0, 5, 27, 2, 9, 5, 110, NULL, '23-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2778, 3, NULL, NULL),
	(3168, 97, 0, 5, 28, 2, 9, 5, 110, NULL, '24-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2779, 3, NULL, NULL),
	(3169, 97, 0, 5, 29, 2, 9, 5, 110, NULL, '25-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2780, 3, NULL, NULL),
	(3170, 97, 0, 5, 30, 2, 9, 5, 110, NULL, '26-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2781, 3, NULL, NULL),
	(3171, 97, 0, 5, 31, 2, 9, 5, 110, NULL, '27-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2782, 3, NULL, NULL),
	(3172, 97, 0, 5, 32, 2, 9, 5, 110, NULL, '28-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2783, 3, NULL, NULL),
	(3173, 97, 0, 5, 33, 2, 9, 5, 110, NULL, '29-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2784, 3, NULL, NULL),
	(3174, 97, 0, 5, 34, 2, 9, 5, 110, NULL, '30-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2785, 3, NULL, NULL),
	(3175, 97, 0, 5, 35, 2, 9, 5, 110, NULL, '31-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2786, 3, NULL, NULL),
	(3176, 97, 0, 5, 36, 2, 9, 5, 110, NULL, '32-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2787, 3, NULL, NULL),
	(3177, 97, 0, 5, 37, 2, 9, 5, 110, NULL, '33-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2788, 3, NULL, NULL),
	(3178, 97, 0, 5, 38, 2, 9, 5, 110, NULL, '34-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2789, 3, NULL, NULL),
	(3179, 97, 0, 5, 39, 2, 9, 5, 110, NULL, '35-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2790, 3, NULL, NULL),
	(3180, 97, 0, 5, 40, 2, 9, 5, 110, NULL, '36-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2791, 3, NULL, NULL),
	(3181, 97, 0, 5, 41, 2, 9, 5, 110, NULL, '37-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2792, 3, NULL, NULL),
	(3182, 97, 0, 5, 42, 2, 9, 5, 110, NULL, '38-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2793, 3, NULL, NULL),
	(3183, 97, 0, 5, 43, 2, 9, 5, 110, NULL, '39-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2794, 3, NULL, NULL),
	(3184, 97, 0, 5, 44, 2, 9, 5, 110, NULL, '40-os harmonikos koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 2795, 3, NULL, NULL),
	(3185, 92, 0, 5, 6, 1, 9, 5, 105, NULL, '02-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2796, 3, NULL, NULL),
	(3186, 92, 0, 5, 7, 1, 9, 5, 105, NULL, '03-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2797, 3, NULL, NULL),
	(3187, 92, 0, 5, 8, 1, 9, 5, 105, NULL, '04-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2798, 3, NULL, NULL),
	(3188, 92, 0, 5, 9, 1, 9, 5, 105, NULL, '05-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2799, 3, NULL, NULL),
	(3189, 92, 0, 5, 10, 1, 9, 5, 105, NULL, '06-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2800, 3, NULL, NULL),
	(3190, 92, 0, 5, 11, 1, 9, 5, 105, NULL, '07-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2801, 3, NULL, NULL),
	(3191, 92, 0, 5, 12, 1, 9, 5, 105, NULL, '08-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2802, 3, NULL, NULL),
	(3192, 92, 0, 5, 13, 1, 9, 5, 105, NULL, '09-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2803, 3, NULL, NULL),
	(3193, 92, 0, 5, 14, 1, 9, 5, 105, NULL, '10-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2804, 3, NULL, NULL),
	(3194, 92, 0, 5, 15, 1, 9, 5, 105, NULL, '11-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2805, 3, NULL, NULL),
	(3195, 92, 0, 5, 16, 1, 9, 5, 105, NULL, '12-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2806, 3, NULL, NULL),
	(3196, 92, 0, 5, 17, 1, 9, 5, 105, NULL, '13-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2807, 3, NULL, NULL),
	(3197, 92, 0, 5, 18, 1, 9, 5, 105, NULL, '14-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2808, 3, NULL, NULL),
	(3198, 92, 0, 5, 19, 1, 9, 5, 105, NULL, '15-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2809, 3, NULL, NULL),
	(3199, 92, 0, 5, 20, 1, 9, 5, 105, NULL, '16-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2810, 3, NULL, NULL),
	(3200, 92, 0, 5, 21, 1, 9, 5, 105, NULL, '17-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2811, 3, NULL, NULL),
	(3201, 92, 0, 5, 22, 1, 9, 5, 105, NULL, '18-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2812, 3, NULL, NULL),
	(3202, 92, 0, 5, 23, 1, 9, 5, 105, NULL, '19-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2813, 3, NULL, NULL),
	(3203, 92, 0, 5, 24, 1, 9, 5, 105, NULL, '20-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2814, 3, NULL, NULL),
	(3204, 92, 0, 5, 25, 1, 9, 5, 105, NULL, '21-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2815, 3, NULL, NULL),
	(3205, 92, 0, 5, 26, 1, 9, 5, 105, NULL, '22-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2816, 3, NULL, NULL),
	(3206, 92, 0, 5, 27, 1, 9, 5, 105, NULL, '23-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2817, 3, NULL, NULL),
	(3207, 92, 0, 5, 28, 1, 9, 5, 105, NULL, '24-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2818, 3, NULL, NULL),
	(3208, 92, 0, 5, 29, 1, 9, 5, 105, NULL, '25-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2819, 3, NULL, NULL),
	(3209, 92, 0, 5, 30, 1, 9, 5, 105, NULL, '26-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2820, 3, NULL, NULL),
	(3210, 92, 0, 5, 31, 1, 9, 5, 105, NULL, '27-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2821, 3, NULL, NULL),
	(3211, 92, 0, 5, 32, 1, 9, 5, 105, NULL, '28-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2822, 3, NULL, NULL),
	(3212, 92, 0, 5, 33, 1, 9, 5, 105, NULL, '29-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2823, 3, NULL, NULL),
	(3213, 92, 0, 5, 34, 1, 9, 5, 105, NULL, '30-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2824, 3, NULL, NULL),
	(3214, 92, 0, 5, 35, 1, 9, 5, 105, NULL, '31-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2825, 3, NULL, NULL),
	(3215, 92, 0, 5, 36, 1, 9, 5, 105, NULL, '32-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2826, 3, NULL, NULL),
	(3216, 92, 0, 5, 37, 1, 9, 5, 105, NULL, '33-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2827, 3, NULL, NULL),
	(3217, 92, 0, 5, 38, 1, 9, 5, 105, NULL, '34-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2828, 3, NULL, NULL),
	(3218, 92, 0, 5, 39, 1, 9, 5, 105, NULL, '35-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2829, 3, NULL, NULL),
	(3219, 92, 0, 5, 40, 1, 9, 5, 105, NULL, '36-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2830, 3, NULL, NULL),
	(3220, 92, 0, 5, 41, 1, 9, 5, 105, NULL, '37-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2831, 3, NULL, NULL),
	(3221, 92, 0, 5, 42, 1, 9, 5, 105, NULL, '38-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2832, 3, NULL, NULL),
	(3222, 92, 0, 5, 43, 1, 9, 5, 105, NULL, '39-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2833, 3, NULL, NULL),
	(3223, 92, 0, 5, 44, 1, 9, 5, 105, NULL, '40-os harmonikos koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2834, 3, NULL, NULL),
	(3224, 95, 0, 5, 6, 1, 9, 5, 108, NULL, '02-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2835, 3, NULL, NULL),
	(3225, 95, 0, 5, 7, 1, 9, 5, 108, NULL, '03-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2836, 3, NULL, NULL),
	(3226, 95, 0, 5, 8, 1, 9, 5, 108, NULL, '04-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2837, 3, NULL, NULL),
	(3227, 95, 0, 5, 9, 1, 9, 5, 108, NULL, '05-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2838, 3, NULL, NULL),
	(3228, 95, 0, 5, 10, 1, 9, 5, 108, NULL, '06-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2839, 3, NULL, NULL),
	(3229, 95, 0, 5, 11, 1, 9, 5, 108, NULL, '07-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2840, 3, NULL, NULL),
	(3230, 95, 0, 5, 12, 1, 9, 5, 108, NULL, '08-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2841, 3, NULL, NULL),
	(3231, 95, 0, 5, 13, 1, 9, 5, 108, NULL, '09-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2842, 3, NULL, NULL),
	(3232, 95, 0, 5, 14, 1, 9, 5, 108, NULL, '10-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2843, 3, NULL, NULL),
	(3233, 95, 0, 5, 15, 1, 9, 5, 108, NULL, '11-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2844, 3, NULL, NULL),
	(3234, 95, 0, 5, 16, 1, 9, 5, 108, NULL, '12-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2845, 3, NULL, NULL),
	(3235, 95, 0, 5, 17, 1, 9, 5, 108, NULL, '13-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2846, 3, NULL, NULL),
	(3236, 95, 0, 5, 18, 1, 9, 5, 108, NULL, '14-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2847, 3, NULL, NULL),
	(3237, 95, 0, 5, 19, 1, 9, 5, 108, NULL, '15-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2848, 3, NULL, NULL),
	(3238, 95, 0, 5, 20, 1, 9, 5, 108, NULL, '16-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2849, 3, NULL, NULL),
	(3239, 95, 0, 5, 21, 1, 9, 5, 108, NULL, '17-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2850, 3, NULL, NULL),
	(3240, 95, 0, 5, 22, 1, 9, 5, 108, NULL, '18-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2851, 3, NULL, NULL),
	(3241, 95, 0, 5, 23, 1, 9, 5, 108, NULL, '19-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2852, 3, NULL, NULL),
	(3242, 95, 0, 5, 24, 1, 9, 5, 108, NULL, '20-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2853, 3, NULL, NULL),
	(3243, 95, 0, 5, 25, 1, 9, 5, 108, NULL, '21-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2854, 3, NULL, NULL),
	(3244, 95, 0, 5, 26, 1, 9, 5, 108, NULL, '22-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2855, 3, NULL, NULL),
	(3245, 95, 0, 5, 27, 1, 9, 5, 108, NULL, '23-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2856, 3, NULL, NULL),
	(3246, 95, 0, 5, 28, 1, 9, 5, 108, NULL, '24-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2857, 3, NULL, NULL),
	(3247, 95, 0, 5, 29, 1, 9, 5, 108, NULL, '25-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2858, 3, NULL, NULL),
	(3248, 95, 0, 5, 30, 1, 9, 5, 108, NULL, '26-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2859, 3, NULL, NULL),
	(3249, 95, 0, 5, 31, 1, 9, 5, 108, NULL, '27-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2860, 3, NULL, NULL),
	(3250, 95, 0, 5, 32, 1, 9, 5, 108, NULL, '28-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2861, 3, NULL, NULL),
	(3251, 95, 0, 5, 33, 1, 9, 5, 108, NULL, '29-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2862, 3, NULL, NULL),
	(3252, 95, 0, 5, 34, 1, 9, 5, 108, NULL, '30-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2863, 3, NULL, NULL),
	(3253, 95, 0, 5, 35, 1, 9, 5, 108, NULL, '31-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2864, 3, NULL, NULL),
	(3254, 95, 0, 5, 36, 1, 9, 5, 108, NULL, '32-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2865, 3, NULL, NULL),
	(3255, 95, 0, 5, 37, 1, 9, 5, 108, NULL, '33-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2866, 3, NULL, NULL),
	(3256, 95, 0, 5, 38, 1, 9, 5, 108, NULL, '34-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2867, 3, NULL, NULL),
	(3257, 95, 0, 5, 39, 1, 9, 5, 108, NULL, '35-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2868, 3, NULL, NULL),
	(3258, 95, 0, 5, 40, 1, 9, 5, 108, NULL, '36-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2869, 3, NULL, NULL),
	(3259, 95, 0, 5, 41, 1, 9, 5, 108, NULL, '37-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2870, 3, NULL, NULL),
	(3260, 95, 0, 5, 42, 1, 9, 5, 108, NULL, '38-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2871, 3, NULL, NULL),
	(3261, 95, 0, 5, 43, 1, 9, 5, 108, NULL, '39-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2872, 3, NULL, NULL),
	(3262, 95, 0, 5, 44, 1, 9, 5, 108, NULL, '40-os harmonikos koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2873, 3, NULL, NULL),
	(3263, 98, 0, 5, 6, 1, 9, 5, 111, NULL, '02-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2874, 3, NULL, NULL),
	(3264, 98, 0, 5, 7, 1, 9, 5, 111, NULL, '03-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2875, 3, NULL, NULL),
	(3265, 98, 0, 5, 8, 1, 9, 5, 111, NULL, '04-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2876, 3, NULL, NULL),
	(3266, 98, 0, 5, 9, 1, 9, 5, 111, NULL, '05-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2877, 3, NULL, NULL),
	(3267, 98, 0, 5, 10, 1, 9, 5, 111, NULL, '06-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2878, 3, NULL, NULL),
	(3268, 98, 0, 5, 11, 1, 9, 5, 111, NULL, '07-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2879, 3, NULL, NULL),
	(3269, 98, 0, 5, 12, 1, 9, 5, 111, NULL, '08-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2880, 3, NULL, NULL),
	(3270, 98, 0, 5, 13, 1, 9, 5, 111, NULL, '09-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2881, 3, NULL, NULL),
	(3271, 98, 0, 5, 14, 1, 9, 5, 111, NULL, '10-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2882, 3, NULL, NULL),
	(3272, 98, 0, 5, 15, 1, 9, 5, 111, NULL, '11-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2883, 3, NULL, NULL),
	(3273, 98, 0, 5, 16, 1, 9, 5, 111, NULL, '12-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2884, 3, NULL, NULL),
	(3274, 98, 0, 5, 17, 1, 9, 5, 111, NULL, '13-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2885, 3, NULL, NULL),
	(3275, 98, 0, 5, 18, 1, 9, 5, 111, NULL, '14-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2886, 3, NULL, NULL),
	(3276, 98, 0, 5, 19, 1, 9, 5, 111, NULL, '15-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2887, 3, NULL, NULL),
	(3277, 98, 0, 5, 20, 1, 9, 5, 111, NULL, '16-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2888, 3, NULL, NULL),
	(3278, 98, 0, 5, 21, 1, 9, 5, 111, NULL, '17-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2889, 3, NULL, NULL),
	(3279, 98, 0, 5, 22, 1, 9, 5, 111, NULL, '18-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2890, 3, NULL, NULL),
	(3280, 98, 0, 5, 23, 1, 9, 5, 111, NULL, '19-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2891, 3, NULL, NULL),
	(3281, 98, 0, 5, 24, 1, 9, 5, 111, NULL, '20-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2892, 3, NULL, NULL),
	(3282, 98, 0, 5, 25, 1, 9, 5, 111, NULL, '21-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2893, 3, NULL, NULL),
	(3283, 98, 0, 5, 26, 1, 9, 5, 111, NULL, '22-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2894, 3, NULL, NULL),
	(3284, 98, 0, 5, 27, 1, 9, 5, 111, NULL, '23-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2895, 3, NULL, NULL),
	(3285, 98, 0, 5, 28, 1, 9, 5, 111, NULL, '24-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2896, 3, NULL, NULL),
	(3286, 98, 0, 5, 29, 1, 9, 5, 111, NULL, '25-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2897, 3, NULL, NULL),
	(3287, 98, 0, 5, 30, 1, 9, 5, 111, NULL, '26-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2898, 3, NULL, NULL),
	(3288, 98, 0, 5, 31, 1, 9, 5, 111, NULL, '27-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2899, 3, NULL, NULL),
	(3289, 98, 0, 5, 32, 1, 9, 5, 111, NULL, '28-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2900, 3, NULL, NULL),
	(3290, 98, 0, 5, 33, 1, 9, 5, 111, NULL, '29-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2901, 3, NULL, NULL),
	(3291, 98, 0, 5, 34, 1, 9, 5, 111, NULL, '30-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2902, 3, NULL, NULL),
	(3292, 98, 0, 5, 35, 1, 9, 5, 111, NULL, '31-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2903, 3, NULL, NULL),
	(3293, 98, 0, 5, 36, 1, 9, 5, 111, NULL, '32-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2904, 3, NULL, NULL),
	(3294, 98, 0, 5, 37, 1, 9, 5, 111, NULL, '33-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2905, 3, NULL, NULL),
	(3295, 98, 0, 5, 38, 1, 9, 5, 111, NULL, '34-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2906, 3, NULL, NULL),
	(3296, 98, 0, 5, 39, 1, 9, 5, 111, NULL, '35-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2907, 3, NULL, NULL),
	(3297, 98, 0, 5, 40, 1, 9, 5, 111, NULL, '36-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2908, 3, NULL, NULL),
	(3298, 98, 0, 5, 41, 1, 9, 5, 111, NULL, '37-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2909, 3, NULL, NULL),
	(3299, 98, 0, 5, 42, 1, 9, 5, 111, NULL, '38-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2910, 3, NULL, NULL),
	(3300, 98, 0, 5, 43, 1, 9, 5, 111, NULL, '39-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2911, 3, NULL, NULL),
	(3301, 98, 0, 5, 44, 1, 9, 5, 111, NULL, '40-os harmonikos koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 2912, 3, NULL, NULL),
	(3302, 91, 0, 5, 6, 1, 9, 5, 104, NULL, '02-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2913, 3, NULL, NULL),
	(3303, 91, 0, 5, 7, 1, 9, 5, 104, NULL, '03-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2914, 3, NULL, NULL),
	(3304, 91, 0, 5, 8, 1, 9, 5, 104, NULL, '04-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2915, 3, NULL, NULL),
	(3305, 91, 0, 5, 9, 1, 9, 5, 104, NULL, '05-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2916, 3, NULL, NULL),
	(3306, 91, 0, 5, 10, 1, 9, 5, 104, NULL, '06-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2917, 3, NULL, NULL),
	(3307, 91, 0, 5, 11, 1, 9, 5, 104, NULL, '07-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2918, 3, NULL, NULL),
	(3308, 91, 0, 5, 12, 1, 9, 5, 104, NULL, '08-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2919, 3, NULL, NULL),
	(3309, 91, 0, 5, 13, 1, 9, 5, 104, NULL, '09-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2920, 3, NULL, NULL),
	(3310, 91, 0, 5, 14, 1, 9, 5, 104, NULL, '10-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2921, 3, NULL, NULL),
	(3311, 91, 0, 5, 15, 1, 9, 5, 104, NULL, '11-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2922, 3, NULL, NULL),
	(3312, 91, 0, 5, 16, 1, 9, 5, 104, NULL, '12-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2923, 3, NULL, NULL),
	(3313, 91, 0, 5, 17, 1, 9, 5, 104, NULL, '13-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2924, 3, NULL, NULL),
	(3314, 91, 0, 5, 18, 1, 9, 5, 104, NULL, '14-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2925, 3, NULL, NULL),
	(3315, 91, 0, 5, 19, 1, 9, 5, 104, NULL, '15-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2926, 3, NULL, NULL),
	(3316, 91, 0, 5, 20, 1, 9, 5, 104, NULL, '16-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2927, 3, NULL, NULL),
	(3317, 91, 0, 5, 21, 1, 9, 5, 104, NULL, '17-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2928, 3, NULL, NULL),
	(3318, 91, 0, 5, 22, 1, 9, 5, 104, NULL, '18-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2929, 3, NULL, NULL),
	(3319, 91, 0, 5, 23, 1, 9, 5, 104, NULL, '19-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2930, 3, NULL, NULL),
	(3320, 91, 0, 5, 24, 1, 9, 5, 104, NULL, '20-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2931, 3, NULL, NULL),
	(3321, 91, 0, 5, 25, 1, 9, 5, 104, NULL, '21-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2932, 3, NULL, NULL),
	(3322, 91, 0, 5, 26, 1, 9, 5, 104, NULL, '22-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2933, 3, NULL, NULL),
	(3323, 91, 0, 5, 27, 1, 9, 5, 104, NULL, '23-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2934, 3, NULL, NULL),
	(3324, 91, 0, 5, 28, 1, 9, 5, 104, NULL, '24-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2935, 3, NULL, NULL),
	(3325, 91, 0, 5, 29, 1, 9, 5, 104, NULL, '25-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2936, 3, NULL, NULL),
	(3326, 91, 0, 5, 30, 1, 9, 5, 104, NULL, '26-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2937, 3, NULL, NULL),
	(3327, 91, 0, 5, 31, 1, 9, 5, 104, NULL, '27-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2938, 3, NULL, NULL),
	(3328, 91, 0, 5, 32, 1, 9, 5, 104, NULL, '28-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2939, 3, NULL, NULL),
	(3329, 91, 0, 5, 33, 1, 9, 5, 104, NULL, '29-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2940, 3, NULL, NULL),
	(3330, 91, 0, 5, 34, 1, 9, 5, 104, NULL, '30-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2941, 3, NULL, NULL),
	(3331, 91, 0, 5, 35, 1, 9, 5, 104, NULL, '31-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2942, 3, NULL, NULL),
	(3332, 91, 0, 5, 36, 1, 9, 5, 104, NULL, '32-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2943, 3, NULL, NULL),
	(3333, 91, 0, 5, 37, 1, 9, 5, 104, NULL, '33-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2944, 3, NULL, NULL),
	(3334, 91, 0, 5, 38, 1, 9, 5, 104, NULL, '34-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2945, 3, NULL, NULL),
	(3335, 91, 0, 5, 39, 1, 9, 5, 104, NULL, '35-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2946, 3, NULL, NULL),
	(3336, 91, 0, 5, 40, 1, 9, 5, 104, NULL, '36-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2947, 3, NULL, NULL),
	(3337, 91, 0, 5, 41, 1, 9, 5, 104, NULL, '37-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2948, 3, NULL, NULL),
	(3338, 91, 0, 5, 42, 1, 9, 5, 104, NULL, '38-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2949, 3, NULL, NULL),
	(3339, 91, 0, 5, 43, 1, 9, 5, 104, NULL, '39-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2950, 3, NULL, NULL),
	(3340, 91, 0, 5, 44, 1, 9, 5, 104, NULL, '40-os harmonikos koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2951, 3, NULL, NULL),
	(3341, 94, 0, 5, 6, 1, 9, 5, 107, NULL, '02-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2952, 3, NULL, NULL),
	(3342, 94, 0, 5, 7, 1, 9, 5, 107, NULL, '03-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2953, 3, NULL, NULL),
	(3343, 94, 0, 5, 8, 1, 9, 5, 107, NULL, '04-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2954, 3, NULL, NULL),
	(3344, 94, 0, 5, 9, 1, 9, 5, 107, NULL, '05-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2955, 3, NULL, NULL),
	(3345, 94, 0, 5, 10, 1, 9, 5, 107, NULL, '06-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2956, 3, NULL, NULL),
	(3346, 94, 0, 5, 11, 1, 9, 5, 107, NULL, '07-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2957, 3, NULL, NULL),
	(3347, 94, 0, 5, 12, 1, 9, 5, 107, NULL, '08-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2958, 3, NULL, NULL),
	(3348, 94, 0, 5, 13, 1, 9, 5, 107, NULL, '09-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2959, 3, NULL, NULL),
	(3349, 94, 0, 5, 14, 1, 9, 5, 107, NULL, '10-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2960, 3, NULL, NULL),
	(3350, 94, 0, 5, 15, 1, 9, 5, 107, NULL, '11-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2961, 3, NULL, NULL),
	(3351, 94, 0, 5, 16, 1, 9, 5, 107, NULL, '12-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2962, 3, NULL, NULL),
	(3352, 94, 0, 5, 17, 1, 9, 5, 107, NULL, '13-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2963, 3, NULL, NULL),
	(3353, 94, 0, 5, 18, 1, 9, 5, 107, NULL, '14-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2964, 3, NULL, NULL),
	(3354, 94, 0, 5, 19, 1, 9, 5, 107, NULL, '15-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2965, 3, NULL, NULL),
	(3355, 94, 0, 5, 20, 1, 9, 5, 107, NULL, '16-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2966, 3, NULL, NULL),
	(3356, 94, 0, 5, 21, 1, 9, 5, 107, NULL, '17-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2967, 3, NULL, NULL),
	(3357, 94, 0, 5, 22, 1, 9, 5, 107, NULL, '18-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2968, 3, NULL, NULL),
	(3358, 94, 0, 5, 23, 1, 9, 5, 107, NULL, '19-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2969, 3, NULL, NULL),
	(3359, 94, 0, 5, 24, 1, 9, 5, 107, NULL, '20-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2970, 3, NULL, NULL),
	(3360, 94, 0, 5, 25, 1, 9, 5, 107, NULL, '21-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2971, 3, NULL, NULL),
	(3361, 94, 0, 5, 26, 1, 9, 5, 107, NULL, '22-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2972, 3, NULL, NULL),
	(3362, 94, 0, 5, 27, 1, 9, 5, 107, NULL, '23-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2973, 3, NULL, NULL),
	(3363, 94, 0, 5, 28, 1, 9, 5, 107, NULL, '24-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2974, 3, NULL, NULL),
	(3364, 94, 0, 5, 29, 1, 9, 5, 107, NULL, '25-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2975, 3, NULL, NULL),
	(3365, 94, 0, 5, 30, 1, 9, 5, 107, NULL, '26-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2976, 3, NULL, NULL),
	(3366, 94, 0, 5, 31, 1, 9, 5, 107, NULL, '27-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2977, 3, NULL, NULL),
	(3367, 94, 0, 5, 32, 1, 9, 5, 107, NULL, '28-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2978, 3, NULL, NULL),
	(3368, 94, 0, 5, 33, 1, 9, 5, 107, NULL, '29-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2979, 3, NULL, NULL),
	(3369, 94, 0, 5, 34, 1, 9, 5, 107, NULL, '30-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2980, 3, NULL, NULL),
	(3370, 94, 0, 5, 35, 1, 9, 5, 107, NULL, '31-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2981, 3, NULL, NULL),
	(3371, 94, 0, 5, 36, 1, 9, 5, 107, NULL, '32-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2982, 3, NULL, NULL),
	(3372, 94, 0, 5, 37, 1, 9, 5, 107, NULL, '33-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2983, 3, NULL, NULL),
	(3373, 94, 0, 5, 38, 1, 9, 5, 107, NULL, '34-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2984, 3, NULL, NULL),
	(3374, 94, 0, 5, 39, 1, 9, 5, 107, NULL, '35-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2985, 3, NULL, NULL),
	(3375, 94, 0, 5, 40, 1, 9, 5, 107, NULL, '36-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2986, 3, NULL, NULL),
	(3376, 94, 0, 5, 41, 1, 9, 5, 107, NULL, '37-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2987, 3, NULL, NULL),
	(3377, 94, 0, 5, 42, 1, 9, 5, 107, NULL, '38-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2988, 3, NULL, NULL),
	(3378, 94, 0, 5, 43, 1, 9, 5, 107, NULL, '39-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2989, 3, NULL, NULL),
	(3379, 94, 0, 5, 44, 1, 9, 5, 107, NULL, '40-os harmonikos koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2990, 3, NULL, NULL),
	(3380, 97, 0, 5, 6, 1, 9, 5, 110, NULL, '02-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2991, 3, NULL, NULL),
	(3381, 97, 0, 5, 7, 1, 9, 5, 110, NULL, '03-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2992, 3, NULL, NULL),
	(3382, 97, 0, 5, 8, 1, 9, 5, 110, NULL, '04-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2993, 3, NULL, NULL),
	(3383, 97, 0, 5, 9, 1, 9, 5, 110, NULL, '05-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2994, 3, NULL, NULL),
	(3384, 97, 0, 5, 10, 1, 9, 5, 110, NULL, '06-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2995, 3, NULL, NULL),
	(3385, 97, 0, 5, 11, 1, 9, 5, 110, NULL, '07-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2996, 3, NULL, NULL),
	(3386, 97, 0, 5, 12, 1, 9, 5, 110, NULL, '08-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2997, 3, NULL, NULL),
	(3387, 97, 0, 5, 13, 1, 9, 5, 110, NULL, '09-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2998, 3, NULL, NULL),
	(3388, 97, 0, 5, 14, 1, 9, 5, 110, NULL, '10-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 2999, 3, NULL, NULL),
	(3389, 97, 0, 5, 15, 1, 9, 5, 110, NULL, '11-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3000, 3, NULL, NULL),
	(3390, 97, 0, 5, 16, 1, 9, 5, 110, NULL, '12-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3001, 3, NULL, NULL),
	(3391, 97, 0, 5, 17, 1, 9, 5, 110, NULL, '13-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3002, 3, NULL, NULL),
	(3392, 97, 0, 5, 18, 1, 9, 5, 110, NULL, '14-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3003, 3, NULL, NULL),
	(3393, 97, 0, 5, 19, 1, 9, 5, 110, NULL, '15-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3004, 3, NULL, NULL),
	(3394, 97, 0, 5, 20, 1, 9, 5, 110, NULL, '16-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3005, 3, NULL, NULL),
	(3395, 97, 0, 5, 21, 1, 9, 5, 110, NULL, '17-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3006, 3, NULL, NULL),
	(3396, 97, 0, 5, 22, 1, 9, 5, 110, NULL, '18-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3007, 3, NULL, NULL),
	(3397, 97, 0, 5, 23, 1, 9, 5, 110, NULL, '19-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3008, 3, NULL, NULL),
	(3398, 97, 0, 5, 24, 1, 9, 5, 110, NULL, '20-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3009, 3, NULL, NULL),
	(3399, 97, 0, 5, 25, 1, 9, 5, 110, NULL, '21-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3010, 3, NULL, NULL),
	(3400, 97, 0, 5, 26, 1, 9, 5, 110, NULL, '22-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3011, 3, NULL, NULL),
	(3401, 97, 0, 5, 27, 1, 9, 5, 110, NULL, '23-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3012, 3, NULL, NULL),
	(3402, 97, 0, 5, 28, 1, 9, 5, 110, NULL, '24-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3013, 3, NULL, NULL),
	(3403, 97, 0, 5, 29, 1, 9, 5, 110, NULL, '25-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3014, 3, NULL, NULL),
	(3404, 97, 0, 5, 30, 1, 9, 5, 110, NULL, '26-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3015, 3, NULL, NULL),
	(3405, 97, 0, 5, 31, 1, 9, 5, 110, NULL, '27-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3016, 3, NULL, NULL),
	(3406, 97, 0, 5, 32, 1, 9, 5, 110, NULL, '28-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3017, 3, NULL, NULL),
	(3407, 97, 0, 5, 33, 1, 9, 5, 110, NULL, '29-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3018, 3, NULL, NULL),
	(3408, 97, 0, 5, 34, 1, 9, 5, 110, NULL, '30-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3019, 3, NULL, NULL),
	(3409, 97, 0, 5, 35, 1, 9, 5, 110, NULL, '31-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3020, 3, NULL, NULL),
	(3410, 97, 0, 5, 36, 1, 9, 5, 110, NULL, '32-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3021, 3, NULL, NULL),
	(3411, 97, 0, 5, 37, 1, 9, 5, 110, NULL, '33-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3022, 3, NULL, NULL),
	(3412, 97, 0, 5, 38, 1, 9, 5, 110, NULL, '34-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3023, 3, NULL, NULL),
	(3413, 97, 0, 5, 39, 1, 9, 5, 110, NULL, '35-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3024, 3, NULL, NULL),
	(3414, 97, 0, 5, 40, 1, 9, 5, 110, NULL, '36-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3025, 3, NULL, NULL),
	(3415, 97, 0, 5, 41, 1, 9, 5, 110, NULL, '37-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3026, 3, NULL, NULL),
	(3416, 97, 0, 5, 42, 1, 9, 5, 110, NULL, '38-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3027, 3, NULL, NULL),
	(3417, 97, 0, 5, 43, 1, 9, 5, 110, NULL, '39-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3028, 3, NULL, NULL),
	(3418, 97, 0, 5, 44, 1, 9, 5, 110, NULL, '40-os harmonikos koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3029, 3, NULL, NULL),
	(3419, 89, 0, 5, 3, 2, 9, 5, 102, NULL, 'Dažnio nukrypimo NLN peržengimo % (normalios apkrovos) per parą', 3030, 3, NULL, NULL),
	(3420, 88, 0, 5, 3, 2, 9, 5, 101, NULL, 'Dažnio nukrypimo ALN peržengimo % (normalios apkrovos) per parą', 3031, 3, NULL, NULL),
	(3421, 81, 0, 5, 3, 2, 9, 5, 94, NULL, 'Dažnio nukrypimo L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 3032, 3, NULL, NULL),
	(3422, 80, 0, 5, 3, 2, 9, 5, 93, NULL, 'Dažnio nukrypimo L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3033, 3, NULL, NULL),
	(3423, 84, 0, 5, 3, 2, 9, 5, 97, NULL, 'Dažnio nukrypimo L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 3034, 3, NULL, NULL),
	(3424, 83, 0, 5, 3, 2, 9, 5, 96, NULL, 'Dažnio nukrypimo L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3035, 3, NULL, NULL),
	(3425, 87, 0, 5, 3, 2, 9, 5, 100, NULL, 'Dažnio nukrypimo L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 3036, 3, NULL, NULL),
	(3426, 86, 0, 5, 3, 2, 9, 5, 99, NULL, 'Dažnio nukrypimo L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3037, 3, NULL, NULL),
	(3427, 140, 0, 5, 3, 2, 9, 5, 153, NULL, 'Susidarusio įtampos nukrypimo NLN peržengimo % (normalios apkrovos) per parą', 3038, 3, NULL, NULL),
	(3428, 139, 0, 5, 3, 2, 9, 5, 152, NULL, 'Susidarusio įtampos nukrypimo ALN peržengimo % (normalios apkrovos) per parą', 3039, 3, NULL, NULL),
	(3429, 123, 0, 5, 3, 2, 9, 5, 136, NULL, 'Susidarusio įtampos nukrypimo L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 3040, 3, NULL, NULL),
	(3430, 122, 0, 5, 3, 2, 9, 5, 135, NULL, 'Susidarusio įtampos nukrypimo L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3041, 3, NULL, NULL),
	(3431, 126, 0, 5, 3, 2, 9, 5, 139, NULL, 'Susidarusio įtampos nukrypimo L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 3042, 3, NULL, NULL),
	(3432, 125, 0, 5, 3, 2, 9, 5, 138, NULL, 'Susidarusio įtampos nukrypimo L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3043, 3, NULL, NULL),
	(3433, 129, 0, 5, 3, 2, 9, 5, 142, NULL, 'Susidarusio įtampos nukrypimo L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 3044, 3, NULL, NULL),
	(3434, 128, 0, 5, 3, 2, 9, 5, 141, NULL, 'Susidarusio įtampos nukrypimo L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3045, 3, NULL, NULL),
	(3435, 68, 0, 5, 3, 2, 9, 5, 81, NULL, 'Atvirkštinės sekos nesimetrijos koeficiento NLN peržengimo % (normalios apkrovos) per parą', 3046, 3, NULL, NULL),
	(3436, 67, 0, 5, 3, 2, 9, 5, 80, NULL, 'Atvirkštinės sekos nesimetrijos koeficiento ALN peržengimo % (normalios apkrovos) per parą', 3047, 3, NULL, NULL),
	(3437, 71, 0, 5, 3, 2, 9, 5, 84, NULL, 'Nulinės sekos nesimetrijos koeficiento NLN peržengimo % (normalios apkrovos) per parą', 3048, 3, NULL, NULL),
	(3438, 70, 0, 5, 3, 2, 9, 5, 83, NULL, 'Nulinės sekos nesimetrijos koeficiento ALN peržengimo % (normalios apkrovos) per parą', 3049, 3, NULL, NULL),
	(3439, 113, 0, 5, 3, 2, 9, 5, 126, NULL, 'Sinusoidės iškreipimo koeficiento L1 fazėje NLN peržengimo % (normalios apkrovos) per parą', 3050, 3, NULL, NULL),
	(3440, 112, 0, 5, 3, 2, 9, 5, 125, NULL, 'Sinusoidės iškreipimo koeficiento L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3051, 3, NULL, NULL),
	(3441, 116, 0, 5, 3, 2, 9, 5, 129, NULL, 'Sinusoidės iškreipimo koeficiento L2 fazėje NLN peržengimo % (normalios apkrovos) per parą', 3052, 3, NULL, NULL),
	(3442, 115, 0, 5, 3, 2, 9, 5, 128, NULL, 'Sinusoidės iškreipimo koeficiento L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3053, 3, NULL, NULL),
	(3443, 119, 0, 5, 3, 2, 9, 5, 132, NULL, 'Sinusoidės iškreipimo koeficiento L3 fazėje NLN peržengimo % (normalios apkrovos) per parą', 3054, 3, NULL, NULL),
	(3444, 118, 0, 5, 3, 2, 9, 5, 131, NULL, 'Sinusoidės iškreipimo koeficiento L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3055, 3, NULL, NULL),
	(3445, 73, 0, 5, 3, 2, 9, 5, 86, NULL, 'Trumpalaikės mirksėjimo dozės L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3056, 3, NULL, NULL),
	(3446, 75, 0, 5, 3, 2, 9, 5, 88, NULL, 'Trumpalaikės mirksėjimo dozės L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3057, 3, NULL, NULL),
	(3447, 77, 0, 5, 3, 2, 9, 5, 90, NULL, 'Trumpalaikės mirksėjimo dozės L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3058, 3, NULL, NULL),
	(3448, 131, 0, 5, 3, 2, 9, 5, 144, NULL, 'Įtampos pakeitimų diapazono amplitudės L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3059, 3, NULL, NULL),
	(3449, 133, 0, 5, 3, 2, 9, 5, 146, NULL, 'Įtampos pakeitimų diapazono amplitudės L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3060, 3, NULL, NULL),
	(3450, 135, 0, 5, 3, 2, 9, 5, 148, NULL, 'Įtampos pakeitimų diapazono amplitudės L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3061, 3, NULL, NULL),
	(3451, 103, 0, 5, 3, 2, 9, 5, 116, NULL, 'Ilgalaikės mirksėjimo dozės L1 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3062, 3, NULL, NULL),
	(3452, 105, 0, 5, 3, 2, 9, 5, 118, NULL, 'Ilgalaikės mirksėjimo dozės L2 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3063, 3, NULL, NULL),
	(3453, 107, 0, 5, 3, 2, 9, 5, 120, NULL, 'Ilgalaikės mirksėjimo dozės L3 fazėje ALN peržengimo % (normalios apkrovos) per parą', 3064, 3, NULL, NULL),
	(3454, 89, 0, 5, 3, 1, 9, 5, 102, NULL, 'Dažnio nukrypimo NLN peržengimo % (maksimalios apkrovos) per parą', 3065, 3, NULL, NULL),
	(3455, 88, 0, 5, 3, 1, 9, 5, 101, NULL, 'Dažnio nukrypimo ALN peržengimo % (maksimalios apkrovos) per parą', 3066, 3, NULL, NULL),
	(3456, 81, 0, 5, 3, 1, 9, 5, 94, NULL, 'Dažnio nukrypimo L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 3067, 3, NULL, NULL),
	(3457, 80, 0, 5, 3, 1, 9, 5, 93, NULL, 'Dažnio nukrypimo L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3068, 3, NULL, NULL),
	(3458, 84, 0, 5, 3, 1, 9, 5, 97, NULL, 'Dažnio nukrypimo L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 3069, 3, NULL, NULL),
	(3459, 83, 0, 5, 3, 1, 9, 5, 96, NULL, 'Dažnio nukrypimo L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3070, 3, NULL, NULL),
	(3460, 87, 0, 5, 3, 1, 9, 5, 100, NULL, 'Dažnio nukrypimo L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 3071, 3, NULL, NULL),
	(3461, 86, 0, 5, 3, 1, 9, 5, 99, NULL, 'Dažnio nukrypimo L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3072, 3, NULL, NULL),
	(3462, 140, 0, 5, 3, 1, 9, 5, 153, NULL, 'Susidarusio įtampos nukrypimo NLN peržengimo % (maksimalios apkrovos) per parą', 3073, 3, NULL, NULL),
	(3463, 139, 0, 5, 3, 1, 9, 5, 152, NULL, 'Susidarusio įtampos nukrypimo ALN peržengimo % (maksimalios apkrovos) per parą', 3074, 3, NULL, NULL),
	(3464, 123, 0, 5, 3, 1, 9, 5, 136, NULL, 'Susidarusio įtampos nukrypimo L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 3075, 3, NULL, NULL),
	(3465, 122, 0, 5, 3, 1, 9, 5, 135, NULL, 'Susidarusio įtampos nukrypimo L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3076, 3, NULL, NULL),
	(3466, 126, 0, 5, 3, 1, 9, 5, 139, NULL, 'Susidarusio įtampos nukrypimo L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 3077, 3, NULL, NULL),
	(3467, 125, 0, 5, 3, 1, 9, 5, 138, NULL, 'Susidarusio įtampos nukrypimo L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3078, 3, NULL, NULL),
	(3468, 129, 0, 5, 3, 1, 9, 5, 142, NULL, 'Susidarusio įtampos nukrypimo L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 3079, 3, NULL, NULL),
	(3469, 128, 0, 5, 3, 1, 9, 5, 141, NULL, 'Susidarusio įtampos nukrypimo L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3080, 3, NULL, NULL),
	(3470, 68, 0, 5, 3, 1, 9, 5, 81, NULL, 'Atvirkštinės sekos nesimetrijos koeficiento NLN peržengimo % (maksimalios apkrovos) per parą', 3081, 3, NULL, NULL),
	(3471, 67, 0, 5, 3, 1, 9, 5, 80, NULL, 'Atvirkštinės sekos nesimetrijos koeficiento ALN peržengimo % (maksimalios apkrovos) per parą', 3082, 3, NULL, NULL),
	(3472, 71, 0, 5, 3, 1, 9, 5, 84, NULL, 'Nulinės sekos nesimetrijos koeficiento NLN peržengimo % (maksimalios apkrovos) per parą', 3083, 3, NULL, NULL),
	(3473, 70, 0, 5, 3, 1, 9, 5, 83, NULL, 'Nulinės sekos nesimetrijos koeficiento ALN peržengimo % (maksimalios apkrovos) per parą', 3084, 3, NULL, NULL),
	(3474, 113, 0, 5, 3, 1, 9, 5, 126, NULL, 'Sinusoidės iškreipimo koeficiento L1 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 3085, 3, NULL, NULL),
	(3475, 112, 0, 5, 3, 1, 9, 5, 125, NULL, 'Sinusoidės iškreipimo koeficiento L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3086, 3, NULL, NULL),
	(3476, 116, 0, 5, 3, 1, 9, 5, 129, NULL, 'Sinusoidės iškreipimo koeficiento L2 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 3087, 3, NULL, NULL),
	(3477, 115, 0, 5, 3, 1, 9, 5, 128, NULL, 'Sinusoidės iškreipimo koeficiento L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3088, 3, NULL, NULL),
	(3478, 119, 0, 5, 3, 1, 9, 5, 132, NULL, 'Sinusoidės iškreipimo koeficiento L3 fazėje NLN peržengimo % (maksimalios apkrovos) per parą', 3089, 3, NULL, NULL),
	(3479, 118, 0, 5, 3, 1, 9, 5, 131, NULL, 'Sinusoidės iškreipimo koeficiento L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3090, 3, NULL, NULL),
	(3480, 73, 0, 5, 3, 1, 9, 5, 86, NULL, 'Trumpalaikės mirksėjimo dozės L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3091, 3, NULL, NULL),
	(3481, 75, 0, 5, 3, 1, 9, 5, 88, NULL, 'Trumpalaikės mirksėjimo dozės L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3092, 3, NULL, NULL),
	(3482, 77, 0, 5, 3, 1, 9, 5, 90, NULL, 'Trumpalaikės mirksėjimo dozės L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3093, 3, NULL, NULL),
	(3483, 131, 0, 5, 3, 1, 9, 5, 144, NULL, 'Įtampos pakeitimų diapazono amplitudės L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3094, 3, NULL, NULL),
	(3484, 133, 0, 5, 3, 1, 9, 5, 146, NULL, 'Įtampos pakeitimų diapazono amplitudės L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3095, 3, NULL, NULL),
	(3485, 135, 0, 5, 3, 1, 9, 5, 148, NULL, 'Įtampos pakeitimų diapazono amplitudės L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3096, 3, NULL, NULL),
	(3486, 103, 0, 5, 3, 1, 9, 5, 116, NULL, 'Ilgalaikės mirksėjimo dozės L1 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3097, 3, NULL, NULL),
	(3487, 105, 0, 5, 3, 1, 9, 5, 118, NULL, 'Ilgalaikės mirksėjimo dozės L2 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3098, 3, NULL, NULL),
	(3488, 107, 0, 5, 3, 1, 9, 5, 120, NULL, 'Ilgalaikės mirksėjimo dozės L3 fazėje ALN peržengimo % (maksimalios apkrovos) per parą', 3099, 3, NULL, NULL),
	(3489, 1, 2, 3, 4, 0, 1, 5, 13, NULL, 'Maksimali pusvalandinė P- galia per parą', 395, 3, NULL, NULL),
	(3490, 1, 2, 3, 4, 0, 1, 6, 13, NULL, 'Maksimali pusvalandinė P- galia per mėnesį', 375, 4, NULL, NULL),
	(3491, 1, 2, 4, 4, 0, 1, 5, 13, NULL, 'Maksimali valandinė P- galia per parą', 395, 3, NULL, NULL),
	(3492, 1, 2, 4, 4, 0, 1, 6, 13, NULL, 'Maksimali valandinė P- galia per mėnesį', 375, 4, NULL, NULL),
	(3493, 1, 2, 3, 5, 0, 1, 5, 13, NULL, 'Minimali pusvalandinė P- galia per parą', NULL, 3, NULL, NULL),
	(3494, 1, 2, 3, 5, 0, 1, 6, 13, NULL, 'Minimali pusvalandinė P- galia per mėnesį', NULL, 4, NULL, NULL),
	(3495, 1, 2, 4, 5, 0, 1, 5, 13, NULL, 'Minimali valandinė P- galia per parą', NULL, 3, NULL, NULL),
	(3496, 1, 2, 4, 5, 0, 1, 6, 13, NULL, 'Minimali valandinė P- galia per mėnesį', NULL, 4, NULL, NULL),
	(3497, 3, 1, 3, 4, 0, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q+ galia per parą', 396, 3, NULL, NULL),
	(3498, 3, 1, 3, 4, 0, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q+ galia per mėnesį', 376, 4, NULL, NULL),
	(3499, 3, 1, 4, 4, 0, 3, 5, 16, NULL, 'Maksimali valandinė Q+ galia per parą', 396, 3, NULL, NULL),
	(3500, 3, 1, 4, 4, 0, 3, 6, 16, NULL, 'Maksimali valandinė Q+ galia per mėnesį', 376, 4, NULL, NULL),
	(3501, 3, 1, 3, 5, 0, 3, 5, 16, NULL, 'Minimali pusvalandinė Q+ galia per parą', NULL, 3, NULL, NULL),
	(3502, 3, 1, 3, 5, 0, 3, 6, 16, NULL, 'Minimali pusvalandinė Q+ galia per mėnesį', NULL, 4, NULL, NULL),
	(3503, 3, 1, 4, 5, 0, 3, 5, 16, NULL, 'Minimali valandinė Q+ galia per parą', NULL, 3, NULL, NULL),
	(3504, 3, 1, 4, 5, 0, 3, 6, 16, NULL, 'Minimali valandinė Q+ galia per mėnesį', NULL, 4, NULL, NULL),
	(3505, 3, 2, 3, 4, 0, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q- galia per parą', 397, 3, NULL, NULL),
	(3506, 3, 2, 3, 4, 0, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q- galia per mėnesį', 377, 4, NULL, NULL),
	(3507, 3, 2, 4, 4, 0, 3, 5, 16, NULL, 'Maksimali valandinė Q- galia per parą', 397, 3, NULL, NULL),
	(3508, 3, 2, 4, 4, 0, 3, 6, 16, NULL, 'Maksimali valandinė Q- galia per mėnesį', 377, 4, NULL, NULL),
	(3509, 3, 2, 3, 5, 0, 3, 5, 16, NULL, 'Minimali pusvalandinė Q- galia per parą', NULL, 3, NULL, NULL),
	(3510, 3, 2, 3, 5, 0, 3, 6, 16, NULL, 'Minimali pusvalandinė Q- galia per mėnesį', NULL, 4, NULL, NULL),
	(3511, 3, 2, 4, 5, 0, 3, 5, 16, NULL, 'Minimali valandinė Q- galia per parą', NULL, 3, NULL, NULL),
	(3512, 3, 2, 4, 5, 0, 3, 6, 16, NULL, 'Minimali valandinė Q- galia per mėnesį', NULL, 4, NULL, NULL),
	(3513, 1, 1, 9, 4, 0, 1, 5, 13, NULL, 'Maksimali 3 minučių P+ galia per parą', 394, 3, NULL, NULL),
	(3514, 1, 1, 9, 5, 0, 1, 5, 13, NULL, 'Minimali 3 minučių P+ galia per parą', NULL, 3, NULL, NULL),
	(3515, 1, 2, 9, 4, 0, 1, 5, 13, NULL, 'Maksimali 3 minučių P- galia per parą', 395, 3, NULL, NULL),
	(3516, 1, 2, 9, 5, 0, 1, 5, 13, NULL, 'Minimali 3 minučių P- galia per parą', NULL, 3, NULL, NULL),
	(3517, 3, 1, 9, 4, 0, 3, 5, 16, NULL, 'Maksimali 3 minučių Q+ galia per parą', 396, 3, NULL, NULL),
	(3518, 3, 1, 9, 5, 0, 3, 5, 16, NULL, 'Minimali 3 minučių Q+ galia per parą', NULL, 3, NULL, NULL),
	(3519, 3, 2, 9, 4, 0, 3, 5, 16, NULL, 'Maksimali 3 minučių Q- galia per parą', 397, 3, NULL, NULL),
	(3520, 3, 2, 9, 5, 0, 3, 5, 16, NULL, 'Minimali 3 minučių Q- galia per parą', NULL, 3, NULL, NULL),
	(3521, 141, 0, 5, 3, 0, 0, 5, 154, NULL, 'Energijos kokybės per parą atitikimo standartams rodiklis', 3100, 3, NULL, NULL),
	(3522, 142, 0, 12, 3, 0, 28, 11, 155, NULL, 'Vidutinis šalto vandens slėgis per 10 minučių', 1216, 1, NULL, NULL),
	(3523, 142, 0, 11, 3, 0, 28, 10, 155, NULL, 'Vidutinis šalto vandens slėgis per 5 minutes', 1216, 1, NULL, NULL),
	(3524, 142, 0, 10, 3, 0, 28, 9, 155, NULL, 'Vidutinis šalto vandens slėgis per 4 minutes', 1216, 1, NULL, NULL),
	(3525, 142, 0, 9, 3, 0, 28, 8, 155, NULL, 'Vidutinis šalto vandens slėgis per 3 minutes', 1216, 1, NULL, NULL),
	(3526, 142, 0, 2, 3, 0, 28, 2, 155, NULL, 'Vidutinis šalto vandens slėgis per 2 minutes', 1216, 1, NULL, NULL),
	(3527, 142, 0, 1, 3, 0, 28, 1, 155, NULL, 'Vidutinis šalto vandens slėgis per minutę', 1216, 1, NULL, NULL),
	(3528, 142, 0, 4, 3, 0, 28, 4, 155, NULL, 'Vidutinis šalto vandens slėgis per valandą', 1216, 2, NULL, NULL),
	(3529, 142, 0, 3, 3, 0, 28, 3, 155, NULL, 'Vidutinis šalto vandens slėgis per 30 minučių', 1216, 2, NULL, NULL),
	(3530, 142, 0, 14, 3, 0, 28, 13, 155, NULL, 'Vidutinis šalto vandens slėgis per 20 minučių', 1216, 2, NULL, NULL),
	(3531, 142, 0, 13, 3, 0, 28, 12, 155, NULL, 'Vidutinis šalto vandens slėgis per 15 minučių', 1216, 2, NULL, NULL),
	(3532, 142, 0, 5, 3, 0, 28, 5, 155, NULL, 'Vidutinis šalto vandens slėgis per parą', 1216, 3, NULL, NULL),
	(3533, 142, 0, 6, 3, 0, 28, 6, 155, NULL, 'Vidutinis šalto vandens slėgis per mėnesį', 1216, 4, NULL, NULL),
	(3534, 142, 0, 7, 1, 0, 28, 7, 155, NULL, 'Momentinis šalto vandens slėgis', 1209, 6, NULL, NULL),
	(3535, 142, 0, 13, 5, 0, 28, 5, 155, NULL, 'Minimalus 15 minučių šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(3536, 142, 0, 13, 4, 0, 28, 5, 155, NULL, 'Maksimalus 15 minučių šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(3537, 142, 0, 3, 5, 0, 28, 5, 155, NULL, 'Minimalus pusvalandinis šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(3538, 142, 0, 3, 4, 0, 28, 5, 155, NULL, 'Maksimalus pusvalandinis šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(3539, 142, 0, 4, 5, 0, 28, 5, 155, NULL, 'Minimalus valandinis šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(3540, 142, 0, 4, 4, 0, 28, 5, 155, NULL, 'Maksimalus valandinis šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(3541, 142, 0, 13, 5, 0, 28, 6, 155, NULL, 'Minimalus 15 minučių šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(3542, 142, 0, 13, 4, 0, 28, 6, 155, NULL, 'Maksimalus 15 minučių šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(3543, 142, 0, 3, 5, 0, 28, 6, 155, NULL, 'Minimalus pusvalandinis šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(3544, 142, 0, 3, 4, 0, 28, 6, 155, NULL, 'Maksimalus pusvalandinis šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(3545, 142, 0, 4, 5, 0, 28, 6, 155, NULL, 'Minimalus valandinis šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(3546, 142, 0, 4, 4, 0, 28, 6, 155, NULL, 'Maksimalus valandinis šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(3547, 143, 0, 12, 3, 0, 28, 11, 156, NULL, 'Vidutinis karšto vandens slėgis per 10 minučių', 1216, 1, NULL, NULL),
	(3548, 143, 0, 11, 3, 0, 28, 10, 156, NULL, 'Vidutinis karšto vandens slėgis per 5 minutes', 1216, 1, NULL, NULL),
	(3549, 143, 0, 10, 3, 0, 28, 9, 156, NULL, 'Vidutinis karšto vandens slėgis per 4 minutes', 1216, 1, NULL, NULL),
	(3550, 143, 0, 9, 3, 0, 28, 8, 156, NULL, 'Vidutinis karšto vandens slėgis per 3 minutes', 1216, 1, NULL, NULL),
	(3551, 143, 0, 2, 3, 0, 28, 2, 156, NULL, 'Vidutinis karšto vandens slėgis per 2 minutes', 1216, 1, NULL, NULL),
	(3552, 143, 0, 1, 3, 0, 28, 1, 156, NULL, 'Vidutinis karšto vandens slėgis per minutę', 1216, 1, NULL, NULL),
	(3553, 143, 0, 4, 3, 0, 28, 4, 156, NULL, 'Vidutinis karšto vandens slėgis per valandą', 1216, 2, NULL, NULL),
	(3554, 143, 0, 3, 3, 0, 28, 3, 156, NULL, 'Vidutinis karšto vandens slėgis per 30 minučių', 1216, 2, NULL, NULL),
	(3555, 143, 0, 14, 3, 0, 28, 13, 156, NULL, 'Vidutinis karšto vandens slėgis per 20 minučių', 1216, 2, NULL, NULL),
	(3556, 143, 0, 13, 3, 0, 28, 12, 156, NULL, 'Vidutinis karšto vandens slėgis per 15 minučių', 1216, 2, NULL, NULL),
	(3557, 143, 0, 5, 3, 0, 28, 5, 156, NULL, 'Vidutinis karšto vandens slėgis per parą', 1216, 3, NULL, NULL),
	(3558, 143, 0, 6, 3, 0, 28, 6, 156, NULL, 'Vidutinis karšto vandens slėgis per mėnesį', 1216, 4, NULL, NULL),
	(3559, 143, 0, 7, 1, 0, 28, 7, 156, NULL, 'Momentinis karšto vandens slėgis', 1209, 6, NULL, NULL),
	(3560, 143, 0, 13, 5, 0, 28, 5, 156, NULL, 'Minimalus 15 minučių karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(3561, 143, 0, 13, 4, 0, 28, 5, 156, NULL, 'Maksimalus 15 minučių karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(3562, 143, 0, 3, 5, 0, 28, 5, 156, NULL, 'Minimalus pusvalandinis karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(3563, 143, 0, 3, 4, 0, 28, 5, 156, NULL, 'Maksimalus pusvalandinis karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(3564, 143, 0, 4, 5, 0, 28, 5, 156, NULL, 'Minimalus valandinis karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(3565, 143, 0, 4, 4, 0, 28, 5, 156, NULL, 'Maksimalus valandinis karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(3566, 143, 0, 13, 5, 0, 28, 6, 156, NULL, 'Minimalus 15 minučių karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(3567, 143, 0, 13, 4, 0, 28, 6, 156, NULL, 'Maksimalus 15 minučių karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(3568, 143, 0, 3, 5, 0, 28, 6, 156, NULL, 'Minimalus pusvalandinis karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(3569, 143, 0, 3, 4, 0, 28, 6, 156, NULL, 'Maksimalus pusvalandinis karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(3570, 143, 0, 4, 5, 0, 28, 6, 156, NULL, 'Minimalus valandinis karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(3571, 143, 0, 4, 4, 0, 28, 6, 156, NULL, 'Maksimalus valandinis karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(3572, 39, 0, 4, 2, 0, 35, 4, 2, NULL, 'Dujų koreguotos masės kiekis per valandą', 1130, 2, NULL, NULL),
	(3573, 40, 0, 4, 2, 0, 31, 4, 4, NULL, 'Dujų koreguoto tūrio kiekis per valandą', 1131, 2, NULL, NULL),
	(3574, 41, 0, 4, 2, 0, 35, 4, 6, NULL, 'Dujų masės kiekis per valandą', 1128, 2, NULL, NULL),
	(3575, 43, 0, 4, 2, 0, 34, 4, 9, NULL, 'Dujų šilumos kiekis per valandą', 1127, 2, NULL, NULL),
	(3576, 45, 0, 4, 2, 0, 31, 4, 12, NULL, 'Dujų tūrio kiekis per valandą', 1129, 2, NULL, NULL),
	(3577, 48, 0, 4, 2, 0, 2, 4, 62, NULL, 'Šalčio energija per valandą', 1001, 2, NULL, NULL),
	(3578, 48, 1, 4, 2, 0, 2, 4, 62, NULL, 'Tiekiamo šalčio energija per valandą', 1001, 2, NULL, NULL),
	(3579, 48, 2, 4, 2, 0, 2, 4, 62, NULL, 'Grįžtamo šalčio energija per valandą', 1001, 2, NULL, NULL),
	(3580, 48, 3, 4, 2, 0, 2, 4, 62, NULL, 'Tiekiamo ir grįžtamo šalčio šilumos kiekių skirtumas per valandą', 1001, 2, NULL, NULL),
	(3581, 50, 0, 4, 2, 0, 31, 4, 66, NULL, 'Šalčio tūrio kiekis per valandą', 1010, 2, NULL, NULL),
	(3582, 50, 1, 4, 2, 0, 31, 4, 66, NULL, 'Tiekiamo šalčio tūrio kiekis per valandą', 1010, 2, NULL, NULL),
	(3583, 50, 2, 4, 2, 0, 31, 4, 66, NULL, 'Grįžtamo šalčio tūrio kiekis per valandą', 1010, 2, NULL, NULL),
	(3584, 50, 3, 4, 2, 0, 31, 4, 66, NULL, 'Tiekiamo ir grįžtamo šalčio tūrio kiekių skirtumas per valandą', 1010, 2, NULL, NULL),
	(3585, 51, 0, 4, 2, 0, 35, 4, 68, NULL, 'Šilumnešio masės kiekis per valandą', 1065, 2, NULL, NULL),
	(3586, 51, 1, 4, 2, 0, 35, 4, 68, NULL, 'Tiekiamo šilumnešio masės kiekis per valandą', 1065, 2, NULL, NULL),
	(3587, 51, 2, 4, 2, 0, 35, 4, 68, NULL, 'Grįžtamo šilumnešio masės kiekis per valandą', 1077, 2, NULL, NULL),
	(3588, 51, 3, 4, 2, 0, 35, 4, 68, NULL, 'Tiekiamo ir grįžtamo šilumnešio masės kiekių skirtumas per valandą', 1088, 2, NULL, NULL),
	(3589, 53, 0, 4, 2, 0, 2, 4, 71, NULL, 'Šilumnešio šilumos kiekis per valandą', 1064, 2, NULL, NULL),
	(3590, 53, 1, 4, 2, 0, 2, 4, 71, NULL, 'Tiekiamo šilumnešio šilumos kiekis per valandą', 1064, 2, NULL, NULL),
	(3591, 53, 2, 4, 2, 0, 2, 4, 71, NULL, 'Grįžtamo šilumnešio šilumos kiekis per valandą', 1076, 2, NULL, NULL),
	(3592, 53, 3, 4, 2, 0, 2, 4, 71, NULL, 'Sunaudotos šilumnešio šilumos kiekis per valandą', 1719, 2, NULL, NULL),
	(3593, 55, 0, 4, 2, 0, 31, 4, 74, NULL, 'Šilumnešio tūrio kiekis per valandą', 1066, 2, NULL, NULL),
	(3594, 55, 1, 4, 2, 0, 31, 4, 74, NULL, 'Tiekiamo šilumnešio tūrio kiekis per valandą', 1066, 2, NULL, NULL),
	(3595, 55, 2, 4, 2, 0, 31, 4, 74, NULL, 'Grįžtamo šilumnešio tūrio kiekis per valandą', 1078, 2, NULL, NULL),
	(3596, 55, 3, 4, 2, 0, 31, 4, 74, NULL, 'Tiekiamo ir grįžtamo šilumnešio tūrio kiekių skirtumas per valandą', 1737, 2, NULL, NULL),
	(3597, 56, 0, 4, 2, 0, 34, 4, 56, NULL, 'Šalto vandens šilumos kiekis per valandą', 1212, 2, NULL, NULL),
	(3598, 56, 1, 4, 2, 0, 34, 4, 56, NULL, 'Tiekiamo šalto vandens šilumos kiekis per valandą', 1212, 2, NULL, NULL),
	(3599, 56, 2, 4, 2, 0, 34, 4, 56, NULL, 'Grįžtamo šalto vandens šilumos kiekis per valandą', 1238, 2, NULL, NULL),
	(3600, 56, 3, 4, 2, 0, 34, 4, 56, NULL, 'Tiekiamo ir grįžtamo šalto vandens šilumos kiekių skirtumas per valandą', 1240, 2, NULL, NULL),
	(3601, 58, 0, 4, 2, 0, 31, 4, 59, NULL, 'Šalto vandens tūrio kiekis per valandą', 1214, 2, NULL, NULL),
	(3602, 58, 1, 4, 2, 0, 31, 4, 59, NULL, 'Tiekiamo šalto vandens tūrio kiekis per valandą', 1214, 2, NULL, NULL),
	(3603, 58, 2, 4, 2, 0, 31, 4, 59, NULL, 'Grįžtamo šalto vandens tūrio kiekis per valandą', 1259, 2, NULL, NULL),
	(3604, 58, 3, 4, 2, 0, 31, 4, 59, NULL, 'Tiekiamo ir grįžtamo šalto vandens tūrio kiekių skirtumas per valandą', 1214, 2, NULL, NULL),
	(3605, 1, 1, 4, 2, 0, 2, 4, 14, NULL, 'A+ energija per valandą', 709, 2, NULL, NULL),
	(3606, 1, 2, 4, 2, 0, 2, 4, 14, NULL, 'A- energija per valandą', 710, 2, NULL, NULL),
	(3607, 3, 1, 4, 2, 0, 4, 4, 15, NULL, 'R+ energija per valandą', 711, 2, NULL, NULL),
	(3608, 3, 2, 4, 2, 0, 4, 4, 15, NULL, 'R- energija per valandą', 712, 2, NULL, NULL),
	(3609, 3, 5, 4, 2, 0, 4, 4, 15, NULL, 'R1 energija per valandą', 713, 2, NULL, NULL),
	(3610, 3, 6, 4, 2, 0, 4, 4, 15, NULL, 'R2 energija per valandą', 714, 2, NULL, NULL),
	(3611, 3, 7, 4, 2, 0, 4, 4, 15, NULL, 'R3 energija per valandą', 715, 2, NULL, NULL),
	(3612, 3, 8, 4, 2, 0, 4, 4, 15, NULL, 'R4 energija per valandą', 716, 2, NULL, NULL),
	(3613, 34, 1, 4, 2, 0, 41, 4, 45, NULL, 'W+ energija per valandą', 717, 2, NULL, NULL),
	(3614, 34, 2, 4, 2, 0, 41, 4, 45, NULL, 'W- energija per valandą', 718, 2, NULL, NULL),
	(3615, 61, 0, 4, 2, 0, 31, 4, 53, NULL, 'Karšto vandens tūrio kiekis per valandą', 1214, 2, NULL, NULL),
	(3616, 61, 1, 4, 2, 0, 31, 4, 53, NULL, 'Tiekiamo karšto vandens tūrio kiekis per valandą', 1214, 2, NULL, NULL),
	(3617, 61, 2, 4, 2, 0, 31, 4, 53, NULL, 'Grįžtamo karšto vandens tūrio kiekis per valandą', 1259, 2, NULL, NULL),
	(3618, 61, 3, 4, 2, 0, 31, 4, 53, NULL, 'Tiekiamo ir grįžtamo karšto vandens tūrio kiekių skirtumas per valandą', 1214, 2, NULL, NULL),
	(3619, 59, 0, 4, 2, 0, 34, 4, 51, NULL, 'Karšto vandens šilumos kiekis per valandą', 1212, 2, NULL, NULL),
	(3620, 59, 1, 4, 2, 0, 34, 4, 51, NULL, 'Tiekiamo karšto vandens šilumos kiekis per valandą', 1212, 2, NULL, NULL),
	(3621, 59, 2, 4, 2, 0, 34, 4, 51, NULL, 'Grįžtamo karšto vandens šilumos kiekis per valandą', 1238, 2, NULL, NULL),
	(3622, 59, 3, 4, 2, 0, 34, 4, 51, NULL, 'Sunaudotos karšto vandens šilumos kiekis per valandą', 1240, 2, NULL, NULL),
	(3623, 144, 0, 7, 1, 0, 0, 7, 157, NULL, 'Klaidos kodas', 3101, 6, NULL, NULL),
	(3624, 145, 0, 5, 3, 0, 0, 5, 158, NULL, 'Įtampos nukrypimo neatitikimas standartui per parą', 3104, 3, NULL, NULL),
	(3625, 146, 0, 5, 3, 0, 0, 5, 159, NULL, 'Dažnio nukrypimo neatitikimas standartui per parą', 3105, 3, NULL, NULL),
	(3626, 147, 0, 5, 3, 0, 0, 5, 160, NULL, 'Sinusoidės iškreipimo L1 fazėje neatitikimas standartui per parą', 3106, 3, NULL, NULL),
	(3627, 148, 0, 5, 3, 0, 0, 5, 161, NULL, 'Sinusoidės iškreipimo L2 fazėje neatitikimas standartui per parą', 3107, 3, NULL, NULL),
	(3628, 149, 0, 5, 3, 0, 0, 5, 162, NULL, 'Sinusoidės iškreipimo L3 fazėje neatitikimas standartui per parą', 3108, 3, NULL, NULL),
	(3629, 150, 0, 5, 3, 0, 0, 5, 163, NULL, 'U2 nesimetrijos neatitikimas standartui per parą', 3109, 3, NULL, NULL),
	(3630, 151, 0, 5, 3, 0, 0, 5, 164, NULL, 'U0 nesimetrijos neatitikimas standartui per parą', 3110, 3, NULL, NULL),
	(3631, 152, 0, 5, 3, 0, 0, 5, 165, NULL, 'Pst mirksėjimo dozės L1 fazėje neatitikimas standartui per parą', 3111, 3, NULL, NULL),
	(3632, 153, 0, 5, 3, 0, 0, 5, 166, NULL, 'Pst mirksėjimo dozės L2 fazėje neatitikimas standartui per parą', 3112, 3, NULL, NULL),
	(3633, 154, 0, 5, 3, 0, 0, 5, 167, NULL, 'Pst mirksėjimo dozės L3 fazėje neatitikimas standartui per parą', 3113, 3, NULL, NULL),
	(3634, 155, 0, 5, 3, 0, 0, 5, 168, NULL, 'Plt mirksėjimo dozės L1 fazėje neatitikimas standartui per parą', 3114, 3, NULL, NULL),
	(3635, 156, 0, 5, 3, 0, 0, 5, 169, NULL, 'Plt mirksėjimo dozės L2 fazėje neatitikimas standartui per parą', 3115, 3, NULL, NULL),
	(3636, 157, 0, 5, 3, 0, 0, 5, 170, NULL, 'Plt mirksėjimo dozės L3 fazėje neatitikimas standartui per parą', 3116, 3, NULL, NULL),
	(3637, 158, 0, 5, 3, 0, 0, 5, 171, NULL, 'Harmonikos koeficientų L1 fazėje neatitikimas standartui per parą', 3117, 3, NULL, NULL),
	(3638, 159, 0, 5, 3, 0, 0, 5, 172, NULL, 'Harmonikos koeficientų L2 fazėje neatitikimas standartui per parą', 3118, 3, NULL, NULL),
	(3639, 160, 0, 5, 3, 0, 0, 5, 173, NULL, 'Harmonikos koeficientų L3 fazėje neatitikimas standartui per parą', 3119, 3, NULL, NULL),
	(3640, 144, 0, 4, 2, 0, 0, 4, 157, NULL, 'Klaidos kodas per valandą', 3101, 2, NULL, NULL),
	(3641, 144, 0, 5, 2, 0, 0, 5, 157, NULL, 'Klaidos kodas per parą', 3101, 3, NULL, NULL),
	(3642, 161, 0, 7, 1, 0, 56, 7, 174, NULL, 'Įtampos fazių poslinkio kampas L1 fazėje', 3132, 6, NULL, NULL),
	(3643, 162, 0, 7, 1, 0, 56, 7, 175, NULL, 'Įtampos fazių poslinkio kampas L2 fazėje', 3133, 6, NULL, NULL),
	(3644, 163, 0, 7, 1, 0, 56, 7, 176, NULL, 'Įtampos fazių poslinkio kampas L3 fazėje', 3134, 6, NULL, NULL),
	(3645, 164, 0, 7, 1, 0, 56, 7, 177, NULL, 'Srovės fazių poslinkio kampas L1 fazėje', 3135, 6, NULL, NULL),
	(3646, 165, 0, 7, 1, 0, 56, 7, 178, NULL, 'Srovės fazių poslinkio kampas L2 fazėje', 3136, 6, NULL, NULL),
	(3647, 166, 0, 7, 1, 0, 56, 7, 179, NULL, 'Srovės fazių poslinkio kampas L3 fazėje', 3137, 6, NULL, NULL),
	(3648, 1, 1, 3, 4, 1, 1, 6, 13, NULL, 'Maksimali pusvalandinė P+ galia pagal 1 tarifą per mėnesį', 358, 4, NULL, NULL),
	(3649, 1, 2, 3, 4, 1, 1, 6, 13, NULL, 'Maksimali pusvalandinė P- galia pagal 1 tarifą per mėnesį', 359, 4, NULL, NULL),
	(3650, 3, 1, 3, 4, 1, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q+ galia pagal 1 tarifą per mėnesį', 360, 4, NULL, NULL),
	(3651, 3, 2, 3, 4, 1, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q- galia pagal 1 tarifą per mėnesį', 361, 4, NULL, NULL),
	(3652, 1, 1, 4, 4, 1, 1, 6, 13, NULL, 'Maksimali valandinė P+ galia pagal 1 tarifą per mėnesį', 358, 4, NULL, NULL),
	(3653, 1, 2, 4, 4, 1, 1, 6, 13, NULL, 'Maksimali valandinė P- galia pagal 1 tarifą per mėnesį', 359, 4, NULL, NULL),
	(3654, 3, 1, 4, 4, 1, 3, 6, 16, NULL, 'Maksimali valandinė Q+ galia pagal 1 tarifą per mėnesį', 360, 4, NULL, NULL),
	(3655, 3, 2, 4, 4, 1, 3, 6, 16, NULL, 'Maksimali valandinė Q- galia pagal 1 tarifą per mėnesį', 361, 4, NULL, NULL),
	(3656, 1, 1, 9, 4, 1, 1, 6, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 1 tarifą per mėnesį', 358, 4, NULL, NULL),
	(3657, 1, 2, 9, 4, 1, 1, 6, 13, NULL, 'Maksimali 3 minučių P- galia pagal 1 tarifą per mėnesį', 359, 4, NULL, NULL),
	(3658, 3, 1, 9, 4, 1, 3, 6, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 1 tarifą per mėnesį', 360, 4, NULL, NULL),
	(3659, 3, 2, 9, 4, 1, 3, 6, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 1 tarifą per mėnesį', 361, 4, NULL, NULL),
	(3660, 1, 1, 13, 4, 1, 1, 6, 13, NULL, 'Maksimali 15 minučių P+ galia pagal 1 tarifą per mėnesį', 358, 4, NULL, NULL),
	(3661, 1, 2, 13, 4, 1, 1, 6, 13, NULL, 'Maksimali 15 minučių P- galia pagal 1 tarifą per mėnesį', 359, 4, NULL, NULL),
	(3662, 3, 1, 13, 4, 1, 3, 6, 16, NULL, 'Maksimali 15 minučių Q+ galia pagal 1 tarifą per mėnesį', 360, 4, NULL, NULL),
	(3663, 3, 2, 13, 4, 1, 3, 6, 16, NULL, 'Maksimali 15 minučių Q- galia pagal 1 tarifą per mėnesį', 361, 4, NULL, NULL),
	(3664, 1, 1, 3, 4, 2, 1, 6, 13, NULL, 'Maksimali pusvalandinė P+ galia pagal 2 tarifą per mėnesį', 362, 4, NULL, NULL),
	(3665, 1, 2, 3, 4, 2, 1, 6, 13, NULL, 'Maksimali pusvalandinė P- galia pagal 2 tarifą per mėnesį', 363, 4, NULL, NULL),
	(3666, 3, 1, 3, 4, 2, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q+ galia pagal 2 tarifą per mėnesį', 364, 4, NULL, NULL),
	(3667, 3, 2, 3, 4, 2, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q- galia pagal 2 tarifą per mėnesį', 365, 4, NULL, NULL),
	(3668, 1, 1, 4, 4, 2, 1, 6, 13, NULL, 'Maksimali valandinė P+ galia pagal 2 tarifą per mėnesį', 362, 4, NULL, NULL),
	(3669, 1, 2, 4, 4, 2, 1, 6, 13, NULL, 'Maksimali valandinė P- galia pagal 2 tarifą per mėnesį', 363, 4, NULL, NULL),
	(3670, 3, 1, 4, 4, 2, 3, 6, 16, NULL, 'Maksimali valandinė Q+ galia pagal 2 tarifą per mėnesį', 364, 4, NULL, NULL),
	(3671, 3, 2, 4, 4, 2, 3, 6, 16, NULL, 'Maksimali valandinė Q- galia pagal 2 tarifą per mėnesį', 365, 4, NULL, NULL),
	(3672, 1, 1, 9, 4, 2, 1, 6, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 2 tarifą per mėnesį', 362, 4, NULL, NULL),
	(3673, 1, 2, 9, 4, 2, 1, 6, 13, NULL, 'Maksimali 3 minučių P- galia pagal 2 tarifą per mėnesį', 363, 4, NULL, NULL),
	(3674, 3, 1, 9, 4, 2, 3, 6, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 2 tarifą per mėnesį', 364, 4, NULL, NULL),
	(3675, 3, 2, 9, 4, 2, 3, 6, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 2 tarifą per mėnesį', 365, 4, NULL, NULL),
	(3676, 1, 1, 13, 4, 2, 1, 6, 13, NULL, 'Maksimali 15 minučių P+ galia pagal 2 tarifą per mėnesį', 362, 4, NULL, NULL),
	(3677, 1, 2, 13, 4, 2, 1, 6, 13, NULL, 'Maksimali 15 minučių P- galia pagal 2 tarifą per mėnesį', 363, 4, NULL, NULL),
	(3678, 3, 1, 13, 4, 2, 3, 6, 16, NULL, 'Maksimali 15 minučių Q+ galia pagal 2 tarifą per mėnesį', 364, 4, NULL, NULL),
	(3679, 3, 2, 13, 4, 2, 3, 6, 16, NULL, 'Maksimali 15 minučių Q- galia pagal 2 tarifą per mėnesį', 365, 4, NULL, NULL),
	(3680, 1, 1, 3, 4, 3, 1, 6, 13, NULL, 'Maksimali pusvalandinė P+ galia pagal 3 tarifą per mėnesį', 366, 4, NULL, NULL),
	(3681, 1, 2, 3, 4, 3, 1, 6, 13, NULL, 'Maksimali pusvalandinė P- galia pagal 3 tarifą per mėnesį', 367, 4, NULL, NULL),
	(3682, 3, 1, 3, 4, 3, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q+ galia pagal 3 tarifą per mėnesį', 368, 4, NULL, NULL),
	(3683, 3, 2, 3, 4, 3, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q- galia pagal 3 tarifą per mėnesį', 369, 4, NULL, NULL),
	(3684, 1, 1, 4, 4, 3, 1, 6, 13, NULL, 'Maksimali valandinė P+ galia pagal 3 tarifą per mėnesį', 366, 4, NULL, NULL),
	(3685, 1, 2, 4, 4, 3, 1, 6, 13, NULL, 'Maksimali valandinė P- galia pagal 3 tarifą per mėnesį', 367, 4, NULL, NULL),
	(3686, 3, 1, 4, 4, 3, 3, 6, 16, NULL, 'Maksimali valandinė Q+ galia pagal 3 tarifą per mėnesį', 368, 4, NULL, NULL),
	(3687, 3, 2, 4, 4, 3, 3, 6, 16, NULL, 'Maksimali valandinė Q- galia pagal 3 tarifą per mėnesį', 369, 4, NULL, NULL),
	(3688, 1, 1, 9, 4, 3, 1, 6, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 3 tarifą per mėnesį', 366, 4, NULL, NULL),
	(3689, 1, 2, 9, 4, 3, 1, 6, 13, NULL, 'Maksimali 3 minučių P- galia pagal 3 tarifą per mėnesį', 367, 4, NULL, NULL),
	(3690, 3, 1, 9, 4, 3, 3, 6, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 3 tarifą per mėnesį', 368, 4, NULL, NULL),
	(3691, 3, 2, 9, 4, 3, 3, 6, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 3 tarifą per mėnesį', 369, 4, NULL, NULL),
	(3692, 1, 1, 13, 4, 3, 1, 6, 13, NULL, 'Maksimali 15 minučių P+ galia pagal 3 tarifą per mėnesį', 366, 4, NULL, NULL),
	(3693, 1, 2, 13, 4, 3, 1, 6, 13, NULL, 'Maksimali 15 minučių P- galia pagal 3 tarifą per mėnesį', 367, 4, NULL, NULL),
	(3694, 3, 1, 13, 4, 3, 3, 6, 16, NULL, 'Maksimali 15 minučių Q+ galia pagal 3 tarifą per mėnesį', 368, 4, NULL, NULL),
	(3695, 3, 2, 13, 4, 3, 3, 6, 16, NULL, 'Maksimali 15 minučių Q- galia pagal 3 tarifą per mėnesį', 369, 4, NULL, NULL),
	(3696, 1, 1, 3, 4, 4, 1, 6, 13, NULL, 'Maksimali pusvalandinė P+ galia pagal 4 tarifą per mėnesį', 370, 4, NULL, NULL),
	(3697, 1, 2, 3, 4, 4, 1, 6, 13, NULL, 'Maksimali pusvalandinė P- galia pagal 4 tarifą per mėnesį', 371, 4, NULL, NULL),
	(3698, 3, 1, 3, 4, 4, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q+ galia pagal 4 tarifą per mėnesį', 372, 4, NULL, NULL),
	(3699, 3, 2, 3, 4, 4, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q- galia pagal 4 tarifą per mėnesį', 373, 4, NULL, NULL),
	(3700, 1, 1, 4, 4, 4, 1, 6, 13, NULL, 'Maksimali valandinė P+ galia pagal 4 tarifą per mėnesį', 370, 4, NULL, NULL),
	(3701, 1, 2, 4, 4, 4, 1, 6, 13, NULL, 'Maksimali valandinė P- galia pagal 4 tarifą per mėnesį', 371, 4, NULL, NULL),
	(3702, 3, 1, 4, 4, 4, 3, 6, 16, NULL, 'Maksimali valandinė Q+ galia pagal 4 tarifą per mėnesį', 372, 4, NULL, NULL),
	(3703, 3, 2, 4, 4, 4, 3, 6, 16, NULL, 'Maksimali valandinė Q- galia pagal 4 tarifą per mėnesį', 373, 4, NULL, NULL),
	(3704, 1, 1, 9, 4, 4, 1, 6, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 4 tarifą per mėnesį', 370, 4, NULL, NULL),
	(3705, 1, 2, 9, 4, 4, 1, 6, 13, NULL, 'Maksimali 3 minučių P- galia pagal 4 tarifą per mėnesį', 371, 4, NULL, NULL),
	(3706, 3, 1, 9, 4, 4, 3, 6, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 4 tarifą per mėnesį', 372, 4, NULL, NULL),
	(3707, 3, 2, 9, 4, 4, 3, 6, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 4 tarifą per mėnesį', 373, 4, NULL, NULL),
	(3708, 1, 1, 13, 4, 4, 1, 6, 13, NULL, 'Maksimali 15 minučių P+ galia pagal 4 tarifą per mėnesį', 370, 4, NULL, NULL),
	(3709, 1, 2, 13, 4, 4, 1, 6, 13, NULL, 'Maksimali 15 minučių P- galia pagal 4 tarifą per mėnesį', 371, 4, NULL, NULL),
	(3710, 3, 1, 13, 4, 4, 3, 6, 16, NULL, 'Maksimali 15 minučių Q+ galia pagal 4 tarifą per mėnesį', 372, 4, NULL, NULL),
	(3711, 3, 2, 13, 4, 4, 3, 6, 16, NULL, 'Maksimali 15 minučių Q- galia pagal 4 tarifą per mėnesį', 373, 4, NULL, NULL),
	(3712, 1, 1, 3, 4, 1, 1, 5, 13, NULL, 'Maksimali pusvalandinė P+ galia pagal 1 tarifą per parą', 378, 3, NULL, NULL),
	(3713, 1, 2, 3, 4, 1, 1, 5, 13, NULL, 'Maksimali pusvalandinė P- galia pagal 1 tarifą per parą', 379, 3, NULL, NULL),
	(3714, 3, 1, 3, 4, 1, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q+ galia pagal 1 tarifą per parą', 380, 3, NULL, NULL),
	(3715, 3, 2, 3, 4, 1, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q- galia pagal 1 tarifą per parą', 381, 3, NULL, NULL),
	(3716, 1, 1, 4, 4, 1, 1, 5, 13, NULL, 'Maksimali valandinė P+ galia pagal 1 tarifą per parą', 378, 3, NULL, NULL),
	(3717, 1, 2, 4, 4, 1, 1, 5, 13, NULL, 'Maksimali valandinė P- galia pagal 1 tarifą per parą', 379, 3, NULL, NULL),
	(3718, 3, 1, 4, 4, 1, 3, 5, 16, NULL, 'Maksimali valandinė Q+ galia pagal 1 tarifą per parą', 380, 3, NULL, NULL),
	(3719, 3, 2, 4, 4, 1, 3, 5, 16, NULL, 'Maksimali valandinė Q- galia pagal 1 tarifą per parą', 381, 3, NULL, NULL),
	(3720, 1, 1, 9, 4, 1, 1, 5, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 1 tarifą per parą', 378, 3, NULL, NULL),
	(3721, 1, 2, 9, 4, 1, 1, 5, 13, NULL, 'Maksimali 3 minučių P- galia pagal 1 tarifą per parą', 379, 3, NULL, NULL),
	(3722, 3, 1, 9, 4, 1, 3, 5, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 1 tarifą per parą', 380, 3, NULL, NULL),
	(3723, 3, 2, 9, 4, 1, 3, 5, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 1 tarifą per parą', 381, 3, NULL, NULL),
	(3724, 1, 1, 13, 4, 1, 1, 5, 13, NULL, 'Maksimali 15 minučių P+ galia pagal 1 tarifą per parą', 378, 3, NULL, NULL),
	(3725, 1, 2, 13, 4, 1, 1, 5, 13, NULL, 'Maksimali 15 minučių P- galia pagal 1 tarifą per parą', 379, 3, NULL, NULL),
	(3726, 3, 1, 13, 4, 1, 3, 5, 16, NULL, 'Maksimali 15 minučių Q+ galia pagal 1 tarifą per parą', 380, 3, NULL, NULL),
	(3727, 3, 2, 13, 4, 1, 3, 5, 16, NULL, 'Maksimali 15 minučių Q- galia pagal 1 tarifą per parą', 381, 3, NULL, NULL),
	(3728, 1, 1, 3, 4, 2, 1, 5, 13, NULL, 'Maksimali pusvalandinė P+ galia pagal 2 tarifą per parą', 382, 3, NULL, NULL),
	(3729, 1, 2, 3, 4, 2, 1, 5, 13, NULL, 'Maksimali pusvalandinė P- galia pagal 2 tarifą per parą', 383, 3, NULL, NULL),
	(3730, 3, 1, 3, 4, 2, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q+ galia pagal 2 tarifą per parą', 384, 3, NULL, NULL),
	(3731, 3, 2, 3, 4, 2, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q- galia pagal 2 tarifą per parą', 385, 3, NULL, NULL),
	(3732, 1, 1, 4, 4, 2, 1, 5, 13, NULL, 'Maksimali valandinė P+ galia pagal 2 tarifą per parą', 382, 3, NULL, NULL),
	(3733, 1, 2, 4, 4, 2, 1, 5, 13, NULL, 'Maksimali valandinė P- galia pagal 2 tarifą per parą', 383, 3, NULL, NULL),
	(3734, 3, 1, 4, 4, 2, 3, 5, 16, NULL, 'Maksimali valandinė Q+ galia pagal 2 tarifą per parą', 384, 3, NULL, NULL),
	(3735, 3, 2, 4, 4, 2, 3, 5, 16, NULL, 'Maksimali valandinė Q- galia pagal 2 tarifą per parą', 385, 3, NULL, NULL),
	(3736, 1, 1, 9, 4, 2, 1, 5, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 2 tarifą per parą', 382, 3, NULL, NULL),
	(3737, 1, 2, 9, 4, 2, 1, 5, 13, NULL, 'Maksimali 3 minučių P- galia pagal 2 tarifą per parą', 383, 3, NULL, NULL),
	(3738, 3, 1, 9, 4, 2, 3, 5, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 2 tarifą per parą', 384, 3, NULL, NULL),
	(3739, 3, 2, 9, 4, 2, 3, 5, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 2 tarifą per parą', 385, 3, NULL, NULL),
	(3740, 1, 1, 13, 4, 2, 1, 5, 13, NULL, 'Maksimali 15 minučių P+ galia pagal 2 tarifą per parą', 382, 3, NULL, NULL),
	(3741, 1, 2, 13, 4, 2, 1, 5, 13, NULL, 'Maksimali 15 minučių P- galia pagal 2 tarifą per parą', 383, 3, NULL, NULL),
	(3742, 3, 1, 13, 4, 2, 3, 5, 16, NULL, 'Maksimali 15 minučių Q+ galia pagal 2 tarifą per parą', 384, 3, NULL, NULL),
	(3743, 3, 2, 13, 4, 2, 3, 5, 16, NULL, 'Maksimali 15 minučių Q- galia pagal 2 tarifą per parą', 385, 3, NULL, NULL),
	(3744, 1, 1, 3, 4, 3, 1, 5, 13, NULL, 'Maksimali pusvalandinė P+ galia pagal 3 tarifą per parą', 386, 3, NULL, NULL),
	(3745, 1, 2, 3, 4, 3, 1, 5, 13, NULL, 'Maksimali pusvalandinė P- galia pagal 3 tarifą per parą', 387, 3, NULL, NULL),
	(3746, 3, 1, 3, 4, 3, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q+ galia pagal 3 tarifą per parą', 388, 3, NULL, NULL),
	(3747, 3, 2, 3, 4, 3, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q- galia pagal 3 tarifą per parą', 389, 3, NULL, NULL),
	(3748, 1, 1, 4, 4, 3, 1, 5, 13, NULL, 'Maksimali valandinė P+ galia pagal 3 tarifą per parą', 386, 3, NULL, NULL),
	(3749, 1, 2, 4, 4, 3, 1, 5, 13, NULL, 'Maksimali valandinė P- galia pagal 3 tarifą per parą', 387, 3, NULL, NULL),
	(3750, 3, 1, 4, 4, 3, 3, 5, 16, NULL, 'Maksimali valandinė Q+ galia pagal 3 tarifą per parą', 388, 3, NULL, NULL),
	(3751, 3, 2, 4, 4, 3, 3, 5, 16, NULL, 'Maksimali valandinė Q- galia pagal 3 tarifą per parą', 389, 3, NULL, NULL),
	(3752, 1, 1, 9, 4, 3, 1, 5, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 3 tarifą per parą', 386, 3, NULL, NULL),
	(3753, 1, 2, 9, 4, 3, 1, 5, 13, NULL, 'Maksimali 3 minučių P- galia pagal 3 tarifą per parą', 387, 3, NULL, NULL),
	(3754, 3, 1, 9, 4, 3, 3, 5, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 3 tarifą per parą', 388, 3, NULL, NULL),
	(3755, 3, 2, 9, 4, 3, 3, 5, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 3 tarifą per parą', 389, 3, NULL, NULL),
	(3756, 1, 1, 13, 4, 3, 1, 5, 13, NULL, 'Maksimali 15 minučių P+ galia pagal 3 tarifą per parą', 386, 3, NULL, NULL),
	(3757, 1, 2, 13, 4, 3, 1, 5, 13, NULL, 'Maksimali 15 minučių P- galia pagal 3 tarifą per parą', 387, 3, NULL, NULL),
	(3758, 3, 1, 13, 4, 3, 3, 5, 16, NULL, 'Maksimali 15 minučių Q+ galia pagal 3 tarifą per parą', 388, 3, NULL, NULL),
	(3759, 3, 2, 13, 4, 3, 3, 5, 16, NULL, 'Maksimali 15 minučių Q- galia pagal 3 tarifą per parą', 389, 3, NULL, NULL),
	(3760, 1, 1, 3, 4, 4, 1, 5, 13, NULL, 'Maksimali pusvalandinė P+ galia pagal 4 tarifą per parą', 390, 3, NULL, NULL),
	(3761, 1, 2, 3, 4, 4, 1, 5, 13, NULL, 'Maksimali pusvalandinė P- galia pagal 4 tarifą per parą', 391, 3, NULL, NULL),
	(3762, 3, 1, 3, 4, 4, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q+ galia pagal 4 tarifą per parą', 392, 3, NULL, NULL),
	(3763, 3, 2, 3, 4, 4, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q- galia pagal 4 tarifą per parą', 393, 3, NULL, NULL),
	(3764, 1, 1, 4, 4, 4, 1, 5, 13, NULL, 'Maksimali valandinė P+ galia pagal 4 tarifą per parą', 390, 3, NULL, NULL),
	(3765, 1, 2, 4, 4, 4, 1, 5, 13, NULL, 'Maksimali valandinė P- galia pagal 4 tarifą per parą', 391, 3, NULL, NULL),
	(3766, 3, 1, 4, 4, 4, 3, 5, 16, NULL, 'Maksimali valandinė Q+ galia pagal 4 tarifą per parą', 392, 3, NULL, NULL),
	(3767, 3, 2, 4, 4, 4, 3, 5, 16, NULL, 'Maksimali valandinė Q- galia pagal 4 tarifą per parą', 393, 3, NULL, NULL),
	(3768, 1, 1, 9, 4, 4, 1, 5, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 4 tarifą per parą', 390, 3, NULL, NULL),
	(3769, 1, 2, 9, 4, 4, 1, 5, 13, NULL, 'Maksimali 3 minučių P- galia pagal 4 tarifą per parą', 391, 3, NULL, NULL),
	(3770, 3, 1, 9, 4, 4, 3, 5, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 4 tarifą per parą', 392, 3, NULL, NULL),
	(3771, 3, 2, 9, 4, 4, 3, 5, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 4 tarifą per parą', 393, 3, NULL, NULL),
	(3772, 1, 1, 13, 4, 4, 1, 5, 13, NULL, 'Maksimali 15 minučių P+ galia pagal 4 tarifą per parą', 390, 3, NULL, NULL),
	(3773, 1, 2, 13, 4, 4, 1, 5, 13, NULL, 'Maksimali 15 minučių P- galia pagal 4 tarifą per parą', 391, 3, NULL, NULL),
	(3774, 3, 1, 13, 4, 4, 3, 5, 16, NULL, 'Maksimali 15 minučių Q+ galia pagal 4 tarifą per parą', 392, 3, NULL, NULL),
	(3775, 3, 2, 13, 4, 4, 3, 5, 16, NULL, 'Maksimali 15 minučių Q- galia pagal 4 tarifą per parą', 393, 3, NULL, NULL),
	(3776, 3, 5, 3, 4, 1, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q1 galia pagal 1 tarifą per mėnesį', 398, 4, NULL, NULL),
	(3777, 3, 6, 3, 4, 1, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q2 galia pagal 1 tarifą per mėnesį', 399, 4, NULL, NULL),
	(3778, 3, 7, 3, 4, 1, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q3 galia pagal 1 tarifą per mėnesį', 400, 4, NULL, NULL),
	(3779, 3, 8, 3, 4, 1, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q4 galia pagal 1 tarifą per mėnesį', 401, 4, NULL, NULL),
	(3780, 34, 1, 3, 4, 1, 7, 6, 44, NULL, 'Maksimali pusvalandinė S+ galia pagal 1 tarifą per mėnesį', 402, 4, NULL, NULL),
	(3781, 34, 2, 3, 4, 1, 7, 6, 44, NULL, 'Maksimali pusvalandinė S- galia pagal 1 tarifą per mėnesį', 403, 4, NULL, NULL),
	(3782, 3, 5, 4, 4, 1, 3, 6, 16, NULL, 'Maksimali valandinė Q1 galia pagal 1 tarifą per mėnesį', 398, 4, NULL, NULL),
	(3783, 3, 6, 4, 4, 1, 3, 6, 16, NULL, 'Maksimali valandinė Q2 galia pagal 1 tarifą per mėnesį', 399, 4, NULL, NULL),
	(3784, 3, 7, 4, 4, 1, 3, 6, 16, NULL, 'Maksimali valandinė Q3 galia pagal 1 tarifą per mėnesį', 400, 4, NULL, NULL),
	(3785, 3, 8, 4, 4, 1, 3, 6, 16, NULL, 'Maksimali valandinė Q4 galia pagal 1 tarifą per mėnesį', 401, 4, NULL, NULL),
	(3786, 34, 1, 4, 4, 1, 7, 6, 44, NULL, 'Maksimali valandinė S+ galia pagal 1 tarifą per mėnesį', 402, 4, NULL, NULL),
	(3787, 34, 2, 4, 4, 1, 7, 6, 44, NULL, 'Maksimali valandinė S- galia pagal 1 tarifą per mėnesį', 403, 4, NULL, NULL),
	(3788, 3, 5, 9, 4, 1, 3, 6, 16, NULL, 'Maksimali 3 minučių Q1 galia pagal 1 tarifą per mėnesį', 398, 4, NULL, NULL),
	(3789, 3, 6, 9, 4, 1, 3, 6, 16, NULL, 'Maksimali 3 minučių Q2 galia pagal 1 tarifą per mėnesį', 399, 4, NULL, NULL),
	(3790, 3, 7, 9, 4, 1, 3, 6, 16, NULL, 'Maksimali 3 minučių Q3 galia pagal 1 tarifą per mėnesį', 400, 4, NULL, NULL),
	(3791, 3, 8, 9, 4, 1, 3, 6, 16, NULL, 'Maksimali 3 minučių Q4 galia pagal 1 tarifą per mėnesį', 401, 4, NULL, NULL),
	(3792, 34, 1, 9, 4, 1, 7, 6, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 1 tarifą per mėnesį', 402, 4, NULL, NULL),
	(3793, 34, 2, 9, 4, 1, 7, 6, 44, NULL, 'Maksimali 3 minučių S- galia pagal 1 tarifą per mėnesį', 403, 4, NULL, NULL),
	(3794, 3, 5, 13, 4, 1, 3, 6, 16, NULL, 'Maksimali 15 minučių Q1 galia pagal 1 tarifą per mėnesį', 398, 4, NULL, NULL),
	(3795, 3, 6, 13, 4, 1, 3, 6, 16, NULL, 'Maksimali 15 minučių Q2 galia pagal 1 tarifą per mėnesį', 399, 4, NULL, NULL),
	(3796, 3, 7, 13, 4, 1, 3, 6, 16, NULL, 'Maksimali 15 minučių Q3 galia pagal 1 tarifą per mėnesį', 400, 4, NULL, NULL),
	(3797, 3, 8, 13, 4, 1, 3, 6, 16, NULL, 'Maksimali 15 minučių Q4 galia pagal 1 tarifą per mėnesį', 401, 4, NULL, NULL),
	(3798, 34, 1, 13, 4, 1, 7, 6, 44, NULL, 'Maksimali 15 minučių S+ galia pagal 1 tarifą per mėnesį', 402, 4, NULL, NULL),
	(3799, 34, 2, 13, 4, 1, 7, 6, 44, NULL, 'Maksimali 15 minučių S- galia pagal 1 tarifą per mėnesį', 403, 4, NULL, NULL),
	(3800, 3, 5, 3, 4, 2, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q1 galia pagal 2 tarifą per mėnesį', 404, 4, NULL, NULL),
	(3801, 3, 6, 3, 4, 2, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q2 galia pagal 2 tarifą per mėnesį', 405, 4, NULL, NULL),
	(3802, 3, 7, 3, 4, 2, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q3 galia pagal 2 tarifą per mėnesį', 406, 4, NULL, NULL),
	(3803, 3, 8, 3, 4, 2, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q4 galia pagal 2 tarifą per mėnesį', 407, 4, NULL, NULL),
	(3804, 34, 1, 3, 4, 2, 7, 6, 44, NULL, 'Maksimali pusvalandinė S+ galia pagal 2 tarifą per mėnesį', 408, 4, NULL, NULL),
	(3805, 34, 2, 3, 4, 2, 7, 6, 44, NULL, 'Maksimali pusvalandinė S- galia pagal 2 tarifą per mėnesį', 409, 4, NULL, NULL),
	(3806, 3, 5, 4, 4, 2, 3, 6, 16, NULL, 'Maksimali valandinė Q1 galia pagal 2 tarifą per mėnesį', 404, 4, NULL, NULL),
	(3807, 3, 6, 4, 4, 2, 3, 6, 16, NULL, 'Maksimali valandinė Q2 galia pagal 2 tarifą per mėnesį', 405, 4, NULL, NULL),
	(3808, 3, 7, 4, 4, 2, 3, 6, 16, NULL, 'Maksimali valandinė Q3 galia pagal 2 tarifą per mėnesį', 406, 4, NULL, NULL),
	(3809, 3, 8, 4, 4, 2, 3, 6, 16, NULL, 'Maksimali valandinė Q4 galia pagal 2 tarifą per mėnesį', 407, 4, NULL, NULL),
	(3810, 34, 1, 4, 4, 2, 7, 6, 44, NULL, 'Maksimali valandinė S+ galia pagal 2 tarifą per mėnesį', 408, 4, NULL, NULL),
	(3811, 34, 2, 4, 4, 2, 7, 6, 44, NULL, 'Maksimali valandinė S- galia pagal 2 tarifą per mėnesį', 409, 4, NULL, NULL),
	(3812, 3, 5, 9, 4, 2, 3, 6, 16, NULL, 'Maksimali 3 minučių Q1 galia pagal 2 tarifą per mėnesį', 404, 4, NULL, NULL),
	(3813, 3, 6, 9, 4, 2, 3, 6, 16, NULL, 'Maksimali 3 minučių Q2 galia pagal 2 tarifą per mėnesį', 405, 4, NULL, NULL),
	(3814, 3, 7, 9, 4, 2, 3, 6, 16, NULL, 'Maksimali 3 minučių Q3 galia pagal 2 tarifą per mėnesį', 406, 4, NULL, NULL),
	(3815, 3, 8, 9, 4, 2, 3, 6, 16, NULL, 'Maksimali 3 minučių Q4 galia pagal 2 tarifą per mėnesį', 407, 4, NULL, NULL),
	(3816, 34, 1, 9, 4, 2, 7, 6, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 2 tarifą per mėnesį', 408, 4, NULL, NULL),
	(3817, 34, 2, 9, 4, 2, 7, 6, 44, NULL, 'Maksimali 3 minučių S- galia pagal 2 tarifą per mėnesį', 409, 4, NULL, NULL),
	(3818, 3, 5, 13, 4, 2, 3, 6, 16, NULL, 'Maksimali 15 minučių Q1 galia pagal 2 tarifą per mėnesį', 404, 4, NULL, NULL),
	(3819, 3, 6, 13, 4, 2, 3, 6, 16, NULL, 'Maksimali 15 minučių Q2 galia pagal 2 tarifą per mėnesį', 405, 4, NULL, NULL),
	(3820, 3, 7, 13, 4, 2, 3, 6, 16, NULL, 'Maksimali 15 minučių Q3 galia pagal 2 tarifą per mėnesį', 406, 4, NULL, NULL),
	(3821, 3, 8, 13, 4, 2, 3, 6, 16, NULL, 'Maksimali 15 minučių Q4 galia pagal 2 tarifą per mėnesį', 407, 4, NULL, NULL),
	(3822, 34, 1, 13, 4, 2, 7, 6, 44, NULL, 'Maksimali 15 minučių S+ galia pagal 2 tarifą per mėnesį', 408, 4, NULL, NULL),
	(3823, 34, 2, 13, 4, 2, 7, 6, 44, NULL, 'Maksimali 15 minučių S- galia pagal 2 tarifą per mėnesį', 409, 4, NULL, NULL),
	(3824, 3, 5, 3, 4, 3, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q1 galia pagal 3 tarifą per mėnesį', 410, 4, NULL, NULL),
	(3825, 3, 6, 3, 4, 3, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q2 galia pagal 3 tarifą per mėnesį', 411, 4, NULL, NULL),
	(3826, 3, 7, 3, 4, 3, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q3 galia pagal 3 tarifą per mėnesį', 412, 4, NULL, NULL),
	(3827, 3, 8, 3, 4, 3, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q4 galia pagal 3 tarifą per mėnesį', 413, 4, NULL, NULL),
	(3828, 34, 1, 3, 4, 3, 7, 6, 44, NULL, 'Maksimali pusvalandinė S+ galia pagal 3 tarifą per mėnesį', 414, 4, NULL, NULL),
	(3829, 34, 2, 3, 4, 3, 7, 6, 44, NULL, 'Maksimali pusvalandinė S- galia pagal 3 tarifą per mėnesį', 415, 4, NULL, NULL),
	(3830, 3, 5, 4, 4, 3, 3, 6, 16, NULL, 'Maksimali valandinė Q1 galia pagal 3 tarifą per mėnesį', 410, 4, NULL, NULL),
	(3831, 3, 6, 4, 4, 3, 3, 6, 16, NULL, 'Maksimali valandinė Q2 galia pagal 3 tarifą per mėnesį', 411, 4, NULL, NULL),
	(3832, 3, 7, 4, 4, 3, 3, 6, 16, NULL, 'Maksimali valandinė Q3 galia pagal 3 tarifą per mėnesį', 412, 4, NULL, NULL),
	(3833, 3, 8, 4, 4, 3, 3, 6, 16, NULL, 'Maksimali valandinė Q4 galia pagal 3 tarifą per mėnesį', 413, 4, NULL, NULL),
	(3834, 34, 1, 4, 4, 3, 7, 6, 44, NULL, 'Maksimali valandinė S+ galia pagal 3 tarifą per mėnesį', 414, 4, NULL, NULL),
	(3835, 34, 2, 4, 4, 3, 7, 6, 44, NULL, 'Maksimali valandinė S- galia pagal 3 tarifą per mėnesį', 415, 4, NULL, NULL),
	(3836, 3, 5, 9, 4, 3, 3, 6, 16, NULL, 'Maksimali 3 minučių Q1 galia pagal 3 tarifą per mėnesį', 410, 4, NULL, NULL),
	(3837, 3, 6, 9, 4, 3, 3, 6, 16, NULL, 'Maksimali 3 minučių Q2 galia pagal 3 tarifą per mėnesį', 411, 4, NULL, NULL),
	(3838, 3, 7, 9, 4, 3, 3, 6, 16, NULL, 'Maksimali 3 minučių Q3 galia pagal 3 tarifą per mėnesį', 412, 4, NULL, NULL),
	(3839, 3, 8, 9, 4, 3, 3, 6, 16, NULL, 'Maksimali 3 minučių Q4 galia pagal 3 tarifą per mėnesį', 413, 4, NULL, NULL),
	(3840, 34, 1, 9, 4, 3, 7, 6, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 3 tarifą per mėnesį', 414, 4, NULL, NULL),
	(3841, 34, 2, 9, 4, 3, 7, 6, 44, NULL, 'Maksimali 3 minučių S- galia pagal 3 tarifą per mėnesį', 415, 4, NULL, NULL),
	(3842, 3, 5, 13, 4, 3, 3, 6, 16, NULL, 'Maksimali 15 minučių Q1 galia pagal 3 tarifą per mėnesį', 410, 4, NULL, NULL),
	(3843, 3, 6, 13, 4, 3, 3, 6, 16, NULL, 'Maksimali 15 minučių Q2 galia pagal 3 tarifą per mėnesį', 411, 4, NULL, NULL),
	(3844, 3, 7, 13, 4, 3, 3, 6, 16, NULL, 'Maksimali 15 minučių Q3 galia pagal 3 tarifą per mėnesį', 412, 4, NULL, NULL),
	(3845, 3, 8, 13, 4, 3, 3, 6, 16, NULL, 'Maksimali 15 minučių Q4 galia pagal 3 tarifą per mėnesį', 413, 4, NULL, NULL),
	(3846, 34, 1, 13, 4, 3, 7, 6, 44, NULL, 'Maksimali 15 minučių S+ galia pagal 3 tarifą per mėnesį', 414, 4, NULL, NULL),
	(3847, 34, 2, 13, 4, 3, 7, 6, 44, NULL, 'Maksimali 15 minučių S- galia pagal 3 tarifą per mėnesį', 415, 4, NULL, NULL),
	(3848, 3, 5, 3, 4, 4, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q1 galia pagal 4 tarifą per mėnesį', 416, 4, NULL, NULL),
	(3849, 3, 6, 3, 4, 4, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q2 galia pagal 4 tarifą per mėnesį', 417, 4, NULL, NULL),
	(3850, 3, 7, 3, 4, 4, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q3 galia pagal 4 tarifą per mėnesį', 418, 4, NULL, NULL),
	(3851, 3, 8, 3, 4, 4, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q4 galia pagal 4 tarifą per mėnesį', 419, 4, NULL, NULL),
	(3852, 34, 1, 3, 4, 4, 7, 6, 44, NULL, 'Maksimali pusvalandinė S+ galia pagal 4 tarifą per mėnesį', 420, 4, NULL, NULL),
	(3853, 34, 2, 3, 4, 4, 7, 6, 44, NULL, 'Maksimali pusvalandinė S- galia pagal 4 tarifą per mėnesį', 421, 4, NULL, NULL),
	(3854, 3, 5, 4, 4, 4, 3, 6, 16, NULL, 'Maksimali valandinė Q1 galia pagal 4 tarifą per mėnesį', 416, 4, NULL, NULL),
	(3855, 3, 6, 4, 4, 4, 3, 6, 16, NULL, 'Maksimali valandinė Q2 galia pagal 4 tarifą per mėnesį', 417, 4, NULL, NULL),
	(3856, 3, 7, 4, 4, 4, 3, 6, 16, NULL, 'Maksimali valandinė Q3 galia pagal 4 tarifą per mėnesį', 418, 4, NULL, NULL),
	(3857, 3, 8, 4, 4, 4, 3, 6, 16, NULL, 'Maksimali valandinė Q4 galia pagal 4 tarifą per mėnesį', 419, 4, NULL, NULL),
	(3858, 34, 1, 4, 4, 4, 7, 6, 44, NULL, 'Maksimali valandinė S+ galia pagal 4 tarifą per mėnesį', 420, 4, NULL, NULL),
	(3859, 34, 2, 4, 4, 4, 7, 6, 44, NULL, 'Maksimali valandinė S- galia pagal 4 tarifą per mėnesį', 421, 4, NULL, NULL),
	(3860, 3, 5, 9, 4, 4, 3, 6, 16, NULL, 'Maksimali 3 minučių Q1 galia pagal 4 tarifą per mėnesį', 416, 4, NULL, NULL),
	(3861, 3, 6, 9, 4, 4, 3, 6, 16, NULL, 'Maksimali 3 minučių Q2 galia pagal 4 tarifą per mėnesį', 417, 4, NULL, NULL),
	(3862, 3, 7, 9, 4, 4, 3, 6, 16, NULL, 'Maksimali 3 minučių Q3 galia pagal 4 tarifą per mėnesį', 418, 4, NULL, NULL),
	(3863, 3, 8, 9, 4, 4, 3, 6, 16, NULL, 'Maksimali 3 minučių Q4 galia pagal 4 tarifą per mėnesį', 419, 4, NULL, NULL),
	(3864, 34, 1, 9, 4, 4, 7, 6, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 4 tarifą per mėnesį', 420, 4, NULL, NULL),
	(3865, 34, 2, 9, 4, 4, 7, 6, 44, NULL, 'Maksimali 3 minučių S- galia pagal 4 tarifą per mėnesį', 421, 4, NULL, NULL),
	(3866, 3, 5, 13, 4, 4, 3, 6, 16, NULL, 'Maksimali 15 minučių Q1 galia pagal 4 tarifą per mėnesį', 416, 4, NULL, NULL),
	(3867, 3, 6, 13, 4, 4, 3, 6, 16, NULL, 'Maksimali 15 minučių Q2 galia pagal 4 tarifą per mėnesį', 417, 4, NULL, NULL),
	(3868, 3, 7, 13, 4, 4, 3, 6, 16, NULL, 'Maksimali 15 minučių Q3 galia pagal 4 tarifą per mėnesį', 418, 4, NULL, NULL),
	(3869, 3, 8, 13, 4, 4, 3, 6, 16, NULL, 'Maksimali 15 minučių Q4 galia pagal 4 tarifą per mėnesį', 419, 4, NULL, NULL),
	(3870, 34, 1, 13, 4, 4, 7, 6, 44, NULL, 'Maksimali 15 minučių S+ galia pagal 4 tarifą per mėnesį', 420, 4, NULL, NULL),
	(3871, 34, 2, 13, 4, 4, 7, 6, 44, NULL, 'Maksimali 15 minučių S- galia pagal 4 tarifą per mėnesį', 421, 4, NULL, NULL),
	(3872, 3, 5, 3, 4, 1, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q1 galia pagal 1 tarifą per parą', 422, 3, NULL, NULL),
	(3873, 3, 6, 3, 4, 1, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q2 galia pagal 1 tarifą per parą', 423, 3, NULL, NULL),
	(3874, 3, 7, 3, 4, 1, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q3 galia pagal 1 tarifą per parą', 424, 3, NULL, NULL),
	(3875, 3, 8, 3, 4, 1, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q4 galia pagal 1 tarifą per parą', 425, 3, NULL, NULL),
	(3876, 34, 1, 3, 4, 1, 7, 5, 44, NULL, 'Maksimali pusvalandinė S+ galia pagal 1 tarifą per parą', 426, 3, NULL, NULL),
	(3877, 34, 2, 3, 4, 1, 7, 5, 44, NULL, 'Maksimali pusvalandinė S- galia pagal 1 tarifą per parą', 427, 3, NULL, NULL),
	(3878, 3, 5, 4, 4, 1, 3, 5, 16, NULL, 'Maksimali valandinė Q1 galia pagal 1 tarifą per parą', 422, 3, NULL, NULL),
	(3879, 3, 6, 4, 4, 1, 3, 5, 16, NULL, 'Maksimali valandinė Q2 galia pagal 1 tarifą per parą', 423, 3, NULL, NULL),
	(3880, 3, 7, 4, 4, 1, 3, 5, 16, NULL, 'Maksimali valandinė Q3 galia pagal 1 tarifą per parą', 424, 3, NULL, NULL),
	(3881, 3, 8, 4, 4, 1, 3, 5, 16, NULL, 'Maksimali valandinė Q4 galia pagal 1 tarifą per parą', 425, 3, NULL, NULL),
	(3882, 34, 1, 4, 4, 1, 7, 5, 44, NULL, 'Maksimali valandinė S+ galia pagal 1 tarifą per parą', 426, 3, NULL, NULL),
	(3883, 34, 2, 4, 4, 1, 7, 5, 44, NULL, 'Maksimali valandinė S- galia pagal 1 tarifą per parą', 427, 3, NULL, NULL),
	(3884, 3, 5, 9, 4, 1, 3, 5, 16, NULL, 'Maksimali 3 minučių Q1 galia pagal 1 tarifą per parą', 422, 3, NULL, NULL),
	(3885, 3, 6, 9, 4, 1, 3, 5, 16, NULL, 'Maksimali 3 minučių Q2 galia pagal 1 tarifą per parą', 423, 3, NULL, NULL),
	(3886, 3, 7, 9, 4, 1, 3, 5, 16, NULL, 'Maksimali 3 minučių Q3 galia pagal 1 tarifą per parą', 424, 3, NULL, NULL),
	(3887, 3, 8, 9, 4, 1, 3, 5, 16, NULL, 'Maksimali 3 minučių Q4 galia pagal 1 tarifą per parą', 425, 3, NULL, NULL),
	(3888, 34, 1, 9, 4, 1, 7, 5, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 1 tarifą per parą', 426, 3, NULL, NULL),
	(3889, 34, 2, 9, 4, 1, 7, 5, 44, NULL, 'Maksimali 3 minučių S- galia pagal 1 tarifą per parą', 427, 3, NULL, NULL),
	(3890, 3, 5, 13, 4, 1, 3, 5, 16, NULL, 'Maksimali 15 minučių Q1 galia pagal 1 tarifą per parą', 422, 3, NULL, NULL),
	(3891, 3, 6, 13, 4, 1, 3, 5, 16, NULL, 'Maksimali 15 minučių Q2 galia pagal 1 tarifą per parą', 423, 3, NULL, NULL),
	(3892, 3, 7, 13, 4, 1, 3, 5, 16, NULL, 'Maksimali 15 minučių Q3 galia pagal 1 tarifą per parą', 424, 3, NULL, NULL),
	(3893, 3, 8, 13, 4, 1, 3, 5, 16, NULL, 'Maksimali 15 minučių Q4 galia pagal 1 tarifą per parą', 425, 3, NULL, NULL),
	(3894, 34, 1, 13, 4, 1, 7, 5, 44, NULL, 'Maksimali 15 minučių S+ galia pagal 1 tarifą per parą', 426, 3, NULL, NULL),
	(3895, 34, 2, 13, 4, 1, 7, 5, 44, NULL, 'Maksimali 15 minučių S- galia pagal 1 tarifą per parą', 427, 3, NULL, NULL),
	(3896, 3, 5, 3, 4, 2, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q1 galia pagal 2 tarifą per parą', 428, 3, NULL, NULL),
	(3897, 3, 6, 3, 4, 2, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q2 galia pagal 2 tarifą per parą', 429, 3, NULL, NULL),
	(3898, 3, 7, 3, 4, 2, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q3 galia pagal 2 tarifą per parą', 430, 3, NULL, NULL),
	(3899, 3, 8, 3, 4, 2, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q4 galia pagal 2 tarifą per parą', 431, 3, NULL, NULL),
	(3900, 34, 1, 3, 4, 2, 7, 5, 44, NULL, 'Maksimali pusvalandinė S+ galia pagal 2 tarifą per parą', 432, 3, NULL, NULL),
	(3901, 34, 2, 3, 4, 2, 7, 5, 44, NULL, 'Maksimali pusvalandinė S- galia pagal 2 tarifą per parą', 433, 3, NULL, NULL),
	(3902, 3, 5, 4, 4, 2, 3, 5, 16, NULL, 'Maksimali valandinė Q1 galia pagal 2 tarifą per parą', 428, 3, NULL, NULL),
	(3903, 3, 6, 4, 4, 2, 3, 5, 16, NULL, 'Maksimali valandinė Q2 galia pagal 2 tarifą per parą', 429, 3, NULL, NULL),
	(3904, 3, 7, 4, 4, 2, 3, 5, 16, NULL, 'Maksimali valandinė Q3 galia pagal 2 tarifą per parą', 430, 3, NULL, NULL),
	(3905, 3, 8, 4, 4, 2, 3, 5, 16, NULL, 'Maksimali valandinė Q4 galia pagal 2 tarifą per parą', 431, 3, NULL, NULL),
	(3906, 34, 1, 4, 4, 2, 7, 5, 44, NULL, 'Maksimali valandinė S+ galia pagal 2 tarifą per parą', 432, 3, NULL, NULL),
	(3907, 34, 2, 4, 4, 2, 7, 5, 44, NULL, 'Maksimali valandinė S- galia pagal 2 tarifą per parą', 433, 3, NULL, NULL),
	(3908, 3, 5, 9, 4, 2, 3, 5, 16, NULL, 'Maksimali 3 minučių Q1 galia pagal 2 tarifą per parą', 428, 3, NULL, NULL),
	(3909, 3, 6, 9, 4, 2, 3, 5, 16, NULL, 'Maksimali 3 minučių Q2 galia pagal 2 tarifą per parą', 429, 3, NULL, NULL),
	(3910, 3, 7, 9, 4, 2, 3, 5, 16, NULL, 'Maksimali 3 minučių Q3 galia pagal 2 tarifą per parą', 430, 3, NULL, NULL),
	(3911, 3, 8, 9, 4, 2, 3, 5, 16, NULL, 'Maksimali 3 minučių Q4 galia pagal 2 tarifą per parą', 431, 3, NULL, NULL),
	(3912, 34, 1, 9, 4, 2, 7, 5, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 2 tarifą per parą', 432, 3, NULL, NULL),
	(3913, 34, 2, 9, 4, 2, 7, 5, 44, NULL, 'Maksimali 3 minučių S- galia pagal 2 tarifą per parą', 433, 3, NULL, NULL),
	(3914, 3, 5, 13, 4, 2, 3, 5, 16, NULL, 'Maksimali 15 minučių Q1 galia pagal 2 tarifą per parą', 428, 3, NULL, NULL),
	(3915, 3, 6, 13, 4, 2, 3, 5, 16, NULL, 'Maksimali 15 minučių Q2 galia pagal 2 tarifą per parą', 429, 3, NULL, NULL),
	(3916, 3, 7, 13, 4, 2, 3, 5, 16, NULL, 'Maksimali 15 minučių Q3 galia pagal 2 tarifą per parą', 430, 3, NULL, NULL),
	(3917, 3, 8, 13, 4, 2, 3, 5, 16, NULL, 'Maksimali 15 minučių Q4 galia pagal 2 tarifą per parą', 431, 3, NULL, NULL),
	(3918, 34, 1, 13, 4, 2, 7, 5, 44, NULL, 'Maksimali 15 minučių S+ galia pagal 2 tarifą per parą', 432, 3, NULL, NULL),
	(3919, 34, 2, 13, 4, 2, 7, 5, 44, NULL, 'Maksimali 15 minučių S- galia pagal 2 tarifą per parą', 433, 3, NULL, NULL),
	(3920, 3, 5, 3, 4, 3, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q1 galia pagal 3 tarifą per parą', 434, 3, NULL, NULL),
	(3921, 3, 6, 3, 4, 3, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q2 galia pagal 3 tarifą per parą', 435, 3, NULL, NULL),
	(3922, 3, 7, 3, 4, 3, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q3 galia pagal 3 tarifą per parą', 436, 3, NULL, NULL),
	(3923, 3, 8, 3, 4, 3, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q4 galia pagal 3 tarifą per parą', 437, 3, NULL, NULL),
	(3924, 34, 1, 3, 4, 3, 7, 5, 44, NULL, 'Maksimali pusvalandinė S+ galia pagal 3 tarifą per parą', 438, 3, NULL, NULL),
	(3925, 34, 2, 3, 4, 3, 7, 5, 44, NULL, 'Maksimali pusvalandinė S- galia pagal 3 tarifą per parą', 439, 3, NULL, NULL),
	(3926, 3, 5, 4, 4, 3, 3, 5, 16, NULL, 'Maksimali valandinė Q1 galia pagal 3 tarifą per parą', 434, 3, NULL, NULL),
	(3927, 3, 6, 4, 4, 3, 3, 5, 16, NULL, 'Maksimali valandinė Q2 galia pagal 3 tarifą per parą', 435, 3, NULL, NULL),
	(3928, 3, 7, 4, 4, 3, 3, 5, 16, NULL, 'Maksimali valandinė Q3 galia pagal 3 tarifą per parą', 436, 3, NULL, NULL),
	(3929, 3, 8, 4, 4, 3, 3, 5, 16, NULL, 'Maksimali valandinė Q4 galia pagal 3 tarifą per parą', 437, 3, NULL, NULL),
	(3930, 34, 1, 4, 4, 3, 7, 5, 44, NULL, 'Maksimali valandinė S+ galia pagal 3 tarifą per parą', 438, 3, NULL, NULL),
	(3931, 34, 2, 4, 4, 3, 7, 5, 44, NULL, 'Maksimali valandinė S- galia pagal 3 tarifą per parą', 439, 3, NULL, NULL),
	(3932, 3, 5, 9, 4, 3, 3, 5, 16, NULL, 'Maksimali 3 minučių Q1 galia pagal 3 tarifą per parą', 434, 3, NULL, NULL),
	(3933, 3, 6, 9, 4, 3, 3, 5, 16, NULL, 'Maksimali 3 minučių Q2 galia pagal 3 tarifą per parą', 435, 3, NULL, NULL),
	(3934, 3, 7, 9, 4, 3, 3, 5, 16, NULL, 'Maksimali 3 minučių Q3 galia pagal 3 tarifą per parą', 436, 3, NULL, NULL),
	(3935, 3, 8, 9, 4, 3, 3, 5, 16, NULL, 'Maksimali 3 minučių Q4 galia pagal 3 tarifą per parą', 437, 3, NULL, NULL),
	(3936, 34, 1, 9, 4, 3, 7, 5, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 3 tarifą per parą', 438, 3, NULL, NULL),
	(3937, 34, 2, 9, 4, 3, 7, 5, 44, NULL, 'Maksimali 3 minučių S- galia pagal 3 tarifą per parą', 439, 3, NULL, NULL),
	(3938, 3, 5, 13, 4, 3, 3, 5, 16, NULL, 'Maksimali 15 minučių Q1 galia pagal 3 tarifą per parą', 434, 3, NULL, NULL),
	(3939, 3, 6, 13, 4, 3, 3, 5, 16, NULL, 'Maksimali 15 minučių Q2 galia pagal 3 tarifą per parą', 435, 3, NULL, NULL),
	(3940, 3, 7, 13, 4, 3, 3, 5, 16, NULL, 'Maksimali 15 minučių Q3 galia pagal 3 tarifą per parą', 436, 3, NULL, NULL),
	(3941, 3, 8, 13, 4, 3, 3, 5, 16, NULL, 'Maksimali 15 minučių Q4 galia pagal 3 tarifą per parą', 437, 3, NULL, NULL),
	(3942, 34, 1, 13, 4, 3, 7, 5, 44, NULL, 'Maksimali 15 minučių S+ galia pagal 3 tarifą per parą', 438, 3, NULL, NULL),
	(3943, 34, 2, 13, 4, 3, 7, 5, 44, NULL, 'Maksimali 15 minučių S- galia pagal 3 tarifą per parą', 439, 3, NULL, NULL),
	(3944, 3, 5, 3, 4, 4, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q1 galia pagal 4 tarifą per parą', 440, 3, NULL, NULL),
	(3945, 3, 6, 3, 4, 4, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q2 galia pagal 4 tarifą per parą', 441, 3, NULL, NULL),
	(3946, 3, 7, 3, 4, 4, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q3 galia pagal 4 tarifą per parą', 442, 3, NULL, NULL),
	(3947, 3, 8, 3, 4, 4, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q4 galia pagal 4 tarifą per parą', 443, 3, NULL, NULL),
	(3948, 34, 1, 3, 4, 4, 7, 5, 44, NULL, 'Maksimali pusvalandinė S+ galia pagal 4 tarifą per parą', 444, 3, NULL, NULL),
	(3949, 34, 2, 3, 4, 4, 7, 5, 44, NULL, 'Maksimali pusvalandinė S- galia pagal 4 tarifą per parą', 445, 3, NULL, NULL),
	(3950, 3, 5, 4, 4, 4, 3, 5, 16, NULL, 'Maksimali valandinė Q1 galia pagal 4 tarifą per parą', 440, 3, NULL, NULL),
	(3951, 3, 6, 4, 4, 4, 3, 5, 16, NULL, 'Maksimali valandinė Q2 galia pagal 4 tarifą per parą', 441, 3, NULL, NULL),
	(3952, 3, 7, 4, 4, 4, 3, 5, 16, NULL, 'Maksimali valandinė Q3 galia pagal 4 tarifą per parą', 442, 3, NULL, NULL),
	(3953, 3, 8, 4, 4, 4, 3, 5, 16, NULL, 'Maksimali valandinė Q4 galia pagal 4 tarifą per parą', 443, 3, NULL, NULL),
	(3954, 34, 1, 4, 4, 4, 7, 5, 44, NULL, 'Maksimali valandinė S+ galia pagal 4 tarifą per parą', 444, 3, NULL, NULL),
	(3955, 34, 2, 4, 4, 4, 7, 5, 44, NULL, 'Maksimali valandinė S- galia pagal 4 tarifą per parą', 445, 3, NULL, NULL),
	(3956, 3, 5, 9, 4, 4, 3, 5, 16, NULL, 'Maksimali 3 minučių Q1 galia pagal 4 tarifą per parą', 440, 3, NULL, NULL),
	(3957, 3, 6, 9, 4, 4, 3, 5, 16, NULL, 'Maksimali 3 minučių Q2 galia pagal 4 tarifą per parą', 441, 3, NULL, NULL),
	(3958, 3, 7, 9, 4, 4, 3, 5, 16, NULL, 'Maksimali 3 minučių Q3 galia pagal 4 tarifą per parą', 442, 3, NULL, NULL),
	(3959, 3, 8, 9, 4, 4, 3, 5, 16, NULL, 'Maksimali 3 minučių Q4 galia pagal 4 tarifą per parą', 443, 3, NULL, NULL),
	(3960, 34, 1, 9, 4, 4, 7, 5, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 4 tarifą per parą', 444, 3, NULL, NULL),
	(3961, 34, 2, 9, 4, 4, 7, 5, 44, NULL, 'Maksimali 3 minučių S- galia pagal 4 tarifą per parą', 445, 3, NULL, NULL),
	(3962, 3, 5, 13, 4, 4, 3, 5, 16, NULL, 'Maksimali 15 minučių Q1 galia pagal 4 tarifą per parą', 440, 3, NULL, NULL),
	(3963, 3, 6, 13, 4, 4, 3, 5, 16, NULL, 'Maksimali 15 minučių Q2 galia pagal 4 tarifą per parą', 441, 3, NULL, NULL),
	(3964, 3, 7, 13, 4, 4, 3, 5, 16, NULL, 'Maksimali 15 minučių Q3 galia pagal 4 tarifą per parą', 442, 3, NULL, NULL),
	(3965, 3, 8, 13, 4, 4, 3, 5, 16, NULL, 'Maksimali 15 minučių Q4 galia pagal 4 tarifą per parą', 443, 3, NULL, NULL),
	(3966, 34, 1, 13, 4, 4, 7, 5, 44, NULL, 'Maksimali 15 minučių S+ galia pagal 4 tarifą per parą', 444, 3, NULL, NULL),
	(3967, 34, 2, 13, 4, 4, 7, 5, 44, NULL, 'Maksimali 15 minučių S- galia pagal 4 tarifą per parą', 445, 3, NULL, NULL),
	(3968, 167, 0, 8, 2, 0, 29, 7, 180, NULL, 'Suminis šalčio skaitiklio darbo laikas', 1007, 5, NULL, NULL),
	(3969, 167, 0, 4, 2, 0, 29, 4, 180, NULL, 'Šalčio skaitiklio darbo laikas per valandą', 1018, 2, NULL, NULL),
	(3970, 167, 0, 5, 2, 0, 29, 5, 180, NULL, 'Šalčio skaitiklio darbo laikas per parą', 1018, 3, NULL, NULL),
	(3971, 167, 0, 6, 2, 0, 29, 6, 180, NULL, 'Šalčio skaitiklio darbo laikas per mėnesį', 1018, 4, NULL, NULL),
	(3972, 168, 0, 8, 2, 0, 29, 7, 181, NULL, 'Suminis šalčio skaitiklio nedarbo laikas', 1012, 5, NULL, NULL),
	(3973, 168, 0, 4, 2, 0, 29, 4, 181, NULL, 'Šalčio skaitiklio nedarbo laikas per valandą', 1012, 2, NULL, NULL),
	(3974, 168, 0, 5, 2, 0, 29, 5, 181, NULL, 'Šalčio skaitiklio nedarbo laikas per parą', 1012, 3, NULL, NULL),
	(3975, 168, 0, 6, 2, 0, 29, 6, 181, NULL, 'Šalčio skaitiklio nedarbo laikas per mėnesį', 1012, 4, NULL, NULL),
	(3976, 167, 0, 13, 2, 0, 29, 12, 180, NULL, 'Šalčio skaitiklio darbo laikas per 15 minučių', 1018, 2, NULL, NULL),
	(3977, 167, 0, 3, 2, 0, 29, 3, 180, NULL, 'Šalčio skaitiklio darbo laikas per 30 minučių', 1018, 2, NULL, NULL),
	(3978, 168, 0, 13, 2, 0, 29, 12, 181, NULL, 'Šalčio skaitiklio nedarbo laikas per 15 minučių', 1012, 2, NULL, NULL),
	(3979, 168, 0, 3, 2, 0, 29, 3, 181, NULL, 'Šalčio skaitiklio nedarbo laikas per 30 minučių', 1012, 2, NULL, NULL),
	(3980, 167, 0, 8, 2, 0, 29, 4, 180, NULL, 'Suminis šalčio skaitiklio darbo laikas, fiksuojamas kas valandą', 1007, 5, NULL, NULL),
	(3981, 167, 0, 8, 2, 0, 29, 3, 180, NULL, 'Suminis šalčio skaitiklio darbo laikas, fiksuojamas kas 30 minučių', 1007, 5, NULL, NULL),
	(3982, 167, 0, 8, 2, 0, 29, 12, 180, NULL, 'Suminis šalčio skaitiklio darbo laikas, fiksuojamas kas 15 minučių', 1007, 5, NULL, NULL),
	(3983, 168, 0, 8, 2, 0, 29, 12, 181, NULL, 'Suminis šalčio skaitiklio nedarbo laikas, fiksuojamas kas 15 minučių', 1012, 5, NULL, NULL),
	(3984, 168, 0, 8, 2, 0, 29, 3, 181, NULL, 'Suminis šalčio skaitiklio nedarbo laikas, fiksuojamas kas 30 minučių', 1012, 5, NULL, NULL),
	(3985, 168, 0, 8, 2, 0, 29, 4, 181, NULL, 'Suminis šalčio skaitiklio nedarbo laikas, fiksuojamas kas valandą', 1012, 5, NULL, NULL),
	(3986, 167, 0, 8, 2, 0, 29, 5, 180, NULL, 'Suminis šalčio skaitiklio darbo laikas, fiksuojamas kas parą', 1007, 5, NULL, NULL),
	(3987, 167, 0, 8, 2, 0, 29, 6, 180, NULL, 'Suminis šalčio skaitiklio darbo laikas, fiksuojamas kas mėnesį', 1007, 5, NULL, NULL),
	(3988, 168, 0, 8, 2, 0, 29, 5, 181, NULL, 'Suminis šalčio skaitiklio nedarbo laikas, fiksuojamas kas parą', 1012, 5, NULL, NULL),
	(3989, 168, 0, 8, 2, 0, 29, 6, 181, NULL, 'Suminis šalčio skaitiklio nedarbo laikas, fiksuojamas kas mėnesį', 1012, 5, NULL, NULL),
	(3990, 169, 0, 7, 1, 0, 56, 7, 182, NULL, 'Kampas tarp L1 ir L2 fazės įtampų', 91, 6, NULL, NULL),
	(3991, 170, 0, 7, 1, 0, 56, 7, 183, NULL, 'Kampas tarp L2 ir L3 fazės įtampų', 92, 6, NULL, NULL),
	(3992, 171, 0, 7, 1, 0, 56, 7, 184, NULL, 'Kampas tarp L3 ir L1 fazės įtampų', 93, 6, NULL, NULL),
	(3993, 172, 0, 7, 1, 0, 56, 7, 185, NULL, 'Kampas tarp srovės ir įtampos L1 fazėje', 94, 6, NULL, NULL),
	(3994, 173, 0, 7, 1, 0, 56, 7, 186, NULL, 'Kampas tarp srovės ir įtampos L2 fazėje', 95, 6, NULL, NULL),
	(3995, 174, 0, 7, 1, 0, 56, 7, 187, NULL, 'Kampas tarp srovės ir įtampos L3 fazėje', 96, 6, NULL, NULL),
	(3996, 175, 0, 7, 1, 0, 0, 7, 188, NULL, 'Galios koeficientas L1 fazėje', 552, 6, NULL, NULL),
	(3997, 176, 0, 7, 1, 0, 0, 7, 189, NULL, 'Galios koeficientas L2 fazėje', 553, 6, NULL, NULL),
	(3998, 177, 0, 7, 1, 0, 0, 7, 190, NULL, 'Galios koeficientas L3 fazėje', 554, 6, NULL, NULL),
	(3999, 1, 0, 3, 2, 0, 2, 3, 14, NULL, 'A energija per 30 minučių', 719, 2, NULL, NULL),
	(4000, 1, 0, 3, 3, 0, 1, 3, 13, NULL, 'Vidutinė P galia per 30 minučių', 446, 2, NULL, NULL),
	(4001, 1, 0, 3, 4, 0, 1, 5, 13, NULL, 'Maksimali pusvalandinė P galia per parą', NULL, 3, NULL, NULL),
	(4002, 1, 0, 3, 4, 0, 1, 6, 13, NULL, 'Maksimali pusvalandinė P galia per mėnesį', 3351, 4, NULL, NULL),
	(4003, 1, 0, 3, 4, 1, 1, 5, 13, NULL, 'Maksimali pusvalandinė P galia pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(4004, 1, 0, 3, 4, 1, 1, 6, 13, NULL, 'Maksimali pusvalandinė P galia pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4005, 1, 0, 3, 4, 2, 1, 5, 13, NULL, 'Maksimali pusvalandinė P galia pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(4006, 1, 0, 3, 4, 2, 1, 6, 13, NULL, 'Maksimali pusvalandinė P galia pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4007, 1, 0, 3, 4, 3, 1, 5, 13, NULL, 'Maksimali pusvalandinė P galia pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(4008, 1, 0, 3, 4, 3, 1, 6, 13, NULL, 'Maksimali pusvalandinė P galia pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4009, 1, 0, 3, 4, 4, 1, 5, 13, NULL, 'Maksimali pusvalandinė P galia pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(4010, 1, 0, 3, 4, 4, 1, 6, 13, NULL, 'Maksimali pusvalandinė P galia pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4011, 1, 0, 3, 5, 0, 1, 5, 13, NULL, 'Minimali pusvalandinė P galia per parą', NULL, 3, NULL, NULL),
	(4012, 1, 0, 3, 5, 0, 1, 6, 13, NULL, 'Minimali pusvalandinė P galia per mėnesį', NULL, 4, NULL, NULL),
	(4013, 3, 0, 3, 2, 0, 4, 3, 15, NULL, 'R energija per 30 minučių', 721, 2, NULL, NULL),
	(4014, 3, 0, 3, 3, 0, 3, 3, 16, NULL, 'Vidutinė Q galia per 30 minučių', 448, 2, NULL, NULL),
	(4015, 3, 0, 3, 4, 0, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q galia per parą', NULL, 3, NULL, NULL),
	(4016, 3, 0, 3, 4, 0, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q galia per mėnesį', 3352, 4, NULL, NULL),
	(4017, 3, 0, 3, 4, 1, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q galia pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(4018, 3, 0, 3, 4, 1, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q galia pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4019, 3, 0, 3, 4, 2, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q galia pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(4020, 3, 0, 3, 4, 2, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q galia pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4021, 3, 0, 3, 4, 3, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q galia pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(4022, 3, 0, 3, 4, 3, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q galia pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4023, 3, 0, 3, 4, 4, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q galia pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(4024, 3, 0, 3, 4, 4, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q galia pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4025, 3, 0, 3, 5, 0, 3, 5, 16, NULL, 'Minimali pusvalandinė Q galia per parą', NULL, 3, NULL, NULL),
	(4026, 3, 0, 3, 5, 0, 3, 6, 16, NULL, 'Minimali pusvalandinė Q galia per mėnesį', NULL, 4, NULL, NULL),
	(4027, 34, 0, 3, 2, 0, 41, 3, 45, NULL, 'W energija per 30 minučių', 723, 2, NULL, NULL),
	(4028, 34, 0, 3, 3, 0, 7, 3, 44, NULL, 'Vidutinė S galia per 30 minučių', 450, 2, NULL, NULL),
	(4029, 34, 0, 3, 4, 1, 7, 5, 44, NULL, 'Maksimali pusvalandinė S galia pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(4030, 34, 0, 3, 4, 1, 7, 6, 44, NULL, 'Maksimali pusvalandinė S galia pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4031, 34, 0, 3, 4, 2, 7, 5, 44, NULL, 'Maksimali pusvalandinė S galia pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(4032, 34, 0, 3, 4, 2, 7, 6, 44, NULL, 'Maksimali pusvalandinė S galia pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4033, 34, 0, 3, 4, 3, 7, 5, 44, NULL, 'Maksimali pusvalandinė S galia pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(4034, 34, 0, 3, 4, 3, 7, 6, 44, NULL, 'Maksimali pusvalandinė S galia pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4035, 34, 0, 3, 4, 4, 7, 5, 44, NULL, 'Maksimali pusvalandinė S galia pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(4036, 34, 0, 3, 4, 4, 7, 6, 44, NULL, 'Maksimali pusvalandinė S galia pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4037, 34, 0, 3, 4, 0, 7, 5, 44, NULL, 'Maksimali pusvalandinė S galia per parą', NULL, 3, NULL, NULL),
	(4038, 34, 0, 3, 4, 0, 7, 6, 44, NULL, 'Maksimali pusvalandinė S galia per mėnesį', 3353, 4, NULL, NULL),
	(4039, 34, 0, 3, 5, 0, 7, 5, 44, NULL, 'Minimali pusvalandinė S galia per parą', NULL, 3, NULL, NULL),
	(4040, 34, 0, 3, 5, 0, 7, 6, 44, NULL, 'Minimali pusvalandinė S galia per mėnesį', NULL, 4, NULL, NULL),
	(4041, 1, 0, 4, 2, 0, 2, 4, 14, NULL, 'A energija per valandą', 719, 2, NULL, NULL),
	(4042, 1, 0, 4, 3, 0, 1, 4, 13, NULL, 'Vidutinė P galia per valandą', 446, 2, NULL, NULL),
	(4043, 1, 0, 4, 4, 0, 1, 5, 13, NULL, 'Maksimali valandinė P galia per parą', NULL, 3, NULL, NULL),
	(4044, 1, 0, 4, 4, 0, 1, 6, 13, NULL, 'Maksimali valandinė P galia per mėnesį', 3351, 4, NULL, NULL),
	(4045, 1, 0, 4, 4, 1, 1, 5, 13, NULL, 'Maksimali valandinė P galia pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(4046, 1, 0, 4, 4, 1, 1, 6, 13, NULL, 'Maksimali valandinė P galia pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4047, 1, 0, 4, 4, 2, 1, 5, 13, NULL, 'Maksimali valandinė P galia pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(4048, 1, 0, 4, 4, 2, 1, 6, 13, NULL, 'Maksimali valandinė P galia pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4049, 1, 0, 4, 4, 3, 1, 5, 13, NULL, 'Maksimali valandinė P galia pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(4050, 1, 0, 4, 4, 3, 1, 6, 13, NULL, 'Maksimali valandinė P galia pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4051, 1, 0, 4, 4, 4, 1, 5, 13, NULL, 'Maksimali valandinė P galia pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(4052, 1, 0, 4, 4, 4, 1, 6, 13, NULL, 'Maksimali valandinė P galia pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4053, 1, 0, 4, 5, 0, 1, 5, 13, NULL, 'Minimali valandinė P galia per parą', NULL, 3, NULL, NULL),
	(4054, 1, 0, 4, 5, 0, 1, 6, 13, NULL, 'Minimali valandinė P galia per mėnesį', NULL, 4, NULL, NULL),
	(4055, 3, 0, 4, 2, 0, 4, 4, 15, NULL, 'R energija per valandą', 721, 2, NULL, NULL),
	(4056, 3, 0, 4, 3, 0, 3, 4, 16, NULL, 'Vidutinė Q galia per valandą', 448, 2, NULL, NULL),
	(4057, 3, 0, 4, 4, 0, 3, 5, 16, NULL, 'Maksimali valandinė Q galia per parą', NULL, 3, NULL, NULL),
	(4058, 3, 0, 4, 4, 0, 3, 6, 16, NULL, 'Maksimali valandinė Q galia per mėnesį', 3352, 4, NULL, NULL),
	(4059, 3, 0, 4, 4, 1, 3, 5, 16, NULL, 'Maksimali valandinė Q galia pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(4060, 3, 0, 4, 4, 1, 3, 6, 16, NULL, 'Maksimali valandinė Q galia pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4061, 3, 0, 4, 4, 2, 3, 5, 16, NULL, 'Maksimali valandinė Q galia pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(4062, 3, 0, 4, 4, 2, 3, 6, 16, NULL, 'Maksimali valandinė Q galia pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4063, 3, 0, 4, 4, 3, 3, 5, 16, NULL, 'Maksimali valandinė Q galia pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(4064, 3, 0, 4, 4, 3, 3, 6, 16, NULL, 'Maksimali valandinė Q galia pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4065, 3, 0, 4, 4, 4, 3, 5, 16, NULL, 'Maksimali valandinė Q galia pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(4066, 3, 0, 4, 4, 4, 3, 6, 16, NULL, 'Maksimali valandinė Q galia pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4067, 3, 0, 4, 5, 0, 3, 5, 16, NULL, 'Minimali valandinė Q galia per parą', NULL, 3, NULL, NULL),
	(4068, 3, 0, 4, 5, 0, 3, 6, 16, NULL, 'Minimali valandinė Q galia per mėnesį', NULL, 4, NULL, NULL),
	(4069, 34, 0, 4, 2, 0, 41, 4, 45, NULL, 'W energija per valandą', 723, 2, NULL, NULL),
	(4070, 34, 0, 4, 3, 0, 7, 4, 44, NULL, 'Vidutinė S galia per valandą', 450, 2, NULL, NULL),
	(4071, 34, 0, 4, 4, 4, 7, 5, 44, NULL, 'Maksimali valandinė S galia pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(4072, 34, 0, 4, 4, 4, 7, 6, 44, NULL, 'Maksimali valandinė S galia pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4073, 34, 0, 4, 4, 3, 7, 5, 44, NULL, 'Maksimali valandinė S galia pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(4074, 34, 0, 4, 4, 3, 7, 6, 44, NULL, 'Maksimali valandinė S galia pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4075, 34, 0, 4, 4, 2, 7, 5, 44, NULL, 'Maksimali valandinė S galia pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(4076, 34, 0, 4, 4, 2, 7, 6, 44, NULL, 'Maksimali valandinė S galia pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4077, 34, 0, 4, 4, 1, 7, 5, 44, NULL, 'Maksimali valandinė S galia pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(4078, 34, 0, 4, 4, 1, 7, 6, 44, NULL, 'Maksimali valandinė S galia pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4079, 34, 0, 4, 4, 0, 7, 5, 44, NULL, 'Maksimali valandinė S galia per parą', NULL, 3, NULL, NULL),
	(4080, 34, 0, 4, 4, 0, 7, 6, 44, NULL, 'Maksimali valandinė S galia per mėnesį', 3353, 4, NULL, NULL),
	(4081, 34, 0, 4, 5, 0, 7, 5, 44, NULL, 'Minimali valandinė S galia per parą', NULL, 3, NULL, NULL),
	(4082, 34, 0, 4, 5, 0, 7, 6, 44, NULL, 'Minimali valandinė S galia per mėnesį', NULL, 4, NULL, NULL),
	(4083, 3, 0, 1, 3, 0, 3, 1, 16, NULL, 'Vidutinė Q galia per minutę', 448, 1, NULL, NULL),
	(4084, 3, 0, 1, 2, 0, 4, 1, 15, NULL, 'R energija per minutę', 721, 1, NULL, NULL),
	(4085, 3, 0, 1, 4, 0, 3, 5, 16, NULL, 'Maksimali 1 minutės Q galia per parą', NULL, 3, NULL, NULL),
	(4086, 3, 0, 1, 4, 0, 3, 6, 16, NULL, 'Maksimali 1 minutės Q galia per mėnesį', 3352, 4, NULL, NULL),
	(4087, 3, 0, 1, 5, 0, 3, 5, 16, NULL, 'Minimali 1 minutės Q galia per parą', NULL, 3, NULL, NULL),
	(4088, 3, 0, 1, 5, 0, 3, 6, 16, NULL, 'Minimali 1 minutės Q galia per mėnesį', NULL, 4, NULL, NULL),
	(4089, 1, 0, 1, 2, 0, 2, 1, 14, NULL, 'A energija per minutę', 719, 1, NULL, NULL),
	(4090, 1, 0, 1, 3, 0, 1, 1, 13, NULL, 'Vidutinė P galia per minutę', 446, 1, NULL, NULL),
	(4091, 1, 0, 1, 4, 0, 1, 5, 13, NULL, 'Maksimali 1 minutės P galia per parą', NULL, 3, NULL, NULL),
	(4092, 1, 0, 1, 4, 0, 1, 6, 13, NULL, 'Maksimali 1 minutės P galia per mėnesį', 3351, 4, NULL, NULL),
	(4093, 1, 0, 1, 5, 0, 1, 5, 13, NULL, 'Minimali 1 minutės P galia per parą', NULL, 3, NULL, NULL),
	(4094, 1, 0, 1, 5, 0, 1, 6, 13, NULL, 'Minimali 1 minutės P galia per mėnesį', NULL, 4, NULL, NULL),
	(4095, 34, 0, 1, 3, 0, 7, 1, 44, NULL, 'Vidutinė S galia per minutę', 450, 1, NULL, NULL),
	(4096, 34, 0, 1, 2, 0, 41, 1, 45, NULL, 'W energija per minutę', 723, 1, NULL, NULL),
	(4097, 34, 0, 1, 4, 0, 7, 5, 44, NULL, 'Maksimali 1 minutės S galia per parą', NULL, 3, NULL, NULL),
	(4098, 34, 0, 1, 4, 0, 7, 6, 44, NULL, 'Maksimali 1 minutės S galia per mėnesį', NULL, 4, NULL, NULL),
	(4099, 34, 0, 1, 5, 0, 7, 5, 44, NULL, 'Minimali 1 minutės S galia per parą', NULL, 3, NULL, NULL),
	(4100, 34, 0, 1, 5, 0, 7, 6, 44, NULL, 'Minimali 1 minutės S galia per mėnesį', NULL, 4, NULL, NULL),
	(4101, 1, 0, 2, 3, 0, 1, 2, 13, NULL, 'Vidutinė P galia per 2 minutes', 446, 1, NULL, NULL),
	(4102, 1, 0, 2, 2, 0, 2, 2, 14, NULL, 'A energija per 2 minutes', 719, 1, NULL, NULL),
	(4103, 1, 0, 2, 4, 0, 1, 5, 13, NULL, 'Maksimali 2 minučių P galia per parą', NULL, 3, NULL, NULL),
	(4104, 1, 0, 2, 4, 0, 1, 6, 13, NULL, 'Maksimali 2 minučių P galia per mėnesį', 3351, 4, NULL, NULL),
	(4105, 1, 0, 2, 5, 0, 1, 5, 13, NULL, 'Minimali 2 minučių P galia per parą', NULL, 3, NULL, NULL),
	(4106, 1, 0, 2, 5, 0, 1, 6, 13, NULL, 'Minimali 2 minučių P galia per mėnesį', NULL, 4, NULL, NULL),
	(4107, 3, 0, 2, 3, 0, 3, 2, 16, NULL, 'Vidutinė Q galia per 2 minutes', 448, 1, NULL, NULL),
	(4108, 3, 0, 2, 2, 0, 4, 2, 15, NULL, 'R energija per 2 minutes', 721, 1, NULL, NULL),
	(4109, 3, 0, 2, 4, 0, 3, 5, 16, NULL, 'Maksimali 2 minučių Q galia per parą', NULL, 3, NULL, NULL),
	(4110, 3, 0, 2, 4, 0, 3, 6, 16, NULL, 'Maksimali 2 minučių Q galia per mėnesį', 3352, 4, NULL, NULL),
	(4111, 3, 0, 2, 5, 0, 3, 5, 16, NULL, 'Minimali 2 minučių Q galia per parą', NULL, 3, NULL, NULL),
	(4112, 3, 0, 2, 5, 0, 3, 6, 16, NULL, 'Minimali 2 minučių Q galia per mėnesį', NULL, 4, NULL, NULL),
	(4113, 34, 0, 2, 3, 0, 7, 2, 44, NULL, 'Vidutinė S galia per 2 minutes', 450, 1, NULL, NULL),
	(4114, 34, 0, 2, 2, 0, 41, 2, 45, NULL, 'W energija per 2 minutes', 723, 1, NULL, NULL),
	(4115, 34, 0, 2, 4, 0, 7, 5, 44, NULL, 'Maksimali 2 minučių S galia per parą', NULL, 3, NULL, NULL),
	(4116, 34, 0, 2, 4, 0, 7, 6, 44, NULL, 'Maksimali 2 minučių S galia per mėnesį', NULL, 4, NULL, NULL),
	(4117, 34, 0, 2, 5, 0, 7, 5, 44, NULL, 'Minimali 2 minučių S galia per parą', NULL, 3, NULL, NULL),
	(4118, 34, 0, 2, 5, 0, 7, 6, 44, NULL, 'Minimali 2 minučių S galia per mėnesį', NULL, 4, NULL, NULL),
	(4119, 1, 0, 9, 2, 0, 2, 8, 14, NULL, 'A energija per 3 minutes', 719, 1, NULL, NULL),
	(4120, 1, 0, 9, 3, 0, 1, 8, 13, NULL, 'Vidutinė P galia per 3 minutes', 446, 1, NULL, NULL),
	(4121, 1, 0, 9, 4, 0, 1, 5, 13, NULL, 'Maksimali 3 minučių P galia per parą', NULL, 3, NULL, NULL),
	(4122, 1, 0, 9, 4, 0, 1, 6, 13, NULL, 'Maksimali 3 minučių P galia per mėnesį', 3351, 4, NULL, NULL),
	(4123, 1, 0, 9, 5, 0, 1, 5, 13, NULL, 'Minimali 3 minučių P galia per parą', NULL, 3, NULL, NULL),
	(4124, 1, 0, 9, 5, 0, 1, 6, 13, NULL, 'Minimali 3 minučių P galia per mėnesį', NULL, 4, NULL, NULL),
	(4125, 1, 0, 9, 4, 1, 1, 5, 13, NULL, 'Maksimali 3 minučių P galia pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(4126, 1, 0, 9, 4, 1, 1, 6, 13, NULL, 'Maksimali 3 minučių P galia pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4127, 1, 0, 9, 4, 2, 1, 5, 13, NULL, 'Maksimali 3 minučių P galia pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(4128, 1, 0, 9, 4, 2, 1, 6, 13, NULL, 'Maksimali 3 minučių P galia pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4129, 1, 0, 9, 4, 3, 1, 5, 13, NULL, 'Maksimali 3 minučių P galia pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(4130, 1, 0, 9, 4, 3, 1, 6, 13, NULL, 'Maksimali 3 minučių P galia pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4131, 1, 0, 9, 4, 4, 1, 5, 13, NULL, 'Maksimali 3 minučių P galia pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(4132, 1, 0, 9, 4, 4, 1, 6, 13, NULL, 'Maksimali 3 minučių P galia pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4133, 3, 0, 9, 2, 0, 4, 8, 15, NULL, 'R energija per 3 minutes', 721, 1, NULL, NULL),
	(4134, 3, 0, 9, 3, 0, 3, 8, 16, NULL, 'Vidutinė Q galia per 3 minutes', 448, 1, NULL, NULL),
	(4135, 3, 0, 9, 4, 0, 3, 5, 16, NULL, 'Maksimali 3 minučių Q galia per parą', NULL, 3, NULL, NULL),
	(4136, 3, 0, 9, 4, 0, 3, 6, 16, NULL, 'Maksimali 3 minučių Q galia per mėnesį', 3352, 4, NULL, NULL),
	(4137, 3, 0, 9, 5, 0, 3, 5, 16, NULL, 'Minimali 3 minučių Q galia per parą', NULL, 3, NULL, NULL),
	(4138, 3, 0, 9, 5, 0, 3, 6, 16, NULL, 'Minimali 3 minučių Q galia per mėnesį', NULL, 4, NULL, NULL),
	(4139, 3, 0, 9, 4, 1, 3, 5, 16, NULL, 'Maksimali 3 minučių Q galia pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(4140, 3, 0, 9, 4, 1, 3, 6, 16, NULL, 'Maksimali 3 minučių Q galia pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4141, 3, 0, 9, 4, 2, 3, 5, 16, NULL, 'Maksimali 3 minučių Q galia pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(4142, 3, 0, 9, 4, 2, 3, 6, 16, NULL, 'Maksimali 3 minučių Q galia pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4143, 3, 0, 9, 4, 3, 3, 5, 16, NULL, 'Maksimali 3 minučių Q galia pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(4144, 3, 0, 9, 4, 3, 3, 6, 16, NULL, 'Maksimali 3 minučių Q galia pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4145, 3, 0, 9, 4, 4, 3, 5, 16, NULL, 'Maksimali 3 minučių Q galia pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(4146, 3, 0, 9, 4, 4, 3, 6, 16, NULL, 'Maksimali 3 minučių Q galia pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4147, 34, 0, 9, 2, 0, 41, 8, 45, NULL, 'W energija per 3 minutes', 723, 1, NULL, NULL),
	(4148, 34, 0, 9, 3, 0, 7, 8, 44, NULL, 'Vidutinė S galia per 3 minutes', 450, 1, NULL, NULL),
	(4149, 34, 0, 9, 4, 0, 7, 5, 44, NULL, 'Maksimali 3 minučių S galia per parą', NULL, 3, NULL, NULL),
	(4150, 34, 0, 9, 4, 0, 7, 6, 44, NULL, 'Maksimali 3 minučių S galia per mėnesį', NULL, 4, NULL, NULL),
	(4151, 34, 0, 9, 5, 0, 7, 5, 44, NULL, 'Minimali 3 minučių S galia per parą', NULL, 3, NULL, NULL),
	(4152, 34, 0, 9, 5, 0, 7, 6, 44, NULL, 'Minimali 3 minučių S galia per mėnesį', NULL, 4, NULL, NULL),
	(4153, 34, 0, 9, 4, 1, 7, 5, 44, NULL, 'Maksimali 3 minučių S galia pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(4154, 34, 0, 9, 4, 1, 7, 6, 44, NULL, 'Maksimali 3 minučių S galia pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4155, 34, 0, 9, 4, 2, 7, 5, 44, NULL, 'Maksimali 3 minučių S galia pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(4156, 34, 0, 9, 4, 2, 7, 6, 44, NULL, 'Maksimali 3 minučių S galia pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4157, 34, 0, 9, 4, 3, 7, 5, 44, NULL, 'Maksimali 3 minučių S galia pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(4158, 34, 0, 9, 4, 3, 7, 6, 44, NULL, 'Maksimali 3 minučių S galia pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4159, 34, 0, 9, 4, 4, 7, 5, 44, NULL, 'Maksimali 3 minučių S galia pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(4160, 34, 0, 9, 4, 4, 7, 6, 44, NULL, 'Maksimali 3 minučių S galia pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4161, 1, 0, 12, 2, 0, 2, 11, 14, NULL, 'A energija per 10 minučių', 719, 1, NULL, NULL),
	(4162, 1, 0, 12, 3, 0, 1, 11, 13, NULL, 'Vidutinė P galia per 10 minučių', 446, 1, NULL, NULL),
	(4163, 1, 0, 12, 4, 0, 1, 5, 13, NULL, 'Maksimali 10 minučių P galia per parą', NULL, 3, NULL, NULL),
	(4164, 1, 0, 12, 4, 0, 1, 6, 13, NULL, 'Maksimali 10 minučių P galia per mėnesį', 3351, 4, NULL, NULL),
	(4165, 1, 0, 12, 5, 0, 1, 5, 13, NULL, 'Minimali 10 minučių P galia per parą', NULL, 3, NULL, NULL),
	(4166, 1, 0, 12, 5, 0, 1, 6, 13, NULL, 'Minimali 10 minučių P galia per mėnesį', NULL, 4, NULL, NULL),
	(4167, 3, 0, 12, 2, 0, 4, 11, 15, NULL, 'R energija per 10 minučių', 721, 1, NULL, NULL),
	(4168, 3, 0, 12, 3, 0, 3, 11, 16, NULL, 'Vidutinė Q galia per 10 minučių', 448, 1, NULL, NULL),
	(4169, 3, 0, 12, 4, 0, 3, 5, 16, NULL, 'Maksimali 10 minučių Q galia per parą', NULL, 3, NULL, NULL),
	(4170, 3, 0, 12, 4, 0, 3, 6, 16, NULL, 'Maksimali 10 minučių Q galia per mėnesį', 3352, 4, NULL, NULL),
	(4171, 3, 0, 12, 5, 0, 3, 5, 16, NULL, 'Minimali 10 minučių Q galia per parą', NULL, 3, NULL, NULL),
	(4172, 3, 0, 12, 5, 0, 3, 6, 16, NULL, 'Minimali 10 minučių Q galia per mėnesį', NULL, 4, NULL, NULL),
	(4173, 34, 0, 12, 2, 0, 41, 11, 45, NULL, 'W energija per 10 minučių', 723, 1, NULL, NULL),
	(4174, 34, 0, 12, 3, 0, 7, 11, 44, NULL, 'Vidutinė S galia per 10 minučių', 450, 1, NULL, NULL),
	(4175, 34, 0, 12, 4, 0, 7, 5, 44, NULL, 'Maksimali 10 minučių S galia per parą', NULL, 3, NULL, NULL),
	(4176, 34, 0, 12, 4, 0, 7, 6, 44, NULL, 'Maksimali 10 minučių S galia per mėnesį', NULL, 4, NULL, NULL),
	(4177, 34, 0, 12, 5, 0, 7, 5, 44, NULL, 'Minimali 10 minučių S galia per parą', NULL, 3, NULL, NULL),
	(4178, 34, 0, 12, 5, 0, 7, 6, 44, NULL, 'Minimali 10 minučių S galia per mėnesį', NULL, 4, NULL, NULL),
	(4179, 1, 0, 5, 3, 0, 1, 5, 13, NULL, 'Vidutinė P galia per parą', 446, 3, NULL, NULL),
	(4181, 1, 0, 5, 4, 0, 1, 6, 13, NULL, 'Maksimali paros P galia per mėnesį', 3351, 4, NULL, NULL),
	(4183, 1, 0, 5, 5, 0, 1, 6, 13, NULL, 'Minimali paros P galia per mėnesį', NULL, 4, NULL, NULL),
	(4184, 1, 0, 5, 2, 0, 2, 5, 14, NULL, 'A energija per parą', 691, 3, NULL, NULL),
	(4185, 1, 0, 5, 2, 6, 2, 5, 14, NULL, 'A energija pagal 6 tarifą per parą', 697, 3, NULL, NULL),
	(4187, 1, 0, 5, 4, 6, 2, 6, 14, NULL, 'Maksimali paros A energija pagal 6 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4189, 1, 0, 5, 5, 6, 2, 6, 14, NULL, 'Minimali paros A energija pagal 6 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4190, 1, 0, 5, 2, 7, 2, 5, 14, NULL, 'A energija pagal 7 tarifą per parą', 698, 3, NULL, NULL),
	(4192, 1, 0, 5, 4, 7, 2, 6, 14, NULL, 'Maksimali paros A energija pagal 7 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4194, 1, 0, 5, 5, 7, 2, 6, 14, NULL, 'Minimali paros A energija pagal 7 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4195, 1, 0, 5, 2, 1, 2, 5, 14, NULL, 'A energija pagal 1 tarifą per parą', 692, 3, NULL, NULL),
	(4197, 1, 0, 5, 4, 1, 2, 6, 14, NULL, 'Maksimali paros A energija pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4199, 1, 0, 5, 5, 1, 2, 6, 14, NULL, 'Minimali paros A energija pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4200, 1, 0, 5, 2, 8, 2, 5, 14, NULL, 'A energija pagal 8 tarifą per parą', 699, 3, NULL, NULL),
	(4202, 1, 0, 5, 4, 8, 2, 6, 14, NULL, 'Maksimali paros A energija pagal 8 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4204, 1, 0, 5, 5, 8, 2, 6, 14, NULL, 'Minimali paros A energija pagal 8 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4205, 1, 0, 5, 2, 2, 2, 5, 14, NULL, 'A energija pagal 2 tarifą per parą', 693, 3, NULL, NULL),
	(4207, 1, 0, 5, 4, 2, 2, 6, 14, NULL, 'Maksimali paros A energija pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4209, 1, 0, 5, 5, 2, 2, 6, 14, NULL, 'Minimali paros A energija pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4210, 1, 0, 5, 2, 3, 2, 5, 14, NULL, 'A energija pagal 3 tarifą per parą', 694, 3, NULL, NULL),
	(4212, 1, 0, 5, 4, 3, 2, 6, 14, NULL, 'Maksimali paros A energija pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4214, 1, 0, 5, 5, 3, 2, 6, 14, NULL, 'Minimali paros A energija pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4215, 1, 0, 5, 2, 5, 2, 5, 14, NULL, 'A energija pagal 5 tarifą per parą', 696, 3, NULL, NULL),
	(4217, 1, 0, 5, 4, 5, 2, 6, 14, NULL, 'Maksimali paros A energija pagal 5 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4219, 1, 0, 5, 5, 5, 2, 6, 14, NULL, 'Minimali paros A energija pagal 5 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4220, 1, 0, 5, 2, 4, 2, 5, 14, NULL, 'A energija pagal 4 tarifą per parą', 695, 3, NULL, NULL),
	(4222, 1, 0, 5, 4, 4, 2, 6, 14, NULL, 'Maksimali paros A energija pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4224, 1, 0, 5, 5, 4, 2, 6, 14, NULL, 'Minimali paros A energija pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4225, 3, 0, 5, 3, 0, 3, 5, 16, NULL, 'Vidutinė Q galia per parą', 448, 3, NULL, NULL),
	(4227, 3, 0, 5, 4, 0, 3, 6, 16, NULL, 'Maksimali paros Q galia per mėnesį', 3352, 4, NULL, NULL),
	(4229, 3, 0, 5, 5, 0, 3, 6, 16, NULL, 'Minimali paros Q galia per mėnesį', NULL, 4, NULL, NULL),
	(4230, 3, 0, 5, 2, 0, 4, 5, 15, NULL, 'R energija per parą', NULL, 3, NULL, NULL),
	(4231, 3, 0, 5, 2, 6, 4, 5, 15, NULL, 'R energija pagal 6 tarifą per parą', NULL, 3, NULL, NULL),
	(4233, 3, 0, 5, 4, 6, 4, 6, 15, NULL, 'Maksimali paros R energija pagal 6 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4235, 3, 0, 5, 5, 6, 4, 6, 15, NULL, 'Minimali paros R energija pagal 6 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4236, 3, 0, 5, 2, 7, 4, 5, 15, NULL, 'R energija pagal 7 tarifą per parą', NULL, 3, NULL, NULL),
	(4238, 3, 0, 5, 4, 7, 4, 6, 15, NULL, 'Maksimali paros R energija pagal 7 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4240, 3, 0, 5, 5, 7, 4, 6, 15, NULL, 'Minimali paros R energija pagal 7 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4241, 3, 0, 5, 2, 1, 4, 5, 15, NULL, 'R energija pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(4243, 3, 0, 5, 4, 1, 4, 6, 15, NULL, 'Maksimali paros R energija pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4245, 3, 0, 5, 5, 1, 4, 6, 15, NULL, 'Minimali paros R energija pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4246, 3, 0, 5, 2, 8, 4, 5, 15, NULL, 'R energija pagal 8 tarifą per parą', NULL, 3, NULL, NULL),
	(4248, 3, 0, 5, 4, 8, 4, 6, 15, NULL, 'Maksimali paros R energija pagal 8 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4250, 3, 0, 5, 5, 8, 4, 6, 15, NULL, 'Minimali paros R energija pagal 8 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4251, 3, 0, 5, 2, 2, 4, 5, 15, NULL, 'R energija pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(4253, 3, 0, 5, 4, 2, 4, 6, 15, NULL, 'Maksimali paros R energija pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4255, 3, 0, 5, 5, 2, 4, 6, 15, NULL, 'Minimali paros R energija pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4256, 3, 0, 5, 2, 3, 4, 5, 15, NULL, 'R energija pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(4258, 3, 0, 5, 4, 3, 4, 6, 15, NULL, 'Maksimali paros R energija pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4260, 3, 0, 5, 5, 3, 4, 6, 15, NULL, 'Minimali paros R energija pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4261, 3, 0, 5, 2, 5, 4, 5, 15, NULL, 'R energija pagal 5 tarifą per parą', NULL, 3, NULL, NULL),
	(4263, 3, 0, 5, 4, 5, 4, 6, 15, NULL, 'Maksimali paros R energija pagal 5 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4265, 3, 0, 5, 5, 5, 4, 6, 15, NULL, 'Minimali paros R energija pagal 5 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4266, 3, 0, 5, 2, 4, 4, 5, 15, NULL, 'R energija pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(4268, 3, 0, 5, 4, 4, 4, 6, 15, NULL, 'Maksimali paros R energija pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4270, 3, 0, 5, 5, 4, 4, 6, 15, NULL, 'Minimali paros R energija pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4271, 34, 0, 5, 3, 0, 7, 5, 44, NULL, 'Vidutinė S galia per parą', 450, 3, NULL, NULL),
	(4272, 34, 0, 5, 2, 0, 41, 5, 45, NULL, 'W energija per parą', NULL, 3, NULL, NULL),
	(4273, 34, 0, 5, 2, 6, 41, 5, 45, NULL, 'W energija pagal 6 tarifą per parą', NULL, 3, NULL, NULL),
	(4275, 34, 0, 5, 4, 6, 41, 6, 45, NULL, 'Maksimali paros W energija pagal 6 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4277, 34, 0, 5, 5, 6, 41, 6, 45, NULL, 'Minimali paros W energija pagal 6 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4278, 34, 0, 5, 2, 7, 41, 5, 45, NULL, 'W energija pagal 7 tarifą per parą', NULL, 3, NULL, NULL),
	(4280, 34, 0, 5, 4, 7, 41, 6, 45, NULL, 'Maksimali paros W energija pagal 7 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4282, 34, 0, 5, 5, 7, 41, 6, 45, NULL, 'Minimali paros W energija pagal 7 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4283, 34, 0, 5, 2, 1, 41, 5, 45, NULL, 'W energija pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(4285, 34, 0, 5, 4, 1, 41, 6, 45, NULL, 'Maksimali paros W energija pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4287, 34, 0, 5, 5, 1, 41, 6, 45, NULL, 'Minimali paros W energija pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4288, 34, 0, 5, 2, 8, 41, 5, 45, NULL, 'W energija pagal 8 tarifą per parą', NULL, 3, NULL, NULL),
	(4290, 34, 0, 5, 4, 8, 41, 6, 45, NULL, 'Maksimali paros W energija pagal 8 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4292, 34, 0, 5, 5, 8, 41, 6, 45, NULL, 'Minimali paros W energija pagal 8 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4293, 34, 0, 5, 2, 2, 41, 5, 45, NULL, 'W energija pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(4295, 34, 0, 5, 4, 2, 41, 6, 45, NULL, 'Maksimali paros W energija pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4297, 34, 0, 5, 5, 2, 41, 6, 45, NULL, 'Minimali paros W energija pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4298, 34, 0, 5, 2, 3, 41, 5, 45, NULL, 'W energija pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(4300, 34, 0, 5, 4, 3, 41, 6, 45, NULL, 'Maksimali paros W energija pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4302, 34, 0, 5, 5, 3, 41, 6, 45, NULL, 'Minimali paros W energija pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4303, 34, 0, 5, 2, 5, 41, 5, 45, NULL, 'W energija pagal 5 tarifą per parą', NULL, 3, NULL, NULL),
	(4305, 34, 0, 5, 4, 5, 41, 6, 45, NULL, 'Maksimali paros W energija pagal 5 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4307, 34, 0, 5, 5, 5, 41, 6, 45, NULL, 'Minimali paros W energija pagal 5 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4308, 34, 0, 5, 2, 4, 41, 5, 45, NULL, 'W energija pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(4310, 34, 0, 5, 4, 4, 41, 6, 45, NULL, 'Maksimali paros W energija pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4312, 34, 0, 5, 5, 4, 41, 6, 45, NULL, 'Minimali paros W energija pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4313, 1, 0, 6, 2, 0, 2, 6, 14, NULL, 'A energija per mėnesį', 700, 4, NULL, NULL),
	(4316, 1, 0, 6, 2, 6, 2, 6, 14, NULL, 'A energija pagal 6 tarifą per mėnesį', 706, 4, NULL, NULL),
	(4319, 1, 0, 6, 2, 7, 2, 6, 14, NULL, 'A energija pagal 7 tarifą per mėnesį', 707, 4, NULL, NULL),
	(4322, 1, 0, 6, 2, 1, 2, 6, 14, NULL, 'A energija pagal 1 tarifą per mėnesį', 701, 4, NULL, NULL),
	(4325, 1, 0, 6, 2, 8, 2, 6, 14, NULL, 'A energija pagal 8 tarifą per mėnesį', 708, 4, NULL, NULL),
	(4328, 1, 0, 6, 2, 2, 2, 6, 14, NULL, 'A energija pagal 2 tarifą per mėnesį', 702, 4, NULL, NULL),
	(4331, 1, 0, 6, 2, 3, 2, 6, 14, NULL, 'A energija pagal 3 tarifą per mėnesį', 703, 4, NULL, NULL),
	(4334, 1, 0, 6, 2, 5, 2, 6, 14, NULL, 'A energija pagal 5 tarifą per mėnesį', 705, 4, NULL, NULL),
	(4337, 1, 0, 6, 2, 4, 2, 6, 14, NULL, 'A energija pagal 4 tarifą per mėnesį', 704, 4, NULL, NULL),
	(4340, 3, 0, 6, 2, 0, 4, 6, 15, NULL, 'R energija per mėnesį', NULL, 4, NULL, NULL),
	(4343, 3, 0, 6, 2, 6, 4, 6, 15, NULL, 'R energija pagal 6 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4346, 3, 0, 6, 2, 7, 4, 6, 15, NULL, 'R energija pagal 7 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4349, 3, 0, 6, 2, 1, 4, 6, 15, NULL, 'R energija pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4352, 3, 0, 6, 2, 8, 4, 6, 15, NULL, 'R energija pagal 8 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4355, 3, 0, 6, 2, 2, 4, 6, 15, NULL, 'R energija pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4358, 3, 0, 6, 2, 3, 4, 6, 15, NULL, 'R energija pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4361, 3, 0, 6, 2, 5, 4, 6, 15, NULL, 'R energija pagal 5 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4364, 3, 0, 6, 2, 4, 4, 6, 15, NULL, 'R energija pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4367, 34, 0, 6, 2, 0, 41, 6, 45, NULL, 'W energija per mėnesį', NULL, 4, NULL, NULL),
	(4370, 34, 0, 6, 2, 6, 41, 6, 45, NULL, 'W energija pagal 6 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4373, 34, 0, 6, 2, 7, 41, 6, 45, NULL, 'W energija pagal 7 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4376, 34, 0, 6, 2, 1, 41, 6, 45, NULL, 'W energija pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4379, 34, 0, 6, 2, 8, 41, 6, 45, NULL, 'W energija pagal 8 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4382, 34, 0, 6, 2, 2, 41, 6, 45, NULL, 'W energija pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4385, 34, 0, 6, 2, 3, 41, 6, 45, NULL, 'W energija pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4388, 34, 0, 6, 2, 5, 41, 6, 45, NULL, 'W energija pagal 5 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4391, 34, 0, 6, 2, 4, 41, 6, 45, NULL, 'W energija pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4394, 1, 0, 11, 2, 0, 2, 10, 14, NULL, 'A energija per 5 minutes', 719, 1, NULL, NULL),
	(4395, 1, 0, 11, 3, 0, 1, 10, 13, NULL, 'Vidutinė P galia per 5 minutes', 446, 1, NULL, NULL),
	(4396, 1, 0, 11, 4, 0, 1, 5, 13, NULL, 'Maksimali 5 minučių P galia per parą', NULL, 3, NULL, NULL),
	(4397, 1, 0, 11, 4, 0, 1, 6, 13, NULL, 'Maksimali 5 minučių P galia per mėnesį', 3351, 4, NULL, NULL),
	(4398, 1, 0, 11, 5, 0, 1, 5, 13, NULL, 'Minimali 5 minučių P galia per parą', NULL, 3, NULL, NULL),
	(4399, 1, 0, 11, 5, 0, 1, 6, 13, NULL, 'Minimali 5 minučių P galia per mėnesį', NULL, 4, NULL, NULL),
	(4400, 3, 0, 11, 2, 0, 4, 10, 15, NULL, 'R energija per 5 minutes', 721, 1, NULL, NULL),
	(4401, 3, 0, 11, 3, 0, 3, 10, 16, NULL, 'Vidutinė Q galia per 5 minutes', 448, 1, NULL, NULL),
	(4402, 3, 0, 11, 4, 0, 3, 5, 16, NULL, 'Maksimali 5 minučių Q galia per parą', NULL, 3, NULL, NULL),
	(4403, 3, 0, 11, 4, 0, 3, 6, 16, NULL, 'Maksimali 5 minučių Q galia per mėnesį', 3352, 4, NULL, NULL),
	(4404, 3, 0, 11, 5, 0, 3, 5, 16, NULL, 'Minimali 5 minučių Q galia per parą', NULL, 3, NULL, NULL),
	(4405, 3, 0, 11, 5, 0, 3, 6, 16, NULL, 'Minimali 5 minučių Q galia per mėnesį', NULL, 4, NULL, NULL),
	(4406, 34, 0, 11, 2, 0, 41, 10, 45, NULL, 'W energija per 5 minutes', 723, 1, NULL, NULL),
	(4407, 34, 0, 11, 3, 0, 7, 10, 44, NULL, 'Vidutinė S galia per 5 minutes', 450, 1, NULL, NULL),
	(4408, 34, 0, 11, 4, 0, 7, 5, 44, NULL, 'Maksimali 5 minučių S galia per parą', NULL, 3, NULL, NULL),
	(4409, 34, 0, 11, 4, 0, 7, 6, 44, NULL, 'Maksimali 5 minučių S galia per mėnesį', NULL, 4, NULL, NULL),
	(4410, 34, 0, 11, 5, 0, 7, 5, 44, NULL, 'Minimali 5 minučių S galia per parą', NULL, 3, NULL, NULL),
	(4411, 34, 0, 11, 5, 0, 7, 6, 44, NULL, 'Minimali 5 minučių S galia per mėnesį', NULL, 4, NULL, NULL),
	(4412, 1, 0, 10, 2, 0, 2, 9, 14, NULL, 'A energija per 4 minutes', 719, 1, NULL, NULL),
	(4413, 1, 0, 10, 3, 0, 1, 9, 13, NULL, 'Vidutinė P galia per 4 minutes', 446, 1, NULL, NULL),
	(4414, 1, 0, 10, 4, 0, 1, 5, 13, NULL, 'Maksimali 4 minučių P galia per parą', NULL, 3, NULL, NULL),
	(4415, 1, 0, 10, 4, 0, 1, 6, 13, NULL, 'Maksimali 4 minučių P galia per mėnesį', 3351, 4, NULL, NULL),
	(4416, 1, 0, 10, 5, 0, 1, 5, 13, NULL, 'Minimali 4 minučių P galia per parą', NULL, 3, NULL, NULL),
	(4417, 1, 0, 10, 5, 0, 1, 6, 13, NULL, 'Minimali 4 minučių P galia per mėnesį', NULL, 4, NULL, NULL),
	(4418, 3, 0, 10, 2, 0, 4, 9, 15, NULL, 'R energija per 4 minutes', 721, 1, NULL, NULL),
	(4419, 3, 0, 10, 3, 0, 3, 9, 16, NULL, 'Vidutinė Q galia per 4 minutes', 448, 1, NULL, NULL),
	(4420, 3, 0, 10, 4, 0, 3, 5, 16, NULL, 'Maksimali 4 minučių Q galia per parą', NULL, 3, NULL, NULL),
	(4421, 3, 0, 10, 4, 0, 3, 6, 16, NULL, 'Maksimali 4 minučių Q galia per mėnesį', 3352, 4, NULL, NULL),
	(4422, 3, 0, 10, 5, 0, 3, 5, 16, NULL, 'Minimali 4 minučių Q galia per parą', NULL, 3, NULL, NULL),
	(4423, 3, 0, 10, 5, 0, 3, 6, 16, NULL, 'Minimali 4 minučių Q galia per mėnesį', NULL, 4, NULL, NULL),
	(4424, 34, 0, 10, 2, 0, 41, 9, 45, NULL, 'W energija per 4 minutes', 723, 1, NULL, NULL),
	(4425, 34, 0, 10, 3, 0, 7, 9, 44, NULL, 'Vidutinė S galia per 4 minutes', 450, 1, NULL, NULL),
	(4426, 34, 0, 10, 4, 0, 7, 5, 44, NULL, 'Maksimali 4 minučių S galia per parą', NULL, 3, NULL, NULL),
	(4427, 34, 0, 10, 4, 0, 7, 6, 44, NULL, 'Maksimali 4 minučių S galia per mėnesį', NULL, 4, NULL, NULL),
	(4428, 34, 0, 10, 5, 0, 7, 5, 44, NULL, 'Minimali 4 minučių S galia per parą', NULL, 3, NULL, NULL),
	(4429, 34, 0, 10, 5, 0, 7, 6, 44, NULL, 'Minimali 4 minučių S galia per mėnesį', NULL, 4, NULL, NULL),
	(4430, 1, 0, 13, 2, 0, 2, 12, 14, NULL, 'A energija per 15 minučių', 719, 2, NULL, NULL),
	(4431, 1, 0, 13, 3, 0, 1, 12, 13, NULL, 'Vidutinė P galia per 15 minučių', 446, 2, NULL, NULL),
	(4432, 1, 0, 13, 4, 0, 1, 5, 13, NULL, 'Maksimali 15 minučių P galia per parą', NULL, 3, NULL, NULL),
	(4433, 1, 0, 13, 4, 0, 1, 6, 13, NULL, 'Maksimali 15 minučių P galia per mėnesį', 3351, 4, NULL, NULL),
	(4434, 1, 0, 13, 5, 0, 1, 5, 13, NULL, 'Minimali 15 minučių P galia per parą', NULL, 3, NULL, NULL),
	(4435, 1, 0, 13, 5, 0, 1, 6, 13, NULL, 'Minimali 15 minučių P galia per mėnesį', NULL, 4, NULL, NULL),
	(4436, 1, 0, 13, 4, 1, 1, 5, 13, NULL, 'Maksimali 15 minučių P galia pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(4437, 1, 0, 13, 4, 1, 1, 6, 13, NULL, 'Maksimali 15 minučių P galia pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4438, 1, 0, 13, 4, 2, 1, 5, 13, NULL, 'Maksimali 15 minučių P galia pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(4439, 1, 0, 13, 4, 2, 1, 6, 13, NULL, 'Maksimali 15 minučių P galia pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4440, 1, 0, 13, 4, 3, 1, 5, 13, NULL, 'Maksimali 15 minučių P galia pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(4441, 1, 0, 13, 4, 3, 1, 6, 13, NULL, 'Maksimali 15 minučių P galia pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4442, 1, 0, 13, 4, 4, 1, 5, 13, NULL, 'Maksimali 15 minučių P galia pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(4443, 1, 0, 13, 4, 4, 1, 6, 13, NULL, 'Maksimali 15 minučių P galia pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4444, 3, 0, 13, 2, 0, 4, 12, 15, NULL, 'R energija per 15 minučių', 721, 2, NULL, NULL),
	(4445, 3, 0, 13, 3, 0, 3, 12, 16, NULL, 'Vidutinė Q galia per 15 minučių', 448, 2, NULL, NULL),
	(4446, 3, 0, 13, 4, 0, 3, 5, 16, NULL, 'Maksimali 15 minučių Q galia per parą', NULL, 3, NULL, NULL),
	(4447, 3, 0, 13, 4, 0, 3, 6, 16, NULL, 'Maksimali 15 minučių Q galia per mėnesį', 3352, 4, NULL, NULL),
	(4448, 3, 0, 13, 5, 0, 3, 5, 16, NULL, 'Minimali 15 minučių Q galia per parą', NULL, 3, NULL, NULL),
	(4449, 3, 0, 13, 5, 0, 3, 6, 16, NULL, 'Minimali 15 minučių Q galia per mėnesį', NULL, 4, NULL, NULL),
	(4450, 3, 0, 13, 4, 1, 3, 5, 16, NULL, 'Maksimali 15 minučių Q galia pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(4451, 3, 0, 13, 4, 1, 3, 6, 16, NULL, 'Maksimali 15 minučių Q galia pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4452, 3, 0, 13, 4, 2, 3, 5, 16, NULL, 'Maksimali 15 minučių Q galia pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(4453, 3, 0, 13, 4, 2, 3, 6, 16, NULL, 'Maksimali 15 minučių Q galia pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4454, 3, 0, 13, 4, 3, 3, 5, 16, NULL, 'Maksimali 15 minučių Q galia pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(4455, 3, 0, 13, 4, 3, 3, 6, 16, NULL, 'Maksimali 15 minučių Q galia pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4456, 3, 0, 13, 4, 4, 3, 5, 16, NULL, 'Maksimali 15 minučių Q galia pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(4457, 3, 0, 13, 4, 4, 3, 6, 16, NULL, 'Maksimali 15 minučių Q galia pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4458, 34, 0, 13, 2, 0, 41, 12, 45, NULL, 'W energija per 15 minučių', 723, 2, NULL, NULL),
	(4459, 34, 0, 13, 3, 0, 7, 12, 44, NULL, 'Vidutinė S galia per 15 minučių', 450, 2, NULL, NULL),
	(4460, 34, 0, 13, 4, 0, 7, 5, 44, NULL, 'Maksimali 15 minučių S galia per parą', NULL, 3, NULL, NULL),
	(4461, 34, 0, 13, 4, 0, 7, 6, 44, NULL, 'Maksimali 15 minučių S galia per mėnesį', NULL, 4, NULL, NULL),
	(4462, 34, 0, 13, 5, 0, 7, 5, 44, NULL, 'Minimali 15 minučių S galia per parą', NULL, 3, NULL, NULL),
	(4463, 34, 0, 13, 5, 0, 7, 6, 44, NULL, 'Minimali 15 minučių S galia per mėnesį', NULL, 4, NULL, NULL),
	(4464, 34, 0, 13, 4, 1, 7, 5, 44, NULL, 'Maksimali 15 minučių S galia pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(4465, 34, 0, 13, 4, 1, 7, 6, 44, NULL, 'Maksimali 15 minučių S galia pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4466, 34, 0, 13, 4, 2, 7, 5, 44, NULL, 'Maksimali 15 minučių S galia pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(4467, 34, 0, 13, 4, 2, 7, 6, 44, NULL, 'Maksimali 15 minučių S galia pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4468, 34, 0, 13, 4, 3, 7, 5, 44, NULL, 'Maksimali 15 minučių S galia pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(4469, 34, 0, 13, 4, 3, 7, 6, 44, NULL, 'Maksimali 15 minučių S galia pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4470, 34, 0, 13, 4, 4, 7, 5, 44, NULL, 'Maksimali 15 minučių S galia pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(4471, 34, 0, 13, 4, 4, 7, 6, 44, NULL, 'Maksimali 15 minučių S galia pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(4472, 1, 0, 14, 2, 0, 2, 13, 14, NULL, 'A energija per 20 minučių', 719, 2, NULL, NULL),
	(4473, 1, 0, 14, 3, 0, 1, 13, 13, NULL, 'Vidutinė P galia per 20 minučių', 446, 2, NULL, NULL),
	(4474, 1, 0, 14, 4, 0, 1, 5, 13, NULL, 'Maksimali 20 minučių P galia per parą', NULL, 3, NULL, NULL),
	(4475, 1, 0, 14, 4, 0, 1, 6, 13, NULL, 'Maksimali 20 minučių P galia per mėnesį', 3351, 4, NULL, NULL),
	(4476, 1, 0, 14, 5, 0, 1, 5, 13, NULL, 'Minimali 20 minučių P galia per parą', NULL, 3, NULL, NULL),
	(4477, 1, 0, 14, 5, 0, 1, 6, 13, NULL, 'Minimali 20 minučių P galia per mėnesį', NULL, 4, NULL, NULL),
	(4478, 3, 0, 14, 2, 0, 4, 13, 15, NULL, 'R energija per 20 minučių', 721, 2, NULL, NULL),
	(4479, 3, 0, 14, 3, 0, 3, 13, 16, NULL, 'Vidutinė Q galia per 20 minučių', 448, 2, NULL, NULL),
	(4480, 3, 0, 14, 4, 0, 3, 5, 16, NULL, 'Maksimali 20 minučių Q galia per parą', NULL, 3, NULL, NULL),
	(4481, 3, 0, 14, 4, 0, 3, 6, 16, NULL, 'Maksimali 20 minučių Q galia per mėnesį', 3352, 4, NULL, NULL),
	(4482, 3, 0, 14, 5, 0, 3, 5, 16, NULL, 'Minimali 20 minučių Q galia per parą', NULL, 3, NULL, NULL),
	(4483, 3, 0, 14, 5, 0, 3, 6, 16, NULL, 'Minimali 20 minučių Q galia per mėnesį', NULL, 4, NULL, NULL),
	(4484, 34, 0, 14, 2, 0, 41, 13, 45, NULL, 'W energija per 20 minučių', 723, 2, NULL, NULL),
	(4485, 34, 0, 14, 3, 0, 7, 13, 44, NULL, 'Vidutinė S galia per 20 minučių', 450, 2, NULL, NULL),
	(4486, 34, 0, 14, 4, 0, 7, 5, 44, NULL, 'Maksimali 20 minučių S galia per parą', NULL, 3, NULL, NULL),
	(4487, 34, 0, 14, 4, 0, 7, 6, 44, NULL, 'Maksimali 20 minučių S galia per mėnesį', NULL, 4, NULL, NULL),
	(4488, 34, 0, 14, 5, 0, 7, 5, 44, NULL, 'Minimali 20 minučių S galia per parą', NULL, 3, NULL, NULL),
	(4489, 34, 0, 14, 5, 0, 7, 6, 44, NULL, 'Minimali 20 minučių S galia per mėnesį', NULL, 4, NULL, NULL),
	(4490, 5, 0, 7, 1, 0, 5, 2, 17, NULL, 'Momentinis srovės stiprumas L1 fazėje, fiksuojamas kas 2 minutes', 53, 1, NULL, NULL),
	(4491, 5, 0, 7, 1, 0, 5, 15, 17, NULL, 'Momentinis srovės stiprumas L1 fazėje, fiksuojamas kas 5 sekundes', 53, 7, NULL, NULL),
	(4492, 5, 0, 7, 1, 0, 5, 19, 17, NULL, 'Momentinis srovės stiprumas L1 fazėje, fiksuojamas kas 30 sekundžių', 53, 7, NULL, NULL),
	(4493, 6, 0, 7, 1, 0, 6, 2, 18, NULL, 'Momentinė įtampa L1 fazėje, fiksuojama kas 2 minutes', 54, 1, NULL, NULL),
	(4494, 6, 0, 7, 1, 0, 6, 15, 18, NULL, 'Momentinė įtampa L1 fazėje, fiksuojama kas 5 sekundes', 54, 7, NULL, NULL),
	(4495, 6, 0, 7, 1, 0, 6, 19, 18, NULL, 'Momentinė įtampa L1 fazėje, fiksuojama kas 30 sekundžių', 54, 7, NULL, NULL),
	(4496, 7, 0, 7, 1, 0, 5, 2, 19, NULL, 'Momentinis srovės stiprumas L2 fazėje, fiksuojamas kas 2 minutes', 55, 1, NULL, NULL),
	(4497, 7, 0, 7, 1, 0, 5, 15, 19, NULL, 'Momentinis srovės stiprumas L2 fazėje, fiksuojamas kas 5 sekundes', 55, 7, NULL, NULL),
	(4498, 7, 0, 7, 1, 0, 5, 19, 19, NULL, 'Momentinis srovės stiprumas L2 fazėje, fiksuojamas kas 30 sekundžių', 55, 7, NULL, NULL),
	(4499, 8, 0, 7, 1, 0, 6, 2, 20, NULL, 'Momentinė įtampa L2 fazėje, fiksuojama kas 2 minutes', 56, 1, NULL, NULL),
	(4500, 8, 0, 7, 1, 0, 6, 15, 20, NULL, 'Momentinė įtampa L2 fazėje, fiksuojama kas 5 sekundes', 56, 7, NULL, NULL),
	(4501, 8, 0, 7, 1, 0, 6, 19, 20, NULL, 'Momentinė įtampa L2 fazėje, fiksuojama kas 30 sekundžių', 56, 7, NULL, NULL),
	(4502, 9, 0, 7, 1, 0, 5, 2, 21, NULL, 'Momentinis srovės stiprumas L3 fazėje, fiksuojamas kas 2 minutes', 57, 1, NULL, NULL),
	(4503, 9, 0, 7, 1, 0, 5, 15, 21, NULL, 'Momentinis srovės stiprumas L3 fazėje, fiksuojamas kas 5 sekundes', 57, 7, NULL, NULL),
	(4504, 9, 0, 7, 1, 0, 5, 19, 21, NULL, 'Momentinis srovės stiprumas L3 fazėje, fiksuojamas kas 30 sekundžių', 57, 7, NULL, NULL),
	(4505, 10, 0, 7, 1, 0, 6, 2, 22, NULL, 'Momentinė įtampa L3 fazėje, fiksuojama kas 2 minutes', 58, 1, NULL, NULL),
	(4506, 10, 0, 7, 1, 0, 6, 15, 22, NULL, 'Momentinė įtampa L3 fazėje, fiksuojama kas 5 sekundes', 58, 7, NULL, NULL),
	(4507, 10, 0, 7, 1, 0, 6, 19, 22, NULL, 'Momentinė įtampa L3 fazėje, fiksuojama kas 30 sekundžių', 58, 7, NULL, NULL),
	(4508, 11, 0, 7, 1, 0, 6, 2, 23, NULL, 'Momentinė linijinė įtampa L1 fazėje, fiksuojama kas 2 minutes', 59, 1, NULL, NULL),
	(4509, 11, 0, 7, 1, 0, 6, 15, 23, NULL, 'Momentinė linijinė įtampa L1 fazėje, fiksuojama kas 5 sekundes', 59, 7, NULL, NULL),
	(4510, 11, 0, 7, 1, 0, 6, 19, 23, NULL, 'Momentinė linijinė įtampa L1 fazėje, fiksuojama kas 30 sekundžių', 59, 7, NULL, NULL),
	(4511, 12, 0, 7, 1, 0, 6, 2, 24, NULL, 'Momentinė linijinė įtampa L2 fazėje, fiksuojama kas 2 minutes', 60, 1, NULL, NULL),
	(4512, 12, 0, 7, 1, 0, 6, 15, 24, NULL, 'Momentinė linijinė įtampa L2 fazėje, fiksuojama kas 5 sekundes', 60, 7, NULL, NULL),
	(4513, 12, 0, 7, 1, 0, 6, 19, 24, NULL, 'Momentinė linijinė įtampa L2 fazėje, fiksuojama kas 30 sekundžių', 60, 7, NULL, NULL),
	(4514, 13, 0, 7, 1, 0, 6, 2, 25, NULL, 'Momentinė linijinė įtampa L3 fazėje, fiksuojama kas 2 minutes', 61, 1, NULL, NULL),
	(4515, 13, 0, 7, 1, 0, 6, 15, 25, NULL, 'Momentinė linijinė įtampa L3 fazėje, fiksuojama kas 5 sekundes', 61, 7, NULL, NULL),
	(4516, 13, 0, 7, 1, 0, 6, 19, 25, NULL, 'Momentinė linijinė įtampa L3 fazėje, fiksuojama kas 30 sekundžių', 61, 7, NULL, NULL),
	(4517, 14, 0, 7, 1, 0, 1, 2, 26, NULL, 'Momentinė aktyvinė galia L1 fazėje, fiksuojama kas 2 minutes', 62, 1, NULL, NULL),
	(4518, 14, 0, 7, 1, 0, 1, 15, 26, NULL, 'Momentinė aktyvinė galia L1 fazėje, fiksuojama kas 5 sekundes', 62, 7, NULL, NULL),
	(4519, 14, 0, 7, 1, 0, 1, 19, 26, NULL, 'Momentinė aktyvinė galia L1 fazėje, fiksuojama kas 30 sekundžių', 62, 7, NULL, NULL),
	(4520, 15, 0, 7, 1, 0, 1, 2, 27, NULL, 'Momentinė aktyvinė galia L2 fazėje, fiksuojama kas 2 minutes', 63, 1, NULL, NULL),
	(4521, 15, 0, 7, 1, 0, 1, 15, 27, NULL, 'Momentinė aktyvinė galia L2 fazėje, fiksuojama kas 5 sekundes', 63, 7, NULL, NULL),
	(4522, 15, 0, 7, 1, 0, 1, 19, 27, NULL, 'Momentinė aktyvinė galia L2 fazėje, fiksuojama kas 30 sekundžių', 63, 7, NULL, NULL),
	(4523, 16, 0, 7, 1, 0, 1, 2, 28, NULL, 'Momentinė aktyvinė galia L3 fazėje, fiksuojama kas 2 minutes', 64, 1, NULL, NULL),
	(4524, 16, 0, 7, 1, 0, 1, 15, 28, NULL, 'Momentinė aktyvinė galia L3 fazėje, fiksuojama kas 5 sekundes', 64, 7, NULL, NULL),
	(4525, 16, 0, 7, 1, 0, 1, 19, 28, NULL, 'Momentinė aktyvinė galia L3 fazėje, fiksuojama kas 30 sekundžių', 64, 7, NULL, NULL),
	(4526, 17, 0, 7, 1, 0, 3, 2, 29, NULL, 'Momentinė reaktyvinė galia L1 fazėje, fiksuojama kas 2 minutes', 65, 1, NULL, NULL),
	(4527, 17, 0, 7, 1, 0, 3, 15, 29, NULL, 'Momentinė reaktyvinė galia L1 fazėje, fiksuojama kas 5 sekundes', 65, 7, NULL, NULL),
	(4528, 17, 0, 7, 1, 0, 3, 19, 29, NULL, 'Momentinė reaktyvinė galia L1 fazėje, fiksuojama kas 30 sekundžių', 65, 7, NULL, NULL),
	(4529, 18, 0, 7, 1, 0, 3, 2, 30, NULL, 'Momentinė reaktyvinė galia L2 fazėje, fiksuojama kas 2 minutes', 66, 1, NULL, NULL),
	(4530, 18, 0, 7, 1, 0, 3, 15, 30, NULL, 'Momentinė reaktyvinė galia L2 fazėje, fiksuojama kas 5 sekundes', 66, 7, NULL, NULL),
	(4531, 18, 0, 7, 1, 0, 3, 19, 30, NULL, 'Momentinė reaktyvinė galia L2 fazėje, fiksuojama kas 30 sekundžių', 66, 7, NULL, NULL),
	(4532, 19, 0, 7, 1, 0, 3, 2, 31, NULL, 'Momentinė reaktyvinė galia L3 fazėje, fiksuojama kas 2 minutes', 67, 1, NULL, NULL),
	(4533, 19, 0, 7, 1, 0, 3, 15, 31, NULL, 'Momentinė reaktyvinė galia L3 fazėje, fiksuojama kas 5 sekundes', 67, 7, NULL, NULL),
	(4534, 19, 0, 7, 1, 0, 3, 19, 31, NULL, 'Momentinė reaktyvinė galia L3 fazėje, fiksuojama kas 30 sekundžių', 67, 7, NULL, NULL),
	(4535, 20, 0, 7, 1, 0, 7, 2, 32, NULL, 'Momentinė pilnoji galia L1 fazėje, fiksuojama kas 2 minutes', 68, 1, NULL, NULL),
	(4536, 20, 0, 7, 1, 0, 7, 15, 32, NULL, 'Momentinė pilnoji galia L1 fazėje, fiksuojama kas 5 sekundes', 68, 7, NULL, NULL),
	(4537, 20, 0, 7, 1, 0, 7, 19, 32, NULL, 'Momentinė pilnoji galia L1 fazėje, fiksuojama kas 30 sekundžių', 68, 7, NULL, NULL),
	(4538, 21, 0, 7, 1, 0, 7, 2, 33, NULL, 'Momentinė pilnoji galia L2 fazėje, fiksuojama kas 2 minutes', 69, 1, NULL, NULL),
	(4539, 21, 0, 7, 1, 0, 7, 15, 33, NULL, 'Momentinė pilnoji galia L2 fazėje, fiksuojama kas 5 sekundes', 69, 7, NULL, NULL),
	(4540, 21, 0, 7, 1, 0, 7, 19, 33, NULL, 'Momentinė pilnoji galia L2 fazėje, fiksuojama kas 30 sekundžių', 69, 7, NULL, NULL),
	(4541, 22, 0, 7, 1, 0, 7, 2, 34, NULL, 'Momentinė pilnoji galia L3 fazėje, fiksuojama kas 2 minutes', 70, 1, NULL, NULL),
	(4542, 22, 0, 7, 1, 0, 7, 15, 34, NULL, 'Momentinė pilnoji galia L3 fazėje, fiksuojama kas 5 sekundes', 70, 7, NULL, NULL),
	(4543, 22, 0, 7, 1, 0, 7, 19, 34, NULL, 'Momentinė pilnoji galia L3 fazėje, fiksuojama kas 30 sekundžių', 70, 7, NULL, NULL),
	(4544, 23, 0, 7, 1, 0, 0, 2, 35, NULL, 'Momentinė cos(fi) reikšmė L1 fazėje, fiksuojama kas 2 minutes', 71, 1, NULL, NULL),
	(4545, 23, 0, 7, 1, 0, 0, 15, 35, NULL, 'Momentinė cos(fi) reikšmė L1 fazėje, fiksuojama kas 5 sekundes', 71, 7, NULL, NULL),
	(4546, 23, 0, 7, 1, 0, 0, 19, 35, NULL, 'Momentinė cos(fi) reikšmė L1 fazėje, fiksuojama kas 30 sekundžių', 71, 7, NULL, NULL),
	(4547, 24, 0, 7, 1, 0, 0, 2, 36, NULL, 'Momentinė cos(fi) reikšmė L2 fazėje, fiksuojama kas 2 minutes', 72, 1, NULL, NULL),
	(4548, 24, 0, 7, 1, 0, 0, 15, 36, NULL, 'Momentinė cos(fi) reikšmė L2 fazėje, fiksuojama kas 5 sekundes', 72, 7, NULL, NULL),
	(4549, 24, 0, 7, 1, 0, 0, 19, 36, NULL, 'Momentinė cos(fi) reikšmė L2 fazėje, fiksuojama kas 30 sekundžių', 72, 7, NULL, NULL),
	(4550, 25, 0, 7, 1, 0, 0, 2, 37, NULL, 'Momentinė cos(fi) reikšmė L3 fazėje, fiksuojama kas 2 minutes', 73, 1, NULL, NULL),
	(4551, 25, 0, 7, 1, 0, 0, 15, 37, NULL, 'Momentinė cos(fi) reikšmė L3 fazėje, fiksuojama kas 5 sekundes', 73, 7, NULL, NULL),
	(4552, 25, 0, 7, 1, 0, 0, 19, 37, NULL, 'Momentinė cos(fi) reikšmė L3 fazėje, fiksuojama kas 30 sekundžių', 73, 7, NULL, NULL),
	(4553, 26, 0, 7, 1, 0, 0, 2, 38, NULL, 'Momentinis kvadrantas L1 fazėje, fiksuojamas kas 2 minutes', 74, 1, NULL, NULL),
	(4554, 26, 0, 7, 1, 0, 0, 15, 38, NULL, 'Momentinis kvadrantas L1 fazėje, fiksuojamas kas 5 sekundes', 74, 7, NULL, NULL),
	(4555, 26, 0, 7, 1, 0, 0, 19, 38, NULL, 'Momentinis kvadrantas L1 fazėje, fiksuojamas kas 30 sekundžių', 74, 7, NULL, NULL),
	(4556, 27, 0, 7, 1, 0, 0, 2, 39, NULL, 'Momentinis kvadrantas L2 fazėje, fiksuojamas kas 2 minutes', 75, 1, NULL, NULL),
	(4557, 27, 0, 7, 1, 0, 0, 15, 39, NULL, 'Momentinis kvadrantas L2 fazėje, fiksuojamas kas 5 sekundes', 75, 7, NULL, NULL),
	(4558, 27, 0, 7, 1, 0, 0, 19, 39, NULL, 'Momentinis kvadrantas L2 fazėje, fiksuojamas kas 30 sekundžių', 75, 7, NULL, NULL),
	(4559, 28, 0, 7, 1, 0, 0, 2, 40, NULL, 'Momentinis kvadrantas L3 fazėje, fiksuojamas kas 2 minutes', 76, 1, NULL, NULL),
	(4560, 28, 0, 7, 1, 0, 0, 15, 40, NULL, 'Momentinis kvadrantas L3 fazėje, fiksuojamas kas 5 sekundes', 76, 7, NULL, NULL),
	(4561, 28, 0, 7, 1, 0, 0, 19, 40, NULL, 'Momentinis kvadrantas L3 fazėje, fiksuojamas kas 30 sekundžių', 76, 7, NULL, NULL),
	(4562, 29, 0, 7, 1, 0, 5, 2, 41, NULL, 'Momentinis srovės stiprumas, fiksuojamas kas 2 minutes', 77, 1, NULL, NULL),
	(4563, 29, 0, 7, 1, 0, 5, 15, 41, NULL, 'Momentinis srovės stiprumas, fiksuojamas kas 5 sekundes', 77, 7, NULL, NULL),
	(4564, 29, 0, 7, 1, 0, 5, 19, 41, NULL, 'Momentinis srovės stiprumas, fiksuojamas kas 30 sekundžių', 77, 7, NULL, NULL),
	(4565, 30, 0, 7, 1, 0, 6, 2, 42, NULL, 'Momentinė įtampa, fiksuojama kas 2 minutes', 78, 1, NULL, NULL),
	(4566, 30, 0, 7, 1, 0, 6, 15, 42, NULL, 'Momentinė įtampa, fiksuojama kas 5 sekundes', 78, 7, NULL, NULL),
	(4567, 30, 0, 7, 1, 0, 6, 19, 42, NULL, 'Momentinė įtampa, fiksuojama kas 30 sekundžių', 78, 7, NULL, NULL),
	(4568, 31, 0, 7, 1, 0, 6, 2, 43, NULL, 'Momentinė linijinė įtampa, fiksuojama kas 2 minutes', 79, 1, NULL, NULL),
	(4569, 31, 0, 7, 1, 0, 6, 15, 43, NULL, 'Momentinė linijinė įtampa, fiksuojama kas 5 sekundes', 79, 7, NULL, NULL),
	(4570, 31, 0, 7, 1, 0, 6, 19, 43, NULL, 'Momentinė linijinė įtampa, fiksuojama kas 30 sekundžių', 79, 7, NULL, NULL),
	(4571, 1, 0, 7, 1, 0, 1, 2, 13, NULL, 'Momentinė aktyvinė galia, fiksuojama kas 2 minutes', 80, 1, NULL, NULL),
	(4572, 1, 0, 7, 1, 0, 1, 15, 13, NULL, 'Momentinė aktyvinė galia, fiksuojama kas 5 sekundes', 80, 7, NULL, NULL),
	(4573, 1, 0, 7, 1, 0, 1, 19, 13, NULL, 'Momentinė aktyvinė galia, fiksuojama kas 30 sekundžių', 80, 7, NULL, NULL),
	(4574, 3, 0, 7, 1, 0, 3, 15, 16, NULL, 'Momentinė reaktyvinė galia, fiksuojama kas 5 sekundes', 81, 7, NULL, NULL),
	(4575, 3, 0, 7, 1, 0, 3, 2, 16, NULL, 'Momentinė reaktyvinė galia, fiksuojama kas 2 minutes', 81, 1, NULL, NULL),
	(4576, 3, 0, 7, 1, 0, 3, 19, 16, NULL, 'Momentinė reaktyvinė galia, fiksuojama kas 30 sekundžių', 81, 7, NULL, NULL),
	(4577, 34, 0, 7, 1, 0, 7, 2, 44, NULL, 'Momentinė pilnoji galia, fiksuojama kas 2 minutes', 82, 1, NULL, NULL),
	(4578, 34, 0, 7, 1, 0, 7, 15, 44, NULL, 'Momentinė pilnoji galia, fiksuojama kas 5 sekundes', 82, 7, NULL, NULL),
	(4579, 34, 0, 7, 1, 0, 7, 19, 44, NULL, 'Momentinė pilnoji galia, fiksuojama kas 30 sekundžių', 82, 7, NULL, NULL),
	(4580, 35, 0, 7, 1, 0, 0, 15, 46, NULL, 'Momentinė cos(fi) reikšmė, fiksuojama kas 5 sekundes', 83, 7, NULL, NULL),
	(4581, 35, 0, 7, 1, 0, 0, 2, 46, NULL, 'Momentinė cos(fi) reikšmė, fiksuojama kas 2 minutes', 83, 1, NULL, NULL),
	(4582, 35, 0, 7, 1, 0, 0, 19, 46, NULL, 'Momentinė cos(fi) reikšmė, fiksuojama kas 30 sekundžių', 83, 7, NULL, NULL),
	(4583, 36, 0, 7, 1, 0, 0, 2, 47, NULL, 'Momentinis kvadrantas, fiksuojamas kas 2 minutes', 84, 1, NULL, NULL),
	(4584, 36, 0, 7, 1, 0, 0, 15, 47, NULL, 'Momentinis kvadrantas, fiksuojamas kas 5 sekundes', 84, 7, NULL, NULL),
	(4585, 36, 0, 7, 1, 0, 0, 19, 47, NULL, 'Momentinis kvadrantas, fiksuojamas kas 30 sekundžių', 84, 7, NULL, NULL),
	(4586, 37, 0, 7, 1, 0, 8, 2, 48, NULL, 'Momentinis dažnis, fiksuojamas kas 2 minutes', 85, 1, NULL, NULL),
	(4587, 37, 0, 7, 1, 0, 8, 15, 48, NULL, 'Momentinis dažnis, fiksuojamas kas 5 sekundes', 85, 7, NULL, NULL),
	(4588, 37, 0, 7, 1, 0, 8, 19, 48, NULL, 'Momentinis dažnis, fiksuojamas kas 30 sekundžių', 85, 7, NULL, NULL),
	(4589, 38, 0, 7, 1, 0, 0, 2, 49, NULL, 'Momentinė fazių seka, fiksuojama kas 2 minutes', 86, 1, NULL, NULL),
	(4590, 38, 0, 7, 1, 0, 0, 15, 49, NULL, 'Momentinė fazių seka, fiksuojama kas 5 sekundes', 86, 7, NULL, NULL),
	(4591, 38, 0, 7, 1, 0, 0, 19, 49, NULL, 'Momentinė fazių seka, fiksuojama kas 30 sekundžių', 86, 7, NULL, NULL),
	(4592, 1, 1, 9, 4, 0, 1, 4, 13, NULL, 'Maksimali 3 minučių P+ galia per valandą', 394, 2, NULL, NULL),
	(4593, 1, 1, 9, 5, 0, 1, 4, 13, NULL, 'Minimali 3 minučių P+ galia per valandą', NULL, 2, NULL, NULL),
	(4594, 1, 2, 9, 4, 0, 1, 4, 13, NULL, 'Maksimali 3 minučių P- galia per valandą', 395, 2, NULL, NULL),
	(4595, 1, 2, 9, 5, 0, 1, 4, 13, NULL, 'Minimali 3 minučių P- galia per valandą', NULL, 2, NULL, NULL),
	(4596, 3, 1, 9, 4, 0, 3, 4, 16, NULL, 'Maksimali 3 minučių Q+ galia per valandą', 396, 2, NULL, NULL),
	(4597, 3, 1, 9, 5, 0, 3, 4, 16, NULL, 'Minimali 3 minučių Q+ galia per valandą', NULL, 2, NULL, NULL),
	(4598, 3, 2, 9, 4, 0, 3, 4, 16, NULL, 'Maksimali 3 minučių Q- galia per valandą', 397, 2, NULL, NULL),
	(4599, 3, 2, 9, 5, 0, 3, 4, 16, NULL, 'Minimali 3 minučių Q- galia per valandą', NULL, 2, NULL, NULL),
	(4600, 1, 1, 9, 4, 1, 1, 4, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 1 tarifą per valandą', 378, 2, NULL, NULL),
	(4601, 1, 2, 9, 4, 1, 1, 4, 13, NULL, 'Maksimali 3 minučių P- galia pagal 1 tarifą per valandą', 379, 2, NULL, NULL),
	(4602, 3, 1, 9, 4, 1, 3, 4, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 1 tarifą per valandą', 380, 2, NULL, NULL),
	(4603, 3, 2, 9, 4, 1, 3, 4, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 1 tarifą per valandą', 381, 2, NULL, NULL),
	(4604, 1, 1, 9, 4, 2, 1, 4, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 2 tarifą per valandą', 382, 2, NULL, NULL),
	(4605, 1, 2, 9, 4, 2, 1, 4, 13, NULL, 'Maksimali 3 minučių P- galia pagal 2 tarifą per valandą', 383, 2, NULL, NULL),
	(4606, 3, 1, 9, 4, 2, 3, 4, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 2 tarifą per valandą', 384, 2, NULL, NULL),
	(4607, 3, 2, 9, 4, 2, 3, 4, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 2 tarifą per valandą', 385, 2, NULL, NULL),
	(4608, 1, 1, 9, 4, 3, 1, 4, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 3 tarifą per valandą', 386, 2, NULL, NULL),
	(4609, 1, 2, 9, 4, 3, 1, 4, 13, NULL, 'Maksimali 3 minučių P- galia pagal 3 tarifą per valandą', 387, 2, NULL, NULL),
	(4610, 3, 1, 9, 4, 3, 3, 4, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 3 tarifą per valandą', 388, 2, NULL, NULL),
	(4611, 3, 2, 9, 4, 3, 3, 4, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 3 tarifą per valandą', 389, 2, NULL, NULL),
	(4612, 1, 1, 9, 4, 4, 1, 4, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 4 tarifą per valandą', 390, 2, NULL, NULL),
	(4613, 1, 2, 9, 4, 4, 1, 4, 13, NULL, 'Maksimali 3 minučių P- galia pagal 4 tarifą per valandą', 391, 2, NULL, NULL),
	(4614, 3, 1, 9, 4, 4, 3, 4, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 4 tarifą per valandą', 392, 2, NULL, NULL),
	(4615, 3, 2, 9, 4, 4, 3, 4, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 4 tarifą per valandą', 393, 2, NULL, NULL),
	(4616, 3, 5, 9, 4, 1, 3, 4, 16, NULL, 'Maksimali 3 minučių Q1 galia pagal 1 tarifą per valandą', 422, 2, NULL, NULL),
	(4617, 3, 6, 9, 4, 1, 3, 4, 16, NULL, 'Maksimali 3 minučių Q2 galia pagal 1 tarifą per valandą', 423, 2, NULL, NULL),
	(4618, 3, 7, 9, 4, 1, 3, 4, 16, NULL, 'Maksimali 3 minučių Q3 galia pagal 1 tarifą per valandą', 424, 2, NULL, NULL),
	(4619, 3, 8, 9, 4, 1, 3, 4, 16, NULL, 'Maksimali 3 minučių Q4 galia pagal 1 tarifą per valandą', 425, 2, NULL, NULL),
	(4620, 34, 1, 9, 4, 1, 7, 4, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 1 tarifą per valandą', 426, 2, NULL, NULL),
	(4621, 34, 2, 9, 4, 1, 7, 4, 44, NULL, 'Maksimali 3 minučių S- galia pagal 1 tarifą per valandą', 427, 2, NULL, NULL),
	(4622, 3, 5, 9, 4, 2, 3, 4, 16, NULL, 'Maksimali 3 minučių Q1 galia pagal 2 tarifą per valandą', 428, 2, NULL, NULL),
	(4623, 3, 6, 9, 4, 2, 3, 4, 16, NULL, 'Maksimali 3 minučių Q2 galia pagal 2 tarifą per valandą', 429, 2, NULL, NULL),
	(4624, 3, 7, 9, 4, 2, 3, 4, 16, NULL, 'Maksimali 3 minučių Q3 galia pagal 2 tarifą per valandą', 430, 2, NULL, NULL),
	(4625, 3, 8, 9, 4, 2, 3, 4, 16, NULL, 'Maksimali 3 minučių Q4 galia pagal 2 tarifą per valandą', 431, 2, NULL, NULL),
	(4626, 34, 1, 9, 4, 2, 7, 4, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 2 tarifą per valandą', 432, 2, NULL, NULL),
	(4627, 34, 2, 9, 4, 2, 7, 4, 44, NULL, 'Maksimali 3 minučių S- galia pagal 2 tarifą per valandą', 433, 2, NULL, NULL),
	(4628, 3, 5, 9, 4, 3, 3, 4, 16, NULL, 'Maksimali 3 minučių Q1 galia pagal 3 tarifą per valandą', 434, 2, NULL, NULL),
	(4629, 3, 6, 9, 4, 3, 3, 4, 16, NULL, 'Maksimali 3 minučių Q2 galia pagal 3 tarifą per valandą', 435, 2, NULL, NULL),
	(4630, 3, 7, 9, 4, 3, 3, 4, 16, NULL, 'Maksimali 3 minučių Q3 galia pagal 3 tarifą per valandą', 436, 2, NULL, NULL),
	(4631, 3, 8, 9, 4, 3, 3, 4, 16, NULL, 'Maksimali 3 minučių Q4 galia pagal 3 tarifą per valandą', 437, 2, NULL, NULL),
	(4632, 34, 1, 9, 4, 3, 7, 4, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 3 tarifą per valandą', 438, 2, NULL, NULL),
	(4633, 34, 2, 9, 4, 3, 7, 4, 44, NULL, 'Maksimali 3 minučių S- galia pagal 3 tarifą per valandą', 439, 2, NULL, NULL),
	(4634, 3, 5, 9, 4, 4, 3, 4, 16, NULL, 'Maksimali 3 minučių Q1 galia pagal 4 tarifą per valandą', 440, 2, NULL, NULL),
	(4635, 3, 6, 9, 4, 4, 3, 4, 16, NULL, 'Maksimali 3 minučių Q2 galia pagal 4 tarifą per valandą', 441, 2, NULL, NULL),
	(4636, 3, 7, 9, 4, 4, 3, 4, 16, NULL, 'Maksimali 3 minučių Q3 galia pagal 4 tarifą per valandą', 442, 2, NULL, NULL),
	(4637, 3, 8, 9, 4, 4, 3, 4, 16, NULL, 'Maksimali 3 minučių Q4 galia pagal 4 tarifą per valandą', 443, 2, NULL, NULL),
	(4638, 34, 1, 9, 4, 4, 7, 4, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 4 tarifą per valandą', 444, 2, NULL, NULL),
	(4639, 34, 2, 9, 4, 4, 7, 4, 44, NULL, 'Maksimali 3 minučių S- galia pagal 4 tarifą per valandą', 445, 2, NULL, NULL),
	(4640, 3, 0, 1, 4, 0, 3, 4, 16, NULL, 'Maksimali 1 minutės Q galia per valandą', NULL, 2, NULL, NULL),
	(4641, 3, 0, 1, 5, 0, 3, 4, 16, NULL, 'Minimali 1 minutės Q galia per valandą', NULL, 2, NULL, NULL),
	(4642, 1, 0, 1, 4, 0, 1, 4, 13, NULL, 'Maksimali 1 minutės P galia per valandą', NULL, 2, NULL, NULL),
	(4643, 1, 0, 1, 5, 0, 1, 4, 13, NULL, 'Minimali 1 minutės P galia per valandą', NULL, 2, NULL, NULL),
	(4644, 34, 0, 1, 4, 0, 7, 4, 44, NULL, 'Maksimali 1 minutės S galia per valandą', NULL, 2, NULL, NULL),
	(4645, 34, 0, 1, 5, 0, 7, 4, 44, NULL, 'Minimali 1 minutės S galia per valandą', NULL, 2, NULL, NULL),
	(4646, 1, 0, 2, 4, 0, 1, 4, 13, NULL, 'Maksimali 2 minučių P galia per valandą', NULL, 2, NULL, NULL),
	(4647, 1, 0, 2, 5, 0, 1, 4, 13, NULL, 'Minimali 2 minučių P galia per valandą', NULL, 2, NULL, NULL),
	(4648, 3, 0, 2, 4, 0, 3, 4, 16, NULL, 'Maksimali 2 minučių Q galia per valandą', NULL, 2, NULL, NULL),
	(4649, 3, 0, 2, 5, 0, 3, 4, 16, NULL, 'Minimali 2 minučių Q galia per valandą', NULL, 2, NULL, NULL),
	(4650, 34, 0, 2, 4, 0, 7, 4, 44, NULL, 'Maksimali 2 minučių S galia per valandą', NULL, 2, NULL, NULL),
	(4651, 34, 0, 2, 5, 0, 7, 4, 44, NULL, 'Minimali 2 minučių S galia per valandą', NULL, 2, NULL, NULL),
	(4652, 1, 0, 9, 4, 0, 1, 4, 13, NULL, 'Maksimali 3 minučių P galia per valandą', NULL, 2, NULL, NULL),
	(4653, 1, 0, 9, 5, 0, 1, 4, 13, NULL, 'Minimali 3 minučių P galia per valandą', NULL, 2, NULL, NULL),
	(4654, 1, 0, 9, 4, 1, 1, 4, 13, NULL, 'Maksimali 3 minučių P galia pagal 1 tarifą per valandą', NULL, 2, NULL, NULL),
	(4655, 1, 0, 9, 4, 2, 1, 4, 13, NULL, 'Maksimali 3 minučių P galia pagal 2 tarifą per valandą', NULL, 2, NULL, NULL),
	(4656, 1, 0, 9, 4, 3, 1, 4, 13, NULL, 'Maksimali 3 minučių P galia pagal 3 tarifą per valandą', NULL, 2, NULL, NULL),
	(4657, 1, 0, 9, 4, 4, 1, 4, 13, NULL, 'Maksimali 3 minučių P galia pagal 4 tarifą per valandą', NULL, 2, NULL, NULL),
	(4658, 3, 0, 9, 4, 0, 3, 4, 16, NULL, 'Maksimali 3 minučių Q galia per valandą', NULL, 2, NULL, NULL),
	(4659, 3, 0, 9, 5, 0, 3, 4, 16, NULL, 'Minimali 3 minučių Q galia per valandą', NULL, 2, NULL, NULL),
	(4660, 3, 0, 9, 4, 1, 3, 4, 16, NULL, 'Maksimali 3 minučių Q galia pagal 1 tarifą per valandą', NULL, 2, NULL, NULL),
	(4661, 3, 0, 9, 4, 2, 3, 4, 16, NULL, 'Maksimali 3 minučių Q galia pagal 2 tarifą per valandą', NULL, 2, NULL, NULL),
	(4662, 3, 0, 9, 4, 3, 3, 4, 16, NULL, 'Maksimali 3 minučių Q galia pagal 3 tarifą per valandą', NULL, 2, NULL, NULL),
	(4663, 3, 0, 9, 4, 4, 3, 4, 16, NULL, 'Maksimali 3 minučių Q galia pagal 4 tarifą per valandą', NULL, 2, NULL, NULL),
	(4664, 34, 0, 9, 4, 0, 7, 4, 44, NULL, 'Maksimali 3 minučių S galia per valandą', NULL, 2, NULL, NULL),
	(4665, 34, 0, 9, 5, 0, 7, 4, 44, NULL, 'Minimali 3 minučių S galia per valandą', NULL, 2, NULL, NULL),
	(4666, 34, 0, 9, 4, 1, 7, 4, 44, NULL, 'Maksimali 3 minučių S galia pagal 1 tarifą per valandą', NULL, 2, NULL, NULL),
	(4667, 34, 0, 9, 4, 2, 7, 4, 44, NULL, 'Maksimali 3 minučių S galia pagal 2 tarifą per valandą', NULL, 2, NULL, NULL),
	(4668, 34, 0, 9, 4, 3, 7, 4, 44, NULL, 'Maksimali 3 minučių S galia pagal 3 tarifą per valandą', NULL, 2, NULL, NULL),
	(4669, 34, 0, 9, 4, 4, 7, 4, 44, NULL, 'Maksimali 3 minučių S galia pagal 4 tarifą per valandą', NULL, 2, NULL, NULL),
	(4670, 1, 0, 12, 4, 0, 1, 4, 13, NULL, 'Maksimali 10 minučių P galia per valandą', NULL, 2, NULL, NULL),
	(4671, 1, 0, 12, 5, 0, 1, 4, 13, NULL, 'Minimali 10 minučių P galia per valandą', NULL, 2, NULL, NULL),
	(4672, 3, 0, 12, 4, 0, 3, 4, 16, NULL, 'Maksimali 10 minučių Q galia per valandą', NULL, 2, NULL, NULL),
	(4673, 3, 0, 12, 5, 0, 3, 4, 16, NULL, 'Minimali 10 minučių Q galia per valandą', NULL, 2, NULL, NULL),
	(4674, 34, 0, 12, 4, 0, 7, 4, 44, NULL, 'Maksimali 10 minučių S galia per valandą', NULL, 2, NULL, NULL),
	(4675, 34, 0, 12, 5, 0, 7, 4, 44, NULL, 'Minimali 10 minučių S galia per valandą', NULL, 2, NULL, NULL),
	(4676, 1, 0, 11, 4, 0, 1, 4, 13, NULL, 'Maksimali 5 minučių P galia per valandą', NULL, 2, NULL, NULL),
	(4677, 1, 0, 11, 5, 0, 1, 4, 13, NULL, 'Minimali 5 minučių P galia per valandą', NULL, 2, NULL, NULL),
	(4678, 3, 0, 11, 4, 0, 3, 4, 16, NULL, 'Maksimali 5 minučių Q galia per valandą', NULL, 2, NULL, NULL),
	(4679, 3, 0, 11, 5, 0, 3, 4, 16, NULL, 'Minimali 5 minučių Q galia per valandą', NULL, 2, NULL, NULL),
	(4680, 34, 0, 11, 4, 0, 7, 4, 44, NULL, 'Maksimali 5 minučių S galia per valandą', NULL, 2, NULL, NULL),
	(4681, 34, 0, 11, 5, 0, 7, 4, 44, NULL, 'Minimali 5 minučių S galia per valandą', NULL, 2, NULL, NULL),
	(4682, 1, 0, 10, 4, 0, 1, 4, 13, NULL, 'Maksimali 4 minučių P galia per valandą', NULL, 2, NULL, NULL),
	(4683, 1, 0, 10, 5, 0, 1, 4, 13, NULL, 'Minimali 4 minučių P galia per valandą', NULL, 2, NULL, NULL),
	(4684, 3, 0, 10, 4, 0, 3, 4, 16, NULL, 'Maksimali 4 minučių Q galia per valandą', NULL, 2, NULL, NULL),
	(4685, 3, 0, 10, 5, 0, 3, 4, 16, NULL, 'Minimali 4 minučių Q galia per valandą', NULL, 2, NULL, NULL),
	(4686, 34, 0, 10, 4, 0, 7, 4, 44, NULL, 'Maksimali 4 minučių S galia per valandą', NULL, 2, NULL, NULL),
	(4687, 34, 0, 10, 5, 0, 7, 4, 44, NULL, 'Minimali 4 minučių S galia per valandą', NULL, 2, NULL, NULL),
	(4688, 5, 0, 7, 4, 0, 5, 4, 17, NULL, 'Maksimalus momentinis srovės stiprumas L1 fazėje per valandą', 454, 2, NULL, NULL),
	(4689, 5, 0, 7, 5, 0, 5, 4, 17, NULL, 'Minimalus momentinis srovės stiprumas L1 fazėje per valandą', 501, 2, NULL, NULL),
	(4690, 5, 0, 7, 4, 0, 5, 5, 17, NULL, 'Maksimalus momentinis srovės stiprumas L1 fazėje per parą', 454, 3, NULL, NULL),
	(4691, 5, 0, 7, 5, 0, 5, 5, 17, NULL, 'Minimalus momentinis srovės stiprumas L1 fazėje per parą', 501, 3, NULL, NULL),
	(4692, 5, 0, 7, 4, 0, 5, 6, 17, NULL, 'Maksimalus momentinis srovės stiprumas L1 fazėje per mėnesį', 454, 4, NULL, NULL),
	(4693, 5, 0, 7, 5, 0, 5, 6, 17, NULL, 'Minimalus momentinis srovės stiprumas L1 fazėje per mėnesį', 501, 4, NULL, NULL),
	(4694, 6, 0, 7, 4, 0, 6, 4, 18, NULL, 'Maksimali momentinė įtampa L1 fazėje per valandą', 455, 2, NULL, NULL),
	(4695, 6, 0, 7, 5, 0, 6, 4, 18, NULL, 'Minimali momentinė įtampa L1 fazėje per valandą', 502, 2, NULL, NULL),
	(4696, 6, 0, 7, 4, 0, 6, 5, 18, NULL, 'Maksimali momentinė įtampa L1 fazėje per parą', 455, 3, NULL, NULL),
	(4697, 6, 0, 7, 5, 0, 6, 5, 18, NULL, 'Minimali momentinė įtampa L1 fazėje per parą', 502, 3, NULL, NULL),
	(4698, 6, 0, 7, 4, 0, 6, 6, 18, NULL, 'Maksimali momentinė įtampa L1 fazėje per mėnesį', 455, 4, NULL, NULL),
	(4699, 6, 0, 7, 5, 0, 6, 6, 18, NULL, 'Minimali momentinė įtampa L1 fazėje per mėnesį', 502, 4, NULL, NULL),
	(4700, 7, 0, 7, 4, 0, 5, 4, 19, NULL, 'Maksimalus momentinis srovės stiprumas L2 fazėje per valandą', 456, 2, NULL, NULL),
	(4701, 7, 0, 7, 5, 0, 5, 4, 19, NULL, 'Minimalus momentinis srovės stiprumas L2 fazėje per valandą', 503, 2, NULL, NULL),
	(4702, 7, 0, 7, 4, 0, 5, 5, 19, NULL, 'Maksimalus momentinis srovės stiprumas L2 fazėje per parą', 456, 3, NULL, NULL),
	(4703, 7, 0, 7, 5, 0, 5, 5, 19, NULL, 'Minimalus momentinis srovės stiprumas L2 fazėje per parą', 503, 3, NULL, NULL),
	(4704, 7, 0, 7, 4, 0, 5, 6, 19, NULL, 'Maksimalus momentinis srovės stiprumas L2 fazėje per mėnesį', 456, 4, NULL, NULL),
	(4705, 7, 0, 7, 5, 0, 5, 6, 19, NULL, 'Minimalus momentinis srovės stiprumas L2 fazėje per mėnesį', 503, 4, NULL, NULL),
	(4706, 8, 0, 7, 4, 0, 6, 4, 20, NULL, 'Maksimali momentinė įtampa L2 fazėje per valandą', 457, 2, NULL, NULL),
	(4707, 8, 0, 7, 5, 0, 6, 4, 20, NULL, 'Minimali momentinė įtampa L2 fazėje per valandą', 504, 2, NULL, NULL),
	(4708, 8, 0, 7, 4, 0, 6, 5, 20, NULL, 'Maksimali momentinė įtampa L2 fazėje per parą', 457, 3, NULL, NULL),
	(4709, 8, 0, 7, 5, 0, 6, 5, 20, NULL, 'Minimali momentinė įtampa L2 fazėje per parą', 504, 3, NULL, NULL),
	(4710, 8, 0, 7, 4, 0, 6, 6, 20, NULL, 'Maksimali momentinė įtampa L2 fazėje per mėnesį', 457, 4, NULL, NULL),
	(4711, 8, 0, 7, 5, 0, 6, 6, 20, NULL, 'Minimali momentinė įtampa L2 fazėje per mėnesį', 504, 4, NULL, NULL),
	(4712, 9, 0, 7, 4, 0, 5, 4, 21, NULL, 'Maksimalus momentinis srovės stiprumas L3 fazėje per valandą', 458, 2, NULL, NULL),
	(4713, 9, 0, 7, 5, 0, 5, 4, 21, NULL, 'Minimalus momentinis srovės stiprumas L3 fazėje per valandą', 505, 2, NULL, NULL),
	(4714, 9, 0, 7, 4, 0, 5, 5, 21, NULL, 'Maksimalus momentinis srovės stiprumas L3 fazėje per parą', 458, 3, NULL, NULL),
	(4715, 9, 0, 7, 5, 0, 5, 5, 21, NULL, 'Minimalus momentinis srovės stiprumas L3 fazėje per parą', 505, 3, NULL, NULL),
	(4716, 9, 0, 7, 4, 0, 5, 6, 21, NULL, 'Maksimalus momentinis srovės stiprumas L3 fazėje per mėnesį', 458, 4, NULL, NULL),
	(4717, 9, 0, 7, 5, 0, 5, 6, 21, NULL, 'Minimalus momentinis srovės stiprumas L3 fazėje per mėnesį', 505, 4, NULL, NULL),
	(4718, 10, 0, 7, 4, 0, 6, 4, 22, NULL, 'Maksimali momentinė įtampa L3 fazėje per valandą', 459, 2, NULL, NULL),
	(4719, 10, 0, 7, 5, 0, 6, 4, 22, NULL, 'Minimali momentinė įtampa L3 fazėje per valandą', 506, 2, NULL, NULL),
	(4720, 10, 0, 7, 4, 0, 6, 5, 22, NULL, 'Maksimali momentinė įtampa L3 fazėje per parą', 459, 3, NULL, NULL),
	(4721, 10, 0, 7, 5, 0, 6, 5, 22, NULL, 'Minimali momentinė įtampa L3 fazėje per parą', 506, 3, NULL, NULL),
	(4722, 10, 0, 7, 4, 0, 6, 6, 22, NULL, 'Maksimali momentinė įtampa L3 fazėje per mėnesį', 459, 4, NULL, NULL),
	(4723, 10, 0, 7, 5, 0, 6, 6, 22, NULL, 'Minimali momentinė įtampa L3 fazėje per mėnesį', 506, 4, NULL, NULL),
	(4724, 11, 0, 7, 4, 0, 6, 4, 23, NULL, 'Maksimali momentinė linijinė įtampa L1 fazėje per valandą', NULL, 2, NULL, NULL),
	(4725, 11, 0, 7, 5, 0, 6, 4, 23, NULL, 'Minimali momentinė linijinė įtampa L1 fazėje per valandą', NULL, 2, NULL, NULL),
	(4726, 11, 0, 7, 4, 0, 6, 5, 23, NULL, 'Maksimali momentinė linijinė įtampa L1 fazėje per parą', NULL, 3, NULL, NULL),
	(4727, 11, 0, 7, 5, 0, 6, 5, 23, NULL, 'Minimali momentinė linijinė įtampa L1 fazėje per parą', NULL, 3, NULL, NULL),
	(4728, 11, 0, 7, 4, 0, 6, 6, 23, NULL, 'Maksimali momentinė linijinė įtampa L1 fazėje per mėnesį', NULL, 4, NULL, NULL),
	(4729, 11, 0, 7, 5, 0, 6, 6, 23, NULL, 'Minimali momentinė linijinė įtampa L1 fazėje per mėnesį', NULL, 4, NULL, NULL),
	(4730, 12, 0, 7, 4, 0, 6, 4, 24, NULL, 'Maksimali momentinė linijinė įtampa L2 fazėje per valandą', NULL, 2, NULL, NULL),
	(4731, 12, 0, 7, 5, 0, 6, 4, 24, NULL, 'Minimali momentinė linijinė įtampa L2 fazėje per valandą', NULL, 2, NULL, NULL),
	(4732, 12, 0, 7, 4, 0, 6, 5, 24, NULL, 'Maksimali momentinė linijinė įtampa L2 fazėje per parą', NULL, 3, NULL, NULL),
	(4733, 12, 0, 7, 5, 0, 6, 5, 24, NULL, 'Minimali momentinė linijinė įtampa L2 fazėje per parą', NULL, 3, NULL, NULL),
	(4734, 12, 0, 7, 4, 0, 6, 6, 24, NULL, 'Maksimali momentinė linijinė įtampa L2 fazėje per mėnesį', NULL, 4, NULL, NULL),
	(4735, 12, 0, 7, 5, 0, 6, 6, 24, NULL, 'Minimali momentinė linijinė įtampa L2 fazėje per mėnesį', NULL, 4, NULL, NULL),
	(4736, 13, 0, 7, 4, 0, 6, 4, 25, NULL, 'Maksimali momentinė linijinė įtampa L3 fazėje per valandą', NULL, 2, NULL, NULL),
	(4737, 13, 0, 7, 5, 0, 6, 4, 25, NULL, 'Minimali momentinė linijinė įtampa L3 fazėje per valandą', NULL, 2, NULL, NULL),
	(4738, 13, 0, 7, 4, 0, 6, 5, 25, NULL, 'Maksimali momentinė linijinė įtampa L3 fazėje per parą', NULL, 3, NULL, NULL),
	(4739, 13, 0, 7, 5, 0, 6, 5, 25, NULL, 'Minimali momentinė linijinė įtampa L3 fazėje per parą', NULL, 3, NULL, NULL),
	(4740, 13, 0, 7, 4, 0, 6, 6, 25, NULL, 'Maksimali momentinė linijinė įtampa L3 fazėje per mėnesį', NULL, 4, NULL, NULL),
	(4741, 13, 0, 7, 5, 0, 6, 6, 25, NULL, 'Minimali momentinė linijinė įtampa L3 fazėje per mėnesį', NULL, 4, NULL, NULL),
	(4742, 14, 0, 7, 4, 0, 1, 4, 26, NULL, 'Maksimali momentinė aktyvinė galia L1 fazėje per valandą', 463, 2, NULL, NULL),
	(4743, 14, 0, 7, 5, 0, 1, 4, 26, NULL, 'Minimali momentinė aktyvinė galia L1 fazėje per valandą', 510, 2, NULL, NULL),
	(4744, 14, 0, 7, 4, 0, 1, 5, 26, NULL, 'Maksimali momentinė aktyvinė galia L1 fazėje per parą', 463, 3, NULL, NULL),
	(4745, 14, 0, 7, 5, 0, 1, 5, 26, NULL, 'Minimali momentinė aktyvinė galia L1 fazėje per parą', 510, 3, NULL, NULL),
	(4746, 14, 0, 7, 4, 0, 1, 6, 26, NULL, 'Maksimali momentinė aktyvinė galia L1 fazėje per mėnesį', 463, 4, NULL, NULL),
	(4747, 14, 0, 7, 5, 0, 1, 6, 26, NULL, 'Minimali momentinė aktyvinė galia L1 fazėje per mėnesį', 510, 4, NULL, NULL),
	(4748, 15, 0, 7, 4, 0, 1, 4, 27, NULL, 'Maksimali momentinė aktyvinė galia L2 fazėje per valandą', 464, 2, NULL, NULL),
	(4749, 15, 0, 7, 5, 0, 1, 4, 27, NULL, 'Minimali momentinė aktyvinė galia L2 fazėje per valandą', 511, 2, NULL, NULL),
	(4750, 15, 0, 7, 4, 0, 1, 5, 27, NULL, 'Maksimali momentinė aktyvinė galia L2 fazėje per parą', 464, 3, NULL, NULL),
	(4751, 15, 0, 7, 5, 0, 1, 5, 27, NULL, 'Minimali momentinė aktyvinė galia L2 fazėje per parą', 511, 3, NULL, NULL),
	(4752, 15, 0, 7, 4, 0, 1, 6, 27, NULL, 'Maksimali momentinė aktyvinė galia L2 fazėje per mėnesį', 464, 4, NULL, NULL),
	(4753, 15, 0, 7, 5, 0, 1, 6, 27, NULL, 'Minimali momentinė aktyvinė galia L2 fazėje per mėnesį', 511, 4, NULL, NULL),
	(4754, 16, 0, 7, 4, 0, 1, 4, 28, NULL, 'Maksimali momentinė aktyvinė galia L3 fazėje per valandą', 465, 2, NULL, NULL),
	(4755, 16, 0, 7, 5, 0, 1, 4, 28, NULL, 'Minimali momentinė aktyvinė galia L3 fazėje per valandą', 512, 2, NULL, NULL),
	(4756, 16, 0, 7, 4, 0, 1, 5, 28, NULL, 'Maksimali momentinė aktyvinė galia L3 fazėje per parą', 465, 3, NULL, NULL),
	(4757, 16, 0, 7, 5, 0, 1, 5, 28, NULL, 'Minimali momentinė aktyvinė galia L3 fazėje per parą', 512, 3, NULL, NULL),
	(4758, 16, 0, 7, 4, 0, 1, 6, 28, NULL, 'Maksimali momentinė aktyvinė galia L3 fazėje per mėnesį', 465, 4, NULL, NULL),
	(4759, 16, 0, 7, 5, 0, 1, 6, 28, NULL, 'Minimali momentinė aktyvinė galia L3 fazėje per mėnesį', 512, 4, NULL, NULL),
	(4760, 17, 0, 7, 4, 0, 3, 4, 29, NULL, 'Maksimali momentinė reaktyvinė galia L1 fazėje per valandą', 466, 2, NULL, NULL),
	(4761, 17, 0, 7, 5, 0, 3, 4, 29, NULL, 'Minimali momentinė reaktyvinė galia L1 fazėje per valandą', 513, 2, NULL, NULL),
	(4762, 17, 0, 7, 4, 0, 3, 5, 29, NULL, 'Maksimali momentinė reaktyvinė galia L1 fazėje per parą', 466, 3, NULL, NULL),
	(4763, 17, 0, 7, 5, 0, 3, 5, 29, NULL, 'Minimali momentinė reaktyvinė galia L1 fazėje per parą', 513, 3, NULL, NULL),
	(4764, 17, 0, 7, 4, 0, 3, 6, 29, NULL, 'Maksimali momentinė reaktyvinė galia L1 fazėje per mėnesį', 466, 4, NULL, NULL),
	(4765, 17, 0, 7, 5, 0, 3, 6, 29, NULL, 'Minimali momentinė reaktyvinė galia L1 fazėje per mėnesį', 513, 4, NULL, NULL),
	(4766, 18, 0, 7, 4, 0, 3, 4, 30, NULL, 'Maksimali momentinė reaktyvinė galia L2 fazėje per valandą', 467, 2, NULL, NULL),
	(4767, 18, 0, 7, 5, 0, 3, 4, 30, NULL, 'Minimali momentinė reaktyvinė galia L2 fazėje per valandą', 514, 2, NULL, NULL),
	(4768, 18, 0, 7, 4, 0, 3, 5, 30, NULL, 'Maksimali momentinė reaktyvinė galia L2 fazėje per parą', 467, 3, NULL, NULL),
	(4769, 18, 0, 7, 5, 0, 3, 5, 30, NULL, 'Minimali momentinė reaktyvinė galia L2 fazėje per parą', 514, 3, NULL, NULL),
	(4770, 18, 0, 7, 4, 0, 3, 6, 30, NULL, 'Maksimali momentinė reaktyvinė galia L2 fazėje per mėnesį', 467, 4, NULL, NULL),
	(4771, 18, 0, 7, 5, 0, 3, 6, 30, NULL, 'Minimali momentinė reaktyvinė galia L2 fazėje per mėnesį', 514, 4, NULL, NULL),
	(4772, 19, 0, 7, 4, 0, 3, 4, 31, NULL, 'Maksimali momentinė reaktyvinė galia L3 fazėje per valandą', 468, 2, NULL, NULL),
	(4773, 19, 0, 7, 5, 0, 3, 4, 31, NULL, 'Minimali momentinė reaktyvinė galia L3 fazėje per valandą', 515, 2, NULL, NULL),
	(4774, 19, 0, 7, 4, 0, 3, 5, 31, NULL, 'Maksimali momentinė reaktyvinė galia L3 fazėje per parą', 468, 3, NULL, NULL),
	(4775, 19, 0, 7, 5, 0, 3, 5, 31, NULL, 'Minimali momentinė reaktyvinė galia L3 fazėje per parą', 515, 3, NULL, NULL),
	(4776, 19, 0, 7, 4, 0, 3, 6, 31, NULL, 'Maksimali momentinė reaktyvinė galia L3 fazėje per mėnesį', 468, 4, NULL, NULL),
	(4777, 19, 0, 7, 5, 0, 3, 6, 31, NULL, 'Minimali momentinė reaktyvinė galia L3 fazėje per mėnesį', 515, 4, NULL, NULL),
	(4778, 20, 0, 7, 4, 0, 7, 4, 32, NULL, 'Maksimali momentinė pilnoji galia L1 fazėje per valandą', 469, 2, NULL, NULL),
	(4779, 20, 0, 7, 5, 0, 7, 4, 32, NULL, 'Minimali momentinė pilnoji galia L1 fazėje per valandą', 516, 2, NULL, NULL),
	(4780, 20, 0, 7, 4, 0, 7, 5, 32, NULL, 'Maksimali momentinė pilnoji galia L1 fazėje per parą', 469, 3, NULL, NULL),
	(4781, 20, 0, 7, 5, 0, 7, 5, 32, NULL, 'Minimali momentinė pilnoji galia L1 fazėje per parą', 516, 3, NULL, NULL),
	(4782, 20, 0, 7, 4, 0, 7, 6, 32, NULL, 'Maksimali momentinė pilnoji galia L1 fazėje per mėnesį', 469, 4, NULL, NULL),
	(4783, 20, 0, 7, 5, 0, 7, 6, 32, NULL, 'Minimali momentinė pilnoji galia L1 fazėje per mėnesį', 516, 4, NULL, NULL),
	(4784, 21, 0, 7, 4, 0, 7, 4, 33, NULL, 'Maksimali momentinė pilnoji galia L2 fazėje per valandą', 470, 2, NULL, NULL),
	(4785, 21, 0, 7, 5, 0, 7, 4, 33, NULL, 'Minimali momentinė pilnoji galia L2 fazėje per valandą', 517, 2, NULL, NULL),
	(4786, 21, 0, 7, 4, 0, 7, 5, 33, NULL, 'Maksimali momentinė pilnoji galia L2 fazėje per parą', 470, 3, NULL, NULL),
	(4787, 21, 0, 7, 5, 0, 7, 5, 33, NULL, 'Minimali momentinė pilnoji galia L2 fazėje per parą', 517, 3, NULL, NULL),
	(4788, 21, 0, 7, 4, 0, 7, 6, 33, NULL, 'Maksimali momentinė pilnoji galia L2 fazėje per mėnesį', 470, 4, NULL, NULL),
	(4789, 21, 0, 7, 5, 0, 7, 6, 33, NULL, 'Minimali momentinė pilnoji galia L2 fazėje per mėnesį', 517, 4, NULL, NULL),
	(4790, 22, 0, 7, 4, 0, 7, 4, 34, NULL, 'Maksimali momentinė pilnoji galia L3 fazėje per valandą', 471, 2, NULL, NULL),
	(4791, 22, 0, 7, 5, 0, 7, 4, 34, NULL, 'Minimali momentinė pilnoji galia L3 fazėje per valandą', 518, 2, NULL, NULL),
	(4792, 22, 0, 7, 4, 0, 7, 5, 34, NULL, 'Maksimali momentinė pilnoji galia L3 fazėje per parą', 471, 3, NULL, NULL),
	(4793, 22, 0, 7, 5, 0, 7, 5, 34, NULL, 'Minimali momentinė pilnoji galia L3 fazėje per parą', 518, 3, NULL, NULL),
	(4794, 22, 0, 7, 4, 0, 7, 6, 34, NULL, 'Maksimali momentinė pilnoji galia L3 fazėje per mėnesį', 471, 4, NULL, NULL),
	(4795, 22, 0, 7, 5, 0, 7, 6, 34, NULL, 'Minimali momentinė pilnoji galia L3 fazėje per mėnesį', 518, 4, NULL, NULL),
	(4796, 23, 0, 7, 4, 0, 0, 4, 35, NULL, 'Maksimali momentinė cos(fi) reikšmė L1 fazėje per valandą', 472, 2, NULL, NULL),
	(4797, 23, 0, 7, 5, 0, 0, 4, 35, NULL, 'Minimali momentinė cos(fi) reikšmė L1 fazėje per valandą', 519, 2, NULL, NULL),
	(4798, 23, 0, 7, 4, 0, 0, 5, 35, NULL, 'Maksimali momentinė cos(fi) reikšmė L1 fazėje per parą', 472, 3, NULL, NULL),
	(4799, 23, 0, 7, 5, 0, 0, 5, 35, NULL, 'Minimali momentinė cos(fi) reikšmė L1 fazėje per parą', 519, 3, NULL, NULL),
	(4800, 23, 0, 7, 4, 0, 0, 6, 35, NULL, 'Maksimali momentinė cos(fi) reikšmė L1 fazėje per mėnesį', 472, 4, NULL, NULL),
	(4801, 23, 0, 7, 5, 0, 0, 6, 35, NULL, 'Minimali momentinė cos(fi) reikšmė L1 fazėje per mėnesį', 519, 4, NULL, NULL),
	(4802, 24, 0, 7, 4, 0, 0, 4, 36, NULL, 'Maksimali momentinė cos(fi) reikšmė L2 fazėje per valandą', 473, 2, NULL, NULL),
	(4803, 24, 0, 7, 5, 0, 0, 4, 36, NULL, 'Minimali momentinė cos(fi) reikšmė L2 fazėje per valandą', 520, 2, NULL, NULL),
	(4804, 24, 0, 7, 4, 0, 0, 5, 36, NULL, 'Maksimali momentinė cos(fi) reikšmė L2 fazėje per parą', 473, 3, NULL, NULL),
	(4805, 24, 0, 7, 5, 0, 0, 5, 36, NULL, 'Minimali momentinė cos(fi) reikšmė L2 fazėje per parą', 520, 3, NULL, NULL),
	(4806, 24, 0, 7, 4, 0, 0, 6, 36, NULL, 'Maksimali momentinė cos(fi) reikšmė L2 fazėje per mėnesį', 473, 4, NULL, NULL),
	(4807, 24, 0, 7, 5, 0, 0, 6, 36, NULL, 'Minimali momentinė cos(fi) reikšmė L2 fazėje per mėnesį', 520, 4, NULL, NULL),
	(4808, 25, 0, 7, 4, 0, 0, 4, 37, NULL, 'Maksimali momentinė cos(fi) reikšmė L3 fazėje per valandą', 474, 2, NULL, NULL),
	(4809, 25, 0, 7, 5, 0, 0, 4, 37, NULL, 'Minimali momentinė cos(fi) reikšmė L3 fazėje per valandą', 521, 2, NULL, NULL),
	(4810, 25, 0, 7, 4, 0, 0, 5, 37, NULL, 'Maksimali momentinė cos(fi) reikšmė L3 fazėje per parą', 474, 3, NULL, NULL),
	(4811, 25, 0, 7, 5, 0, 0, 5, 37, NULL, 'Minimali momentinė cos(fi) reikšmė L3 fazėje per parą', 521, 3, NULL, NULL),
	(4812, 25, 0, 7, 4, 0, 0, 6, 37, NULL, 'Maksimali momentinė cos(fi) reikšmė L3 fazėje per mėnesį', 474, 4, NULL, NULL),
	(4813, 25, 0, 7, 5, 0, 0, 6, 37, NULL, 'Minimali momentinė cos(fi) reikšmė L3 fazėje per mėnesį', 521, 4, NULL, NULL),
	(4814, 26, 0, 7, 4, 0, 0, 4, 38, NULL, 'Maksimalus momentinis kvadrantas L1 fazėje per valandą', 475, 2, NULL, NULL),
	(4815, 26, 0, 7, 5, 0, 0, 4, 38, NULL, 'Minimalus momentinis kvadrantas L1 fazėje per valandą', 522, 2, NULL, NULL),
	(4816, 26, 0, 7, 4, 0, 0, 5, 38, NULL, 'Maksimalus momentinis kvadrantas L1 fazėje per parą', 475, 3, NULL, NULL),
	(4817, 26, 0, 7, 5, 0, 0, 5, 38, NULL, 'Minimalus momentinis kvadrantas L1 fazėje per parą', 522, 3, NULL, NULL),
	(4818, 26, 0, 7, 4, 0, 0, 6, 38, NULL, 'Maksimalus momentinis kvadrantas L1 fazėje per mėnesį', 475, 4, NULL, NULL),
	(4819, 26, 0, 7, 5, 0, 0, 6, 38, NULL, 'Minimalus momentinis kvadrantas L1 fazėje per mėnesį', 522, 4, NULL, NULL),
	(4820, 27, 0, 7, 4, 0, 0, 4, 39, NULL, 'Maksimalus momentinis kvadrantas L2 fazėje per valandą', 476, 2, NULL, NULL),
	(4821, 27, 0, 7, 5, 0, 0, 4, 39, NULL, 'Minimalus momentinis kvadrantas L2 fazėje per valandą', 523, 2, NULL, NULL),
	(4822, 27, 0, 7, 4, 0, 0, 5, 39, NULL, 'Maksimalus momentinis kvadrantas L2 fazėje per parą', 476, 3, NULL, NULL),
	(4823, 27, 0, 7, 5, 0, 0, 5, 39, NULL, 'Minimalus momentinis kvadrantas L2 fazėje per parą', 523, 3, NULL, NULL),
	(4824, 27, 0, 7, 4, 0, 0, 6, 39, NULL, 'Maksimalus momentinis kvadrantas L2 fazėje per mėnesį', 476, 4, NULL, NULL),
	(4825, 27, 0, 7, 5, 0, 0, 6, 39, NULL, 'Minimalus momentinis kvadrantas L2 fazėje per mėnesį', 523, 4, NULL, NULL),
	(4826, 28, 0, 7, 4, 0, 0, 4, 40, NULL, 'Maksimalus momentinis kvadrantas L3 fazėje per valandą', 477, 2, NULL, NULL),
	(4827, 28, 0, 7, 5, 0, 0, 4, 40, NULL, 'Minimalus momentinis kvadrantas L3 fazėje per valandą', 524, 2, NULL, NULL),
	(4828, 28, 0, 7, 4, 0, 0, 5, 40, NULL, 'Maksimalus momentinis kvadrantas L3 fazėje per parą', 477, 3, NULL, NULL),
	(4829, 28, 0, 7, 5, 0, 0, 5, 40, NULL, 'Minimalus momentinis kvadrantas L3 fazėje per parą', 524, 3, NULL, NULL),
	(4830, 28, 0, 7, 4, 0, 0, 6, 40, NULL, 'Maksimalus momentinis kvadrantas L3 fazėje per mėnesį', 477, 4, NULL, NULL),
	(4831, 28, 0, 7, 5, 0, 0, 6, 40, NULL, 'Minimalus momentinis kvadrantas L3 fazėje per mėnesį', 524, 4, NULL, NULL),
	(4832, 29, 0, 7, 4, 0, 5, 4, 41, NULL, 'Maksimalus momentinis srovės stiprumas per valandą', 478, 2, NULL, NULL),
	(4833, 29, 0, 7, 5, 0, 5, 4, 41, NULL, 'Minimalus momentinis srovės stiprumas per valandą', 525, 2, NULL, NULL),
	(4834, 29, 0, 7, 4, 0, 5, 5, 41, NULL, 'Maksimalus momentinis srovės stiprumas per parą', 478, 3, NULL, NULL),
	(4835, 29, 0, 7, 5, 0, 5, 5, 41, NULL, 'Minimalus momentinis srovės stiprumas per parą', 525, 3, NULL, NULL),
	(4836, 29, 0, 7, 4, 0, 5, 6, 41, NULL, 'Maksimalus momentinis srovės stiprumas per mėnesį', 478, 4, NULL, NULL),
	(4837, 29, 0, 7, 5, 0, 5, 6, 41, NULL, 'Minimalus momentinis srovės stiprumas per mėnesį', 525, 4, NULL, NULL),
	(4838, 30, 0, 7, 4, 0, 6, 4, 42, NULL, 'Maksimali momentinė įtampa per valandą', 479, 2, NULL, NULL),
	(4839, 30, 0, 7, 5, 0, 6, 4, 42, NULL, 'Minimali momentinė įtampa per valandą', 526, 2, NULL, NULL),
	(4840, 30, 0, 7, 4, 0, 6, 5, 42, NULL, 'Maksimali momentinė įtampa per parą', 479, 3, NULL, NULL),
	(4841, 30, 0, 7, 5, 0, 6, 5, 42, NULL, 'Minimali momentinė įtampa per parą', 526, 3, NULL, NULL),
	(4842, 30, 0, 7, 4, 0, 6, 6, 42, NULL, 'Maksimali momentinė įtampa per mėnesį', 479, 4, NULL, NULL),
	(4843, 30, 0, 7, 5, 0, 6, 6, 42, NULL, 'Minimali momentinė įtampa per mėnesį', 526, 4, NULL, NULL),
	(4844, 31, 0, 7, 4, 0, 6, 4, 43, NULL, 'Maksimali momentinė linijinė įtampa per valandą', 480, 2, NULL, NULL),
	(4845, 31, 0, 7, 5, 0, 6, 4, 43, NULL, 'Minimali momentinė linijinė įtampa per valandą', 527, 2, NULL, NULL),
	(4846, 31, 0, 7, 4, 0, 6, 5, 43, NULL, 'Maksimali momentinė linijinė įtampa per parą', 480, 3, NULL, NULL),
	(4847, 31, 0, 7, 5, 0, 6, 5, 43, NULL, 'Minimali momentinė linijinė įtampa per parą', 527, 3, NULL, NULL),
	(4848, 31, 0, 7, 4, 0, 6, 6, 43, NULL, 'Maksimali momentinė linijinė įtampa per mėnesį', 480, 4, NULL, NULL),
	(4849, 31, 0, 7, 5, 0, 6, 6, 43, NULL, 'Minimali momentinė linijinė įtampa per mėnesį', 527, 4, NULL, NULL),
	(4850, 1, 0, 7, 4, 0, 1, 4, 13, NULL, 'Maksimali momentinė aktyvinė galia per valandą', 481, 2, NULL, NULL),
	(4851, 1, 0, 7, 5, 0, 1, 4, 13, NULL, 'Minimali momentinė aktyvinė galia per valandą', 528, 2, NULL, NULL),
	(4852, 1, 0, 7, 4, 0, 1, 5, 13, NULL, 'Maksimali momentinė aktyvinė galia per parą', 481, 3, NULL, NULL),
	(4853, 1, 0, 7, 5, 0, 1, 5, 13, NULL, 'Minimali momentinė aktyvinė galia per parą', 528, 3, NULL, NULL),
	(4854, 1, 0, 7, 4, 0, 1, 6, 13, NULL, 'Maksimali momentinė aktyvinė galia per mėnesį', 481, 4, NULL, NULL),
	(4855, 1, 0, 7, 5, 0, 1, 6, 13, NULL, 'Minimali momentinė aktyvinė galia per mėnesį', 528, 4, NULL, NULL),
	(4856, 3, 0, 7, 4, 0, 3, 4, 16, NULL, 'Maksimali momentinė reaktyvinė galia per valandą', 482, 2, NULL, NULL),
	(4857, 3, 0, 7, 5, 0, 3, 4, 16, NULL, 'Minimali momentinė reaktyvinė galia per valandą', 529, 2, NULL, NULL),
	(4858, 3, 0, 7, 4, 0, 3, 5, 16, NULL, 'Maksimali momentinė reaktyvinė galia per parą', 482, 3, NULL, NULL),
	(4859, 3, 0, 7, 5, 0, 3, 5, 16, NULL, 'Minimali momentinė reaktyvinė galia per parą', 529, 3, NULL, NULL),
	(4860, 3, 0, 7, 4, 0, 3, 6, 16, NULL, 'Maksimali momentinė reaktyvinė galia per mėnesį', 482, 4, NULL, NULL),
	(4861, 3, 0, 7, 5, 0, 3, 6, 16, NULL, 'Minimali momentinė reaktyvinė galia per mėnesį', 529, 4, NULL, NULL),
	(4862, 34, 0, 7, 4, 0, 7, 4, 44, NULL, 'Maksimali momentinė pilnoji galia per valandą', 483, 2, NULL, NULL),
	(4863, 34, 0, 7, 5, 0, 7, 4, 44, NULL, 'Minimali momentinė pilnoji galia per valandą', 530, 2, NULL, NULL),
	(4864, 34, 0, 7, 4, 0, 7, 5, 44, NULL, 'Maksimali momentinė pilnoji galia per parą', 483, 3, NULL, NULL),
	(4865, 34, 0, 7, 5, 0, 7, 5, 44, NULL, 'Minimali momentinė pilnoji galia per parą', 530, 3, NULL, NULL),
	(4866, 34, 0, 7, 4, 0, 7, 6, 44, NULL, 'Maksimali momentinė pilnoji galia per mėnesį', 483, 4, NULL, NULL),
	(4867, 34, 0, 7, 5, 0, 7, 6, 44, NULL, 'Minimali momentinė pilnoji galia per mėnesį', 530, 4, NULL, NULL),
	(4868, 35, 0, 7, 4, 0, 0, 4, 46, NULL, 'Maksimali momentinė cos(fi) reikšmė per valandą', 484, 2, NULL, NULL),
	(4869, 35, 0, 7, 5, 0, 0, 4, 46, NULL, 'Minimali momentinė cos(fi) reikšmė per valandą', 531, 2, NULL, NULL),
	(4870, 35, 0, 7, 4, 0, 0, 5, 46, NULL, 'Maksimali momentinė cos(fi) reikšmė per parą', 484, 3, NULL, NULL),
	(4871, 35, 0, 7, 5, 0, 0, 5, 46, NULL, 'Minimali momentinė cos(fi) reikšmė per parą', 531, 3, NULL, NULL),
	(4872, 35, 0, 7, 4, 0, 0, 6, 46, NULL, 'Maksimali momentinė cos(fi) reikšmė per mėnesį', 484, 4, NULL, NULL),
	(4873, 35, 0, 7, 5, 0, 0, 6, 46, NULL, 'Minimali momentinė cos(fi) reikšmė per mėnesį', 531, 4, NULL, NULL),
	(4874, 36, 0, 7, 4, 0, 0, 4, 47, NULL, 'Maksimalus momentinis kvadrantas per valandą', 485, 2, NULL, NULL),
	(4875, 36, 0, 7, 5, 0, 0, 4, 47, NULL, 'Minimalus momentinis kvadrantas per valandą', 532, 2, NULL, NULL),
	(4876, 36, 0, 7, 4, 0, 0, 5, 47, NULL, 'Maksimalus momentinis kvadrantas per parą', 485, 3, NULL, NULL),
	(4877, 36, 0, 7, 5, 0, 0, 5, 47, NULL, 'Minimalus momentinis kvadrantas per parą', 532, 3, NULL, NULL),
	(4878, 36, 0, 7, 4, 0, 0, 6, 47, NULL, 'Maksimalus momentinis kvadrantas per mėnesį', 485, 4, NULL, NULL),
	(4879, 36, 0, 7, 5, 0, 0, 6, 47, NULL, 'Minimalus momentinis kvadrantas per mėnesį', 532, 4, NULL, NULL),
	(4880, 37, 0, 7, 4, 0, 8, 4, 48, NULL, 'Maksimalus momentinis dažnis per valandą', 486, 2, NULL, NULL),
	(4881, 37, 0, 7, 5, 0, 8, 4, 48, NULL, 'Minimalus momentinis dažnis per valandą', 533, 2, NULL, NULL),
	(4882, 37, 0, 7, 4, 0, 8, 5, 48, NULL, 'Maksimalus momentinis dažnis per parą', 486, 3, NULL, NULL),
	(4883, 37, 0, 7, 5, 0, 8, 5, 48, NULL, 'Minimalus momentinis dažnis per parą', 533, 3, NULL, NULL),
	(4884, 37, 0, 7, 4, 0, 8, 6, 48, NULL, 'Maksimalus momentinis dažnis per mėnesį', 486, 4, NULL, NULL),
	(4885, 37, 0, 7, 5, 0, 8, 6, 48, NULL, 'Minimalus momentinis dažnis per mėnesį', 533, 4, NULL, NULL),
	(4886, 38, 0, 7, 4, 0, 0, 4, 49, NULL, 'Maksimali momentinė fazių seka per valandą', 487, 2, NULL, NULL),
	(4887, 38, 0, 7, 5, 0, 0, 4, 49, NULL, 'Minimali momentinė fazių seka per valandą', 534, 2, NULL, NULL),
	(4888, 38, 0, 7, 4, 0, 0, 5, 49, NULL, 'Maksimali momentinė fazių seka per parą', 487, 3, NULL, NULL),
	(4889, 38, 0, 7, 5, 0, 0, 5, 49, NULL, 'Minimali momentinė fazių seka per parą', 534, 3, NULL, NULL),
	(4890, 38, 0, 7, 4, 0, 0, 6, 49, NULL, 'Maksimali momentinė fazių seka per mėnesį', 487, 4, NULL, NULL),
	(4891, 38, 0, 7, 5, 0, 0, 6, 49, NULL, 'Minimali momentinė fazių seka per mėnesį', 534, 4, NULL, NULL),
	(4892, 178, 0, 7, 1, 0, 0, 7, 191, NULL, 'Įtampos iškraipymų harmonikos koeficientas L1 fazėje', 3138, 6, NULL, NULL),
	(4893, 179, 0, 7, 1, 0, 0, 7, 192, NULL, 'Įtampos iškraipymų harmonikos koeficientas L2 fazėje', 3139, 6, NULL, NULL),
	(4894, 180, 0, 7, 1, 0, 0, 7, 193, NULL, 'Įtampos iškraipymų harmonikos koeficientas L3 fazėje', 3140, 6, NULL, NULL),
	(4895, 181, 0, 7, 1, 0, 0, 7, 194, NULL, 'Srovės iškraipymų harmonikos koeficientas L1 fazėje', 3141, 6, NULL, NULL),
	(4896, 182, 0, 7, 1, 0, 0, 7, 195, NULL, 'Srovės iškraipymų harmonikos koeficientas L2 fazėje', 3142, 6, NULL, NULL),
	(4897, 183, 0, 7, 1, 0, 0, 7, 196, NULL, 'Srovės iškraipymų harmonikos koeficientas L3 fazėje', 3143, 6, NULL, NULL),
	(4898, 184, 0, 7, 1, 0, 0, 7, 197, NULL, 'Įtampos iškraipymų harmonikos koeficientas', 3144, 6, NULL, NULL),
	(4899, 185, 0, 7, 1, 0, 0, 7, 198, NULL, 'Srovės iškraipymų harmonikos koeficientas', 3145, 6, NULL, NULL),
	(4900, 186, 0, 5, 2, 0, 0, 5, 199, NULL, 'Produkcija per parą', 1500, 3, NULL, NULL),
	(4901, 186, 0, 6, 2, 0, 0, 6, 199, NULL, 'Produkcija per mėnesį', 1500, 4, NULL, NULL),
	(4902, 187, 0, 5, 2, 0, 0, 5, 200, NULL, 'Rodiklis Nr.1 per parą', NULL, 3, NULL, NULL),
	(4903, 187, 0, 6, 2, 0, 0, 6, 200, NULL, 'Rodiklis Nr.1 per mėnesį', NULL, 4, NULL, NULL),
	(4904, 188, 0, 7, 1, 0, 0, 7, 201, NULL, 'Galios koeficientas', 551, 6, NULL, NULL),
	(4905, 188, 0, 7, 4, 0, 0, 4, 201, NULL, 'Maksimalus galios koeficientas per valandą', 555, 2, NULL, NULL),
	(4906, 188, 0, 7, 5, 0, 0, 4, 201, NULL, 'Minimalus galios koeficientas per valandą', 559, 2, NULL, NULL),
	(4907, 188, 0, 7, 4, 0, 0, 5, 201, NULL, 'Maksimalus galios koeficientas per parą', 555, 3, NULL, NULL),
	(4908, 188, 0, 7, 5, 0, 0, 5, 201, NULL, 'Minimalus galios koeficientas per parą', 559, 3, NULL, NULL),
	(4909, 188, 0, 7, 4, 0, 0, 6, 201, NULL, 'Maksimalus galios koeficientas per mėnesį', 555, 4, NULL, NULL),
	(4910, 188, 0, 7, 5, 0, 0, 6, 201, NULL, 'Minimalus galios koeficientas per mėnesį', 559, 4, NULL, NULL),
	(4911, 175, 0, 7, 4, 0, 0, 4, 188, NULL, 'Maksimalus galios koeficientas L1 fazėje per valandą', 556, 2, NULL, NULL),
	(4912, 175, 0, 7, 5, 0, 0, 4, 188, NULL, 'Minimalus galios koeficientas L1 fazėje per valandą', 560, 2, NULL, NULL),
	(4913, 175, 0, 7, 4, 0, 0, 5, 188, NULL, 'Maksimalus galios koeficientas L1 fazėje per parą', 556, 3, NULL, NULL),
	(4914, 175, 0, 7, 5, 0, 0, 5, 188, NULL, 'Minimalus galios koeficientas L1 fazėje per parą', 560, 3, NULL, NULL),
	(4915, 175, 0, 7, 4, 0, 0, 6, 188, NULL, 'Maksimalus galios koeficientas L1 fazėje per mėnesį', 556, 4, NULL, NULL),
	(4916, 175, 0, 7, 5, 0, 0, 6, 188, NULL, 'Minimalus galios koeficientas L1 fazėje per mėnesį', 560, 4, NULL, NULL),
	(4917, 176, 0, 7, 4, 0, 0, 4, 189, NULL, 'Maksimalus galios koeficientas L2 fazėje per valandą', 557, 2, NULL, NULL),
	(4918, 176, 0, 7, 5, 0, 0, 4, 189, NULL, 'Minimalus galios koeficientas L2 fazėje per valandą', 561, 2, NULL, NULL),
	(4919, 176, 0, 7, 4, 0, 0, 5, 189, NULL, 'Maksimalus galios koeficientas L2 fazėje per parą', 557, 3, NULL, NULL),
	(4920, 176, 0, 7, 5, 0, 0, 5, 189, NULL, 'Minimalus galios koeficientas L2 fazėje per parą', 561, 3, NULL, NULL),
	(4921, 176, 0, 7, 4, 0, 0, 6, 189, NULL, 'Maksimalus galios koeficientas L2 fazėje per mėnesį', 557, 4, NULL, NULL),
	(4922, 176, 0, 7, 5, 0, 0, 6, 189, NULL, 'Minimalus galios koeficientas L2 fazėje per mėnesį', 561, 4, NULL, NULL),
	(4923, 177, 0, 7, 4, 0, 0, 4, 190, NULL, 'Maksimalus galios koeficientas L3 fazėje per valandą', 558, 2, NULL, NULL),
	(4924, 177, 0, 7, 5, 0, 0, 4, 190, NULL, 'Minimalus galios koeficientas L3 fazėje per valandą', 562, 2, NULL, NULL),
	(4925, 177, 0, 7, 4, 0, 0, 5, 190, NULL, 'Maksimalus galios koeficientas L3 fazėje per parą', 558, 3, NULL, NULL),
	(4926, 177, 0, 7, 5, 0, 0, 5, 190, NULL, 'Minimalus galios koeficientas L3 fazėje per parą', 562, 3, NULL, NULL),
	(4927, 177, 0, 7, 4, 0, 0, 6, 190, NULL, 'Maksimalus galios koeficientas L3 fazėje per mėnesį', 558, 4, NULL, NULL),
	(4928, 177, 0, 7, 5, 0, 0, 6, 190, NULL, 'Minimalus galios koeficientas L3 fazėje per mėnesį', 562, 4, NULL, NULL),
	(4929, 189, 1, 8, 2, 0, 2, 7, 202, NULL, 'Suminė A+ energija L1 fazėje', 3161, 5, NULL, NULL),
	(4930, 190, 1, 8, 2, 0, 2, 7, 203, NULL, 'Suminė A+ energija L2 fazėje', 3162, 5, NULL, NULL),
	(4931, 191, 1, 8, 2, 0, 2, 7, 204, NULL, 'Suminė A+ energija L3 fazėje', 3163, 5, NULL, NULL),
	(4932, 189, 2, 8, 2, 0, 2, 7, 202, NULL, 'Suminė A- energija L1 fazėje', 3164, 5, NULL, NULL),
	(4933, 190, 2, 8, 2, 0, 2, 7, 203, NULL, 'Suminė A- energija L2 fazėje', 3165, 5, NULL, NULL),
	(4934, 191, 2, 8, 2, 0, 2, 7, 204, NULL, 'Suminė A- energija L3 fazėje', 3166, 5, NULL, NULL),
	(4935, 193, 1, 8, 2, 0, 4, 7, 205, NULL, 'Suminė R+ energija L1 fazėje', 3167, 5, NULL, NULL),
	(4936, 194, 1, 8, 2, 0, 4, 7, 206, NULL, 'Suminė R+ energija L2 fazėje', 3168, 5, NULL, NULL),
	(4937, 195, 1, 8, 2, 0, 4, 7, 207, NULL, 'Suminė R+ energija L3 fazėje', 3169, 5, NULL, NULL),
	(4938, 193, 2, 8, 2, 0, 4, 7, 205, NULL, 'Suminė R- energija L1 fazėje', 3170, 5, NULL, NULL),
	(4939, 194, 2, 8, 2, 0, 4, 7, 206, NULL, 'Suminė R- energija L2 fazėje', 3171, 5, NULL, NULL),
	(4940, 195, 2, 8, 2, 0, 4, 7, 207, NULL, 'Suminė R- energija L3 fazėje', 3172, 5, NULL, NULL),
	(4941, 196, 0, 8, 2, 0, 41, 7, 208, NULL, 'Suminė W energija L1 fazėje', 3173, 5, NULL, NULL),
	(4942, 197, 0, 8, 2, 0, 41, 7, 209, NULL, 'Suminė W energija L2 fazėje', 3174, 5, NULL, NULL),
	(4943, 198, 0, 8, 2, 0, 41, 7, 210, NULL, 'Suminė W energija L3 fazėje', 3175, 5, NULL, NULL),
	(4947, 202, 0, 7, 1, 0, 0, 7, 214, NULL, 'Momentinė sin(fi) reikšmė', 90, 6, NULL, NULL),
	(4948, 202, 0, 7, 4, 0, 0, 4, 214, NULL, 'Maksimali momentinė sin(fi) reikšmė per valandą', 491, 2, NULL, NULL),
	(4949, 202, 0, 7, 5, 0, 0, 4, 214, NULL, 'Minimali momentinė sin(fi) reikšmė per valandą', 538, 2, NULL, NULL),
	(4950, 202, 0, 7, 4, 0, 0, 5, 214, NULL, 'Maksimali momentinė sin(fi) reikšmė per parą', 491, 3, NULL, NULL),
	(4951, 202, 0, 7, 5, 0, 0, 5, 214, NULL, 'Minimali momentinė sin(fi) reikšmė per parą', 538, 3, NULL, NULL),
	(4952, 202, 0, 7, 4, 0, 0, 6, 214, NULL, 'Maksimali momentinė sin(fi) reikšmė per mėnesį', 491, 4, NULL, NULL),
	(4953, 202, 0, 7, 5, 0, 0, 6, 214, NULL, 'Minimali momentinė sin(fi) reikšmė per mėnesį', 538, 4, NULL, NULL),
	(4954, 203, 0, 7, 1, 0, 0, 7, 215, NULL, 'Momentinė sin(fi) reikšmė L1 fazėje', 87, 6, NULL, NULL),
	(4955, 203, 0, 7, 4, 0, 0, 4, 215, NULL, 'Maksimali momentinė sin(fi) reikšmė L1 fazėje per valandą', 488, 2, NULL, NULL),
	(4956, 203, 0, 7, 5, 0, 0, 4, 215, NULL, 'Minimali momentinė sin(fi) reikšmė L1 fazėje per valandą', 535, 2, NULL, NULL),
	(4957, 203, 0, 7, 4, 0, 0, 5, 215, NULL, 'Maksimali momentinė sin(fi) reikšmė L1 fazėje per parą', 488, 3, NULL, NULL),
	(4958, 203, 0, 7, 5, 0, 0, 5, 215, NULL, 'Minimali momentinė sin(fi) reikšmė L1 fazėje per parą', 535, 3, NULL, NULL),
	(4959, 203, 0, 7, 4, 0, 0, 6, 215, NULL, 'Maksimali momentinė sin(fi) reikšmė L1 fazėje per mėnesį', 488, 4, NULL, NULL),
	(4960, 203, 0, 7, 5, 0, 0, 6, 215, NULL, 'Minimali momentinė sin(fi) reikšmė L1 fazėje per mėnesį', 535, 4, NULL, NULL),
	(4961, 204, 0, 7, 1, 0, 0, 7, 216, NULL, 'Momentinė sin(fi) reikšmė L2 fazėje', 88, 6, NULL, NULL),
	(4962, 204, 0, 7, 4, 0, 0, 4, 216, NULL, 'Maksimali momentinė sin(fi) reikšmė L2 fazėje per valandą', 489, 2, NULL, NULL),
	(4963, 204, 0, 7, 5, 0, 0, 4, 216, NULL, 'Minimali momentinė sin(fi) reikšmė L2 fazėje per valandą', 536, 2, NULL, NULL),
	(4964, 204, 0, 7, 4, 0, 0, 5, 216, NULL, 'Maksimali momentinė sin(fi) reikšmė L2 fazėje per parą', 489, 3, NULL, NULL),
	(4965, 204, 0, 7, 5, 0, 0, 5, 216, NULL, 'Minimali momentinė sin(fi) reikšmė L2 fazėje per parą', 536, 3, NULL, NULL),
	(4966, 204, 0, 7, 4, 0, 0, 6, 216, NULL, 'Maksimali momentinė sin(fi) reikšmė L2 fazėje per mėnesį', 489, 4, NULL, NULL),
	(4967, 204, 0, 7, 5, 0, 0, 6, 216, NULL, 'Minimali momentinė sin(fi) reikšmė L2 fazėje per mėnesį', 536, 4, NULL, NULL),
	(4968, 205, 0, 7, 1, 0, 0, 7, 217, NULL, 'Momentinė sin(fi) reikšmė L3 fazėje', 89, 6, NULL, NULL),
	(4969, 205, 0, 7, 4, 0, 0, 4, 217, NULL, 'Maksimali momentinė sin(fi) reikšmė L3 fazėje per valandą', 490, 2, NULL, NULL),
	(4970, 205, 0, 7, 5, 0, 0, 4, 217, NULL, 'Minimali momentinė sin(fi) reikšmė L3 fazėje per valandą', 537, 2, NULL, NULL),
	(4971, 205, 0, 7, 4, 0, 0, 5, 217, NULL, 'Maksimali momentinė sin(fi) reikšmė L3 fazėje per parą', 490, 3, NULL, NULL),
	(4972, 205, 0, 7, 5, 0, 0, 5, 217, NULL, 'Minimali momentinė sin(fi) reikšmė L3 fazėje per parą', 537, 3, NULL, NULL),
	(4973, 205, 0, 7, 4, 0, 0, 6, 217, NULL, 'Maksimali momentinė sin(fi) reikšmė L3 fazėje per mėnesį', 490, 4, NULL, NULL),
	(4974, 205, 0, 7, 5, 0, 0, 6, 217, NULL, 'Minimali momentinė sin(fi) reikšmė L3 fazėje per mėnesį', 537, 4, NULL, NULL),
	(4975, 169, 0, 7, 4, 0, 0, 4, 182, NULL, 'Maksimalus kampas tarp L1 ir L2 fazės įtampų per valandą', 492, 2, NULL, NULL),
	(4976, 169, 0, 7, 5, 0, 0, 4, 182, NULL, 'Minimalus kampas tarp L1 ir L2 fazės įtampų per valandą', 539, 2, NULL, NULL),
	(4977, 169, 0, 7, 4, 0, 0, 5, 182, NULL, 'Maksimalus kampas tarp L1 ir L2 fazės įtampų per parą', 492, 3, NULL, NULL),
	(4978, 169, 0, 7, 5, 0, 0, 5, 182, NULL, 'Minimalus kampas tarp L1 ir L2 fazės įtampų per parą', 539, 3, NULL, NULL),
	(4979, 169, 0, 7, 4, 0, 0, 6, 182, NULL, 'Maksimalus kampas tarp L1 ir L2 fazės įtampų per mėnesį', 492, 4, NULL, NULL),
	(4980, 169, 0, 7, 5, 0, 0, 6, 182, NULL, 'Minimalus kampas tarp L1 ir L2 fazės įtampų per mėnesį', 539, 4, NULL, NULL),
	(4981, 170, 0, 7, 4, 0, 0, 4, 183, NULL, 'Maksimalus kampas tarp L2 ir L3 fazės įtampų per valandą', 493, 2, NULL, NULL),
	(4982, 170, 0, 7, 5, 0, 0, 4, 183, NULL, 'Minimalus kampas tarp L2 ir L3 fazės įtampų per valandą', 540, 2, NULL, NULL),
	(4983, 170, 0, 7, 4, 0, 0, 5, 183, NULL, 'Maksimalus kampas tarp L2 ir L3 fazės įtampų per parą', 493, 3, NULL, NULL),
	(4984, 170, 0, 7, 5, 0, 0, 5, 183, NULL, 'Minimalus kampas tarp L2 ir L3 fazės įtampų per parą', 540, 3, NULL, NULL),
	(4985, 170, 0, 7, 4, 0, 0, 6, 183, NULL, 'Maksimalus kampas tarp L2 ir L3 fazės įtampų per mėnesį', 493, 4, NULL, NULL),
	(4986, 170, 0, 7, 5, 0, 0, 6, 183, NULL, 'Minimalus kampas tarp L2 ir L3 fazės įtampų per mėnesį', 540, 4, NULL, NULL),
	(4987, 171, 0, 7, 4, 0, 0, 4, 184, NULL, 'Maksimalus kampas tarp L3 ir L1 fazės įtampų per valandą', 494, 2, NULL, NULL),
	(4988, 171, 0, 7, 5, 0, 0, 4, 184, NULL, 'Minimalus kampas tarp L3 ir L1 fazės įtampų per valandą', 541, 2, NULL, NULL),
	(4989, 171, 0, 7, 4, 0, 0, 5, 184, NULL, 'Maksimalus kampas tarp L3 ir L1 fazės įtampų per parą', 494, 3, NULL, NULL),
	(4990, 171, 0, 7, 5, 0, 0, 5, 184, NULL, 'Minimalus kampas tarp L3 ir L1 fazės įtampų per parą', 541, 3, NULL, NULL),
	(4991, 171, 0, 7, 4, 0, 0, 6, 184, NULL, 'Maksimalus kampas tarp L3 ir L1 fazės įtampų per mėnesį', 494, 4, NULL, NULL),
	(4992, 171, 0, 7, 5, 0, 0, 6, 184, NULL, 'Minimalus kampas tarp L3 ir L1 fazės įtampų per mėnesį', 541, 4, NULL, NULL),
	(4993, 172, 0, 7, 4, 0, 0, 4, 185, NULL, 'Maksimalus kampas tarp srovės ir įtampos L1 fazėje per valandą', 495, 2, NULL, NULL),
	(4994, 172, 0, 7, 5, 0, 0, 4, 185, NULL, 'Minimalus kampas tarp srovės ir įtampos L1 fazėje per valandą', 542, 2, NULL, NULL),
	(4995, 172, 0, 7, 4, 0, 0, 5, 185, NULL, 'Maksimalus kampas tarp srovės ir įtampos L1 fazėje per parą', 495, 3, NULL, NULL),
	(4996, 172, 0, 7, 5, 0, 0, 5, 185, NULL, 'Minimalus kampas tarp srovės ir įtampos L1 fazėje per parą', 542, 3, NULL, NULL),
	(4997, 172, 0, 7, 4, 0, 0, 6, 185, NULL, 'Maksimalus kampas tarp srovės ir įtampos L1 fazėje per mėnesį', 495, 4, NULL, NULL),
	(4998, 172, 0, 7, 5, 0, 0, 6, 185, NULL, 'Minimalus kampas tarp srovės ir įtampos L1 fazėje per mėnesį', 542, 4, NULL, NULL),
	(4999, 173, 0, 7, 4, 0, 0, 4, 186, NULL, 'Maksimalus kampas tarp srovės ir įtampos L2 fazėje per valandą', 496, 2, NULL, NULL),
	(5000, 173, 0, 7, 5, 0, 0, 4, 186, NULL, 'Minimalus kampas tarp srovės ir įtampos L2 fazėje per valandą', 543, 2, NULL, NULL),
	(5001, 173, 0, 7, 4, 0, 0, 5, 186, NULL, 'Maksimalus kampas tarp srovės ir įtampos L2 fazėje per parą', 496, 3, NULL, NULL),
	(5002, 173, 0, 7, 5, 0, 0, 5, 186, NULL, 'Minimalus kampas tarp srovės ir įtampos L2 fazėje per parą', 543, 3, NULL, NULL),
	(5003, 173, 0, 7, 4, 0, 0, 6, 186, NULL, 'Maksimalus kampas tarp srovės ir įtampos L2 fazėje per mėnesį', 496, 4, NULL, NULL),
	(5004, 173, 0, 7, 5, 0, 0, 6, 186, NULL, 'Minimalus kampas tarp srovės ir įtampos L2 fazėje per mėnesį', 543, 4, NULL, NULL),
	(5005, 174, 0, 7, 4, 0, 0, 4, 187, NULL, 'Maksimalus kampas tarp srovės ir įtampos L3 fazėje per valandą', 497, 2, NULL, NULL),
	(5006, 174, 0, 7, 5, 0, 0, 4, 187, NULL, 'Minimalus kampas tarp srovės ir įtampos L3 fazėje per valandą', 544, 2, NULL, NULL),
	(5007, 174, 0, 7, 4, 0, 0, 5, 187, NULL, 'Maksimalus kampas tarp srovės ir įtampos L3 fazėje per parą', 497, 3, NULL, NULL),
	(5008, 174, 0, 7, 5, 0, 0, 5, 187, NULL, 'Minimalus kampas tarp srovės ir įtampos L3 fazėje per parą', 544, 3, NULL, NULL),
	(5009, 174, 0, 7, 4, 0, 0, 6, 187, NULL, 'Maksimalus kampas tarp srovės ir įtampos L3 fazėje per mėnesį', 497, 4, NULL, NULL),
	(5010, 174, 0, 7, 5, 0, 0, 6, 187, NULL, 'Minimalus kampas tarp srovės ir įtampos L3 fazėje per mėnesį', 544, 4, NULL, NULL),
	(5011, 90, 0, 7, 6, 0, 9, 7, 103, NULL, 'Įtampos 2-os harmonikos koeficientas L1 fazėje', 2316, 6, NULL, NULL),
	(5012, 93, 0, 7, 6, 0, 9, 7, 106, NULL, 'Įtampos 2-os harmonikos koeficientas L2 fazėje', 2317, 6, NULL, NULL),
	(5013, 96, 0, 7, 6, 0, 9, 7, 109, NULL, 'Įtampos 2-os harmonikos koeficientas L3 fazėje', 2318, 6, NULL, NULL),
	(5014, 90, 0, 7, 7, 0, 9, 7, 103, NULL, 'Įtampos 3-os harmonikos koeficientas L1 fazėje', 2319, 6, NULL, NULL),
	(5015, 93, 0, 7, 7, 0, 9, 7, 106, NULL, 'Įtampos 3-os harmonikos koeficientas L2 fazėje', 2320, 6, NULL, NULL),
	(5016, 96, 0, 7, 7, 0, 9, 7, 109, NULL, 'Įtampos 3-os harmonikos koeficientas L3 fazėje', 2321, 6, NULL, NULL),
	(5017, 90, 0, 7, 8, 0, 9, 7, 103, NULL, 'Įtampos 4-os harmonikos koeficientas L1 fazėje', 2322, 6, NULL, NULL),
	(5018, 93, 0, 7, 8, 0, 9, 7, 106, NULL, 'Įtampos 4-os harmonikos koeficientas L2 fazėje', 2323, 6, NULL, NULL),
	(5019, 96, 0, 7, 8, 0, 9, 7, 109, NULL, 'Įtampos 4-os harmonikos koeficientas L3 fazėje', 2324, 6, NULL, NULL),
	(5020, 90, 0, 7, 9, 0, 9, 7, 103, NULL, 'Įtampos 5-os harmonikos koeficientas L1 fazėje', 2325, 6, NULL, NULL),
	(5021, 93, 0, 7, 9, 0, 9, 7, 106, NULL, 'Įtampos 5-os harmonikos koeficientas L2 fazėje', 2326, 6, NULL, NULL),
	(5022, 96, 0, 7, 9, 0, 9, 7, 109, NULL, 'Įtampos 5-os harmonikos koeficientas L3 fazėje', 2327, 6, NULL, NULL),
	(5023, 90, 0, 7, 10, 0, 9, 7, 103, NULL, 'Įtampos 6-os harmonikos koeficientas L1 fazėje', 2328, 6, NULL, NULL),
	(5024, 93, 0, 7, 10, 0, 9, 7, 106, NULL, 'Įtampos 6-os harmonikos koeficientas L2 fazėje', 2329, 6, NULL, NULL),
	(5025, 96, 0, 7, 10, 0, 9, 7, 109, NULL, 'Įtampos 6-os harmonikos koeficientas L3 fazėje', 2330, 6, NULL, NULL),
	(5026, 90, 0, 7, 11, 0, 9, 7, 103, NULL, 'Įtampos 7-os harmonikos koeficientas L1 fazėje', 2331, 6, NULL, NULL),
	(5027, 93, 0, 7, 11, 0, 9, 7, 106, NULL, 'Įtampos 7-os harmonikos koeficientas L2 fazėje', 2332, 6, NULL, NULL),
	(5028, 96, 0, 7, 11, 0, 9, 7, 109, NULL, 'Įtampos 7-os harmonikos koeficientas L3 fazėje', 2333, 6, NULL, NULL),
	(5029, 90, 0, 7, 12, 0, 9, 7, 103, NULL, 'Įtampos 8-os harmonikos koeficientas L1 fazėje', 2334, 6, NULL, NULL),
	(5030, 93, 0, 7, 12, 0, 9, 7, 106, NULL, 'Įtampos 8-os harmonikos koeficientas L2 fazėje', 2335, 6, NULL, NULL),
	(5031, 96, 0, 7, 12, 0, 9, 7, 109, NULL, 'Įtampos 8-os harmonikos koeficientas L3 fazėje', 2336, 6, NULL, NULL),
	(5032, 90, 0, 7, 13, 0, 9, 7, 103, NULL, 'Įtampos 9-os harmonikos koeficientas L1 fazėje', 2337, 6, NULL, NULL),
	(5033, 93, 0, 7, 13, 0, 9, 7, 106, NULL, 'Įtampos 9-os harmonikos koeficientas L2 fazėje', 2338, 6, NULL, NULL),
	(5034, 96, 0, 7, 13, 0, 9, 7, 109, NULL, 'Įtampos 9-os harmonikos koeficientas L3 fazėje', 2339, 6, NULL, NULL),
	(5035, 90, 0, 7, 14, 0, 9, 7, 103, NULL, 'Įtampos 10-os harmonikos koeficientas L1 fazėje', 2340, 6, NULL, NULL),
	(5036, 93, 0, 7, 14, 0, 9, 7, 106, NULL, 'Įtampos 10-os harmonikos koeficientas L2 fazėje', 2341, 6, NULL, NULL),
	(5037, 96, 0, 7, 14, 0, 9, 7, 109, NULL, 'Įtampos 10-os harmonikos koeficientas L3 fazėje', 2342, 6, NULL, NULL),
	(5038, 90, 0, 7, 15, 0, 9, 7, 103, NULL, 'Įtampos 11-os harmonikos koeficientas L1 fazėje', 2343, 6, NULL, NULL),
	(5039, 93, 0, 7, 15, 0, 9, 7, 106, NULL, 'Įtampos 11-os harmonikos koeficientas L2 fazėje', 2344, 6, NULL, NULL),
	(5040, 96, 0, 7, 15, 0, 9, 7, 109, NULL, 'Įtampos 11-os harmonikos koeficientas L3 fazėje', 2345, 6, NULL, NULL),
	(5041, 90, 0, 7, 16, 0, 9, 7, 103, NULL, 'Įtampos 12-os harmonikos koeficientas L1 fazėje', 2346, 6, NULL, NULL),
	(5042, 93, 0, 7, 16, 0, 9, 7, 106, NULL, 'Įtampos 12-os harmonikos koeficientas L2 fazėje', 2347, 6, NULL, NULL),
	(5043, 96, 0, 7, 16, 0, 9, 7, 109, NULL, 'Įtampos 12-os harmonikos koeficientas L3 fazėje', 2348, 6, NULL, NULL),
	(5044, 90, 0, 7, 17, 0, 9, 7, 103, NULL, 'Įtampos 13-os harmonikos koeficientas L1 fazėje', 2349, 6, NULL, NULL),
	(5045, 93, 0, 7, 17, 0, 9, 7, 106, NULL, 'Įtampos 13-os harmonikos koeficientas L2 fazėje', 2350, 6, NULL, NULL),
	(5046, 96, 0, 7, 17, 0, 9, 7, 109, NULL, 'Įtampos 13-os harmonikos koeficientas L3 fazėje', 2351, 6, NULL, NULL),
	(5047, 90, 0, 7, 18, 0, 9, 7, 103, NULL, 'Įtampos 14-os harmonikos koeficientas L1 fazėje', 2352, 6, NULL, NULL),
	(5048, 93, 0, 7, 18, 0, 9, 7, 106, NULL, 'Įtampos 14-os harmonikos koeficientas L2 fazėje', 2353, 6, NULL, NULL),
	(5049, 96, 0, 7, 18, 0, 9, 7, 109, NULL, 'Įtampos 14-os harmonikos koeficientas L3 fazėje', 2354, 6, NULL, NULL),
	(5050, 90, 0, 7, 19, 0, 9, 7, 103, NULL, 'Įtampos 15-os harmonikos koeficientas L1 fazėje', 2355, 6, NULL, NULL),
	(5051, 93, 0, 7, 19, 0, 9, 7, 106, NULL, 'Įtampos 15-os harmonikos koeficientas L2 fazėje', 2356, 6, NULL, NULL),
	(5052, 96, 0, 7, 19, 0, 9, 7, 109, NULL, 'Įtampos 15-os harmonikos koeficientas L3 fazėje', 2357, 6, NULL, NULL),
	(5053, 90, 0, 7, 20, 0, 9, 7, 103, NULL, 'Įtampos 16-os harmonikos koeficientas L1 fazėje', 2358, 6, NULL, NULL),
	(5054, 93, 0, 7, 20, 0, 9, 7, 106, NULL, 'Įtampos 16-os harmonikos koeficientas L2 fazėje', 2359, 6, NULL, NULL),
	(5055, 96, 0, 7, 20, 0, 9, 7, 109, NULL, 'Įtampos 16-os harmonikos koeficientas L3 fazėje', 2360, 6, NULL, NULL),
	(5056, 90, 0, 7, 21, 0, 9, 7, 103, NULL, 'Įtampos 17-os harmonikos koeficientas L1 fazėje', 2361, 6, NULL, NULL),
	(5057, 93, 0, 7, 21, 0, 9, 7, 106, NULL, 'Įtampos 17-os harmonikos koeficientas L2 fazėje', 2362, 6, NULL, NULL),
	(5058, 96, 0, 7, 21, 0, 9, 7, 109, NULL, 'Įtampos 17-os harmonikos koeficientas L3 fazėje', 2363, 6, NULL, NULL),
	(5059, 90, 0, 7, 22, 0, 9, 7, 103, NULL, 'Įtampos 18-os harmonikos koeficientas L1 fazėje', 2364, 6, NULL, NULL),
	(5060, 93, 0, 7, 22, 0, 9, 7, 106, NULL, 'Įtampos 18-os harmonikos koeficientas L2 fazėje', 2365, 6, NULL, NULL),
	(5061, 96, 0, 7, 22, 0, 9, 7, 109, NULL, 'Įtampos 18-os harmonikos koeficientas L3 fazėje', 2366, 6, NULL, NULL),
	(5062, 90, 0, 7, 23, 0, 9, 7, 103, NULL, 'Įtampos 19-os harmonikos koeficientas L1 fazėje', 2367, 6, NULL, NULL),
	(5063, 93, 0, 7, 23, 0, 9, 7, 106, NULL, 'Įtampos 19-os harmonikos koeficientas L2 fazėje', 2368, 6, NULL, NULL),
	(5064, 96, 0, 7, 23, 0, 9, 7, 109, NULL, 'Įtampos 19-os harmonikos koeficientas L3 fazėje', 2369, 6, NULL, NULL),
	(5065, 90, 0, 7, 24, 0, 9, 7, 103, NULL, 'Įtampos 20-os harmonikos koeficientas L1 fazėje', 2370, 6, NULL, NULL),
	(5066, 93, 0, 7, 24, 0, 9, 7, 106, NULL, 'Įtampos 20-os harmonikos koeficientas L2 fazėje', 2371, 6, NULL, NULL),
	(5067, 96, 0, 7, 24, 0, 9, 7, 109, NULL, 'Įtampos 20-os harmonikos koeficientas L3 fazėje', 2372, 6, NULL, NULL),
	(5068, 90, 0, 7, 25, 0, 9, 7, 103, NULL, 'Įtampos 21-os harmonikos koeficientas L1 fazėje', 2373, 6, NULL, NULL),
	(5069, 93, 0, 7, 25, 0, 9, 7, 106, NULL, 'Įtampos 21-os harmonikos koeficientas L2 fazėje', 2374, 6, NULL, NULL),
	(5070, 96, 0, 7, 25, 0, 9, 7, 109, NULL, 'Įtampos 21-os harmonikos koeficientas L3 fazėje', 2375, 6, NULL, NULL),
	(5071, 90, 0, 7, 26, 0, 9, 7, 103, NULL, 'Įtampos 22-os harmonikos koeficientas L1 fazėje', 2376, 6, NULL, NULL),
	(5072, 93, 0, 7, 26, 0, 9, 7, 106, NULL, 'Įtampos 22-os harmonikos koeficientas L2 fazėje', 2377, 6, NULL, NULL),
	(5073, 96, 0, 7, 26, 0, 9, 7, 109, NULL, 'Įtampos 22-os harmonikos koeficientas L3 fazėje', 2378, 6, NULL, NULL),
	(5074, 90, 0, 7, 27, 0, 9, 7, 103, NULL, 'Įtampos 23-os harmonikos koeficientas L1 fazėje', 2379, 6, NULL, NULL),
	(5075, 93, 0, 7, 27, 0, 9, 7, 106, NULL, 'Įtampos 23-os harmonikos koeficientas L2 fazėje', 2380, 6, NULL, NULL),
	(5076, 96, 0, 7, 27, 0, 9, 7, 109, NULL, 'Įtampos 23-os harmonikos koeficientas L3 fazėje', 2381, 6, NULL, NULL),
	(5077, 90, 0, 7, 28, 0, 9, 7, 103, NULL, 'Įtampos 24-os harmonikos koeficientas L1 fazėje', 2382, 6, NULL, NULL),
	(5078, 93, 0, 7, 28, 0, 9, 7, 106, NULL, 'Įtampos 24-os harmonikos koeficientas L2 fazėje', 2383, 6, NULL, NULL),
	(5079, 96, 0, 7, 28, 0, 9, 7, 109, NULL, 'Įtampos 24-os harmonikos koeficientas L3 fazėje', 2384, 6, NULL, NULL),
	(5080, 90, 0, 7, 29, 0, 9, 7, 103, NULL, 'Įtampos 25-os harmonikos koeficientas L1 fazėje', 2385, 6, NULL, NULL),
	(5081, 93, 0, 7, 29, 0, 9, 7, 106, NULL, 'Įtampos 25-os harmonikos koeficientas L2 fazėje', 2386, 6, NULL, NULL),
	(5082, 96, 0, 7, 29, 0, 9, 7, 109, NULL, 'Įtampos 25-os harmonikos koeficientas L3 fazėje', 2387, 6, NULL, NULL),
	(5083, 90, 0, 7, 30, 0, 9, 7, 103, NULL, 'Įtampos 26-os harmonikos koeficientas L1 fazėje', 2388, 6, NULL, NULL),
	(5084, 93, 0, 7, 30, 0, 9, 7, 106, NULL, 'Įtampos 26-os harmonikos koeficientas L2 fazėje', 2389, 6, NULL, NULL),
	(5085, 96, 0, 7, 30, 0, 9, 7, 109, NULL, 'Įtampos 26-os harmonikos koeficientas L3 fazėje', 2390, 6, NULL, NULL),
	(5086, 90, 0, 7, 31, 0, 9, 7, 103, NULL, 'Įtampos 27-os harmonikos koeficientas L1 fazėje', 2391, 6, NULL, NULL),
	(5087, 93, 0, 7, 31, 0, 9, 7, 106, NULL, 'Įtampos 27-os harmonikos koeficientas L2 fazėje', 2392, 6, NULL, NULL),
	(5088, 96, 0, 7, 31, 0, 9, 7, 109, NULL, 'Įtampos 27-os harmonikos koeficientas L3 fazėje', 2393, 6, NULL, NULL),
	(5089, 90, 0, 7, 32, 0, 9, 7, 103, NULL, 'Įtampos 28-os harmonikos koeficientas L1 fazėje', 2394, 6, NULL, NULL),
	(5090, 93, 0, 7, 32, 0, 9, 7, 106, NULL, 'Įtampos 28-os harmonikos koeficientas L2 fazėje', 2395, 6, NULL, NULL),
	(5091, 96, 0, 7, 32, 0, 9, 7, 109, NULL, 'Įtampos 28-os harmonikos koeficientas L3 fazėje', 2396, 6, NULL, NULL),
	(5092, 90, 0, 7, 33, 0, 9, 7, 103, NULL, 'Įtampos 29-os harmonikos koeficientas L1 fazėje', 2397, 6, NULL, NULL),
	(5093, 93, 0, 7, 33, 0, 9, 7, 106, NULL, 'Įtampos 29-os harmonikos koeficientas L2 fazėje', 2398, 6, NULL, NULL),
	(5094, 96, 0, 7, 33, 0, 9, 7, 109, NULL, 'Įtampos 29-os harmonikos koeficientas L3 fazėje', 2399, 6, NULL, NULL),
	(5095, 90, 0, 7, 34, 0, 9, 7, 103, NULL, 'Įtampos 30-os harmonikos koeficientas L1 fazėje', 2400, 6, NULL, NULL),
	(5096, 93, 0, 7, 34, 0, 9, 7, 106, NULL, 'Įtampos 30-os harmonikos koeficientas L2 fazėje', 2401, 6, NULL, NULL),
	(5097, 96, 0, 7, 34, 0, 9, 7, 109, NULL, 'Įtampos 30-os harmonikos koeficientas L3 fazėje', 2402, 6, NULL, NULL),
	(5098, 90, 0, 7, 35, 0, 9, 7, 103, NULL, 'Įtampos 31-os harmonikos koeficientas L1 fazėje', 2403, 6, NULL, NULL),
	(5099, 93, 0, 7, 35, 0, 9, 7, 106, NULL, 'Įtampos 31-os harmonikos koeficientas L2 fazėje', 2404, 6, NULL, NULL),
	(5100, 96, 0, 7, 35, 0, 9, 7, 109, NULL, 'Įtampos 31-os harmonikos koeficientas L3 fazėje', 2405, 6, NULL, NULL),
	(5101, 90, 0, 7, 36, 0, 9, 7, 103, NULL, 'Įtampos 32-os harmonikos koeficientas L1 fazėje', 2406, 6, NULL, NULL),
	(5102, 93, 0, 7, 36, 0, 9, 7, 106, NULL, 'Įtampos 32-os harmonikos koeficientas L2 fazėje', 2407, 6, NULL, NULL),
	(5103, 96, 0, 7, 36, 0, 9, 7, 109, NULL, 'Įtampos 32-os harmonikos koeficientas L3 fazėje', 2408, 6, NULL, NULL),
	(5104, 90, 0, 7, 37, 0, 9, 7, 103, NULL, 'Įtampos 33-os harmonikos koeficientas L1 fazėje', 2409, 6, NULL, NULL),
	(5105, 93, 0, 7, 37, 0, 9, 7, 106, NULL, 'Įtampos 33-os harmonikos koeficientas L2 fazėje', 2410, 6, NULL, NULL),
	(5106, 96, 0, 7, 37, 0, 9, 7, 109, NULL, 'Įtampos 33-os harmonikos koeficientas L3 fazėje', 2411, 6, NULL, NULL),
	(5107, 90, 0, 7, 38, 0, 9, 7, 103, NULL, 'Įtampos 34-os harmonikos koeficientas L1 fazėje', 2412, 6, NULL, NULL),
	(5108, 93, 0, 7, 38, 0, 9, 7, 106, NULL, 'Įtampos 34-os harmonikos koeficientas L2 fazėje', 2413, 6, NULL, NULL),
	(5109, 96, 0, 7, 38, 0, 9, 7, 109, NULL, 'Įtampos 34-os harmonikos koeficientas L3 fazėje', 2414, 6, NULL, NULL),
	(5110, 90, 0, 7, 39, 0, 9, 7, 103, NULL, 'Įtampos 35-os harmonikos koeficientas L1 fazėje', 2415, 6, NULL, NULL),
	(5111, 93, 0, 7, 39, 0, 9, 7, 106, NULL, 'Įtampos 35-os harmonikos koeficientas L2 fazėje', 2416, 6, NULL, NULL),
	(5112, 96, 0, 7, 39, 0, 9, 7, 109, NULL, 'Įtampos 35-os harmonikos koeficientas L3 fazėje', 2417, 6, NULL, NULL),
	(5113, 90, 0, 7, 40, 0, 9, 7, 103, NULL, 'Įtampos 36-os harmonikos koeficientas L1 fazėje', 2418, 6, NULL, NULL),
	(5114, 93, 0, 7, 40, 0, 9, 7, 106, NULL, 'Įtampos 36-os harmonikos koeficientas L2 fazėje', 2419, 6, NULL, NULL),
	(5115, 96, 0, 7, 40, 0, 9, 7, 109, NULL, 'Įtampos 36-os harmonikos koeficientas L3 fazėje', 2420, 6, NULL, NULL),
	(5116, 90, 0, 7, 41, 0, 9, 7, 103, NULL, 'Įtampos 37-os harmonikos koeficientas L1 fazėje', 2421, 6, NULL, NULL),
	(5117, 93, 0, 7, 41, 0, 9, 7, 106, NULL, 'Įtampos 37-os harmonikos koeficientas L2 fazėje', 2422, 6, NULL, NULL),
	(5118, 96, 0, 7, 41, 0, 9, 7, 109, NULL, 'Įtampos 37-os harmonikos koeficientas L3 fazėje', 2423, 6, NULL, NULL),
	(5119, 90, 0, 7, 42, 0, 9, 7, 103, NULL, 'Įtampos 38-os harmonikos koeficientas L1 fazėje', 2424, 6, NULL, NULL),
	(5120, 93, 0, 7, 42, 0, 9, 7, 106, NULL, 'Įtampos 38-os harmonikos koeficientas L2 fazėje', 2425, 6, NULL, NULL),
	(5121, 96, 0, 7, 42, 0, 9, 7, 109, NULL, 'Įtampos 38-os harmonikos koeficientas L3 fazėje', 2426, 6, NULL, NULL),
	(5122, 90, 0, 7, 43, 0, 9, 7, 103, NULL, 'Įtampos 39-os harmonikos koeficientas L1 fazėje', 2427, 6, NULL, NULL),
	(5123, 93, 0, 7, 43, 0, 9, 7, 106, NULL, 'Įtampos 39-os harmonikos koeficientas L2 fazėje', 2428, 6, NULL, NULL),
	(5124, 96, 0, 7, 43, 0, 9, 7, 109, NULL, 'Įtampos 39-os harmonikos koeficientas L3 fazėje', 2429, 6, NULL, NULL),
	(5125, 90, 0, 7, 44, 0, 9, 7, 103, NULL, 'Įtampos 40-os harmonikos koeficientas L1 fazėje', 2430, 6, NULL, NULL),
	(5126, 93, 0, 7, 44, 0, 9, 7, 106, NULL, 'Įtampos 40-os harmonikos koeficientas L2 fazėje', 2431, 6, NULL, NULL),
	(5127, 96, 0, 7, 44, 0, 9, 7, 109, NULL, 'Įtampos 40-os harmonikos koeficientas L3 fazėje', 2432, 6, NULL, NULL),
	(5128, 206, 0, 7, 6, 0, 9, 7, 218, NULL, 'Srovės 2-os harmonikos koeficientas L1 fazėje', 3179, 6, NULL, NULL),
	(5129, 207, 0, 7, 6, 0, 9, 7, 219, NULL, 'Srovės 2-os harmonikos koeficientas L2 fazėje', 3180, 6, NULL, NULL),
	(5130, 208, 0, 7, 6, 0, 9, 7, 220, NULL, 'Srovės 2-os harmonikos koeficientas L3 fazėje', 3181, 6, NULL, NULL),
	(5131, 206, 0, 7, 7, 0, 9, 7, 218, NULL, 'Srovės 3-os harmonikos koeficientas L1 fazėje', 3182, 6, NULL, NULL),
	(5132, 207, 0, 7, 7, 0, 9, 7, 219, NULL, 'Srovės 3-os harmonikos koeficientas L2 fazėje', 3183, 6, NULL, NULL),
	(5133, 208, 0, 7, 7, 0, 9, 7, 220, NULL, 'Srovės 3-os harmonikos koeficientas L3 fazėje', 3184, 6, NULL, NULL),
	(5134, 206, 0, 7, 8, 0, 9, 7, 218, NULL, 'Srovės 4-os harmonikos koeficientas L1 fazėje', 3185, 6, NULL, NULL),
	(5135, 207, 0, 7, 8, 0, 9, 7, 219, NULL, 'Srovės 4-os harmonikos koeficientas L2 fazėje', 3186, 6, NULL, NULL),
	(5136, 208, 0, 7, 8, 0, 9, 7, 220, NULL, 'Srovės 4-os harmonikos koeficientas L3 fazėje', 3187, 6, NULL, NULL),
	(5137, 206, 0, 7, 9, 0, 9, 7, 218, NULL, 'Srovės 5-os harmonikos koeficientas L1 fazėje', 3188, 6, NULL, NULL),
	(5138, 207, 0, 7, 9, 0, 9, 7, 219, NULL, 'Srovės 5-os harmonikos koeficientas L2 fazėje', 3189, 6, NULL, NULL),
	(5139, 208, 0, 7, 9, 0, 9, 7, 220, NULL, 'Srovės 5-os harmonikos koeficientas L3 fazėje', 3190, 6, NULL, NULL),
	(5140, 206, 0, 7, 10, 0, 9, 7, 218, NULL, 'Srovės 6-os harmonikos koeficientas L1 fazėje', 3191, 6, NULL, NULL),
	(5141, 207, 0, 7, 10, 0, 9, 7, 219, NULL, 'Srovės 6-os harmonikos koeficientas L2 fazėje', 3192, 6, NULL, NULL),
	(5142, 208, 0, 7, 10, 0, 9, 7, 220, NULL, 'Srovės 6-os harmonikos koeficientas L3 fazėje', 3193, 6, NULL, NULL),
	(5143, 206, 0, 7, 11, 0, 9, 7, 218, NULL, 'Srovės 7-os harmonikos koeficientas L1 fazėje', 3194, 6, NULL, NULL),
	(5144, 207, 0, 7, 11, 0, 9, 7, 219, NULL, 'Srovės 7-os harmonikos koeficientas L2 fazėje', 3195, 6, NULL, NULL),
	(5145, 208, 0, 7, 11, 0, 9, 7, 220, NULL, 'Srovės 7-os harmonikos koeficientas L3 fazėje', 3196, 6, NULL, NULL),
	(5146, 206, 0, 7, 12, 0, 9, 7, 218, NULL, 'Srovės 8-os harmonikos koeficientas L1 fazėje', 3197, 6, NULL, NULL),
	(5147, 207, 0, 7, 12, 0, 9, 7, 219, NULL, 'Srovės 8-os harmonikos koeficientas L2 fazėje', 3198, 6, NULL, NULL),
	(5148, 208, 0, 7, 12, 0, 9, 7, 220, NULL, 'Srovės 8-os harmonikos koeficientas L3 fazėje', 3199, 6, NULL, NULL),
	(5149, 206, 0, 7, 13, 0, 9, 7, 218, NULL, 'Srovės 9-os harmonikos koeficientas L1 fazėje', 3200, 6, NULL, NULL),
	(5150, 207, 0, 7, 13, 0, 9, 7, 219, NULL, 'Srovės 9-os harmonikos koeficientas L2 fazėje', 3201, 6, NULL, NULL),
	(5151, 208, 0, 7, 13, 0, 9, 7, 220, NULL, 'Srovės 9-os harmonikos koeficientas L3 fazėje', 3202, 6, NULL, NULL),
	(5152, 206, 0, 7, 14, 0, 9, 7, 218, NULL, 'Srovės 10-os harmonikos koeficientas L1 fazėje', 3203, 6, NULL, NULL),
	(5153, 207, 0, 7, 14, 0, 9, 7, 219, NULL, 'Srovės 10-os harmonikos koeficientas L2 fazėje', 3204, 6, NULL, NULL),
	(5154, 208, 0, 7, 14, 0, 9, 7, 220, NULL, 'Srovės 10-os harmonikos koeficientas L3 fazėje', 3205, 6, NULL, NULL),
	(5155, 206, 0, 7, 15, 0, 9, 7, 218, NULL, 'Srovės 11-os harmonikos koeficientas L1 fazėje', 3206, 6, NULL, NULL),
	(5156, 207, 0, 7, 15, 0, 9, 7, 219, NULL, 'Srovės 11-os harmonikos koeficientas L2 fazėje', 3207, 6, NULL, NULL),
	(5157, 208, 0, 7, 15, 0, 9, 7, 220, NULL, 'Srovės 11-os harmonikos koeficientas L3 fazėje', 3208, 6, NULL, NULL),
	(5158, 206, 0, 7, 16, 0, 9, 7, 218, NULL, 'Srovės 12-os harmonikos koeficientas L1 fazėje', 3209, 6, NULL, NULL),
	(5159, 207, 0, 7, 16, 0, 9, 7, 219, NULL, 'Srovės 12-os harmonikos koeficientas L2 fazėje', 3210, 6, NULL, NULL),
	(5160, 208, 0, 7, 16, 0, 9, 7, 220, NULL, 'Srovės 12-os harmonikos koeficientas L3 fazėje', 3211, 6, NULL, NULL),
	(5161, 206, 0, 7, 17, 0, 9, 7, 218, NULL, 'Srovės 13-os harmonikos koeficientas L1 fazėje', 3212, 6, NULL, NULL),
	(5162, 207, 0, 7, 17, 0, 9, 7, 219, NULL, 'Srovės 13-os harmonikos koeficientas L2 fazėje', 3213, 6, NULL, NULL),
	(5163, 208, 0, 7, 17, 0, 9, 7, 220, NULL, 'Srovės 13-os harmonikos koeficientas L3 fazėje', 3214, 6, NULL, NULL),
	(5164, 206, 0, 7, 18, 0, 9, 7, 218, NULL, 'Srovės 14-os harmonikos koeficientas L1 fazėje', 3215, 6, NULL, NULL),
	(5165, 207, 0, 7, 18, 0, 9, 7, 219, NULL, 'Srovės 14-os harmonikos koeficientas L2 fazėje', 3216, 6, NULL, NULL),
	(5166, 208, 0, 7, 18, 0, 9, 7, 220, NULL, 'Srovės 14-os harmonikos koeficientas L3 fazėje', 3217, 6, NULL, NULL),
	(5167, 206, 0, 7, 19, 0, 9, 7, 218, NULL, 'Srovės 15-os harmonikos koeficientas L1 fazėje', 3218, 6, NULL, NULL),
	(5168, 207, 0, 7, 19, 0, 9, 7, 219, NULL, 'Srovės 15-os harmonikos koeficientas L2 fazėje', 3219, 6, NULL, NULL),
	(5169, 208, 0, 7, 19, 0, 9, 7, 220, NULL, 'Srovės 15-os harmonikos koeficientas L3 fazėje', 3220, 6, NULL, NULL),
	(5170, 206, 0, 7, 20, 0, 9, 7, 218, NULL, 'Srovės 16-os harmonikos koeficientas L1 fazėje', 3221, 6, NULL, NULL),
	(5171, 207, 0, 7, 20, 0, 9, 7, 219, NULL, 'Srovės 16-os harmonikos koeficientas L2 fazėje', 3222, 6, NULL, NULL),
	(5172, 208, 0, 7, 20, 0, 9, 7, 220, NULL, 'Srovės 16-os harmonikos koeficientas L3 fazėje', 3223, 6, NULL, NULL),
	(5173, 206, 0, 7, 21, 0, 9, 7, 218, NULL, 'Srovės 17-os harmonikos koeficientas L1 fazėje', 3224, 6, NULL, NULL),
	(5174, 207, 0, 7, 21, 0, 9, 7, 219, NULL, 'Srovės 17-os harmonikos koeficientas L2 fazėje', 3225, 6, NULL, NULL),
	(5175, 208, 0, 7, 21, 0, 9, 7, 220, NULL, 'Srovės 17-os harmonikos koeficientas L3 fazėje', 3226, 6, NULL, NULL),
	(5176, 206, 0, 7, 22, 0, 9, 7, 218, NULL, 'Srovės 18-os harmonikos koeficientas L1 fazėje', 3227, 6, NULL, NULL),
	(5177, 207, 0, 7, 22, 0, 9, 7, 219, NULL, 'Srovės 18-os harmonikos koeficientas L2 fazėje', 3228, 6, NULL, NULL),
	(5178, 208, 0, 7, 22, 0, 9, 7, 220, NULL, 'Srovės 18-os harmonikos koeficientas L3 fazėje', 3229, 6, NULL, NULL),
	(5179, 206, 0, 7, 23, 0, 9, 7, 218, NULL, 'Srovės 19-os harmonikos koeficientas L1 fazėje', 3230, 6, NULL, NULL),
	(5180, 207, 0, 7, 23, 0, 9, 7, 219, NULL, 'Srovės 19-os harmonikos koeficientas L2 fazėje', 3231, 6, NULL, NULL),
	(5181, 208, 0, 7, 23, 0, 9, 7, 220, NULL, 'Srovės 19-os harmonikos koeficientas L3 fazėje', 3232, 6, NULL, NULL),
	(5182, 206, 0, 7, 24, 0, 9, 7, 218, NULL, 'Srovės 20-os harmonikos koeficientas L1 fazėje', 3233, 6, NULL, NULL),
	(5183, 207, 0, 7, 24, 0, 9, 7, 219, NULL, 'Srovės 20-os harmonikos koeficientas L2 fazėje', 3234, 6, NULL, NULL),
	(5184, 208, 0, 7, 24, 0, 9, 7, 220, NULL, 'Srovės 20-os harmonikos koeficientas L3 fazėje', 3235, 6, NULL, NULL),
	(5185, 206, 0, 7, 25, 0, 9, 7, 218, NULL, 'Srovės 21-os harmonikos koeficientas L1 fazėje', 3236, 6, NULL, NULL),
	(5186, 207, 0, 7, 25, 0, 9, 7, 219, NULL, 'Srovės 21-os harmonikos koeficientas L2 fazėje', 3237, 6, NULL, NULL),
	(5187, 208, 0, 7, 25, 0, 9, 7, 220, NULL, 'Srovės 21-os harmonikos koeficientas L3 fazėje', 3238, 6, NULL, NULL),
	(5188, 206, 0, 7, 26, 0, 9, 7, 218, NULL, 'Srovės 22-os harmonikos koeficientas L1 fazėje', 3239, 6, NULL, NULL),
	(5189, 207, 0, 7, 26, 0, 9, 7, 219, NULL, 'Srovės 22-os harmonikos koeficientas L2 fazėje', 3240, 6, NULL, NULL),
	(5190, 208, 0, 7, 26, 0, 9, 7, 220, NULL, 'Srovės 22-os harmonikos koeficientas L3 fazėje', 3241, 6, NULL, NULL),
	(5191, 206, 0, 7, 27, 0, 9, 7, 218, NULL, 'Srovės 23-os harmonikos koeficientas L1 fazėje', 3242, 6, NULL, NULL),
	(5192, 207, 0, 7, 27, 0, 9, 7, 219, NULL, 'Srovės 23-os harmonikos koeficientas L2 fazėje', 3243, 6, NULL, NULL),
	(5193, 208, 0, 7, 27, 0, 9, 7, 220, NULL, 'Srovės 23-os harmonikos koeficientas L3 fazėje', 3244, 6, NULL, NULL),
	(5194, 206, 0, 7, 28, 0, 9, 7, 218, NULL, 'Srovės 24-os harmonikos koeficientas L1 fazėje', 3245, 6, NULL, NULL),
	(5195, 207, 0, 7, 28, 0, 9, 7, 219, NULL, 'Srovės 24-os harmonikos koeficientas L2 fazėje', 3246, 6, NULL, NULL),
	(5196, 208, 0, 7, 28, 0, 9, 7, 220, NULL, 'Srovės 24-os harmonikos koeficientas L3 fazėje', 3247, 6, NULL, NULL),
	(5197, 206, 0, 7, 29, 0, 9, 7, 218, NULL, 'Srovės 25-os harmonikos koeficientas L1 fazėje', 3248, 6, NULL, NULL),
	(5198, 207, 0, 7, 29, 0, 9, 7, 219, NULL, 'Srovės 25-os harmonikos koeficientas L2 fazėje', 3249, 6, NULL, NULL),
	(5199, 208, 0, 7, 29, 0, 9, 7, 220, NULL, 'Srovės 25-os harmonikos koeficientas L3 fazėje', 3250, 6, NULL, NULL),
	(5200, 206, 0, 7, 30, 0, 9, 7, 218, NULL, 'Srovės 26-os harmonikos koeficientas L1 fazėje', 3251, 6, NULL, NULL),
	(5201, 207, 0, 7, 30, 0, 9, 7, 219, NULL, 'Srovės 26-os harmonikos koeficientas L2 fazėje', 3252, 6, NULL, NULL),
	(5202, 208, 0, 7, 30, 0, 9, 7, 220, NULL, 'Srovės 26-os harmonikos koeficientas L3 fazėje', 3253, 6, NULL, NULL),
	(5203, 206, 0, 7, 31, 0, 9, 7, 218, NULL, 'Srovės 27-os harmonikos koeficientas L1 fazėje', 3254, 6, NULL, NULL),
	(5204, 207, 0, 7, 31, 0, 9, 7, 219, NULL, 'Srovės 27-os harmonikos koeficientas L2 fazėje', 3255, 6, NULL, NULL),
	(5205, 208, 0, 7, 31, 0, 9, 7, 220, NULL, 'Srovės 27-os harmonikos koeficientas L3 fazėje', 3256, 6, NULL, NULL),
	(5206, 206, 0, 7, 32, 0, 9, 7, 218, NULL, 'Srovės 28-os harmonikos koeficientas L1 fazėje', 3257, 6, NULL, NULL),
	(5207, 207, 0, 7, 32, 0, 9, 7, 219, NULL, 'Srovės 28-os harmonikos koeficientas L2 fazėje', 3258, 6, NULL, NULL),
	(5208, 208, 0, 7, 32, 0, 9, 7, 220, NULL, 'Srovės 28-os harmonikos koeficientas L3 fazėje', 3259, 6, NULL, NULL),
	(5209, 206, 0, 7, 33, 0, 9, 7, 218, NULL, 'Srovės 29-os harmonikos koeficientas L1 fazėje', 3260, 6, NULL, NULL),
	(5210, 207, 0, 7, 33, 0, 9, 7, 219, NULL, 'Srovės 29-os harmonikos koeficientas L2 fazėje', 3261, 6, NULL, NULL),
	(5211, 208, 0, 7, 33, 0, 9, 7, 220, NULL, 'Srovės 29-os harmonikos koeficientas L3 fazėje', 3262, 6, NULL, NULL),
	(5212, 206, 0, 7, 34, 0, 9, 7, 218, NULL, 'Srovės 30-os harmonikos koeficientas L1 fazėje', 3263, 6, NULL, NULL),
	(5213, 207, 0, 7, 34, 0, 9, 7, 219, NULL, 'Srovės 30-os harmonikos koeficientas L2 fazėje', 3264, 6, NULL, NULL),
	(5214, 208, 0, 7, 34, 0, 9, 7, 220, NULL, 'Srovės 30-os harmonikos koeficientas L3 fazėje', 3265, 6, NULL, NULL),
	(5215, 206, 0, 7, 35, 0, 9, 7, 218, NULL, 'Srovės 31-os harmonikos koeficientas L1 fazėje', 3266, 6, NULL, NULL),
	(5216, 207, 0, 7, 35, 0, 9, 7, 219, NULL, 'Srovės 31-os harmonikos koeficientas L2 fazėje', 3267, 6, NULL, NULL),
	(5217, 208, 0, 7, 35, 0, 9, 7, 220, NULL, 'Srovės 31-os harmonikos koeficientas L3 fazėje', 3268, 6, NULL, NULL),
	(5218, 206, 0, 7, 36, 0, 9, 7, 218, NULL, 'Srovės 32-os harmonikos koeficientas L1 fazėje', 3269, 6, NULL, NULL),
	(5219, 207, 0, 7, 36, 0, 9, 7, 219, NULL, 'Srovės 32-os harmonikos koeficientas L2 fazėje', 3270, 6, NULL, NULL),
	(5220, 208, 0, 7, 36, 0, 9, 7, 220, NULL, 'Srovės 32-os harmonikos koeficientas L3 fazėje', 3271, 6, NULL, NULL),
	(5221, 206, 0, 7, 37, 0, 9, 7, 218, NULL, 'Srovės 33-os harmonikos koeficientas L1 fazėje', 3272, 6, NULL, NULL),
	(5222, 207, 0, 7, 37, 0, 9, 7, 219, NULL, 'Srovės 33-os harmonikos koeficientas L2 fazėje', 3273, 6, NULL, NULL),
	(5223, 208, 0, 7, 37, 0, 9, 7, 220, NULL, 'Srovės 33-os harmonikos koeficientas L3 fazėje', 3274, 6, NULL, NULL),
	(5224, 206, 0, 7, 38, 0, 9, 7, 218, NULL, 'Srovės 34-os harmonikos koeficientas L1 fazėje', 3275, 6, NULL, NULL),
	(5225, 207, 0, 7, 38, 0, 9, 7, 219, NULL, 'Srovės 34-os harmonikos koeficientas L2 fazėje', 3276, 6, NULL, NULL),
	(5226, 208, 0, 7, 38, 0, 9, 7, 220, NULL, 'Srovės 34-os harmonikos koeficientas L3 fazėje', 3277, 6, NULL, NULL),
	(5227, 206, 0, 7, 39, 0, 9, 7, 218, NULL, 'Srovės 35-os harmonikos koeficientas L1 fazėje', 3278, 6, NULL, NULL),
	(5228, 207, 0, 7, 39, 0, 9, 7, 219, NULL, 'Srovės 35-os harmonikos koeficientas L2 fazėje', 3279, 6, NULL, NULL),
	(5229, 208, 0, 7, 39, 0, 9, 7, 220, NULL, 'Srovės 35-os harmonikos koeficientas L3 fazėje', 3280, 6, NULL, NULL),
	(5230, 206, 0, 7, 40, 0, 9, 7, 218, NULL, 'Srovės 36-os harmonikos koeficientas L1 fazėje', 3281, 6, NULL, NULL),
	(5231, 207, 0, 7, 40, 0, 9, 7, 219, NULL, 'Srovės 36-os harmonikos koeficientas L2 fazėje', 3282, 6, NULL, NULL),
	(5232, 208, 0, 7, 40, 0, 9, 7, 220, NULL, 'Srovės 36-os harmonikos koeficientas L3 fazėje', 3283, 6, NULL, NULL),
	(5233, 206, 0, 7, 41, 0, 9, 7, 218, NULL, 'Srovės 37-os harmonikos koeficientas L1 fazėje', 3284, 6, NULL, NULL),
	(5234, 207, 0, 7, 41, 0, 9, 7, 219, NULL, 'Srovės 37-os harmonikos koeficientas L2 fazėje', 3285, 6, NULL, NULL),
	(5235, 208, 0, 7, 41, 0, 9, 7, 220, NULL, 'Srovės 37-os harmonikos koeficientas L3 fazėje', 3286, 6, NULL, NULL),
	(5236, 206, 0, 7, 42, 0, 9, 7, 218, NULL, 'Srovės 38-os harmonikos koeficientas L1 fazėje', 3287, 6, NULL, NULL),
	(5237, 207, 0, 7, 42, 0, 9, 7, 219, NULL, 'Srovės 38-os harmonikos koeficientas L2 fazėje', 3288, 6, NULL, NULL),
	(5238, 208, 0, 7, 42, 0, 9, 7, 220, NULL, 'Srovės 38-os harmonikos koeficientas L3 fazėje', 3289, 6, NULL, NULL),
	(5239, 206, 0, 7, 43, 0, 9, 7, 218, NULL, 'Srovės 39-os harmonikos koeficientas L1 fazėje', 3290, 6, NULL, NULL),
	(5240, 207, 0, 7, 43, 0, 9, 7, 219, NULL, 'Srovės 39-os harmonikos koeficientas L2 fazėje', 3291, 6, NULL, NULL),
	(5241, 208, 0, 7, 43, 0, 9, 7, 220, NULL, 'Srovės 39-os harmonikos koeficientas L3 fazėje', 3292, 6, NULL, NULL),
	(5242, 206, 0, 7, 44, 0, 9, 7, 218, NULL, 'Srovės 40-os harmonikos koeficientas L1 fazėje', 3293, 6, NULL, NULL),
	(5243, 207, 0, 7, 44, 0, 9, 7, 219, NULL, 'Srovės 40-os harmonikos koeficientas L2 fazėje', 3294, 6, NULL, NULL),
	(5244, 208, 0, 7, 44, 0, 9, 7, 220, NULL, 'Srovės 40-os harmonikos koeficientas L3 fazėje', 3295, 6, NULL, NULL),
	(5245, 209, 0, 4, 3, 0, 1, 4, 221, NULL, 'Vidutinė šilumnešio pilnoji šilumos galia per valandą', NULL, 2, NULL, NULL),
	(5246, 209, 0, 5, 2, 0, 2, 5, 222, NULL, 'Šilumnešio pilnosios šilumos kiekis per parą', 1089, 3, NULL, NULL),
	(5247, 209, 0, 5, 3, 0, 1, 5, 221, NULL, 'Vidutinė šilumnešio pilnoji šilumos galia per parą', NULL, 3, NULL, NULL),
	(5248, 209, 0, 6, 2, 0, 2, 6, 222, NULL, 'Šilumnešio pilnosios šilumos kiekis per mėnesį', 1089, 4, NULL, NULL),
	(5249, 209, 0, 6, 3, 0, 1, 6, 221, NULL, 'Vidutinė šilumnešio pilnoji šilumos galia per mėnesį', NULL, 4, NULL, NULL),
	(5250, 209, 0, 7, 1, 0, 1, 7, 221, NULL, 'Momentinė šilumnešio pilnoji šilumos galia', NULL, 6, NULL, NULL),
	(5251, 209, 0, 1, 2, 0, 2, 1, 222, NULL, 'Šilumnešio pilnosios šilumos kiekis per minutę', 1089, 1, NULL, NULL),
	(5252, 209, 0, 1, 3, 0, 1, 1, 221, NULL, 'Vidutinė šilumnešio pilnoji šilumos galia per minutę', NULL, 1, NULL, NULL),
	(5253, 209, 0, 2, 2, 0, 2, 2, 222, NULL, 'Šilumnešio pilnosios šilumos kiekis per 2 minutes', 1089, 1, NULL, NULL),
	(5254, 209, 0, 2, 3, 0, 1, 2, 221, NULL, 'Vidutinė šilumnešio pilnoji šilumos galia per 2 minutes', NULL, 1, NULL, NULL),
	(5255, 209, 0, 9, 2, 0, 2, 8, 222, NULL, 'Šilumnešio pilnosios šilumos kiekis per 3 minutes', 1089, 1, NULL, NULL),
	(5256, 209, 0, 9, 3, 0, 1, 8, 221, NULL, 'Vidutinė šilumnešio pilnoji šilumos galia per 3 minutes', NULL, 1, NULL, NULL),
	(5257, 209, 0, 10, 2, 0, 2, 9, 222, NULL, 'Šilumnešio pilnosios šilumos kiekis per 4 minutes', 1089, 1, NULL, NULL),
	(5258, 209, 0, 10, 3, 0, 1, 9, 221, NULL, 'Vidutinė šilumnešio pilnoji šilumos galia per 4 minutes', NULL, 1, NULL, NULL),
	(5259, 209, 0, 11, 2, 0, 2, 10, 222, NULL, 'Šilumnešio pilnosios šilumos kiekis per 5 minutes', 1089, 1, NULL, NULL),
	(5260, 209, 0, 11, 3, 0, 1, 10, 221, NULL, 'Vidutinė šilumnešio pilnoji šilumos galia per 5 minutes', NULL, 1, NULL, NULL),
	(5261, 209, 0, 12, 2, 0, 2, 11, 222, NULL, 'Šilumnešio pilnosios šilumos kiekis per 10 minučių', 1089, 1, NULL, NULL),
	(5262, 209, 0, 12, 3, 0, 1, 11, 221, NULL, 'Vidutinė šilumnešio pilnoji šilumos galia per 10 minučių', NULL, 1, NULL, NULL),
	(5263, 209, 0, 13, 2, 0, 2, 12, 222, NULL, 'Šilumnešio pilnosios šilumos kiekis per 15 minučių', 1089, 2, NULL, NULL),
	(5264, 209, 0, 13, 3, 0, 1, 12, 221, NULL, 'Vidutinė šilumnešio pilnoji šilumos galia per 15 minučių', NULL, 2, NULL, NULL),
	(5265, 209, 0, 14, 2, 0, 2, 13, 222, NULL, 'Šilumnešio pilnosios šilumos kiekis per 20 minučių', 1089, 2, NULL, NULL),
	(5266, 209, 0, 14, 3, 0, 1, 13, 221, NULL, 'Vidutinė šilumnešio pilnoji šilumos galia per 20 minučių', NULL, 2, NULL, NULL),
	(5267, 209, 0, 3, 2, 0, 2, 3, 222, NULL, 'Šilumnešio pilnosios šilumos kiekis per 30 minučių', 1089, 2, NULL, NULL),
	(5268, 209, 0, 3, 3, 0, 1, 3, 221, NULL, 'Vidutinė šilumnešio pilnoji šilumos galia per 30 minučių', NULL, 2, NULL, NULL),
	(5269, 209, 0, 4, 2, 0, 2, 4, 222, NULL, 'Šilumnešio pilnosios šilumos kiekis per valandą', 1089, 2, NULL, NULL),
	(5270, 210, 0, 4, 3, 0, 9, 4, 223, NULL, 'Šilumnešio masės nuostoliai per valandą', NULL, 2, NULL, NULL),
	(5271, 210, 0, 5, 3, 0, 9, 5, 223, NULL, 'Šilumnešio masės nuostoliai per parą', NULL, 3, NULL, NULL),
	(5272, 210, 0, 6, 3, 0, 9, 6, 223, NULL, 'Šilumnešio masės nuostoliai per mėnesį', NULL, 4, NULL, NULL),
	(5273, 210, 0, 1, 3, 0, 9, 1, 223, NULL, 'Šilumnešio masės nuostoliai per minutę', NULL, 1, NULL, NULL),
	(5274, 210, 0, 2, 3, 0, 9, 2, 223, NULL, 'Šilumnešio masės nuostoliai per 2 minutes', NULL, 1, NULL, NULL),
	(5275, 210, 0, 9, 3, 0, 9, 8, 223, NULL, 'Šilumnešio masės nuostoliai per 3 minutes', NULL, 1, NULL, NULL),
	(5276, 210, 0, 10, 3, 0, 9, 9, 223, NULL, 'Šilumnešio masės nuostoliai per 4 minutes', NULL, 1, NULL, NULL),
	(5277, 210, 0, 11, 3, 0, 9, 10, 223, NULL, 'Šilumnešio masės nuostoliai per 5 minutes', NULL, 1, NULL, NULL),
	(5278, 210, 0, 12, 3, 0, 9, 11, 223, NULL, 'Šilumnešio masės nuostoliai per 10 minučių', NULL, 1, NULL, NULL),
	(5279, 210, 0, 13, 3, 0, 9, 12, 223, NULL, 'Šilumnešio masės nuostoliai per 15 minučių', NULL, 2, NULL, NULL),
	(5280, 210, 0, 14, 3, 0, 9, 13, 223, NULL, 'Šilumnešio masės nuostoliai per 20 minučių', NULL, 2, NULL, NULL),
	(5281, 210, 0, 3, 3, 0, 9, 3, 223, NULL, 'Šilumnešio masės nuostoliai per 30 minučių', NULL, 2, NULL, NULL),
	(5282, 211, 0, 4, 3, 0, 9, 4, 224, NULL, 'Šilumnešio tūrio nuostoliai per valandą', NULL, 2, NULL, NULL),
	(5283, 211, 0, 5, 3, 0, 9, 5, 224, NULL, 'Šilumnešio tūrio nuostoliai per parą', NULL, 3, NULL, NULL),
	(5284, 211, 0, 6, 3, 0, 9, 6, 224, NULL, 'Šilumnešio tūrio nuostoliai per mėnesį', NULL, 4, NULL, NULL),
	(5285, 211, 0, 1, 3, 0, 9, 1, 224, NULL, 'Šilumnešio tūrio nuostoliai per minutę', NULL, 1, NULL, NULL),
	(5286, 211, 0, 2, 3, 0, 9, 2, 224, NULL, 'Šilumnešio tūrio nuostoliai per 2 minutes', NULL, 1, NULL, NULL),
	(5287, 211, 0, 9, 3, 0, 9, 8, 224, NULL, 'Šilumnešio tūrio nuostoliai per 3 minutes', NULL, 1, NULL, NULL),
	(5288, 211, 0, 10, 3, 0, 9, 9, 224, NULL, 'Šilumnešio tūrio nuostoliai per 4 minutes', NULL, 1, NULL, NULL),
	(5289, 211, 0, 11, 3, 0, 9, 10, 224, NULL, 'Šilumnešio tūrio nuostoliai per 5 minutes', NULL, 1, NULL, NULL),
	(5290, 211, 0, 12, 3, 0, 9, 11, 224, NULL, 'Šilumnešio tūrio nuostoliai per 10 minučių', NULL, 1, NULL, NULL),
	(5291, 211, 0, 13, 3, 0, 9, 12, 224, NULL, 'Šilumnešio tūrio nuostoliai per 15 minučių', NULL, 2, NULL, NULL),
	(5292, 211, 0, 14, 3, 0, 9, 13, 224, NULL, 'Šilumnešio tūrio nuostoliai per 20 minučių', NULL, 2, NULL, NULL),
	(5293, 211, 0, 3, 3, 0, 9, 3, 224, NULL, 'Šilumnešio tūrio nuostoliai per 30 minučių', NULL, 2, NULL, NULL),
	(5294, 3, -1, 8, 2, 0, 4, 7, 15, NULL, 'Suminė talpuminė R energija', 3159, 5, NULL, NULL),
	(5295, 3, -1, 8, 2, 0, 4, 5, 15, NULL, 'Suminė talpuminė R energija, fiksuojama kas parą', 3159, 5, NULL, NULL),
	(5296, 3, -1, 8, 2, 0, 4, 6, 15, NULL, 'Suminė talpuminė R energija, fiksuojama kas mėnesį', 3159, 5, NULL, NULL),
	(5297, 3, -1, 8, 2, 0, 4, 3, 15, NULL, 'Suminė talpuminė R energija, fiksuojama kas 30 minučių', 3159, 5, NULL, NULL),
	(5298, 3, -1, 8, 2, 0, 4, 13, 15, NULL, 'Suminė talpuminė R energija, fiksuojama kas 20 minučių', 3159, 5, NULL, NULL),
	(5299, 3, -1, 8, 2, 0, 4, 4, 15, NULL, 'Suminė talpuminė R energija, fiksuojama kas valandą', 3159, 5, NULL, NULL),
	(5300, 3, -1, 8, 2, 0, 4, 12, 15, NULL, 'Suminė talpuminė R energija, fiksuojama kas 15 minučių', 3159, 5, NULL, NULL),
	(5301, 3, 9, 8, 2, 0, 4, 7, 15, NULL, 'Suminė indukcinė R energija', 3158, 5, NULL, NULL),
	(5302, 3, 9, 8, 2, 0, 4, 5, 15, NULL, 'Suminė indukcinė R energija, fiksuojama kas parą', 3158, 5, NULL, NULL),
	(5303, 3, 9, 8, 2, 0, 4, 6, 15, NULL, 'Suminė indukcinė R energija, fiksuojama kas mėnesį', 3158, 5, NULL, NULL),
	(5304, 3, 9, 8, 2, 0, 4, 3, 15, NULL, 'Suminė indukcinė R energija, fiksuojama kas 30 minučių', 3158, 5, NULL, NULL),
	(5305, 3, 9, 8, 2, 0, 4, 13, 15, NULL, 'Suminė indukcinė R energija, fiksuojama kas 20 minučių', 3158, 5, NULL, NULL),
	(5306, 3, 9, 8, 2, 0, 4, 4, 15, NULL, 'Suminė indukcinė R energija, fiksuojama kas valandą', 3158, 5, NULL, NULL),
	(5307, 3, 9, 8, 2, 0, 4, 12, 15, NULL, 'Suminė indukcinė R energija, fiksuojama kas 15 minučių', 3158, 5, NULL, NULL),
	(5308, 212, 0, 7, 4, 0, 6, 4, 225, NULL, 'Maksimali momentinė įtampa tarp L1 ir L2 fazių per valandą', 460, 2, NULL, NULL),
	(5309, 212, 0, 7, 4, 0, 6, 5, 225, NULL, 'Maksimali momentinė įtampa tarp L1 ir L2 fazių per parą', 460, 3, NULL, NULL),
	(5310, 212, 0, 7, 4, 0, 6, 6, 225, NULL, 'Maksimali momentinė įtampa tarp L1 ir L2 fazių per mėnesį', 460, 4, NULL, NULL),
	(5311, 212, 0, 7, 5, 0, 6, 4, 225, NULL, 'Minimali momentinė įtampa tarp L1 ir L2 fazių per valandą', 507, 2, NULL, NULL),
	(5312, 212, 0, 7, 5, 0, 6, 5, 225, NULL, 'Minimali momentinė įtampa tarp L1 ir L2 fazių per parą', 507, 3, NULL, NULL),
	(5313, 212, 0, 7, 5, 0, 6, 6, 225, NULL, 'Minimali momentinė įtampa tarp L1 ir L2 fazių per mėnesį', 507, 4, NULL, NULL),
	(5314, 213, 0, 7, 4, 0, 6, 4, 226, NULL, 'Maksimali momentinė įtampa tarp L1 ir L3 fazių per valandą', 461, 2, NULL, NULL),
	(5315, 213, 0, 7, 4, 0, 6, 5, 226, NULL, 'Maksimali momentinė įtampa tarp L1 ir L3 fazių per parą', 461, 3, NULL, NULL),
	(5316, 213, 0, 7, 4, 0, 6, 6, 226, NULL, 'Maksimali momentinė įtampa tarp L1 ir L3 fazių per mėnesį', 461, 4, NULL, NULL),
	(5317, 213, 0, 7, 5, 0, 6, 4, 226, NULL, 'Minimali momentinė įtampa tarp L1 ir L3 fazių per valandą', 508, 2, NULL, NULL),
	(5318, 213, 0, 7, 5, 0, 6, 5, 226, NULL, 'Minimali momentinė įtampa tarp L1 ir L3 fazių per parą', 508, 3, NULL, NULL),
	(5319, 213, 0, 7, 5, 0, 6, 6, 226, NULL, 'Minimali momentinė įtampa tarp L1 ir L3 fazių per mėnesį', 508, 4, NULL, NULL),
	(5320, 214, 0, 7, 4, 0, 6, 4, 227, NULL, 'Maksimali momentinė įtampa tarp L2 ir L3 fazių per valandą', 462, 2, NULL, NULL),
	(5321, 214, 0, 7, 4, 0, 6, 5, 227, NULL, 'Maksimali momentinė įtampa tarp L2 ir L3 fazių per parą', 462, 3, NULL, NULL),
	(5322, 214, 0, 7, 4, 0, 6, 6, 227, NULL, 'Maksimali momentinė įtampa tarp L2 ir L3 fazių per mėnesį', 462, 4, NULL, NULL),
	(5323, 214, 0, 7, 5, 0, 6, 4, 227, NULL, 'Minimali momentinė įtampa tarp L2 ir L3 fazių per valandą', 509, 2, NULL, NULL),
	(5324, 214, 0, 7, 5, 0, 6, 5, 227, NULL, 'Minimali momentinė įtampa tarp L2 ir L3 fazių per parą', 509, 3, NULL, NULL),
	(5325, 214, 0, 7, 5, 0, 6, 6, 227, NULL, 'Minimali momentinė įtampa tarp L2 ir L3 fazių per mėnesį', 509, 4, NULL, NULL),
	(5326, 6, 0, 3, 3, 0, 6, 3, 18, NULL, 'Vidutinė įtampa L1 fazėje per 30 minučių', 670, 2, NULL, NULL),
	(5327, 6, 0, 4, 3, 0, 6, 4, 18, NULL, 'Vidutinė įtampa L1 fazėje per valandą', 670, 2, NULL, NULL),
	(5328, 6, 0, 1, 3, 0, 6, 1, 18, NULL, 'Vidutinė įtampa L1 fazėje per minutę', 670, 1, NULL, NULL),
	(5329, 6, 0, 2, 3, 0, 6, 2, 18, NULL, 'Vidutinė įtampa L1 fazėje per 2 minutes', 670, 1, NULL, NULL),
	(5330, 6, 0, 9, 3, 0, 6, 8, 18, NULL, 'Vidutinė įtampa L1 fazėje per 3 minutes', 670, 1, NULL, NULL),
	(5331, 6, 0, 12, 3, 0, 6, 11, 18, NULL, 'Vidutinė įtampa L1 fazėje per 10 minučių', 670, 1, NULL, NULL),
	(5332, 6, 0, 5, 3, 0, 6, 5, 18, NULL, 'Vidutinė įtampa L1 fazėje per parą', 670, 3, NULL, NULL),
	(5333, 6, 0, 11, 3, 0, 6, 10, 18, NULL, 'Vidutinė įtampa L1 fazėje per 5 minutes', 670, 1, NULL, NULL),
	(5334, 6, 0, 10, 3, 0, 6, 9, 18, NULL, 'Vidutinė įtampa L1 fazėje per 4 minutes', 670, 1, NULL, NULL),
	(5335, 6, 0, 13, 3, 0, 6, 12, 18, NULL, 'Vidutinė įtampa L1 fazėje per 15 minučių', 670, 2, NULL, NULL),
	(5336, 6, 0, 14, 3, 0, 6, 13, 18, NULL, 'Vidutinė įtampa L1 fazėje per 20 minučių', 670, 2, NULL, NULL),
	(5337, 8, 0, 3, 3, 0, 6, 3, 20, NULL, 'Vidutinė įtampa L2 fazėje per 30 minučių', 671, 2, NULL, NULL),
	(5338, 8, 0, 4, 3, 0, 6, 4, 20, NULL, 'Vidutinė įtampa L2 fazėje per valandą', 671, 2, NULL, NULL),
	(5339, 8, 0, 1, 3, 0, 6, 1, 20, NULL, 'Vidutinė įtampa L2 fazėje per minutę', 671, 1, NULL, NULL),
	(5340, 8, 0, 2, 3, 0, 6, 2, 20, NULL, 'Vidutinė įtampa L2 fazėje per 2 minutes', 671, 1, NULL, NULL),
	(5341, 8, 0, 9, 3, 0, 6, 8, 20, NULL, 'Vidutinė įtampa L2 fazėje per 3 minutes', 671, 1, NULL, NULL),
	(5342, 8, 0, 12, 3, 0, 6, 11, 20, NULL, 'Vidutinė įtampa L2 fazėje per 10 minučių', 671, 1, NULL, NULL),
	(5343, 8, 0, 5, 3, 0, 6, 5, 20, NULL, 'Vidutinė įtampa L2 fazėje per parą', 671, 3, NULL, NULL),
	(5344, 8, 0, 11, 3, 0, 6, 10, 20, NULL, 'Vidutinė įtampa L2 fazėje per 5 minutes', 671, 1, NULL, NULL),
	(5345, 8, 0, 10, 3, 0, 6, 9, 20, NULL, 'Vidutinė įtampa L2 fazėje per 4 minutes', 671, 1, NULL, NULL),
	(5346, 8, 0, 13, 3, 0, 6, 12, 20, NULL, 'Vidutinė įtampa L2 fazėje per 15 minučių', 671, 2, NULL, NULL),
	(5347, 8, 0, 14, 3, 0, 6, 13, 20, NULL, 'Vidutinė įtampa L2 fazėje per 20 minučių', 671, 2, NULL, NULL),
	(5348, 10, 0, 3, 3, 0, 6, 3, 22, NULL, 'Vidutinė įtampa L3 fazėje per 30 minučių', 672, 2, NULL, NULL),
	(5349, 10, 0, 4, 3, 0, 6, 4, 22, NULL, 'Vidutinė įtampa L3 fazėje per valandą', 672, 2, NULL, NULL),
	(5350, 10, 0, 1, 3, 0, 6, 1, 22, NULL, 'Vidutinė įtampa L3 fazėje per minutę', 672, 1, NULL, NULL),
	(5351, 10, 0, 2, 3, 0, 6, 2, 22, NULL, 'Vidutinė įtampa L3 fazėje per 2 minutes', 672, 1, NULL, NULL),
	(5352, 10, 0, 9, 3, 0, 6, 8, 22, NULL, 'Vidutinė įtampa L3 fazėje per 3 minutes', 672, 1, NULL, NULL),
	(5353, 10, 0, 12, 3, 0, 6, 11, 22, NULL, 'Vidutinė įtampa L3 fazėje per 10 minučių', 672, 1, NULL, NULL),
	(5354, 10, 0, 5, 3, 0, 6, 5, 22, NULL, 'Vidutinė įtampa L3 fazėje per parą', 672, 3, NULL, NULL),
	(5355, 10, 0, 11, 3, 0, 6, 10, 22, NULL, 'Vidutinė įtampa L3 fazėje per 5 minutes', 672, 1, NULL, NULL),
	(5356, 10, 0, 10, 3, 0, 6, 9, 22, NULL, 'Vidutinė įtampa L3 fazėje per 4 minutes', 672, 1, NULL, NULL),
	(5357, 10, 0, 13, 3, 0, 6, 12, 22, NULL, 'Vidutinė įtampa L3 fazėje per 15 minučių', 672, 2, NULL, NULL),
	(5358, 10, 0, 14, 3, 0, 6, 13, 22, NULL, 'Vidutinė įtampa L3 fazėje per 20 minučių', 672, 2, NULL, NULL),
	(5359, 11, 0, 3, 3, 0, 6, 3, 23, NULL, 'Vidutinė linijinė įtampa L1 fazėje per 30 minučių', 673, 2, NULL, NULL),
	(5360, 11, 0, 4, 3, 0, 6, 4, 23, NULL, 'Vidutinė linijinė įtampa L1 fazėje per valandą', 673, 2, NULL, NULL),
	(5361, 11, 0, 1, 3, 0, 6, 1, 23, NULL, 'Vidutinė linijinė įtampa L1 fazėje per minutę', 673, 1, NULL, NULL),
	(5362, 11, 0, 2, 3, 0, 6, 2, 23, NULL, 'Vidutinė linijinė įtampa L1 fazėje per 2 minutes', 673, 1, NULL, NULL),
	(5363, 11, 0, 9, 3, 0, 6, 8, 23, NULL, 'Vidutinė linijinė įtampa L1 fazėje per 3 minutes', 673, 1, NULL, NULL),
	(5364, 11, 0, 12, 3, 0, 6, 11, 23, NULL, 'Vidutinė linijinė įtampa L1 fazėje per 10 minučių', 673, 1, NULL, NULL),
	(5365, 11, 0, 5, 3, 0, 6, 5, 23, NULL, 'Vidutinė linijinė įtampa L1 fazėje per parą', 673, 3, NULL, NULL),
	(5366, 11, 0, 11, 3, 0, 6, 10, 23, NULL, 'Vidutinė linijinė įtampa L1 fazėje per 5 minutes', 673, 1, NULL, NULL),
	(5367, 11, 0, 10, 3, 0, 6, 9, 23, NULL, 'Vidutinė linijinė įtampa L1 fazėje per 4 minutes', 673, 1, NULL, NULL),
	(5368, 11, 0, 13, 3, 0, 6, 12, 23, NULL, 'Vidutinė linijinė įtampa L1 fazėje per 15 minučių', 673, 2, NULL, NULL),
	(5369, 11, 0, 14, 3, 0, 6, 13, 23, NULL, 'Vidutinė linijinė įtampa L1 fazėje per 20 minučių', 673, 2, NULL, NULL),
	(5370, 12, 0, 3, 3, 0, 6, 3, 24, NULL, 'Vidutinė linijinė įtampa L2 fazėje per 30 minučių', 674, 2, NULL, NULL),
	(5371, 12, 0, 4, 3, 0, 6, 4, 24, NULL, 'Vidutinė linijinė įtampa L2 fazėje per valandą', 674, 2, NULL, NULL),
	(5372, 12, 0, 1, 3, 0, 6, 1, 24, NULL, 'Vidutinė linijinė įtampa L2 fazėje per minutę', 674, 1, NULL, NULL),
	(5373, 12, 0, 2, 3, 0, 6, 2, 24, NULL, 'Vidutinė linijinė įtampa L2 fazėje per 2 minutes', 674, 1, NULL, NULL),
	(5374, 12, 0, 9, 3, 0, 6, 8, 24, NULL, 'Vidutinė linijinė įtampa L2 fazėje per 3 minutes', 674, 1, NULL, NULL),
	(5375, 12, 0, 12, 3, 0, 6, 11, 24, NULL, 'Vidutinė linijinė įtampa L2 fazėje per 10 minučių', 674, 1, NULL, NULL),
	(5376, 12, 0, 5, 3, 0, 6, 5, 24, NULL, 'Vidutinė linijinė įtampa L2 fazėje per parą', 674, 3, NULL, NULL),
	(5377, 12, 0, 11, 3, 0, 6, 10, 24, NULL, 'Vidutinė linijinė įtampa L2 fazėje per 5 minutes', 674, 1, NULL, NULL),
	(5378, 12, 0, 10, 3, 0, 6, 9, 24, NULL, 'Vidutinė linijinė įtampa L2 fazėje per 4 minutes', 674, 1, NULL, NULL),
	(5379, 12, 0, 13, 3, 0, 6, 12, 24, NULL, 'Vidutinė linijinė įtampa L2 fazėje per 15 minučių', 674, 2, NULL, NULL),
	(5380, 12, 0, 14, 3, 0, 6, 13, 24, NULL, 'Vidutinė linijinė įtampa L2 fazėje per 20 minučių', 674, 2, NULL, NULL),
	(5381, 13, 0, 3, 3, 0, 6, 3, 25, NULL, 'Vidutinė linijinė įtampa L3 fazėje per 30 minučių', 675, 2, NULL, NULL),
	(5382, 13, 0, 4, 3, 0, 6, 4, 25, NULL, 'Vidutinė linijinė įtampa L3 fazėje per valandą', 675, 2, NULL, NULL),
	(5383, 13, 0, 1, 3, 0, 6, 1, 25, NULL, 'Vidutinė linijinė įtampa L3 fazėje per minutę', 675, 1, NULL, NULL),
	(5384, 13, 0, 2, 3, 0, 6, 2, 25, NULL, 'Vidutinė linijinė įtampa L3 fazėje per 2 minutes', 675, 1, NULL, NULL),
	(5385, 13, 0, 9, 3, 0, 6, 8, 25, NULL, 'Vidutinė linijinė įtampa L3 fazėje per 3 minutes', 675, 1, NULL, NULL),
	(5386, 13, 0, 12, 3, 0, 6, 11, 25, NULL, 'Vidutinė linijinė įtampa L3 fazėje per 10 minučių', 675, 1, NULL, NULL),
	(5387, 13, 0, 5, 3, 0, 6, 5, 25, NULL, 'Vidutinė linijinė įtampa L3 fazėje per parą', 675, 3, NULL, NULL),
	(5388, 13, 0, 11, 3, 0, 6, 10, 25, NULL, 'Vidutinė linijinė įtampa L3 fazėje per 5 minutes', 675, 1, NULL, NULL),
	(5389, 13, 0, 10, 3, 0, 6, 9, 25, NULL, 'Vidutinė linijinė įtampa L3 fazėje per 4 minutes', 675, 1, NULL, NULL),
	(5390, 13, 0, 13, 3, 0, 6, 12, 25, NULL, 'Vidutinė linijinė įtampa L3 fazėje per 15 minučių', 675, 2, NULL, NULL),
	(5391, 13, 0, 14, 3, 0, 6, 13, 25, NULL, 'Vidutinė linijinė įtampa L3 fazėje per 20 minučių', 675, 2, NULL, NULL),
	(5392, 30, 0, 3, 3, 0, 6, 3, 42, NULL, 'Vidutinė įtampa per 30 minučių', 676, 2, NULL, NULL),
	(5393, 30, 0, 4, 3, 0, 6, 4, 42, NULL, 'Vidutinė įtampa per valandą', 676, 2, NULL, NULL),
	(5394, 30, 0, 1, 3, 0, 6, 1, 42, NULL, 'Vidutinė įtampa per minutę', 676, 1, NULL, NULL),
	(5395, 30, 0, 2, 3, 0, 6, 2, 42, NULL, 'Vidutinė įtampa per 2 minutes', 676, 1, NULL, NULL),
	(5396, 30, 0, 9, 3, 0, 6, 8, 42, NULL, 'Vidutinė įtampa per 3 minutes', 676, 1, NULL, NULL),
	(5397, 30, 0, 12, 3, 0, 6, 11, 42, NULL, 'Vidutinė įtampa per 10 minučių', 676, 1, NULL, NULL),
	(5398, 30, 0, 5, 3, 0, 6, 5, 42, NULL, 'Vidutinė įtampa per parą', 676, 3, NULL, NULL),
	(5399, 30, 0, 11, 3, 0, 6, 10, 42, NULL, 'Vidutinė įtampa per 5 minutes', 676, 1, NULL, NULL),
	(5400, 30, 0, 10, 3, 0, 6, 9, 42, NULL, 'Vidutinė įtampa per 4 minutes', 676, 1, NULL, NULL),
	(5401, 30, 0, 13, 3, 0, 6, 12, 42, NULL, 'Vidutinė įtampa per 15 minučių', 676, 2, NULL, NULL),
	(5402, 30, 0, 14, 3, 0, 6, 13, 42, NULL, 'Vidutinė įtampa per 20 minučių', 676, 2, NULL, NULL),
	(5403, 31, 0, 3, 3, 0, 6, 3, 43, NULL, 'Vidutinė linijinė įtampa per 30 minučių', 677, 2, NULL, NULL),
	(5404, 31, 0, 4, 3, 0, 6, 4, 43, NULL, 'Vidutinė linijinė įtampa per valandą', 677, 2, NULL, NULL),
	(5405, 31, 0, 1, 3, 0, 6, 1, 43, NULL, 'Vidutinė linijinė įtampa per minutę', 677, 1, NULL, NULL),
	(5406, 31, 0, 2, 3, 0, 6, 2, 43, NULL, 'Vidutinė linijinė įtampa per 2 minutes', 677, 1, NULL, NULL),
	(5407, 31, 0, 9, 3, 0, 6, 8, 43, NULL, 'Vidutinė linijinė įtampa per 3 minutes', 677, 1, NULL, NULL),
	(5408, 31, 0, 12, 3, 0, 6, 11, 43, NULL, 'Vidutinė linijinė įtampa per 10 minučių', 677, 1, NULL, NULL),
	(5409, 31, 0, 5, 3, 0, 6, 5, 43, NULL, 'Vidutinė linijinė įtampa per parą', 677, 3, NULL, NULL),
	(5410, 31, 0, 11, 3, 0, 6, 10, 43, NULL, 'Vidutinė linijinė įtampa per 5 minutes', 677, 1, NULL, NULL),
	(5411, 31, 0, 10, 3, 0, 6, 9, 43, NULL, 'Vidutinė linijinė įtampa per 4 minutes', 677, 1, NULL, NULL),
	(5412, 31, 0, 13, 3, 0, 6, 12, 43, NULL, 'Vidutinė linijinė įtampa per 15 minučių', 677, 2, NULL, NULL),
	(5413, 31, 0, 14, 3, 0, 6, 13, 43, NULL, 'Vidutinė linijinė įtampa per 20 minučių', 677, 2, NULL, NULL),
	(5414, 212, 0, 3, 3, 0, 6, 3, 225, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L2 fazių per 30 minučių', NULL, 2, NULL, NULL),
	(5415, 212, 0, 4, 3, 0, 6, 4, 225, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L2 fazių per valandą', NULL, 2, NULL, NULL),
	(5416, 212, 0, 1, 3, 0, 6, 1, 225, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L2 fazių per minutę', NULL, 1, NULL, NULL),
	(5417, 212, 0, 2, 3, 0, 6, 2, 225, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L2 fazių per 2 minutes', NULL, 1, NULL, NULL),
	(5418, 212, 0, 9, 3, 0, 6, 8, 225, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L2 fazių per 3 minutes', NULL, 1, NULL, NULL),
	(5419, 212, 0, 12, 3, 0, 6, 11, 225, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L2 fazių per 10 minučių', NULL, 1, NULL, NULL),
	(5420, 212, 0, 5, 3, 0, 6, 5, 225, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L2 fazių per parą', NULL, 3, NULL, NULL),
	(5421, 212, 0, 11, 3, 0, 6, 10, 225, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L2 fazių per 5 minutes', NULL, 1, NULL, NULL),
	(5422, 212, 0, 10, 3, 0, 6, 9, 225, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L2 fazių per 4 minutes', NULL, 1, NULL, NULL),
	(5423, 212, 0, 13, 3, 0, 6, 12, 225, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L2 fazių per 15 minučių', NULL, 2, NULL, NULL),
	(5424, 212, 0, 14, 3, 0, 6, 13, 225, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L2 fazių per 20 minučių', NULL, 2, NULL, NULL),
	(5425, 213, 0, 3, 3, 0, 6, 3, 226, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L3 fazių per 30 minučių', NULL, 2, NULL, NULL),
	(5426, 213, 0, 4, 3, 0, 6, 4, 226, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L3 fazių per valandą', NULL, 2, NULL, NULL),
	(5427, 213, 0, 1, 3, 0, 6, 1, 226, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L3 fazių per minutę', NULL, 1, NULL, NULL),
	(5428, 213, 0, 2, 3, 0, 6, 2, 226, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L3 fazių per 2 minutes', NULL, 1, NULL, NULL),
	(5429, 213, 0, 9, 3, 0, 6, 8, 226, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L3 fazių per 3 minutes', NULL, 1, NULL, NULL),
	(5430, 213, 0, 12, 3, 0, 6, 11, 226, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L3 fazių per 10 minučių', NULL, 1, NULL, NULL),
	(5431, 213, 0, 5, 3, 0, 6, 5, 226, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L3 fazių per parą', NULL, 3, NULL, NULL),
	(5432, 213, 0, 11, 3, 0, 6, 10, 226, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L3 fazių per 5 minutes', NULL, 1, NULL, NULL),
	(5433, 213, 0, 10, 3, 0, 6, 9, 226, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L3 fazių per 4 minutes', NULL, 1, NULL, NULL),
	(5434, 213, 0, 13, 3, 0, 6, 12, 226, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L3 fazių per 15 minučių', NULL, 2, NULL, NULL),
	(5435, 213, 0, 14, 3, 0, 6, 13, 226, NULL, 'Vidutinė elektros linijinė įtampa tarp L1 ir L3 fazių per 20 minučių', NULL, 2, NULL, NULL),
	(5436, 214, 0, 3, 3, 0, 6, 3, 227, NULL, 'Vidutinė elektros linijinė įtampa tarp L2 ir L3 fazių per 30 minučių', NULL, 2, NULL, NULL),
	(5437, 214, 0, 4, 3, 0, 6, 4, 227, NULL, 'Vidutinė elektros linijinė įtampa tarp L2 ir L3 fazių per valandą', NULL, 2, NULL, NULL),
	(5438, 214, 0, 1, 3, 0, 6, 1, 227, NULL, 'Vidutinė elektros linijinė įtampa tarp L2 ir L3 fazių per minutę', NULL, 1, NULL, NULL),
	(5439, 214, 0, 2, 3, 0, 6, 2, 227, NULL, 'Vidutinė elektros linijinė įtampa tarp L2 ir L3 fazių per 2 minutes', NULL, 1, NULL, NULL),
	(5440, 214, 0, 9, 3, 0, 6, 8, 227, NULL, 'Vidutinė elektros linijinė įtampa tarp L2 ir L3 fazių per 3 minutes', NULL, 1, NULL, NULL),
	(5441, 214, 0, 12, 3, 0, 6, 11, 227, NULL, 'Vidutinė elektros linijinė įtampa tarp L2 ir L3 fazių per 10 minučių', NULL, 1, NULL, NULL),
	(5442, 214, 0, 5, 3, 0, 6, 5, 227, NULL, 'Vidutinė elektros linijinė įtampa tarp L2 ir L3 fazių per parą', NULL, 3, NULL, NULL),
	(5443, 214, 0, 11, 3, 0, 6, 10, 227, NULL, 'Vidutinė elektros linijinė įtampa tarp L2 ir L3 fazių per 5 minutes', NULL, 1, NULL, NULL),
	(5444, 214, 0, 10, 3, 0, 6, 9, 227, NULL, 'Vidutinė elektros linijinė įtampa tarp L2 ir L3 fazių per 4 minutes', NULL, 1, NULL, NULL),
	(5445, 214, 0, 13, 3, 0, 6, 12, 227, NULL, 'Vidutinė elektros linijinė įtampa tarp L2 ir L3 fazių per 15 minučių', NULL, 2, NULL, NULL),
	(5446, 214, 0, 14, 3, 0, 6, 13, 227, NULL, 'Vidutinė elektros linijinė įtampa tarp L2 ir L3 fazių per 20 minučių', NULL, 2, NULL, NULL),
	(5447, 215, 0, 8, 2, 0, 29, 7, 228, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su klaida', 1014, 5, NULL, NULL),
	(5448, 215, 0, 4, 2, 0, 29, 4, 228, NULL, 'Šilumnešio skaitiklio darbo laikas su klaida per valandą', 1074, 2, NULL, NULL),
	(5449, 215, 0, 5, 2, 0, 29, 5, 228, NULL, 'Šilumnešio skaitiklio darbo laikas su klaida per parą', 1074, 3, NULL, NULL),
	(5450, 215, 0, 6, 2, 0, 29, 6, 228, NULL, 'Šilumnešio skaitiklio darbo laikas su klaida per mėnesį', 1074, 4, NULL, NULL),
	(5451, 215, 0, 13, 2, 0, 29, 12, 228, NULL, 'Šilumnešio skaitiklio darbo laikas su klaida per 15 minučių', 1074, 2, NULL, NULL),
	(5452, 215, 0, 3, 2, 0, 29, 3, 228, NULL, 'Šilumnešio skaitiklio darbo laikas su klaida per 30 minučių', 1074, 2, NULL, NULL),
	(5453, 215, 0, 8, 2, 0, 29, 4, 228, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su klaida, fiksuojamas kas valandą', 1014, 5, NULL, NULL),
	(5454, 215, 0, 8, 2, 0, 29, 3, 228, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su klaida, fiksuojamas kas 30 minučių', 1014, 5, NULL, NULL),
	(5455, 215, 0, 8, 2, 0, 29, 12, 228, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su klaida, fiksuojamas kas 15 minučių', 1014, 5, NULL, NULL),
	(5456, 215, 0, 8, 2, 0, 29, 5, 228, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su klaida, fiksuojamas kas parą', 1014, 5, NULL, NULL),
	(5457, 215, 0, 8, 2, 0, 29, 6, 228, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su klaida, fiksuojamas kas mėnesį', 1014, 5, NULL, NULL),
	(5458, 216, 0, 8, 2, 0, 29, 7, 229, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su metrologine klaida', 1015, 5, NULL, NULL),
	(5459, 216, 0, 4, 2, 0, 29, 4, 229, NULL, 'Šilumnešio skaitiklio darbo laikas su metrologine klaida per valandą', 1015, 2, NULL, NULL),
	(5460, 216, 0, 5, 2, 0, 29, 5, 229, NULL, 'Šilumnešio skaitiklio darbo laikas su metrologine klaida per parą', 1015, 3, NULL, NULL),
	(5461, 216, 0, 6, 2, 0, 29, 6, 229, NULL, 'Šilumnešio skaitiklio darbo laikas su metrologine klaida per mėnesį', 1015, 4, NULL, NULL),
	(5462, 216, 0, 13, 2, 0, 29, 12, 229, NULL, 'Šilumnešio skaitiklio darbo laikas su metrologine klaida per 15 minučių', 1015, 2, NULL, NULL),
	(5463, 216, 0, 3, 2, 0, 29, 3, 229, NULL, 'Šilumnešio skaitiklio darbo laikas su metrologine klaida per 30 minučių', 1015, 2, NULL, NULL),
	(5464, 216, 0, 8, 2, 0, 29, 4, 229, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su metrologine klaida, fiksuojamas kas valandą', 1015, 5, NULL, NULL),
	(5465, 216, 0, 8, 2, 0, 29, 3, 229, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su metrologine klaida, fiksuojamas kas 30 minučių', 1015, 5, NULL, NULL),
	(5466, 216, 0, 8, 2, 0, 29, 12, 229, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su metrologine klaida, fiksuojamas kas 15 minučių', 1015, 5, NULL, NULL),
	(5467, 216, 0, 8, 2, 0, 29, 5, 229, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su metrologine klaida, fiksuojamas kas parą', 1015, 5, NULL, NULL),
	(5468, 216, 0, 8, 2, 0, 29, 6, 229, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su metrologine klaida, fiksuojamas kas mėnesį', 1015, 5, NULL, NULL),
	(5469, 217, 0, 8, 2, 0, 29, 7, 230, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su perpildymo klaida', 1016, 5, NULL, NULL),
	(5470, 217, 0, 4, 2, 0, 29, 4, 230, NULL, 'Šilumnešio skaitiklio darbo laikas su perpildymo klaida per valandą', 1016, 2, NULL, NULL),
	(5471, 217, 0, 5, 2, 0, 29, 5, 230, NULL, 'Šilumnešio skaitiklio darbo laikas su perpildymo klaida per parą', 1016, 3, NULL, NULL),
	(5472, 217, 0, 6, 2, 0, 29, 6, 230, NULL, 'Šilumnešio skaitiklio darbo laikas su perpildymo klaida per mėnesį', 1016, 4, NULL, NULL),
	(5473, 217, 0, 13, 2, 0, 29, 12, 230, NULL, 'Šilumnešio skaitiklio darbo laikas su perpildymo klaida per 15 minučių', 1016, 2, NULL, NULL),
	(5474, 217, 0, 3, 2, 0, 29, 3, 230, NULL, 'Šilumnešio skaitiklio darbo laikas su perpildymo klaida per 30 minučių', 1016, 2, NULL, NULL),
	(5475, 217, 0, 8, 2, 0, 29, 4, 230, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su perpildymo klaida, fiksuojamas kas valandą', 1016, 5, NULL, NULL),
	(5476, 217, 0, 8, 2, 0, 29, 3, 230, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su perpildymo klaida, fiksuojamas kas 30 minučių', 1016, 5, NULL, NULL),
	(5477, 217, 0, 8, 2, 0, 29, 12, 230, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su perpildymo klaida, fiksuojamas kas 15 minučių', 1016, 5, NULL, NULL),
	(5478, 217, 0, 8, 2, 0, 29, 5, 230, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su perpildymo klaida, fiksuojamas kas parą', 1016, 5, NULL, NULL),
	(5479, 217, 0, 8, 2, 0, 29, 6, 230, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su perpildymo klaida, fiksuojamas kas mėnesį', 1016, 5, NULL, NULL),
	(5480, 218, 0, 8, 2, 0, 29, 7, 231, NULL, 'Suminė šilumnešio skaitiklio maitinimo dingimo trukmė', 1017, 5, NULL, NULL),
	(5481, 218, 0, 4, 2, 0, 29, 4, 231, NULL, 'Šilumnešio skaitiklio maitinimo dingimo trukmė per valandą', 1017, 2, NULL, NULL),
	(5482, 218, 0, 5, 2, 0, 29, 5, 231, NULL, 'Šilumnešio skaitiklio maitinimo dingimo trukmė per parą', 1017, 3, NULL, NULL),
	(5483, 218, 0, 6, 2, 0, 29, 6, 231, NULL, 'Šilumnešio skaitiklio maitinimo dingimo trukmė per mėnesį', 1017, 4, NULL, NULL),
	(5484, 218, 0, 13, 2, 0, 29, 12, 231, NULL, 'Šilumnešio skaitiklio maitinimo dingimo trukmė per 15 minučių', 1017, 2, NULL, NULL),
	(5485, 218, 0, 3, 2, 0, 29, 3, 231, NULL, 'Šilumnešio skaitiklio maitinimo dingimo trukmė per 30 minučių', 1017, 2, NULL, NULL),
	(5486, 218, 0, 8, 2, 0, 29, 4, 231, NULL, 'Suminė šilumnešio skaitiklio maitinimo dingimo trukmė, fiksuojama kas valandą', 1017, 5, NULL, NULL),
	(5487, 218, 0, 8, 2, 0, 29, 3, 231, NULL, 'Suminė šilumnešio skaitiklio maitinimo dingimo trukmė, fiksuojama kas 30 minučių', 1017, 5, NULL, NULL),
	(5488, 218, 0, 8, 2, 0, 29, 12, 231, NULL, 'Suminė šilumnešio skaitiklio maitinimo dingimo trukmė, fiksuojama kas 15 minučių', 1017, 5, NULL, NULL),
	(5489, 218, 0, 8, 2, 0, 29, 5, 231, NULL, 'Suminė šilumnešio skaitiklio maitinimo dingimo trukmė, fiksuojama kas parą', 1017, 5, NULL, NULL),
	(5490, 218, 0, 8, 2, 0, 29, 6, 231, NULL, 'Suminė šilumnešio skaitiklio maitinimo dingimo trukmė, fiksuojama kas mėnesį', 1017, 5, NULL, NULL),
	(5491, 219, 0, 7, 1, 0, 8, 2, 232, NULL, 'Momentinis dažnis L1 fazėje, fiksuojamas kas 2 minutes', 108, 1, NULL, NULL),
	(5492, 219, 0, 7, 1, 0, 8, 7, 232, NULL, 'Momentinis dažnis L1 fazėje', 108, 6, NULL, NULL),
	(5493, 219, 0, 7, 1, 0, 8, 15, 232, NULL, 'Momentinis dažnis L1 fazėje, fiksuojamas kas 5 sekundes', 108, 7, NULL, NULL),
	(5494, 219, 0, 7, 1, 0, 8, 19, 232, NULL, 'Momentinis dažnis L1 fazėje, fiksuojamas kas 30 sekundžių', 108, 7, NULL, NULL),
	(5495, 220, 0, 7, 1, 0, 8, 2, 233, NULL, 'Momentinis dažnis L2 fazėje, fiksuojamas kas 2 minutes', 109, 1, NULL, NULL),
	(5496, 220, 0, 7, 1, 0, 8, 7, 233, NULL, 'Momentinis dažnis L2 fazėje', 109, 6, NULL, NULL),
	(5497, 220, 0, 7, 1, 0, 8, 15, 233, NULL, 'Momentinis dažnis L2 fazėje, fiksuojamas kas 5 sekundes', 109, 7, NULL, NULL),
	(5498, 220, 0, 7, 1, 0, 8, 19, 233, NULL, 'Momentinis dažnis L2 fazėje, fiksuojamas kas 30 sekundžių', 109, 7, NULL, NULL),
	(5499, 221, 0, 7, 1, 0, 8, 2, 234, NULL, 'Momentinis dažnis L3 fazėje, fiksuojamas kas 2 minutes', 110, 1, NULL, NULL),
	(5500, 221, 0, 7, 1, 0, 8, 7, 234, NULL, 'Momentinis dažnis L3 fazėje', 110, 6, NULL, NULL),
	(5501, 221, 0, 7, 1, 0, 8, 15, 234, NULL, 'Momentinis dažnis L3 fazėje, fiksuojamas kas 5 sekundes', 110, 7, NULL, NULL),
	(5502, 221, 0, 7, 1, 0, 8, 19, 234, NULL, 'Momentinis dažnis L3 fazėje, fiksuojamas kas 30 sekundžių', 110, 7, NULL, NULL),
	(5503, 14, 1, 1, 3, 0, 1, 1, 26, NULL, 'Vidutinė P+ galia per minutę L1 fazėje', 617, 1, NULL, NULL),
	(5504, 14, 1, 2, 3, 0, 1, 2, 26, NULL, 'Vidutinė P+ galia per 2 minutes L1 fazėje', 617, 1, NULL, NULL),
	(5505, 14, 1, 3, 3, 0, 1, 3, 26, NULL, 'Vidutinė P+ galia per 30 minučių L1 fazėje', 617, 2, NULL, NULL),
	(5506, 14, 1, 4, 3, 0, 1, 4, 26, NULL, 'Vidutinė P+ galia per valandą L1 fazėje', 617, 2, NULL, NULL),
	(5507, 14, 1, 5, 3, 0, 1, 5, 26, NULL, 'Vidutinė P+ galia per parą L1 fazėje', 617, 3, NULL, NULL),
	(5508, 14, 1, 9, 3, 0, 1, 8, 26, NULL, 'Vidutinė P+ galia per 3 minutes L1 fazėje', 617, 1, NULL, NULL),
	(5509, 14, 1, 10, 3, 0, 1, 9, 26, NULL, 'Vidutinė P+ galia per 4 minutes L1 fazėje', 617, 1, NULL, NULL),
	(5510, 14, 1, 11, 3, 0, 1, 10, 26, NULL, 'Vidutinė P+ galia per 5 minutes L1 fazėje', 617, 1, NULL, NULL),
	(5511, 14, 1, 12, 3, 0, 1, 11, 26, NULL, 'Vidutinė P+ galia per 10 minučių L1 fazėje', 617, 1, NULL, NULL),
	(5512, 14, 1, 13, 3, 0, 1, 12, 26, NULL, 'Vidutinė P+ galia per 15 minučių L1 fazėje', 617, 2, NULL, NULL),
	(5513, 14, 1, 14, 3, 0, 1, 13, 26, NULL, 'Vidutinė P+ galia per 20 minučių L1 fazėje', 617, 2, NULL, NULL),
	(5514, 14, 2, 1, 3, 0, 1, 1, 26, NULL, 'Vidutinė P- galia per minutę L1 fazėje', 618, 1, NULL, NULL),
	(5515, 14, 2, 2, 3, 0, 1, 2, 26, NULL, 'Vidutinė P- galia per 2 minutes L1 fazėje', 618, 1, NULL, NULL),
	(5516, 14, 2, 3, 3, 0, 1, 3, 26, NULL, 'Vidutinė P- galia per 30 minučių L1 fazėje', 618, 2, NULL, NULL),
	(5517, 14, 2, 4, 3, 0, 1, 4, 26, NULL, 'Vidutinė P- galia per valandą L1 fazėje', 618, 2, NULL, NULL),
	(5518, 14, 2, 5, 3, 0, 1, 5, 26, NULL, 'Vidutinė P- galia per parą L1 fazėje', 618, 3, NULL, NULL),
	(5519, 14, 2, 9, 3, 0, 1, 8, 26, NULL, 'Vidutinė P- galia per 3 minutes L1 fazėje', 618, 1, NULL, NULL),
	(5520, 14, 2, 10, 3, 0, 1, 9, 26, NULL, 'Vidutinė P- galia per 4 minutes L1 fazėje', 618, 1, NULL, NULL),
	(5521, 14, 2, 11, 3, 0, 1, 10, 26, NULL, 'Vidutinė P- galia per 5 minutes L1 fazėje', 618, 1, NULL, NULL),
	(5522, 14, 2, 12, 3, 0, 1, 11, 26, NULL, 'Vidutinė P- galia per 10 minučių L1 fazėje', 618, 1, NULL, NULL),
	(5523, 14, 2, 13, 3, 0, 1, 12, 26, NULL, 'Vidutinė P- galia per 15 minučių L1 fazėje', 618, 2, NULL, NULL),
	(5524, 14, 2, 14, 3, 0, 1, 13, 26, NULL, 'Vidutinė P- galia per 20 minučių L1 fazėje', 618, 2, NULL, NULL),
	(5525, 17, 1, 1, 3, 0, 3, 1, 29, NULL, 'Vidutinė Q+ galia per minutę L1 fazėje', 619, 1, NULL, NULL),
	(5526, 17, 1, 2, 3, 0, 3, 2, 29, NULL, 'Vidutinė Q+ galia per 2 minutes L1 fazėje', 619, 1, NULL, NULL),
	(5527, 17, 1, 3, 3, 0, 3, 3, 29, NULL, 'Vidutinė Q+ galia per 30 minučių L1 fazėje', 619, 2, NULL, NULL),
	(5528, 17, 1, 4, 3, 0, 3, 4, 29, NULL, 'Vidutinė Q+ galia per valandą L1 fazėje', 619, 2, NULL, NULL),
	(5529, 17, 1, 5, 3, 0, 3, 5, 29, NULL, 'Vidutinė Q+ galia per parą L1 fazėje', 619, 3, NULL, NULL),
	(5530, 17, 1, 9, 3, 0, 3, 8, 29, NULL, 'Vidutinė Q+ galia per 3 minutes L1 fazėje', 619, 1, NULL, NULL),
	(5531, 17, 1, 10, 3, 0, 3, 9, 29, NULL, 'Vidutinė Q+ galia per 4 minutes L1 fazėje', 619, 1, NULL, NULL),
	(5532, 17, 1, 11, 3, 0, 3, 10, 29, NULL, 'Vidutinė Q+ galia per 5 minutes L1 fazėje', 619, 1, NULL, NULL),
	(5533, 17, 1, 12, 3, 0, 3, 11, 29, NULL, 'Vidutinė Q+ galia per 10 minučių L1 fazėje', 619, 1, NULL, NULL),
	(5534, 17, 1, 13, 3, 0, 3, 12, 29, NULL, 'Vidutinė Q+ galia per 15 minučių L1 fazėje', 619, 2, NULL, NULL),
	(5535, 17, 1, 14, 3, 0, 3, 13, 29, NULL, 'Vidutinė Q+ galia per 20 minučių L1 fazėje', 619, 2, NULL, NULL),
	(5536, 17, 2, 1, 3, 0, 3, 1, 29, NULL, 'Vidutinė Q- galia per minutę L1 fazėje', 620, 1, NULL, NULL),
	(5537, 17, 2, 2, 3, 0, 3, 2, 29, NULL, 'Vidutinė Q- galia per 2 minutes L1 fazėje', 620, 1, NULL, NULL),
	(5538, 17, 2, 3, 3, 0, 3, 3, 29, NULL, 'Vidutinė Q- galia per 30 minučių L1 fazėje', 620, 2, NULL, NULL),
	(5539, 17, 2, 4, 3, 0, 3, 4, 29, NULL, 'Vidutinė Q- galia per valandą L1 fazėje', 620, 2, NULL, NULL),
	(5540, 17, 2, 5, 3, 0, 3, 5, 29, NULL, 'Vidutinė Q- galia per parą L1 fazėje', 620, 3, NULL, NULL),
	(5541, 17, 2, 9, 3, 0, 3, 8, 29, NULL, 'Vidutinė Q- galia per 3 minutes L1 fazėje', 620, 1, NULL, NULL),
	(5542, 17, 2, 10, 3, 0, 3, 9, 29, NULL, 'Vidutinė Q- galia per 4 minutes L1 fazėje', 620, 1, NULL, NULL),
	(5543, 17, 2, 11, 3, 0, 3, 10, 29, NULL, 'Vidutinė Q- galia per 5 minutes L1 fazėje', 620, 1, NULL, NULL),
	(5544, 17, 2, 12, 3, 0, 3, 11, 29, NULL, 'Vidutinė Q- galia per 10 minučių L1 fazėje', 620, 1, NULL, NULL),
	(5545, 17, 2, 13, 3, 0, 3, 12, 29, NULL, 'Vidutinė Q- galia per 15 minučių L1 fazėje', 620, 2, NULL, NULL),
	(5546, 17, 2, 14, 3, 0, 3, 13, 29, NULL, 'Vidutinė Q- galia per 20 minučių L1 fazėje', 620, 2, NULL, NULL),
	(5547, 15, 1, 1, 3, 0, 1, 1, 27, NULL, 'Vidutinė P+ galia per minutę L2 fazėje', 621, 1, NULL, NULL),
	(5548, 15, 1, 2, 3, 0, 1, 2, 27, NULL, 'Vidutinė P+ galia per 2 minutes L2 fazėje', 621, 1, NULL, NULL),
	(5549, 15, 1, 3, 3, 0, 1, 3, 27, NULL, 'Vidutinė P+ galia per 30 minučių L2 fazėje', 621, 2, NULL, NULL),
	(5550, 15, 1, 4, 3, 0, 1, 4, 27, NULL, 'Vidutinė P+ galia per valandą L2 fazėje', 621, 2, NULL, NULL),
	(5551, 15, 1, 5, 3, 0, 1, 5, 27, NULL, 'Vidutinė P+ galia per parą L2 fazėje', 621, 3, NULL, NULL),
	(5552, 15, 1, 9, 3, 0, 1, 8, 27, NULL, 'Vidutinė P+ galia per 3 minutes L2 fazėje', 621, 1, NULL, NULL),
	(5553, 15, 1, 10, 3, 0, 1, 9, 27, NULL, 'Vidutinė P+ galia per 4 minutes L2 fazėje', 621, 1, NULL, NULL),
	(5554, 15, 1, 11, 3, 0, 1, 10, 27, NULL, 'Vidutinė P+ galia per 5 minutes L2 fazėje', 621, 1, NULL, NULL),
	(5555, 15, 1, 12, 3, 0, 1, 11, 27, NULL, 'Vidutinė P+ galia per 10 minučių L2 fazėje', 621, 1, NULL, NULL),
	(5556, 15, 1, 13, 3, 0, 1, 12, 27, NULL, 'Vidutinė P+ galia per 15 minučių L2 fazėje', 621, 2, NULL, NULL),
	(5557, 15, 1, 14, 3, 0, 1, 13, 27, NULL, 'Vidutinė P+ galia per 20 minučių L2 fazėje', 621, 2, NULL, NULL),
	(5558, 15, 2, 1, 3, 0, 1, 1, 27, NULL, 'Vidutinė P- galia per minutę L2 fazėje', 622, 1, NULL, NULL),
	(5559, 15, 2, 2, 3, 0, 1, 2, 27, NULL, 'Vidutinė P- galia per 2 minutes L2 fazėje', 622, 1, NULL, NULL),
	(5560, 15, 2, 3, 3, 0, 1, 3, 27, NULL, 'Vidutinė P- galia per 30 minučių L2 fazėje', 622, 2, NULL, NULL),
	(5561, 15, 2, 4, 3, 0, 1, 4, 27, NULL, 'Vidutinė P- galia per valandą L2 fazėje', 622, 2, NULL, NULL),
	(5562, 15, 2, 5, 3, 0, 1, 5, 27, NULL, 'Vidutinė P- galia per parą L2 fazėje', 622, 3, NULL, NULL),
	(5563, 15, 2, 9, 3, 0, 1, 8, 27, NULL, 'Vidutinė P- galia per 3 minutes L2 fazėje', 622, 1, NULL, NULL),
	(5564, 15, 2, 10, 3, 0, 1, 9, 27, NULL, 'Vidutinė P- galia per 4 minutes L2 fazėje', 622, 1, NULL, NULL),
	(5565, 15, 2, 11, 3, 0, 1, 10, 27, NULL, 'Vidutinė P- galia per 5 minutes L2 fazėje', 622, 1, NULL, NULL),
	(5566, 15, 2, 12, 3, 0, 1, 11, 27, NULL, 'Vidutinė P- galia per 10 minučių L2 fazėje', 622, 1, NULL, NULL),
	(5567, 15, 2, 13, 3, 0, 1, 12, 27, NULL, 'Vidutinė P- galia per 15 minučių L2 fazėje', 622, 2, NULL, NULL),
	(5568, 15, 2, 14, 3, 0, 1, 13, 27, NULL, 'Vidutinė P- galia per 20 minučių L2 fazėje', 622, 2, NULL, NULL),
	(5569, 18, 1, 1, 3, 0, 3, 1, 30, NULL, 'Vidutinė Q+ galia per minutę L2 fazėje', 623, 1, NULL, NULL),
	(5570, 18, 1, 2, 3, 0, 3, 2, 30, NULL, 'Vidutinė Q+ galia per 2 minutes L2 fazėje', 623, 1, NULL, NULL),
	(5571, 18, 1, 3, 3, 0, 3, 3, 30, NULL, 'Vidutinė Q+ galia per 30 minučių L2 fazėje', 623, 2, NULL, NULL),
	(5572, 18, 1, 4, 3, 0, 3, 4, 30, NULL, 'Vidutinė Q+ galia per valandą L2 fazėje', 623, 2, NULL, NULL),
	(5573, 18, 1, 5, 3, 0, 3, 5, 30, NULL, 'Vidutinė Q+ galia per parą L2 fazėje', 623, 3, NULL, NULL),
	(5574, 18, 1, 9, 3, 0, 3, 8, 30, NULL, 'Vidutinė Q+ galia per 3 minutes L2 fazėje', 623, 1, NULL, NULL),
	(5575, 18, 1, 10, 3, 0, 3, 9, 30, NULL, 'Vidutinė Q+ galia per 4 minutes L2 fazėje', 623, 1, NULL, NULL),
	(5576, 18, 1, 11, 3, 0, 3, 10, 30, NULL, 'Vidutinė Q+ galia per 5 minutes L2 fazėje', 623, 1, NULL, NULL),
	(5577, 18, 1, 12, 3, 0, 3, 11, 30, NULL, 'Vidutinė Q+ galia per 10 minučių L2 fazėje', 623, 1, NULL, NULL),
	(5578, 18, 1, 13, 3, 0, 3, 12, 30, NULL, 'Vidutinė Q+ galia per 15 minučių L2 fazėje', 623, 2, NULL, NULL),
	(5579, 18, 1, 14, 3, 0, 3, 13, 30, NULL, 'Vidutinė Q+ galia per 20 minučių L2 fazėje', 623, 2, NULL, NULL),
	(5580, 18, 2, 1, 3, 0, 3, 1, 30, NULL, 'Vidutinė Q- galia per minutę L2 fazėje', 624, 1, NULL, NULL),
	(5581, 18, 2, 2, 3, 0, 3, 2, 30, NULL, 'Vidutinė Q- galia per 2 minutes L2 fazėje', 624, 1, NULL, NULL),
	(5582, 18, 2, 3, 3, 0, 3, 3, 30, NULL, 'Vidutinė Q- galia per 30 minučių L2 fazėje', 624, 2, NULL, NULL),
	(5583, 18, 2, 4, 3, 0, 3, 4, 30, NULL, 'Vidutinė Q- galia per valandą L2 fazėje', 624, 2, NULL, NULL),
	(5584, 18, 2, 5, 3, 0, 3, 5, 30, NULL, 'Vidutinė Q- galia per parą L2 fazėje', 624, 3, NULL, NULL),
	(5585, 18, 2, 9, 3, 0, 3, 8, 30, NULL, 'Vidutinė Q- galia per 3 minutes L2 fazėje', 624, 1, NULL, NULL),
	(5586, 18, 2, 10, 3, 0, 3, 9, 30, NULL, 'Vidutinė Q- galia per 4 minutes L2 fazėje', 624, 1, NULL, NULL),
	(5587, 18, 2, 11, 3, 0, 3, 10, 30, NULL, 'Vidutinė Q- galia per 5 minutes L2 fazėje', 624, 1, NULL, NULL),
	(5588, 18, 2, 12, 3, 0, 3, 11, 30, NULL, 'Vidutinė Q- galia per 10 minučių L2 fazėje', 624, 1, NULL, NULL),
	(5589, 18, 2, 13, 3, 0, 3, 12, 30, NULL, 'Vidutinė Q- galia per 15 minučių L2 fazėje', 624, 2, NULL, NULL),
	(5590, 18, 2, 14, 3, 0, 3, 13, 30, NULL, 'Vidutinė Q- galia per 20 minučių L2 fazėje', 624, 2, NULL, NULL),
	(5591, 16, 1, 1, 3, 0, 1, 1, 28, NULL, 'Vidutinė P+ galia per minutę L3 fazėje', 625, 1, NULL, NULL),
	(5592, 16, 1, 2, 3, 0, 1, 2, 28, NULL, 'Vidutinė P+ galia per 2 minutes L3 fazėje', 625, 1, NULL, NULL),
	(5593, 16, 1, 3, 3, 0, 1, 3, 28, NULL, 'Vidutinė P+ galia per 30 minučių L3 fazėje', 625, 2, NULL, NULL),
	(5594, 16, 1, 4, 3, 0, 1, 4, 28, NULL, 'Vidutinė P+ galia per valandą L3 fazėje', 625, 2, NULL, NULL),
	(5595, 16, 1, 5, 3, 0, 1, 5, 28, NULL, 'Vidutinė P+ galia per parą L3 fazėje', 625, 3, NULL, NULL),
	(5596, 16, 1, 9, 3, 0, 1, 8, 28, NULL, 'Vidutinė P+ galia per 3 minutes L3 fazėje', 625, 1, NULL, NULL),
	(5597, 16, 1, 10, 3, 0, 1, 9, 28, NULL, 'Vidutinė P+ galia per 4 minutes L3 fazėje', 625, 1, NULL, NULL),
	(5598, 16, 1, 11, 3, 0, 1, 10, 28, NULL, 'Vidutinė P+ galia per 5 minutes L3 fazėje', 625, 1, NULL, NULL),
	(5599, 16, 1, 12, 3, 0, 1, 11, 28, NULL, 'Vidutinė P+ galia per 10 minučių L3 fazėje', 625, 1, NULL, NULL),
	(5600, 16, 1, 13, 3, 0, 1, 12, 28, NULL, 'Vidutinė P+ galia per 15 minučių L3 fazėje', 625, 2, NULL, NULL),
	(5601, 16, 1, 14, 3, 0, 1, 13, 28, NULL, 'Vidutinė P+ galia per 20 minučių L3 fazėje', 625, 2, NULL, NULL),
	(5602, 16, 2, 1, 3, 0, 1, 1, 28, NULL, 'Vidutinė P- galia per minutę L3 fazėje', 626, 1, NULL, NULL),
	(5603, 16, 2, 2, 3, 0, 1, 2, 28, NULL, 'Vidutinė P- galia per 2 minutes L3 fazėje', 626, 1, NULL, NULL),
	(5604, 16, 2, 3, 3, 0, 1, 3, 28, NULL, 'Vidutinė P- galia per 30 minučių L3 fazėje', 626, 2, NULL, NULL),
	(5605, 16, 2, 4, 3, 0, 1, 4, 28, NULL, 'Vidutinė P- galia per valandą L3 fazėje', 626, 2, NULL, NULL),
	(5606, 16, 2, 5, 3, 0, 1, 5, 28, NULL, 'Vidutinė P- galia per parą L3 fazėje', 626, 3, NULL, NULL),
	(5607, 16, 2, 9, 3, 0, 1, 8, 28, NULL, 'Vidutinė P- galia per 3 minutes L3 fazėje', 626, 1, NULL, NULL),
	(5608, 16, 2, 10, 3, 0, 1, 9, 28, NULL, 'Vidutinė P- galia per 4 minutes L3 fazėje', 626, 1, NULL, NULL),
	(5609, 16, 2, 11, 3, 0, 1, 10, 28, NULL, 'Vidutinė P- galia per 5 minutes L3 fazėje', 626, 1, NULL, NULL),
	(5610, 16, 2, 12, 3, 0, 1, 11, 28, NULL, 'Vidutinė P- galia per 10 minučių L3 fazėje', 626, 1, NULL, NULL),
	(5611, 16, 2, 13, 3, 0, 1, 12, 28, NULL, 'Vidutinė P- galia per 15 minučių L3 fazėje', 626, 2, NULL, NULL),
	(5612, 16, 2, 14, 3, 0, 1, 13, 28, NULL, 'Vidutinė P- galia per 20 minučių L3 fazėje', 626, 2, NULL, NULL),
	(5613, 19, 1, 1, 3, 0, 3, 1, 31, NULL, 'Vidutinė Q+ galia per minutę L3 fazėje', 627, 1, NULL, NULL),
	(5614, 19, 1, 2, 3, 0, 3, 2, 31, NULL, 'Vidutinė Q+ galia per 2 minutes L3 fazėje', 627, 1, NULL, NULL),
	(5615, 19, 1, 3, 3, 0, 3, 3, 31, NULL, 'Vidutinė Q+ galia per 30 minučių L3 fazėje', 627, 2, NULL, NULL),
	(5616, 19, 1, 4, 3, 0, 3, 4, 31, NULL, 'Vidutinė Q+ galia per valandą L3 fazėje', 627, 2, NULL, NULL),
	(5617, 19, 1, 5, 3, 0, 3, 5, 31, NULL, 'Vidutinė Q+ galia per parą L3 fazėje', 627, 3, NULL, NULL),
	(5618, 19, 1, 9, 3, 0, 3, 8, 31, NULL, 'Vidutinė Q+ galia per 3 minutes L3 fazėje', 627, 1, NULL, NULL),
	(5619, 19, 1, 10, 3, 0, 3, 9, 31, NULL, 'Vidutinė Q+ galia per 4 minutes L3 fazėje', 627, 1, NULL, NULL),
	(5620, 19, 1, 11, 3, 0, 3, 10, 31, NULL, 'Vidutinė Q+ galia per 5 minutes L3 fazėje', 627, 1, NULL, NULL),
	(5621, 19, 1, 12, 3, 0, 3, 11, 31, NULL, 'Vidutinė Q+ galia per 10 minučių L3 fazėje', 627, 1, NULL, NULL),
	(5622, 19, 1, 13, 3, 0, 3, 12, 31, NULL, 'Vidutinė Q+ galia per 15 minučių L3 fazėje', 627, 2, NULL, NULL),
	(5623, 19, 1, 14, 3, 0, 3, 13, 31, NULL, 'Vidutinė Q+ galia per 20 minučių L3 fazėje', 627, 2, NULL, NULL),
	(5624, 19, 2, 1, 3, 0, 3, 1, 31, NULL, 'Vidutinė Q- galia per minutę L3 fazėje', 628, 1, NULL, NULL),
	(5625, 19, 2, 2, 3, 0, 3, 2, 31, NULL, 'Vidutinė Q- galia per 2 minutes L3 fazėje', 628, 1, NULL, NULL),
	(5626, 19, 2, 3, 3, 0, 3, 3, 31, NULL, 'Vidutinė Q- galia per 30 minučių L3 fazėje', 628, 2, NULL, NULL),
	(5627, 19, 2, 4, 3, 0, 3, 4, 31, NULL, 'Vidutinė Q- galia per valandą L3 fazėje', 628, 2, NULL, NULL),
	(5628, 19, 2, 5, 3, 0, 3, 5, 31, NULL, 'Vidutinė Q- galia per parą L3 fazėje', 628, 3, NULL, NULL),
	(5629, 19, 2, 9, 3, 0, 3, 8, 31, NULL, 'Vidutinė Q- galia per 3 minutes L3 fazėje', 628, 1, NULL, NULL),
	(5630, 19, 2, 10, 3, 0, 3, 9, 31, NULL, 'Vidutinė Q- galia per 4 minutes L3 fazėje', 628, 1, NULL, NULL),
	(5631, 19, 2, 11, 3, 0, 3, 10, 31, NULL, 'Vidutinė Q- galia per 5 minutes L3 fazėje', 628, 1, NULL, NULL),
	(5632, 19, 2, 12, 3, 0, 3, 11, 31, NULL, 'Vidutinė Q- galia per 10 minučių L3 fazėje', 628, 1, NULL, NULL),
	(5633, 19, 2, 13, 3, 0, 3, 12, 31, NULL, 'Vidutinė Q- galia per 15 minučių L3 fazėje', 628, 2, NULL, NULL),
	(5634, 19, 2, 14, 3, 0, 3, 13, 31, NULL, 'Vidutinė Q- galia per 20 minučių L3 fazėje', 628, 2, NULL, NULL),
	(5635, 17, 5, 1, 3, 0, 3, 1, 29, NULL, 'Vidutinė Q1 galia per minutę L1 fazėje', 629, 1, NULL, NULL),
	(5636, 17, 5, 2, 3, 0, 3, 2, 29, NULL, 'Vidutinė Q1 galia per 2 minutes L1 fazėje', 629, 1, NULL, NULL),
	(5637, 17, 5, 3, 3, 0, 3, 3, 29, NULL, 'Vidutinė Q1 galia per 30 minučių L1 fazėje', 629, 2, NULL, NULL),
	(5638, 17, 5, 4, 3, 0, 3, 4, 29, NULL, 'Vidutinė Q1 galia per valandą L1 fazėje', 629, 2, NULL, NULL),
	(5639, 17, 5, 5, 3, 0, 3, 5, 29, NULL, 'Vidutinė Q1 galia per parą L1 fazėje', 629, 3, NULL, NULL),
	(5640, 17, 5, 9, 3, 0, 3, 8, 29, NULL, 'Vidutinė Q1 galia per 3 minutes L1 fazėje', 629, 1, NULL, NULL),
	(5641, 17, 5, 10, 3, 0, 3, 9, 29, NULL, 'Vidutinė Q1 galia per 4 minutes L1 fazėje', 629, 1, NULL, NULL),
	(5642, 17, 5, 11, 3, 0, 3, 10, 29, NULL, 'Vidutinė Q1 galia per 5 minutes L1 fazėje', 629, 1, NULL, NULL),
	(5643, 17, 5, 12, 3, 0, 3, 11, 29, NULL, 'Vidutinė Q1 galia per 10 minučių L1 fazėje', 629, 1, NULL, NULL),
	(5644, 17, 5, 13, 3, 0, 3, 12, 29, NULL, 'Vidutinė Q1 galia per 15 minučių L1 fazėje', 629, 2, NULL, NULL),
	(5645, 17, 5, 14, 3, 0, 3, 13, 29, NULL, 'Vidutinė Q1 galia per 20 minučių L1 fazėje', 629, 2, NULL, NULL),
	(5646, 17, 6, 1, 3, 0, 3, 1, 29, NULL, 'Vidutinė Q2 galia per minutę L1 fazėje', 630, 1, NULL, NULL),
	(5647, 17, 6, 2, 3, 0, 3, 2, 29, NULL, 'Vidutinė Q2 galia per 2 minutes L1 fazėje', 630, 1, NULL, NULL),
	(5648, 17, 6, 3, 3, 0, 3, 3, 29, NULL, 'Vidutinė Q2 galia per 30 minučių L1 fazėje', 630, 2, NULL, NULL),
	(5649, 17, 6, 4, 3, 0, 3, 4, 29, NULL, 'Vidutinė Q2 galia per valandą L1 fazėje', 630, 2, NULL, NULL),
	(5650, 17, 6, 5, 3, 0, 3, 5, 29, NULL, 'Vidutinė Q2 galia per parą L1 fazėje', 630, 3, NULL, NULL),
	(5651, 17, 6, 9, 3, 0, 3, 8, 29, NULL, 'Vidutinė Q2 galia per 3 minutes L1 fazėje', 630, 1, NULL, NULL),
	(5652, 17, 6, 10, 3, 0, 3, 9, 29, NULL, 'Vidutinė Q2 galia per 4 minutes L1 fazėje', 630, 1, NULL, NULL),
	(5653, 17, 6, 11, 3, 0, 3, 10, 29, NULL, 'Vidutinė Q2 galia per 5 minutes L1 fazėje', 630, 1, NULL, NULL),
	(5654, 17, 6, 12, 3, 0, 3, 11, 29, NULL, 'Vidutinė Q2 galia per 10 minučių L1 fazėje', 630, 1, NULL, NULL),
	(5655, 17, 6, 13, 3, 0, 3, 12, 29, NULL, 'Vidutinė Q2 galia per 15 minučių L1 fazėje', 630, 2, NULL, NULL),
	(5656, 17, 6, 14, 3, 0, 3, 13, 29, NULL, 'Vidutinė Q2 galia per 20 minučių L1 fazėje', 630, 2, NULL, NULL),
	(5657, 17, 7, 1, 3, 0, 3, 1, 29, NULL, 'Vidutinė Q3 galia per minutę L1 fazėje', 631, 1, NULL, NULL),
	(5658, 17, 7, 2, 3, 0, 3, 2, 29, NULL, 'Vidutinė Q3 galia per 2 minutes L1 fazėje', 631, 1, NULL, NULL),
	(5659, 17, 7, 3, 3, 0, 3, 3, 29, NULL, 'Vidutinė Q3 galia per 30 minučių L1 fazėje', 631, 2, NULL, NULL),
	(5660, 17, 7, 4, 3, 0, 3, 4, 29, NULL, 'Vidutinė Q3 galia per valandą L1 fazėje', 631, 2, NULL, NULL),
	(5661, 17, 7, 5, 3, 0, 3, 5, 29, NULL, 'Vidutinė Q3 galia per parą L1 fazėje', 631, 3, NULL, NULL),
	(5662, 17, 7, 9, 3, 0, 3, 8, 29, NULL, 'Vidutinė Q3 galia per 3 minutes L1 fazėje', 631, 1, NULL, NULL),
	(5663, 17, 7, 10, 3, 0, 3, 9, 29, NULL, 'Vidutinė Q3 galia per 4 minutes L1 fazėje', 631, 1, NULL, NULL),
	(5664, 17, 7, 11, 3, 0, 3, 10, 29, NULL, 'Vidutinė Q3 galia per 5 minutes L1 fazėje', 631, 1, NULL, NULL),
	(5665, 17, 7, 12, 3, 0, 3, 11, 29, NULL, 'Vidutinė Q3 galia per 10 minučių L1 fazėje', 631, 1, NULL, NULL),
	(5666, 17, 7, 13, 3, 0, 3, 12, 29, NULL, 'Vidutinė Q3 galia per 15 minučių L1 fazėje', 631, 2, NULL, NULL),
	(5667, 17, 7, 14, 3, 0, 3, 13, 29, NULL, 'Vidutinė Q3 galia per 20 minučių L1 fazėje', 631, 2, NULL, NULL),
	(5668, 17, 8, 1, 3, 0, 3, 1, 29, NULL, 'Vidutinė Q4 galia per minutę L1 fazėje', 632, 1, NULL, NULL),
	(5669, 17, 8, 2, 3, 0, 3, 2, 29, NULL, 'Vidutinė Q4 galia per 2 minutes L1 fazėje', 632, 1, NULL, NULL),
	(5670, 17, 8, 3, 3, 0, 3, 3, 29, NULL, 'Vidutinė Q4 galia per 30 minučių L1 fazėje', 632, 2, NULL, NULL),
	(5671, 17, 8, 4, 3, 0, 3, 4, 29, NULL, 'Vidutinė Q4 galia per valandą L1 fazėje', 632, 2, NULL, NULL),
	(5672, 17, 8, 5, 3, 0, 3, 5, 29, NULL, 'Vidutinė Q4 galia per parą L1 fazėje', 632, 3, NULL, NULL),
	(5673, 17, 8, 9, 3, 0, 3, 8, 29, NULL, 'Vidutinė Q4 galia per 3 minutes L1 fazėje', 632, 1, NULL, NULL),
	(5674, 17, 8, 10, 3, 0, 3, 9, 29, NULL, 'Vidutinė Q4 galia per 4 minutes L1 fazėje', 632, 1, NULL, NULL),
	(5675, 17, 8, 11, 3, 0, 3, 10, 29, NULL, 'Vidutinė Q4 galia per 5 minutes L1 fazėje', 632, 1, NULL, NULL),
	(5676, 17, 8, 12, 3, 0, 3, 11, 29, NULL, 'Vidutinė Q4 galia per 10 minučių L1 fazėje', 632, 1, NULL, NULL),
	(5677, 17, 8, 13, 3, 0, 3, 12, 29, NULL, 'Vidutinė Q4 galia per 15 minučių L1 fazėje', 632, 2, NULL, NULL),
	(5678, 17, 8, 14, 3, 0, 3, 13, 29, NULL, 'Vidutinė Q4 galia per 20 minučių L1 fazėje', 632, 2, NULL, NULL),
	(5679, 18, 5, 1, 3, 0, 3, 1, 30, NULL, 'Vidutinė Q1 galia per minutę L2 fazėje', 635, 1, NULL, NULL),
	(5680, 18, 5, 2, 3, 0, 3, 2, 30, NULL, 'Vidutinė Q1 galia per 2 minutes L2 fazėje', 635, 1, NULL, NULL),
	(5681, 18, 5, 3, 3, 0, 3, 3, 30, NULL, 'Vidutinė Q1 galia per 30 minučių L2 fazėje', 635, 2, NULL, NULL),
	(5682, 18, 5, 4, 3, 0, 3, 4, 30, NULL, 'Vidutinė Q1 galia per valandą L2 fazėje', 635, 2, NULL, NULL),
	(5683, 18, 5, 5, 3, 0, 3, 5, 30, NULL, 'Vidutinė Q1 galia per parą L2 fazėje', 635, 3, NULL, NULL),
	(5684, 18, 5, 9, 3, 0, 3, 8, 30, NULL, 'Vidutinė Q1 galia per 3 minutes L2 fazėje', 635, 1, NULL, NULL),
	(5685, 18, 5, 10, 3, 0, 3, 9, 30, NULL, 'Vidutinė Q1 galia per 4 minutes L2 fazėje', 635, 1, NULL, NULL),
	(5686, 18, 5, 11, 3, 0, 3, 10, 30, NULL, 'Vidutinė Q1 galia per 5 minutes L2 fazėje', 635, 1, NULL, NULL),
	(5687, 18, 5, 12, 3, 0, 3, 11, 30, NULL, 'Vidutinė Q1 galia per 10 minučių L2 fazėje', 635, 1, NULL, NULL),
	(5688, 18, 5, 13, 3, 0, 3, 12, 30, NULL, 'Vidutinė Q1 galia per 15 minučių L2 fazėje', 635, 2, NULL, NULL),
	(5689, 18, 5, 14, 3, 0, 3, 13, 30, NULL, 'Vidutinė Q1 galia per 20 minučių L2 fazėje', 635, 2, NULL, NULL),
	(5690, 18, 6, 1, 3, 0, 3, 1, 30, NULL, 'Vidutinė Q2 galia per minutę L2 fazėje', 636, 1, NULL, NULL),
	(5691, 18, 6, 2, 3, 0, 3, 2, 30, NULL, 'Vidutinė Q2 galia per 2 minutes L2 fazėje', 636, 1, NULL, NULL),
	(5692, 18, 6, 3, 3, 0, 3, 3, 30, NULL, 'Vidutinė Q2 galia per 30 minučių L2 fazėje', 636, 2, NULL, NULL),
	(5693, 18, 6, 4, 3, 0, 3, 4, 30, NULL, 'Vidutinė Q2 galia per valandą L2 fazėje', 636, 2, NULL, NULL),
	(5694, 18, 6, 5, 3, 0, 3, 5, 30, NULL, 'Vidutinė Q2 galia per parą L2 fazėje', 636, 3, NULL, NULL),
	(5695, 18, 6, 9, 3, 0, 3, 8, 30, NULL, 'Vidutinė Q2 galia per 3 minutes L2 fazėje', 636, 1, NULL, NULL),
	(5696, 18, 6, 10, 3, 0, 3, 9, 30, NULL, 'Vidutinė Q2 galia per 4 minutes L2 fazėje', 636, 1, NULL, NULL),
	(5697, 18, 6, 11, 3, 0, 3, 10, 30, NULL, 'Vidutinė Q2 galia per 5 minutes L2 fazėje', 636, 1, NULL, NULL),
	(5698, 18, 6, 12, 3, 0, 3, 11, 30, NULL, 'Vidutinė Q2 galia per 10 minučių L2 fazėje', 636, 1, NULL, NULL),
	(5699, 18, 6, 13, 3, 0, 3, 12, 30, NULL, 'Vidutinė Q2 galia per 15 minučių L2 fazėje', 636, 2, NULL, NULL),
	(5700, 18, 6, 14, 3, 0, 3, 13, 30, NULL, 'Vidutinė Q2 galia per 20 minučių L2 fazėje', 636, 2, NULL, NULL),
	(5701, 18, 7, 1, 3, 0, 3, 1, 30, NULL, 'Vidutinė Q3 galia per minutę L2 fazėje', 637, 1, NULL, NULL),
	(5702, 18, 7, 2, 3, 0, 3, 2, 30, NULL, 'Vidutinė Q3 galia per 2 minutes L2 fazėje', 637, 1, NULL, NULL),
	(5703, 18, 7, 3, 3, 0, 3, 3, 30, NULL, 'Vidutinė Q3 galia per 30 minučių L2 fazėje', 637, 2, NULL, NULL),
	(5704, 18, 7, 4, 3, 0, 3, 4, 30, NULL, 'Vidutinė Q3 galia per valandą L2 fazėje', 637, 2, NULL, NULL),
	(5705, 18, 7, 5, 3, 0, 3, 5, 30, NULL, 'Vidutinė Q3 galia per parą L2 fazėje', 637, 3, NULL, NULL),
	(5706, 18, 7, 9, 3, 0, 3, 8, 30, NULL, 'Vidutinė Q3 galia per 3 minutes L2 fazėje', 637, 1, NULL, NULL),
	(5707, 18, 7, 10, 3, 0, 3, 9, 30, NULL, 'Vidutinė Q3 galia per 4 minutes L2 fazėje', 637, 1, NULL, NULL),
	(5708, 18, 7, 11, 3, 0, 3, 10, 30, NULL, 'Vidutinė Q3 galia per 5 minutes L2 fazėje', 637, 1, NULL, NULL),
	(5709, 18, 7, 12, 3, 0, 3, 11, 30, NULL, 'Vidutinė Q3 galia per 10 minučių L2 fazėje', 637, 1, NULL, NULL),
	(5710, 18, 7, 13, 3, 0, 3, 12, 30, NULL, 'Vidutinė Q3 galia per 15 minučių L2 fazėje', 637, 2, NULL, NULL),
	(5711, 18, 7, 14, 3, 0, 3, 13, 30, NULL, 'Vidutinė Q3 galia per 20 minučių L2 fazėje', 637, 2, NULL, NULL),
	(5712, 18, 8, 1, 3, 0, 3, 1, 30, NULL, 'Vidutinė Q4 galia per minutę L2 fazėje', 638, 1, NULL, NULL),
	(5713, 18, 8, 2, 3, 0, 3, 2, 30, NULL, 'Vidutinė Q4 galia per 2 minutes L2 fazėje', 638, 1, NULL, NULL),
	(5714, 18, 8, 3, 3, 0, 3, 3, 30, NULL, 'Vidutinė Q4 galia per 30 minučių L2 fazėje', 638, 2, NULL, NULL),
	(5715, 18, 8, 4, 3, 0, 3, 4, 30, NULL, 'Vidutinė Q4 galia per valandą L2 fazėje', 638, 2, NULL, NULL),
	(5716, 18, 8, 5, 3, 0, 3, 5, 30, NULL, 'Vidutinė Q4 galia per parą L2 fazėje', 638, 3, NULL, NULL),
	(5717, 18, 8, 9, 3, 0, 3, 8, 30, NULL, 'Vidutinė Q4 galia per 3 minutes L2 fazėje', 638, 1, NULL, NULL),
	(5718, 18, 8, 10, 3, 0, 3, 9, 30, NULL, 'Vidutinė Q4 galia per 4 minutes L2 fazėje', 638, 1, NULL, NULL),
	(5719, 18, 8, 11, 3, 0, 3, 10, 30, NULL, 'Vidutinė Q4 galia per 5 minutes L2 fazėje', 638, 1, NULL, NULL),
	(5720, 18, 8, 12, 3, 0, 3, 11, 30, NULL, 'Vidutinė Q4 galia per 10 minučių L2 fazėje', 638, 1, NULL, NULL),
	(5721, 18, 8, 13, 3, 0, 3, 12, 30, NULL, 'Vidutinė Q4 galia per 15 minučių L2 fazėje', 638, 2, NULL, NULL),
	(5722, 18, 8, 14, 3, 0, 3, 13, 30, NULL, 'Vidutinė Q4 galia per 20 minučių L2 fazėje', 638, 2, NULL, NULL),
	(5723, 19, 5, 1, 3, 0, 3, 1, 31, NULL, 'Vidutinė Q1 galia per minutę L3 fazėje', 641, 1, NULL, NULL),
	(5724, 19, 5, 2, 3, 0, 3, 2, 31, NULL, 'Vidutinė Q1 galia per 2 minutes L3 fazėje', 641, 1, NULL, NULL),
	(5725, 19, 5, 3, 3, 0, 3, 3, 31, NULL, 'Vidutinė Q1 galia per 30 minučių L3 fazėje', 641, 2, NULL, NULL),
	(5726, 19, 5, 4, 3, 0, 3, 4, 31, NULL, 'Vidutinė Q1 galia per valandą L3 fazėje', 641, 2, NULL, NULL),
	(5727, 19, 5, 5, 3, 0, 3, 5, 31, NULL, 'Vidutinė Q1 galia per parą L3 fazėje', 641, 3, NULL, NULL),
	(5728, 19, 5, 9, 3, 0, 3, 8, 31, NULL, 'Vidutinė Q1 galia per 3 minutes L3 fazėje', 641, 1, NULL, NULL),
	(5729, 19, 5, 10, 3, 0, 3, 9, 31, NULL, 'Vidutinė Q1 galia per 4 minutes L3 fazėje', 641, 1, NULL, NULL),
	(5730, 19, 5, 11, 3, 0, 3, 10, 31, NULL, 'Vidutinė Q1 galia per 5 minutes L3 fazėje', 641, 1, NULL, NULL),
	(5731, 19, 5, 12, 3, 0, 3, 11, 31, NULL, 'Vidutinė Q1 galia per 10 minučių L3 fazėje', 641, 1, NULL, NULL),
	(5732, 19, 5, 13, 3, 0, 3, 12, 31, NULL, 'Vidutinė Q1 galia per 15 minučių L3 fazėje', 641, 2, NULL, NULL),
	(5733, 19, 5, 14, 3, 0, 3, 13, 31, NULL, 'Vidutinė Q1 galia per 20 minučių L3 fazėje', 641, 2, NULL, NULL),
	(5734, 19, 6, 1, 3, 0, 3, 1, 31, NULL, 'Vidutinė Q2 galia per minutę L3 fazėje', 642, 1, NULL, NULL),
	(5735, 19, 6, 2, 3, 0, 3, 2, 31, NULL, 'Vidutinė Q2 galia per 2 minutes L3 fazėje', 642, 1, NULL, NULL),
	(5736, 19, 6, 3, 3, 0, 3, 3, 31, NULL, 'Vidutinė Q2 galia per 30 minučių L3 fazėje', 642, 2, NULL, NULL),
	(5737, 19, 6, 4, 3, 0, 3, 4, 31, NULL, 'Vidutinė Q2 galia per valandą L3 fazėje', 642, 2, NULL, NULL),
	(5738, 19, 6, 5, 3, 0, 3, 5, 31, NULL, 'Vidutinė Q2 galia per parą L3 fazėje', 642, 3, NULL, NULL),
	(5739, 19, 6, 9, 3, 0, 3, 8, 31, NULL, 'Vidutinė Q2 galia per 3 minutes L3 fazėje', 642, 1, NULL, NULL),
	(5740, 19, 6, 10, 3, 0, 3, 9, 31, NULL, 'Vidutinė Q2 galia per 4 minutes L3 fazėje', 642, 1, NULL, NULL),
	(5741, 19, 6, 11, 3, 0, 3, 10, 31, NULL, 'Vidutinė Q2 galia per 5 minutes L3 fazėje', 642, 1, NULL, NULL),
	(5742, 19, 6, 12, 3, 0, 3, 11, 31, NULL, 'Vidutinė Q2 galia per 10 minučių L3 fazėje', 642, 1, NULL, NULL),
	(5743, 19, 6, 13, 3, 0, 3, 12, 31, NULL, 'Vidutinė Q2 galia per 15 minučių L3 fazėje', 642, 2, NULL, NULL),
	(5744, 19, 6, 14, 3, 0, 3, 13, 31, NULL, 'Vidutinė Q2 galia per 20 minučių L3 fazėje', 642, 2, NULL, NULL),
	(5745, 19, 7, 1, 3, 0, 3, 1, 31, NULL, 'Vidutinė Q3 galia per minutę L3 fazėje', 643, 1, NULL, NULL),
	(5746, 19, 7, 2, 3, 0, 3, 2, 31, NULL, 'Vidutinė Q3 galia per 2 minutes L3 fazėje', 643, 1, NULL, NULL),
	(5747, 19, 7, 3, 3, 0, 3, 3, 31, NULL, 'Vidutinė Q3 galia per 30 minučių L3 fazėje', 643, 2, NULL, NULL),
	(5748, 19, 7, 4, 3, 0, 3, 4, 31, NULL, 'Vidutinė Q3 galia per valandą L3 fazėje', 643, 2, NULL, NULL),
	(5749, 19, 7, 5, 3, 0, 3, 5, 31, NULL, 'Vidutinė Q3 galia per parą L3 fazėje', 643, 3, NULL, NULL),
	(5750, 19, 7, 9, 3, 0, 3, 8, 31, NULL, 'Vidutinė Q3 galia per 3 minutes L3 fazėje', 643, 1, NULL, NULL),
	(5751, 19, 7, 10, 3, 0, 3, 9, 31, NULL, 'Vidutinė Q3 galia per 4 minutes L3 fazėje', 643, 1, NULL, NULL),
	(5752, 19, 7, 11, 3, 0, 3, 10, 31, NULL, 'Vidutinė Q3 galia per 5 minutes L3 fazėje', 643, 1, NULL, NULL),
	(5753, 19, 7, 12, 3, 0, 3, 11, 31, NULL, 'Vidutinė Q3 galia per 10 minučių L3 fazėje', 643, 1, NULL, NULL),
	(5754, 19, 7, 13, 3, 0, 3, 12, 31, NULL, 'Vidutinė Q3 galia per 15 minučių L3 fazėje', 643, 2, NULL, NULL),
	(5755, 19, 7, 14, 3, 0, 3, 13, 31, NULL, 'Vidutinė Q3 galia per 20 minučių L3 fazėje', 643, 2, NULL, NULL),
	(5756, 19, 8, 1, 3, 0, 3, 1, 31, NULL, 'Vidutinė Q4 galia per minutę L3 fazėje', 644, 1, NULL, NULL),
	(5757, 19, 8, 2, 3, 0, 3, 2, 31, NULL, 'Vidutinė Q4 galia per 2 minutes L3 fazėje', 644, 1, NULL, NULL),
	(5758, 19, 8, 3, 3, 0, 3, 3, 31, NULL, 'Vidutinė Q4 galia per 30 minučių L3 fazėje', 644, 2, NULL, NULL),
	(5759, 19, 8, 4, 3, 0, 3, 4, 31, NULL, 'Vidutinė Q4 galia per valandą L3 fazėje', 644, 2, NULL, NULL),
	(5760, 19, 8, 5, 3, 0, 3, 5, 31, NULL, 'Vidutinė Q4 galia per parą L3 fazėje', 644, 3, NULL, NULL),
	(5761, 19, 8, 9, 3, 0, 3, 8, 31, NULL, 'Vidutinė Q4 galia per 3 minutes L3 fazėje', 644, 1, NULL, NULL),
	(5762, 19, 8, 10, 3, 0, 3, 9, 31, NULL, 'Vidutinė Q4 galia per 4 minutes L3 fazėje', 644, 1, NULL, NULL),
	(5763, 19, 8, 11, 3, 0, 3, 10, 31, NULL, 'Vidutinė Q4 galia per 5 minutes L3 fazėje', 644, 1, NULL, NULL),
	(5764, 19, 8, 12, 3, 0, 3, 11, 31, NULL, 'Vidutinė Q4 galia per 10 minučių L3 fazėje', 644, 1, NULL, NULL),
	(5765, 19, 8, 13, 3, 0, 3, 12, 31, NULL, 'Vidutinė Q4 galia per 15 minučių L3 fazėje', 644, 2, NULL, NULL),
	(5766, 19, 8, 14, 3, 0, 3, 13, 31, NULL, 'Vidutinė Q4 galia per 20 minučių L3 fazėje', 644, 2, NULL, NULL),
	(5767, 20, 1, 1, 3, 0, 7, 1, 32, NULL, 'Vidutinė S+ galia per minutę L1 fazėje', 633, 1, NULL, NULL),
	(5768, 20, 1, 2, 3, 0, 7, 2, 32, NULL, 'Vidutinė S+ galia per 2 minutes L1 fazėje', 633, 1, NULL, NULL),
	(5769, 20, 1, 3, 3, 0, 7, 3, 32, NULL, 'Vidutinė S+ galia per 30 minučių L1 fazėje', 633, 2, NULL, NULL),
	(5770, 20, 1, 4, 3, 0, 7, 4, 32, NULL, 'Vidutinė S+ galia per valandą L1 fazėje', 633, 2, NULL, NULL),
	(5771, 20, 1, 5, 3, 0, 7, 5, 32, NULL, 'Vidutinė S+ galia per parą L1 fazėje', 633, 3, NULL, NULL),
	(5772, 20, 1, 9, 3, 0, 7, 8, 32, NULL, 'Vidutinė S+ galia per 3 minutes L1 fazėje', 633, 1, NULL, NULL),
	(5773, 20, 1, 10, 3, 0, 7, 9, 32, NULL, 'Vidutinė S+ galia per 4 minutes L1 fazėje', 633, 1, NULL, NULL),
	(5774, 20, 1, 11, 3, 0, 7, 10, 32, NULL, 'Vidutinė S+ galia per 5 minutes L1 fazėje', 633, 1, NULL, NULL),
	(5775, 20, 1, 12, 3, 0, 7, 11, 32, NULL, 'Vidutinė S+ galia per 10 minučių L1 fazėje', 633, 1, NULL, NULL),
	(5776, 20, 1, 13, 3, 0, 7, 12, 32, NULL, 'Vidutinė S+ galia per 15 minučių L1 fazėje', 633, 2, NULL, NULL),
	(5777, 20, 1, 14, 3, 0, 7, 13, 32, NULL, 'Vidutinė S+ galia per 20 minučių L1 fazėje', 633, 2, NULL, NULL),
	(5778, 20, 2, 1, 3, 0, 7, 1, 32, NULL, 'Vidutinė S- galia per minutę L1 fazėje', 634, 1, NULL, NULL),
	(5779, 20, 2, 2, 3, 0, 7, 2, 32, NULL, 'Vidutinė S- galia per 2 minutes L1 fazėje', 634, 1, NULL, NULL),
	(5780, 20, 2, 3, 3, 0, 7, 3, 32, NULL, 'Vidutinė S- galia per 30 minučių L1 fazėje', 634, 2, NULL, NULL),
	(5781, 20, 2, 4, 3, 0, 7, 4, 32, NULL, 'Vidutinė S- galia per valandą L1 fazėje', 634, 2, NULL, NULL),
	(5782, 20, 2, 5, 3, 0, 7, 5, 32, NULL, 'Vidutinė S- galia per parą L1 fazėje', 634, 3, NULL, NULL),
	(5783, 20, 2, 9, 3, 0, 7, 8, 32, NULL, 'Vidutinė S- galia per 3 minutes L1 fazėje', 634, 1, NULL, NULL),
	(5784, 20, 2, 10, 3, 0, 7, 9, 32, NULL, 'Vidutinė S- galia per 4 minutes L1 fazėje', 634, 1, NULL, NULL),
	(5785, 20, 2, 11, 3, 0, 7, 10, 32, NULL, 'Vidutinė S- galia per 5 minutes L1 fazėje', 634, 1, NULL, NULL),
	(5786, 20, 2, 12, 3, 0, 7, 11, 32, NULL, 'Vidutinė S- galia per 10 minučių L1 fazėje', 634, 1, NULL, NULL),
	(5787, 20, 2, 13, 3, 0, 7, 12, 32, NULL, 'Vidutinė S- galia per 15 minučių L1 fazėje', 634, 2, NULL, NULL),
	(5788, 20, 2, 14, 3, 0, 7, 13, 32, NULL, 'Vidutinė S- galia per 20 minučių L1 fazėje', 634, 2, NULL, NULL),
	(5789, 21, 1, 1, 3, 0, 7, 1, 33, NULL, 'Vidutinė S+ galia per minutę L2 fazėje', 639, 1, NULL, NULL),
	(5790, 21, 1, 2, 3, 0, 7, 2, 33, NULL, 'Vidutinė S+ galia per 2 minutes L2 fazėje', 639, 1, NULL, NULL),
	(5791, 21, 1, 3, 3, 0, 7, 3, 33, NULL, 'Vidutinė S+ galia per 30 minučių L2 fazėje', 639, 2, NULL, NULL),
	(5792, 21, 1, 4, 3, 0, 7, 4, 33, NULL, 'Vidutinė S+ galia per valandą L2 fazėje', 639, 2, NULL, NULL),
	(5793, 21, 1, 5, 3, 0, 7, 5, 33, NULL, 'Vidutinė S+ galia per parą L2 fazėje', 639, 3, NULL, NULL),
	(5794, 21, 1, 9, 3, 0, 7, 8, 33, NULL, 'Vidutinė S+ galia per 3 minutes L2 fazėje', 639, 1, NULL, NULL),
	(5795, 21, 1, 10, 3, 0, 7, 9, 33, NULL, 'Vidutinė S+ galia per 4 minutes L2 fazėje', 639, 1, NULL, NULL),
	(5796, 21, 1, 11, 3, 0, 7, 10, 33, NULL, 'Vidutinė S+ galia per 5 minutes L2 fazėje', 639, 1, NULL, NULL),
	(5797, 21, 1, 12, 3, 0, 7, 11, 33, NULL, 'Vidutinė S+ galia per 10 minučių L2 fazėje', 639, 1, NULL, NULL),
	(5798, 21, 1, 13, 3, 0, 7, 12, 33, NULL, 'Vidutinė S+ galia per 15 minučių L2 fazėje', 639, 2, NULL, NULL),
	(5799, 21, 1, 14, 3, 0, 7, 13, 33, NULL, 'Vidutinė S+ galia per 20 minučių L2 fazėje', 639, 2, NULL, NULL),
	(5800, 21, 2, 1, 3, 0, 7, 1, 33, NULL, 'Vidutinė S- galia per minutę L2 fazėje', 640, 1, NULL, NULL),
	(5801, 21, 2, 2, 3, 0, 7, 2, 33, NULL, 'Vidutinė S- galia per 2 minutes L2 fazėje', 640, 1, NULL, NULL),
	(5802, 21, 2, 3, 3, 0, 7, 3, 33, NULL, 'Vidutinė S- galia per 30 minučių L2 fazėje', 640, 2, NULL, NULL),
	(5803, 21, 2, 4, 3, 0, 7, 4, 33, NULL, 'Vidutinė S- galia per valandą L2 fazėje', 640, 2, NULL, NULL),
	(5804, 21, 2, 5, 3, 0, 7, 5, 33, NULL, 'Vidutinė S- galia per parą L2 fazėje', 640, 3, NULL, NULL),
	(5805, 21, 2, 9, 3, 0, 7, 8, 33, NULL, 'Vidutinė S- galia per 3 minutes L2 fazėje', 640, 1, NULL, NULL),
	(5806, 21, 2, 10, 3, 0, 7, 9, 33, NULL, 'Vidutinė S- galia per 4 minutes L2 fazėje', 640, 1, NULL, NULL),
	(5807, 21, 2, 11, 3, 0, 7, 10, 33, NULL, 'Vidutinė S- galia per 5 minutes L2 fazėje', 640, 1, NULL, NULL),
	(5808, 21, 2, 12, 3, 0, 7, 11, 33, NULL, 'Vidutinė S- galia per 10 minučių L2 fazėje', 640, 1, NULL, NULL),
	(5809, 21, 2, 13, 3, 0, 7, 12, 33, NULL, 'Vidutinė S- galia per 15 minučių L2 fazėje', 640, 2, NULL, NULL),
	(5810, 21, 2, 14, 3, 0, 7, 13, 33, NULL, 'Vidutinė S- galia per 20 minučių L2 fazėje', 640, 2, NULL, NULL),
	(5811, 22, 1, 1, 3, 0, 7, 1, 34, NULL, 'Vidutinė S+ galia per minutę L3 fazėje', 645, 1, NULL, NULL),
	(5812, 22, 1, 2, 3, 0, 7, 2, 34, NULL, 'Vidutinė S+ galia per 2 minutes L3 fazėje', 645, 1, NULL, NULL),
	(5813, 22, 1, 3, 3, 0, 7, 3, 34, NULL, 'Vidutinė S+ galia per 30 minučių L3 fazėje', 645, 2, NULL, NULL),
	(5814, 22, 1, 4, 3, 0, 7, 4, 34, NULL, 'Vidutinė S+ galia per valandą L3 fazėje', 645, 2, NULL, NULL),
	(5815, 22, 1, 5, 3, 0, 7, 5, 34, NULL, 'Vidutinė S+ galia per parą L3 fazėje', 645, 3, NULL, NULL),
	(5816, 22, 1, 9, 3, 0, 7, 8, 34, NULL, 'Vidutinė S+ galia per 3 minutes L3 fazėje', 645, 1, NULL, NULL),
	(5817, 22, 1, 10, 3, 0, 7, 9, 34, NULL, 'Vidutinė S+ galia per 4 minutes L3 fazėje', 645, 1, NULL, NULL),
	(5818, 22, 1, 11, 3, 0, 7, 10, 34, NULL, 'Vidutinė S+ galia per 5 minutes L3 fazėje', 645, 1, NULL, NULL),
	(5819, 22, 1, 12, 3, 0, 7, 11, 34, NULL, 'Vidutinė S+ galia per 10 minučių L3 fazėje', 645, 1, NULL, NULL),
	(5820, 22, 1, 13, 3, 0, 7, 12, 34, NULL, 'Vidutinė S+ galia per 15 minučių L3 fazėje', 645, 2, NULL, NULL),
	(5821, 22, 1, 14, 3, 0, 7, 13, 34, NULL, 'Vidutinė S+ galia per 20 minučių L3 fazėje', 645, 2, NULL, NULL),
	(5822, 22, 2, 1, 3, 0, 7, 1, 34, NULL, 'Vidutinė S- galia per minutę L3 fazėje', 646, 1, NULL, NULL),
	(5823, 22, 2, 2, 3, 0, 7, 2, 34, NULL, 'Vidutinė S- galia per 2 minutes L3 fazėje', 646, 1, NULL, NULL),
	(5824, 22, 2, 3, 3, 0, 7, 3, 34, NULL, 'Vidutinė S- galia per 30 minučių L3 fazėje', 646, 2, NULL, NULL),
	(5825, 22, 2, 4, 3, 0, 7, 4, 34, NULL, 'Vidutinė S- galia per valandą L3 fazėje', 646, 2, NULL, NULL),
	(5826, 22, 2, 5, 3, 0, 7, 5, 34, NULL, 'Vidutinė S- galia per parą L3 fazėje', 646, 3, NULL, NULL),
	(5827, 22, 2, 9, 3, 0, 7, 8, 34, NULL, 'Vidutinė S- galia per 3 minutes L3 fazėje', 646, 1, NULL, NULL),
	(5828, 22, 2, 10, 3, 0, 7, 9, 34, NULL, 'Vidutinė S- galia per 4 minutes L3 fazėje', 646, 1, NULL, NULL),
	(5829, 22, 2, 11, 3, 0, 7, 10, 34, NULL, 'Vidutinė S- galia per 5 minutes L3 fazėje', 646, 1, NULL, NULL),
	(5830, 22, 2, 12, 3, 0, 7, 11, 34, NULL, 'Vidutinė S- galia per 10 minučių L3 fazėje', 646, 1, NULL, NULL),
	(5831, 22, 2, 13, 3, 0, 7, 12, 34, NULL, 'Vidutinė S- galia per 15 minučių L3 fazėje', 646, 2, NULL, NULL),
	(5832, 22, 2, 14, 3, 0, 7, 13, 34, NULL, 'Vidutinė S- galia per 20 minučių L3 fazėje', 646, 2, NULL, NULL),
	(5833, 17, 9, 1, 3, 0, 3, 1, 29, NULL, 'Vidutinė indukcinė galia per minutę L1 fazėje', 649, 1, NULL, NULL),
	(5834, 17, 9, 2, 3, 0, 3, 2, 29, NULL, 'Vidutinė indukcinė galia per 2 minutes L1 fazėje', 649, 1, NULL, NULL),
	(5835, 17, 9, 3, 3, 0, 3, 3, 29, NULL, 'Vidutinė indukcinė galia per 30 minučių L1 fazėje', 649, 2, NULL, NULL),
	(5836, 17, 9, 4, 3, 0, 3, 4, 29, NULL, 'Vidutinė indukcinė galia per valandą L1 fazėje', 649, 2, NULL, NULL),
	(5837, 17, 9, 5, 3, 0, 3, 5, 29, NULL, 'Vidutinė indukcinė galia per parą L1 fazėje', 649, 3, NULL, NULL),
	(5838, 17, 9, 9, 3, 0, 3, 8, 29, NULL, 'Vidutinė indukcinė galia per 3 minutes L1 fazėje', 649, 1, NULL, NULL),
	(5839, 17, 9, 10, 3, 0, 3, 9, 29, NULL, 'Vidutinė indukcinė galia per 4 minutes L1 fazėje', 649, 1, NULL, NULL),
	(5840, 17, 9, 11, 3, 0, 3, 10, 29, NULL, 'Vidutinė indukcinė galia per 5 minutes L1 fazėje', 649, 1, NULL, NULL),
	(5841, 17, 9, 12, 3, 0, 3, 11, 29, NULL, 'Vidutinė indukcinė galia per 10 minučių L1 fazėje', 649, 1, NULL, NULL),
	(5842, 17, 9, 13, 3, 0, 3, 12, 29, NULL, 'Vidutinė indukcinė galia per 15 minučių L1 fazėje', 649, 2, NULL, NULL),
	(5843, 17, 9, 14, 3, 0, 3, 13, 29, NULL, 'Vidutinė indukcinė galia per 20 minučių L1 fazėje', 649, 2, NULL, NULL),
	(5844, 17, -1, 1, 3, 0, 3, 1, 29, NULL, 'Vidutinė talpuminė galia per minutę L1 fazėje', 650, 1, NULL, NULL),
	(5845, 17, -1, 2, 3, 0, 3, 2, 29, NULL, 'Vidutinė talpuminė galia per 2 minutes L1 fazėje', 650, 1, NULL, NULL),
	(5846, 17, -1, 3, 3, 0, 3, 3, 29, NULL, 'Vidutinė talpuminė galia per 30 minučių L1 fazėje', 650, 2, NULL, NULL),
	(5847, 17, -1, 4, 3, 0, 3, 4, 29, NULL, 'Vidutinė talpuminė galia per valandą L1 fazėje', 650, 2, NULL, NULL),
	(5848, 17, -1, 5, 3, 0, 3, 5, 29, NULL, 'Vidutinė talpuminė galia per parą L1 fazėje', 650, 3, NULL, NULL),
	(5849, 17, -1, 9, 3, 0, 3, 8, 29, NULL, 'Vidutinė talpuminė galia per 3 minutes L1 fazėje', 650, 1, NULL, NULL),
	(5850, 17, -1, 10, 3, 0, 3, 9, 29, NULL, 'Vidutinė talpuminė galia per 4 minutes L1 fazėje', 650, 1, NULL, NULL),
	(5851, 17, -1, 11, 3, 0, 3, 10, 29, NULL, 'Vidutinė talpuminė galia per 5 minutes L1 fazėje', 650, 1, NULL, NULL),
	(5852, 17, -1, 12, 3, 0, 3, 11, 29, NULL, 'Vidutinė talpuminė galia per 10 minučių L1 fazėje', 650, 1, NULL, NULL),
	(5853, 17, -1, 13, 3, 0, 3, 12, 29, NULL, 'Vidutinė talpuminė galia per 15 minučių L1 fazėje', 650, 2, NULL, NULL),
	(5854, 17, -1, 14, 3, 0, 3, 13, 29, NULL, 'Vidutinė talpuminė galia per 20 minučių L1 fazėje', 650, 2, NULL, NULL),
	(5855, 18, 9, 1, 3, 0, 3, 1, 30, NULL, 'Vidutinė indukcinė galia per minutę L2 fazėje', 651, 1, NULL, NULL),
	(5856, 18, 9, 2, 3, 0, 3, 2, 30, NULL, 'Vidutinė indukcinė galia per 2 minutes L2 fazėje', 651, 1, NULL, NULL),
	(5857, 18, 9, 3, 3, 0, 3, 3, 30, NULL, 'Vidutinė indukcinė galia per 30 minučių L2 fazėje', 651, 2, NULL, NULL),
	(5858, 18, 9, 4, 3, 0, 3, 4, 30, NULL, 'Vidutinė indukcinė galia per valandą L2 fazėje', 651, 2, NULL, NULL),
	(5859, 18, 9, 5, 3, 0, 3, 5, 30, NULL, 'Vidutinė indukcinė galia per parą L2 fazėje', 651, 3, NULL, NULL),
	(5860, 18, 9, 9, 3, 0, 3, 8, 30, NULL, 'Vidutinė indukcinė galia per 3 minutes L2 fazėje', 651, 1, NULL, NULL),
	(5861, 18, 9, 10, 3, 0, 3, 9, 30, NULL, 'Vidutinė indukcinė galia per 4 minutes L2 fazėje', 651, 1, NULL, NULL),
	(5862, 18, 9, 11, 3, 0, 3, 10, 30, NULL, 'Vidutinė indukcinė galia per 5 minutes L2 fazėje', 651, 1, NULL, NULL),
	(5863, 18, 9, 12, 3, 0, 3, 11, 30, NULL, 'Vidutinė indukcinė galia per 10 minučių L2 fazėje', 651, 1, NULL, NULL),
	(5864, 18, 9, 13, 3, 0, 3, 12, 30, NULL, 'Vidutinė indukcinė galia per 15 minučių L2 fazėje', 651, 2, NULL, NULL),
	(5865, 18, 9, 14, 3, 0, 3, 13, 30, NULL, 'Vidutinė indukcinė galia per 20 minučių L2 fazėje', 651, 2, NULL, NULL),
	(5866, 18, -1, 1, 3, 0, 3, 1, 30, NULL, 'Vidutinė talpuminė galia per minutę L2 fazėje', 652, 1, NULL, NULL),
	(5867, 18, -1, 2, 3, 0, 3, 2, 30, NULL, 'Vidutinė talpuminė galia per 2 minutes L2 fazėje', 652, 1, NULL, NULL),
	(5868, 18, -1, 3, 3, 0, 3, 3, 30, NULL, 'Vidutinė talpuminė galia per 30 minučių L2 fazėje', 652, 2, NULL, NULL),
	(5869, 18, -1, 4, 3, 0, 3, 4, 30, NULL, 'Vidutinė talpuminė galia per valandą L2 fazėje', 652, 2, NULL, NULL),
	(5870, 18, -1, 5, 3, 0, 3, 5, 30, NULL, 'Vidutinė talpuminė galia per parą L2 fazėje', 652, 3, NULL, NULL),
	(5871, 18, -1, 9, 3, 0, 3, 8, 30, NULL, 'Vidutinė talpuminė galia per 3 minutes L2 fazėje', 652, 1, NULL, NULL),
	(5872, 18, -1, 10, 3, 0, 3, 9, 30, NULL, 'Vidutinė talpuminė galia per 4 minutes L2 fazėje', 652, 1, NULL, NULL),
	(5873, 18, -1, 11, 3, 0, 3, 10, 30, NULL, 'Vidutinė talpuminė galia per 5 minutes L2 fazėje', 652, 1, NULL, NULL),
	(5874, 18, -1, 12, 3, 0, 3, 11, 30, NULL, 'Vidutinė talpuminė galia per 10 minučių L2 fazėje', 652, 1, NULL, NULL),
	(5875, 18, -1, 13, 3, 0, 3, 12, 30, NULL, 'Vidutinė talpuminė galia per 15 minučių L2 fazėje', 652, 2, NULL, NULL),
	(5876, 18, -1, 14, 3, 0, 3, 13, 30, NULL, 'Vidutinė talpuminė galia per 20 minučių L2 fazėje', 652, 2, NULL, NULL),
	(5877, 19, -1, 1, 3, 0, 3, 1, 31, NULL, 'Vidutinė talpuminė galia per minutę L3 fazėje', 654, 1, NULL, NULL),
	(5878, 19, -1, 2, 3, 0, 3, 2, 31, NULL, 'Vidutinė talpuminė galia per 2 minutes L3 fazėje', 654, 1, NULL, NULL),
	(5879, 19, -1, 3, 3, 0, 3, 3, 31, NULL, 'Vidutinė talpuminė galia per 30 minučių L3 fazėje', 654, 2, NULL, NULL),
	(5880, 19, -1, 4, 3, 0, 3, 4, 31, NULL, 'Vidutinė talpuminė galia per valandą L3 fazėje', 654, 2, NULL, NULL),
	(5881, 19, -1, 5, 3, 0, 3, 5, 31, NULL, 'Vidutinė talpuminė galia per parą L3 fazėje', 654, 3, NULL, NULL),
	(5882, 19, -1, 9, 3, 0, 3, 8, 31, NULL, 'Vidutinė talpuminė galia per 3 minutes L3 fazėje', 654, 1, NULL, NULL),
	(5883, 19, -1, 10, 3, 0, 3, 9, 31, NULL, 'Vidutinė talpuminė galia per 4 minutes L3 fazėje', 654, 1, NULL, NULL),
	(5884, 19, -1, 11, 3, 0, 3, 10, 31, NULL, 'Vidutinė talpuminė galia per 5 minutes L3 fazėje', 654, 1, NULL, NULL),
	(5885, 19, -1, 12, 3, 0, 3, 11, 31, NULL, 'Vidutinė talpuminė galia per 10 minučių L3 fazėje', 654, 1, NULL, NULL),
	(5886, 19, -1, 13, 3, 0, 3, 12, 31, NULL, 'Vidutinė talpuminė galia per 15 minučių L3 fazėje', 654, 2, NULL, NULL),
	(5887, 19, -1, 14, 3, 0, 3, 13, 31, NULL, 'Vidutinė talpuminė galia per 20 minučių L3 fazėje', 654, 2, NULL, NULL),
	(5888, 19, 9, 1, 3, 0, 3, 1, 31, NULL, 'Vidutinė indukcinė galia per minutę L3 fazėje', 653, 1, NULL, NULL),
	(5889, 19, 9, 2, 3, 0, 3, 2, 31, NULL, 'Vidutinė indukcinė galia per 2 minutes L3 fazėje', 653, 1, NULL, NULL),
	(5890, 19, 9, 3, 3, 0, 3, 3, 31, NULL, 'Vidutinė indukcinė galia per 30 minučių L3 fazėje', 653, 2, NULL, NULL),
	(5891, 19, 9, 4, 3, 0, 3, 4, 31, NULL, 'Vidutinė indukcinė galia per valandą L3 fazėje', 653, 2, NULL, NULL),
	(5892, 19, 9, 5, 3, 0, 3, 5, 31, NULL, 'Vidutinė indukcinė galia per parą L3 fazėje', 653, 3, NULL, NULL),
	(5893, 19, 9, 9, 3, 0, 3, 8, 31, NULL, 'Vidutinė indukcinė galia per 3 minutes L3 fazėje', 653, 1, NULL, NULL),
	(5894, 19, 9, 10, 3, 0, 3, 9, 31, NULL, 'Vidutinė indukcinė galia per 4 minutes L3 fazėje', 653, 1, NULL, NULL),
	(5895, 19, 9, 11, 3, 0, 3, 10, 31, NULL, 'Vidutinė indukcinė galia per 5 minutes L3 fazėje', 653, 1, NULL, NULL),
	(5896, 19, 9, 12, 3, 0, 3, 11, 31, NULL, 'Vidutinė indukcinė galia per 10 minučių L3 fazėje', 653, 1, NULL, NULL),
	(5897, 19, 9, 13, 3, 0, 3, 12, 31, NULL, 'Vidutinė indukcinė galia per 15 minučių L3 fazėje', 653, 2, NULL, NULL),
	(5898, 19, 9, 14, 3, 0, 3, 13, 31, NULL, 'Vidutinė indukcinė galia per 20 minučių L3 fazėje', 653, 2, NULL, NULL),
	(5899, 3, 9, 1, 3, 0, 3, 1, 16, NULL, 'Vidutinė indukcinė galia per minutę', 647, 1, NULL, NULL),
	(5900, 3, 9, 2, 3, 0, 3, 2, 16, NULL, 'Vidutinė indukcinė galia per 2 minutes', 647, 1, NULL, NULL),
	(5901, 3, 9, 3, 3, 0, 3, 3, 16, NULL, 'Vidutinė indukcinė galia per 30 minučių', 647, 2, NULL, NULL),
	(5902, 3, 9, 4, 3, 0, 3, 4, 16, NULL, 'Vidutinė indukcinė galia per valandą', 647, 2, NULL, NULL),
	(5903, 3, 9, 5, 3, 0, 3, 5, 16, NULL, 'Vidutinė indukcinė galia per parą', 647, 3, NULL, NULL),
	(5904, 3, 9, 9, 3, 0, 3, 8, 16, NULL, 'Vidutinė indukcinė galia per 3 minutes', 647, 1, NULL, NULL),
	(5905, 3, 9, 10, 3, 0, 3, 9, 16, NULL, 'Vidutinė indukcinė galia per 4 minutes', 647, 1, NULL, NULL),
	(5906, 3, 9, 11, 3, 0, 3, 10, 16, NULL, 'Vidutinė indukcinė galia per 5 minutes', 647, 1, NULL, NULL),
	(5907, 3, 9, 12, 3, 0, 3, 11, 16, NULL, 'Vidutinė indukcinė galia per 10 minučių', 647, 1, NULL, NULL),
	(5908, 3, 9, 13, 3, 0, 3, 12, 16, NULL, 'Vidutinė indukcinė galia per 15 minučių', 647, 2, NULL, NULL),
	(5909, 3, 9, 14, 3, 0, 3, 13, 16, NULL, 'Vidutinė indukcinė galia per 20 minučių', 647, 2, NULL, NULL),
	(5910, 3, -1, 1, 3, 0, 3, 1, 16, NULL, 'Vidutinė talpuminė galia per minutę', 648, 1, NULL, NULL),
	(5911, 3, -1, 2, 3, 0, 3, 2, 16, NULL, 'Vidutinė talpuminė galia per 2 minutes', 648, 1, NULL, NULL),
	(5912, 3, -1, 3, 3, 0, 3, 3, 16, NULL, 'Vidutinė talpuminė galia per 30 minučių', 648, 2, NULL, NULL),
	(5913, 3, -1, 4, 3, 0, 3, 4, 16, NULL, 'Vidutinė talpuminė galia per valandą', 648, 2, NULL, NULL),
	(5914, 3, -1, 5, 3, 0, 3, 5, 16, NULL, 'Vidutinė talpuminė galia per parą', 648, 3, NULL, NULL),
	(5915, 3, -1, 9, 3, 0, 3, 8, 16, NULL, 'Vidutinė talpuminė galia per 3 minutes', 648, 1, NULL, NULL),
	(5916, 3, -1, 10, 3, 0, 3, 9, 16, NULL, 'Vidutinė talpuminė galia per 4 minutes', 648, 1, NULL, NULL),
	(5917, 3, -1, 11, 3, 0, 3, 10, 16, NULL, 'Vidutinė talpuminė galia per 5 minutes', 648, 1, NULL, NULL),
	(5918, 3, -1, 12, 3, 0, 3, 11, 16, NULL, 'Vidutinė talpuminė galia per 10 minučių', 648, 1, NULL, NULL),
	(5919, 3, -1, 13, 3, 0, 3, 12, 16, NULL, 'Vidutinė talpuminė galia per 15 minučių', 648, 2, NULL, NULL),
	(5920, 3, -1, 14, 3, 0, 3, 13, 16, NULL, 'Vidutinė talpuminė galia per 20 minučių', 648, 2, NULL, NULL),
	(5921, 34, 1, 3, 4, 0, 7, 6, 44, NULL, 'Maksimali pusvalandinė S+ galia per mėnesį', 663, 4, NULL, NULL),
	(5922, 34, 1, 4, 4, 0, 7, 6, 44, NULL, 'Maksimali valandinė S+ galia per mėnesį', 663, 4, NULL, NULL),
	(5923, 34, 1, 9, 4, 0, 7, 6, 44, NULL, 'Maksimali 3 minučių S+ galia per mėnesį', 663, 4, NULL, NULL),
	(5924, 34, 1, 13, 4, 0, 7, 6, 44, NULL, 'Maksimali 15 minučių S+ galia per mėnesį', 663, 4, NULL, NULL),
	(5925, 34, 1, 3, 4, 0, 7, 5, 44, NULL, 'Maksimali pusvalandinė S+ galia per parą', 665, 3, NULL, NULL),
	(5926, 34, 1, 4, 4, 0, 7, 5, 44, NULL, 'Maksimali valandinė S+ galia per parą', 665, 3, NULL, NULL),
	(5927, 34, 1, 9, 4, 0, 7, 5, 44, NULL, 'Maksimali 3 minučių S+ galia per parą', 665, 3, NULL, NULL),
	(5928, 34, 1, 13, 4, 0, 7, 5, 44, NULL, 'Maksimali 15 minučių S+ galia per parą', 665, 3, NULL, NULL),
	(5929, 34, 2, 3, 4, 0, 7, 6, 44, NULL, 'Maksimali pusvalandinė S- galia per mėnesį', 664, 4, NULL, NULL),
	(5930, 34, 2, 4, 4, 0, 7, 6, 44, NULL, 'Maksimali valandinė S- galia per mėnesį', 664, 4, NULL, NULL),
	(5931, 34, 2, 9, 4, 0, 7, 6, 44, NULL, 'Maksimali 3 minučių S- galia per mėnesį', 664, 4, NULL, NULL),
	(5932, 34, 2, 13, 4, 0, 7, 6, 44, NULL, 'Maksimali 15 minučių S- galia per mėnesį', 664, 4, NULL, NULL),
	(5933, 34, 2, 3, 4, 0, 7, 5, 44, NULL, 'Maksimali pusvalandinė S- galia per parą', 666, 3, NULL, NULL),
	(5934, 34, 2, 4, 4, 0, 7, 5, 44, NULL, 'Maksimali valandinė S- galia per parą', 666, 3, NULL, NULL),
	(5935, 34, 2, 9, 4, 0, 7, 5, 44, NULL, 'Maksimali 3 minučių S- galia per parą', 666, 3, NULL, NULL),
	(5936, 34, 2, 13, 4, 0, 7, 5, 44, NULL, 'Maksimali 15 minučių S- galia per parą', 666, 3, NULL, NULL),
	(5937, 3, 5, 3, 4, 0, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q1 galia per mėnesį', 655, 4, NULL, NULL),
	(5938, 3, 6, 3, 4, 0, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q2 galia per mėnesį', 656, 4, NULL, NULL),
	(5939, 3, 7, 3, 4, 0, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q3 galia per mėnesį', 657, 4, NULL, NULL),
	(5940, 3, 8, 3, 4, 0, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q4 galia per mėnesį', 658, 4, NULL, NULL),
	(5941, 3, 5, 4, 4, 0, 3, 6, 16, NULL, 'Maksimali valandinė Q1 galia per mėnesį', 655, 4, NULL, NULL),
	(5942, 3, 6, 4, 4, 0, 3, 6, 16, NULL, 'Maksimali valandinė Q2 galia per mėnesį', 656, 4, NULL, NULL),
	(5943, 3, 7, 4, 4, 0, 3, 6, 16, NULL, 'Maksimali valandinė Q3 galia per mėnesį', 657, 4, NULL, NULL),
	(5944, 3, 8, 4, 4, 0, 3, 6, 16, NULL, 'Maksimali valandinė Q4 galia per mėnesį', 658, 4, NULL, NULL),
	(5945, 3, 5, 9, 4, 0, 3, 6, 16, NULL, 'Maksimali 3 minučių Q1 galia per mėnesį', 655, 4, NULL, NULL),
	(5946, 3, 6, 9, 4, 0, 3, 6, 16, NULL, 'Maksimali 3 minučių Q2 galia per mėnesį', 656, 4, NULL, NULL),
	(5947, 3, 7, 9, 4, 0, 3, 6, 16, NULL, 'Maksimali 3 minučių Q3 galia per mėnesį', 657, 4, NULL, NULL),
	(5948, 3, 8, 9, 4, 0, 3, 6, 16, NULL, 'Maksimali 3 minučių Q4 galia per mėnesį', 658, 4, NULL, NULL),
	(5949, 3, 5, 13, 4, 0, 3, 6, 16, NULL, 'Maksimali 15 minučių Q1 galia per mėnesį', 655, 4, NULL, NULL),
	(5950, 3, 6, 13, 4, 0, 3, 6, 16, NULL, 'Maksimali 15 minučių Q2 galia per mėnesį', 656, 4, NULL, NULL),
	(5951, 3, 7, 13, 4, 0, 3, 6, 16, NULL, 'Maksimali 15 minučių Q3 galia per mėnesį', 657, 4, NULL, NULL),
	(5952, 3, 8, 13, 4, 0, 3, 6, 16, NULL, 'Maksimali 15 minučių Q4 galia per mėnesį', 658, 4, NULL, NULL),
	(5953, 3, 5, 3, 4, 0, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q1 galia per parą', 659, 3, NULL, NULL),
	(5954, 3, 6, 3, 4, 0, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q2 galia per parą', 660, 3, NULL, NULL),
	(5955, 3, 7, 3, 4, 0, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q3 galia per parą', 661, 3, NULL, NULL),
	(5956, 3, 8, 3, 4, 0, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q4 galia per parą', 662, 3, NULL, NULL),
	(5957, 3, 5, 4, 4, 0, 3, 5, 16, NULL, 'Maksimali valandinė Q1 galia per parą', 659, 3, NULL, NULL),
	(5958, 3, 6, 4, 4, 0, 3, 5, 16, NULL, 'Maksimali valandinė Q2 galia per parą', 660, 3, NULL, NULL),
	(5959, 3, 7, 4, 4, 0, 3, 5, 16, NULL, 'Maksimali valandinė Q3 galia per parą', 661, 3, NULL, NULL),
	(5960, 3, 8, 4, 4, 0, 3, 5, 16, NULL, 'Maksimali valandinė Q4 galia per parą', 662, 3, NULL, NULL),
	(5961, 3, 5, 9, 4, 0, 3, 5, 16, NULL, 'Maksimali 3 minučių Q1 galia per parą', 659, 3, NULL, NULL),
	(5962, 3, 6, 9, 4, 0, 3, 5, 16, NULL, 'Maksimali 3 minučių Q2 galia per parą', 660, 3, NULL, NULL),
	(5963, 3, 7, 9, 4, 0, 3, 5, 16, NULL, 'Maksimali 3 minučių Q3 galia per parą', 661, 3, NULL, NULL),
	(5964, 3, 8, 9, 4, 0, 3, 5, 16, NULL, 'Maksimali 3 minučių Q4 galia per parą', 662, 3, NULL, NULL),
	(5965, 3, 5, 13, 4, 0, 3, 5, 16, NULL, 'Maksimali 15 minučių Q1 galia per parą', 659, 3, NULL, NULL),
	(5966, 3, 6, 13, 4, 0, 3, 5, 16, NULL, 'Maksimali 15 minučių Q2 galia per parą', 660, 3, NULL, NULL),
	(5967, 3, 7, 13, 4, 0, 3, 5, 16, NULL, 'Maksimali 15 minučių Q3 galia per parą', 661, 3, NULL, NULL),
	(5968, 3, 8, 13, 4, 0, 3, 5, 16, NULL, 'Maksimali 15 minučių Q4 galia per parą', 662, 3, NULL, NULL),
	(5969, 1, 0, 8, 2, 0, 2, 7, 14, NULL, 'Suminė A energija', 682, 5, NULL, NULL),
	(5970, 1, 0, 8, 2, 0, 2, 6, 14, NULL, 'Suminė A energija, fiksuojama kas mėnesį', 682, 5, NULL, NULL),
	(5971, 1, 0, 8, 2, 0, 2, 5, 14, NULL, 'Suminė A energija, fiksuojama kas parą', 682, 5, NULL, NULL),
	(5972, 1, 0, 8, 2, 0, 2, 4, 14, NULL, 'Suminė A energija, fiksuojama kas valandą', 682, 5, NULL, NULL),
	(5973, 1, 0, 8, 2, 0, 2, 12, 14, NULL, 'Suminė A energija, fiksuojama kas 15 minučių', 682, 5, NULL, NULL),
	(5974, 1, 0, 8, 2, 0, 2, 13, 14, NULL, 'Suminė A energija, fiksuojama kas 20 minučių', 682, 5, NULL, NULL),
	(5975, 1, 0, 8, 2, 0, 2, 3, 14, NULL, 'Suminė A energija, fiksuojama kas 30 minučių', 682, 5, NULL, NULL),
	(5976, 1, 0, 8, 2, 1, 2, 7, 14, NULL, 'Suminė A energija pagal 1 tarifą', 683, 5, NULL, NULL),
	(5977, 1, 0, 8, 2, 1, 2, 6, 14, NULL, 'Suminė A energija pagal 1 tarifą, fiksuojama kas mėnesį', 683, 5, NULL, NULL),
	(5978, 1, 0, 8, 2, 1, 2, 5, 14, NULL, 'Suminė A energija pagal 1 tarifą, fiksuojama kas parą', 683, 5, NULL, NULL),
	(5979, 1, 0, 8, 2, 1, 2, 4, 14, NULL, 'Suminė A energija pagal 1 tarifą, fiksuojama kas valandą', 683, 5, NULL, NULL),
	(5980, 1, 0, 8, 2, 1, 2, 12, 14, NULL, 'Suminė A energija pagal 1 tarifą, fiksuojama kas 15 minučių', 683, 5, NULL, NULL),
	(5981, 1, 0, 8, 2, 1, 2, 13, 14, NULL, 'Suminė A energija pagal 1 tarifą, fiksuojama kas 20 minučių', 683, 5, NULL, NULL),
	(5982, 1, 0, 8, 2, 1, 2, 3, 14, NULL, 'Suminė A energija pagal 1 tarifą, fiksuojama kas 30 minučių', 683, 5, NULL, NULL),
	(5983, 1, 0, 8, 2, 2, 2, 7, 14, NULL, 'Suminė A energija pagal 2 tarifą', 684, 5, NULL, NULL),
	(5984, 1, 0, 8, 2, 2, 2, 6, 14, NULL, 'Suminė A energija pagal 2 tarifą, fiksuojama kas mėnesį', 684, 5, NULL, NULL),
	(5985, 1, 0, 8, 2, 2, 2, 5, 14, NULL, 'Suminė A energija pagal 2 tarifą, fiksuojama kas parą', 684, 5, NULL, NULL),
	(5986, 1, 0, 8, 2, 2, 2, 4, 14, NULL, 'Suminė A energija pagal 2 tarifą, fiksuojama kas valandą', 684, 5, NULL, NULL),
	(5987, 1, 0, 8, 2, 2, 2, 12, 14, NULL, 'Suminė A energija pagal 2 tarifą, fiksuojama kas 15 minučių', 684, 5, NULL, NULL),
	(5988, 1, 0, 8, 2, 2, 2, 13, 14, NULL, 'Suminė A energija pagal 2 tarifą, fiksuojama kas 20 minučių', 684, 5, NULL, NULL),
	(5989, 1, 0, 8, 2, 2, 2, 3, 14, NULL, 'Suminė A energija pagal 2 tarifą, fiksuojama kas 30 minučių', 684, 5, NULL, NULL),
	(5990, 1, 0, 8, 2, 3, 2, 7, 14, NULL, 'Suminė A energija pagal 3 tarifą', 685, 5, NULL, NULL),
	(5991, 1, 0, 8, 2, 3, 2, 6, 14, NULL, 'Suminė A energija pagal 3 tarifą, fiksuojama kas mėnesį', 685, 5, NULL, NULL),
	(5992, 1, 0, 8, 2, 3, 2, 5, 14, NULL, 'Suminė A energija pagal 3 tarifą, fiksuojama kas parą', 685, 5, NULL, NULL),
	(5993, 1, 0, 8, 2, 3, 2, 4, 14, NULL, 'Suminė A energija pagal 3 tarifą, fiksuojama kas valandą', 685, 5, NULL, NULL),
	(5994, 1, 0, 8, 2, 3, 2, 12, 14, NULL, 'Suminė A energija pagal 3 tarifą, fiksuojama kas 15 minučių', 685, 5, NULL, NULL),
	(5995, 1, 0, 8, 2, 3, 2, 13, 14, NULL, 'Suminė A energija pagal 3 tarifą, fiksuojama kas 20 minučių', 685, 5, NULL, NULL),
	(5996, 1, 0, 8, 2, 3, 2, 3, 14, NULL, 'Suminė A energija pagal 3 tarifą, fiksuojama kas 30 minučių', 685, 5, NULL, NULL),
	(5997, 1, 0, 8, 2, 4, 2, 7, 14, NULL, 'Suminė A energija pagal 4 tarifą', 686, 5, NULL, NULL),
	(5998, 1, 0, 8, 2, 4, 2, 6, 14, NULL, 'Suminė A energija pagal 4 tarifą, fiksuojama kas mėnesį', 686, 5, NULL, NULL),
	(5999, 1, 0, 8, 2, 4, 2, 5, 14, NULL, 'Suminė A energija pagal 4 tarifą, fiksuojama kas parą', 686, 5, NULL, NULL),
	(6000, 1, 0, 8, 2, 4, 2, 4, 14, NULL, 'Suminė A energija pagal 4 tarifą, fiksuojama kas valandą', 686, 5, NULL, NULL),
	(6001, 1, 0, 8, 2, 4, 2, 12, 14, NULL, 'Suminė A energija pagal 4 tarifą, fiksuojama kas 15 minučių', 686, 5, NULL, NULL),
	(6002, 1, 0, 8, 2, 4, 2, 13, 14, NULL, 'Suminė A energija pagal 4 tarifą, fiksuojama kas 20 minučių', 686, 5, NULL, NULL),
	(6003, 1, 0, 8, 2, 4, 2, 3, 14, NULL, 'Suminė A energija pagal 4 tarifą, fiksuojama kas 30 minučių', 686, 5, NULL, NULL),
	(6004, 1, 0, 8, 2, 5, 2, 7, 14, NULL, 'Suminė A energija pagal 5 tarifą', 687, 5, NULL, NULL),
	(6005, 1, 0, 8, 2, 5, 2, 6, 14, NULL, 'Suminė A energija pagal 5 tarifą, fiksuojama kas mėnesį', 687, 5, NULL, NULL),
	(6006, 1, 0, 8, 2, 5, 2, 5, 14, NULL, 'Suminė A energija pagal 5 tarifą, fiksuojama kas parą', 687, 5, NULL, NULL),
	(6007, 1, 0, 8, 2, 5, 2, 4, 14, NULL, 'Suminė A energija pagal 5 tarifą, fiksuojama kas valandą', 687, 5, NULL, NULL),
	(6008, 1, 0, 8, 2, 5, 2, 12, 14, NULL, 'Suminė A energija pagal 5 tarifą, fiksuojama kas 15 minučių', 687, 5, NULL, NULL),
	(6009, 1, 0, 8, 2, 5, 2, 13, 14, NULL, 'Suminė A energija pagal 5 tarifą, fiksuojama kas 20 minučių', 687, 5, NULL, NULL),
	(6010, 1, 0, 8, 2, 5, 2, 3, 14, NULL, 'Suminė A energija pagal 5 tarifą, fiksuojama kas 30 minučių', 687, 5, NULL, NULL),
	(6011, 1, 0, 8, 2, 6, 2, 7, 14, NULL, 'Suminė A energija pagal 6 tarifą', 688, 5, NULL, NULL),
	(6012, 1, 0, 8, 2, 6, 2, 6, 14, NULL, 'Suminė A energija pagal 6 tarifą, fiksuojama kas mėnesį', 688, 5, NULL, NULL),
	(6013, 1, 0, 8, 2, 6, 2, 5, 14, NULL, 'Suminė A energija pagal 6 tarifą, fiksuojama kas parą', 688, 5, NULL, NULL),
	(6014, 1, 0, 8, 2, 6, 2, 4, 14, NULL, 'Suminė A energija pagal 6 tarifą, fiksuojama kas valandą', 688, 5, NULL, NULL),
	(6015, 1, 0, 8, 2, 6, 2, 12, 14, NULL, 'Suminė A energija pagal 6 tarifą, fiksuojama kas 15 minučių', 688, 5, NULL, NULL),
	(6016, 1, 0, 8, 2, 6, 2, 13, 14, NULL, 'Suminė A energija pagal 6 tarifą, fiksuojama kas 20 minučių', 688, 5, NULL, NULL),
	(6017, 1, 0, 8, 2, 6, 2, 3, 14, NULL, 'Suminė A energija pagal 6 tarifą, fiksuojama kas 30 minučių', 688, 5, NULL, NULL),
	(6018, 1, 0, 8, 2, 7, 2, 7, 14, NULL, 'Suminė A energija pagal 7 tarifą', 689, 5, NULL, NULL),
	(6019, 1, 0, 8, 2, 7, 2, 6, 14, NULL, 'Suminė A energija pagal 7 tarifą, fiksuojama kas mėnesį', 689, 5, NULL, NULL),
	(6020, 1, 0, 8, 2, 7, 2, 5, 14, NULL, 'Suminė A energija pagal 7 tarifą, fiksuojama kas parą', 689, 5, NULL, NULL),
	(6021, 1, 0, 8, 2, 7, 2, 4, 14, NULL, 'Suminė A energija pagal 7 tarifą, fiksuojama kas valandą', 689, 5, NULL, NULL),
	(6022, 1, 0, 8, 2, 7, 2, 12, 14, NULL, 'Suminė A energija pagal 7 tarifą, fiksuojama kas 15 minučių', 689, 5, NULL, NULL),
	(6023, 1, 0, 8, 2, 7, 2, 13, 14, NULL, 'Suminė A energija pagal 7 tarifą, fiksuojama kas 20 minučių', 689, 5, NULL, NULL),
	(6024, 1, 0, 8, 2, 7, 2, 3, 14, NULL, 'Suminė A energija pagal 7 tarifą, fiksuojama kas 30 minučių', 689, 5, NULL, NULL),
	(6025, 1, 0, 8, 2, 8, 2, 7, 14, NULL, 'Suminė A energija pagal 8 tarifą', 690, 5, NULL, NULL),
	(6026, 1, 0, 8, 2, 8, 2, 6, 14, NULL, 'Suminė A energija pagal 8 tarifą, fiksuojama kas mėnesį', 690, 5, NULL, NULL),
	(6027, 1, 0, 8, 2, 8, 2, 5, 14, NULL, 'Suminė A energija pagal 8 tarifą, fiksuojama kas parą', 690, 5, NULL, NULL),
	(6028, 1, 0, 8, 2, 8, 2, 4, 14, NULL, 'Suminė A energija pagal 8 tarifą, fiksuojama kas valandą', 690, 5, NULL, NULL),
	(6029, 1, 0, 8, 2, 8, 2, 12, 14, NULL, 'Suminė A energija pagal 8 tarifą, fiksuojama kas 15 minučių', 690, 5, NULL, NULL),
	(6030, 1, 0, 8, 2, 8, 2, 13, 14, NULL, 'Suminė A energija pagal 8 tarifą, fiksuojama kas 20 minučių', 690, 5, NULL, NULL),
	(6031, 1, 0, 8, 2, 8, 2, 3, 14, NULL, 'Suminė A energija pagal 8 tarifą, fiksuojama kas 30 minučių', 690, 5, NULL, NULL),
	(6032, 5, 0, 3, 3, 0, 5, 3, 17, NULL, 'Vidutinis srovės stiprumas L1 fazėje per 30 minučių', 678, 2, NULL, NULL),
	(6033, 5, 0, 4, 3, 0, 5, 4, 17, NULL, 'Vidutinis srovės stiprumas L1 fazėje per valandą', 678, 2, NULL, NULL),
	(6034, 5, 0, 1, 3, 0, 5, 1, 17, NULL, 'Vidutinis srovės stiprumas L1 fazėje per minutę', 678, 1, NULL, NULL),
	(6035, 5, 0, 2, 3, 0, 5, 2, 17, NULL, 'Vidutinis srovės stiprumas L1 fazėje per 2 minutes', 678, 1, NULL, NULL),
	(6036, 5, 0, 9, 3, 0, 5, 8, 17, NULL, 'Vidutinis srovės stiprumas L1 fazėje per 3 minutes', 678, 1, NULL, NULL),
	(6037, 5, 0, 12, 3, 0, 5, 11, 17, NULL, 'Vidutinis srovės stiprumas L1 fazėje per 10 minučių', 678, 1, NULL, NULL),
	(6038, 5, 0, 5, 3, 0, 5, 5, 17, NULL, 'Vidutinis srovės stiprumas L1 fazėje per parą', 678, 3, NULL, NULL),
	(6039, 5, 0, 11, 3, 0, 5, 10, 17, NULL, 'Vidutinis srovės stiprumas L1 fazėje per 5 minutes', 678, 1, NULL, NULL),
	(6040, 5, 0, 10, 3, 0, 5, 9, 17, NULL, 'Vidutinis srovės stiprumas L1 fazėje per 4 minutes', 678, 1, NULL, NULL),
	(6041, 5, 0, 13, 3, 0, 5, 12, 17, NULL, 'Vidutinis srovės stiprumas L1 fazėje per 15 minučių', 678, 2, NULL, NULL),
	(6042, 5, 0, 14, 3, 0, 5, 13, 17, NULL, 'Vidutinis srovės stiprumas L1 fazėje per 20 minučių', 678, 2, NULL, NULL),
	(6043, 7, 0, 3, 3, 0, 5, 3, 19, NULL, 'Vidutinis srovės stiprumas L2 fazėje per 30 minučių', 679, 2, NULL, NULL),
	(6044, 7, 0, 4, 3, 0, 5, 4, 19, NULL, 'Vidutinis srovės stiprumas L2 fazėje per valandą', 679, 2, NULL, NULL),
	(6045, 7, 0, 1, 3, 0, 5, 1, 19, NULL, 'Vidutinis srovės stiprumas L2 fazėje per minutę', 679, 1, NULL, NULL),
	(6046, 7, 0, 2, 3, 0, 5, 2, 19, NULL, 'Vidutinis srovės stiprumas L2 fazėje per 2 minutes', 679, 1, NULL, NULL),
	(6047, 7, 0, 9, 3, 0, 5, 8, 19, NULL, 'Vidutinis srovės stiprumas L2 fazėje per 3 minutes', 679, 1, NULL, NULL),
	(6048, 7, 0, 12, 3, 0, 5, 11, 19, NULL, 'Vidutinis srovės stiprumas L2 fazėje per 10 minučių', 679, 1, NULL, NULL),
	(6049, 7, 0, 5, 3, 0, 5, 5, 19, NULL, 'Vidutinis srovės stiprumas L2 fazėje per parą', 679, 3, NULL, NULL),
	(6050, 7, 0, 11, 3, 0, 5, 10, 19, NULL, 'Vidutinis srovės stiprumas L2 fazėje per 5 minutes', 679, 1, NULL, NULL),
	(6051, 7, 0, 10, 3, 0, 5, 9, 19, NULL, 'Vidutinis srovės stiprumas L2 fazėje per 4 minutes', 679, 1, NULL, NULL),
	(6052, 7, 0, 13, 3, 0, 5, 12, 19, NULL, 'Vidutinis srovės stiprumas L2 fazėje per 15 minučių', 679, 2, NULL, NULL),
	(6053, 7, 0, 14, 3, 0, 5, 13, 19, NULL, 'Vidutinis srovės stiprumas L2 fazėje per 20 minučių', 679, 2, NULL, NULL),
	(6054, 9, 0, 3, 3, 0, 5, 3, 21, NULL, 'Vidutinis srovės stiprumas L3 fazėje per 30 minučių', 680, 2, NULL, NULL),
	(6055, 9, 0, 4, 3, 0, 5, 4, 21, NULL, 'Vidutinis srovės stiprumas L3 fazėje per valandą', 680, 2, NULL, NULL),
	(6056, 9, 0, 1, 3, 0, 5, 1, 21, NULL, 'Vidutinis srovės stiprumas L3 fazėje per minutę', 680, 1, NULL, NULL),
	(6057, 9, 0, 2, 3, 0, 5, 2, 21, NULL, 'Vidutinis srovės stiprumas L3 fazėje per 2 minutes', 680, 1, NULL, NULL),
	(6058, 9, 0, 9, 3, 0, 5, 8, 21, NULL, 'Vidutinis srovės stiprumas L3 fazėje per 3 minutes', 680, 1, NULL, NULL),
	(6059, 9, 0, 12, 3, 0, 5, 11, 21, NULL, 'Vidutinis srovės stiprumas L3 fazėje per 10 minučių', 680, 1, NULL, NULL),
	(6060, 9, 0, 5, 3, 0, 5, 5, 21, NULL, 'Vidutinis srovės stiprumas L3 fazėje per parą', 680, 3, NULL, NULL),
	(6061, 9, 0, 11, 3, 0, 5, 10, 21, NULL, 'Vidutinis srovės stiprumas L3 fazėje per 5 minutes', 680, 1, NULL, NULL),
	(6062, 9, 0, 10, 3, 0, 5, 9, 21, NULL, 'Vidutinis srovės stiprumas L3 fazėje per 4 minutes', 680, 1, NULL, NULL),
	(6063, 9, 0, 13, 3, 0, 5, 12, 21, NULL, 'Vidutinis srovės stiprumas L3 fazėje per 15 minučių', 680, 2, NULL, NULL),
	(6064, 9, 0, 14, 3, 0, 5, 13, 21, NULL, 'Vidutinis srovės stiprumas L3 fazėje per 20 minučių', 680, 2, NULL, NULL),
	(6065, 29, 0, 3, 3, 0, 5, 3, 41, NULL, 'Vidutinis srovės stiprumas per 30 minučių', 681, 2, NULL, NULL),
	(6066, 29, 0, 4, 3, 0, 5, 4, 41, NULL, 'Vidutinis srovės stiprumas per valandą', 681, 2, NULL, NULL),
	(6067, 29, 0, 1, 3, 0, 5, 1, 41, NULL, 'Vidutinis srovės stiprumas per minutę', 681, 1, NULL, NULL),
	(6068, 29, 0, 2, 3, 0, 5, 2, 41, NULL, 'Vidutinis srovės stiprumas per 2 minutes', 681, 1, NULL, NULL),
	(6069, 29, 0, 9, 3, 0, 5, 8, 41, NULL, 'Vidutinis srovės stiprumas per 3 minutes', 681, 1, NULL, NULL),
	(6070, 29, 0, 12, 3, 0, 5, 11, 41, NULL, 'Vidutinis srovės stiprumas per 10 minučių', 681, 1, NULL, NULL),
	(6071, 29, 0, 5, 3, 0, 5, 5, 41, NULL, 'Vidutinis srovės stiprumas per parą', 681, 3, NULL, NULL),
	(6072, 29, 0, 11, 3, 0, 5, 10, 41, NULL, 'Vidutinis srovės stiprumas per 5 minutes', 681, 1, NULL, NULL),
	(6073, 29, 0, 10, 3, 0, 5, 9, 41, NULL, 'Vidutinis srovės stiprumas per 4 minutes', 681, 1, NULL, NULL),
	(6074, 29, 0, 13, 3, 0, 5, 12, 41, NULL, 'Vidutinis srovės stiprumas per 15 minučių', 681, 2, NULL, NULL),
	(6075, 29, 0, 14, 3, 0, 5, 13, 41, NULL, 'Vidutinis srovės stiprumas per 20 minučių', 681, 2, NULL, NULL),
	(6076, 222, 0, 7, 1, 0, 5, 7, 235, NULL, 'Momentinis srovės stiprumas neutralėje', 548, 6, NULL, NULL),
	(6077, 222, 0, 7, 1, 0, 5, 15, 235, NULL, 'Momentinis srovės stiprumas neutralėje, fiksuojamas kas 5 sekundes', 548, 7, NULL, NULL),
	(6078, 222, 0, 7, 1, 0, 5, 19, 235, NULL, 'Momentinis srovės stiprumas neutralėje, fiksuojamas kas 30 sekundžių', 548, 7, NULL, NULL),
	(6079, 1, 3, 3, 3, 0, 1, 3, 13, NULL, 'Vidutinė aktyvinė tinklo galia per 30 minučių', 447, 2, NULL, NULL),
	(6080, 1, 3, 4, 3, 0, 1, 4, 13, NULL, 'Vidutinė aktyvinė tinklo galia per valandą', 447, 2, NULL, NULL),
	(6081, 1, 3, 13, 3, 0, 1, 12, 13, NULL, 'Vidutinė aktyvinė tinklo galia per 15 minučių', 447, 2, NULL, NULL),
	(6082, 1, 3, 14, 3, 0, 1, 13, 13, NULL, 'Vidutinė aktyvinė tinklo galia per 20 minučių', 447, 2, NULL, NULL),
	(6083, 222, 0, 7, 5, 0, 5, 4, 235, NULL, 'Minimalus momentinis srovės stiprumas neutralėje per valandą', 550, 2, NULL, NULL),
	(6084, 222, 0, 7, 4, 0, 5, 4, 235, NULL, 'Maksimalus momentinis srovės stiprumas neutralėje per valandą', 549, 2, NULL, NULL),
	(6085, 222, 0, 7, 4, 0, 5, 5, 235, NULL, 'Maksimalus momentinis srovės stiprumas neutralėje per parą', 549, 3, NULL, NULL),
	(6086, 222, 0, 7, 4, 0, 5, 6, 235, NULL, 'Maksimalus momentinis srovės stiprumas neutralėje per mėnesį', 549, 4, NULL, NULL),
	(6087, 3, 3, 3, 3, 0, 3, 3, 16, NULL, 'Vidutinė reaktyvinė tinklo galia per 30 minučių', 449, 2, NULL, NULL),
	(6088, 3, 3, 4, 3, 0, 3, 4, 16, NULL, 'Vidutinė reaktyvinė tinklo galia per valandą', 449, 2, NULL, NULL),
	(6089, 3, 3, 13, 3, 0, 3, 12, 16, NULL, 'Vidutinė reaktyvinė tinklo galia per 15 minučių', 449, 2, NULL, NULL),
	(6090, 3, 3, 14, 3, 0, 3, 13, 16, NULL, 'Vidutinė reaktyvinė tinklo galia per 20 minučių', 449, 2, NULL, NULL),
	(6091, 3, -2, 3, 3, 0, 3, 3, 16, NULL, 'Vidutinė Q1+Q4 galia per 30 minučių', 452, 2, NULL, NULL),
	(6092, 3, -2, 4, 3, 0, 3, 4, 16, NULL, 'Vidutinė Q1+Q4 galia per valandą', 452, 2, NULL, NULL),
	(6093, 3, -2, 13, 3, 0, 3, 12, 16, NULL, 'Vidutinė Q1+Q4 galia per 15 minučių', 452, 2, NULL, NULL),
	(6094, 3, -2, 14, 3, 0, 3, 13, 16, NULL, 'Vidutinė Q1+Q4 galia per 20 minučių', 452, 2, NULL, NULL),
	(6095, 3, -3, 3, 3, 0, 3, 3, 16, NULL, 'Vidutinė Q2+Q3 galia per 30 minučių', 453, 2, NULL, NULL),
	(6096, 3, -3, 4, 3, 0, 3, 4, 16, NULL, 'Vidutinė Q2+Q3 galia per valandą', 453, 2, NULL, NULL),
	(6097, 3, -3, 13, 3, 0, 3, 12, 16, NULL, 'Vidutinė Q2+Q3 galia per 15 minučių', 453, 2, NULL, NULL),
	(6098, 3, -3, 14, 3, 0, 3, 13, 16, NULL, 'Vidutinė Q2+Q3 galia per 20 minučių', 453, 2, NULL, NULL),
	(6099, 222, 0, 7, 5, 0, 5, 5, 235, NULL, 'Minimalus momentinis srovės stiprumas neutralėje per parą', 550, 3, NULL, NULL),
	(6100, 222, 0, 7, 5, 0, 5, 6, 235, NULL, 'Minimalus momentinis srovės stiprumas neutralėje per mėnesį', 550, 4, NULL, NULL),
	(6103, 34, 3, 3, 3, 0, 7, 3, 44, NULL, 'Vidutinė pilnoji tinklo galia per 30 minučių', 451, 2, NULL, NULL),
	(6104, 34, 3, 4, 3, 0, 7, 4, 44, NULL, 'Vidutinė pilnoji tinklo galia per valandą', 451, 2, NULL, NULL),
	(6105, 34, 3, 13, 3, 0, 7, 12, 44, NULL, 'Vidutinė pilnoji tinklo galia per 15 minučių', 451, 2, NULL, NULL),
	(6106, 34, 3, 14, 3, 0, 7, 13, 44, NULL, 'Vidutinė pilnoji tinklo galia per 20 minučių', 451, 2, NULL, NULL),
	(6111, 1, 3, 3, 2, 0, 2, 3, 14, NULL, 'Aktyvinė tinklo energija per 30 minučių', 720, 2, NULL, NULL),
	(6112, 1, 3, 4, 2, 0, 2, 4, 14, NULL, 'Aktyvinė tinklo energija per valandą', 720, 2, NULL, NULL),
	(6113, 1, 3, 13, 2, 0, 2, 12, 14, NULL, 'Aktyvinė tinklo energija per 15 minučių', 720, 2, NULL, NULL),
	(6114, 1, 3, 14, 2, 0, 2, 13, 14, NULL, 'Aktyvinė tinklo energija per 20 minučių', 720, 2, NULL, NULL),
	(6119, 3, 3, 3, 2, 0, 4, 3, 15, NULL, 'Reaktyvinė tinklo energija per 30 minučių', 722, 2, NULL, NULL),
	(6120, 3, 3, 4, 2, 0, 4, 4, 15, NULL, 'Reaktyvinė tinklo energija per valandą', 722, 2, NULL, NULL),
	(6121, 3, 3, 13, 2, 0, 4, 12, 15, NULL, 'Reaktyvinė tinklo energija per 15 minučių', 722, 2, NULL, NULL),
	(6122, 3, 3, 14, 2, 0, 4, 13, 15, NULL, 'Reaktyvinė tinklo energija per 20 minučių', 722, 2, NULL, NULL),
	(6123, 3, -2, 3, 2, 0, 4, 3, 15, NULL, 'R1+R4 energija per 30 minučių', 725, 2, NULL, NULL),
	(6124, 3, -2, 4, 2, 0, 4, 4, 15, NULL, 'R1+R4 energija per valandą', 725, 2, NULL, NULL),
	(6125, 3, -2, 13, 2, 0, 4, 12, 15, NULL, 'R1+R4 energija per 15 minučių', 725, 2, NULL, NULL),
	(6126, 3, -2, 14, 2, 0, 4, 13, 15, NULL, 'R1+R4 energija per 20 minučių', 725, 2, NULL, NULL),
	(6127, 3, -3, 3, 2, 0, 4, 3, 15, NULL, 'R2+R3 energija per 30 minučių', 726, 2, NULL, NULL),
	(6128, 3, -3, 4, 2, 0, 4, 4, 15, NULL, 'R2+R3 energija per valandą', 726, 2, NULL, NULL),
	(6129, 3, -3, 13, 2, 0, 4, 12, 15, NULL, 'R2+R3 energija per 15 minučių', 726, 2, NULL, NULL),
	(6130, 3, -3, 14, 2, 0, 4, 13, 15, NULL, 'R2+R3 energija per 20 minučių', 726, 2, NULL, NULL),
	(6135, 34, 3, 3, 2, 0, 41, 3, 45, NULL, 'Pilnoji tinklo energija per 30 minučių', 724, 2, NULL, NULL),
	(6136, 34, 3, 4, 2, 0, 41, 4, 45, NULL, 'Pilnoji tinklo energija per valandą', 724, 2, NULL, NULL),
	(6137, 34, 3, 13, 2, 0, 41, 12, 45, NULL, 'Pilnoji tinklo energija per 15 minučių', 724, 2, NULL, NULL),
	(6138, 34, 3, 14, 2, 0, 41, 13, 45, NULL, 'Pilnoji tinklo energija per 20 minučių', 724, 2, NULL, NULL),
	(6139, 189, 1, 3, 2, 0, 2, 3, 202, NULL, 'A+ energija per 30 minučių L1 fazėje', 727, 2, NULL, NULL),
	(6140, 189, 1, 4, 2, 0, 2, 4, 202, NULL, 'A+ energija per valandą L1 fazėje', 727, 2, NULL, NULL),
	(6141, 189, 1, 13, 2, 0, 2, 12, 202, NULL, 'A+ energija per 15 minučių L1 fazėje', 727, 2, NULL, NULL),
	(6142, 189, 1, 14, 2, 0, 2, 13, 202, NULL, 'A+ energija per 20 minučių L1 fazėje', 727, 2, NULL, NULL),
	(6143, 189, 2, 3, 2, 0, 2, 3, 202, NULL, 'A- energija per 30 minučių L1 fazėje', 728, 2, NULL, NULL),
	(6144, 189, 2, 4, 2, 0, 2, 4, 202, NULL, 'A- energija per valandą L1 fazėje', 728, 2, NULL, NULL),
	(6145, 189, 2, 13, 2, 0, 2, 12, 202, NULL, 'A- energija per 15 minučių L1 fazėje', 728, 2, NULL, NULL),
	(6146, 189, 2, 14, 2, 0, 2, 13, 202, NULL, 'A- energija per 20 minučių L1 fazėje', 728, 2, NULL, NULL),
	(6147, 193, 1, 3, 2, 0, 4, 3, 205, NULL, 'R+ energija per 30 minučių L1 fazėje', 729, 2, NULL, NULL),
	(6148, 193, 1, 4, 2, 0, 4, 4, 205, NULL, 'R+ energija per valandą L1 fazėje', 729, 2, NULL, NULL),
	(6149, 193, 1, 13, 2, 0, 4, 12, 205, NULL, 'R+ energija per 15 minučių L1 fazėje', 729, 2, NULL, NULL),
	(6150, 193, 1, 14, 2, 0, 4, 13, 205, NULL, 'R+ energija per 20 minučių L1 fazėje', 729, 2, NULL, NULL),
	(6151, 193, 2, 3, 2, 0, 4, 3, 205, NULL, 'R- energija per 30 minučių L1 fazėje', 730, 2, NULL, NULL),
	(6152, 193, 2, 4, 2, 0, 4, 4, 205, NULL, 'R- energija per valandą L1 fazėje', 730, 2, NULL, NULL),
	(6153, 193, 2, 13, 2, 0, 4, 12, 205, NULL, 'R- energija per 15 minučių L1 fazėje', 730, 2, NULL, NULL),
	(6154, 193, 2, 14, 2, 0, 4, 13, 205, NULL, 'R- energija per 20 minučių L1 fazėje', 730, 2, NULL, NULL),
	(6155, 190, 1, 3, 2, 0, 2, 3, 203, NULL, 'A+ energija per 30 minučių L2 fazėje', 731, 2, NULL, NULL),
	(6156, 190, 1, 4, 2, 0, 2, 4, 203, NULL, 'A+ energija per valandą L2 fazėje', 731, 2, NULL, NULL),
	(6157, 190, 1, 13, 2, 0, 2, 12, 203, NULL, 'A+ energija per 15 minučių L2 fazėje', 731, 2, NULL, NULL),
	(6158, 190, 1, 14, 2, 0, 2, 13, 203, NULL, 'A+ energija per 20 minučių L2 fazėje', 731, 2, NULL, NULL),
	(6159, 190, 2, 3, 2, 0, 2, 3, 203, NULL, 'A- energija per 30 minučių L2 fazėje', 732, 2, NULL, NULL),
	(6160, 190, 2, 4, 2, 0, 2, 4, 203, NULL, 'A- energija per valandą L2 fazėje', 732, 2, NULL, NULL),
	(6161, 190, 2, 13, 2, 0, 2, 12, 203, NULL, 'A- energija per 15 minučių L2 fazėje', 732, 2, NULL, NULL),
	(6162, 190, 2, 14, 2, 0, 2, 13, 203, NULL, 'A- energija per 20 minučių L2 fazėje', 732, 2, NULL, NULL),
	(6163, 194, 1, 3, 2, 0, 4, 3, 206, NULL, 'R+ energija per 30 minučių L2 fazėje', 733, 2, NULL, NULL),
	(6164, 194, 1, 4, 2, 0, 4, 4, 206, NULL, 'R+ energija per valandą L2 fazėje', 733, 2, NULL, NULL),
	(6165, 194, 1, 13, 2, 0, 4, 12, 206, NULL, 'R+ energija per 15 minučių L2 fazėje', 733, 2, NULL, NULL),
	(6166, 194, 1, 14, 2, 0, 4, 13, 206, NULL, 'R+ energija per 20 minučių L2 fazėje', 733, 2, NULL, NULL),
	(6167, 194, 2, 3, 2, 0, 4, 3, 206, NULL, 'R- energija per 30 minučių L2 fazėje', 734, 2, NULL, NULL),
	(6168, 194, 2, 4, 2, 0, 4, 4, 206, NULL, 'R- energija per valandą L2 fazėje', 734, 2, NULL, NULL),
	(6169, 194, 2, 13, 2, 0, 4, 12, 206, NULL, 'R- energija per 15 minučių L2 fazėje', 734, 2, NULL, NULL),
	(6170, 194, 2, 14, 2, 0, 4, 13, 206, NULL, 'R- energija per 20 minučių L2 fazėje', 734, 2, NULL, NULL),
	(6171, 191, 1, 3, 2, 0, 2, 3, 204, NULL, 'A+ energija per 30 minučių L3 fazėje', 735, 2, NULL, NULL),
	(6172, 191, 1, 4, 2, 0, 2, 4, 204, NULL, 'A+ energija per valandą L3 fazėje', 735, 2, NULL, NULL),
	(6173, 191, 1, 13, 2, 0, 2, 12, 204, NULL, 'A+ energija per 15 minučių L3 fazėje', 735, 2, NULL, NULL),
	(6174, 191, 1, 14, 2, 0, 2, 13, 204, NULL, 'A+ energija per 20 minučių L3 fazėje', 735, 2, NULL, NULL),
	(6175, 191, 2, 3, 2, 0, 2, 3, 204, NULL, 'A- energija per 30 minučių L3 fazėje', 736, 2, NULL, NULL),
	(6176, 191, 2, 4, 2, 0, 2, 4, 204, NULL, 'A- energija per valandą L3 fazėje', 736, 2, NULL, NULL),
	(6177, 191, 2, 13, 2, 0, 2, 12, 204, NULL, 'A- energija per 15 minučių L3 fazėje', 736, 2, NULL, NULL),
	(6178, 191, 2, 14, 2, 0, 2, 13, 204, NULL, 'A- energija per 20 minučių L3 fazėje', 736, 2, NULL, NULL),
	(6179, 195, 1, 3, 2, 0, 4, 3, 207, NULL, 'R+ energija per 30 minučių L3 fazėje', 737, 2, NULL, NULL),
	(6180, 195, 1, 4, 2, 0, 4, 4, 207, NULL, 'R+ energija per valandą L3 fazėje', 737, 2, NULL, NULL),
	(6181, 195, 1, 13, 2, 0, 4, 12, 207, NULL, 'R+ energija per 15 minučių L3 fazėje', 737, 2, NULL, NULL),
	(6182, 195, 1, 14, 2, 0, 4, 13, 207, NULL, 'R+ energija per 20 minučių L3 fazėje', 737, 2, NULL, NULL),
	(6183, 195, 2, 3, 2, 0, 4, 3, 207, NULL, 'R- energija per 30 minučių L3 fazėje', 738, 2, NULL, NULL),
	(6184, 195, 2, 4, 2, 0, 4, 4, 207, NULL, 'R- energija per valandą L3 fazėje', 738, 2, NULL, NULL),
	(6185, 195, 2, 13, 2, 0, 4, 12, 207, NULL, 'R- energija per 15 minučių L3 fazėje', 738, 2, NULL, NULL),
	(6186, 195, 2, 14, 2, 0, 4, 13, 207, NULL, 'R- energija per 20 minučių L3 fazėje', 738, 2, NULL, NULL),
	(6187, 193, 5, 3, 2, 0, 4, 3, 205, NULL, 'R1 energija per 30 minučių L1 fazėje', 739, 2, NULL, NULL),
	(6188, 193, 5, 4, 2, 0, 4, 4, 205, NULL, 'R1 energija per valandą L1 fazėje', 739, 2, NULL, NULL),
	(6189, 193, 5, 13, 2, 0, 4, 12, 205, NULL, 'R1 energija per 15 minučių L1 fazėje', 739, 2, NULL, NULL),
	(6190, 193, 5, 14, 2, 0, 4, 13, 205, NULL, 'R1 energija per 20 minučių L1 fazėje', 739, 2, NULL, NULL),
	(6191, 193, 6, 3, 2, 0, 4, 3, 205, NULL, 'R2 energija per 30 minučių L1 fazėje', 740, 2, NULL, NULL),
	(6192, 193, 6, 4, 2, 0, 4, 4, 205, NULL, 'R2 energija per valandą L1 fazėje', 740, 2, NULL, NULL),
	(6193, 193, 6, 13, 2, 0, 4, 12, 205, NULL, 'R2 energija per 15 minučių L1 fazėje', 740, 2, NULL, NULL),
	(6194, 193, 6, 14, 2, 0, 4, 13, 205, NULL, 'R2 energija per 20 minučių L1 fazėje', 740, 2, NULL, NULL),
	(6195, 193, 7, 3, 2, 0, 4, 3, 205, NULL, 'R3 energija per 30 minučių L1 fazėje', 741, 2, NULL, NULL),
	(6196, 193, 7, 4, 2, 0, 4, 4, 205, NULL, 'R3 energija per valandą L1 fazėje', 741, 2, NULL, NULL),
	(6197, 193, 7, 13, 2, 0, 4, 12, 205, NULL, 'R3 energija per 15 minučių L1 fazėje', 741, 2, NULL, NULL),
	(6198, 193, 7, 14, 2, 0, 4, 13, 205, NULL, 'R3 energija per 20 minučių L1 fazėje', 741, 2, NULL, NULL),
	(6199, 193, 8, 3, 2, 0, 4, 3, 205, NULL, 'R4 energija per 30 minučių L1 fazėje', 742, 2, NULL, NULL),
	(6200, 193, 8, 4, 2, 0, 4, 4, 205, NULL, 'R4 energija per valandą L1 fazėje', 742, 2, NULL, NULL),
	(6201, 193, 8, 13, 2, 0, 4, 12, 205, NULL, 'R4 energija per 15 minučių L1 fazėje', 742, 2, NULL, NULL),
	(6202, 193, 8, 14, 2, 0, 4, 13, 205, NULL, 'R4 energija per 20 minučių L1 fazėje', 742, 2, NULL, NULL),
	(6203, 194, 5, 3, 2, 0, 4, 3, 206, NULL, 'R1 energija per 30 minučių L2 fazėje', 745, 2, NULL, NULL),
	(6204, 194, 5, 4, 2, 0, 4, 4, 206, NULL, 'R1 energija per valandą L2 fazėje', 745, 2, NULL, NULL),
	(6205, 194, 5, 13, 2, 0, 4, 12, 206, NULL, 'R1 energija per 15 minučių L2 fazėje', 745, 2, NULL, NULL),
	(6206, 194, 5, 14, 2, 0, 4, 13, 206, NULL, 'R1 energija per 20 minučių L2 fazėje', 745, 2, NULL, NULL),
	(6207, 194, 6, 3, 2, 0, 4, 3, 206, NULL, 'R2 energija per 30 minučių L2 fazėje', 746, 2, NULL, NULL),
	(6208, 194, 6, 4, 2, 0, 4, 4, 206, NULL, 'R2 energija per valandą L2 fazėje', 746, 2, NULL, NULL),
	(6209, 194, 6, 13, 2, 0, 4, 12, 206, NULL, 'R2 energija per 15 minučių L2 fazėje', 746, 2, NULL, NULL),
	(6210, 194, 6, 14, 2, 0, 4, 13, 206, NULL, 'R2 energija per 20 minučių L2 fazėje', 746, 2, NULL, NULL),
	(6211, 194, 7, 3, 2, 0, 4, 3, 206, NULL, 'R3 energija per 30 minučių L2 fazėje', 747, 2, NULL, NULL),
	(6212, 194, 7, 4, 2, 0, 4, 4, 206, NULL, 'R3 energija per valandą L2 fazėje', 747, 2, NULL, NULL),
	(6213, 194, 7, 13, 2, 0, 4, 12, 206, NULL, 'R3 energija per 15 minučių L2 fazėje', 747, 2, NULL, NULL),
	(6214, 194, 7, 14, 2, 0, 4, 13, 206, NULL, 'R3 energija per 20 minučių L2 fazėje', 747, 2, NULL, NULL),
	(6215, 194, 8, 3, 2, 0, 4, 3, 206, NULL, 'R4 energija per 30 minučių L2 fazėje', 748, 2, NULL, NULL),
	(6216, 194, 8, 4, 2, 0, 4, 4, 206, NULL, 'R4 energija per valandą L2 fazėje', 748, 2, NULL, NULL),
	(6217, 194, 8, 13, 2, 0, 4, 12, 206, NULL, 'R4 energija per 15 minučių L2 fazėje', 748, 2, NULL, NULL),
	(6218, 194, 8, 14, 2, 0, 4, 13, 206, NULL, 'R4 energija per 20 minučių L2 fazėje', 748, 2, NULL, NULL),
	(6219, 195, 5, 3, 2, 0, 4, 3, 207, NULL, 'R1 energija per 30 minučių L3 fazėje', 751, 2, NULL, NULL),
	(6220, 195, 5, 4, 2, 0, 4, 4, 207, NULL, 'R1 energija per valandą L3 fazėje', 751, 2, NULL, NULL),
	(6221, 195, 5, 13, 2, 0, 4, 12, 207, NULL, 'R1 energija per 15 minučių L3 fazėje', 751, 2, NULL, NULL),
	(6222, 195, 5, 14, 2, 0, 4, 13, 207, NULL, 'R1 energija per 20 minučių L3 fazėje', 751, 2, NULL, NULL),
	(6223, 195, 6, 3, 2, 0, 4, 3, 207, NULL, 'R2 energija per 30 minučių L3 fazėje', 752, 2, NULL, NULL),
	(6224, 195, 6, 4, 2, 0, 4, 4, 207, NULL, 'R2 energija per valandą L3 fazėje', 752, 2, NULL, NULL),
	(6225, 195, 6, 13, 2, 0, 4, 12, 207, NULL, 'R2 energija per 15 minučių L3 fazėje', 752, 2, NULL, NULL),
	(6226, 195, 6, 14, 2, 0, 4, 13, 207, NULL, 'R2 energija per 20 minučių L3 fazėje', 752, 2, NULL, NULL),
	(6227, 195, 7, 3, 2, 0, 4, 3, 207, NULL, 'R3 energija per 30 minučių L3 fazėje', 753, 2, NULL, NULL),
	(6228, 195, 7, 4, 2, 0, 4, 4, 207, NULL, 'R3 energija per valandą L3 fazėje', 753, 2, NULL, NULL),
	(6229, 195, 7, 13, 2, 0, 4, 12, 207, NULL, 'R3 energija per 15 minučių L3 fazėje', 753, 2, NULL, NULL),
	(6230, 195, 7, 14, 2, 0, 4, 13, 207, NULL, 'R3 energija per 20 minučių L3 fazėje', 753, 2, NULL, NULL),
	(6231, 195, 8, 3, 2, 0, 4, 3, 207, NULL, 'R4 energija per 30 minučių L3 fazėje', 754, 2, NULL, NULL),
	(6232, 195, 8, 4, 2, 0, 4, 4, 207, NULL, 'R4 energija per valandą L3 fazėje', 754, 2, NULL, NULL),
	(6233, 195, 8, 13, 2, 0, 4, 12, 207, NULL, 'R4 energija per 15 minučių L3 fazėje', 754, 2, NULL, NULL),
	(6234, 195, 8, 14, 2, 0, 4, 13, 207, NULL, 'R4 energija per 20 minučių L3 fazėje', 754, 2, NULL, NULL),
	(6235, 196, 1, 3, 2, 0, 41, 3, 208, NULL, 'W+ energija per 30 minučių L1 fazėje', 743, 2, NULL, NULL),
	(6236, 196, 1, 4, 2, 0, 41, 4, 208, NULL, 'W+ energija per valandą L1 fazėje', 743, 2, NULL, NULL),
	(6237, 196, 1, 13, 2, 0, 41, 12, 208, NULL, 'W+ energija per 15 minučių L1 fazėje', 743, 2, NULL, NULL),
	(6238, 196, 1, 14, 2, 0, 41, 13, 208, NULL, 'W+ energija per 20 minučių L1 fazėje', 743, 2, NULL, NULL),
	(6239, 196, 2, 3, 2, 0, 41, 3, 208, NULL, 'W- energija per 30 minučių L1 fazėje', 744, 2, NULL, NULL),
	(6240, 196, 2, 4, 2, 0, 41, 4, 208, NULL, 'W- energija per valandą L1 fazėje', 744, 2, NULL, NULL),
	(6241, 196, 2, 13, 2, 0, 41, 12, 208, NULL, 'W- energija per 15 minučių L1 fazėje', 744, 2, NULL, NULL),
	(6242, 196, 2, 14, 2, 0, 41, 13, 208, NULL, 'W- energija per 20 minučių L1 fazėje', 744, 2, NULL, NULL),
	(6243, 197, 1, 3, 2, 0, 41, 3, 209, NULL, 'W+ energija per 30 minučių L2 fazėje', 749, 2, NULL, NULL),
	(6244, 197, 1, 4, 2, 0, 41, 4, 209, NULL, 'W+ energija per valandą L2 fazėje', 749, 2, NULL, NULL),
	(6245, 197, 1, 13, 2, 0, 41, 12, 209, NULL, 'W+ energija per 15 minučių L2 fazėje', 749, 2, NULL, NULL),
	(6246, 197, 1, 14, 2, 0, 41, 13, 209, NULL, 'W+ energija per 20 minučių L2 fazėje', 749, 2, NULL, NULL),
	(6247, 197, 2, 3, 2, 0, 41, 3, 209, NULL, 'W- energija per 30 minučių L2 fazėje', 750, 2, NULL, NULL),
	(6248, 197, 2, 4, 2, 0, 41, 4, 209, NULL, 'W- energija per valandą L2 fazėje', 750, 2, NULL, NULL),
	(6249, 197, 2, 13, 2, 0, 41, 12, 209, NULL, 'W- energija per 15 minučių L2 fazėje', 750, 2, NULL, NULL),
	(6250, 197, 2, 14, 2, 0, 41, 13, 209, NULL, 'W- energija per 20 minučių L2 fazėje', 750, 2, NULL, NULL),
	(6251, 198, 2, 3, 2, 0, 41, 3, 210, NULL, 'W- energija per 30 minučių L3 fazėje', 755, 2, NULL, NULL),
	(6252, 198, 2, 4, 2, 0, 41, 4, 210, NULL, 'W- energija per valandą L3 fazėje', 755, 2, NULL, NULL),
	(6253, 198, 2, 13, 2, 0, 41, 12, 210, NULL, 'W- energija per 15 minučių L3 fazėje', 755, 2, NULL, NULL),
	(6254, 198, 2, 14, 2, 0, 41, 13, 210, NULL, 'W- energija per 20 minučių L3 fazėje', 755, 2, NULL, NULL),
	(6255, 198, 1, 3, 2, 0, 41, 3, 210, NULL, 'W+ energija per 30 minučių L3 fazėje', 756, 2, NULL, NULL),
	(6256, 198, 1, 4, 2, 0, 41, 4, 210, NULL, 'W+ energija per valandą L3 fazėje', 756, 2, NULL, NULL),
	(6257, 198, 1, 13, 2, 0, 41, 12, 210, NULL, 'W+ energija per 15 minučių L3 fazėje', 756, 2, NULL, NULL),
	(6258, 198, 1, 14, 2, 0, 41, 13, 210, NULL, 'W+ energija per 20 minučių L3 fazėje', 756, 2, NULL, NULL),
	(6259, 193, 9, 3, 2, 0, 4, 3, 205, NULL, 'Indukcinė energija per 30 minučių L1 fazėje', 759, 2, NULL, NULL),
	(6260, 193, 9, 4, 2, 0, 4, 4, 205, NULL, 'Indukcinė energija per valandą L1 fazėje', 759, 2, NULL, NULL),
	(6261, 193, 9, 13, 2, 0, 4, 12, 205, NULL, 'Indukcinė energija per 15 minučių L1 fazėje', 759, 2, NULL, NULL),
	(6262, 193, 9, 14, 2, 0, 4, 13, 205, NULL, 'Indukcinė energija per 20 minučių L1 fazėje', 759, 2, NULL, NULL),
	(6263, 193, -1, 3, 2, 0, 4, 3, 205, NULL, 'Talpuminė energija per 30 minučių L1 fazėje', 760, 2, NULL, NULL),
	(6264, 193, -1, 4, 2, 0, 4, 4, 205, NULL, 'Talpuminė energija per valandą L1 fazėje', 760, 2, NULL, NULL),
	(6265, 193, -1, 13, 2, 0, 4, 12, 205, NULL, 'Talpuminė energija per 15 minučių L1 fazėje', 760, 2, NULL, NULL),
	(6266, 193, -1, 14, 2, 0, 4, 13, 205, NULL, 'Talpuminė energija per 20 minučių L1 fazėje', 760, 2, NULL, NULL),
	(6267, 194, 9, 3, 2, 0, 4, 3, 206, NULL, 'Indukcinė energija per 30 minučių L2 fazėje', 761, 2, NULL, NULL),
	(6268, 194, 9, 4, 2, 0, 4, 4, 206, NULL, 'Indukcinė energija per valandą L2 fazėje', 761, 2, NULL, NULL),
	(6269, 194, 9, 13, 2, 0, 4, 12, 206, NULL, 'Indukcinė energija per 15 minučių L2 fazėje', 761, 2, NULL, NULL),
	(6270, 194, 9, 14, 2, 0, 4, 13, 206, NULL, 'Indukcinė energija per 20 minučių L2 fazėje', 761, 2, NULL, NULL),
	(6271, 194, -1, 3, 2, 0, 4, 3, 206, NULL, 'Talpuminė energija per 30 minučių L2 fazėje', 762, 2, NULL, NULL),
	(6272, 194, -1, 4, 2, 0, 4, 4, 206, NULL, 'Talpuminė energija per valandą L2 fazėje', 762, 2, NULL, NULL),
	(6273, 194, -1, 13, 2, 0, 4, 12, 206, NULL, 'Talpuminė energija per 15 minučių L2 fazėje', 762, 2, NULL, NULL),
	(6274, 194, -1, 14, 2, 0, 4, 13, 206, NULL, 'Talpuminė energija per 20 minučių L2 fazėje', 762, 2, NULL, NULL),
	(6275, 195, -1, 3, 2, 0, 4, 3, 207, NULL, 'Talpuminė energija per 30 minučių L3 fazėje', 763, 2, NULL, NULL),
	(6276, 195, -1, 4, 2, 0, 4, 4, 207, NULL, 'Talpuminė energija per valandą L3 fazėje', 763, 2, NULL, NULL),
	(6277, 195, -1, 13, 2, 0, 4, 12, 207, NULL, 'Talpuminė energija per 15 minučių L3 fazėje', 763, 2, NULL, NULL),
	(6278, 195, -1, 14, 2, 0, 4, 13, 207, NULL, 'Talpuminė energija per 20 minučių L3 fazėje', 763, 2, NULL, NULL),
	(6279, 195, 9, 3, 2, 0, 4, 3, 207, NULL, 'Indukcinė energija per 30 minučių L3 fazėje', 764, 2, NULL, NULL),
	(6280, 195, 9, 4, 2, 0, 4, 4, 207, NULL, 'Indukcinė energija per valandą L3 fazėje', 764, 2, NULL, NULL),
	(6281, 195, 9, 13, 2, 0, 4, 12, 207, NULL, 'Indukcinė energija per 15 minučių L3 fazėje', 764, 2, NULL, NULL),
	(6282, 195, 9, 14, 2, 0, 4, 13, 207, NULL, 'Indukcinė energija per 20 minučių L3 fazėje', 764, 2, NULL, NULL),
	(6283, 3, -1, 3, 2, 0, 4, 3, 15, NULL, 'Talpuminė energija per 30 minučių', 757, 2, NULL, NULL),
	(6284, 3, -1, 4, 2, 0, 4, 4, 15, NULL, 'Talpuminė energija per valandą', 757, 2, NULL, NULL),
	(6285, 3, -1, 13, 2, 0, 4, 12, 15, NULL, 'Talpuminė energija per 15 minučių', 757, 2, NULL, NULL),
	(6286, 3, -1, 14, 2, 0, 4, 13, 15, NULL, 'Talpuminė energija per 20 minučių', 757, 2, NULL, NULL),
	(6287, 3, 9, 3, 2, 0, 4, 3, 15, NULL, 'Indukcinė energija per 30 minučių', 758, 2, NULL, NULL),
	(6288, 3, 9, 4, 2, 0, 4, 4, 15, NULL, 'Indukcinė energija per valandą', 758, 2, NULL, NULL),
	(6289, 3, 9, 13, 2, 0, 4, 12, 15, NULL, 'Indukcinė energija per 15 minučių', 758, 2, NULL, NULL),
	(6290, 3, 9, 14, 2, 0, 4, 13, 15, NULL, 'Indukcinė energija per 20 minučių', 758, 2, NULL, NULL),
	(6291, 209, 0, 8, 2, 0, 2, 7, 222, NULL, 'Suminis šilumnešio pilnosios šilumos kiekis', 1029, 5, NULL, NULL),
	(6292, 209, 1, 8, 2, 0, 2, 7, 222, NULL, 'Suminis tiekiamo šilumnešio pilnosios šilumos kiekis', 1029, 5, NULL, NULL),
	(6293, 209, 2, 8, 2, 0, 2, 7, 222, NULL, 'Suminis grįžtamo šilumnešio pilnosios šilumos kiekis', 1029, 5, NULL, NULL),
	(6294, 209, 0, 8, 2, 0, 2, 3, 222, NULL, 'Suminis šilumnešio pilnosios šilumos kiekis, fiksuojamas kas 30 minučių', 1029, 5, NULL, NULL),
	(6295, 209, 0, 8, 2, 0, 2, 12, 222, NULL, 'Suminis šilumnešio pilnosios šilumos kiekis, fiksuojamas kas 15 minučių', 1029, 5, NULL, NULL),
	(6296, 209, 0, 8, 2, 0, 2, 4, 222, NULL, 'Suminis šilumnešio pilnosios šilumos kiekis, fiksuojamas kas valandą', 1029, 5, NULL, NULL),
	(6297, 209, 0, 8, 2, 0, 2, 13, 222, NULL, 'Suminis šilumnešio pilnosios šilumos kiekis, fiksuojamas kas 20 minučių', 1029, 5, NULL, NULL),
	(6298, 209, 1, 8, 2, 0, 2, 4, 222, NULL, 'Suminis tiekiamo šilumnešio pilnosios šilumos kiekis, fiksuojamas kas valandą', 1029, 5, NULL, NULL),
	(6299, 209, 1, 8, 2, 0, 2, 12, 222, NULL, 'Suminis tiekiamo šilumnešio pilnosios šilumos kiekis, fiksuojamas kas 15 minučių', 1029, 5, NULL, NULL),
	(6300, 209, 1, 8, 2, 0, 2, 3, 222, NULL, 'Suminis tiekiamo šilumnešio pilnosios šilumos kiekis, fiksuojamas kas 30 minučių', 1029, 5, NULL, NULL),
	(6301, 209, 1, 8, 2, 0, 2, 13, 222, NULL, 'Suminis tiekiamo šilumnešio pilnosios šilumos kiekis, fiksuojamas kas 20 minučių', 1029, 5, NULL, NULL),
	(6302, 209, 2, 8, 2, 0, 2, 4, 222, NULL, 'Suminis grįžtamo šilumnešio pilnosios šilumos kiekis, fiksuojamas kas valandą', 1029, 5, NULL, NULL),
	(6303, 209, 2, 8, 2, 0, 2, 13, 222, NULL, 'Suminis grįžtamo šilumnešio pilnosios šilumos kiekis, fiksuojamas kas 20 minučių', 1029, 5, NULL, NULL),
	(6304, 209, 2, 8, 2, 0, 2, 12, 222, NULL, 'Suminis grįžtamo šilumnešio pilnosios šilumos kiekis, fiksuojamas kas 15 minučių', 1029, 5, NULL, NULL),
	(6305, 209, 2, 8, 2, 0, 2, 3, 222, NULL, 'Suminis grįžtamo šilumnešio pilnosios šilumos kiekis, fiksuojamas kas 30 minučių', 1029, 5, NULL, NULL),
	(6306, 209, 0, 8, 2, 0, 2, 6, 222, NULL, 'Suminis šilumnešio pilnosios šilumos kiekis, fiksuojamas kas mėnesį', 1029, 5, NULL, NULL),
	(6307, 209, 0, 8, 2, 0, 2, 5, 222, NULL, 'Suminis šilumnešio pilnosios šilumos kiekis, fiksuojamas kas parą', 1029, 5, NULL, NULL),
	(6308, 209, 1, 8, 2, 0, 2, 5, 222, NULL, 'Suminis tiekiamo šilumnešio pilnosios šilumos kiekis, fiksuojamas kas parą', 1029, 5, NULL, NULL),
	(6309, 209, 1, 8, 2, 0, 2, 6, 222, NULL, 'Suminis tiekiamo šilumnešio pilnosios šilumos kiekis, fiksuojamas kas mėnesį', 1029, 5, NULL, NULL),
	(6310, 209, 2, 8, 2, 0, 2, 5, 222, NULL, 'Suminis grįžtamo šilumnešio pilnosios šilumos kiekis, fiksuojamas kas parą', 1029, 5, NULL, NULL),
	(6311, 209, 2, 8, 2, 0, 2, 6, 222, NULL, 'Suminis grįžtamo šilumnešio pilnosios šilumos kiekis, fiksuojamas kas mėnesį', 1029, 5, NULL, NULL),
	(6312, 193, 5, 8, 2, 0, 4, 7, 205, NULL, 'Suminė R1 energija L1 fazėje', 3296, 5, NULL, NULL),
	(6313, 194, 5, 8, 2, 0, 4, 7, 206, NULL, 'Suminė R1 energija L2 fazėje', 3297, 5, NULL, NULL),
	(6314, 195, 5, 8, 2, 0, 4, 7, 207, NULL, 'Suminė R1 energija L3 fazėje', 3298, 5, NULL, NULL),
	(6315, 193, 6, 8, 2, 0, 4, 7, 205, NULL, 'Suminė R2 energija L1 fazėje', 3299, 5, NULL, NULL),
	(6316, 194, 6, 8, 2, 0, 4, 7, 206, NULL, 'Suminė R2 energija L2 fazėje', 3300, 5, NULL, NULL),
	(6317, 195, 6, 8, 2, 0, 4, 7, 207, NULL, 'Suminė R2 energija L3 fazėje', 3301, 5, NULL, NULL),
	(6318, 193, 7, 8, 2, 0, 4, 7, 205, NULL, 'Suminė R3 energija L1 fazėje', 3302, 5, NULL, NULL),
	(6319, 194, 7, 8, 2, 0, 4, 7, 206, NULL, 'Suminė R3 energija L2 fazėje', 3303, 5, NULL, NULL),
	(6320, 195, 7, 8, 2, 0, 4, 7, 207, NULL, 'Suminė R3 energija L3 fazėje', 3304, 5, NULL, NULL),
	(6321, 193, 8, 8, 2, 0, 4, 7, 205, NULL, 'Suminė R4 energija L1 fazėje', 3305, 5, NULL, NULL),
	(6322, 194, 8, 8, 2, 0, 4, 7, 206, NULL, 'Suminė R4 energija L2 fazėje', 3306, 5, NULL, NULL),
	(6323, 195, 8, 8, 2, 0, 4, 7, 207, NULL, 'Suminė R4 energija L3 fazėje', 3307, 5, NULL, NULL),
	(6324, 223, 0, 8, 2, 0, 2, 7, 236, NULL, 'Savitoji nuostolių energija srovės grandinėje L1 fazėje', 3308, 5, NULL, NULL),
	(6325, 224, 0, 8, 2, 0, 2, 7, 237, NULL, 'Savitoji nuostolių energija srovės grandinėje L2 fazėje', 3309, 5, NULL, NULL),
	(6326, 225, 0, 8, 2, 0, 2, 7, 238, NULL, 'Savitoji nuostolių energija srovės grandinėje L3 fazėje', 3310, 5, NULL, NULL),
	(6327, 226, 0, 8, 2, 0, 2, 7, 239, NULL, 'Savitoji nuostolių energija srovės grandinėje', 3311, 5, NULL, NULL),
	(6328, 54, -4, 4, 3, 0, 27, 4, 72, NULL, 'Vidutinė pamaitinimo vandens temperatūra per valandą', 1085, 2, NULL, NULL),
	(6329, 54, -4, 5, 3, 0, 27, 5, 72, NULL, 'Vidutinė pamaitinimo vandens temperatūra per parą', 1085, 3, NULL, NULL),
	(6330, 54, -4, 6, 3, 0, 27, 6, 72, NULL, 'Vidutinė pamaitinimo vandens temperatūra per mėnesį', 1085, 4, NULL, NULL),
	(6331, 54, -4, 7, 1, 0, 27, 7, 72, NULL, 'Momentinė pamaitinimo vandens temperatūra', 1026, 6, NULL, NULL),
	(6332, 55, -4, 5, 2, 0, 31, 5, 74, NULL, 'Pamaitinimo vandens tūrio kiekis per parą', 1084, 3, NULL, NULL),
	(6333, 55, -4, 6, 2, 0, 31, 6, 74, NULL, 'Pamaitinimo vandens tūrio kiekis per mėnesį', 1084, 4, NULL, NULL),
	(6334, 55, -4, 8, 2, 0, 31, 7, 74, NULL, 'Suminis pamaitinimo vandens tūrio kiekis', 1027, 5, NULL, NULL),
	(6335, 55, -4, 8, 2, 0, 31, 4, 74, NULL, 'Suminis pamaitinimo vandens tūrio kiekis, fiksuojamas kas valandą', 1027, 5, NULL, NULL),
	(6336, 55, -4, 4, 2, 0, 31, 4, 74, NULL, 'Pamaitinimo vandens tūrio kiekis per valandą', 1084, 2, NULL, NULL),
	(6337, 51, -4, 5, 2, 0, 35, 5, 68, NULL, 'Pamaitinimo vandens masės kiekis per parą', 1083, 3, NULL, NULL),
	(6338, 51, -4, 6, 2, 0, 35, 6, 68, NULL, 'Pamaitinimo vandens masės kiekis per mėnesį', 1083, 4, NULL, NULL),
	(6339, 51, -4, 8, 2, 0, 35, 7, 68, NULL, 'Suminis pamaitinimo vandens masės kiekis', 1028, 5, NULL, NULL),
	(6340, 51, -4, 8, 2, 0, 35, 4, 68, NULL, 'Suminis pamaitinimo vandens masės kiekis, fiksuojamas kas valandą', 1028, 5, NULL, NULL),
	(6341, 51, -4, 4, 2, 0, 35, 4, 68, NULL, 'Pamaitinimo vandens masės kiekis per valandą', 1083, 2, NULL, NULL),
	(6347, 53, -4, 5, 2, 0, 2, 5, 71, NULL, 'Pamaitinimo šilumos energija per parą', 1082, 3, NULL, NULL),
	(6348, 53, -4, 6, 2, 0, 2, 6, 71, NULL, 'Pamaitinimo šilumos energija per mėnesį', 1082, 4, NULL, NULL),
	(6349, 53, -4, 8, 2, 0, 2, 7, 71, NULL, 'Suminė pamaitinimo šilumos energija', 1030, 5, NULL, NULL),
	(6350, 53, -4, 8, 2, 0, 2, 4, 71, NULL, 'Suminė pamaitinimo šilumos energija, fiksuojama kas valandą', 1030, 5, NULL, NULL),
	(6351, 53, -4, 4, 2, 0, 2, 4, 71, NULL, 'Pamaitinimo šilumos energija per valandą', 1082, 2, NULL, NULL),
	(6352, 51, 4, 5, 2, 0, 35, 5, 68, NULL, 'Tiekiamo ir grįžtamo pamaitinimo vandens masės kiekių skirtumas per parą', 1083, 3, NULL, NULL),
	(6353, 51, 4, 6, 2, 0, 35, 6, 68, NULL, 'Tiekiamo ir grįžtamo pamaitinimo vandens masės kiekių skirtumas per mėnesį', 1083, 4, NULL, NULL),
	(6354, 51, 4, 8, 2, 0, 35, 7, 68, NULL, 'Suminis tiekiamo ir grįžtamo pamaitinimo vandens masės kiekių skirtumas', 1031, 5, NULL, NULL),
	(6355, 51, 4, 8, 2, 0, 35, 4, 68, NULL, 'Suminis tiekiamo ir grįžtamo pamaitinimo vandens masės kiekių skirtumas, fiksuojamas kas valandą', 1031, 5, NULL, NULL),
	(6356, 51, 4, 4, 2, 0, 35, 4, 68, NULL, 'Tiekiamo ir grįžtamo pamaitinimo vandens masės kiekių skirtumas per valandą', 1083, 2, NULL, NULL),
	(6357, 55, -4, 7, 1, 0, 32, 7, 73, NULL, 'Momentinis pamaitinimo vandens tūrio debitas', 1033, 6, NULL, NULL),
	(6358, 52, -4, 4, 3, 0, 28, 4, 69, NULL, 'Vidutinis pamaitinimo vandens slėgis per valandą', 1086, 2, NULL, NULL),
	(6359, 52, -4, 5, 3, 0, 28, 5, 69, NULL, 'Vidutinis pamaitinimo vandens slėgis per parą', 1086, 3, NULL, NULL),
	(6360, 52, -4, 6, 3, 0, 28, 6, 69, NULL, 'Vidutinis pamaitinimo vandens slėgis per mėnesį', 1086, 4, NULL, NULL),
	(6361, 52, -4, 7, 1, 0, 28, 7, 69, NULL, 'Momentinis pamaitinimo vandens slėgis', 1034, 6, NULL, NULL),
	(6362, 292, -4, 4, 2, 0, 29, 4, 305, NULL, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą pamaitinimo vandens vamzdyje per valandą', 1070, 2, NULL, NULL),
	(6363, 292, -4, 5, 2, 0, 29, 5, 305, NULL, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą pamaitinimo vandens vamzdyje per parą', 1070, 3, NULL, NULL),
	(6364, 292, -4, 6, 2, 0, 29, 6, 305, NULL, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą pamaitinimo vandens vamzdyje per mėnesį', 1070, 4, NULL, NULL),
	(6365, 293, -4, 4, 2, 0, 29, 4, 306, NULL, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą pamaitinimo vandens vamzdyje per valandą', 1071, 2, NULL, NULL),
	(6366, 293, -4, 5, 2, 0, 29, 5, 306, NULL, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą pamaitinimo vandens vamzdyje per parą', 1071, 3, NULL, NULL),
	(6367, 293, -4, 6, 2, 0, 29, 6, 306, NULL, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą pamaitinimo vandens vamzdyje per mėnesį', 1071, 4, NULL, NULL),
	(6368, 294, -4, 4, 2, 0, 29, 4, 307, NULL, 'Skaitiklio darbo laikas su daviklio gedimu pamaitinimo vandens vamzdyje per valandą', 1073, 2, NULL, NULL),
	(6369, 294, -4, 5, 2, 0, 29, 5, 307, NULL, 'Skaitiklio darbo laikas su daviklio gedimu pamaitinimo vandens vamzdyje per parą', 1073, 3, NULL, NULL),
	(6370, 294, -4, 6, 2, 0, 29, 6, 307, NULL, 'Skaitiklio darbo laikas su daviklio gedimu pamaitinimo vandens vamzdyje per mėnesį', 1073, 4, NULL, NULL),
	(6371, 295, -4, 4, 2, 0, 29, 4, 308, NULL, 'Skaitiklio darbo laikas su dt < 2 pamaitinimo vandens vamzdyje per valandą', 1038, 2, NULL, NULL),
	(6372, 295, -4, 5, 2, 0, 29, 5, 308, NULL, 'Skaitiklio darbo laikas su dt < 2 pamaitinimo vandens vamzdyje per parą', 1038, 3, NULL, NULL),
	(6373, 295, -4, 6, 2, 0, 29, 6, 308, NULL, 'Skaitiklio darbo laikas su dt < 2 pamaitinimo vandens vamzdyje per mėnesį', 1038, 4, NULL, NULL),
	(6374, 142, 1, 7, 1, 0, 28, 7, 155, NULL, 'Momentinis tiekiamo šalto vandens slėgis', 1209, 6, NULL, NULL),
	(6375, 142, 1, 1, 3, 0, 28, 1, 155, NULL, 'Vidutinis tiekiamo šalto vandens slėgis per minutę', 1216, 1, NULL, NULL),
	(6376, 142, 1, 2, 3, 0, 28, 2, 155, NULL, 'Vidutinis tiekiamo šalto vandens slėgis per 2 minutes', 1216, 1, NULL, NULL),
	(6377, 142, 1, 9, 3, 0, 28, 8, 155, NULL, 'Vidutinis tiekiamo šalto vandens slėgis per 3 minutes', 1216, 1, NULL, NULL),
	(6378, 142, 1, 10, 3, 0, 28, 9, 155, NULL, 'Vidutinis tiekiamo šalto vandens slėgis per 4 minutes', 1216, 1, NULL, NULL),
	(6379, 142, 1, 11, 3, 0, 28, 10, 155, NULL, 'Vidutinis tiekiamo šalto vandens slėgis per 5 minutes', 1216, 1, NULL, NULL),
	(6380, 142, 1, 12, 3, 0, 28, 11, 155, NULL, 'Vidutinis tiekiamo šalto vandens slėgis per 10 minučių', 1216, 1, NULL, NULL),
	(6381, 142, 1, 3, 3, 0, 28, 3, 155, NULL, 'Vidutinis tiekiamo šalto vandens slėgis per 30 minučių', 1216, 2, NULL, NULL),
	(6382, 142, 1, 4, 3, 0, 28, 4, 155, NULL, 'Vidutinis tiekiamo šalto vandens slėgis per valandą', 1216, 2, NULL, NULL),
	(6383, 142, 1, 13, 3, 0, 28, 12, 155, NULL, 'Vidutinis tiekiamo šalto vandens slėgis per 15 minučių', 1216, 2, NULL, NULL),
	(6384, 142, 1, 14, 3, 0, 28, 13, 155, NULL, 'Vidutinis tiekiamo šalto vandens slėgis per 20 minučių', 1216, 2, NULL, NULL),
	(6385, 142, 1, 5, 3, 0, 28, 5, 155, NULL, 'Vidutinis tiekiamo šalto vandens slėgis per parą', 1216, 3, NULL, NULL),
	(6386, 142, 1, 6, 3, 0, 28, 6, 155, NULL, 'Vidutinis tiekiamo šalto vandens slėgis per mėnesį', 1216, 4, NULL, NULL),
	(6387, 142, 1, 3, 4, 0, 28, 5, 155, NULL, 'Maksimalus pusvalandinis tiekiamo šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6388, 142, 1, 4, 4, 0, 28, 5, 155, NULL, 'Maksimalus valandinis tiekiamo šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6389, 142, 1, 13, 4, 0, 28, 5, 155, NULL, 'Maksimalus 15 minučių tiekiamo šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6390, 142, 1, 3, 4, 0, 28, 6, 155, NULL, 'Maksimalus pusvalandinis tiekiamo šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6391, 142, 1, 4, 4, 0, 28, 6, 155, NULL, 'Maksimalus valandinis tiekiamo šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6392, 142, 1, 13, 4, 0, 28, 6, 155, NULL, 'Maksimalus 15 minučių tiekiamo šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6393, 142, 1, 3, 5, 0, 28, 5, 155, NULL, 'Minimalus pusvalandinis tiekiamo šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6394, 142, 1, 4, 5, 0, 28, 5, 155, NULL, 'Minimalus valandinis tiekiamo šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6395, 142, 1, 13, 5, 0, 28, 5, 155, NULL, 'Minimalus 15 minučių tiekiamo šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6396, 142, 1, 3, 5, 0, 28, 6, 155, NULL, 'Minimalus pusvalandinis tiekiamo šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6397, 142, 1, 4, 5, 0, 28, 6, 155, NULL, 'Minimalus valandinis tiekiamo šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6398, 142, 1, 13, 5, 0, 28, 6, 155, NULL, 'Minimalus 15 minučių tiekiamo šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6399, 143, 1, 7, 1, 0, 28, 7, 156, NULL, 'Momentinis tiekiamo karšto vandens slėgis', 1209, 6, NULL, NULL),
	(6400, 143, 1, 1, 3, 0, 28, 1, 156, NULL, 'Vidutinis tiekiamo karšto vandens slėgis per minutę', 1216, 1, NULL, NULL),
	(6401, 143, 1, 2, 3, 0, 28, 2, 156, NULL, 'Vidutinis tiekiamo karšto vandens slėgis per 2 minutes', 1216, 1, NULL, NULL),
	(6402, 143, 1, 9, 3, 0, 28, 8, 156, NULL, 'Vidutinis tiekiamo karšto vandens slėgis per 3 minutes', 1216, 1, NULL, NULL),
	(6403, 143, 1, 10, 3, 0, 28, 9, 156, NULL, 'Vidutinis tiekiamo karšto vandens slėgis per 4 minutes', 1216, 1, NULL, NULL),
	(6404, 143, 1, 11, 3, 0, 28, 10, 156, NULL, 'Vidutinis tiekiamo karšto vandens slėgis per 5 minutes', 1216, 1, NULL, NULL),
	(6405, 143, 1, 12, 3, 0, 28, 11, 156, NULL, 'Vidutinis tiekiamo karšto vandens slėgis per 10 minučių', 1216, 1, NULL, NULL),
	(6406, 143, 1, 3, 3, 0, 28, 3, 156, NULL, 'Vidutinis tiekiamo karšto vandens slėgis per 30 minučių', 1216, 2, NULL, NULL),
	(6407, 143, 1, 4, 3, 0, 28, 4, 156, NULL, 'Vidutinis tiekiamo karšto vandens slėgis per valandą', 1216, 2, NULL, NULL),
	(6408, 143, 1, 13, 3, 0, 28, 12, 156, NULL, 'Vidutinis tiekiamo karšto vandens slėgis per 15 minučių', 1216, 2, NULL, NULL),
	(6409, 143, 1, 14, 3, 0, 28, 13, 156, NULL, 'Vidutinis tiekiamo karšto vandens slėgis per 20 minučių', 1216, 2, NULL, NULL),
	(6410, 143, 1, 5, 3, 0, 28, 5, 156, NULL, 'Vidutinis tiekiamo karšto vandens slėgis per parą', 1216, 3, NULL, NULL),
	(6411, 143, 1, 6, 3, 0, 28, 6, 156, NULL, 'Vidutinis tiekiamo karšto vandens slėgis per mėnesį', 1216, 4, NULL, NULL),
	(6412, 143, 1, 3, 4, 0, 28, 5, 156, NULL, 'Maksimalus pusvalandinis tiekiamo karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6413, 143, 1, 4, 4, 0, 28, 5, 156, NULL, 'Maksimalus valandinis tiekiamo karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6414, 143, 1, 13, 4, 0, 28, 5, 156, NULL, 'Maksimalus 15 minučių tiekiamo karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6415, 143, 1, 3, 4, 0, 28, 6, 156, NULL, 'Maksimalus pusvalandinis tiekiamo karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6416, 143, 1, 4, 4, 0, 28, 6, 156, NULL, 'Maksimalus valandinis tiekiamo karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6417, 143, 1, 13, 4, 0, 28, 6, 156, NULL, 'Maksimalus 15 minučių tiekiamo karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6418, 143, 1, 3, 5, 0, 28, 5, 156, NULL, 'Minimalus pusvalandinis tiekiamo karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6419, 143, 1, 4, 5, 0, 28, 5, 156, NULL, 'Minimalus valandinis tiekiamo karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6420, 143, 1, 13, 5, 0, 28, 5, 156, NULL, 'Minimalus 15 minučių tiekiamo karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6421, 143, 1, 3, 5, 0, 28, 6, 156, NULL, 'Minimalus pusvalandinis tiekiamo karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6422, 143, 1, 4, 5, 0, 28, 6, 156, NULL, 'Minimalus valandinis tiekiamo karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6423, 143, 1, 13, 5, 0, 28, 6, 156, NULL, 'Minimalus 15 minučių tiekiamo karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6424, 142, 2, 7, 1, 0, 28, 7, 155, NULL, 'Momentinis grįžtamo šalto vandens slėgis', 1210, 6, NULL, NULL),
	(6425, 142, 2, 1, 3, 0, 28, 1, 155, NULL, 'Vidutinis grįžtamo šalto vandens slėgis per minutę', 1249, 1, NULL, NULL),
	(6426, 142, 2, 2, 3, 0, 28, 2, 155, NULL, 'Vidutinis grįžtamo šalto vandens slėgis per 2 minutes', 1249, 1, NULL, NULL),
	(6427, 142, 2, 9, 3, 0, 28, 8, 155, NULL, 'Vidutinis grįžtamo šalto vandens slėgis per 3 minutes', 1249, 1, NULL, NULL),
	(6428, 142, 2, 10, 3, 0, 28, 9, 155, NULL, 'Vidutinis grįžtamo šalto vandens slėgis per 4 minutes', 1249, 1, NULL, NULL),
	(6429, 142, 2, 11, 3, 0, 28, 10, 155, NULL, 'Vidutinis grįžtamo šalto vandens slėgis per 5 minutes', 1249, 1, NULL, NULL),
	(6430, 142, 2, 12, 3, 0, 28, 11, 155, NULL, 'Vidutinis grįžtamo šalto vandens slėgis per 10 minučių', 1249, 1, NULL, NULL),
	(6431, 142, 2, 3, 3, 0, 28, 3, 155, NULL, 'Vidutinis grįžtamo šalto vandens slėgis per 30 minučių', 1249, 2, NULL, NULL),
	(6432, 142, 2, 4, 3, 0, 28, 4, 155, NULL, 'Vidutinis grįžtamo šalto vandens slėgis per valandą', 1249, 2, NULL, NULL),
	(6433, 142, 2, 13, 3, 0, 28, 12, 155, NULL, 'Vidutinis grįžtamo šalto vandens slėgis per 15 minučių', 1249, 2, NULL, NULL),
	(6434, 142, 2, 14, 3, 0, 28, 13, 155, NULL, 'Vidutinis grįžtamo šalto vandens slėgis per 20 minučių', 1249, 2, NULL, NULL),
	(6435, 142, 2, 5, 3, 0, 28, 5, 155, NULL, 'Vidutinis grįžtamo šalto vandens slėgis per parą', 1249, 3, NULL, NULL),
	(6436, 142, 2, 6, 3, 0, 28, 6, 155, NULL, 'Vidutinis grįžtamo šalto vandens slėgis per mėnesį', 1249, 4, NULL, NULL),
	(6437, 142, 2, 3, 4, 0, 28, 5, 155, NULL, 'Maksimalus pusvalandinis grįžtamo šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6438, 142, 2, 4, 4, 0, 28, 5, 155, NULL, 'Maksimalus valandinis grįžtamo šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6439, 142, 2, 13, 4, 0, 28, 5, 155, NULL, 'Maksimalus 15 minučių grįžtamo šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6440, 142, 2, 3, 4, 0, 28, 6, 155, NULL, 'Maksimalus pusvalandinis grįžtamo šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6441, 142, 2, 4, 4, 0, 28, 6, 155, NULL, 'Maksimalus valandinis grįžtamo šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6442, 142, 2, 13, 4, 0, 28, 6, 155, NULL, 'Maksimalus 15 minučių grįžtamo šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6443, 142, 2, 3, 5, 0, 28, 5, 155, NULL, 'Minimalus pusvalandinis grįžtamo šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6444, 142, 2, 4, 5, 0, 28, 5, 155, NULL, 'Minimalus valandinis grįžtamo šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6445, 142, 2, 13, 5, 0, 28, 5, 155, NULL, 'Minimalus 15 minučių grįžtamo šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6446, 142, 2, 3, 5, 0, 28, 6, 155, NULL, 'Minimalus pusvalandinis grįžtamo šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6447, 142, 2, 4, 5, 0, 28, 6, 155, NULL, 'Minimalus valandinis grįžtamo šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6448, 142, 2, 13, 5, 0, 28, 6, 155, NULL, 'Minimalus 15 minučių grįžtamo šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6449, 143, 2, 7, 1, 0, 28, 7, 156, NULL, 'Momentinis grįžtamo karšto vandens slėgis', 1210, 6, NULL, NULL),
	(6450, 143, 2, 1, 3, 0, 28, 1, 156, NULL, 'Vidutinis grįžtamo karšto vandens slėgis per minutę', 1249, 1, NULL, NULL),
	(6451, 143, 2, 2, 3, 0, 28, 2, 156, NULL, 'Vidutinis grįžtamo karšto vandens slėgis per 2 minutes', 1249, 1, NULL, NULL),
	(6452, 143, 2, 9, 3, 0, 28, 8, 156, NULL, 'Vidutinis grįžtamo karšto vandens slėgis per 3 minutes', 1249, 1, NULL, NULL),
	(6453, 143, 2, 10, 3, 0, 28, 9, 156, NULL, 'Vidutinis grįžtamo karšto vandens slėgis per 4 minutes', 1249, 1, NULL, NULL),
	(6454, 143, 2, 11, 3, 0, 28, 10, 156, NULL, 'Vidutinis grįžtamo karšto vandens slėgis per 5 minutes', 1249, 1, NULL, NULL),
	(6455, 143, 2, 12, 3, 0, 28, 11, 156, NULL, 'Vidutinis grįžtamo karšto vandens slėgis per 10 minučių', 1249, 1, NULL, NULL),
	(6456, 143, 2, 3, 3, 0, 28, 3, 156, NULL, 'Vidutinis grįžtamo karšto vandens slėgis per 30 minučių', 1249, 2, NULL, NULL),
	(6457, 143, 2, 4, 3, 0, 28, 4, 156, NULL, 'Vidutinis grįžtamo karšto vandens slėgis per valandą', 1249, 2, NULL, NULL),
	(6458, 143, 2, 13, 3, 0, 28, 12, 156, NULL, 'Vidutinis grįžtamo karšto vandens slėgis per 15 minučių', 1249, 2, NULL, NULL),
	(6459, 143, 2, 14, 3, 0, 28, 13, 156, NULL, 'Vidutinis grįžtamo karšto vandens slėgis per 20 minučių', 1249, 2, NULL, NULL),
	(6460, 143, 2, 5, 3, 0, 28, 5, 156, NULL, 'Vidutinis grįžtamo karšto vandens slėgis per parą', 1249, 3, NULL, NULL),
	(6461, 143, 2, 6, 3, 0, 28, 6, 156, NULL, 'Vidutinis grįžtamo karšto vandens slėgis per mėnesį', 1249, 4, NULL, NULL),
	(6462, 143, 2, 3, 4, 0, 28, 5, 156, NULL, 'Maksimalus pusvalandinis grįžtamo karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6463, 143, 2, 4, 4, 0, 28, 5, 156, NULL, 'Maksimalus valandinis grįžtamo karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6464, 143, 2, 13, 4, 0, 28, 5, 156, NULL, 'Maksimalus 15 minučių grįžtamo karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6465, 143, 2, 3, 4, 0, 28, 6, 156, NULL, 'Maksimalus pusvalandinis grįžtamo karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6466, 143, 2, 4, 4, 0, 28, 6, 156, NULL, 'Maksimalus valandinis grįžtamo karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6467, 143, 2, 13, 4, 0, 28, 6, 156, NULL, 'Maksimalus 15 minučių grįžtamo karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6468, 143, 2, 3, 5, 0, 28, 5, 156, NULL, 'Minimalus pusvalandinis grįžtamo karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6469, 143, 2, 4, 5, 0, 28, 5, 156, NULL, 'Minimalus valandinis grįžtamo karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6470, 143, 2, 13, 5, 0, 28, 5, 156, NULL, 'Minimalus 15 minučių grįžtamo karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6471, 143, 2, 3, 5, 0, 28, 6, 156, NULL, 'Minimalus pusvalandinis grįžtamo karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6472, 143, 2, 4, 5, 0, 28, 6, 156, NULL, 'Minimalus valandinis grįžtamo karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6473, 143, 2, 13, 5, 0, 28, 6, 156, NULL, 'Minimalus 15 minučių grįžtamo karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6474, 3, 1, 7, 1, 0, 3, 7, 16, NULL, 'Momentinė Q+ galia', 3314, 6, NULL, NULL),
	(6475, 3, 1, 7, 1, 0, 3, 15, 16, NULL, 'Momentinė Q+ galia, fiksuojama kas 5 sekundes', 3314, 7, NULL, NULL),
	(6476, 3, 1, 7, 1, 0, 3, 2, 16, NULL, 'Momentinė Q+ galia, fiksuojama kas 2 minutes', 3314, 1, NULL, NULL),
	(6477, 3, 1, 7, 1, 0, 3, 19, 16, NULL, 'Momentinė Q+ galia, fiksuojama kas 30 sekundžių', 3314, 7, NULL, NULL),
	(6478, 3, 2, 7, 1, 0, 3, 7, 16, NULL, 'Momentinė Q- galia', 3315, 6, NULL, NULL),
	(6479, 3, 2, 7, 1, 0, 3, 15, 16, NULL, 'Momentinė Q- galia, fiksuojama kas 5 sekundes', 3315, 7, NULL, NULL),
	(6480, 3, 2, 7, 1, 0, 3, 2, 16, NULL, 'Momentinė Q- galia, fiksuojama kas 2 minutes', 3315, 1, NULL, NULL),
	(6481, 3, 2, 7, 1, 0, 3, 19, 16, NULL, 'Momentinė Q- galia, fiksuojama kas 30 sekundžių', 3315, 7, NULL, NULL),
	(6482, 14, 1, 7, 1, 0, 1, 19, 26, NULL, 'Momentinė P+ galia L1 fazėje, fiksuojama kas 30 sekundžių', 3330, 7, NULL, NULL),
	(6483, 14, 1, 7, 1, 0, 1, 7, 26, NULL, 'Momentinė P+ galia L1 fazėje', 3330, 6, NULL, NULL),
	(6484, 14, 1, 7, 1, 0, 1, 15, 26, NULL, 'Momentinė P+ galia L1 fazėje, fiksuojama kas 5 sekundes', 3330, 7, NULL, NULL),
	(6485, 14, 1, 7, 1, 0, 1, 2, 26, NULL, 'Momentinė P+ galia L1 fazėje, fiksuojama kas 2 minutes', 3330, 1, NULL, NULL),
	(6486, 15, 1, 7, 1, 0, 1, 2, 27, NULL, 'Momentinė P+ galia L2 fazėje, fiksuojama kas 2 minutes', 3331, 1, NULL, NULL),
	(6487, 15, 1, 7, 1, 0, 1, 15, 27, NULL, 'Momentinė P+ galia L2 fazėje, fiksuojama kas 5 sekundes', 3331, 7, NULL, NULL),
	(6488, 15, 1, 7, 1, 0, 1, 7, 27, NULL, 'Momentinė P+ galia L2 fazėje', 3331, 6, NULL, NULL),
	(6489, 15, 1, 7, 1, 0, 1, 19, 27, NULL, 'Momentinė P+ galia L2 fazėje, fiksuojama kas 30 sekundžių', 3331, 7, NULL, NULL),
	(6490, 16, 1, 7, 1, 0, 1, 2, 28, NULL, 'Momentinė P+ galia L3 fazėje, fiksuojama kas 2 minutes', 3332, 1, NULL, NULL),
	(6491, 16, 1, 7, 1, 0, 1, 19, 28, NULL, 'Momentinė P+ galia L3 fazėje, fiksuojama kas 30 sekundžių', 3332, 7, NULL, NULL),
	(6492, 16, 1, 7, 1, 0, 1, 7, 28, NULL, 'Momentinė P+ galia L3 fazėje', 3332, 6, NULL, NULL),
	(6493, 16, 1, 7, 1, 0, 1, 15, 28, NULL, 'Momentinė P+ galia L3 fazėje, fiksuojama kas 5 sekundes', 3332, 7, NULL, NULL),
	(6494, 17, 1, 7, 1, 0, 3, 7, 29, NULL, 'Momentinė Q+ galia L1 fazėje', 3336, 6, NULL, NULL),
	(6495, 17, 1, 7, 1, 0, 3, 15, 29, NULL, 'Momentinė Q+ galia L1 fazėje, fiksuojama kas 5 sekundes', 3336, 7, NULL, NULL),
	(6496, 17, 1, 7, 1, 0, 3, 19, 29, NULL, 'Momentinė Q+ galia L1 fazėje, fiksuojama kas 30 sekundžių', 3336, 7, NULL, NULL),
	(6497, 17, 1, 7, 1, 0, 3, 2, 29, NULL, 'Momentinė Q+ galia L1 fazėje, fiksuojama kas 2 minutes', 3336, 1, NULL, NULL),
	(6498, 18, 1, 7, 1, 0, 3, 19, 30, NULL, 'Momentinė Q+ galia L2 fazėje, fiksuojama kas 30 sekundžių', 3337, 7, NULL, NULL),
	(6499, 18, 1, 7, 1, 0, 3, 15, 30, NULL, 'Momentinė Q+ galia L2 fazėje, fiksuojama kas 5 sekundes', 3337, 7, NULL, NULL),
	(6500, 18, 1, 7, 1, 0, 3, 2, 30, NULL, 'Momentinė Q+ galia L2 fazėje, fiksuojama kas 2 minutes', 3337, 1, NULL, NULL),
	(6501, 18, 1, 7, 1, 0, 3, 7, 30, NULL, 'Momentinė Q+ galia L2 fazėje', 3337, 6, NULL, NULL),
	(6502, 19, 1, 7, 1, 0, 3, 7, 31, NULL, 'Momentinė Q+ galia L3 fazėje', 3338, 6, NULL, NULL),
	(6503, 19, 1, 7, 1, 0, 3, 2, 31, NULL, 'Momentinė Q+ galia L3 fazėje, fiksuojama kas 2 minutes', 3338, 1, NULL, NULL),
	(6504, 19, 1, 7, 1, 0, 3, 15, 31, NULL, 'Momentinė Q+ galia L3 fazėje, fiksuojama kas 5 sekundes', 3338, 7, NULL, NULL),
	(6505, 19, 1, 7, 1, 0, 3, 19, 31, NULL, 'Momentinė Q+ galia L3 fazėje, fiksuojama kas 30 sekundžių', 3338, 7, NULL, NULL),
	(6506, 14, 2, 7, 1, 0, 1, 19, 26, NULL, 'Momentinė P- galia L1 fazėje, fiksuojama kas 30 sekundžių', 3333, 7, NULL, NULL),
	(6507, 14, 2, 7, 1, 0, 1, 7, 26, NULL, 'Momentinė P- galia L1 fazėje', 3333, 6, NULL, NULL),
	(6508, 14, 2, 7, 1, 0, 1, 15, 26, NULL, 'Momentinė P- galia L1 fazėje, fiksuojama kas 5 sekundes', 3333, 7, NULL, NULL),
	(6509, 14, 2, 7, 1, 0, 1, 2, 26, NULL, 'Momentinė P- galia L1 fazėje, fiksuojama kas 2 minutes', 3333, 1, NULL, NULL),
	(6510, 15, 2, 7, 1, 0, 1, 2, 27, NULL, 'Momentinė P- galia L2 fazėje, fiksuojama kas 2 minutes', 3334, 1, NULL, NULL),
	(6511, 15, 2, 7, 1, 0, 1, 15, 27, NULL, 'Momentinė P- galia L2 fazėje, fiksuojama kas 5 sekundes', 3334, 7, NULL, NULL),
	(6512, 15, 2, 7, 1, 0, 1, 7, 27, NULL, 'Momentinė P- galia L2 fazėje', 3334, 6, NULL, NULL),
	(6513, 15, 2, 7, 1, 0, 1, 19, 27, NULL, 'Momentinė P- galia L2 fazėje, fiksuojama kas 30 sekundžių', 3334, 7, NULL, NULL),
	(6514, 16, 2, 7, 1, 0, 1, 2, 28, NULL, 'Momentinė P- galia L3 fazėje, fiksuojama kas 2 minutes', 3335, 1, NULL, NULL),
	(6515, 16, 2, 7, 1, 0, 1, 19, 28, NULL, 'Momentinė P- galia L3 fazėje, fiksuojama kas 30 sekundžių', 3335, 7, NULL, NULL),
	(6516, 16, 2, 7, 1, 0, 1, 7, 28, NULL, 'Momentinė P- galia L3 fazėje', 3335, 6, NULL, NULL),
	(6517, 16, 2, 7, 1, 0, 1, 15, 28, NULL, 'Momentinė P- galia L3 fazėje, fiksuojama kas 5 sekundes', 3335, 7, NULL, NULL),
	(6518, 17, 2, 7, 1, 0, 3, 7, 29, NULL, 'Momentinė Q- galia L1 fazėje', 3339, 6, NULL, NULL),
	(6519, 17, 2, 7, 1, 0, 3, 15, 29, NULL, 'Momentinė Q- galia L1 fazėje, fiksuojama kas 5 sekundes', 3339, 7, NULL, NULL),
	(6520, 17, 2, 7, 1, 0, 3, 19, 29, NULL, 'Momentinė Q- galia L1 fazėje, fiksuojama kas 30 sekundžių', 3339, 7, NULL, NULL),
	(6521, 17, 2, 7, 1, 0, 3, 2, 29, NULL, 'Momentinė Q- galia L1 fazėje, fiksuojama kas 2 minutes', 3339, 1, NULL, NULL),
	(6522, 18, 2, 7, 1, 0, 3, 19, 30, NULL, 'Momentinė Q- galia L2 fazėje, fiksuojama kas 30 sekundžių', 3340, 7, NULL, NULL),
	(6523, 18, 2, 7, 1, 0, 3, 15, 30, NULL, 'Momentinė Q- galia L2 fazėje, fiksuojama kas 5 sekundes', 3340, 7, NULL, NULL),
	(6524, 18, 2, 7, 1, 0, 3, 2, 30, NULL, 'Momentinė Q- galia L2 fazėje, fiksuojama kas 2 minutes', 3340, 1, NULL, NULL),
	(6525, 18, 2, 7, 1, 0, 3, 7, 30, NULL, 'Momentinė Q- galia L2 fazėje', 3340, 6, NULL, NULL),
	(6526, 19, 2, 7, 1, 0, 3, 7, 31, NULL, 'Momentinė Q- galia L3 fazėje', 3341, 6, NULL, NULL),
	(6527, 19, 2, 7, 1, 0, 3, 2, 31, NULL, 'Momentinė Q- galia L3 fazėje, fiksuojama kas 2 minutes', 3341, 1, NULL, NULL),
	(6528, 19, 2, 7, 1, 0, 3, 15, 31, NULL, 'Momentinė Q- galia L3 fazėje, fiksuojama kas 5 sekundes', 3341, 7, NULL, NULL),
	(6529, 19, 2, 7, 1, 0, 3, 19, 31, NULL, 'Momentinė Q- galia L3 fazėje, fiksuojama kas 30 sekundžių', 3341, 7, NULL, NULL),
	(6530, 20, 1, 7, 1, 0, 7, 2, 32, NULL, 'Momentinė S+ galia L1 fazėje, fiksuojama kas 2 minutes', 3342, 1, NULL, NULL),
	(6531, 20, 1, 7, 1, 0, 7, 7, 32, NULL, 'Momentinė S+ galia L1 fazėje', 3342, 6, NULL, NULL),
	(6532, 20, 1, 7, 1, 0, 7, 15, 32, NULL, 'Momentinė S+ galia L1 fazėje, fiksuojama kas 5 sekundes', 3342, 7, NULL, NULL),
	(6533, 20, 1, 7, 1, 0, 7, 19, 32, NULL, 'Momentinė S+ galia L1 fazėje, fiksuojama kas 30 sekundžių', 3342, 7, NULL, NULL),
	(6534, 21, 1, 7, 1, 0, 7, 2, 33, NULL, 'Momentinė S+ galia L2 fazėje, fiksuojama kas 2 minutes', 3343, 1, NULL, NULL),
	(6535, 21, 1, 7, 1, 0, 7, 7, 33, NULL, 'Momentinė S+ galia L2 fazėje', 3343, 6, NULL, NULL),
	(6536, 21, 1, 7, 1, 0, 7, 15, 33, NULL, 'Momentinė S+ galia L2 fazėje, fiksuojama kas 5 sekundes', 3343, 7, NULL, NULL),
	(6537, 21, 1, 7, 1, 0, 7, 19, 33, NULL, 'Momentinė S+ galia L2 fazėje, fiksuojama kas 30 sekundžių', 3343, 7, NULL, NULL),
	(6538, 22, 1, 7, 1, 0, 7, 2, 34, NULL, 'Momentinė S+ galia L3 fazėje, fiksuojama kas 2 minutes', 3344, 1, NULL, NULL),
	(6539, 22, 1, 7, 1, 0, 7, 7, 34, NULL, 'Momentinė S+ galia L3 fazėje', 3344, 6, NULL, NULL),
	(6540, 22, 1, 7, 1, 0, 7, 15, 34, NULL, 'Momentinė S+ galia L3 fazėje, fiksuojama kas 5 sekundes', 3344, 7, NULL, NULL),
	(6541, 22, 1, 7, 1, 0, 7, 19, 34, NULL, 'Momentinė S+ galia L3 fazėje, fiksuojama kas 30 sekundžių', 3344, 7, NULL, NULL),
	(6542, 20, 2, 7, 1, 0, 7, 2, 32, NULL, 'Momentinė S- galia L1 fazėje, fiksuojama kas 2 minutes', 3345, 1, NULL, NULL),
	(6543, 20, 2, 7, 1, 0, 7, 7, 32, NULL, 'Momentinė S- galia L1 fazėje', 3345, 6, NULL, NULL),
	(6544, 20, 2, 7, 1, 0, 7, 15, 32, NULL, 'Momentinė S- galia L1 fazėje, fiksuojama kas 5 sekundes', 3345, 7, NULL, NULL),
	(6545, 20, 2, 7, 1, 0, 7, 19, 32, NULL, 'Momentinė S- galia L1 fazėje, fiksuojama kas 30 sekundžių', 3345, 7, NULL, NULL),
	(6546, 21, 2, 7, 1, 0, 7, 2, 33, NULL, 'Momentinė S- galia L2 fazėje, fiksuojama kas 2 minutes', 3346, 1, NULL, NULL),
	(6547, 21, 2, 7, 1, 0, 7, 7, 33, NULL, 'Momentinė S- galia L2 fazėje', 3346, 6, NULL, NULL),
	(6548, 21, 2, 7, 1, 0, 7, 15, 33, NULL, 'Momentinė S- galia L2 fazėje, fiksuojama kas 5 sekundes', 3346, 7, NULL, NULL),
	(6549, 21, 2, 7, 1, 0, 7, 19, 33, NULL, 'Momentinė S- galia L2 fazėje, fiksuojama kas 30 sekundžių', 3346, 7, NULL, NULL),
	(6550, 22, 2, 7, 1, 0, 7, 2, 34, NULL, 'Momentinė S- galia L3 fazėje, fiksuojama kas 2 minutes', 3347, 1, NULL, NULL),
	(6551, 22, 2, 7, 1, 0, 7, 7, 34, NULL, 'Momentinė S- galia L3 fazėje', 3347, 6, NULL, NULL),
	(6552, 22, 2, 7, 1, 0, 7, 15, 34, NULL, 'Momentinė S- galia L3 fazėje, fiksuojama kas 5 sekundes', 3347, 7, NULL, NULL),
	(6553, 22, 2, 7, 1, 0, 7, 19, 34, NULL, 'Momentinė S- galia L3 fazėje, fiksuojama kas 30 sekundžių', 3347, 7, NULL, NULL),
	(6554, 239, 0, 5, 2, 0, 35, 5, 252, NULL, 'Šalto vandens masės kiekis per parą', 1213, 3, NULL, NULL),
	(6555, 239, 0, 6, 2, 0, 35, 6, 252, NULL, 'Šalto vandens masės kiekis per mėnesį', 1213, 4, NULL, NULL),
	(6556, 239, 0, 14, 2, 0, 35, 13, 252, NULL, 'Šalto vandens masės kiekis per 20 minučių', 1213, 2, NULL, NULL),
	(6557, 239, 0, 9, 2, 0, 35, 8, 252, NULL, 'Šalto vandens masės kiekis per 3 minutes', 1213, 1, NULL, NULL),
	(6558, 239, 0, 10, 2, 0, 35, 9, 252, NULL, 'Šalto vandens masės kiekis per 4 minutes', 1213, 1, NULL, NULL),
	(6559, 239, 0, 11, 2, 0, 35, 10, 252, NULL, 'Šalto vandens masės kiekis per 5 minutes', 1213, 1, NULL, NULL),
	(6560, 239, 0, 12, 2, 0, 35, 11, 252, NULL, 'Šalto vandens masės kiekis per 10 minučių', 1213, 1, NULL, NULL),
	(6561, 239, 0, 1, 2, 0, 35, 1, 252, NULL, 'Šalto vandens masės kiekis per minutę', 1213, 1, NULL, NULL),
	(6562, 239, 0, 2, 2, 0, 35, 2, 252, NULL, 'Šalto vandens masės kiekis per 2 minutes', 1213, 1, NULL, NULL),
	(6563, 239, 0, 3, 2, 0, 35, 3, 252, NULL, 'Šalto vandens masės kiekis per 30 minučių', 1213, 2, NULL, NULL),
	(6564, 239, 0, 13, 2, 0, 35, 12, 252, NULL, 'Šalto vandens masės kiekis per 15 minučių', 1213, 2, NULL, NULL),
	(6565, 239, 0, 8, 2, 0, 35, 7, 252, NULL, 'Suminis šalto vandens masės kiekis', 1211, 5, NULL, NULL),
	(6566, 239, 0, 8, 2, 0, 35, 6, 252, NULL, 'Suminis šalto vandens masės kiekis, fiksuojamas kas mėnesį', 1211, 5, NULL, NULL),
	(6567, 239, 0, 8, 2, 0, 35, 5, 252, NULL, 'Suminis šalto vandens masės kiekis, fiksuojamas kas parą', 1211, 5, NULL, NULL),
	(6568, 239, 0, 8, 2, 0, 35, 4, 252, NULL, 'Suminis šalto vandens masės kiekis, fiksuojamas kas valandą', 1211, 5, NULL, NULL),
	(6569, 239, 0, 8, 2, 0, 35, 12, 252, NULL, 'Suminis šalto vandens masės kiekis, fiksuojamas kas 15 minučių', 1211, 5, NULL, NULL),
	(6570, 239, 0, 8, 2, 0, 35, 13, 252, NULL, 'Suminis šalto vandens masės kiekis, fiksuojamas kas 20 minučių', 1211, 5, NULL, NULL),
	(6571, 239, 0, 8, 2, 0, 35, 3, 252, NULL, 'Suminis šalto vandens masės kiekis, fiksuojamas kas 30 minučių', 1211, 5, NULL, NULL),
	(6572, 239, 0, 4, 2, 0, 35, 4, 252, NULL, 'Šalto vandens masės kiekis per valandą', 1213, 2, NULL, NULL),
	(6573, 240, 0, 5, 2, 0, 35, 5, 253, NULL, 'Karšto vandens masės kiekis per parą', 1213, 3, NULL, NULL),
	(6574, 240, 0, 6, 2, 0, 35, 6, 253, NULL, 'Karšto vandens masės kiekis per mėnesį', 1213, 4, NULL, NULL),
	(6575, 240, 0, 14, 2, 0, 35, 13, 253, NULL, 'Karšto vandens masės kiekis per 20 minučių', 1213, 2, NULL, NULL),
	(6576, 240, 0, 9, 2, 0, 35, 8, 253, NULL, 'Karšto vandens masės kiekis per 3 minutes', 1213, 1, NULL, NULL),
	(6577, 240, 0, 10, 2, 0, 35, 9, 253, NULL, 'Karšto vandens masės kiekis per 4 minutes', 1213, 1, NULL, NULL),
	(6578, 240, 0, 11, 2, 0, 35, 10, 253, NULL, 'Karšto vandens masės kiekis per 5 minutes', 1213, 1, NULL, NULL),
	(6579, 240, 0, 12, 2, 0, 35, 11, 253, NULL, 'Karšto vandens masės kiekis per 10 minučių', 1213, 1, NULL, NULL),
	(6580, 240, 0, 1, 2, 0, 35, 1, 253, NULL, 'Karšto vandens masės kiekis per minutę', 1213, 1, NULL, NULL),
	(6581, 240, 0, 2, 2, 0, 35, 2, 253, NULL, 'Karšto vandens masės kiekis per 2 minutes', 1213, 1, NULL, NULL),
	(6582, 240, 0, 3, 2, 0, 35, 3, 253, NULL, 'Karšto vandens masės kiekis per 30 minučių', 1213, 2, NULL, NULL),
	(6583, 240, 0, 13, 2, 0, 35, 12, 253, NULL, 'Karšto vandens masės kiekis per 15 minučių', 1213, 2, NULL, NULL),
	(6584, 240, 0, 8, 2, 0, 35, 7, 253, NULL, 'Suminis karšto vandens masės kiekis', 1211, 5, NULL, NULL),
	(6585, 240, 0, 8, 2, 0, 35, 6, 253, NULL, 'Suminis karšto vandens masės kiekis, fiksuojamas kas mėnesį', 1211, 5, NULL, NULL),
	(6586, 240, 0, 8, 2, 0, 35, 5, 253, NULL, 'Suminis karšto vandens masės kiekis, fiksuojamas kas parą', 1211, 5, NULL, NULL),
	(6587, 240, 0, 8, 2, 0, 35, 4, 253, NULL, 'Suminis karšto vandens masės kiekis, fiksuojamas kas valandą', 1211, 5, NULL, NULL),
	(6588, 240, 0, 8, 2, 0, 35, 12, 253, NULL, 'Suminis karšto vandens masės kiekis, fiksuojamas kas 15 minučių', 1211, 5, NULL, NULL),
	(6589, 240, 0, 8, 2, 0, 35, 13, 253, NULL, 'Suminis karšto vandens masės kiekis, fiksuojamas kas 20 minučių', 1211, 5, NULL, NULL),
	(6590, 240, 0, 8, 2, 0, 35, 3, 253, NULL, 'Suminis karšto vandens masės kiekis, fiksuojamas kas 30 minučių', 1211, 5, NULL, NULL),
	(6591, 240, 0, 4, 2, 0, 35, 4, 253, NULL, 'Karšto vandens masės kiekis per valandą', 1213, 2, NULL, NULL),
	(6592, 241, 0, 7, 1, 0, 0, 7, 254, NULL, 'Neįprastos situacijos egzistavimas', 1039, 6, NULL, NULL),
	(6593, 241, 0, 4, 2, 0, 0, 4, 254, NULL, 'Neįprastos situacijos egzistavimas per valandą', 1092, 2, NULL, NULL),
	(6594, 241, 0, 5, 2, 0, 0, 5, 254, NULL, 'Neįprastos situacijos egzistavimas per parą', 1092, 3, NULL, NULL),
	(6595, 241, 0, 6, 2, 0, 0, 6, 254, NULL, 'Neįprastos situacijos egzistavimas per mėnesį', 1092, 4, NULL, NULL),
	(6626, 1, 0, 7, 4, 1, 1, 5, 13, NULL, 'Maksimali momentinė aktyvinė galia pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(6627, 1, 0, 7, 4, 1, 1, 6, 13, NULL, 'Maksimali momentinė aktyvinė galia pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6628, 3, 0, 7, 4, 1, 3, 5, 16, NULL, 'Maksimali momentinė reaktyvinė galia pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(6629, 3, 0, 7, 4, 1, 3, 6, 16, NULL, 'Maksimali momentinė reaktyvinė galia pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6630, 1, 0, 7, 4, 2, 1, 5, 13, NULL, 'Maksimali momentinė aktyvinė galia pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(6631, 1, 0, 7, 4, 2, 1, 6, 13, NULL, 'Maksimali momentinė aktyvinė galia pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6632, 3, 0, 7, 4, 2, 3, 5, 16, NULL, 'Maksimali momentinė reaktyvinė galia pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(6633, 3, 0, 7, 4, 2, 3, 6, 16, NULL, 'Maksimali momentinė reaktyvinė galia pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6634, 1, 0, 7, 4, 3, 1, 5, 13, NULL, 'Maksimali momentinė aktyvinė galia pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(6635, 1, 0, 7, 4, 3, 1, 6, 13, NULL, 'Maksimali momentinė aktyvinė galia pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6636, 3, 0, 7, 4, 3, 3, 5, 16, NULL, 'Maksimali momentinė reaktyvinė galia pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(6637, 3, 0, 7, 4, 3, 3, 6, 16, NULL, 'Maksimali momentinė reaktyvinė galia pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6638, 1, 0, 7, 4, 4, 1, 5, 13, NULL, 'Maksimali momentinė aktyvinė galia pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(6639, 1, 0, 7, 4, 4, 1, 6, 13, NULL, 'Maksimali momentinė aktyvinė galia pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6640, 3, 0, 7, 4, 4, 3, 5, 16, NULL, 'Maksimali momentinė reaktyvinė galia pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(6641, 3, 0, 7, 4, 4, 3, 6, 16, NULL, 'Maksimali momentinė reaktyvinė galia pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6642, 266, 0, 7, 1, 0, 1, 7, 279, NULL, 'Momentinė aktyvinė absoliuti galia', 775, 6, NULL, NULL),
	(6643, 267, 0, 7, 1, 0, 1, 7, 280, NULL, 'Momentinė aktyvinė absoliuti galia L1 fazėje', 776, 6, NULL, NULL),
	(6644, 268, 0, 7, 1, 0, 1, 7, 281, NULL, 'Momentinė aktyvinė absoliuti galia L2 fazėje', 777, 6, NULL, NULL),
	(6645, 269, 0, 7, 1, 0, 1, 7, 282, NULL, 'Momentinė aktyvinė absoliuti galia L3 fazėje', 778, 6, NULL, NULL),
	(6646, 270, 0, 7, 1, 0, 3, 7, 283, NULL, 'Momentinė reaktyvinė absoliuti galia', 779, 6, NULL, NULL),
	(6647, 271, 0, 7, 1, 0, 3, 7, 284, NULL, 'Momentinė reaktyvinė absoliuti galia L1 fazėje', 780, 6, NULL, NULL),
	(6648, 248, 0, 7, 1, 0, 3, 7, 261, NULL, 'Momentinė reaktyvinė absoliuti galia L2 fazėje', 781, 6, NULL, NULL),
	(6649, 249, 0, 7, 1, 0, 3, 7, 262, NULL, 'Momentinė reaktyvinė absoliuti galia L3 fazėje', 782, 6, NULL, NULL),
	(6650, 250, 0, 7, 1, 0, 7, 7, 263, NULL, 'Momentinė pilnoji absoliuti galia', 783, 6, NULL, NULL),
	(6651, 251, 0, 7, 1, 0, 7, 7, 264, NULL, 'Momentinė pilnoji absoliuti galia L1 fazėje', 784, 6, NULL, NULL),
	(6652, 252, 0, 7, 1, 0, 7, 7, 265, NULL, 'Momentinė pilnoji absoliuti galia L2 fazėje', 785, 6, NULL, NULL),
	(6653, 253, 0, 7, 1, 0, 7, 7, 266, NULL, 'Momentinė pilnoji absoliuti galia L3 fazėje', 786, 6, NULL, NULL),
	(6654, 58, 0, 8, 2, 0, 31, 10, 59, NULL, 'Suminis šalto vandens tūrio kiekis, fiksuojamas kas 5 minutes', 1201, 5, NULL, NULL),
	(6655, 1, 1, 8, 2, 4, 2, 10, 14, '1.0.1.8.0.4', 'Suminė A+ energija pagal 4 tarifą, fiksuojama kas 5 minutes', 13, 5, NULL, NULL),
	(6656, 1, 1, 8, 2, 0, 2, 10, 14, NULL, 'Suminė A+ energija, fiksuojama kas 5 minutes', 132, 5, NULL, NULL),
	(6657, 1, 1, 8, 2, 3, 2, 10, 14, '1.0.1.8.0.3', 'Suminė A+ energija pagal 3 tarifą, fiksuojama kas 5 minutes', 9, 5, NULL, NULL),
	(6658, 1, 1, 8, 2, 2, 2, 10, 14, '1.0.1.8.0.2', 'Suminė A+ energija pagal 2 tarifą, fiksuojama kas 5 minutes', 5, 5, NULL, NULL),
	(6659, 1, 1, 8, 2, 1, 2, 10, 14, '1.0.1.8.0.1', 'Suminė A+ energija pagal 1 tarifą, fiksuojama kas 5 minutes', 1, 5, NULL, NULL),
	(6660, 1, 2, 8, 2, 0, 2, 10, 14, NULL, 'Suminė A- energija, fiksuojama kas 5 minutes', 133, 5, NULL, NULL),
	(6661, 1, 2, 8, 2, 4, 2, 10, 14, '1.0.2.8.0.4', 'Suminė A- energija pagal 4 tarifą, fiksuojama kas 5 minutes', 14, 5, NULL, NULL),
	(6662, 1, 2, 8, 2, 3, 2, 10, 14, '1.0.2.8.0.3', 'Suminė A- energija pagal 3 tarifą, fiksuojama kas 5 minutes', 10, 5, NULL, NULL),
	(6663, 1, 2, 8, 2, 2, 2, 10, 14, '1.0.2.8.0.2', 'Suminė A- energija pagal 2 tarifą, fiksuojama kas 5 minutes', 6, 5, NULL, NULL),
	(6664, 1, 2, 8, 2, 1, 2, 10, 14, '1.0.2.8.0.1', 'Suminė A- energija pagal 1 tarifą, fiksuojama kas 5 minutes', 2, 5, NULL, NULL),
	(6665, 1, 1, 8, 2, 5, 2, 10, 14, '1.0.1.8.0.5', 'Suminė A+ energija pagal 5 tarifą, fiksuojama kas 5 minutes', 274, 5, NULL, NULL),
	(6666, 1, 1, 8, 2, 6, 2, 10, 14, '1.0.1.8.0.6', 'Suminė A+ energija pagal 6 tarifą, fiksuojama kas 5 minutes', 284, 5, NULL, NULL),
	(6667, 1, 1, 8, 2, 7, 2, 10, 14, '1.0.1.8.0.7', 'Suminė A+ energija pagal 7 tarifą, fiksuojama kas 5 minutes', 294, 5, NULL, NULL),
	(6668, 1, 1, 8, 2, 8, 2, 10, 14, '1.0.1.8.0.8', 'Suminė A+ energija pagal 8 tarifą, fiksuojama kas 5 minutes', 304, 5, NULL, NULL),
	(6669, 1, 2, 8, 2, 5, 2, 10, 14, '1.0.2.8.0.5', 'Suminė A- energija pagal 5 tarifą, fiksuojama kas 5 minutes', 275, 5, NULL, NULL),
	(6670, 1, 2, 8, 2, 6, 2, 10, 14, '1.0.2.8.0.6', 'Suminė A- energija pagal 6 tarifą, fiksuojama kas 5 minutes', 285, 5, NULL, NULL),
	(6671, 1, 2, 8, 2, 7, 2, 10, 14, '1.0.2.8.0.7', 'Suminė A- energija pagal 7 tarifą, fiksuojama kas 5 minutes', 295, 5, NULL, NULL),
	(6672, 1, 2, 8, 2, 8, 2, 10, 14, '1.0.2.8.0.8', 'Suminė A- energija pagal 8 tarifą, fiksuojama kas 5 minutes', 305, 5, NULL, NULL),
	(6673, 1, 1, 11, 4, 1, 1, 6, 13, NULL, 'Maksimali 5 minučių P+ galia pagal 1 tarifą per mėnesį', 358, 4, NULL, NULL),
	(6674, 1, 2, 11, 4, 1, 1, 6, 13, NULL, 'Maksimali 5 minučių P- galia pagal 1 tarifą per mėnesį', 359, 4, NULL, NULL),
	(6675, 1, 1, 11, 4, 2, 1, 6, 13, NULL, 'Maksimali 5 minučių P+ galia pagal 2 tarifą per mėnesį', 362, 4, NULL, NULL),
	(6676, 1, 2, 11, 4, 2, 1, 6, 13, NULL, 'Maksimali 5 minučių P- galia pagal 2 tarifą per mėnesį', 363, 4, NULL, NULL),
	(6677, 1, 1, 11, 4, 3, 1, 6, 13, NULL, 'Maksimali 5 minučių P+ galia pagal 3 tarifą per mėnesį', 366, 4, NULL, NULL),
	(6678, 1, 2, 11, 4, 3, 1, 6, 13, NULL, 'Maksimali 5 minučių P- galia pagal 3 tarifą per mėnesį', 367, 4, NULL, NULL),
	(6679, 1, 1, 11, 4, 4, 1, 6, 13, NULL, 'Maksimali 5 minučių P+ galia pagal 4 tarifą per mėnesį', 370, 4, NULL, NULL),
	(6680, 1, 2, 11, 4, 4, 1, 6, 13, NULL, 'Maksimali 5 minučių P- galia pagal 4 tarifą per mėnesį', 371, 4, NULL, NULL),
	(6681, 1, 1, 11, 4, 1, 1, 5, 13, NULL, 'Maksimali 5 minučių P+ galia pagal 1 tarifą per parą', 378, 3, NULL, NULL),
	(6682, 1, 2, 11, 4, 1, 1, 5, 13, NULL, 'Maksimali 5 minučių P- galia pagal 1 tarifą per parą', 379, 3, NULL, NULL),
	(6683, 1, 1, 11, 4, 2, 1, 5, 13, NULL, 'Maksimali 5 minučių P+ galia pagal 2 tarifą per parą', 382, 3, NULL, NULL),
	(6684, 1, 2, 11, 4, 2, 1, 5, 13, NULL, 'Maksimali 5 minučių P- galia pagal 2 tarifą per parą', 383, 3, NULL, NULL),
	(6685, 1, 1, 11, 4, 3, 1, 5, 13, NULL, 'Maksimali 5 minučių P+ galia pagal 3 tarifą per parą', 386, 3, NULL, NULL),
	(6686, 1, 2, 11, 4, 3, 1, 5, 13, NULL, 'Maksimali 5 minučių P- galia pagal 3 tarifą per parą', 387, 3, NULL, NULL),
	(6687, 1, 1, 11, 4, 4, 1, 5, 13, NULL, 'Maksimali 5 minučių P+ galia pagal 4 tarifą per parą', 390, 3, NULL, NULL),
	(6688, 1, 2, 11, 4, 4, 1, 5, 13, NULL, 'Maksimali 5 minučių P- galia pagal 4 tarifą per parą', 391, 3, NULL, NULL),
	(6689, 1, 0, 11, 4, 1, 1, 5, 13, NULL, 'Maksimali 5 minučių P galia pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(6690, 1, 0, 11, 4, 1, 1, 6, 13, NULL, 'Maksimali 5 minučių P galia pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6691, 1, 0, 11, 4, 2, 1, 5, 13, NULL, 'Maksimali 5 minučių P galia pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(6692, 1, 0, 11, 4, 2, 1, 6, 13, NULL, 'Maksimali 5 minučių P galia pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6693, 1, 0, 11, 4, 3, 1, 5, 13, NULL, 'Maksimali 5 minučių P galia pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(6694, 1, 0, 11, 4, 3, 1, 6, 13, NULL, 'Maksimali 5 minučių P galia pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6695, 1, 0, 11, 4, 4, 1, 5, 13, NULL, 'Maksimali 5 minučių P galia pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(6696, 1, 0, 11, 4, 4, 1, 6, 13, NULL, 'Maksimali 5 minučių P galia pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6699, 1, 0, 8, 2, 0, 2, 10, 14, NULL, 'Suminė A energija, fiksuojama kas 5 minutes', 682, 5, NULL, NULL),
	(6700, 1, 0, 8, 2, 1, 2, 10, 14, NULL, 'Suminė A energija pagal 1 tarifą, fiksuojama kas 5 minutes', 683, 5, NULL, NULL),
	(6701, 1, 0, 8, 2, 2, 2, 10, 14, NULL, 'Suminė A energija pagal 2 tarifą, fiksuojama kas 5 minutes', 684, 5, NULL, NULL),
	(6702, 1, 0, 8, 2, 3, 2, 10, 14, NULL, 'Suminė A energija pagal 3 tarifą, fiksuojama kas 5 minutes', 685, 5, NULL, NULL),
	(6703, 1, 0, 8, 2, 4, 2, 10, 14, NULL, 'Suminė A energija pagal 4 tarifą, fiksuojama kas 5 minutes', 686, 5, NULL, NULL),
	(6704, 1, 0, 8, 2, 5, 2, 10, 14, NULL, 'Suminė A energija pagal 5 tarifą, fiksuojama kas 5 minutes', 687, 5, NULL, NULL),
	(6705, 1, 0, 8, 2, 6, 2, 10, 14, NULL, 'Suminė A energija pagal 6 tarifą, fiksuojama kas 5 minutes', 688, 5, NULL, NULL),
	(6706, 1, 0, 8, 2, 7, 2, 10, 14, NULL, 'Suminė A energija pagal 7 tarifą, fiksuojama kas 5 minutes', 689, 5, NULL, NULL),
	(6707, 1, 0, 8, 2, 8, 2, 10, 14, NULL, 'Suminė A energija pagal 8 tarifą, fiksuojama kas 5 minutes', 690, 5, NULL, NULL),
	(6708, 1, 3, 11, 3, 0, 1, 10, 13, NULL, 'Vidutinė aktyvinė tinklo galia per 5 minutes', 447, 1, NULL, NULL),
	(6709, 1, 3, 11, 2, 0, 2, 10, 14, NULL, 'Aktyvinė tinklo energija per 5 minutes', 720, 1, NULL, NULL),
	(6710, 3, 1, 8, 2, 0, 4, 10, 15, NULL, 'Suminė R+ energija, fiksuojama kas 5 minutes', 134, 5, NULL, NULL),
	(6711, 3, 1, 8, 2, 4, 4, 10, 15, '1.0.3.8.0.4', 'Suminė R+ energija pagal 4 tarifą, fiksuojama kas 5 minutes', 15, 5, NULL, NULL),
	(6712, 3, 1, 8, 2, 3, 4, 10, 15, '1.0.3.8.0.3', 'Suminė R+ energija pagal 3 tarifą, fiksuojama kas 5 minutes', 11, 5, NULL, NULL),
	(6713, 3, 1, 8, 2, 2, 4, 10, 15, '1.0.3.8.0.2', 'Suminė R+ energija pagal 2 tarifą, fiksuojama kas 5 minutes', 7, 5, NULL, NULL),
	(6714, 3, 1, 8, 2, 1, 4, 10, 15, '1.0.3.8.0.1', 'Suminė R+ energija pagal 1 tarifą, fiksuojama kas 5 minutes', 3, 5, NULL, NULL),
	(6715, 3, 2, 8, 2, 0, 4, 10, 15, NULL, 'Suminė R- energija, fiksuojama kas 5 minutes', 135, 5, NULL, NULL),
	(6716, 3, 2, 8, 2, 4, 4, 10, 15, '1.0.4.8.0.4', 'Suminė R- energija pagal 4 tarifą, fiksuojama kas 5 minutes', 16, 5, NULL, NULL),
	(6717, 3, 2, 8, 2, 3, 4, 10, 15, '1.0.4.8.0.3', 'Suminė R- energija pagal 3 tarifą, fiksuojama kas 5 minutes', 12, 5, NULL, NULL),
	(6718, 3, 2, 8, 2, 2, 4, 10, 15, '1.0.4.8.0.2', 'Suminė R- energija pagal 2 tarifą, fiksuojama kas 5 minutes', 8, 5, NULL, NULL),
	(6719, 3, 2, 8, 2, 1, 4, 10, 15, '1.0.4.8.0.1', 'Suminė R- energija pagal 1 tarifą, fiksuojama kas 5 minutes', 4, 5, NULL, NULL),
	(6720, 3, 5, 8, 2, 1, 4, 10, 15, NULL, 'Suminė R1 energija pagal 1 tarifą, fiksuojama kas 5 minutes', 138, 5, NULL, NULL),
	(6721, 3, 5, 8, 2, 2, 4, 10, 15, NULL, 'Suminė R1 energija pagal 2 tarifą, fiksuojama kas 5 minutes', 144, 5, NULL, NULL),
	(6722, 3, 5, 8, 2, 3, 4, 10, 15, NULL, 'Suminė R1 energija pagal 3 tarifą, fiksuojama kas 5 minutes', 150, 5, NULL, NULL),
	(6723, 3, 5, 8, 2, 4, 4, 10, 15, NULL, 'Suminė R1 energija pagal 4 tarifą, fiksuojama kas 5 minutes', 156, 5, NULL, NULL),
	(6724, 3, 5, 8, 2, 0, 4, 10, 15, NULL, 'Suminė R1 energija, fiksuojama kas 5 minutes', 322, 5, NULL, NULL),
	(6725, 3, 6, 8, 2, 3, 4, 10, 15, NULL, 'Suminė R2 energija pagal 3 tarifą, fiksuojama kas 5 minutes', 151, 5, NULL, NULL),
	(6726, 3, 6, 8, 2, 1, 4, 10, 15, NULL, 'Suminė R2 energija pagal 1 tarifą, fiksuojama kas 5 minutes', 139, 5, NULL, NULL),
	(6727, 3, 6, 8, 2, 2, 4, 10, 15, NULL, 'Suminė R2 energija pagal 2 tarifą, fiksuojama kas 5 minutes', 145, 5, NULL, NULL),
	(6728, 3, 6, 8, 2, 0, 4, 10, 15, NULL, 'Suminė R2 energija, fiksuojama kas 5 minutes', 323, 5, NULL, NULL),
	(6729, 3, 6, 8, 2, 4, 4, 10, 15, NULL, 'Suminė R2 energija pagal 4 tarifą, fiksuojama kas 5 minutes', 157, 5, NULL, NULL),
	(6730, 3, 7, 8, 2, 0, 4, 10, 15, NULL, 'Suminė R3 energija, fiksuojama kas 5 minutes', 324, 5, NULL, NULL),
	(6731, 3, 7, 8, 2, 4, 4, 10, 15, NULL, 'Suminė R3 energija pagal 4 tarifą, fiksuojama kas 5 minutes', 158, 5, NULL, NULL),
	(6732, 3, 7, 8, 2, 3, 4, 10, 15, NULL, 'Suminė R3 energija pagal 3 tarifą, fiksuojama kas 5 minutes', 152, 5, NULL, NULL),
	(6733, 3, 7, 8, 2, 2, 4, 10, 15, NULL, 'Suminė R3 energija pagal 2 tarifą, fiksuojama kas 5 minutes', 146, 5, NULL, NULL),
	(6734, 3, 7, 8, 2, 1, 4, 10, 15, NULL, 'Suminė R3 energija pagal 1 tarifą, fiksuojama kas 5 minutes', 140, 5, NULL, NULL),
	(6735, 3, 8, 8, 2, 2, 4, 10, 15, NULL, 'Suminė R4 energija pagal 2 tarifą, fiksuojama kas 5 minutes', 147, 5, NULL, NULL),
	(6736, 3, 8, 8, 2, 3, 4, 10, 15, NULL, 'Suminė R4 energija pagal 3 tarifą, fiksuojama kas 5 minutes', 153, 5, NULL, NULL),
	(6737, 3, 8, 8, 2, 4, 4, 10, 15, NULL, 'Suminė R4 energija pagal 4 tarifą, fiksuojama kas 5 minutes', 159, 5, NULL, NULL),
	(6738, 3, 8, 8, 2, 0, 4, 10, 15, NULL, 'Suminė R4 energija, fiksuojama kas 5 minutes', 325, 5, NULL, NULL),
	(6739, 3, 8, 8, 2, 1, 4, 10, 15, NULL, 'Suminė R4 energija pagal 1 tarifą, fiksuojama kas 5 minutes', 141, 5, NULL, NULL),
	(6740, 3, 1, 8, 2, 5, 4, 10, 15, '1.0.3.8.0.5', 'Suminė R+ energija pagal 5 tarifą, fiksuojama kas 5 minutes', 276, 5, NULL, NULL),
	(6741, 3, 1, 8, 2, 6, 4, 10, 15, '1.0.3.8.0.6', 'Suminė R+ energija pagal 6 tarifą, fiksuojama kas 5 minutes', 286, 5, NULL, NULL),
	(6742, 3, 1, 8, 2, 7, 4, 10, 15, '1.0.3.8.0.7', 'Suminė R+ energija pagal 7 tarifą, fiksuojama kas 5 minutes', 296, 5, NULL, NULL),
	(6743, 3, 1, 8, 2, 8, 4, 10, 15, '1.0.3.8.0.8', 'Suminė R+ energija pagal 8 tarifą, fiksuojama kas 5 minutes', 306, 5, NULL, NULL),
	(6744, 3, 2, 8, 2, 5, 4, 10, 15, '1.0.4.8.0.5', 'Suminė R- energija pagal 5 tarifą, fiksuojama kas 5 minutes', 277, 5, NULL, NULL),
	(6745, 3, 2, 8, 2, 6, 4, 10, 15, '1.0.4.8.0.6', 'Suminė R- energija pagal 6 tarifą, fiksuojama kas 5 minutes', 287, 5, NULL, NULL),
	(6746, 3, 2, 8, 2, 7, 4, 10, 15, '1.0.4.8.0.7', 'Suminė R- energija pagal 7 tarifą, fiksuojama kas 5 minutes', 297, 5, NULL, NULL),
	(6747, 3, 2, 8, 2, 8, 4, 10, 15, '1.0.4.8.0.8', 'Suminė R- energija pagal 8 tarifą, fiksuojama kas 5 minutes', 307, 5, NULL, NULL),
	(6748, 3, 5, 8, 2, 5, 4, 10, 15, NULL, 'Suminė R1 energija pagal 5 tarifą, fiksuojama kas 5 minutes', 278, 5, NULL, NULL),
	(6749, 3, 5, 8, 2, 6, 4, 10, 15, NULL, 'Suminė R1 energija pagal 6 tarifą, fiksuojama kas 5 minutes', 288, 5, NULL, NULL),
	(6750, 3, 5, 8, 2, 7, 4, 10, 15, NULL, 'Suminė R1 energija pagal 7 tarifą, fiksuojama kas 5 minutes', 298, 5, NULL, NULL),
	(6751, 3, 5, 8, 2, 8, 4, 10, 15, NULL, 'Suminė R1 energija pagal 8 tarifą, fiksuojama kas 5 minutes', 308, 5, NULL, NULL),
	(6752, 3, 6, 8, 2, 5, 4, 10, 15, NULL, 'Suminė R2 energija pagal 5 tarifą, fiksuojama kas 5 minutes', 279, 5, NULL, NULL),
	(6753, 3, 6, 8, 2, 6, 4, 10, 15, NULL, 'Suminė R2 energija pagal 6 tarifą, fiksuojama kas 5 minutes', 289, 5, NULL, NULL),
	(6754, 3, 6, 8, 2, 7, 4, 10, 15, NULL, 'Suminė R2 energija pagal 7 tarifą, fiksuojama kas 5 minutes', 299, 5, NULL, NULL),
	(6755, 3, 6, 8, 2, 8, 4, 10, 15, NULL, 'Suminė R2 energija pagal 8 tarifą, fiksuojama kas 5 minutes', 309, 5, NULL, NULL),
	(6756, 3, 7, 8, 2, 5, 4, 10, 15, NULL, 'Suminė R3 energija pagal 5 tarifą, fiksuojama kas 5 minutes', 280, 5, NULL, NULL),
	(6757, 3, 7, 8, 2, 6, 4, 10, 15, NULL, 'Suminė R3 energija pagal 6 tarifą, fiksuojama kas 5 minutes', 290, 5, NULL, NULL),
	(6758, 3, 7, 8, 2, 7, 4, 10, 15, NULL, 'Suminė R3 energija pagal 7 tarifą, fiksuojama kas 5 minutes', 300, 5, NULL, NULL),
	(6759, 3, 7, 8, 2, 8, 4, 10, 15, NULL, 'Suminė R3 energija pagal 8 tarifą, fiksuojama kas 5 minutes', 310, 5, NULL, NULL),
	(6760, 3, 8, 8, 2, 5, 4, 10, 15, NULL, 'Suminė R4 energija pagal 5 tarifą, fiksuojama kas 5 minutes', 281, 5, NULL, NULL),
	(6761, 3, 8, 8, 2, 6, 4, 10, 15, NULL, 'Suminė R4 energija pagal 6 tarifą, fiksuojama kas 5 minutes', 291, 5, NULL, NULL),
	(6762, 3, 8, 8, 2, 7, 4, 10, 15, NULL, 'Suminė R4 energija pagal 7 tarifą, fiksuojama kas 5 minutes', 301, 5, NULL, NULL),
	(6763, 3, 8, 8, 2, 8, 4, 10, 15, NULL, 'Suminė R4 energija pagal 8 tarifą, fiksuojama kas 5 minutes', 311, 5, NULL, NULL),
	(6764, 3, 1, 11, 4, 1, 3, 6, 16, NULL, 'Maksimali 5 minučių Q+ galia pagal 1 tarifą per mėnesį', 360, 4, NULL, NULL),
	(6765, 3, 2, 11, 4, 1, 3, 6, 16, NULL, 'Maksimali 5 minučių Q- galia pagal 1 tarifą per mėnesį', 361, 4, NULL, NULL),
	(6766, 3, 1, 11, 4, 2, 3, 6, 16, NULL, 'Maksimali 5 minučių Q+ galia pagal 2 tarifą per mėnesį', 364, 4, NULL, NULL),
	(6767, 3, 2, 11, 4, 2, 3, 6, 16, NULL, 'Maksimali 5 minučių Q- galia pagal 2 tarifą per mėnesį', 365, 4, NULL, NULL),
	(6768, 3, 1, 11, 4, 3, 3, 6, 16, NULL, 'Maksimali 5 minučių Q+ galia pagal 3 tarifą per mėnesį', 368, 4, NULL, NULL),
	(6769, 3, 2, 11, 4, 3, 3, 6, 16, NULL, 'Maksimali 5 minučių Q- galia pagal 3 tarifą per mėnesį', 369, 4, NULL, NULL),
	(6770, 3, 1, 11, 4, 4, 3, 6, 16, NULL, 'Maksimali 5 minučių Q+ galia pagal 4 tarifą per mėnesį', 372, 4, NULL, NULL),
	(6771, 3, 2, 11, 4, 4, 3, 6, 16, NULL, 'Maksimali 5 minučių Q- galia pagal 4 tarifą per mėnesį', 373, 4, NULL, NULL),
	(6772, 3, 1, 11, 4, 1, 3, 5, 16, NULL, 'Maksimali 5 minučių Q+ galia pagal 1 tarifą per parą', 380, 3, NULL, NULL),
	(6773, 3, 2, 11, 4, 1, 3, 5, 16, NULL, 'Maksimali 5 minučių Q- galia pagal 1 tarifą per parą', 381, 3, NULL, NULL),
	(6774, 3, 1, 11, 4, 2, 3, 5, 16, NULL, 'Maksimali 5 minučių Q+ galia pagal 2 tarifą per parą', 384, 3, NULL, NULL),
	(6775, 3, 2, 11, 4, 2, 3, 5, 16, NULL, 'Maksimali 5 minučių Q- galia pagal 2 tarifą per parą', 385, 3, NULL, NULL),
	(6776, 3, 1, 11, 4, 3, 3, 5, 16, NULL, 'Maksimali 5 minučių Q+ galia pagal 3 tarifą per parą', 388, 3, NULL, NULL),
	(6777, 3, 2, 11, 4, 3, 3, 5, 16, NULL, 'Maksimali 5 minučių Q- galia pagal 3 tarifą per parą', 389, 3, NULL, NULL),
	(6778, 3, 1, 11, 4, 4, 3, 5, 16, NULL, 'Maksimali 5 minučių Q+ galia pagal 4 tarifą per parą', 392, 3, NULL, NULL),
	(6779, 3, 2, 11, 4, 4, 3, 5, 16, NULL, 'Maksimali 5 minučių Q- galia pagal 4 tarifą per parą', 393, 3, NULL, NULL),
	(6780, 3, 5, 11, 4, 1, 3, 6, 16, NULL, 'Maksimali 5 minučių Q1 galia pagal 1 tarifą per mėnesį', 398, 4, NULL, NULL),
	(6781, 3, 6, 11, 4, 1, 3, 6, 16, NULL, 'Maksimali 5 minučių Q2 galia pagal 1 tarifą per mėnesį', 399, 4, NULL, NULL),
	(6782, 3, 7, 11, 4, 1, 3, 6, 16, NULL, 'Maksimali 5 minučių Q3 galia pagal 1 tarifą per mėnesį', 400, 4, NULL, NULL),
	(6783, 3, 8, 11, 4, 1, 3, 6, 16, NULL, 'Maksimali 5 minučių Q4 galia pagal 1 tarifą per mėnesį', 401, 4, NULL, NULL),
	(6784, 3, 5, 11, 4, 2, 3, 6, 16, NULL, 'Maksimali 5 minučių Q1 galia pagal 2 tarifą per mėnesį', 404, 4, NULL, NULL),
	(6785, 3, 6, 11, 4, 2, 3, 6, 16, NULL, 'Maksimali 5 minučių Q2 galia pagal 2 tarifą per mėnesį', 405, 4, NULL, NULL),
	(6786, 3, 7, 11, 4, 2, 3, 6, 16, NULL, 'Maksimali 5 minučių Q3 galia pagal 2 tarifą per mėnesį', 406, 4, NULL, NULL),
	(6787, 3, 8, 11, 4, 2, 3, 6, 16, NULL, 'Maksimali 5 minučių Q4 galia pagal 2 tarifą per mėnesį', 407, 4, NULL, NULL),
	(6788, 3, 5, 11, 4, 3, 3, 6, 16, NULL, 'Maksimali 5 minučių Q1 galia pagal 3 tarifą per mėnesį', 410, 4, NULL, NULL),
	(6789, 3, 6, 11, 4, 3, 3, 6, 16, NULL, 'Maksimali 5 minučių Q2 galia pagal 3 tarifą per mėnesį', 411, 4, NULL, NULL),
	(6790, 3, 7, 11, 4, 3, 3, 6, 16, NULL, 'Maksimali 5 minučių Q3 galia pagal 3 tarifą per mėnesį', 412, 4, NULL, NULL),
	(6791, 3, 8, 11, 4, 3, 3, 6, 16, NULL, 'Maksimali 5 minučių Q4 galia pagal 3 tarifą per mėnesį', 413, 4, NULL, NULL),
	(6792, 3, 5, 11, 4, 4, 3, 6, 16, NULL, 'Maksimali 5 minučių Q1 galia pagal 4 tarifą per mėnesį', 416, 4, NULL, NULL),
	(6793, 3, 6, 11, 4, 4, 3, 6, 16, NULL, 'Maksimali 5 minučių Q2 galia pagal 4 tarifą per mėnesį', 417, 4, NULL, NULL),
	(6794, 3, 7, 11, 4, 4, 3, 6, 16, NULL, 'Maksimali 5 minučių Q3 galia pagal 4 tarifą per mėnesį', 418, 4, NULL, NULL),
	(6795, 3, 8, 11, 4, 4, 3, 6, 16, NULL, 'Maksimali 5 minučių Q4 galia pagal 4 tarifą per mėnesį', 419, 4, NULL, NULL),
	(6796, 3, 5, 11, 4, 1, 3, 5, 16, NULL, 'Maksimali 5 minučių Q1 galia pagal 1 tarifą per parą', 422, 3, NULL, NULL),
	(6797, 3, 6, 11, 4, 1, 3, 5, 16, NULL, 'Maksimali 5 minučių Q2 galia pagal 1 tarifą per parą', 423, 3, NULL, NULL),
	(6798, 3, 7, 11, 4, 1, 3, 5, 16, NULL, 'Maksimali 5 minučių Q3 galia pagal 1 tarifą per parą', 424, 3, NULL, NULL),
	(6799, 3, 8, 11, 4, 1, 3, 5, 16, NULL, 'Maksimali 5 minučių Q4 galia pagal 1 tarifą per parą', 425, 3, NULL, NULL),
	(6800, 3, 5, 11, 4, 2, 3, 5, 16, NULL, 'Maksimali 5 minučių Q1 galia pagal 2 tarifą per parą', 428, 3, NULL, NULL),
	(6801, 3, 6, 11, 4, 2, 3, 5, 16, NULL, 'Maksimali 5 minučių Q2 galia pagal 2 tarifą per parą', 429, 3, NULL, NULL),
	(6802, 3, 7, 11, 4, 2, 3, 5, 16, NULL, 'Maksimali 5 minučių Q3 galia pagal 2 tarifą per parą', 430, 3, NULL, NULL),
	(6803, 3, 8, 11, 4, 2, 3, 5, 16, NULL, 'Maksimali 5 minučių Q4 galia pagal 2 tarifą per parą', 431, 3, NULL, NULL),
	(6804, 3, 5, 11, 4, 3, 3, 5, 16, NULL, 'Maksimali 5 minučių Q1 galia pagal 3 tarifą per parą', 434, 3, NULL, NULL),
	(6805, 3, 6, 11, 4, 3, 3, 5, 16, NULL, 'Maksimali 5 minučių Q2 galia pagal 3 tarifą per parą', 435, 3, NULL, NULL),
	(6806, 3, 7, 11, 4, 3, 3, 5, 16, NULL, 'Maksimali 5 minučių Q3 galia pagal 3 tarifą per parą', 436, 3, NULL, NULL),
	(6807, 3, 8, 11, 4, 3, 3, 5, 16, NULL, 'Maksimali 5 minučių Q4 galia pagal 3 tarifą per parą', 437, 3, NULL, NULL),
	(6808, 3, 5, 11, 4, 4, 3, 5, 16, NULL, 'Maksimali 5 minučių Q1 galia pagal 4 tarifą per parą', 440, 3, NULL, NULL),
	(6809, 3, 6, 11, 4, 4, 3, 5, 16, NULL, 'Maksimali 5 minučių Q2 galia pagal 4 tarifą per parą', 441, 3, NULL, NULL),
	(6810, 3, 7, 11, 4, 4, 3, 5, 16, NULL, 'Maksimali 5 minučių Q3 galia pagal 4 tarifą per parą', 442, 3, NULL, NULL),
	(6811, 3, 8, 11, 4, 4, 3, 5, 16, NULL, 'Maksimali 5 minučių Q4 galia pagal 4 tarifą per parą', 443, 3, NULL, NULL),
	(6812, 3, 0, 11, 4, 1, 3, 5, 16, NULL, 'Maksimali 5 minučių Q galia pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(6813, 3, 0, 11, 4, 1, 3, 6, 16, NULL, 'Maksimali 5 minučių Q galia pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6814, 3, 0, 11, 4, 2, 3, 5, 16, NULL, 'Maksimali 5 minučių Q galia pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(6815, 3, 0, 11, 4, 2, 3, 6, 16, NULL, 'Maksimali 5 minučių Q galia pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6816, 3, 0, 11, 4, 3, 3, 5, 16, NULL, 'Maksimali 5 minučių Q galia pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(6817, 3, 0, 11, 4, 3, 3, 6, 16, NULL, 'Maksimali 5 minučių Q galia pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6818, 3, 0, 11, 4, 4, 3, 5, 16, NULL, 'Maksimali 5 minučių Q galia pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(6819, 3, 0, 11, 4, 4, 3, 6, 16, NULL, 'Maksimali 5 minučių Q galia pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6822, 3, -1, 8, 2, 0, 4, 10, 15, NULL, 'Suminė talpuminė R energija, fiksuojama kas 5 minutes', 3159, 5, NULL, NULL),
	(6823, 3, 9, 8, 2, 0, 4, 10, 15, NULL, 'Suminė indukcinė R energija, fiksuojama kas 5 minutes', 3158, 5, NULL, NULL),
	(6824, 3, 5, 11, 4, 0, 3, 6, 16, NULL, 'Maksimali 5 minučių Q1 galia per mėnesį', 655, 4, NULL, NULL),
	(6825, 3, 6, 11, 4, 0, 3, 6, 16, NULL, 'Maksimali 5 minučių Q2 galia per mėnesį', 656, 4, NULL, NULL),
	(6826, 3, 7, 11, 4, 0, 3, 6, 16, NULL, 'Maksimali 5 minučių Q3 galia per mėnesį', 657, 4, NULL, NULL),
	(6827, 3, 8, 11, 4, 0, 3, 6, 16, NULL, 'Maksimali 5 minučių Q4 galia per mėnesį', 658, 4, NULL, NULL),
	(6828, 3, 5, 11, 4, 0, 3, 5, 16, NULL, 'Maksimali 5 minučių Q1 galia per parą', 659, 3, NULL, NULL),
	(6829, 3, 6, 11, 4, 0, 3, 5, 16, NULL, 'Maksimali 5 minučių Q2 galia per parą', 660, 3, NULL, NULL),
	(6830, 3, 7, 11, 4, 0, 3, 5, 16, NULL, 'Maksimali 5 minučių Q3 galia per parą', 661, 3, NULL, NULL),
	(6831, 3, 8, 11, 4, 0, 3, 5, 16, NULL, 'Maksimali 5 minučių Q4 galia per parą', 662, 3, NULL, NULL),
	(6832, 3, 3, 11, 3, 0, 3, 10, 16, NULL, 'Vidutinė reaktyvinė tinklo galia per 5 minutes', 449, 1, NULL, NULL),
	(6833, 3, -2, 11, 3, 0, 3, 10, 16, NULL, 'Vidutinė Q1+Q4 galia per 5 minutes', 452, 1, NULL, NULL),
	(6834, 3, -3, 11, 3, 0, 3, 10, 16, NULL, 'Vidutinė Q2+Q3 galia per 5 minutes', 453, 1, NULL, NULL),
	(6835, 3, 3, 11, 2, 0, 4, 10, 15, NULL, 'Reaktyvinė tinklo energija per 5 minutes', 722, 1, NULL, NULL),
	(6836, 3, -2, 11, 2, 0, 4, 10, 15, NULL, 'R1+R4 energija per 5 minutes', 725, 1, NULL, NULL),
	(6837, 3, -3, 11, 2, 0, 4, 10, 15, NULL, 'R2+R3 energija per 5 minutes', 726, 1, NULL, NULL),
	(6838, 3, -1, 11, 2, 0, 4, 10, 15, NULL, 'Talpuminė energija per 5 minutes', 757, 1, NULL, NULL),
	(6839, 3, 9, 11, 2, 0, 4, 10, 15, NULL, 'Indukcinė energija per 5 minutes', 758, 1, NULL, NULL),
	(6840, 34, 1, 8, 2, 0, 41, 10, 45, NULL, 'Suminė W+ energija, fiksuojama kas 5 minutes', 136, 5, NULL, NULL),
	(6841, 34, 1, 8, 2, 4, 41, 10, 45, NULL, 'Suminė W+ energija pagal 4 tarifą, fiksuojama kas 5 minutes', 160, 5, NULL, NULL),
	(6842, 34, 1, 8, 2, 3, 41, 10, 45, NULL, 'Suminė W+ energija pagal 3 tarifą, fiksuojama kas 5 minutes', 154, 5, NULL, NULL),
	(6843, 34, 1, 8, 2, 2, 41, 10, 45, NULL, 'Suminė W+ energija pagal 2 tarifą, fiksuojama kas 5 minutes', 148, 5, NULL, NULL),
	(6844, 34, 1, 8, 2, 1, 41, 10, 45, NULL, 'Suminė W+ energija pagal 1 tarifą, fiksuojama kas 5 minutes', 142, 5, NULL, NULL),
	(6845, 34, 2, 8, 2, 3, 41, 10, 45, NULL, 'Suminė W- energija pagal 3 tarifą, fiksuojama kas 5 minutes', 155, 5, NULL, NULL),
	(6846, 34, 2, 8, 2, 0, 41, 10, 45, NULL, 'Suminė W- energija, fiksuojama kas 5 minutes', 137, 5, NULL, NULL),
	(6847, 34, 2, 8, 2, 2, 41, 10, 45, NULL, 'Suminė W- energija pagal 2 tarifą, fiksuojama kas 5 minutes', 149, 5, NULL, NULL),
	(6848, 34, 2, 8, 2, 1, 41, 10, 45, NULL, 'Suminė W- energija pagal 1 tarifą, fiksuojama kas 5 minutes', 143, 5, NULL, NULL),
	(6849, 34, 2, 8, 2, 4, 41, 10, 45, NULL, 'Suminė W- energija pagal 4 tarifą, fiksuojama kas 5 minutes', 161, 5, NULL, NULL),
	(6850, 34, 1, 8, 2, 5, 41, 10, 45, NULL, 'Suminė W+ energija pagal 5 tarifą, fiksuojama kas 5 minutes', 282, 5, NULL, NULL),
	(6851, 34, 1, 8, 2, 6, 41, 10, 45, NULL, 'Suminė W+ energija pagal 6 tarifą, fiksuojama kas 5 minutes', 292, 5, NULL, NULL),
	(6852, 34, 1, 8, 2, 7, 41, 10, 45, NULL, 'Suminė W+ energija pagal 7 tarifą, fiksuojama kas 5 minutes', 302, 5, NULL, NULL),
	(6853, 34, 1, 8, 2, 8, 41, 10, 45, NULL, 'Suminė W+ energija pagal 8 tarifą, fiksuojama kas 5 minutes', 312, 5, NULL, NULL),
	(6854, 34, 2, 8, 2, 5, 41, 10, 45, NULL, 'Suminė W- energija pagal 5 tarifą, fiksuojama kas 5 minutes', 283, 5, NULL, NULL),
	(6855, 34, 2, 8, 2, 6, 41, 10, 45, NULL, 'Suminė W- energija pagal 6 tarifą, fiksuojama kas 5 minutes', 293, 5, NULL, NULL),
	(6856, 34, 2, 8, 2, 7, 41, 10, 45, NULL, 'Suminė W- energija pagal 7 tarifą, fiksuojama kas 5 minutes', 303, 5, NULL, NULL),
	(6857, 34, 2, 8, 2, 8, 41, 10, 45, NULL, 'Suminė W- energija pagal 8 tarifą, fiksuojama kas 5 minutes', 313, 5, NULL, NULL),
	(6858, 34, 1, 11, 4, 1, 7, 6, 44, NULL, 'Maksimali 5 minučių S+ galia pagal 1 tarifą per mėnesį', 402, 4, NULL, NULL),
	(6859, 34, 2, 11, 4, 1, 7, 6, 44, NULL, 'Maksimali 5 minučių S- galia pagal 1 tarifą per mėnesį', 403, 4, NULL, NULL),
	(6860, 34, 1, 11, 4, 2, 7, 6, 44, NULL, 'Maksimali 5 minučių S+ galia pagal 2 tarifą per mėnesį', 408, 4, NULL, NULL),
	(6861, 34, 2, 11, 4, 2, 7, 6, 44, NULL, 'Maksimali 5 minučių S- galia pagal 2 tarifą per mėnesį', 409, 4, NULL, NULL),
	(6862, 34, 1, 11, 4, 3, 7, 6, 44, NULL, 'Maksimali 5 minučių S+ galia pagal 3 tarifą per mėnesį', 414, 4, NULL, NULL),
	(6863, 34, 2, 11, 4, 3, 7, 6, 44, NULL, 'Maksimali 5 minučių S- galia pagal 3 tarifą per mėnesį', 415, 4, NULL, NULL),
	(6864, 34, 1, 11, 4, 4, 7, 6, 44, NULL, 'Maksimali 5 minučių S+ galia pagal 4 tarifą per mėnesį', 420, 4, NULL, NULL),
	(6865, 34, 2, 11, 4, 4, 7, 6, 44, NULL, 'Maksimali 5 minučių S- galia pagal 4 tarifą per mėnesį', 421, 4, NULL, NULL),
	(6866, 34, 1, 11, 4, 1, 7, 5, 44, NULL, 'Maksimali 5 minučių S+ galia pagal 1 tarifą per parą', 426, 3, NULL, NULL),
	(6867, 34, 2, 11, 4, 1, 7, 5, 44, NULL, 'Maksimali 5 minučių S- galia pagal 1 tarifą per parą', 427, 3, NULL, NULL),
	(6868, 34, 1, 11, 4, 2, 7, 5, 44, NULL, 'Maksimali 5 minučių S+ galia pagal 2 tarifą per parą', 432, 3, NULL, NULL),
	(6869, 34, 2, 11, 4, 2, 7, 5, 44, NULL, 'Maksimali 5 minučių S- galia pagal 2 tarifą per parą', 433, 3, NULL, NULL),
	(6870, 34, 1, 11, 4, 3, 7, 5, 44, NULL, 'Maksimali 5 minučių S+ galia pagal 3 tarifą per parą', 438, 3, NULL, NULL),
	(6871, 34, 2, 11, 4, 3, 7, 5, 44, NULL, 'Maksimali 5 minučių S- galia pagal 3 tarifą per parą', 439, 3, NULL, NULL),
	(6872, 34, 1, 11, 4, 4, 7, 5, 44, NULL, 'Maksimali 5 minučių S+ galia pagal 4 tarifą per parą', 444, 3, NULL, NULL),
	(6873, 34, 2, 11, 4, 4, 7, 5, 44, NULL, 'Maksimali 5 minučių S- galia pagal 4 tarifą per parą', 445, 3, NULL, NULL),
	(6874, 34, 0, 11, 4, 1, 7, 5, 44, NULL, 'Maksimali 5 minučių S galia pagal 1 tarifą per parą', NULL, 3, NULL, NULL),
	(6875, 34, 0, 11, 4, 1, 7, 6, 44, NULL, 'Maksimali 5 minučių S galia pagal 1 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6876, 34, 0, 11, 4, 2, 7, 5, 44, NULL, 'Maksimali 5 minučių S galia pagal 2 tarifą per parą', NULL, 3, NULL, NULL),
	(6877, 34, 0, 11, 4, 2, 7, 6, 44, NULL, 'Maksimali 5 minučių S galia pagal 2 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6878, 34, 0, 11, 4, 3, 7, 5, 44, NULL, 'Maksimali 5 minučių S galia pagal 3 tarifą per parą', NULL, 3, NULL, NULL),
	(6879, 34, 0, 11, 4, 3, 7, 6, 44, NULL, 'Maksimali 5 minučių S galia pagal 3 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6880, 34, 0, 11, 4, 4, 7, 5, 44, NULL, 'Maksimali 5 minučių S galia pagal 4 tarifą per parą', NULL, 3, NULL, NULL),
	(6881, 34, 0, 11, 4, 4, 7, 6, 44, NULL, 'Maksimali 5 minučių S galia pagal 4 tarifą per mėnesį', NULL, 4, NULL, NULL),
	(6884, 34, 1, 11, 4, 0, 7, 6, 44, NULL, 'Maksimali 5 minučių S+ galia per mėnesį', 663, 4, NULL, NULL),
	(6885, 34, 1, 11, 4, 0, 7, 5, 44, NULL, 'Maksimali 5 minučių S+ galia per parą', 665, 3, NULL, NULL),
	(6886, 34, 2, 11, 4, 0, 7, 6, 44, NULL, 'Maksimali 5 minučių S- galia per mėnesį', 664, 4, NULL, NULL),
	(6887, 34, 2, 11, 4, 0, 7, 5, 44, NULL, 'Maksimali 5 minučių S- galia per parą', 666, 3, NULL, NULL),
	(6888, 34, 3, 11, 3, 0, 7, 10, 44, NULL, 'Vidutinė pilnoji tinklo galia per 5 minutes', 451, 1, NULL, NULL),
	(6889, 34, 3, 11, 2, 0, 41, 10, 45, NULL, 'Pilnoji tinklo energija per 5 minutes', 724, 1, NULL, NULL),
	(6890, 39, 0, 8, 2, 0, 35, 10, 2, NULL, 'Suminis dujų koreguotos masės kiekis, fiksuojamas kas 5 minutes', 1110, 5, NULL, NULL),
	(6891, 40, 0, 8, 2, 0, 31, 10, 4, NULL, 'Suminis dujų koreguoto tūrio kiekis, fiksuojamas kas 5 minutes', 1112, 5, NULL, NULL),
	(6892, 41, 0, 8, 2, 0, 35, 10, 6, NULL, 'Suminis dujų masės kiekis, fiksuojamas kas 5 minutes', 1105, 5, NULL, NULL),
	(6893, 43, 0, 8, 2, 0, 34, 10, 9, NULL, 'Suminis dujų šilumos kiekis, fiksuojamas kas 5 minutes', 1101, 5, NULL, NULL),
	(6894, 45, 0, 8, 2, 0, 31, 10, 12, NULL, 'Suminis dujų tūrio kiekis, fiksuojamas kas 5 minutes', 1107, 5, NULL, NULL),
	(6895, 46, 0, 11, 4, 0, 27, 5, 55, NULL, 'Maksimali 5 minučių oro temperatūra per parą', NULL, 3, NULL, NULL),
	(6896, 46, 0, 11, 5, 0, 27, 5, 55, NULL, 'Minimali 5 minučių oro temperatūra per parą', NULL, 3, NULL, NULL),
	(6897, 46, 0, 11, 4, 0, 27, 6, 55, NULL, 'Maksimali 5 minučių oro temperatūra per mėnesį', NULL, 4, NULL, NULL),
	(6898, 46, 0, 11, 5, 0, 27, 6, 55, NULL, 'Minimali 5 minučių oro temperatūra per mėnesį', NULL, 4, NULL, NULL),
	(6899, 48, 0, 8, 2, 0, 2, 10, 62, NULL, 'Suminė šalčio energija, fiksuojama kas 5 minutes', 1001, 5, NULL, NULL),
	(6900, 48, 1, 8, 2, 0, 2, 10, 62, NULL, 'Suminė tiekiamo šalčio energija, fiksuojama kas 5 minutes', 1001, 5, NULL, NULL),
	(6901, 48, 2, 8, 2, 0, 2, 10, 62, NULL, 'Suminė grįžtamo šalčio energija, fiksuojama kas 5 minutes', 1001, 5, NULL, NULL),
	(6902, 50, 0, 8, 2, 0, 31, 10, 66, NULL, 'Suminis šalčio tūrio kiekis, fiksuojamas kas 5 minutes', 1010, 5, NULL, NULL),
	(6903, 50, 1, 8, 2, 0, 31, 10, 66, NULL, 'Suminis tiekiamo šalčio tūrio kiekis, fiksuojamas kas 5 minutes', 1010, 5, NULL, NULL),
	(6904, 50, 2, 8, 2, 0, 31, 10, 66, NULL, 'Suminis grįžtamo šalčio tūrio kiekis, fiksuojamas kas 5 minutes', 1010, 5, NULL, NULL),
	(6905, 51, 0, 8, 2, 0, 35, 10, 68, NULL, 'Suminis šilumnešio masės kiekis, fiksuojamas kas 5 minutes', 1005, 5, NULL, NULL),
	(6906, 51, 1, 8, 2, 0, 35, 10, 68, NULL, 'Suminis tiekiamo šilumnešio masės kiekis, fiksuojamas kas 5 minutes', 1005, 5, NULL, NULL),
	(6907, 51, 2, 8, 2, 0, 35, 10, 68, NULL, 'Suminis grįžtamo šilumnešio masės kiekis, fiksuojamas kas 5 minutes', 1024, 5, NULL, NULL),
	(6908, 53, 0, 8, 2, 0, 2, 10, 71, NULL, 'Suminis šilumnešio šilumos kiekis, fiksuojamas kas 5 minutes', 1001, 5, NULL, NULL),
	(6909, 53, 1, 8, 2, 0, 2, 10, 71, NULL, 'Suminis tiekiamo šilumnešio šilumos kiekis, fiksuojamas kas 5 minutes', 1001, 5, NULL, NULL),
	(6910, 53, 2, 8, 2, 0, 2, 10, 71, NULL, 'Suminis grįžtamo šilumnešio šilumos kiekis, fiksuojamas kas 5 minutes', 1019, 5, NULL, NULL),
	(6911, 55, 0, 8, 2, 0, 31, 10, 74, NULL, 'Suminis šilumnešio tūrio kiekis, fiksuojamas kas 5 minutes', 1010, 5, NULL, NULL),
	(6912, 55, 1, 8, 2, 0, 31, 10, 74, NULL, 'Suminis tiekiamo šilumnešio tūrio kiekis, fiksuojamas kas 5 minutes', 1010, 5, NULL, NULL),
	(6913, 55, 2, 8, 2, 0, 31, 10, 74, NULL, 'Suminis grįžtamo šilumnešio tūrio kiekis, fiksuojamas kas 5 minutes', 1022, 5, NULL, NULL),
	(6914, 56, 0, 8, 2, 0, 34, 10, 56, NULL, 'Suminis šalto vandens šilumos kiekis, fiksuojamas kas 5 minutes', 1205, 5, NULL, NULL),
	(6915, 56, 1, 8, 2, 0, 34, 10, 56, NULL, 'Suminis tiekiamo šalto vandens šilumos kiekis, fiksuojamas kas 5 minutes', 1205, 5, NULL, NULL),
	(6916, 56, 2, 8, 2, 0, 34, 10, 56, NULL, 'Suminis grįžtamo šalto vandens šilumos kiekis, fiksuojamas kas 5 minutes', 1237, 5, NULL, NULL),
	(6917, 58, 1, 8, 2, 0, 31, 10, 59, NULL, 'Suminis tiekiamo šalto vandens tūrio kiekis, fiksuojamas kas 5 minutes', 1201, 5, NULL, NULL),
	(6918, 58, 2, 8, 2, 0, 31, 10, 59, NULL, 'Suminis grįžtamo šalto vandens tūrio kiekis, fiksuojamas kas 5 minutes', 1258, 5, NULL, NULL),
	(6919, 59, 0, 8, 2, 0, 34, 10, 51, NULL, 'Suminis karšto vandens šilumos kiekis, fiksuojamas kas 5 minutes', 1205, 5, NULL, NULL),
	(6920, 59, 1, 8, 2, 0, 34, 10, 51, NULL, 'Suminis tiekiamo karšto vandens šilumos kiekis, fiksuojamas kas 5 minutes', 1205, 5, NULL, NULL),
	(6921, 59, 2, 8, 2, 0, 34, 10, 51, NULL, 'Suminis grįžtamo karšto vandens šilumos kiekis, fiksuojamas kas 5 minutes', 1237, 5, NULL, NULL),
	(6922, 61, 0, 8, 2, 0, 31, 10, 53, NULL, 'Suminis karšto vandens tūrio kiekis, fiksuojamas kas 5 minutes', 1201, 5, NULL, NULL),
	(6923, 61, 1, 8, 2, 0, 31, 10, 53, NULL, 'Suminis tiekiamo karšto vandens tūrio kiekis, fiksuojamas kas 5 minutes', 1201, 5, NULL, NULL),
	(6924, 61, 2, 8, 2, 0, 31, 10, 53, NULL, 'Suminis grįžtamo karšto vandens tūrio kiekis, fiksuojamas kas 5 minutes', 1258, 5, NULL, NULL),
	(6925, 62, 0, 11, 2, 0, 29, 10, 75, NULL, 'Šilumnešio skaitiklio darbo laikas per 5 minutes', 1018, 1, NULL, NULL),
	(6926, 62, 0, 8, 2, 0, 29, 10, 75, NULL, 'Suminis šilumnešio skaitiklio darbo laikas, fiksuojamas kas 5 minutes', 1007, 5, NULL, NULL),
	(6927, 63, 0, 11, 2, 0, 29, 10, 76, NULL, 'Šilumnešio skaitiklio nedarbo laikas per 5 minutes', 1091, 1, NULL, NULL),
	(6928, 63, 0, 8, 2, 0, 29, 10, 76, NULL, 'Suminis šilumnešio skaitiklio nedarbo laikas, fiksuojamas kas 5 minutes', 1012, 5, NULL, NULL),
	(6929, 64, 0, 11, 2, 0, 29, 10, 77, NULL, 'Šalto vandens skaitiklio darbo laikas per 5 minutes', 1268, 1, NULL, NULL),
	(6930, 64, 0, 8, 2, 0, 29, 10, 77, NULL, 'Suminis šalto vandens skaitiklio darbo laikas, fiksuojamas kas 5 minutes', 1204, 5, NULL, NULL),
	(6931, 65, 0, 11, 2, 0, 29, 10, 78, NULL, 'Karšto vandens skaitiklio darbo laikas per 5 minutes', 1268, 1, NULL, NULL),
	(6932, 65, 0, 8, 2, 0, 29, 10, 78, NULL, 'Suminis karšto vandens skaitiklio darbo laikas, fiksuojamas kas 5 minutes', 1204, 5, NULL, NULL),
	(6933, 142, 0, 11, 5, 0, 28, 5, 155, NULL, 'Minimalus 5 minučių šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6934, 142, 0, 11, 4, 0, 28, 5, 155, NULL, 'Maksimalus 5 minučių šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6935, 142, 0, 11, 5, 0, 28, 6, 155, NULL, 'Minimalus 5 minučių šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6936, 142, 0, 11, 4, 0, 28, 6, 155, NULL, 'Maksimalus 5 minučių šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6937, 142, 1, 11, 4, 0, 28, 5, 155, NULL, 'Maksimalus 5 minučių tiekiamo šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6938, 142, 1, 11, 4, 0, 28, 6, 155, NULL, 'Maksimalus 5 minučių tiekiamo šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6939, 142, 1, 11, 5, 0, 28, 5, 155, NULL, 'Minimalus 5 minučių tiekiamo šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6940, 142, 1, 11, 5, 0, 28, 6, 155, NULL, 'Minimalus 5 minučių tiekiamo šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6941, 142, 2, 11, 4, 0, 28, 5, 155, NULL, 'Maksimalus 5 minučių grįžtamo šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6942, 142, 2, 11, 4, 0, 28, 6, 155, NULL, 'Maksimalus 5 minučių grįžtamo šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6943, 142, 2, 11, 5, 0, 28, 5, 155, NULL, 'Minimalus 5 minučių grįžtamo šalto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6944, 142, 2, 11, 5, 0, 28, 6, 155, NULL, 'Minimalus 5 minučių grįžtamo šalto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6945, 143, 0, 11, 5, 0, 28, 5, 156, NULL, 'Minimalus 5 minučių karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6946, 143, 0, 11, 4, 0, 28, 5, 156, NULL, 'Maksimalus 5 minučių karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6947, 143, 0, 11, 5, 0, 28, 6, 156, NULL, 'Minimalus 5 minučių karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6948, 143, 0, 11, 4, 0, 28, 6, 156, NULL, 'Maksimalus 5 minučių karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6949, 143, 1, 11, 4, 0, 28, 5, 156, NULL, 'Maksimalus 5 minučių tiekiamo karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6950, 143, 1, 11, 4, 0, 28, 6, 156, NULL, 'Maksimalus 5 minučių tiekiamo karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6951, 143, 1, 11, 5, 0, 28, 5, 156, NULL, 'Minimalus 5 minučių tiekiamo karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6952, 143, 1, 11, 5, 0, 28, 6, 156, NULL, 'Minimalus 5 minučių tiekiamo karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6953, 143, 2, 11, 4, 0, 28, 5, 156, NULL, 'Maksimalus 5 minučių grįžtamo karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6954, 143, 2, 11, 4, 0, 28, 6, 156, NULL, 'Maksimalus 5 minučių grįžtamo karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6955, 143, 2, 11, 5, 0, 28, 5, 156, NULL, 'Minimalus 5 minučių grįžtamo karšto vandens slėgis per parą', NULL, 3, NULL, NULL),
	(6956, 143, 2, 11, 5, 0, 28, 6, 156, NULL, 'Minimalus 5 minučių grįžtamo karšto vandens slėgis per mėnesį', NULL, 4, NULL, NULL),
	(6957, 167, 0, 11, 2, 0, 29, 10, 180, NULL, 'Šalčio skaitiklio darbo laikas per 5 minutes', 1018, 1, NULL, NULL),
	(6958, 167, 0, 8, 2, 0, 29, 10, 180, NULL, 'Suminis šalčio skaitiklio darbo laikas, fiksuojamas kas 5 minutes', 1007, 5, NULL, NULL),
	(6959, 168, 0, 11, 2, 0, 29, 10, 181, NULL, 'Šalčio skaitiklio nedarbo laikas per 5 minutes', 1012, 1, NULL, NULL),
	(6960, 168, 0, 8, 2, 0, 29, 10, 181, NULL, 'Suminis šalčio skaitiklio nedarbo laikas, fiksuojamas kas 5 minutes', 1012, 5, NULL, NULL),
	(6961, 189, 1, 11, 2, 0, 2, 10, 202, NULL, 'A+ energija per 5 minutes L1 fazėje', 727, 1, NULL, NULL),
	(6962, 189, 2, 11, 2, 0, 2, 10, 202, NULL, 'A- energija per 5 minutes L1 fazėje', 728, 1, NULL, NULL),
	(6963, 190, 1, 11, 2, 0, 2, 10, 203, NULL, 'A+ energija per 5 minutes L2 fazėje', 731, 1, NULL, NULL),
	(6964, 190, 2, 11, 2, 0, 2, 10, 203, NULL, 'A- energija per 5 minutes L2 fazėje', 732, 1, NULL, NULL),
	(6965, 191, 1, 11, 2, 0, 2, 10, 204, NULL, 'A+ energija per 5 minutes L3 fazėje', 735, 1, NULL, NULL),
	(6966, 191, 2, 11, 2, 0, 2, 10, 204, NULL, 'A- energija per 5 minutes L3 fazėje', 736, 1, NULL, NULL),
	(6967, 193, 1, 11, 2, 0, 4, 10, 205, NULL, 'R+ energija per 5 minutes L1 fazėje', 729, 1, NULL, NULL),
	(6968, 193, 2, 11, 2, 0, 4, 10, 205, NULL, 'R- energija per 5 minutes L1 fazėje', 730, 1, NULL, NULL),
	(6969, 193, 5, 11, 2, 0, 4, 10, 205, NULL, 'R1 energija per 5 minutes L1 fazėje', 739, 1, NULL, NULL),
	(6970, 193, 6, 11, 2, 0, 4, 10, 205, NULL, 'R2 energija per 5 minutes L1 fazėje', 740, 1, NULL, NULL),
	(6971, 193, 7, 11, 2, 0, 4, 10, 205, NULL, 'R3 energija per 5 minutes L1 fazėje', 741, 1, NULL, NULL),
	(6972, 193, 8, 11, 2, 0, 4, 10, 205, NULL, 'R4 energija per 5 minutes L1 fazėje', 742, 1, NULL, NULL),
	(6973, 193, 9, 11, 2, 0, 4, 10, 205, NULL, 'Indukcinė energija per 5 minutes L1 fazėje', 759, 1, NULL, NULL),
	(6974, 193, -1, 11, 2, 0, 4, 10, 205, NULL, 'Talpuminė energija per 5 minutes L1 fazėje', 760, 1, NULL, NULL),
	(6975, 194, 1, 11, 2, 0, 4, 10, 206, NULL, 'R+ energija per 5 minutes L2 fazėje', 733, 1, NULL, NULL),
	(6976, 194, 2, 11, 2, 0, 4, 10, 206, NULL, 'R- energija per 5 minutes L2 fazėje', 734, 1, NULL, NULL),
	(6977, 194, 5, 11, 2, 0, 4, 10, 206, NULL, 'R1 energija per 5 minutes L2 fazėje', 745, 1, NULL, NULL),
	(6978, 194, 6, 11, 2, 0, 4, 10, 206, NULL, 'R2 energija per 5 minutes L2 fazėje', 746, 1, NULL, NULL),
	(6979, 194, 7, 11, 2, 0, 4, 10, 206, NULL, 'R3 energija per 5 minutes L2 fazėje', 747, 1, NULL, NULL),
	(6980, 194, 8, 11, 2, 0, 4, 10, 206, NULL, 'R4 energija per 5 minutes L2 fazėje', 748, 1, NULL, NULL),
	(6981, 194, 9, 11, 2, 0, 4, 10, 206, NULL, 'Indukcinė energija per 5 minutes L2 fazėje', 761, 1, NULL, NULL),
	(6982, 194, -1, 11, 2, 0, 4, 10, 206, NULL, 'Talpuminė energija per 5 minutes L2 fazėje', 762, 1, NULL, NULL),
	(6983, 195, 1, 11, 2, 0, 4, 10, 207, NULL, 'R+ energija per 5 minutes L3 fazėje', 737, 1, NULL, NULL),
	(6984, 195, 2, 11, 2, 0, 4, 10, 207, NULL, 'R- energija per 5 minutes L3 fazėje', 738, 1, NULL, NULL),
	(6985, 195, 5, 11, 2, 0, 4, 10, 207, NULL, 'R1 energija per 5 minutes L3 fazėje', 751, 1, NULL, NULL),
	(6986, 195, 6, 11, 2, 0, 4, 10, 207, NULL, 'R2 energija per 5 minutes L3 fazėje', 752, 1, NULL, NULL),
	(6987, 195, 7, 11, 2, 0, 4, 10, 207, NULL, 'R3 energija per 5 minutes L3 fazėje', 753, 1, NULL, NULL),
	(6988, 195, 8, 11, 2, 0, 4, 10, 207, NULL, 'R4 energija per 5 minutes L3 fazėje', 754, 1, NULL, NULL),
	(6989, 195, -1, 11, 2, 0, 4, 10, 207, NULL, 'Talpuminė energija per 5 minutes L3 fazėje', 763, 1, NULL, NULL),
	(6990, 195, 9, 11, 2, 0, 4, 10, 207, NULL, 'Indukcinė energija per 5 minutes L3 fazėje', 764, 1, NULL, NULL),
	(6991, 196, 1, 11, 2, 0, 41, 10, 208, NULL, 'W+ energija per 5 minutes L1 fazėje', 743, 1, NULL, NULL),
	(6992, 196, 2, 11, 2, 0, 41, 10, 208, NULL, 'W- energija per 5 minutes L1 fazėje', 744, 1, NULL, NULL),
	(6993, 197, 1, 11, 2, 0, 41, 10, 209, NULL, 'W+ energija per 5 minutes L2 fazėje', 749, 1, NULL, NULL),
	(6994, 197, 2, 11, 2, 0, 41, 10, 209, NULL, 'W- energija per 5 minutes L2 fazėje', 750, 1, NULL, NULL),
	(6995, 198, 2, 11, 2, 0, 41, 10, 210, NULL, 'W- energija per 5 minutes L3 fazėje', 755, 1, NULL, NULL),
	(6996, 198, 1, 11, 2, 0, 41, 10, 210, NULL, 'W+ energija per 5 minutes L3 fazėje', 756, 1, NULL, NULL),
	(6997, 209, 0, 8, 2, 0, 2, 10, 222, NULL, 'Suminis šilumnešio pilnosios šilumos kiekis, fiksuojamas kas 5 minutes', 1029, 5, NULL, NULL),
	(6998, 209, 1, 8, 2, 0, 2, 10, 222, NULL, 'Suminis tiekiamo šilumnešio pilnosios šilumos kiekis, fiksuojamas kas 5 minutes', 1029, 5, NULL, NULL),
	(6999, 209, 2, 8, 2, 0, 2, 10, 222, NULL, 'Suminis grįžtamo šilumnešio pilnosios šilumos kiekis, fiksuojamas kas 5 minutes', 1029, 5, NULL, NULL),
	(7000, 215, 0, 11, 2, 0, 29, 10, 228, NULL, 'Šilumnešio skaitiklio darbo laikas su klaida per 5 minutes', 1074, 1, NULL, NULL),
	(7001, 215, 0, 8, 2, 0, 29, 10, 228, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su klaida, fiksuojamas kas 5 minutes', 1014, 5, NULL, NULL),
	(7002, 216, 0, 11, 2, 0, 29, 10, 229, NULL, 'Šilumnešio skaitiklio darbo laikas su metrologine klaida per 5 minutes', 1015, 1, NULL, NULL),
	(7003, 216, 0, 8, 2, 0, 29, 10, 229, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su metrologine klaida, fiksuojamas kas 5 minutes', 1015, 5, NULL, NULL),
	(7004, 217, 0, 11, 2, 0, 29, 10, 230, NULL, 'Šilumnešio skaitiklio darbo laikas su perpildymo klaida per 5 minutes', 1016, 1, NULL, NULL),
	(7005, 217, 0, 8, 2, 0, 29, 10, 230, NULL, 'Suminis šilumnešio skaitiklio darbo laikas su perpildymo klaida, fiksuojamas kas 5 minutes', 1016, 5, NULL, NULL),
	(7006, 218, 0, 11, 2, 0, 29, 10, 231, NULL, 'Šilumnešio skaitiklio maitinimo dingimo trukmė per 5 minutes', 1017, 1, NULL, NULL),
	(7007, 218, 0, 8, 2, 0, 29, 10, 231, NULL, 'Suminė šilumnešio skaitiklio maitinimo dingimo trukmė, fiksuojama kas 5 minutes', 1017, 5, NULL, NULL),
	(7008, 239, 0, 8, 2, 0, 35, 10, 252, NULL, 'Suminis šalto vandens masės kiekis, fiksuojamas kas 5 minutes', 1211, 5, NULL, NULL),
	(7009, 240, 0, 8, 2, 0, 35, 10, 253, NULL, 'Suminis karšto vandens masės kiekis, fiksuojamas kas 5 minutes', 1211, 5, NULL, NULL),
	(7010, 254, 0, 4, 2, 0, 29, 4, 267, NULL, 'Prastovos laikas išeinant iš darbinio režimo per valandą', 1050, 2, NULL, NULL),
	(7011, 254, 0, 5, 2, 0, 29, 5, 267, NULL, 'Prastovos laikas išeinant iš darbinio režimo per parą', 1050, 3, NULL, NULL),
	(7012, 254, 0, 6, 2, 0, 29, 6, 267, NULL, 'Prastovos laikas išeinant iš darbinio režimo per mėnesį', 1050, 4, NULL, NULL),
	(7013, 255, 0, 4, 2, 0, 29, 4, 268, NULL, '"Suvartojimas mažiau už atkirtą" trukmė karšto vandens vamzdyje per valandą', 1054, 2, NULL, NULL),
	(7014, 255, 0, 5, 2, 0, 29, 5, 268, NULL, '"Suvartojimas mažiau už atkirtą" trukmė karšto vandens vamzdyje per parą', 1054, 3, NULL, NULL),
	(7015, 255, 0, 6, 2, 0, 29, 6, 268, NULL, '"Suvartojimas mažiau už atkirtą" trukmė karšto vandens vamzdyje per mėnesį', 1054, 4, NULL, NULL),
	(7016, 256, 0, 4, 2, 0, 29, 4, 269, NULL, 'Keitiklio gedimo trukmė tūrio impulsų linijoje karšto vandens vamzdyje per valandą', 1055, 2, NULL, NULL),
	(7017, 256, 0, 5, 2, 0, 29, 5, 269, NULL, 'Keitiklio gedimo trukmė tūrio impulsų linijoje karšto vandens vamzdyje per parą', 1055, 3, NULL, NULL),
	(7018, 256, 0, 6, 2, 0, 29, 6, 269, NULL, 'Keitiklio gedimo trukmė tūrio impulsų linijoje karšto vandens vamzdyje per mėnesį', 1055, 4, NULL, NULL),
	(7019, 257, 0, 4, 2, 0, 29, 4, 270, NULL, 'Temperatūros jutiklio gedimo trukmė karšto vandens vamzdyje per valandą', 1056, 2, NULL, NULL),
	(7020, 257, 0, 5, 2, 0, 29, 5, 270, NULL, 'Temperatūros jutiklio gedimo trukmė karšto vandens vamzdyje per parą', 1056, 3, NULL, NULL),
	(7021, 257, 0, 6, 2, 0, 29, 6, 270, NULL, 'Temperatūros jutiklio gedimo trukmė karšto vandens vamzdyje per mėnesį', 1056, 4, NULL, NULL),
	(7022, 258, 0, 4, 2, 0, 29, 4, 271, NULL, 'Slėgio jutiklio gedimo trukmė karšto vandens vamzdyje per valandą', 1057, 2, NULL, NULL),
	(7023, 258, 0, 5, 2, 0, 29, 5, 271, NULL, 'Slėgio jutiklio gedimo trukmė karšto vandens vamzdyje per parą', 1057, 3, NULL, NULL),
	(7024, 258, 0, 6, 2, 0, 29, 6, 271, NULL, 'Slėgio jutiklio gedimo trukmė karšto vandens vamzdyje per mėnesį', 1057, 4, NULL, NULL),
	(7025, 259, 0, 4, 2, 0, 29, 4, 272, NULL, 'Avarinės situacijos trukmė, kai G2>Kpr*G1, per valandą', 1058, 2, NULL, NULL),
	(7026, 259, 0, 5, 2, 0, 29, 5, 272, NULL, 'Avarinės situacijos trukmė, kai G2>Kpr*G1, per parą', 1058, 3, NULL, NULL),
	(7027, 259, 0, 6, 2, 0, 29, 6, 272, NULL, 'Avarinės situacijos trukmė, kai G2>Kpr*G1, per mėnesį', 1058, 4, NULL, NULL),
	(7028, 260, 0, 4, 2, 0, 29, 4, 273, NULL, 'Avarinės situacijos trukmė, kai t1-t2<delta tts, per valandą', 1059, 2, 't1-t2<?tts per valandą', NULL),
	(7029, 260, 0, 5, 2, 0, 29, 5, 273, NULL, 'Avarinės situacijos trukmė, kai t1-t2<delta tts, per parą', 1059, 3, 't1-t2<?tts per parą', NULL),
	(7030, 260, 0, 6, 2, 0, 29, 6, 273, NULL, 'Avarinės situacijos trukmė, kai t1-t2<delta tts, per mėnesį', 1059, 4, 't1-t2<?tts per mėnesį', NULL),
	(7031, 261, 0, 4, 2, 0, 29, 4, 274, NULL, 'Avarinės situacijos trukmė, kai G1<G2<Kpr*G1, per valandą', 1060, 2, NULL, NULL),
	(7032, 261, 0, 5, 2, 0, 29, 5, 274, NULL, 'Avarinės situacijos trukmė, kai G1<G2<Kpr*G1, per parą', 1060, 3, NULL, NULL),
	(7033, 261, 0, 6, 2, 0, 29, 6, 274, NULL, 'Avarinės situacijos trukmė, kai G1<G2<Kpr*G1, per mėnesį', 1060, 4, NULL, NULL),
	(7034, 262, 0, 4, 2, 0, 29, 4, 275, NULL, 'Avarinės situacijos trukmė, kai G4>Kpr*G3, per valandą', 1061, 2, NULL, NULL),
	(7035, 262, 0, 5, 2, 0, 29, 5, 275, NULL, 'Avarinės situacijos trukmė, kai G4>Kpr*G3, per parą', 1061, 3, NULL, NULL),
	(7036, 262, 0, 6, 2, 0, 29, 6, 275, NULL, 'Avarinės situacijos trukmė, kai G4>Kpr*G3, per mėnesį', 1061, 4, NULL, NULL),
	(7037, 263, 0, 4, 2, 0, 29, 4, 276, NULL, 'Avarinės situacijos trukmė, kai t3-t4<delta tts, per valandą', 1062, 2, 't3-t4<?tts per valandą', NULL),
	(7038, 263, 0, 5, 2, 0, 29, 5, 276, NULL, 'Avarinės situacijos trukmė, kai t3-t4<delta tts, per parą', 1062, 3, 't3-t4<?tts per parą', NULL),
	(7039, 263, 0, 6, 2, 0, 29, 6, 276, NULL, 'Avarinės situacijos trukmė, kai t3-t4<delta tts, per mėnesį', 1062, 4, 't3-t4<?tts per mėnesį', NULL),
	(7040, 264, 0, 4, 2, 0, 29, 4, 277, NULL, 'Avarinės situacijos trukmė, kai G3<G4<Kpr*G3, per valandą', 1063, 2, NULL, NULL),
	(7041, 264, 0, 5, 2, 0, 29, 5, 277, NULL, 'Avarinės situacijos trukmė, kai G3<G4<Kpr*G3, per parą', 1063, 3, NULL, NULL),
	(7042, 264, 0, 6, 2, 0, 29, 6, 277, NULL, 'Avarinės situacijos trukmė, kai G3<G4<Kpr*G3, per mėnesį', 1063, 4, NULL, NULL),
	(7043, 265, 0, 4, 2, 0, 27, 4, 278, NULL, 'Šilumnešio temperatūros svertinis vidurkis per valandą', 1053, 2, NULL, NULL),
	(7044, 265, 0, 5, 2, 0, 27, 5, 278, NULL, 'Šilumnešio temperatūros svertinis vidurkis per parą', 1053, 3, NULL, NULL),
	(7045, 265, 0, 6, 2, 0, 27, 6, 278, NULL, 'Šilumnešio temperatūros svertinis vidurkis per mėnesį', 1053, 4, NULL, NULL),
	(7046, 272, 0, 4, 2, 0, 29, 4, 285, NULL, '"Suvartojimas mažiau už atkirtą" trukmė šalto vandens vamzdyje per valandą', 1054, 2, NULL, NULL),
	(7047, 272, 0, 5, 2, 0, 29, 5, 285, NULL, '"Suvartojimas mažiau už atkirtą" trukmė šalto vandens vamzdyje per parą', 1054, 3, NULL, NULL),
	(7048, 272, 0, 6, 2, 0, 29, 6, 285, NULL, '"Suvartojimas mažiau už atkirtą" trukmė šalto vandens vamzdyje per mėnesį', 1054, 4, NULL, NULL),
	(7049, 274, -4, 4, 2, 0, 29, 4, 287, NULL, '"Suvartojimas mažiau už atkirtą" trukmė pamaitinimo vandens vamzdyje per valandą', 1054, 2, NULL, NULL),
	(7050, 274, -4, 5, 2, 0, 29, 5, 287, NULL, '"Suvartojimas mažiau už atkirtą" trukmė pamaitinimo vandens vamzdyje per parą', 1054, 3, NULL, NULL),
	(7051, 274, -4, 6, 2, 0, 29, 6, 287, NULL, '"Suvartojimas mažiau už atkirtą" trukmė pamaitinimo vandens vamzdyje per mėnesį', 1054, 4, NULL, NULL),
	(7052, 274, 1, 4, 2, 0, 29, 4, 287, NULL, '"Suvartojimas mažiau už atkirtą" trukmė tiekiamo šilumnešio vamzdyje per valandą', 1054, 2, NULL, NULL),
	(7053, 274, 1, 5, 2, 0, 29, 5, 287, NULL, '"Suvartojimas mažiau už atkirtą" trukmė tiekiamo šilumnešio vamzdyje per parą', 1054, 3, NULL, NULL),
	(7054, 274, 1, 6, 2, 0, 29, 6, 287, NULL, '"Suvartojimas mažiau už atkirtą" trukmė tiekiamo šilumnešio vamzdyje per mėnesį', 1054, 4, NULL, NULL),
	(7055, 274, 2, 4, 2, 0, 29, 4, 287, NULL, '"Suvartojimas mažiau už atkirtą" trukmė grįžtamo šilumnešio vamzdyje per valandą', 1054, 2, NULL, NULL),
	(7056, 274, 2, 5, 2, 0, 29, 5, 287, NULL, '"Suvartojimas mažiau už atkirtą" trukmė grįžtamo šilumnešio vamzdyje per parą', 1054, 3, NULL, NULL),
	(7057, 274, 2, 6, 2, 0, 29, 6, 287, NULL, '"Suvartojimas mažiau už atkirtą" trukmė grįžtamo šilumnešio vamzdyje per mėnesį', 1054, 4, NULL, NULL),
	(7058, 275, 0, 4, 2, 0, 29, 4, 288, NULL, 'Keitiklio gedimo trukmė tūrio impulsų linijoje šalto vandens vamzdyje per valandą', 1055, 2, NULL, NULL),
	(7059, 275, 0, 5, 2, 0, 29, 5, 288, NULL, 'Keitiklio gedimo trukmė tūrio impulsų linijoje šalto vandens vamzdyje per parą', 1055, 3, NULL, NULL),
	(7060, 275, 0, 6, 2, 0, 29, 6, 288, NULL, 'Keitiklio gedimo trukmė tūrio impulsų linijoje šalto vandens vamzdyje per mėnesį', 1055, 4, NULL, NULL),
	(7061, 277, -4, 4, 2, 0, 29, 4, 290, NULL, 'Keitiklio gedimo trukmė tūrio impulsų linijoje pamaitinimo vandens vamzdyje per valandą', 1055, 2, NULL, NULL),
	(7062, 277, -4, 5, 2, 0, 29, 5, 290, NULL, 'Keitiklio gedimo trukmė tūrio impulsų linijoje pamaitinimo vandens vamzdyje per parą', 1055, 3, NULL, NULL),
	(7063, 277, -4, 6, 2, 0, 29, 6, 290, NULL, 'Keitiklio gedimo trukmė tūrio impulsų linijoje pamaitinimo vandens vamzdyje per mėnesį', 1055, 4, NULL, NULL),
	(7064, 277, 1, 4, 2, 0, 29, 4, 290, NULL, 'Keitiklio gedimo trukmė tūrio impulsų linijoje tiekiamo šilumnešio vamzdyje per valandą', 1055, 2, NULL, NULL),
	(7065, 277, 1, 5, 2, 0, 29, 5, 290, NULL, 'Keitiklio gedimo trukmė tūrio impulsų linijoje tiekiamo šilumnešio vamzdyje per parą', 1055, 3, NULL, NULL),
	(7066, 277, 1, 6, 2, 0, 29, 6, 290, NULL, 'Keitiklio gedimo trukmė tūrio impulsų linijoje tiekiamo šilumnešio vamzdyje per mėnesį', 1055, 4, NULL, NULL),
	(7067, 277, 2, 4, 2, 0, 29, 4, 290, NULL, 'Keitiklio gedimo trukmė tūrio impulsų linijoje grįžtamo šilumnešio vamzdyje per valandą', 1055, 2, NULL, NULL),
	(7068, 277, 2, 5, 2, 0, 29, 5, 290, NULL, 'Keitiklio gedimo trukmė tūrio impulsų linijoje grįžtamo šilumnešio vamzdyje per parą', 1055, 3, NULL, NULL),
	(7069, 277, 2, 6, 2, 0, 29, 6, 290, NULL, 'Keitiklio gedimo trukmė tūrio impulsų linijoje grįžtamo šilumnešio vamzdyje per mėnesį', 1055, 4, NULL, NULL),
	(7070, 278, 0, 4, 2, 0, 29, 4, 291, NULL, 'Temperatūros jutiklio gedimo trukmė šalto vandens vamzdyje per valandą', 1056, 2, NULL, NULL),
	(7071, 278, 0, 5, 2, 0, 29, 5, 291, NULL, 'Temperatūros jutiklio gedimo trukmė šalto vandens vamzdyje per parą', 1056, 3, NULL, NULL),
	(7072, 278, 0, 6, 2, 0, 29, 6, 291, NULL, 'Temperatūros jutiklio gedimo trukmė šalto vandens vamzdyje per mėnesį', 1056, 4, NULL, NULL),
	(7073, 280, -4, 4, 2, 0, 29, 4, 293, NULL, 'Temperatūros jutiklio gedimo trukmė pamaitinimo vandens vamzdyje per valandą', 1056, 2, NULL, NULL),
	(7074, 280, -4, 5, 2, 0, 29, 5, 293, NULL, 'Temperatūros jutiklio gedimo trukmė pamaitinimo vandens vamzdyje per parą', 1056, 3, NULL, NULL),
	(7075, 280, -4, 6, 2, 0, 29, 6, 293, NULL, 'Temperatūros jutiklio gedimo trukmė pamaitinimo vandens vamzdyje per mėnesį', 1056, 4, NULL, NULL),
	(7076, 280, 1, 4, 2, 0, 29, 4, 293, NULL, 'Temperatūros jutiklio gedimo trukmė tiekiamo šilumnešio vamzdyje per valandą', 1056, 2, NULL, NULL),
	(7077, 280, 1, 5, 2, 0, 29, 5, 293, NULL, 'Temperatūros jutiklio gedimo trukmė tiekiamo šilumnešio vamzdyje per parą', 1056, 3, NULL, NULL),
	(7078, 280, 1, 6, 2, 0, 29, 6, 293, NULL, 'Temperatūros jutiklio gedimo trukmė tiekiamo šilumnešio vamzdyje per mėnesį', 1056, 4, NULL, NULL),
	(7079, 280, 2, 4, 2, 0, 29, 4, 293, NULL, 'Temperatūros jutiklio gedimo trukmė grįžtamo šilumnešio vamzdyje per valandą', 1056, 2, NULL, NULL),
	(7080, 280, 2, 5, 2, 0, 29, 5, 293, NULL, 'Temperatūros jutiklio gedimo trukmė grįžtamo šilumnešio vamzdyje per parą', 1056, 3, NULL, NULL),
	(7081, 280, 2, 6, 2, 0, 29, 6, 293, NULL, 'Temperatūros jutiklio gedimo trukmė grįžtamo šilumnešio vamzdyje per mėnesį', 1056, 4, NULL, NULL),
	(7082, 281, 0, 4, 2, 0, 29, 4, 294, NULL, 'Slėgio jutiklio gedimo trukmė šalto vandens vamzdyje per valandą', 1057, 2, NULL, NULL),
	(7083, 281, 0, 5, 2, 0, 29, 5, 294, NULL, 'Slėgio jutiklio gedimo trukmė šalto vandens vamzdyje per parą', 1057, 3, NULL, NULL),
	(7084, 281, 0, 6, 2, 0, 29, 6, 294, NULL, 'Slėgio jutiklio gedimo trukmė šalto vandens vamzdyje per mėnesį', 1057, 4, NULL, NULL),
	(7085, 283, -4, 4, 2, 0, 29, 4, 296, NULL, 'Slėgio jutiklio gedimo trukmė pamaitinimo vandens vamzdyje per valandą', 1057, 2, NULL, NULL),
	(7086, 283, -4, 5, 2, 0, 29, 5, 296, NULL, 'Slėgio jutiklio gedimo trukmė pamaitinimo vandens vamzdyje per parą', 1057, 3, NULL, NULL),
	(7087, 283, -4, 6, 2, 0, 29, 6, 296, NULL, 'Slėgio jutiklio gedimo trukmė pamaitinimo vandens vamzdyje per mėnesį', 1057, 4, NULL, NULL),
	(7088, 283, 1, 4, 2, 0, 29, 4, 296, NULL, 'Slėgio jutiklio gedimo trukmė tiekiamo šilumnešio vamzdyje per valandą', 1057, 2, NULL, NULL),
	(7089, 283, 1, 5, 2, 0, 29, 5, 296, NULL, 'Slėgio jutiklio gedimo trukmė tiekiamo šilumnešio vamzdyje per parą', 1057, 3, NULL, NULL),
	(7090, 283, 1, 6, 2, 0, 29, 6, 296, NULL, 'Slėgio jutiklio gedimo trukmė tiekiamo šilumnešio vamzdyje per mėnesį', 1057, 4, NULL, NULL),
	(7091, 283, 2, 4, 2, 0, 29, 4, 296, NULL, 'Slėgio jutiklio gedimo trukmė grįžtamo šilumnešio vamzdyje per valandą', 1057, 2, NULL, NULL),
	(7092, 283, 2, 5, 2, 0, 29, 5, 296, NULL, 'Slėgio jutiklio gedimo trukmė grįžtamo šilumnešio vamzdyje per parą', 1057, 3, NULL, NULL),
	(7093, 283, 2, 6, 2, 0, 29, 6, 296, NULL, 'Slėgio jutiklio gedimo trukmė grįžtamo šilumnešio vamzdyje per mėnesį', 1057, 4, NULL, NULL),
	(7094, 284, 0, 4, 2, 0, 29, 4, 297, NULL, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą karšto vandens vamzdyje per valandą', 1070, 2, NULL, NULL),
	(7095, 284, 0, 5, 2, 0, 29, 5, 297, NULL, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą karšto vandens vamzdyje per parą', 1070, 3, NULL, NULL),
	(7096, 284, 0, 6, 2, 0, 29, 6, 297, NULL, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą karšto vandens vamzdyje per mėnesį', 1070, 4, NULL, NULL),
	(7097, 285, 0, 4, 2, 0, 29, 4, 298, NULL, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą karšto vandens vamzdyje per valandą', 1071, 2, NULL, NULL),
	(7098, 285, 0, 5, 2, 0, 29, 5, 298, NULL, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą karšto vandens vamzdyje per parą', 1071, 3, NULL, NULL),
	(7099, 285, 0, 6, 2, 0, 29, 6, 298, NULL, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą karšto vandens vamzdyje per mėnesį', 1071, 4, NULL, NULL),
	(7100, 286, 0, 4, 2, 0, 29, 4, 299, NULL, 'Skaitiklio darbo laikas su daviklio gedimu karšto vandens vamzdyje per valandą', 1073, 2, NULL, NULL),
	(7101, 286, 0, 5, 2, 0, 29, 5, 299, NULL, 'Skaitiklio darbo laikas su daviklio gedimu karšto vandens vamzdyje per parą', 1073, 3, NULL, NULL),
	(7102, 286, 0, 6, 2, 0, 29, 6, 299, NULL, 'Skaitiklio darbo laikas su daviklio gedimu karšto vandens vamzdyje per mėnesį', 1073, 4, NULL, NULL),
	(7103, 287, 0, 4, 2, 0, 29, 4, 300, NULL, 'Skaitiklio darbo laikas su dt < 2 karšto vandens vamzdyje per valandą', 1038, 2, NULL, NULL),
	(7104, 287, 0, 5, 2, 0, 29, 5, 300, NULL, 'Skaitiklio darbo laikas su dt < 2 karšto vandens vamzdyje per parą', 1038, 3, NULL, NULL),
	(7105, 287, 0, 6, 2, 0, 29, 6, 300, NULL, 'Skaitiklio darbo laikas su dt < 2 karšto vandens vamzdyje per mėnesį', 1038, 4, NULL, NULL),
	(7106, 288, 0, 4, 2, 0, 29, 4, 301, NULL, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą šalto vandens vamzdyje per valandą', 1070, 2, NULL, NULL),
	(7107, 288, 0, 5, 2, 0, 29, 5, 301, NULL, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą šalto vandens vamzdyje per parą', 1070, 3, NULL, NULL),
	(7108, 288, 0, 6, 2, 0, 29, 6, 301, NULL, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą šalto vandens vamzdyje per mėnesį', 1070, 4, NULL, NULL),
	(7109, 289, 0, 4, 2, 0, 29, 4, 302, NULL, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą šalto vandens vamzdyje per valandą', 1071, 2, NULL, NULL),
	(7110, 289, 0, 5, 2, 0, 29, 5, 302, NULL, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą šalto vandens vamzdyje per parą', 1071, 3, NULL, NULL),
	(7111, 289, 0, 6, 2, 0, 29, 6, 302, NULL, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą šalto vandens vamzdyje per mėnesį', 1071, 4, NULL, NULL),
	(7112, 290, 0, 4, 2, 0, 29, 4, 303, NULL, 'Skaitiklio darbo laikas su daviklio gedimu šalto vandens vamzdyje per valandą', 1073, 2, NULL, NULL),
	(7113, 290, 0, 5, 2, 0, 29, 5, 303, NULL, 'Skaitiklio darbo laikas su daviklio gedimu šalto vandens vamzdyje per parą', 1073, 3, NULL, NULL),
	(7114, 290, 0, 6, 2, 0, 29, 6, 303, NULL, 'Skaitiklio darbo laikas su daviklio gedimu šalto vandens vamzdyje per mėnesį', 1073, 4, NULL, NULL),
	(7115, 291, 0, 4, 2, 0, 29, 4, 304, NULL, 'Skaitiklio darbo laikas su dt < 2 šalto vandens vamzdyje per valandą', 1038, 2, NULL, NULL),
	(7116, 291, 0, 5, 2, 0, 29, 5, 304, NULL, 'Skaitiklio darbo laikas su dt < 2 šalto vandens vamzdyje per parą', 1038, 3, NULL, NULL),
	(7117, 291, 0, 6, 2, 0, 29, 6, 304, NULL, 'Skaitiklio darbo laikas su dt < 2 šalto vandens vamzdyje per mėnesį', 1038, 4, NULL, NULL),
	(7118, 292, 1, 4, 2, 0, 29, 4, 305, NULL, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą tiekiamo šilumnešio vamzdyje per valandą', 1070, 2, NULL, NULL),
	(7119, 292, 1, 5, 2, 0, 29, 5, 305, NULL, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą tiekiamo šilumnešio vamzdyje per parą', 1070, 3, NULL, NULL),
	(7120, 292, 1, 6, 2, 0, 29, 6, 305, NULL, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą tiekiamo šilumnešio vamzdyje per mėnesį', 1070, 4, NULL, NULL),
	(7121, 293, 1, 4, 2, 0, 29, 4, 306, NULL, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą tiekiamo šilumnešio vamzdyje per valandą', 1071, 2, NULL, NULL),
	(7122, 293, 1, 5, 2, 0, 29, 5, 306, NULL, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą tiekiamo šilumnešio vamzdyje per parą', 1071, 3, NULL, NULL),
	(7123, 293, 1, 6, 2, 0, 29, 6, 306, NULL, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą tiekiamo šilumnešio vamzdyje per mėnesį', 1071, 4, NULL, NULL),
	(7124, 294, 1, 4, 2, 0, 29, 4, 307, NULL, 'Skaitiklio darbo laikas su daviklio gedimu tiekiamo šilumnešio vamzdyje per valandą', 1073, 2, NULL, NULL),
	(7125, 294, 1, 5, 2, 0, 29, 5, 307, NULL, 'Skaitiklio darbo laikas su daviklio gedimu tiekiamo šilumnešio vamzdyje per parą', 1073, 3, NULL, NULL),
	(7126, 294, 1, 6, 2, 0, 29, 6, 307, NULL, 'Skaitiklio darbo laikas su daviklio gedimu tiekiamo šilumnešio vamzdyje per mėnesį', 1073, 4, NULL, NULL),
	(7127, 295, 1, 4, 2, 0, 29, 4, 308, NULL, 'Skaitiklio darbo laikas su dt < 2 tiekiamo šilumnešio vamzdyje per valandą', 1038, 2, NULL, NULL),
	(7128, 295, 1, 5, 2, 0, 29, 5, 308, NULL, 'Skaitiklio darbo laikas su dt < 2 tiekiamo šilumnešio vamzdyje per parą', 1038, 3, NULL, NULL),
	(7129, 295, 1, 6, 2, 0, 29, 6, 308, NULL, 'Skaitiklio darbo laikas su dt < 2 tiekiamo šilumnešio vamzdyje per mėnesį', 1038, 4, NULL, NULL),
	(7130, 292, 2, 4, 2, 0, 29, 4, 305, NULL, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą grįžtamo šilumnešio vamzdyje per valandą', 1070, 2, NULL, NULL),
	(7131, 292, 2, 5, 2, 0, 29, 5, 305, NULL, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą grįžtamo šilumnešio vamzdyje per parą', 1070, 3, NULL, NULL),
	(7132, 292, 2, 6, 2, 0, 29, 6, 305, NULL, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą grįžtamo šilumnešio vamzdyje per mėnesį', 1070, 4, NULL, NULL),
	(7133, 293, 2, 4, 2, 0, 29, 4, 306, NULL, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą grįžtamo šilumnešio vamzdyje per valandą', 1071, 2, NULL, NULL),
	(7134, 293, 2, 5, 2, 0, 29, 5, 306, NULL, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą grįžtamo šilumnešio vamzdyje per parą', 1071, 3, NULL, NULL),
	(7135, 293, 2, 6, 2, 0, 29, 6, 306, NULL, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą grįžtamo šilumnešio vamzdyje per mėnesį', 1071, 4, NULL, NULL),
	(7136, 294, 2, 4, 2, 0, 29, 4, 307, NULL, 'Skaitiklio darbo laikas su daviklio gedimu grįžtamo šilumnešio vamzdyje per valandą', 1073, 2, NULL, NULL),
	(7137, 294, 2, 5, 2, 0, 29, 5, 307, NULL, 'Skaitiklio darbo laikas su daviklio gedimu grįžtamo šilumnešio vamzdyje per parą', 1073, 3, NULL, NULL),
	(7138, 294, 2, 6, 2, 0, 29, 6, 307, NULL, 'Skaitiklio darbo laikas su daviklio gedimu grįžtamo šilumnešio vamzdyje per mėnesį', 1073, 4, NULL, NULL),
	(7139, 295, 2, 4, 2, 0, 29, 4, 308, NULL, 'Skaitiklio darbo laikas su dt < 2 grįžtamo šilumnešio vamzdyje per valandą', 1038, 2, NULL, NULL),
	(7140, 295, 2, 5, 2, 0, 29, 5, 308, NULL, 'Skaitiklio darbo laikas su dt < 2 grįžtamo šilumnešio vamzdyje per parą', 1038, 3, NULL, NULL),
	(7141, 295, 2, 6, 2, 0, 29, 6, 308, NULL, 'Skaitiklio darbo laikas su dt < 2 grįžtamo šilumnešio vamzdyje per mėnesį', 1038, 4, NULL, NULL),
	(7142, 296, 0, 4, 2, 0, 29, 4, 309, NULL, 'Maitinimo gedimo trukmė karšto vandens vamzdyje per valandą', 1072, 2, NULL, NULL),
	(7143, 296, 0, 5, 2, 0, 29, 5, 309, NULL, 'Maitinimo gedimo trukmė karšto vandens vamzdyje per parą', 1072, 3, NULL, NULL),
	(7144, 296, 0, 6, 2, 0, 29, 6, 309, NULL, 'Maitinimo gedimo trukmė karšto vandens vamzdyje per mėnesį', 1072, 4, NULL, NULL),
	(7145, 297, 0, 4, 2, 0, 29, 4, 310, NULL, 'Maitinimo gedimo trukmė šalto vandens vamzdyje per valandą', 1072, 2, NULL, NULL),
	(7146, 297, 0, 5, 2, 0, 29, 5, 310, NULL, 'Maitinimo gedimo trukmė šalto vandens vamzdyje per parą', 1072, 3, NULL, NULL),
	(7147, 297, 0, 6, 2, 0, 29, 6, 310, NULL, 'Maitinimo gedimo trukmė šalto vandens vamzdyje per mėnesį', 1072, 4, NULL, NULL),
	(7148, 299, -4, 4, 2, 0, 29, 4, 312, NULL, 'Maitinimo gedimo trukmė pamaitinimo vandens vamzdyje per valandą', 1072, 2, NULL, NULL),
	(7149, 299, -4, 5, 2, 0, 29, 5, 312, NULL, 'Maitinimo gedimo trukmė pamaitinimo vandens vamzdyje per parą', 1072, 3, NULL, NULL),
	(7150, 299, -4, 6, 2, 0, 29, 6, 312, NULL, 'Maitinimo gedimo trukmė pamaitinimo vandens vamzdyje per mėnesį', 1072, 4, NULL, NULL),
	(7151, 299, 1, 4, 2, 0, 29, 4, 312, NULL, 'Maitinimo gedimo trukmė tiekiamo šilumnešio vamzdyje per valandą', 1072, 2, NULL, NULL),
	(7152, 299, 1, 5, 2, 0, 29, 5, 312, NULL, 'Maitinimo gedimo trukmė tiekiamo šilumnešio vamzdyje per parą', 1072, 3, NULL, NULL),
	(7153, 299, 1, 6, 2, 0, 29, 6, 312, NULL, 'Maitinimo gedimo trukmė tiekiamo šilumnešio vamzdyje per mėnesį', 1072, 4, NULL, NULL),
	(7154, 299, 2, 4, 2, 0, 29, 4, 312, NULL, 'Maitinimo gedimo trukmė grįžtamo šilumnešio vamzdyje per valandą', 1072, 2, NULL, NULL),
	(7155, 299, 2, 5, 2, 0, 29, 5, 312, NULL, 'Maitinimo gedimo trukmė grįžtamo šilumnešio vamzdyje per parą', 1072, 3, NULL, NULL),
	(7156, 299, 2, 6, 2, 0, 29, 6, 312, NULL, 'Maitinimo gedimo trukmė grįžtamo šilumnešio vamzdyje per mėnesį', 1072, 4, NULL, NULL),
	(7157, 265, -4, 4, 2, 0, 27, 4, 278, NULL, 'Pamaitinimo vandens temperatūros svertinis vidurkis per valandą', 1087, 2, NULL, NULL),
	(7158, 265, -4, 5, 2, 0, 27, 5, 278, NULL, 'Pamaitinimo vandens temperatūros svertinis vidurkis per parą', 1087, 3, NULL, NULL),
	(7159, 265, -4, 6, 2, 0, 27, 6, 278, NULL, 'Pamaitinimo vandens temperatūros svertinis vidurkis per mėnesį', 1087, 4, NULL, NULL),
	(7160, 265, 2, 4, 2, 0, 27, 4, 278, NULL, 'Grįžtamo šilumnešio temperatūros svertinis vidurkis per valandą', 1081, 2, NULL, NULL),
	(7161, 265, 2, 5, 2, 0, 27, 5, 278, NULL, 'Grįžtamo šilumnešio temperatūros svertinis vidurkis per parą', 1081, 3, NULL, NULL),
	(7162, 265, 2, 6, 2, 0, 27, 6, 278, NULL, 'Grįžtamo šilumnešio temperatūros svertinis vidurkis per mėnesį', 1081, 4, NULL, NULL),
	(7163, 265, 1, 4, 2, 0, 27, 4, 278, NULL, 'Tiekiamo šilumnešio temperatūros svertinis vidurkis per valandą', 1053, 2, NULL, NULL),
	(7164, 265, 1, 5, 2, 0, 27, 5, 278, NULL, 'Tiekiamo šilumnešio temperatūros svertinis vidurkis per parą', 1053, 3, NULL, NULL),
	(7165, 265, 1, 6, 2, 0, 27, 6, 278, NULL, 'Tiekiamo šilumnešio temperatūros svertinis vidurkis per mėnesį', 1053, 4, NULL, NULL),
	(7166, 301, 0, 4, 2, 0, 27, 4, 314, NULL, 'Šalto vandens temperatūros svertinis vidurkis per valandą', 1217, 2, NULL, NULL),
	(7167, 301, 0, 5, 2, 0, 27, 5, 314, NULL, 'Šalto vandens temperatūros svertinis vidurkis per parą', 1217, 3, NULL, NULL),
	(7168, 301, 0, 6, 2, 0, 27, 6, 314, NULL, 'Šalto vandens temperatūros svertinis vidurkis per mėnesį', 1217, 4, NULL, NULL),
	(7169, 266, 0, 3, 4, 0, 1, 6, 279, NULL, 'Maksimali pusvalandinė absoliuti P galia per mėnesį', 800, 4, NULL, NULL),
	(7170, 266, 0, 3, 4, 1, 1, 6, 279, NULL, 'Maksimali pusvalandinė absoliuti P galia pagal 1 tarifą per mėnesį', 792, 4, NULL, NULL),
	(7171, 266, 0, 3, 4, 2, 1, 6, 279, NULL, 'Maksimali pusvalandinė absoliuti P galia pagal 2 tarifą per mėnesį', 794, 4, NULL, NULL),
	(7172, 266, 0, 3, 4, 3, 1, 6, 279, NULL, 'Maksimali pusvalandinė absoliuti P galia pagal 3 tarifą per mėnesį', 796, 4, NULL, NULL),
	(7173, 266, 0, 3, 4, 4, 1, 6, 279, NULL, 'Maksimali pusvalandinė absoliuti P galia pagal 4 tarifą per mėnesį', 798, 4, NULL, NULL),
	(7174, 266, 0, 4, 4, 0, 1, 6, 279, NULL, 'Maksimali valandinė absoliuti P galia per mėnesį', 800, 4, NULL, NULL),
	(7175, 266, 0, 4, 4, 1, 1, 6, 279, NULL, 'Maksimali valandinė absoliuti P galia pagal 1 tarifą per mėnesį', 792, 4, NULL, NULL),
	(7176, 266, 0, 4, 4, 2, 1, 6, 279, NULL, 'Maksimali valandinė absoliuti P galia pagal 2 tarifą per mėnesį', 794, 4, NULL, NULL),
	(7177, 266, 0, 4, 4, 3, 1, 6, 279, NULL, 'Maksimali valandinė absoliuti P galia pagal 3 tarifą per mėnesį', 796, 4, NULL, NULL),
	(7178, 266, 0, 4, 4, 4, 1, 6, 279, NULL, 'Maksimali valandinė absoliuti P galia pagal 4 tarifą per mėnesį', 798, 4, NULL, NULL),
	(7179, 270, 0, 3, 4, 0, 3, 6, 283, NULL, 'Maksimali pusvalandinė absoliuti Q galia per mėnesį', 801, 4, NULL, NULL),
	(7180, 270, 0, 3, 4, 1, 3, 6, 283, NULL, 'Maksimali pusvalandinė absoliuti Q galia pagal 1 tarifą per mėnesį', 793, 4, NULL, NULL),
	(7181, 270, 0, 3, 4, 2, 3, 6, 283, NULL, 'Maksimali pusvalandinė absoliuti Q galia pagal 2 tarifą per mėnesį', 795, 4, NULL, NULL),
	(7182, 270, 0, 3, 4, 3, 3, 6, 283, NULL, 'Maksimali pusvalandinė absoliuti Q galia pagal 3 tarifą per mėnesį', 797, 4, NULL, NULL),
	(7183, 270, 0, 3, 4, 4, 3, 6, 283, NULL, 'Maksimali pusvalandinė absoliuti Q galia pagal 4 tarifą per mėnesį', 799, 4, NULL, NULL),
	(7184, 270, 0, 4, 4, 0, 3, 6, 283, NULL, 'Maksimali valandinė absoliuti Q galia per mėnesį', 801, 4, NULL, NULL),
	(7185, 270, 0, 4, 4, 1, 3, 6, 283, NULL, 'Maksimali valandinė absoliuti Q galia pagal 1 tarifą per mėnesį', 793, 4, NULL, NULL),
	(7186, 270, 0, 4, 4, 2, 3, 6, 283, NULL, 'Maksimali valandinė absoliuti Q galia pagal 2 tarifą per mėnesį', 795, 4, NULL, NULL),
	(7187, 270, 0, 4, 4, 3, 3, 6, 283, NULL, 'Maksimali valandinė absoliuti Q galia pagal 3 tarifą per mėnesį', 797, 4, NULL, NULL),
	(7188, 270, 0, 4, 4, 4, 3, 6, 283, NULL, 'Maksimali valandinė absoliuti Q galia pagal 4 tarifą per mėnesį', 799, 4, NULL, NULL),
	(7189, 266, 0, 3, 4, 0, 1, 5, 279, NULL, 'Maksimali pusvalandinė absoliuti P galia per parą', 810, 3, NULL, NULL),
	(7190, 266, 0, 3, 4, 1, 1, 5, 279, NULL, 'Maksimali pusvalandinė absoliuti P galia pagal 1 tarifą per parą', 802, 3, NULL, NULL),
	(7191, 266, 0, 3, 4, 2, 1, 5, 279, NULL, 'Maksimali pusvalandinė absoliuti P galia pagal 2 tarifą per parą', 804, 3, NULL, NULL),
	(7192, 266, 0, 3, 4, 3, 1, 5, 279, NULL, 'Maksimali pusvalandinė absoliuti P galia pagal 3 tarifą per parą', 806, 3, NULL, NULL),
	(7193, 266, 0, 3, 4, 4, 1, 5, 279, NULL, 'Maksimali pusvalandinė absoliuti P galia pagal 4 tarifą per parą', 808, 3, NULL, NULL),
	(7194, 266, 0, 4, 4, 0, 1, 5, 279, NULL, 'Maksimali valandinė absoliuti P galia per parą', 810, 3, NULL, NULL),
	(7195, 266, 0, 4, 4, 1, 1, 5, 279, NULL, 'Maksimali valandinė absoliuti P galia pagal 1 tarifą per parą', 802, 3, NULL, NULL),
	(7196, 266, 0, 4, 4, 2, 1, 5, 279, NULL, 'Maksimali valandinė absoliuti P galia pagal 2 tarifą per parą', 804, 3, NULL, NULL),
	(7197, 266, 0, 4, 4, 3, 1, 5, 279, NULL, 'Maksimali valandinė absoliuti P galia pagal 3 tarifą per parą', 806, 3, NULL, NULL),
	(7198, 266, 0, 4, 4, 4, 1, 5, 279, NULL, 'Maksimali valandinė absoliuti P galia pagal 4 tarifą per parą', 808, 3, NULL, NULL),
	(7199, 270, 0, 3, 4, 0, 3, 5, 283, NULL, 'Maksimali pusvalandinė absoliuti Q galia per parą', 811, 3, NULL, NULL),
	(7200, 270, 0, 3, 4, 1, 3, 5, 283, NULL, 'Maksimali pusvalandinė absoliuti Q galia pagal 1 tarifą per parą', 803, 3, NULL, NULL),
	(7201, 270, 0, 3, 4, 2, 3, 5, 283, NULL, 'Maksimali pusvalandinė absoliuti Q galia pagal 2 tarifą per parą', 805, 3, NULL, NULL),
	(7202, 270, 0, 3, 4, 3, 3, 5, 283, NULL, 'Maksimali pusvalandinė absoliuti Q galia pagal 3 tarifą per parą', 807, 3, NULL, NULL),
	(7203, 270, 0, 3, 4, 4, 3, 5, 283, NULL, 'Maksimali pusvalandinė absoliuti Q galia pagal 4 tarifą per parą', 809, 3, NULL, NULL),
	(7204, 270, 0, 4, 4, 0, 3, 5, 283, NULL, 'Maksimali valandinė absoliuti Q galia per parą', 811, 3, NULL, NULL),
	(7205, 270, 0, 4, 4, 1, 3, 5, 283, NULL, 'Maksimali valandinė absoliuti Q galia pagal 1 tarifą per parą', 803, 3, NULL, NULL),
	(7206, 270, 0, 4, 4, 2, 3, 5, 283, NULL, 'Maksimali valandinė absoliuti Q galia pagal 2 tarifą per parą', 805, 3, NULL, NULL),
	(7207, 270, 0, 4, 4, 3, 3, 5, 283, NULL, 'Maksimali valandinė absoliuti Q galia pagal 3 tarifą per parą', 807, 3, NULL, NULL),
	(7208, 270, 0, 4, 4, 4, 3, 5, 283, NULL, 'Maksimali valandinė absoliuti Q galia pagal 4 tarifą per parą', 809, 3, NULL, NULL),
	(7209, 51, -4, 7, 1, 0, 36, 7, 67, NULL, 'Momentinis pamaitinimo vandens masės debitas', 1093, 6, NULL, NULL),
	(7210, 239, 0, 7, 1, 0, 36, 7, 316, NULL, 'Momentinis šalto vandens masės debitas', 1218, 6, NULL, NULL),
	(7211, 239, 0, 4, 3, 0, 36, 4, 316, NULL, 'Vidutinis šalto vandens masės debitas per valandą', 1219, 2, NULL, NULL),
	(7212, 239, 0, 5, 3, 0, 36, 5, 316, NULL, 'Vidutinis šalto vandens masės debitas per parą', 1219, 3, NULL, NULL),
	(7213, 239, 0, 6, 3, 0, 36, 6, 316, NULL, 'Vidutinis šalto vandens masės debitas per mėnesį', 1219, 4, NULL, NULL),
	(7214, 14, 0, 7, 1, 0, 1, 8, 26, NULL, 'Momentinė aktyvinė galia L1 fazėje, fiksuojama kas 3 minutes', 62, 1, NULL, NULL),
	(7215, 14, 0, 7, 1, 0, 1, 12, 26, NULL, 'Momentinė aktyvinė galia L1 fazėje, fiksuojama kas 15 minučių', 62, 2, NULL, NULL),
	(7216, 14, 0, 7, 1, 0, 1, 3, 26, NULL, 'Momentinė aktyvinė galia L1 fazėje, fiksuojama kas 30 minučių', 62, 2, NULL, NULL),
	(7217, 14, 0, 7, 1, 0, 1, 4, 26, NULL, 'Momentinė aktyvinė galia L1 fazėje, fiksuojama kas valandą', 62, 2, NULL, NULL),
	(7218, 15, 0, 7, 1, 0, 1, 8, 27, NULL, 'Momentinė aktyvinė galia L2 fazėje, fiksuojama kas 3 minutes', 63, 1, NULL, NULL),
	(7219, 15, 0, 7, 1, 0, 1, 12, 27, NULL, 'Momentinė aktyvinė galia L2 fazėje, fiksuojama kas 15 minučių', 63, 2, NULL, NULL),
	(7220, 15, 0, 7, 1, 0, 1, 3, 27, NULL, 'Momentinė aktyvinė galia L2 fazėje, fiksuojama kas 30 minučių', 63, 2, NULL, NULL),
	(7221, 15, 0, 7, 1, 0, 1, 4, 27, NULL, 'Momentinė aktyvinė galia L2 fazėje, fiksuojama kas valandą', 63, 2, NULL, NULL),
	(7222, 16, 0, 7, 1, 0, 1, 8, 28, NULL, 'Momentinė aktyvinė galia L3 fazėje, fiksuojama kas 3 minutes', 64, 1, NULL, NULL),
	(7223, 16, 0, 7, 1, 0, 1, 12, 28, NULL, 'Momentinė aktyvinė galia L3 fazėje, fiksuojama kas 15 minučių', 64, 2, NULL, NULL),
	(7224, 16, 0, 7, 1, 0, 1, 3, 28, NULL, 'Momentinė aktyvinė galia L3 fazėje, fiksuojama kas 30 minučių', 64, 2, NULL, NULL),
	(7225, 16, 0, 7, 1, 0, 1, 4, 28, NULL, 'Momentinė aktyvinė galia L3 fazėje, fiksuojama kas valandą', 64, 2, NULL, NULL),
	(7226, 1, 0, 7, 1, 0, 1, 8, 13, NULL, 'Momentinė aktyvinė galia, fiksuojama kas 3 minutes', 80, 1, NULL, NULL),
	(7227, 1, 0, 7, 1, 0, 1, 12, 13, NULL, 'Momentinė aktyvinė galia, fiksuojama kas 15 minučių', 80, 2, NULL, NULL),
	(7228, 1, 0, 7, 1, 0, 1, 3, 13, NULL, 'Momentinė aktyvinė galia, fiksuojama kas 30 minučių', 80, 2, NULL, NULL),
	(7229, 1, 0, 7, 1, 0, 1, 4, 13, NULL, 'Momentinė aktyvinė galia, fiksuojama kas valandą', 80, 2, NULL, NULL),
	(7230, 17, 0, 7, 1, 0, 3, 8, 29, NULL, 'Momentinė reaktyvinė galia L1 fazėje, fiksuojama kas 3 minutes', 65, 1, NULL, NULL),
	(7231, 17, 0, 7, 1, 0, 3, 12, 29, NULL, 'Momentinė reaktyvinė galia L1 fazėje, fiksuojama kas 15 minučių', 65, 2, NULL, NULL),
	(7232, 17, 0, 7, 1, 0, 3, 3, 29, NULL, 'Momentinė reaktyvinė galia L1 fazėje, fiksuojama kas 30 minučių', 65, 2, NULL, NULL),
	(7233, 17, 0, 7, 1, 0, 3, 4, 29, NULL, 'Momentinė reaktyvinė galia L1 fazėje, fiksuojama kas valandą', 65, 2, NULL, NULL),
	(7234, 18, 0, 7, 1, 0, 3, 8, 30, NULL, 'Momentinė reaktyvinė galia L2 fazėje, fiksuojama kas 3 minutes', 66, 1, NULL, NULL),
	(7235, 18, 0, 7, 1, 0, 3, 12, 30, NULL, 'Momentinė reaktyvinė galia L2 fazėje, fiksuojama kas 15 minučių', 66, 2, NULL, NULL),
	(7236, 18, 0, 7, 1, 0, 3, 3, 30, NULL, 'Momentinė reaktyvinė galia L2 fazėje, fiksuojama kas 30 minučių', 66, 2, NULL, NULL),
	(7237, 18, 0, 7, 1, 0, 3, 4, 30, NULL, 'Momentinė reaktyvinė galia L2 fazėje, fiksuojama kas valandą', 66, 2, NULL, NULL),
	(7238, 19, 0, 7, 1, 0, 3, 8, 31, NULL, 'Momentinė reaktyvinė galia L3 fazėje, fiksuojama kas 3 minutes', 67, 1, NULL, NULL),
	(7239, 19, 0, 7, 1, 0, 3, 12, 31, NULL, 'Momentinė reaktyvinė galia L3 fazėje, fiksuojama kas 15 minučių', 67, 2, NULL, NULL),
	(7240, 19, 0, 7, 1, 0, 3, 3, 31, NULL, 'Momentinė reaktyvinė galia L3 fazėje, fiksuojama kas 30 minučių', 67, 2, NULL, NULL),
	(7241, 19, 0, 7, 1, 0, 3, 4, 31, NULL, 'Momentinė reaktyvinė galia L3 fazėje, fiksuojama kas valandą', 67, 2, NULL, NULL),
	(7242, 3, 0, 7, 1, 0, 3, 8, 16, NULL, 'Momentinė reaktyvinė galia, fiksuojama kas 3 minutes', 81, 1, NULL, NULL),
	(7243, 3, 0, 7, 1, 0, 3, 12, 16, NULL, 'Momentinė reaktyvinė galia, fiksuojama kas 15 minučių', 81, 2, NULL, NULL),
	(7244, 3, 0, 7, 1, 0, 3, 3, 16, NULL, 'Momentinė reaktyvinė galia, fiksuojama kas 30 minučių', 81, 2, NULL, NULL),
	(7245, 3, 0, 7, 1, 0, 3, 4, 16, NULL, 'Momentinė reaktyvinė galia, fiksuojama kas valandą', 81, 2, NULL, NULL),
	(7246, 30, 0, 7, 1, 0, 6, 8, 42, NULL, 'Momentinė įtampa, fiksuojama kas 3 minutes', 78, 1, NULL, NULL),
	(7247, 30, 0, 7, 1, 0, 6, 12, 42, NULL, 'Momentinė įtampa, fiksuojama kas 15 minučių', 78, 2, NULL, NULL),
	(7248, 30, 0, 7, 1, 0, 6, 3, 42, NULL, 'Momentinė įtampa, fiksuojama kas 30 minučių', 78, 2, NULL, NULL),
	(7249, 30, 0, 7, 1, 0, 6, 4, 42, NULL, 'Momentinė įtampa, fiksuojama kas valandą', 78, 2, NULL, NULL),
	(7250, 6, 0, 7, 1, 0, 6, 8, 18, NULL, 'Momentinė įtampa L1 fazėje, fiksuojama kas 3 minutes', 54, 1, NULL, NULL),
	(7251, 6, 0, 7, 1, 0, 6, 12, 18, NULL, 'Momentinė įtampa L1 fazėje, fiksuojama kas 15 minučių', 54, 2, NULL, NULL),
	(7252, 6, 0, 7, 1, 0, 6, 3, 18, NULL, 'Momentinė įtampa L1 fazėje, fiksuojama kas 30 minučių', 54, 2, NULL, NULL),
	(7253, 6, 0, 7, 1, 0, 6, 4, 18, NULL, 'Momentinė įtampa L1 fazėje, fiksuojama kas valandą', 54, 2, NULL, NULL),
	(7254, 8, 0, 7, 1, 0, 6, 8, 20, NULL, 'Momentinė įtampa L2 fazėje, fiksuojama kas 3 minutes', 56, 1, NULL, NULL),
	(7255, 8, 0, 7, 1, 0, 6, 12, 20, NULL, 'Momentinė įtampa L2 fazėje, fiksuojama kas 15 minučių', 56, 2, NULL, NULL),
	(7256, 8, 0, 7, 1, 0, 6, 3, 20, NULL, 'Momentinė įtampa L2 fazėje, fiksuojama kas 30 minučių', 56, 2, NULL, NULL),
	(7257, 8, 0, 7, 1, 0, 6, 4, 20, NULL, 'Momentinė įtampa L2 fazėje, fiksuojama kas valandą', 56, 2, NULL, NULL),
	(7258, 10, 0, 7, 1, 0, 6, 8, 22, NULL, 'Momentinė įtampa L3 fazėje, fiksuojama kas 3 minutes', 58, 1, NULL, NULL),
	(7259, 10, 0, 7, 1, 0, 6, 12, 22, NULL, 'Momentinė įtampa L3 fazėje, fiksuojama kas 15 minučių', 58, 2, NULL, NULL),
	(7260, 10, 0, 7, 1, 0, 6, 3, 22, NULL, 'Momentinė įtampa L3 fazėje, fiksuojama kas 30 minučių', 58, 2, NULL, NULL),
	(7261, 10, 0, 7, 1, 0, 6, 4, 22, NULL, 'Momentinė įtampa L3 fazėje, fiksuojama kas valandą', 58, 2, NULL, NULL),
	(7262, 37, 0, 7, 1, 0, 8, 8, 48, NULL, 'Momentinis dažnis, fiksuojamas kas 3 minutes', 85, 1, NULL, NULL),
	(7263, 37, 0, 7, 1, 0, 8, 12, 48, NULL, 'Momentinis dažnis, fiksuojamas kas 15 minučių', 85, 2, NULL, NULL),
	(7264, 37, 0, 7, 1, 0, 8, 3, 48, NULL, 'Momentinis dažnis, fiksuojamas kas 30 minučių', 85, 2, NULL, NULL),
	(7265, 37, 0, 7, 1, 0, 8, 4, 48, NULL, 'Momentinis dažnis, fiksuojamas kas valandą', 85, 2, NULL, NULL),
	(7266, 219, 0, 7, 1, 0, 8, 8, 232, NULL, 'Momentinis dažnis L1 fazėje, fiksuojamas kas 3 minutes', 108, 1, NULL, NULL),
	(7267, 219, 0, 7, 1, 0, 8, 12, 232, NULL, 'Momentinis dažnis L1 fazėje, fiksuojamas kas 15 minučių', 108, 2, NULL, NULL),
	(7268, 219, 0, 7, 1, 0, 8, 3, 232, NULL, 'Momentinis dažnis L1 fazėje, fiksuojamas kas 30 minučių', 108, 2, NULL, NULL),
	(7269, 219, 0, 7, 1, 0, 8, 4, 232, NULL, 'Momentinis dažnis L1 fazėje, fiksuojamas kas valandą', 108, 2, NULL, NULL),
	(7270, 220, 0, 7, 1, 0, 8, 8, 233, NULL, 'Momentinis dažnis L2 fazėje, fiksuojamas kas 3 minutes', 109, 1, NULL, NULL),
	(7271, 220, 0, 7, 1, 0, 8, 12, 233, NULL, 'Momentinis dažnis L2 fazėje, fiksuojamas kas 15 minučių', 109, 2, NULL, NULL),
	(7272, 220, 0, 7, 1, 0, 8, 3, 233, NULL, 'Momentinis dažnis L2 fazėje, fiksuojamas kas 30 minučių', 109, 2, NULL, NULL),
	(7273, 220, 0, 7, 1, 0, 8, 4, 233, NULL, 'Momentinis dažnis L2 fazėje, fiksuojamas kas valandą', 109, 2, NULL, NULL),
	(7274, 221, 0, 7, 1, 0, 8, 8, 234, NULL, 'Momentinis dažnis L3 fazėje, fiksuojamas kas 3 minutes', 110, 1, NULL, NULL),
	(7275, 221, 0, 7, 1, 0, 8, 12, 234, NULL, 'Momentinis dažnis L3 fazėje, fiksuojamas kas 15 minučių', 110, 2, NULL, NULL),
	(7276, 221, 0, 7, 1, 0, 8, 3, 234, NULL, 'Momentinis dažnis L3 fazėje, fiksuojamas kas 30 minučių', 110, 2, NULL, NULL),
	(7277, 221, 0, 7, 1, 0, 8, 4, 234, NULL, 'Momentinis dažnis L3 fazėje, fiksuojamas kas valandą', 110, 2, NULL, NULL),
	(7278, 20, 0, 7, 1, 0, 7, 8, 32, NULL, 'Momentinė pilnoji galia L1 fazėje, fiksuojama kas 3 minutes', 68, 1, NULL, NULL),
	(7279, 20, 0, 7, 1, 0, 7, 12, 32, NULL, 'Momentinė pilnoji galia L1 fazėje, fiksuojama kas 15 minučių', 68, 2, NULL, NULL),
	(7280, 20, 0, 7, 1, 0, 7, 3, 32, NULL, 'Momentinė pilnoji galia L1 fazėje, fiksuojama kas 30 minučių', 68, 2, NULL, NULL),
	(7281, 20, 0, 7, 1, 0, 7, 4, 32, NULL, 'Momentinė pilnoji galia L1 fazėje, fiksuojama kas valandą', 68, 2, NULL, NULL),
	(7282, 21, 0, 7, 1, 0, 7, 8, 33, NULL, 'Momentinė pilnoji galia L2 fazėje, fiksuojama kas 3 minutes', 69, 1, NULL, NULL),
	(7283, 21, 0, 7, 1, 0, 7, 12, 33, NULL, 'Momentinė pilnoji galia L2 fazėje, fiksuojama kas 15 minučių', 69, 2, NULL, NULL),
	(7284, 21, 0, 7, 1, 0, 7, 3, 33, NULL, 'Momentinė pilnoji galia L2 fazėje, fiksuojama kas 30 minučių', 69, 2, NULL, NULL),
	(7285, 21, 0, 7, 1, 0, 7, 4, 33, NULL, 'Momentinė pilnoji galia L2 fazėje, fiksuojama kas valandą', 69, 2, NULL, NULL),
	(7286, 22, 0, 7, 1, 0, 7, 8, 34, NULL, 'Momentinė pilnoji galia L3 fazėje, fiksuojama kas 3 minutes', 70, 1, NULL, NULL),
	(7287, 22, 0, 7, 1, 0, 7, 12, 34, NULL, 'Momentinė pilnoji galia L3 fazėje, fiksuojama kas 15 minučių', 70, 2, NULL, NULL),
	(7288, 22, 0, 7, 1, 0, 7, 3, 34, NULL, 'Momentinė pilnoji galia L3 fazėje, fiksuojama kas 30 minučių', 70, 2, NULL, NULL),
	(7289, 22, 0, 7, 1, 0, 7, 4, 34, NULL, 'Momentinė pilnoji galia L3 fazėje, fiksuojama kas valandą', 70, 2, NULL, NULL),
	(7290, 34, 0, 7, 1, 0, 7, 8, 44, NULL, 'Momentinė pilnoji galia, fiksuojama kas 3 minutes', 82, 1, NULL, NULL),
	(7291, 34, 0, 7, 1, 0, 7, 12, 44, NULL, 'Momentinė pilnoji galia, fiksuojama kas 15 minučių', 82, 2, NULL, NULL),
	(7292, 34, 0, 7, 1, 0, 7, 3, 44, NULL, 'Momentinė pilnoji galia, fiksuojama kas 30 minučių', 82, 2, NULL, NULL),
	(7293, 34, 0, 7, 1, 0, 7, 4, 44, NULL, 'Momentinė pilnoji galia, fiksuojama kas valandą', 82, 2, NULL, NULL),
	(7294, 5, 0, 7, 1, 0, 5, 8, 17, NULL, 'Momentinis srovės stiprumas L1 fazėje, fiksuojamas kas 3 minutes', 53, 1, NULL, NULL),
	(7295, 5, 0, 7, 1, 0, 5, 12, 17, NULL, 'Momentinis srovės stiprumas L1 fazėje, fiksuojamas kas 15 minučių', 53, 2, NULL, NULL),
	(7296, 5, 0, 7, 1, 0, 5, 3, 17, NULL, 'Momentinis srovės stiprumas L1 fazėje, fiksuojamas kas 30 minučių', 53, 2, NULL, NULL),
	(7297, 5, 0, 7, 1, 0, 5, 4, 17, NULL, 'Momentinis srovės stiprumas L1 fazėje, fiksuojamas kas valandą', 53, 2, NULL, NULL),
	(7298, 7, 0, 7, 1, 0, 5, 8, 19, NULL, 'Momentinis srovės stiprumas L2 fazėje, fiksuojamas kas 3 minutes', 55, 1, NULL, NULL),
	(7299, 7, 0, 7, 1, 0, 5, 12, 19, NULL, 'Momentinis srovės stiprumas L2 fazėje, fiksuojamas kas 15 minučių', 55, 2, NULL, NULL),
	(7300, 7, 0, 7, 1, 0, 5, 3, 19, NULL, 'Momentinis srovės stiprumas L2 fazėje, fiksuojamas kas 30 minučių', 55, 2, NULL, NULL),
	(7301, 7, 0, 7, 1, 0, 5, 4, 19, NULL, 'Momentinis srovės stiprumas L2 fazėje, fiksuojamas kas valandą', 55, 2, NULL, NULL),
	(7302, 9, 0, 7, 1, 0, 5, 8, 21, NULL, 'Momentinis srovės stiprumas L3 fazėje, fiksuojamas kas 3 minutes', 57, 1, NULL, NULL),
	(7303, 9, 0, 7, 1, 0, 5, 12, 21, NULL, 'Momentinis srovės stiprumas L3 fazėje, fiksuojamas kas 15 minučių', 57, 2, NULL, NULL),
	(7304, 9, 0, 7, 1, 0, 5, 3, 21, NULL, 'Momentinis srovės stiprumas L3 fazėje, fiksuojamas kas 30 minučių', 57, 2, NULL, NULL),
	(7305, 9, 0, 7, 1, 0, 5, 4, 21, NULL, 'Momentinis srovės stiprumas L3 fazėje, fiksuojamas kas valandą', 57, 2, NULL, NULL),
	(7306, 169, 0, 7, 1, 0, 56, 8, 182, NULL, 'Kampas tarp L1 ir L2 fazės įtampų, fiksuojamas kas 3 minutes', 91, 1, NULL, NULL),
	(7307, 169, 0, 7, 1, 0, 56, 12, 182, NULL, 'Kampas tarp L1 ir L2 fazės įtampų, fiksuojamas kas 15 minučių', 91, 2, NULL, NULL),
	(7308, 169, 0, 7, 1, 0, 56, 3, 182, NULL, 'Kampas tarp L1 ir L2 fazės įtampų, fiksuojamas kas 30 minučių', 91, 2, NULL, NULL),
	(7309, 169, 0, 7, 1, 0, 56, 4, 182, NULL, 'Kampas tarp L1 ir L2 fazės įtampų, fiksuojamas kas valandą', 91, 2, NULL, NULL),
	(7310, 170, 0, 7, 1, 0, 56, 8, 183, NULL, 'Kampas tarp L2 ir L3 fazės įtampų, fiksuojamas kas 3 minutes', 92, 1, NULL, NULL),
	(7311, 170, 0, 7, 1, 0, 56, 12, 183, NULL, 'Kampas tarp L2 ir L3 fazės įtampų, fiksuojamas kas 15 minučių', 92, 2, NULL, NULL),
	(7312, 170, 0, 7, 1, 0, 56, 3, 183, NULL, 'Kampas tarp L2 ir L3 fazės įtampų, fiksuojamas kas 30 minučių', 92, 2, NULL, NULL),
	(7313, 170, 0, 7, 1, 0, 56, 4, 183, NULL, 'Kampas tarp L2 ir L3 fazės įtampų, fiksuojamas kas valandą', 92, 2, NULL, NULL),
	(7314, 171, 0, 7, 1, 0, 56, 8, 184, NULL, 'Kampas tarp L3 ir L1 fazės įtampų, fiksuojamas kas 3 minutes', 93, 1, NULL, NULL),
	(7315, 171, 0, 7, 1, 0, 56, 12, 184, NULL, 'Kampas tarp L3 ir L1 fazės įtampų, fiksuojamas kas 15 minučių', 93, 2, NULL, NULL),
	(7316, 171, 0, 7, 1, 0, 56, 3, 184, NULL, 'Kampas tarp L3 ir L1 fazės įtampų, fiksuojamas kas 30 minučių', 93, 2, NULL, NULL),
	(7317, 171, 0, 7, 1, 0, 56, 4, 184, NULL, 'Kampas tarp L3 ir L1 fazės įtampų, fiksuojamas kas valandą', 93, 2, NULL, NULL),
	(7318, 172, 0, 7, 1, 0, 56, 8, 185, NULL, 'Kampas tarp srovės ir įtampos L1 fazėje, fiksuojamas kas 3 minutes', 94, 1, NULL, NULL),
	(7319, 172, 0, 7, 1, 0, 56, 12, 185, NULL, 'Kampas tarp srovės ir įtampos L1 fazėje, fiksuojamas kas 15 minučių', 94, 2, NULL, NULL),
	(7320, 172, 0, 7, 1, 0, 56, 3, 185, NULL, 'Kampas tarp srovės ir įtampos L1 fazėje, fiksuojamas kas 30 minučių', 94, 2, NULL, NULL),
	(7321, 172, 0, 7, 1, 0, 56, 4, 185, NULL, 'Kampas tarp srovės ir įtampos L1 fazėje, fiksuojamas kas valandą', 94, 2, NULL, NULL),
	(7322, 173, 0, 7, 1, 0, 56, 8, 186, NULL, 'Kampas tarp srovės ir įtampos L2 fazėje, fiksuojamas kas 3 minutes', 95, 1, NULL, NULL),
	(7323, 173, 0, 7, 1, 0, 56, 12, 186, NULL, 'Kampas tarp srovės ir įtampos L2 fazėje, fiksuojamas kas 15 minučių', 95, 2, NULL, NULL),
	(7324, 173, 0, 7, 1, 0, 56, 3, 186, NULL, 'Kampas tarp srovės ir įtampos L2 fazėje, fiksuojamas kas 30 minučių', 95, 2, NULL, NULL),
	(7325, 173, 0, 7, 1, 0, 56, 4, 186, NULL, 'Kampas tarp srovės ir įtampos L2 fazėje, fiksuojamas kas valandą', 95, 2, NULL, NULL),
	(7326, 174, 0, 7, 1, 0, 56, 8, 187, NULL, 'Kampas tarp srovės ir įtampos L3 fazėje, fiksuojamas kas 3 minutes', 96, 1, NULL, NULL),
	(7327, 174, 0, 7, 1, 0, 56, 12, 187, NULL, 'Kampas tarp srovės ir įtampos L3 fazėje, fiksuojamas kas 15 minučių', 96, 2, NULL, NULL),
	(7328, 174, 0, 7, 1, 0, 56, 3, 187, NULL, 'Kampas tarp srovės ir įtampos L3 fazėje, fiksuojamas kas 30 minučių', 96, 2, NULL, NULL),
	(7329, 174, 0, 7, 1, 0, 56, 4, 187, NULL, 'Kampas tarp srovės ir įtampos L3 fazėje, fiksuojamas kas valandą', 96, 2, NULL, NULL),
	(7330, 266, 0, 7, 1, 0, 1, 8, 279, NULL, 'Momentinė aktyvinė absoliuti galia, fiksuojama kas 3 minutes', 775, 1, NULL, NULL),
	(7331, 266, 0, 7, 1, 0, 1, 12, 279, NULL, 'Momentinė aktyvinė absoliuti galia, fiksuojama kas 15 minučių', 775, 2, NULL, NULL),
	(7332, 266, 0, 7, 1, 0, 1, 3, 279, NULL, 'Momentinė aktyvinė absoliuti galia, fiksuojama kas 30 minučių', 775, 2, NULL, NULL),
	(7333, 266, 0, 7, 1, 0, 1, 4, 279, NULL, 'Momentinė aktyvinė absoliuti galia, fiksuojama kas valandą', 775, 2, NULL, NULL),
	(7334, 266, 0, 7, 1, 0, 1, 5, 279, NULL, 'Momentinė aktyvinė absoliuti galia, fiksuojama kas parą', 775, 3, NULL, NULL),
	(7335, 3, 1, 7, 1, 0, 3, 8, 16, NULL, 'Momentinė Q+ galia, fiksuojama kas 3 minutes', 3314, 1, NULL, NULL),
	(7336, 3, 1, 7, 1, 0, 3, 12, 16, NULL, 'Momentinė Q+ galia, fiksuojama kas 15 minučių', 3314, 2, NULL, NULL),
	(7337, 3, 1, 7, 1, 0, 3, 3, 16, NULL, 'Momentinė Q+ galia, fiksuojama kas 30 minučių', 3314, 2, NULL, NULL),
	(7338, 3, 1, 7, 1, 0, 3, 4, 16, NULL, 'Momentinė Q+ galia, fiksuojama kas valandą', 3314, 2, NULL, NULL),
	(7339, 3, 1, 7, 1, 0, 3, 5, 16, NULL, 'Momentinė Q+ galia, fiksuojama kas parą', 3314, 3, NULL, NULL),
	(7340, 3, 2, 7, 1, 0, 3, 12, 16, NULL, 'Momentinė Q- galia, fiksuojama kas 15 minučių', 3315, 2, NULL, NULL),
	(7341, 3, 2, 7, 1, 0, 3, 3, 16, NULL, 'Momentinė Q- galia, fiksuojama kas 30 minučių', 3315, 2, NULL, NULL),
	(7342, 3, 2, 7, 1, 0, 3, 4, 16, NULL, 'Momentinė Q- galia, fiksuojama kas valandą', 3315, 2, NULL, NULL),
	(7343, 3, 2, 7, 1, 0, 3, 5, 16, NULL, 'Momentinė Q- galia, fiksuojama kas parą', 3315, 3, NULL, NULL),
	(7344, 3, 2, 7, 1, 0, 3, 8, 16, NULL, 'Momentinė Q- galia, fiksuojama kas 3 minutes', 3315, 1, NULL, NULL),
	(7345, 14, 1, 7, 1, 0, 1, 8, 26, NULL, 'Momentinė P+ galia L1 fazėje, fiksuojama kas 3 minutes', 3330, 1, NULL, NULL),
	(7346, 14, 1, 7, 1, 0, 1, 12, 26, NULL, 'Momentinė P+ galia L1 fazėje, fiksuojama kas 15 minučių', 3330, 2, NULL, NULL),
	(7347, 14, 1, 7, 1, 0, 1, 3, 26, NULL, 'Momentinė P+ galia L1 fazėje, fiksuojama kas 30 minučių', 3330, 2, NULL, NULL),
	(7348, 14, 1, 7, 1, 0, 1, 4, 26, NULL, 'Momentinė P+ galia L1 fazėje, fiksuojama kas valandą', 3330, 2, NULL, NULL),
	(7349, 14, 1, 7, 1, 0, 1, 5, 26, NULL, 'Momentinė P+ galia L1 fazėje, fiksuojama kas parą', 3330, 3, NULL, NULL),
	(7350, 15, 1, 7, 1, 0, 1, 8, 27, NULL, 'Momentinė P+ galia L2 fazėje, fiksuojama kas 3 minutes', 3331, 1, NULL, NULL),
	(7351, 15, 1, 7, 1, 0, 1, 12, 27, NULL, 'Momentinė P+ galia L2 fazėje, fiksuojama kas 15 minučių', 3331, 2, NULL, NULL),
	(7352, 15, 1, 7, 1, 0, 1, 3, 27, NULL, 'Momentinė P+ galia L2 fazėje, fiksuojama kas 30 minučių', 3331, 2, NULL, NULL),
	(7353, 15, 1, 7, 1, 0, 1, 4, 27, NULL, 'Momentinė P+ galia L2 fazėje, fiksuojama kas valandą', 3331, 2, NULL, NULL),
	(7354, 15, 1, 7, 1, 0, 1, 5, 27, NULL, 'Momentinė P+ galia L2 fazėje, fiksuojama kas parą', 3331, 3, NULL, NULL),
	(7355, 16, 1, 7, 1, 0, 1, 8, 28, NULL, 'Momentinė P+ galia L3 fazėje, fiksuojama kas 3 minutes', 3332, 1, NULL, NULL),
	(7356, 16, 1, 7, 1, 0, 1, 12, 28, NULL, 'Momentinė P+ galia L3 fazėje, fiksuojama kas 15 minučių', 3332, 2, NULL, NULL),
	(7357, 16, 1, 7, 1, 0, 1, 3, 28, NULL, 'Momentinė P+ galia L3 fazėje, fiksuojama kas 30 minučių', 3332, 2, NULL, NULL),
	(7358, 16, 1, 7, 1, 0, 1, 4, 28, NULL, 'Momentinė P+ galia L3 fazėje, fiksuojama kas valandą', 3332, 2, NULL, NULL),
	(7359, 16, 1, 7, 1, 0, 1, 5, 28, NULL, 'Momentinė P+ galia L3 fazėje, fiksuojama kas parą', 3332, 3, NULL, NULL),
	(7360, 5, 0, 7, 1, 0, 5, 5, 17, NULL, 'Momentinis srovės stiprumas L1 fazėje, fiksuojamas kas parą', 53, 3, NULL, NULL),
	(7361, 6, 0, 7, 1, 0, 6, 5, 18, NULL, 'Momentinė įtampa L1 fazėje, fiksuojama kas parą', 54, 3, NULL, NULL),
	(7362, 7, 0, 7, 1, 0, 5, 5, 19, NULL, 'Momentinis srovės stiprumas L2 fazėje, fiksuojamas kas parą', 55, 3, NULL, NULL),
	(7363, 8, 0, 7, 1, 0, 6, 5, 20, NULL, 'Momentinė įtampa L2 fazėje, fiksuojama kas parą', 56, 3, NULL, NULL),
	(7364, 9, 0, 7, 1, 0, 5, 5, 21, NULL, 'Momentinis srovės stiprumas L3 fazėje, fiksuojamas kas parą', 57, 3, NULL, NULL),
	(7365, 10, 0, 7, 1, 0, 6, 5, 22, NULL, 'Momentinė įtampa L3 fazėje, fiksuojama kas parą', 58, 3, NULL, NULL),
	(7366, 17, 0, 7, 1, 0, 3, 5, 29, NULL, 'Momentinė reaktyvinė galia L1 fazėje, fiksuojama kas parą', 65, 3, NULL, NULL),
	(7367, 18, 0, 7, 1, 0, 3, 5, 30, NULL, 'Momentinė reaktyvinė galia L2 fazėje, fiksuojama kas parą', 66, 3, NULL, NULL),
	(7368, 19, 0, 7, 1, 0, 3, 5, 31, NULL, 'Momentinė reaktyvinė galia L3 fazėje, fiksuojama kas parą', 67, 3, NULL, NULL),
	(7369, 169, 0, 7, 1, 0, 56, 5, 182, NULL, 'Kampas tarp L1 ir L2 fazės įtampų, fiksuojamas kas parą', 91, 3, NULL, NULL),
	(7370, 171, 0, 7, 1, 0, 56, 5, 184, NULL, 'Kampas tarp L3 ir L1 fazės įtampų, fiksuojamas kas  parą', 93, 3, NULL, NULL),
	(7371, 304, 0, 7, 45, 0, 5, 7, 317, NULL, 'Momentinė 1-os harmonikos srovė L1 fazėje', 3123, 6, NULL, NULL),
	(7372, 304, 0, 7, 45, 0, 5, 8, 317, NULL, 'Momentinė 1-os harmonikos srovė L1 fazėje, fiksuojama kas 3 minutes', 3123, 1, NULL, NULL),
	(7373, 304, 0, 7, 45, 0, 5, 12, 317, NULL, 'Momentinė 1-os harmonikos srovė L1 fazėje, fiksuojama kas 15 minučių', 3123, 2, NULL, NULL),
	(7374, 304, 0, 7, 45, 0, 5, 3, 317, NULL, 'Momentinė 1-os harmonikos srovė L1 fazėje, fiksuojama kas 30 minučių', 3123, 2, NULL, NULL),
	(7375, 304, 0, 7, 45, 0, 5, 4, 317, NULL, 'Momentinė 1-os harmonikos srovė L1 fazėje, fiksuojama kas valandą', 3123, 2, NULL, NULL),
	(7376, 304, 0, 7, 45, 0, 5, 5, 317, NULL, 'Momentinė 1-os harmonikos srovė L1 fazėje, fiksuojama kas parą', 3123, 3, NULL, NULL),
	(7377, 305, 0, 7, 1, 0, 5, 7, 318, NULL, 'Momentinė 1-os harmonikos srovė L2 fazėje', 3124, 6, NULL, NULL),
	(7378, 305, 0, 7, 1, 0, 5, 8, 318, NULL, 'Momentinė 1-os harmonikos srovė L2 fazėje, fiksuojama kas 3 minutes', 3124, 1, NULL, NULL),
	(7379, 305, 0, 7, 1, 0, 5, 12, 318, NULL, 'Momentinė 1-os harmonikos srovė L2 fazėje, fiksuojama kas 15 minučių', 3124, 2, NULL, NULL),
	(7380, 305, 0, 7, 1, 0, 5, 3, 318, NULL, 'Momentinė 1-os harmonikos srovė L2 fazėje, fiksuojama kas 30 minučių', 3124, 2, NULL, NULL),
	(7381, 305, 0, 7, 1, 0, 5, 4, 318, NULL, 'Momentinė 1-os harmonikos srovė L2 fazėje, fiksuojama kas valandą', 3124, 2, NULL, NULL),
	(7382, 305, 0, 7, 1, 0, 5, 5, 318, NULL, 'Momentinė 1-os harmonikos srovė L2 fazėje, fiksuojama kas parą', 3124, 3, NULL, NULL),
	(7383, 306, 0, 7, 1, 0, 5, 7, 319, NULL, 'Momentinė 1-os harmonikos srovė L3 fazėje', 3125, 6, NULL, NULL),
	(7384, 306, 0, 7, 1, 0, 5, 8, 319, NULL, 'Momentinė 1-os harmonikos srovė L3 fazėje, fiksuojama kas 3 minutes', 3125, 1, NULL, NULL),
	(7385, 306, 0, 7, 1, 0, 5, 12, 319, NULL, 'Momentinė 1-os harmonikos srovė L3 fazėje, fiksuojama kas 15 minučių', 3125, 2, NULL, NULL),
	(7386, 306, 0, 7, 1, 0, 5, 3, 319, NULL, 'Momentinė 1-os harmonikos srovė L3 fazėje, fiksuojama kas 30 minučių', 3125, 2, NULL, NULL),
	(7387, 306, 0, 7, 1, 0, 5, 4, 319, NULL, 'Momentinė 1-os harmonikos srovė L3 fazėje, fiksuojama kas valandą', 3125, 2, NULL, NULL),
	(7388, 306, 0, 7, 1, 0, 5, 5, 319, NULL, 'Momentinė 1-os harmonikos srovė L3 fazėje, fiksuojama kas parą', 3125, 3, NULL, NULL),
	(7389, 240, 1, 4, 2, 0, 35, 4, 253, NULL, 'Tiekiamo karšto vandens masės kiekis per valandą', 1213, 2, NULL, NULL),
	(7390, 240, 1, 5, 2, 0, 35, 5, 253, NULL, 'Tiekiamo karšto vandens masės kiekis per parą', 1213, 3, NULL, NULL),
	(7391, 240, 1, 6, 2, 0, 35, 6, 253, NULL, 'Tiekiamo karšto vandens masės kiekis per mėnesį', 1213, 4, NULL, NULL),
	(7392, 240, 2, 4, 2, 0, 35, 4, 253, NULL, 'Grįžtamo karšto vandens masės kiekis per valandą', 1242, 2, NULL, NULL),
	(7393, 240, 2, 5, 2, 0, 35, 5, 253, NULL, 'Grįžtamo karšto vandens masės kiekis per parą', 1242, 3, NULL, NULL),
	(7394, 240, 2, 6, 2, 0, 35, 6, 253, NULL, 'Grįžtamo karšto vandens masės kiekis per mėnesį', 1242, 4, NULL, NULL),
	(7395, 307, 0, 4, 2, 0, 27, 4, 320, NULL, 'Išorinė oro temperatūra per valandą', 1075, 2, NULL, NULL),
	(7396, 307, 0, 5, 2, 0, 27, 5, 320, NULL, 'Išorinė oro temperatūra per parą', 1075, 3, NULL, NULL),
	(7397, 307, 0, 6, 2, 0, 27, 6, 320, NULL, 'Išorinė oro temperatūra per mėnesį', 1075, 4, NULL, NULL),
	(7398, 307, 0, 7, 1, 0, 27, 7, 320, NULL, 'Momentinė išorinė oro temperatūra', 1013, 6, NULL, NULL),
	(7399, 307, 0, 7, 1, 0, 27, 8, 320, NULL, 'Momentinė išorinė oro temperatūra, fiksuojama kas 3 minutes', 1013, 1, NULL, NULL),
	(7400, 307, 0, 7, 1, 0, 27, 12, 320, NULL, 'Momentinė išorinė oro temperatūra, fiksuojama kas 15 minučių', 1013, 2, NULL, NULL),
	(7401, 307, 0, 7, 1, 0, 27, 3, 320, NULL, 'Momentinė išorinė oro temperatūra, fiksuojama kas 30 minučių', 1013, 2, NULL, NULL),
	(7402, 307, 0, 7, 1, 0, 27, 4, 320, NULL, 'Momentinė išorinė oro temperatūra, fiksuojama kas valandą', 1013, 2, NULL, NULL),
	(7403, 307, 0, 7, 1, 0, 27, 5, 320, NULL, 'Momentinė išorinė oro temperatūra, fiksuojama kas parą', 1013, 3, NULL, NULL),
	(7404, 308, 0, 7, 1, 0, 29, 7, 321, NULL, 'Momentinis prietaiso darbo laikas', 4000, 6, NULL, NULL),
	(7405, 309, 0, 7, 1, 0, 27, 7, 322, NULL, 'Momentinė prietaiso vidinė temperatūra', 4001, 6, NULL, NULL),
	(7406, 310, 0, 7, 1, 0, 0, 7, 323, NULL, 'Gauto signalo kokybė', 4002, 6, NULL, NULL),
	(7407, 311, 0, 4, 2, 0, 29, 4, 324, NULL, '1-os neįprastos situacijos trukmė per valandą', 1094, 2, NULL, NULL),
	(7408, 311, 0, 5, 2, 0, 29, 5, 324, NULL, '1-os neįprastos situacijos trukmė per parą', 1094, 3, NULL, NULL),
	(7409, 311, 0, 6, 2, 0, 29, 6, 324, NULL, '1-os neįprastos situacijos trukmė per menesį', 1094, 4, NULL, NULL),
	(7410, 312, 0, 4, 2, 0, 29, 4, 325, NULL, '2-os neįprastos situacijos trukmė per valandą', 1095, 2, NULL, NULL),
	(7411, 312, 0, 5, 2, 0, 29, 5, 325, NULL, '2-os neįprastos situacijos trukmė per parą', 1095, 3, NULL, NULL),
	(7412, 312, 0, 6, 2, 0, 29, 6, 325, NULL, '2-os neįprastos situacijos trukmė per menesį', 1095, 4, NULL, NULL),
	(7413, 313, 0, 4, 2, 0, 29, 4, 326, NULL, '3-os neįprastos situacijos trukmė per valandą', 1096, 2, NULL, NULL),
	(7414, 313, 0, 5, 2, 0, 29, 5, 326, NULL, '3-os neįprastos situacijos trukmė per parą', 1096, 3, NULL, NULL),
	(7415, 313, 0, 6, 2, 0, 29, 6, 326, NULL, '3-os neįprastos situacijos trukmė per menesį', 1096, 4, NULL, NULL),
	(7416, 314, 0, 4, 2, 0, 29, 4, 327, NULL, '4-os neįprastos situacijos trukmė per valandą', 1097, 2, NULL, NULL),
	(7417, 314, 0, 5, 2, 0, 29, 5, 327, NULL, '4-os neįprastos situacijos trukmė per parą', 1097, 3, NULL, NULL),
	(7418, 314, 0, 6, 2, 0, 29, 6, 327, NULL, '4-os neįprastos situacijos trukmė per menesį', 1097, 4, NULL, NULL),
	(7419, 315, 0, 4, 2, 0, 29, 4, 328, NULL, '5-os neįprastos situacijos trukmė per valandą', 1098, 2, NULL, NULL),
	(7420, 315, 0, 5, 2, 0, 29, 5, 328, NULL, '5-os neįprastos situacijos trukmė per parą', 1098, 3, NULL, NULL),
	(7421, 315, 0, 6, 2, 0, 29, 6, 328, NULL, '5-os neįprastos situacijos trukmė per menesį', 1098, 4, NULL, NULL),
	(7422, 53, -4, 7, 1, 0, 1, 7, 70, NULL, 'Momentinė pamaitinimo vandens šilumos galia', 1099, 6, NULL, NULL),
	(7423, 317, 1, 7, 1, 0, 57, 7, 330, NULL, 'Momentinė tiekiamo šilumnešio entalpija', 1700, 6, NULL, NULL),
	(7424, 317, 1, 4, 2, 0, 57, 4, 330, NULL, 'Tiekiamo šilumnešio entalpija per valandą', 1703, 2, NULL, NULL),
	(7425, 317, 1, 5, 2, 0, 57, 5, 330, NULL, 'Tiekiamo šilumnešio entalpija per parą', 1703, 3, NULL, NULL),
	(7426, 317, 1, 6, 2, 0, 57, 6, 330, NULL, 'Tiekiamo šilumnešio entalpija per mėnesį', 1703, 4, NULL, NULL),
	(7427, 317, 2, 7, 1, 0, 57, 7, 330, NULL, 'Momentinė grįžtamo šilumnešio entalpija', 1701, 6, NULL, NULL),
	(7428, 317, 2, 4, 2, 0, 57, 4, 330, NULL, 'Grįžtamo šilumnešio entalpija per valandą', 1704, 2, NULL, NULL),
	(7429, 317, 2, 5, 2, 0, 57, 5, 330, NULL, 'Grįžtamo šilumnešio entalpija per parą', 1704, 3, NULL, NULL),
	(7430, 317, 2, 6, 2, 0, 57, 6, 330, NULL, 'Grįžtamo šilumnešio entalpija per mėnesį', 1704, 4, NULL, NULL),
	(7431, 317, -4, 7, 1, 0, 57, 7, 330, NULL, 'Momentinė pamaitinimo vandens entalpija', 1702, 6, NULL, NULL),
	(7432, 317, -4, 4, 2, 0, 57, 4, 330, NULL, 'Pamaitinimo vandens entalpija per valandą', 1705, 2, NULL, NULL),
	(7433, 317, -4, 5, 2, 0, 57, 5, 330, NULL, 'Pamaitinimo vandens entalpija per parą', 1705, 3, NULL, NULL),
	(7434, 317, -4, 6, 2, 0, 57, 6, 330, NULL, 'Pamaitinimo vandens entalpija per mėnesį', 1705, 4, NULL, NULL),
	(7435, 320, 1, 7, 1, 0, 59, 7, 333, NULL, 'Momentinis tiekiamo šilumnešio tankis', 1706, 6, NULL, NULL),
	(7436, 320, 1, 4, 2, 0, 59, 4, 333, NULL, 'Tiekiamo šilumnešio tankis per valandą', 1709, 2, NULL, NULL),
	(7437, 320, 1, 5, 2, 0, 59, 5, 333, NULL, 'Tiekiamo šilumnešio tankis per parą', 1709, 3, NULL, NULL),
	(7438, 320, 1, 6, 2, 0, 59, 6, 333, NULL, 'Tiekiamo šilumnešio tankis per mėnesį', 1709, 4, NULL, NULL),
	(7439, 320, 2, 7, 1, 0, 59, 7, 333, NULL, 'Momentinis grįžtamo šilumnešio tankis', 1707, 6, NULL, NULL),
	(7440, 320, 2, 4, 2, 0, 59, 4, 333, NULL, 'Grįžtamo šilumnešio tankis per valandą', 1710, 2, NULL, NULL),
	(7441, 320, 2, 5, 2, 0, 59, 5, 333, NULL, 'Grįžtamo šilumnešio tankis per parą', 1710, 3, NULL, NULL),
	(7442, 320, 2, 6, 2, 0, 59, 6, 333, NULL, 'Grįžtamo šilumnešio tankis per mėnesį', 1710, 4, NULL, NULL),
	(7443, 320, -4, 7, 1, 0, 59, 7, 333, NULL, 'Momentinis pamaitinimo vandens tankis', 1708, 6, NULL, NULL),
	(7444, 320, -4, 4, 2, 0, 59, 4, 333, NULL, 'Pamaitinimo vandens tankis per valandą', 1711, 2, NULL, NULL),
	(7445, 320, -4, 5, 2, 0, 59, 5, 333, NULL, 'Pamaitinimo vandens tankis per parą', 1711, 3, NULL, NULL),
	(7446, 320, -4, 6, 2, 0, 59, 6, 333, NULL, 'Pamaitinimo vandens tankis per mėnesį', 1711, 4, NULL, NULL),
	(7447, 323, 0, 7, 1, 0, 28, 7, 336, NULL, 'Momentinis absoliutus šalto vandens slėgis', 1220, 6, NULL, NULL),
	(7448, 324, 0, 7, 1, 0, 57, 7, 337, NULL, 'Momentinė šalto vandens entalpija', 1221, 6, NULL, NULL),
	(7449, 65, 1, 7, 1, 0, 29, 7, 78, NULL, 'Momentinis karšto vandens tiekimo vamzdyno darbo laikas', 1222, 6, NULL, NULL),
	(7450, 65, 1, 8, 2, 0, 29, 7, 78, NULL, 'Suminis karšto vandens tiekimo vamzdyno darbo laikas', 1222, 5, NULL, NULL),
	(7451, 65, 2, 7, 1, 0, 29, 7, 78, NULL, 'Momentinis karšto vandens grąžinimo vamzdyno darbo laikas', 1223, 6, NULL, NULL),
	(7452, 65, 2, 8, 2, 0, 29, 7, 78, NULL, 'Suminis karšto vandens grąžinimo vamzdyno darbo laikas', 1223, 5, NULL, NULL),
	(7453, 62, 1, 7, 1, 0, 29, 7, 75, NULL, 'Momentinis šilumnešio tiekimo vamzdyno darbo laikas', 1712, 6, NULL, NULL),
	(7454, 62, 1, 8, 2, 0, 29, 7, 75, NULL, 'Suminis šilumnešio tiekimo vamzdyno darbo laikas', 1712, 5, NULL, NULL),
	(7455, 62, 2, 7, 1, 0, 29, 7, 75, NULL, 'Momentinis šilumnešio grąžinimo vamzdyno darbo laikas', 1713, 6, NULL, NULL),
	(7456, 62, 2, 8, 2, 0, 29, 7, 75, NULL, 'Suminis šilumnešio grąžinimo vamzdyno darbo laikas', 1713, 5, NULL, NULL),
	(7457, 329, 0, 7, 1, 0, 28, 7, 342, NULL, 'Momentinis šilumnešio absoliutus slėgis', 1040, 6, NULL, NULL),
	(7460, 53, 3, 8, 2, 0, 2, 7, 71, NULL, 'Suminis sunaudotos šilumnešio šilumos kiekis', 1044, 5, NULL, NULL),
	(7461, 323, 0, 12, 3, 0, 28, 11, 336, NULL, 'Vidutinis absoliutus šalto vandens slėgis per 10 minučių', 1224, 1, NULL, NULL),
	(7462, 323, 0, 11, 3, 0, 28, 10, 336, NULL, 'Vidutinis absoliutus šalto vandens slėgis per 5 minutes', 1224, 1, NULL, NULL),
	(7463, 323, 0, 10, 3, 0, 28, 9, 336, NULL, 'Vidutinis absoliutus šalto vandens slėgis per 4 minutes', 1224, 1, NULL, NULL),
	(7464, 323, 0, 9, 3, 0, 28, 8, 336, NULL, 'Vidutinis absoliutus šalto vandens slėgis per 3 minutes', 1224, 1, NULL, NULL),
	(7465, 323, 0, 2, 3, 0, 28, 2, 336, NULL, 'Vidutinis absoliutus šalto vandens slėgis per 2 minutes', 1224, 1, NULL, NULL),
	(7466, 323, 0, 1, 3, 0, 28, 1, 336, NULL, 'Vidutinis absoliutus šalto vandens slėgis per minutę', 1224, 1, NULL, NULL),
	(7467, 323, 0, 4, 3, 0, 28, 4, 336, NULL, 'Vidutinis absoliutus šalto vandens slėgis per valandą', 1224, 2, NULL, NULL),
	(7468, 323, 0, 3, 3, 0, 28, 3, 336, NULL, 'Vidutinis absoliutus šalto vandens slėgis per 30 minučių', 1224, 2, NULL, NULL),
	(7469, 323, 0, 14, 3, 0, 28, 13, 336, NULL, 'Vidutinis absoliutus šalto vandens slėgis per 20 minučių', 1224, 2, NULL, NULL),
	(7470, 323, 0, 13, 3, 0, 28, 12, 336, NULL, 'Vidutinis absoliutus šalto vandens slėgis per 15 minučių', 1224, 2, NULL, NULL),
	(7471, 323, 0, 5, 3, 0, 28, 5, 336, NULL, 'Vidutinis absoliutus šalto vandens slėgis per parą', 1224, 3, NULL, NULL),
	(7472, 323, 0, 6, 3, 0, 28, 6, 336, NULL, 'Vidutinis absoliutus šalto vandens slėgis per mėnesį', 1224, 4, NULL, NULL),
	(7474, 330, 0, 12, 3, 0, 28, 11, 343, NULL, 'Vidutinis oro slėgis per 10 minučių', 1303, 1, NULL, NULL),
	(7475, 330, 0, 11, 3, 0, 28, 10, 343, NULL, 'Vidutinis oro slėgis per 5 minutes', 1303, 1, NULL, NULL),
	(7476, 330, 0, 10, 3, 0, 28, 9, 343, NULL, 'Vidutinis oro slėgis per 4 minutes', 1303, 1, NULL, NULL),
	(7477, 330, 0, 9, 3, 0, 28, 8, 343, NULL, 'Vidutinis oro slėgis per 3 minutes', 1303, 1, NULL, NULL),
	(7478, 330, 0, 2, 3, 0, 28, 2, 343, NULL, 'Vidutinis oro slėgis per 2 minutes', 1303, 1, NULL, NULL),
	(7479, 330, 0, 1, 3, 0, 28, 1, 343, NULL, 'Vidutinis oro slėgis per minutę', 1303, 1, NULL, NULL),
	(7480, 330, 0, 4, 3, 0, 28, 4, 343, NULL, 'Vidutinis oro slėgis per valandą', 1303, 2, NULL, NULL),
	(7481, 330, 0, 3, 3, 0, 28, 3, 343, NULL, 'Vidutinis oro slėgis per 30 minučių', 1303, 2, NULL, NULL),
	(7482, 330, 0, 14, 3, 0, 28, 13, 343, NULL, 'Vidutinis oro slėgis per 20 minučių', 1303, 2, NULL, NULL),
	(7483, 330, 0, 13, 3, 0, 28, 12, 343, NULL, 'Vidutinis oro slėgis per 15 minučių', 1303, 2, NULL, NULL),
	(7484, 330, 0, 5, 3, 0, 28, 5, 343, NULL, 'Vidutinis oro slėgis per parą', 1303, 3, NULL, NULL),
	(7485, 330, 0, 6, 3, 0, 28, 6, 343, NULL, 'Vidutinis oro slėgis per mėnesį', 1303, 4, NULL, NULL),
	(7486, 330, 0, 7, 1, 0, 28, 7, 343, NULL, 'Momentinis oro slėgis', 1301, 6, NULL, NULL),
	(7487, 329, 0, 12, 3, 0, 28, 11, 342, NULL, 'Vidutinis absoliutus šilumnešio slėgis per 10 minučių', 1718, 1, NULL, NULL),
	(7488, 329, 0, 11, 3, 0, 28, 10, 342, NULL, 'Vidutinis absoliutus šilumnešio slėgis per 5 minutes', 1718, 1, NULL, NULL),
	(7489, 329, 0, 10, 3, 0, 28, 9, 342, NULL, 'Vidutinis absoliutus šilumnešio slėgis per 4 minutes', 1718, 1, NULL, NULL),
	(7490, 329, 0, 9, 3, 0, 28, 8, 342, NULL, 'Vidutinis absoliutus šilumnešio slėgis per 3 minutes', 1718, 1, NULL, NULL),
	(7491, 329, 0, 2, 3, 0, 28, 2, 342, NULL, 'Vidutinis absoliutus šilumnešio slėgis per 2 minutes', 1718, 1, NULL, NULL),
	(7492, 329, 0, 1, 3, 0, 28, 1, 342, NULL, 'Vidutinis absoliutus šilumnešio slėgis per minutę', 1718, 1, NULL, NULL),
	(7493, 329, 0, 4, 3, 0, 28, 4, 342, NULL, 'Vidutinis absoliutus šilumnešio slėgis per valandą', 1718, 2, NULL, NULL),
	(7494, 329, 0, 3, 3, 0, 28, 3, 342, NULL, 'Vidutinis absoliutus šilumnešio slėgis per 30 minučių', 1718, 2, NULL, NULL),
	(7495, 329, 0, 14, 3, 0, 28, 13, 342, NULL, 'Vidutinis absoliutus šilumnešio slėgis per 20 minučių', 1718, 2, NULL, NULL),
	(7496, 329, 0, 13, 3, 0, 28, 12, 342, NULL, 'Vidutinis absoliutus šilumnešio slėgis per 15 minučių', 1718, 2, NULL, NULL),
	(7497, 329, 0, 5, 3, 0, 28, 5, 342, NULL, 'Vidutinis absoliutus šilumnešio slėgis per parą', 1718, 3, NULL, NULL),
	(7498, 329, 0, 6, 3, 0, 28, 6, 342, NULL, 'Vidutinis absoliutus šilumnešio slėgis per mėnesį', 1718, 4, NULL, NULL),
	(7499, 331, 0, 12, 3, 0, 28, 11, 344, NULL, 'Vidutinis šilumnešio diferencinis slėgis per 10 minučių', 1717, 1, NULL, NULL),
	(7500, 331, 0, 11, 3, 0, 28, 10, 344, NULL, 'Vidutinis šilumnešio diferencinis slėgis per 5 minutes', 1717, 1, NULL, NULL),
	(7501, 331, 0, 10, 3, 0, 28, 9, 344, NULL, 'Vidutinis šilumnešio diferencinis slėgis per 4 minutes', 1717, 1, NULL, NULL),
	(7502, 331, 0, 9, 3, 0, 28, 8, 344, NULL, 'Vidutinis šilumnešio diferencinis slėgis per 3 minutes', 1717, 1, NULL, NULL),
	(7503, 331, 0, 2, 3, 0, 28, 2, 344, NULL, 'Vidutinis šilumnešio diferencinis slėgis per 2 minutes', 1717, 1, NULL, NULL),
	(7504, 331, 0, 1, 3, 0, 28, 1, 344, NULL, 'Vidutinis šilumnešio diferencinis slėgis per minutę', 1717, 1, NULL, NULL),
	(7505, 331, 0, 4, 3, 0, 28, 4, 344, NULL, 'Vidutinis šilumnešio diferencinis slėgis per valandą', 1717, 2, NULL, NULL),
	(7506, 331, 0, 3, 3, 0, 28, 3, 344, NULL, 'Vidutinis šilumnešio diferencinis slėgis per 30 minučių', 1717, 2, NULL, NULL),
	(7507, 331, 0, 14, 3, 0, 28, 13, 344, NULL, 'Vidutinis šilumnešio diferencinis slėgis per 20 minučių', 1717, 2, NULL, NULL),
	(7508, 331, 0, 13, 3, 0, 28, 12, 344, NULL, 'Vidutinis šilumnešio diferencinis slėgis per 15 minučių', 1717, 2, NULL, NULL),
	(7509, 331, 0, 5, 3, 0, 28, 5, 344, NULL, 'Vidutinis šilumnešio diferencinis slėgis per parą', 1717, 3, NULL, NULL),
	(7510, 331, 0, 6, 3, 0, 28, 6, 344, NULL, 'Vidutinis šilumnešio diferencinis slėgis per mėnesį', 1717, 4, NULL, NULL),
	(7511, 331, 0, 7, 1, 0, 28, 7, 344, NULL, 'Momentinis šilumnešio diferencinis slėgis', 1041, 6, NULL, NULL),
	(7512, 331, 1, 12, 3, 0, 28, 11, 344, NULL, 'Vidutinis tiekiamo šilumnešio diferencinis slėgis per 10 minučių', 1717, 1, NULL, NULL),
	(7513, 331, 1, 11, 3, 0, 28, 10, 344, NULL, 'Vidutinis tiekiamo šilumnešio diferencinis slėgis per 5 minutes', 1717, 1, NULL, NULL),
	(7514, 331, 1, 10, 3, 0, 28, 9, 344, NULL, 'Vidutinis tiekiamo šilumnešio diferencinis slėgis per 4 minutes', 1717, 1, NULL, NULL),
	(7515, 331, 1, 9, 3, 0, 28, 8, 344, NULL, 'Vidutinis tiekiamo šilumnešio diferencinis slėgis per 3 minutes', 1717, 1, NULL, NULL),
	(7516, 331, 1, 2, 3, 0, 28, 2, 344, NULL, 'Vidutinis tiekiamo šilumnešio diferencinis slėgis per 2 minutes', 1717, 1, NULL, NULL),
	(7517, 331, 1, 1, 3, 0, 28, 1, 344, NULL, 'Vidutinis tiekiamo šilumnešio diferencinis slėgis per minutę', 1717, 1, NULL, NULL),
	(7518, 331, 1, 4, 3, 0, 28, 4, 344, NULL, 'Vidutinis tiekiamo šilumnešio diferencinis slėgis per valandą', 1717, 2, NULL, NULL),
	(7519, 331, 1, 3, 3, 0, 28, 3, 344, NULL, 'Vidutinis tiekiamo šilumnešio diferencinis slėgis per 30 minučių', 1717, 2, NULL, NULL),
	(7520, 331, 1, 14, 3, 0, 28, 13, 344, NULL, 'Vidutinis tiekiamo šilumnešio diferencinis slėgis per 20 minučių', 1717, 2, NULL, NULL),
	(7521, 331, 1, 13, 3, 0, 28, 12, 344, NULL, 'Vidutinis tiekiamo šilumnešio diferencinis slėgis per 15 minučių', 1717, 2, NULL, NULL),
	(7522, 331, 1, 5, 3, 0, 28, 5, 344, NULL, 'Vidutinis tiekiamo šilumnešio diferencinis slėgis per parą', 1717, 3, NULL, NULL),
	(7523, 331, 1, 6, 3, 0, 28, 6, 344, NULL, 'Vidutinis tiekiamo šilumnešio diferencinis slėgis per mėnesį', 1717, 4, NULL, NULL),
	(7524, 331, 1, 7, 1, 0, 28, 7, 344, NULL, 'Momentinis tiekiamo šilumnešio diferencinis slėgis', 1041, 6, NULL, NULL),
	(7525, 331, 2, 12, 3, 0, 28, 11, 344, NULL, 'Vidutinis grįžtamo šilumnešio diferencinis slėgis per 10 minučių', 1721, 1, NULL, NULL),
	(7526, 331, 2, 11, 3, 0, 28, 10, 344, NULL, 'Vidutinis grįžtamo šilumnešio diferencinis slėgis per 5 minutes', 1721, 1, NULL, NULL),
	(7527, 331, 2, 10, 3, 0, 28, 9, 344, NULL, 'Vidutinis grįžtamo šilumnešio diferencinis slėgis per 4 minutes', 1721, 1, NULL, NULL),
	(7528, 331, 2, 9, 3, 0, 28, 8, 344, NULL, 'Vidutinis grįžtamo šilumnešio diferencinis slėgis per 3 minutes', 1721, 1, NULL, NULL),
	(7529, 331, 2, 2, 3, 0, 28, 2, 344, NULL, 'Vidutinis grįžtamo šilumnešio diferencinis slėgis per 2 minutes', 1721, 1, NULL, NULL),
	(7530, 331, 2, 1, 3, 0, 28, 1, 344, NULL, 'Vidutinis grįžtamo šilumnešio diferencinis slėgis per minutę', 1721, 1, NULL, NULL),
	(7531, 331, 2, 4, 3, 0, 28, 4, 344, NULL, 'Vidutinis grįžtamo šilumnešio diferencinis slėgis per valandą', 1721, 2, NULL, NULL),
	(7532, 331, 2, 3, 3, 0, 28, 3, 344, NULL, 'Vidutinis grįžtamo šilumnešio diferencinis slėgis per 30 minučių', 1721, 2, NULL, NULL),
	(7533, 331, 2, 14, 3, 0, 28, 13, 344, NULL, 'Vidutinis grįžtamo šilumnešio diferencinis slėgis per 20 minučių', 1721, 2, NULL, NULL),
	(7534, 331, 2, 13, 3, 0, 28, 12, 344, NULL, 'Vidutinis grįžtamo šilumnešio diferencinis slėgis per 15 minučių', 1721, 2, NULL, NULL),
	(7535, 331, 2, 5, 3, 0, 28, 5, 344, NULL, 'Vidutinis grįžtamo šilumnešio diferencinis slėgis per parą', 1721, 3, NULL, NULL),
	(7536, 331, 2, 6, 3, 0, 28, 6, 344, NULL, 'Vidutinis grįžtamo šilumnešio diferencinis slėgis per mėnesį', 1721, 4, NULL, NULL),
	(7537, 331, 2, 7, 1, 0, 28, 7, 344, NULL, 'Momentinis grįžtamo šilumnešio diferencinis slėgis', 1720, 6, NULL, NULL),
	(7538, 331, -4, 12, 3, 0, 28, 11, 344, NULL, 'Vidutinis pamaitinimo vandens diferencinis slėgis per 10 minučių', 1723, 1, NULL, NULL),
	(7539, 331, -4, 11, 3, 0, 28, 10, 344, NULL, 'Vidutinis pamaitinimo vandens diferencinis slėgis per 5 minutes', 1723, 1, NULL, NULL),
	(7540, 331, -4, 10, 3, 0, 28, 9, 344, NULL, 'Vidutinis pamaitinimo vandens diferencinis slėgis per 4 minutes', 1723, 1, NULL, NULL),
	(7541, 331, -4, 9, 3, 0, 28, 8, 344, NULL, 'Vidutinis pamaitinimo vandens diferencinis slėgis per 3 minutes', 1723, 1, NULL, NULL),
	(7542, 331, -4, 2, 3, 0, 28, 2, 344, NULL, 'Vidutinis pamaitinimo vandens diferencinis slėgis per 2 minutes', 1723, 1, NULL, NULL),
	(7543, 331, -4, 1, 3, 0, 28, 1, 344, NULL, 'Vidutinis pamaitinimo vandens diferencinis slėgis per minutę', 1723, 1, NULL, NULL),
	(7544, 331, -4, 4, 3, 0, 28, 4, 344, NULL, 'Vidutinis pamaitinimo vandens diferencinis slėgis per valandą', 1723, 2, NULL, NULL),
	(7545, 331, -4, 3, 3, 0, 28, 3, 344, NULL, 'Vidutinis pamaitinimo vandens diferencinis slėgis per 30 minučių', 1723, 2, NULL, NULL),
	(7546, 331, -4, 14, 3, 0, 28, 13, 344, NULL, 'Vidutinis pamaitinimo vandens diferencinis slėgis per 20 minučių', 1723, 2, NULL, NULL),
	(7547, 331, -4, 13, 3, 0, 28, 12, 344, NULL, 'Vidutinis pamaitinimo vandens diferencinis slėgis per 15 minučių', 1723, 2, NULL, NULL),
	(7548, 331, -4, 5, 3, 0, 28, 5, 344, NULL, 'Vidutinis pamaitinimo vandens diferencinis slėgis per parą', 1723, 3, NULL, NULL),
	(7549, 331, -4, 6, 3, 0, 28, 6, 344, NULL, 'Vidutinis pamaitinimo vandens diferencinis slėgis per mėnesį', 1723, 4, NULL, NULL),
	(7550, 331, -4, 7, 1, 0, 28, 7, 344, NULL, 'Momentinis pamaitinimo vandens diferencinis slėgis', 1722, 6, NULL, NULL),
	(7551, 329, 2, 12, 3, 0, 28, 11, 342, NULL, 'Vidutinis grįžtamo šilumnešio absoliutus slėgis per 10 minučių', 1725, 1, NULL, NULL),
	(7552, 329, 2, 11, 3, 0, 28, 10, 342, NULL, 'Vidutinis grįžtamo šilumnešio absoliutus slėgis per 5 minutes', 1725, 1, NULL, NULL),
	(7553, 329, 2, 10, 3, 0, 28, 9, 342, NULL, 'Vidutinis grįžtamo šilumnešio absoliutus slėgis per 4 minutes', 1725, 1, NULL, NULL),
	(7554, 329, 2, 9, 3, 0, 28, 8, 342, NULL, 'Vidutinis grįžtamo šilumnešio absoliutus slėgis per 3 minutes', 1725, 1, NULL, NULL),
	(7555, 329, 2, 2, 3, 0, 28, 2, 342, NULL, 'Vidutinis grįžtamo šilumnešio absoliutus slėgis per 2 minutes', 1725, 1, NULL, NULL),
	(7556, 329, 2, 1, 3, 0, 28, 1, 342, NULL, 'Vidutinis grįžtamo šilumnešio absoliutus slėgis per minutę', 1725, 1, NULL, NULL),
	(7557, 329, 2, 4, 3, 0, 28, 4, 342, NULL, 'Vidutinis grįžtamo šilumnešio absoliutus slėgis per valandą', 1725, 2, NULL, NULL),
	(7558, 329, 2, 3, 3, 0, 28, 3, 342, NULL, 'Vidutinis grįžtamo šilumnešio absoliutus slėgis per 30 minučių', 1725, 2, NULL, NULL),
	(7559, 329, 2, 14, 3, 0, 28, 13, 342, NULL, 'Vidutinis grįžtamo šilumnešio absoliutus slėgis per 20 minučių', 1725, 2, NULL, NULL),
	(7560, 329, 2, 13, 3, 0, 28, 12, 342, NULL, 'Vidutinis grįžtamo šilumnešio absoliutus slėgis per 15 minučių', 1725, 2, NULL, NULL),
	(7561, 329, 2, 5, 3, 0, 28, 5, 342, NULL, 'Vidutinis grįžtamo šilumnešio absoliutus slėgis per parą', 1725, 3, NULL, NULL),
	(7562, 329, 2, 6, 3, 0, 28, 6, 342, NULL, 'Vidutinis grįžtamo šilumnešio absoliutus slėgis per mėnesį', 1725, 4, NULL, NULL),
	(7563, 329, 2, 7, 1, 0, 28, 7, 342, NULL, 'Momentinis grįžtamo šilumnešio absoliutus slėgis', 1724, 6, NULL, NULL),
	(7564, 329, -4, 12, 3, 0, 28, 11, 342, NULL, 'Vidutinis pamaitinimo vandens absoliutus slėgis per 10 minučių', 1727, 1, NULL, NULL),
	(7565, 329, -4, 11, 3, 0, 28, 10, 342, NULL, 'Vidutinis pamaitinimo vandens absoliutus slėgis per 5 minutes', 1727, 1, NULL, NULL),
	(7566, 329, -4, 10, 3, 0, 28, 9, 342, NULL, 'Vidutinis pamaitinimo vandens absoliutus slėgis per 4 minutes', 1727, 1, NULL, NULL),
	(7567, 329, -4, 9, 3, 0, 28, 8, 342, NULL, 'Vidutinis pamaitinimo vandens absoliutus slėgis per 3 minutes', 1727, 1, NULL, NULL),
	(7568, 329, -4, 2, 3, 0, 28, 2, 342, NULL, 'Vidutinis pamaitinimo vandens absoliutus slėgis per 2 minutes', 1727, 1, NULL, NULL),
	(7569, 329, -4, 1, 3, 0, 28, 1, 342, NULL, 'Vidutinis pamaitinimo vandens absoliutus slėgis per minutę', 1727, 1, NULL, NULL),
	(7570, 329, -4, 4, 3, 0, 28, 4, 342, NULL, 'Vidutinis pamaitinimo vandens absoliutus slėgis per valandą', 1727, 2, NULL, NULL),
	(7571, 329, -4, 3, 3, 0, 28, 3, 342, NULL, 'Vidutinis pamaitinimo vandens absoliutus slėgis per 30 minučių', 1727, 2, NULL, NULL),
	(7572, 329, -4, 14, 3, 0, 28, 13, 342, NULL, 'Vidutinis pamaitinimo vandens absoliutus slėgis per 20 minučių', 1727, 2, NULL, NULL),
	(7573, 329, -4, 13, 3, 0, 28, 12, 342, NULL, 'Vidutinis pamaitinimo vandens absoliutus slėgis per 15 minučių', 1727, 2, NULL, NULL),
	(7574, 329, -4, 5, 3, 0, 28, 5, 342, NULL, 'Vidutinis pamaitinimo vandens absoliutus slėgis per parą', 1727, 3, NULL, NULL),
	(7575, 329, -4, 6, 3, 0, 28, 6, 342, NULL, 'Vidutinis pamaitinimo vandens absoliutus slėgis per mėnesį', 1727, 4, NULL, NULL),
	(7576, 329, -4, 7, 1, 0, 28, 7, 342, NULL, 'Momentinis pamaitinimo vandens absoliutus slėgis', 1726, 6, NULL, NULL),
	(7577, 1, 0, 7, 1, 0, 1, 1, 13, NULL, 'Momentinė aktyvinė galia, fiksuojama kas minutę', 80, 1, NULL, NULL),
	(7578, 1, 0, 7, 1, 0, 1, 10, 13, NULL, 'Momentinė aktyvinė galia, fiksuojama kas 5 minutes', 80, 1, NULL, NULL),
	(7579, 1, 0, 7, 1, 0, 1, 5, 13, NULL, 'Momentinė aktyvinė galia, fiksuojama kas parą', 80, 3, NULL, NULL),
	(7580, 3, 0, 7, 1, 0, 3, 1, 16, NULL, 'Momentinė reaktyvinė galia, fiksuojama kas minutę', 81, 1, NULL, NULL),
	(7581, 3, 0, 7, 1, 0, 3, 10, 16, NULL, 'Momentinė reaktyvinė galia, fiksuojama kas 5 minutes', 81, 1, NULL, NULL),
	(7582, 3, 0, 7, 1, 0, 3, 5, 16, NULL, 'Momentinė reaktyvinė galia, fiksuojama kas parą', 81, 3, NULL, NULL),
	(7583, 3, 1, 7, 1, 0, 3, 1, 16, NULL, 'Momentinė Q+ galia, fiksuojama kas minutę', 3314, 1, NULL, NULL),
	(7584, 3, 1, 7, 1, 0, 3, 10, 16, NULL, 'Momentinė Q+ galia, fiksuojama kas 5 minutes', 3314, 1, NULL, NULL),
	(7585, 3, 2, 7, 1, 0, 3, 1, 16, NULL, 'Momentinė Q- galia, fiksuojama kas minutę', 3315, 1, NULL, NULL),
	(7586, 3, 2, 7, 1, 0, 3, 10, 16, NULL, 'Momentinė Q- galia, fiksuojama kas 5 minutes', 3315, 1, NULL, NULL),
	(7587, 5, 0, 7, 1, 0, 5, 1, 17, NULL, 'Momentinis srovės stiprumas L1 fazėje, fiksuojamas kas minutę', 53, 1, NULL, NULL),
	(7588, 5, 0, 7, 1, 0, 5, 10, 17, NULL, 'Momentinis srovės stiprumas L1 fazėje, fiksuojamas kas 5 minutes', 53, 1, NULL, NULL),
	(7589, 6, 0, 7, 1, 0, 6, 1, 18, NULL, 'Momentinė įtampa L1 fazėje, fiksuojama kas minutę', 54, 1, NULL, NULL),
	(7590, 6, 0, 7, 1, 0, 6, 10, 18, NULL, 'Momentinė įtampa L1 fazėje, fiksuojama kas 5 minutes', 54, 1, NULL, NULL),
	(7591, 7, 0, 7, 1, 0, 5, 1, 19, NULL, 'Momentinis srovės stiprumas L2 fazėje, fiksuojamas kas minutę', 55, 1, NULL, NULL),
	(7592, 7, 0, 7, 1, 0, 5, 10, 19, NULL, 'Momentinis srovės stiprumas L2 fazėje, fiksuojamas kas 5 minutes', 55, 1, NULL, NULL),
	(7593, 8, 0, 7, 1, 0, 6, 1, 20, NULL, 'Momentinė įtampa L2 fazėje, fiksuojama kas minutę', 56, 1, NULL, NULL),
	(7594, 8, 0, 7, 1, 0, 6, 10, 20, NULL, 'Momentinė įtampa L2 fazėje, fiksuojama kas 5 minutes', 56, 1, NULL, NULL),
	(7595, 9, 0, 7, 1, 0, 5, 1, 21, NULL, 'Momentinis srovės stiprumas L3 fazėje, fiksuojamas kas minutę', 57, 1, NULL, NULL),
	(7596, 9, 0, 7, 1, 0, 5, 10, 21, NULL, 'Momentinis srovės stiprumas L3 fazėje, fiksuojamas kas 5 minutes', 57, 1, NULL, NULL),
	(7597, 10, 0, 7, 1, 0, 6, 1, 22, NULL, 'Momentinė įtampa L3 fazėje, fiksuojama kas minutę', 58, 1, NULL, NULL),
	(7598, 10, 0, 7, 1, 0, 6, 10, 22, NULL, 'Momentinė įtampa L3 fazėje, fiksuojama kas 5 minutes', 58, 1, NULL, NULL),
	(7599, 11, 0, 7, 1, 0, 6, 1, 23, NULL, 'Momentinė linijinė įtampa L1 fazėje, fiksuojama kas minutę', 59, 1, NULL, NULL),
	(7600, 11, 0, 7, 1, 0, 6, 8, 23, NULL, 'Momentinė linijinė įtampa L1 fazėje, fiksuojama kas 3 minutes', 59, 1, NULL, NULL),
	(7601, 11, 0, 7, 1, 0, 6, 10, 23, NULL, 'Momentinė linijinė įtampa L1 fazėje, fiksuojama kas 5 minutes', 59, 1, NULL, NULL),
	(7602, 11, 0, 7, 1, 0, 6, 12, 23, NULL, 'Momentinė linijinė įtampa L1 fazėje, fiksuojama kas 15 minučių', 59, 2, NULL, NULL),
	(7603, 11, 0, 7, 1, 0, 6, 3, 23, NULL, 'Momentinė linijinė įtampa L1 fazėje, fiksuojama kas 30 minučių', 59, 2, NULL, NULL),
	(7604, 11, 0, 7, 1, 0, 6, 4, 23, NULL, 'Momentinė linijinė įtampa L1 fazėje, fiksuojama kas valandą', 59, 2, NULL, NULL),
	(7605, 11, 0, 7, 1, 0, 6, 5, 23, NULL, 'Momentinė linijinė įtampa L1 fazėje, fiksuojama kas parą', 59, 3, NULL, NULL),
	(7606, 12, 0, 7, 1, 0, 6, 1, 24, NULL, 'Momentinė linijinė įtampa L2 fazėje, fiksuojama kas minutę', 60, 1, NULL, NULL),
	(7607, 12, 0, 7, 1, 0, 6, 8, 24, NULL, 'Momentinė linijinė įtampa L2 fazėje, fiksuojama kas 3 minutes', 60, 1, NULL, NULL),
	(7608, 12, 0, 7, 1, 0, 6, 10, 24, NULL, 'Momentinė linijinė įtampa L2 fazėje, fiksuojama kas 5 minutes', 60, 1, NULL, NULL),
	(7609, 12, 0, 7, 1, 0, 6, 12, 24, NULL, 'Momentinė linijinė įtampa L2 fazėje, fiksuojama kas 15 minučių', 60, 2, NULL, NULL),
	(7610, 12, 0, 7, 1, 0, 6, 3, 24, NULL, 'Momentinė linijinė įtampa L2 fazėje, fiksuojama kas 30 minučių', 60, 2, NULL, NULL),
	(7611, 12, 0, 7, 1, 0, 6, 4, 24, NULL, 'Momentinė linijinė įtampa L2 fazėje, fiksuojama kas valandą', 60, 2, NULL, NULL),
	(7612, 12, 0, 7, 1, 0, 6, 5, 24, NULL, 'Momentinė linijinė įtampa L2 fazėje, fiksuojama kas parą', 60, 3, NULL, NULL),
	(7613, 13, 0, 7, 1, 0, 6, 1, 25, NULL, 'Momentinė linijinė įtampa L3 fazėje, fiksuojama kas minutę', 61, 1, NULL, NULL),
	(7614, 13, 0, 7, 1, 0, 6, 8, 25, NULL, 'Momentinė linijinė įtampa L3 fazėje, fiksuojama kas 3 minutes', 61, 1, NULL, NULL),
	(7615, 13, 0, 7, 1, 0, 6, 10, 25, NULL, 'Momentinė linijinė įtampa L3 fazėje, fiksuojama kas 5 minutes', 61, 1, NULL, NULL),
	(7616, 13, 0, 7, 1, 0, 6, 12, 25, NULL, 'Momentinė linijinė įtampa L3 fazėje, fiksuojama kas 15 minučių', 61, 2, NULL, NULL),
	(7617, 13, 0, 7, 1, 0, 6, 3, 25, NULL, 'Momentinė linijinė įtampa L3 fazėje, fiksuojama kas 30 minučių', 61, 2, NULL, NULL),
	(7618, 13, 0, 7, 1, 0, 6, 4, 25, NULL, 'Momentinė linijinė įtampa L3 fazėje, fiksuojama kas valandą', 61, 2, NULL, NULL),
	(7619, 13, 0, 7, 1, 0, 6, 5, 25, NULL, 'Momentinė linijinė įtampa L3 fazėje, fiksuojama kas parą', 61, 3, NULL, NULL),
	(7620, 14, 0, 7, 1, 0, 1, 1, 26, NULL, 'Momentinė aktyvinė galia L1 fazėje, fiksuojama kas minutę', 62, 1, NULL, NULL),
	(7621, 14, 0, 7, 1, 0, 1, 10, 26, NULL, 'Momentinė aktyvinė galia L1 fazėje, fiksuojama kas 5 minutes', 62, 1, NULL, NULL),
	(7622, 14, 0, 7, 1, 0, 1, 5, 26, NULL, 'Momentinė aktyvinė galia L1 fazėje, fiksuojama kas parą', 62, 3, NULL, NULL),
	(7623, 14, 1, 7, 1, 0, 1, 1, 26, NULL, 'Momentinė P+ galia L1 fazėje, fiksuojama kas minutę', 3330, 1, NULL, NULL),
	(7624, 14, 1, 7, 1, 0, 1, 10, 26, NULL, 'Momentinė P+ galia L1 fazėje, fiksuojama kas 5 minutes', 3330, 1, NULL, NULL),
	(7625, 14, 2, 7, 1, 0, 1, 1, 26, NULL, 'Momentinė P- galia L1 fazėje, fiksuojama kas minutę', 3333, 1, NULL, NULL),
	(7626, 14, 2, 7, 1, 0, 1, 8, 26, NULL, 'Momentinė P- galia L1 fazėje, fiksuojama kas 3 minutes', 3333, 1, NULL, NULL),
	(7627, 14, 2, 7, 1, 0, 1, 10, 26, NULL, 'Momentinė P- galia L1 fazėje, fiksuojama kas 5 minutes', 3333, 1, NULL, NULL),
	(7628, 14, 2, 7, 1, 0, 1, 12, 26, NULL, 'Momentinė P- galia L1 fazėje, fiksuojama kas 15 minučių', 3333, 2, NULL, NULL),
	(7629, 14, 2, 7, 1, 0, 1, 3, 26, NULL, 'Momentinė P- galia L1 fazėje, fiksuojama kas 30 minučių', 3333, 2, NULL, NULL),
	(7630, 14, 2, 7, 1, 0, 1, 4, 26, NULL, 'Momentinė P- galia L1 fazėje, fiksuojama kas valandą', 3333, 2, NULL, NULL),
	(7631, 14, 2, 7, 1, 0, 1, 5, 26, NULL, 'Momentinė P- galia L1 fazėje, fiksuojama kas parą', 3333, 3, NULL, NULL),
	(7632, 15, 0, 7, 1, 0, 1, 1, 27, NULL, 'Momentinė aktyvinė galia L2 fazėje, fiksuojama kas minutę', 63, 1, NULL, NULL),
	(7633, 15, 0, 7, 1, 0, 1, 10, 27, NULL, 'Momentinė aktyvinė galia L2 fazėje, fiksuojama kas 5 minutes', 63, 1, NULL, NULL),
	(7634, 15, 0, 7, 1, 0, 1, 5, 27, NULL, 'Momentinė aktyvinė galia L2 fazėje, fiksuojama kas parą', 63, 3, NULL, NULL),
	(7635, 15, 1, 7, 1, 0, 1, 1, 27, NULL, 'Momentinė P+ galia L2 fazėje, fiksuojama kas minutę', 3331, 1, NULL, NULL),
	(7636, 15, 1, 7, 1, 0, 1, 10, 27, NULL, 'Momentinė P+ galia L2 fazėje, fiksuojama kas 5 minutes', 3331, 1, NULL, NULL),
	(7637, 15, 2, 7, 1, 0, 1, 1, 27, NULL, 'Momentinė P- galia L2 fazėje, fiksuojama kas minutę', 3334, 1, NULL, NULL),
	(7638, 15, 2, 7, 1, 0, 1, 8, 27, NULL, 'Momentinė P- galia L2 fazėje, fiksuojama kas 3 minutes', 3334, 1, NULL, NULL),
	(7639, 15, 2, 7, 1, 0, 1, 10, 27, NULL, 'Momentinė P- galia L2 fazėje, fiksuojama kas 5 minutes', 3334, 1, NULL, NULL),
	(7640, 15, 2, 7, 1, 0, 1, 12, 27, NULL, 'Momentinė P- galia L2 fazėje, fiksuojama kas 15 minučių', 3334, 2, NULL, NULL),
	(7641, 15, 2, 7, 1, 0, 1, 3, 27, NULL, 'Momentinė P- galia L2 fazėje, fiksuojama kas 30 minučių', 3334, 2, NULL, NULL),
	(7642, 15, 2, 7, 1, 0, 1, 4, 27, NULL, 'Momentinė P- galia L2 fazėje, fiksuojama kas valandą', 3334, 2, NULL, NULL),
	(7643, 15, 2, 7, 1, 0, 1, 5, 27, NULL, 'Momentinė P- galia L2 fazėje, fiksuojama kas parą', 3334, 3, NULL, NULL),
	(7644, 16, 0, 7, 1, 0, 1, 1, 28, NULL, 'Momentinė aktyvinė galia L3 fazėje, fiksuojama kas minutę', 64, 1, NULL, NULL),
	(7645, 16, 0, 7, 1, 0, 1, 10, 28, NULL, 'Momentinė aktyvinė galia L3 fazėje, fiksuojama kas 5 minutes', 64, 1, NULL, NULL),
	(7646, 16, 0, 7, 1, 0, 1, 5, 28, NULL, 'Momentinė aktyvinė galia L3 fazėje, fiksuojama kas parą', 64, 3, NULL, NULL),
	(7647, 16, 1, 7, 1, 0, 1, 1, 28, NULL, 'Momentinė P+ galia L3 fazėje, fiksuojama kas minutę', 3332, 1, NULL, NULL),
	(7648, 16, 1, 7, 1, 0, 1, 10, 28, NULL, 'Momentinė P+ galia L3 fazėje, fiksuojama kas 5 minutes', 3332, 1, NULL, NULL),
	(7649, 16, 2, 7, 1, 0, 1, 1, 28, NULL, 'Momentinė P- galia L3 fazėje, fiksuojama kas minutę', 3335, 1, NULL, NULL),
	(7650, 16, 2, 7, 1, 0, 1, 8, 28, NULL, 'Momentinė P- galia L3 fazėje, fiksuojama kas 3 minutes', 3335, 1, NULL, NULL),
	(7651, 16, 2, 7, 1, 0, 1, 10, 28, NULL, 'Momentinė P- galia L3 fazėje, fiksuojama kas 5 minutes', 3335, 1, NULL, NULL),
	(7652, 16, 2, 7, 1, 0, 1, 12, 28, NULL, 'Momentinė P- galia L3 fazėje, fiksuojama kas 15 minučių', 3335, 2, NULL, NULL),
	(7653, 16, 2, 7, 1, 0, 1, 3, 28, NULL, 'Momentinė P- galia L3 fazėje, fiksuojama kas 30 minučių', 3335, 2, NULL, NULL),
	(7654, 16, 2, 7, 1, 0, 1, 4, 28, NULL, 'Momentinė P- galia L3 fazėje, fiksuojama kas valandą', 3335, 2, NULL, NULL),
	(7655, 16, 2, 7, 1, 0, 1, 5, 28, NULL, 'Momentinė P- galia L3 fazėje, fiksuojama kas parą', 3335, 3, NULL, NULL),
	(7656, 17, 0, 7, 1, 0, 3, 1, 29, NULL, 'Momentinė reaktyvinė galia L1 fazėje, fiksuojama kas minutę', 65, 1, NULL, NULL),
	(7657, 17, 0, 7, 1, 0, 3, 10, 29, NULL, 'Momentinė reaktyvinė galia L1 fazėje, fiksuojama kas 5 minutes', 65, 1, NULL, NULL),
	(7658, 17, 1, 7, 1, 0, 3, 1, 29, NULL, 'Momentinė Q+ galia L1 fazėje, fiksuojama kas minutę', 3336, 1, NULL, NULL),
	(7659, 17, 1, 7, 1, 0, 3, 8, 29, NULL, 'Momentinė Q+ galia L1 fazėje, fiksuojama kas 3 minutes', 3336, 1, NULL, NULL),
	(7660, 17, 1, 7, 1, 0, 3, 10, 29, NULL, 'Momentinė Q+ galia L1 fazėje, fiksuojama kas 5 minutes', 3336, 1, NULL, NULL),
	(7661, 17, 1, 7, 1, 0, 3, 12, 29, NULL, 'Momentinė Q+ galia L1 fazėje, fiksuojama kas 15 minučių', 3336, 2, NULL, NULL),
	(7662, 17, 1, 7, 1, 0, 3, 3, 29, NULL, 'Momentinė Q+ galia L1 fazėje, fiksuojama kas 30 minučių', 3336, 2, NULL, NULL),
	(7663, 17, 1, 7, 1, 0, 3, 4, 29, NULL, 'Momentinė Q+ galia L1 fazėje, fiksuojama kas valandą', 3336, 2, NULL, NULL),
	(7664, 17, 1, 7, 1, 0, 3, 5, 29, NULL, 'Momentinė Q+ galia L1 fazėje, fiksuojama kas parą', 3336, 3, NULL, NULL),
	(7665, 17, 2, 7, 1, 0, 3, 1, 29, NULL, 'Momentinė Q- galia L1 fazėje, fiksuojama kas minutę', 3339, 1, NULL, NULL),
	(7666, 17, 2, 7, 1, 0, 3, 8, 29, NULL, 'Momentinė Q- galia L1 fazėje, fiksuojama kas 3 minutes', 3339, 1, NULL, NULL),
	(7667, 17, 2, 7, 1, 0, 3, 10, 29, NULL, 'Momentinė Q- galia L1 fazėje, fiksuojama kas 5 minutes', 3339, 1, NULL, NULL),
	(7668, 17, 2, 7, 1, 0, 3, 12, 29, NULL, 'Momentinė Q- galia L1 fazėje, fiksuojama kas 15 minučių', 3339, 2, NULL, NULL),
	(7669, 17, 2, 7, 1, 0, 3, 3, 29, NULL, 'Momentinė Q- galia L1 fazėje, fiksuojama kas 30 minučių', 3339, 2, NULL, NULL),
	(7670, 17, 2, 7, 1, 0, 3, 4, 29, NULL, 'Momentinė Q- galia L1 fazėje, fiksuojama kas valandą', 3339, 2, NULL, NULL),
	(7671, 17, 2, 7, 1, 0, 3, 5, 29, NULL, 'Momentinė Q- galia L1 fazėje, fiksuojama kas parą', 3339, 3, NULL, NULL),
	(7672, 18, 0, 7, 1, 0, 3, 1, 30, NULL, 'Momentinė reaktyvinė galia L2 fazėje, fiksuojama kas minutę', 66, 1, NULL, NULL),
	(7673, 18, 0, 7, 1, 0, 3, 10, 30, NULL, 'Momentinė reaktyvinė galia L2 fazėje, fiksuojama kas 5 minutes', 66, 1, NULL, NULL),
	(7674, 18, 1, 7, 1, 0, 3, 1, 30, NULL, 'Momentinė Q+ galia L2 fazėje, fiksuojama kas minutę', 3337, 1, NULL, NULL),
	(7675, 18, 1, 7, 1, 0, 3, 8, 30, NULL, 'Momentinė Q+ galia L2 fazėje, fiksuojama kas 3 minutes', 3337, 1, NULL, NULL),
	(7676, 18, 1, 7, 1, 0, 3, 10, 30, NULL, 'Momentinė Q+ galia L2 fazėje, fiksuojama kas 5 minutes', 3337, 1, NULL, NULL),
	(7677, 18, 1, 7, 1, 0, 3, 12, 30, NULL, 'Momentinė Q+ galia L2 fazėje, fiksuojama kas 15 minučių', 3337, 2, NULL, NULL),
	(7678, 18, 1, 7, 1, 0, 3, 3, 30, NULL, 'Momentinė Q+ galia L2 fazėje, fiksuojama kas 30 minučių', 3337, 2, NULL, NULL),
	(7679, 18, 1, 7, 1, 0, 3, 4, 30, NULL, 'Momentinė Q+ galia L2 fazėje, fiksuojama kas valandą', 3337, 2, NULL, NULL),
	(7680, 18, 1, 7, 1, 0, 3, 5, 30, NULL, 'Momentinė Q+ galia L2 fazėje, fiksuojama kas parą', 3337, 3, NULL, NULL),
	(7681, 18, 2, 7, 1, 0, 3, 1, 30, NULL, 'Momentinė Q- galia L2 fazėje, fiksuojama kas minutę', 3340, 1, NULL, NULL),
	(7682, 18, 2, 7, 1, 0, 3, 8, 30, NULL, 'Momentinė Q- galia L2 fazėje, fiksuojama kas 3 minutes', 3340, 1, NULL, NULL),
	(7683, 18, 2, 7, 1, 0, 3, 10, 30, NULL, 'Momentinė Q- galia L2 fazėje, fiksuojama kas 5 minutes', 3340, 1, NULL, NULL),
	(7684, 18, 2, 7, 1, 0, 3, 12, 30, NULL, 'Momentinė Q- galia L2 fazėje, fiksuojama kas 15 minučių', 3340, 2, NULL, NULL),
	(7685, 18, 2, 7, 1, 0, 3, 3, 30, NULL, 'Momentinė Q- galia L2 fazėje, fiksuojama kas 30 minučių', 3340, 2, NULL, NULL),
	(7686, 18, 2, 7, 1, 0, 3, 4, 30, NULL, 'Momentinė Q- galia L2 fazėje, fiksuojama kas valandą', 3340, 2, NULL, NULL),
	(7687, 18, 2, 7, 1, 0, 3, 5, 30, NULL, 'Momentinė Q- galia L2 fazėje, fiksuojama kas parą', 3340, 3, NULL, NULL),
	(7688, 19, 0, 7, 1, 0, 3, 1, 31, NULL, 'Momentinė reaktyvinė galia L3 fazėje, fiksuojama kas minutę', 67, 1, NULL, NULL),
	(7689, 19, 0, 7, 1, 0, 3, 10, 31, NULL, 'Momentinė reaktyvinė galia L3 fazėje, fiksuojama kas 5 minutes', 67, 1, NULL, NULL),
	(7690, 19, 1, 7, 1, 0, 3, 1, 31, NULL, 'Momentinė Q+ galia L3 fazėje, fiksuojama kas minutę', 3338, 1, NULL, NULL),
	(7691, 19, 1, 7, 1, 0, 3, 8, 31, NULL, 'Momentinė Q+ galia L3 fazėje, fiksuojama kas 3 minutes', 3338, 1, NULL, NULL),
	(7692, 19, 1, 7, 1, 0, 3, 10, 31, NULL, 'Momentinė Q+ galia L3 fazėje, fiksuojama kas 5 minutes', 3338, 1, NULL, NULL),
	(7693, 19, 1, 7, 1, 0, 3, 12, 31, NULL, 'Momentinė Q+ galia L3 fazėje, fiksuojama kas 15 minučių', 3338, 2, NULL, NULL),
	(7694, 19, 1, 7, 1, 0, 3, 3, 31, NULL, 'Momentinė Q+ galia L3 fazėje, fiksuojama kas 30 minučių', 3338, 2, NULL, NULL),
	(7695, 19, 1, 7, 1, 0, 3, 4, 31, NULL, 'Momentinė Q+ galia L3 fazėje, fiksuojama kas valandą', 3338, 2, NULL, NULL),
	(7696, 19, 1, 7, 1, 0, 3, 5, 31, NULL, 'Momentinė Q+ galia L3 fazėje, fiksuojama kas parą', 3338, 3, NULL, NULL),
	(7697, 19, 2, 7, 1, 0, 3, 1, 31, NULL, 'Momentinė Q- galia L3 fazėje, fiksuojama kas minutę', 3341, 1, NULL, NULL),
	(7698, 19, 2, 7, 1, 0, 3, 8, 31, NULL, 'Momentinė Q- galia L3 fazėje, fiksuojama kas 3 minutes', 3341, 1, NULL, NULL),
	(7699, 19, 2, 7, 1, 0, 3, 10, 31, NULL, 'Momentinė Q- galia L3 fazėje, fiksuojama kas 5 minutes', 3341, 1, NULL, NULL),
	(7700, 19, 2, 7, 1, 0, 3, 12, 31, NULL, 'Momentinė Q- galia L3 fazėje, fiksuojama kas 15 minučių', 3341, 2, NULL, NULL),
	(7701, 19, 2, 7, 1, 0, 3, 3, 31, NULL, 'Momentinė Q- galia L3 fazėje, fiksuojama kas 30 minučių', 3341, 2, NULL, NULL),
	(7702, 19, 2, 7, 1, 0, 3, 4, 31, NULL, 'Momentinė Q- galia L3 fazėje, fiksuojama kas valandą', 3341, 2, NULL, NULL),
	(7703, 19, 2, 7, 1, 0, 3, 5, 31, NULL, 'Momentinė Q- galia L3 fazėje, fiksuojama kas parą', 3341, 3, NULL, NULL),
	(7704, 20, 0, 7, 1, 0, 7, 1, 32, NULL, 'Momentinė pilnoji galia L1 fazėje, fiksuojama kas minutę', 68, 1, NULL, NULL),
	(7705, 20, 0, 7, 1, 0, 7, 10, 32, NULL, 'Momentinė pilnoji galia L1 fazėje, fiksuojama kas 5 minutes', 68, 1, NULL, NULL),
	(7706, 20, 0, 7, 1, 0, 7, 5, 32, NULL, 'Momentinė pilnoji galia L1 fazėje, fiksuojama kas parą', 68, 3, NULL, NULL),
	(7707, 20, 1, 7, 1, 0, 7, 1, 32, NULL, 'Momentinė S+ galia L1 fazėje, fiksuojama kas minutę', 3342, 1, NULL, NULL),
	(7708, 20, 1, 7, 1, 0, 7, 8, 32, NULL, 'Momentinė S+ galia L1 fazėje, fiksuojama kas 3 minutes', 3342, 1, NULL, NULL),
	(7709, 20, 1, 7, 1, 0, 7, 10, 32, NULL, 'Momentinė S+ galia L1 fazėje, fiksuojama kas 5 minutes', 3342, 1, NULL, NULL),
	(7710, 20, 1, 7, 1, 0, 7, 12, 32, NULL, 'Momentinė S+ galia L1 fazėje, fiksuojama kas 15 minučių', 3342, 2, NULL, NULL),
	(7711, 20, 1, 7, 1, 0, 7, 3, 32, NULL, 'Momentinė S+ galia L1 fazėje, fiksuojama kas 30 minučių', 3342, 2, NULL, NULL),
	(7712, 20, 1, 7, 1, 0, 7, 4, 32, NULL, 'Momentinė S+ galia L1 fazėje, fiksuojama kas valandą', 3342, 2, NULL, NULL),
	(7713, 20, 1, 7, 1, 0, 7, 5, 32, NULL, 'Momentinė S+ galia L1 fazėje, fiksuojama kas parą', 3342, 3, NULL, NULL),
	(7714, 20, 2, 7, 1, 0, 7, 1, 32, NULL, 'Momentinė S- galia L1 fazėje, fiksuojama kas minutę', 3345, 1, NULL, NULL),
	(7715, 20, 2, 7, 1, 0, 7, 8, 32, NULL, 'Momentinė S- galia L1 fazėje, fiksuojama kas 3 minutes', 3345, 1, NULL, NULL),
	(7716, 20, 2, 7, 1, 0, 7, 10, 32, NULL, 'Momentinė S- galia L1 fazėje, fiksuojama kas 5 minutes', 3345, 1, NULL, NULL),
	(7717, 20, 2, 7, 1, 0, 7, 12, 32, NULL, 'Momentinė S- galia L1 fazėje, fiksuojama kas 15 minučių', 3345, 2, NULL, NULL),
	(7718, 20, 2, 7, 1, 0, 7, 3, 32, NULL, 'Momentinė S- galia L1 fazėje, fiksuojama kas 30 minučių', 3345, 2, NULL, NULL),
	(7719, 20, 2, 7, 1, 0, 7, 4, 32, NULL, 'Momentinė S- galia L1 fazėje, fiksuojama kas valandą', 3345, 2, NULL, NULL),
	(7720, 20, 2, 7, 1, 0, 7, 5, 32, NULL, 'Momentinė S- galia L1 fazėje, fiksuojama kas parą', 3345, 3, NULL, NULL),
	(7721, 21, 0, 7, 1, 0, 7, 1, 33, NULL, 'Momentinė pilnoji galia L2 fazėje, fiksuojama kas minutę', 69, 1, NULL, NULL),
	(7722, 21, 0, 7, 1, 0, 7, 10, 33, NULL, 'Momentinė pilnoji galia L2 fazėje, fiksuojama kas 5 minutes', 69, 1, NULL, NULL),
	(7723, 21, 0, 7, 1, 0, 7, 5, 33, NULL, 'Momentinė pilnoji galia L2 fazėje, fiksuojama kas parą', 69, 3, NULL, NULL),
	(7724, 21, 1, 7, 1, 0, 7, 1, 33, NULL, 'Momentinė S+ galia L2 fazėje, fiksuojama kas minutę', 3343, 1, NULL, NULL),
	(7725, 21, 1, 7, 1, 0, 7, 8, 33, NULL, 'Momentinė S+ galia L2 fazėje, fiksuojama kas 3 minutes', 3343, 1, NULL, NULL),
	(7726, 21, 1, 7, 1, 0, 7, 10, 33, NULL, 'Momentinė S+ galia L2 fazėje, fiksuojama kas 5 minutes', 3343, 1, NULL, NULL),
	(7727, 21, 1, 7, 1, 0, 7, 12, 33, NULL, 'Momentinė S+ galia L2 fazėje, fiksuojama kas 15 minučių', 3343, 2, NULL, NULL),
	(7728, 21, 1, 7, 1, 0, 7, 3, 33, NULL, 'Momentinė S+ galia L2 fazėje, fiksuojama kas 30 minučių', 3343, 2, NULL, NULL),
	(7729, 21, 1, 7, 1, 0, 7, 4, 33, NULL, 'Momentinė S+ galia L2 fazėje, fiksuojama kas valandą', 3343, 2, NULL, NULL),
	(7730, 21, 1, 7, 1, 0, 7, 5, 33, NULL, 'Momentinė S+ galia L2 fazėje, fiksuojama kas parą', 3343, 3, NULL, NULL),
	(7731, 21, 2, 7, 1, 0, 7, 1, 33, NULL, 'Momentinė S- galia L2 fazėje, fiksuojama kas minutę', 3346, 1, NULL, NULL),
	(7732, 21, 2, 7, 1, 0, 7, 8, 33, NULL, 'Momentinė S- galia L2 fazėje, fiksuojama kas 3 minutes', 3346, 1, NULL, NULL),
	(7733, 21, 2, 7, 1, 0, 7, 10, 33, NULL, 'Momentinė S- galia L2 fazėje, fiksuojama kas 5 minutes', 3346, 1, NULL, NULL),
	(7734, 21, 2, 7, 1, 0, 7, 12, 33, NULL, 'Momentinė S- galia L2 fazėje, fiksuojama kas 15 minučių', 3346, 2, NULL, NULL),
	(7735, 21, 2, 7, 1, 0, 7, 3, 33, NULL, 'Momentinė S- galia L2 fazėje, fiksuojama kas 30 minučių', 3346, 2, NULL, NULL),
	(7736, 21, 2, 7, 1, 0, 7, 4, 33, NULL, 'Momentinė S- galia L2 fazėje, fiksuojama kas valandą', 3346, 2, NULL, NULL),
	(7737, 21, 2, 7, 1, 0, 7, 5, 33, NULL, 'Momentinė S- galia L2 fazėje, fiksuojama kas parą', 3346, 3, NULL, NULL),
	(7738, 22, 0, 7, 1, 0, 7, 1, 34, NULL, 'Momentinė pilnoji galia L3 fazėje, fiksuojama kas minutę', 70, 1, NULL, NULL),
	(7739, 22, 0, 7, 1, 0, 7, 10, 34, NULL, 'Momentinė pilnoji galia L3 fazėje, fiksuojama kas 5 minutes', 70, 1, NULL, NULL),
	(7740, 22, 0, 7, 1, 0, 7, 5, 34, NULL, 'Momentinė pilnoji galia L3 fazėje, fiksuojama kas parą', 70, 3, NULL, NULL),
	(7741, 22, 1, 7, 1, 0, 7, 1, 34, NULL, 'Momentinė S+ galia L3 fazėje, fiksuojama kas minutę', 3344, 1, NULL, NULL),
	(7742, 22, 1, 7, 1, 0, 7, 8, 34, NULL, 'Momentinė S+ galia L3 fazėje, fiksuojama kas 3 minutes', 3344, 1, NULL, NULL),
	(7743, 22, 1, 7, 1, 0, 7, 10, 34, NULL, 'Momentinė S+ galia L3 fazėje, fiksuojama kas 5 minutes', 3344, 1, NULL, NULL),
	(7744, 22, 1, 7, 1, 0, 7, 12, 34, NULL, 'Momentinė S+ galia L3 fazėje, fiksuojama kas 15 minučių', 3344, 2, NULL, NULL),
	(7745, 22, 1, 7, 1, 0, 7, 3, 34, NULL, 'Momentinė S+ galia L3 fazėje, fiksuojama kas 30 minučių', 3344, 2, NULL, NULL),
	(7746, 22, 1, 7, 1, 0, 7, 4, 34, NULL, 'Momentinė S+ galia L3 fazėje, fiksuojama kas valandą', 3344, 2, NULL, NULL),
	(7747, 22, 1, 7, 1, 0, 7, 5, 34, NULL, 'Momentinė S+ galia L3 fazėje, fiksuojama kas parą', 3344, 3, NULL, NULL),
	(7748, 22, 2, 7, 1, 0, 7, 1, 34, NULL, 'Momentinė S- galia L3 fazėje, fiksuojama kas minutę', 3347, 1, NULL, NULL),
	(7749, 22, 2, 7, 1, 0, 7, 8, 34, NULL, 'Momentinė S- galia L3 fazėje, fiksuojama kas 3 minutes', 3347, 1, NULL, NULL),
	(7750, 22, 2, 7, 1, 0, 7, 10, 34, NULL, 'Momentinė S- galia L3 fazėje, fiksuojama kas 5 minutes', 3347, 1, NULL, NULL),
	(7751, 22, 2, 7, 1, 0, 7, 12, 34, NULL, 'Momentinė S- galia L3 fazėje, fiksuojama kas 15 minučių', 3347, 2, NULL, NULL),
	(7752, 22, 2, 7, 1, 0, 7, 3, 34, NULL, 'Momentinė S- galia L3 fazėje, fiksuojama kas 30 minučių', 3347, 2, NULL, NULL),
	(7753, 22, 2, 7, 1, 0, 7, 4, 34, NULL, 'Momentinė S- galia L3 fazėje, fiksuojama kas valandą', 3347, 2, NULL, NULL),
	(7754, 22, 2, 7, 1, 0, 7, 5, 34, NULL, 'Momentinė S- galia L3 fazėje, fiksuojama kas parą', 3347, 3, NULL, NULL),
	(7755, 23, 0, 7, 1, 0, 0, 1, 35, NULL, 'Momentinė cos(fi) reikšmė L1 fazėje, fiksuojama kas minutę', 71, 1, NULL, NULL),
	(7756, 23, 0, 7, 1, 0, 0, 8, 35, NULL, 'Momentinė cos(fi) reikšmė L1 fazėje, fiksuojama kas 3 minutes', 71, 1, NULL, NULL),
	(7757, 23, 0, 7, 1, 0, 0, 10, 35, NULL, 'Momentinė cos(fi) reikšmė L1 fazėje, fiksuojama kas 5 minutes', 71, 1, NULL, NULL),
	(7758, 23, 0, 7, 1, 0, 0, 12, 35, NULL, 'Momentinė cos(fi) reikšmė L1 fazėje, fiksuojama kas 15 minučių', 71, 2, NULL, NULL),
	(7759, 23, 0, 7, 1, 0, 0, 3, 35, NULL, 'Momentinė cos(fi) reikšmė L1 fazėje, fiksuojama kas 30 minučių', 71, 2, NULL, NULL),
	(7760, 23, 0, 7, 1, 0, 0, 4, 35, NULL, 'Momentinė cos(fi) reikšmė L1 fazėje, fiksuojama kas valandą', 71, 2, NULL, NULL),
	(7761, 23, 0, 7, 1, 0, 0, 5, 35, NULL, 'Momentinė cos(fi) reikšmė L1 fazėje, fiksuojama kas parą', 71, 3, NULL, NULL),
	(7762, 24, 0, 7, 1, 0, 0, 1, 36, NULL, 'Momentinė cos(fi) reikšmė L2 fazėje, fiksuojama kas minutę', 72, 1, NULL, NULL),
	(7763, 24, 0, 7, 1, 0, 0, 8, 36, NULL, 'Momentinė cos(fi) reikšmė L2 fazėje, fiksuojama kas 3 minutes', 72, 1, NULL, NULL),
	(7764, 24, 0, 7, 1, 0, 0, 10, 36, NULL, 'Momentinė cos(fi) reikšmė L2 fazėje, fiksuojama kas 5 minutes', 72, 1, NULL, NULL),
	(7765, 24, 0, 7, 1, 0, 0, 12, 36, NULL, 'Momentinė cos(fi) reikšmė L2 fazėje, fiksuojama kas 15 minučių', 72, 2, NULL, NULL),
	(7766, 24, 0, 7, 1, 0, 0, 3, 36, NULL, 'Momentinė cos(fi) reikšmė L2 fazėje, fiksuojama kas 30 minučių', 72, 2, NULL, NULL),
	(7767, 24, 0, 7, 1, 0, 0, 4, 36, NULL, 'Momentinė cos(fi) reikšmė L2 fazėje, fiksuojama kas valandą', 72, 2, NULL, NULL),
	(7768, 24, 0, 7, 1, 0, 0, 5, 36, NULL, 'Momentinė cos(fi) reikšmė L2 fazėje, fiksuojama kas parą', 72, 3, NULL, NULL),
	(7769, 25, 0, 7, 1, 0, 0, 1, 37, NULL, 'Momentinė cos(fi) reikšmė L3 fazėje, fiksuojama kas minutę', 73, 1, NULL, NULL),
	(7770, 25, 0, 7, 1, 0, 0, 8, 37, NULL, 'Momentinė cos(fi) reikšmė L3 fazėje, fiksuojama kas 3 minutes', 73, 1, NULL, NULL),
	(7771, 25, 0, 7, 1, 0, 0, 10, 37, NULL, 'Momentinė cos(fi) reikšmė L3 fazėje, fiksuojama kas 5 minutes', 73, 1, NULL, NULL),
	(7772, 25, 0, 7, 1, 0, 0, 12, 37, NULL, 'Momentinė cos(fi) reikšmė L3 fazėje, fiksuojama kas 15 minučių', 73, 2, NULL, NULL),
	(7773, 25, 0, 7, 1, 0, 0, 3, 37, NULL, 'Momentinė cos(fi) reikšmė L3 fazėje, fiksuojama kas 30 minučių', 73, 2, NULL, NULL),
	(7774, 25, 0, 7, 1, 0, 0, 4, 37, NULL, 'Momentinė cos(fi) reikšmė L3 fazėje, fiksuojama kas valandą', 73, 2, NULL, NULL),
	(7775, 25, 0, 7, 1, 0, 0, 5, 37, NULL, 'Momentinė cos(fi) reikšmė L3 fazėje, fiksuojama kas parą', 73, 3, NULL, NULL),
	(7776, 26, 0, 7, 1, 0, 0, 1, 38, NULL, 'Momentinis kvadrantas L1 fazėje, fiksuojamas kas minutę', 74, 1, NULL, NULL),
	(7777, 26, 0, 7, 1, 0, 0, 8, 38, NULL, 'Momentinis kvadrantas L1 fazėje, fiksuojamas kas 3 minutes', 74, 1, NULL, NULL),
	(7778, 26, 0, 7, 1, 0, 0, 10, 38, NULL, 'Momentinis kvadrantas L1 fazėje, fiksuojamas kas 5 minutes', 74, 1, NULL, NULL),
	(7779, 26, 0, 7, 1, 0, 0, 12, 38, NULL, 'Momentinis kvadrantas L1 fazėje, fiksuojamas kas 15 minučių', 74, 2, NULL, NULL),
	(7780, 26, 0, 7, 1, 0, 0, 3, 38, NULL, 'Momentinis kvadrantas L1 fazėje, fiksuojamas kas 30 minučių', 74, 2, NULL, NULL),
	(7781, 26, 0, 7, 1, 0, 0, 4, 38, NULL, 'Momentinis kvadrantas L1 fazėje, fiksuojamas kas valandą', 74, 2, NULL, NULL),
	(7782, 26, 0, 7, 1, 0, 0, 5, 38, NULL, 'Momentinis kvadrantas L1 fazėje, fiksuojamas kas parą', 74, 3, NULL, NULL),
	(7783, 27, 0, 7, 1, 0, 0, 1, 39, NULL, 'Momentinis kvadrantas L2 fazėje, fiksuojamas kas minutę', 75, 1, NULL, NULL),
	(7784, 27, 0, 7, 1, 0, 0, 8, 39, NULL, 'Momentinis kvadrantas L2 fazėje, fiksuojamas kas 3 minutes', 75, 1, NULL, NULL),
	(7785, 27, 0, 7, 1, 0, 0, 10, 39, NULL, 'Momentinis kvadrantas L2 fazėje, fiksuojamas kas 5 minutes', 75, 1, NULL, NULL),
	(7786, 27, 0, 7, 1, 0, 0, 12, 39, NULL, 'Momentinis kvadrantas L2 fazėje, fiksuojamas kas 15 minučių', 75, 2, NULL, NULL),
	(7787, 27, 0, 7, 1, 0, 0, 3, 39, NULL, 'Momentinis kvadrantas L2 fazėje, fiksuojamas kas 30 minučių', 75, 2, NULL, NULL);
INSERT INTO `ml` (`ml_id`, `ms_id`, `dir_id`, `aggs_id`, `aggf_id`, `tff_id`, `eu_id`, `md_id`, `msf_id`, `obis`, `ml_name`, `stobis`, `aggs_type_id`, `ml_custom_code`, `enum_id`) VALUES
	(7788, 27, 0, 7, 1, 0, 0, 4, 39, NULL, 'Momentinis kvadrantas L2 fazėje, fiksuojamas kas valandą', 75, 2, NULL, NULL),
	(7789, 27, 0, 7, 1, 0, 0, 5, 39, NULL, 'Momentinis kvadrantas L2 fazėje, fiksuojamas kas parą', 75, 3, NULL, NULL),
	(7790, 28, 0, 7, 1, 0, 0, 1, 40, NULL, 'Momentinis kvadrantas L3 fazėje, fiksuojamas kas minutę', 76, 1, NULL, NULL),
	(7791, 28, 0, 7, 1, 0, 0, 8, 40, NULL, 'Momentinis kvadrantas L3 fazėje, fiksuojamas kas 3 minutes', 76, 1, NULL, NULL),
	(7792, 28, 0, 7, 1, 0, 0, 10, 40, NULL, 'Momentinis kvadrantas L3 fazėje, fiksuojamas kas 5 minutes', 76, 1, NULL, NULL),
	(7793, 28, 0, 7, 1, 0, 0, 12, 40, NULL, 'Momentinis kvadrantas L3 fazėje, fiksuojamas kas 15 minučių', 76, 2, NULL, NULL),
	(7794, 28, 0, 7, 1, 0, 0, 3, 40, NULL, 'Momentinis kvadrantas L3 fazėje, fiksuojamas kas 30 minučių', 76, 2, NULL, NULL),
	(7795, 28, 0, 7, 1, 0, 0, 4, 40, NULL, 'Momentinis kvadrantas L3 fazėje, fiksuojamas kas valandą', 76, 2, NULL, NULL),
	(7796, 28, 0, 7, 1, 0, 0, 5, 40, NULL, 'Momentinis kvadrantas L3 fazėje, fiksuojamas kas parą', 76, 3, NULL, NULL),
	(7797, 29, 0, 7, 1, 0, 5, 1, 41, NULL, 'Momentinis srovės stiprumas, fiksuojamas kas minutę', 77, 1, NULL, NULL),
	(7798, 29, 0, 7, 1, 0, 5, 8, 41, NULL, 'Momentinis srovės stiprumas, fiksuojamas kas 3 minutes', 77, 1, NULL, NULL),
	(7799, 29, 0, 7, 1, 0, 5, 10, 41, NULL, 'Momentinis srovės stiprumas, fiksuojamas kas 5 minutes', 77, 1, NULL, NULL),
	(7800, 29, 0, 7, 1, 0, 5, 12, 41, NULL, 'Momentinis srovės stiprumas, fiksuojamas kas 15 minučių', 77, 2, NULL, NULL),
	(7801, 29, 0, 7, 1, 0, 5, 3, 41, NULL, 'Momentinis srovės stiprumas, fiksuojamas kas 30 minučių', 77, 2, NULL, NULL),
	(7802, 29, 0, 7, 1, 0, 5, 4, 41, NULL, 'Momentinis srovės stiprumas, fiksuojamas kas valandą', 77, 2, NULL, NULL),
	(7803, 29, 0, 7, 1, 0, 5, 5, 41, NULL, 'Momentinis srovės stiprumas, fiksuojamas kas parą', 77, 3, NULL, NULL),
	(7804, 30, 0, 7, 1, 0, 6, 1, 42, NULL, 'Momentinė įtampa, fiksuojama kas minutę', 78, 1, NULL, NULL),
	(7805, 30, 0, 7, 1, 0, 6, 10, 42, NULL, 'Momentinė įtampa, fiksuojama kas 5 minutes', 78, 1, NULL, NULL),
	(7806, 30, 0, 7, 1, 0, 6, 5, 42, NULL, 'Momentinė įtampa, fiksuojama kas parą', 78, 3, NULL, NULL),
	(7807, 31, 0, 7, 1, 0, 6, 1, 43, NULL, 'Momentinė linijinė įtampa, fiksuojama kas minutę', 79, 1, NULL, NULL),
	(7808, 31, 0, 7, 1, 0, 6, 8, 43, NULL, 'Momentinė linijinė įtampa, fiksuojama kas 3 minutes', 79, 1, NULL, NULL),
	(7809, 31, 0, 7, 1, 0, 6, 10, 43, NULL, 'Momentinė linijinė įtampa, fiksuojama kas 5 minutes', 79, 1, NULL, NULL),
	(7810, 31, 0, 7, 1, 0, 6, 12, 43, NULL, 'Momentinė linijinė įtampa, fiksuojama kas 15 minučių', 79, 2, NULL, NULL),
	(7811, 31, 0, 7, 1, 0, 6, 3, 43, NULL, 'Momentinė linijinė įtampa, fiksuojama kas 30 minučių', 79, 2, NULL, NULL),
	(7812, 31, 0, 7, 1, 0, 6, 4, 43, NULL, 'Momentinė linijinė įtampa, fiksuojama kas valandą', 79, 2, NULL, NULL),
	(7813, 31, 0, 7, 1, 0, 6, 5, 43, NULL, 'Momentinė linijinė įtampa, fiksuojama kas parą', 79, 3, NULL, NULL),
	(7814, 34, 0, 7, 1, 0, 7, 1, 44, NULL, 'Momentinė pilnoji galia, fiksuojama kas minutę', 82, 1, NULL, NULL),
	(7815, 34, 0, 7, 1, 0, 7, 10, 44, NULL, 'Momentinė pilnoji galia, fiksuojama kas 5 minutes', 82, 1, NULL, NULL),
	(7816, 34, 0, 7, 1, 0, 7, 5, 44, NULL, 'Momentinė pilnoji galia, fiksuojama kas parą', 82, 3, NULL, NULL),
	(7817, 35, 0, 7, 1, 0, 0, 1, 46, NULL, 'Momentinė cos(fi) reikšmė, fiksuojama kas minutę', 83, 1, NULL, NULL),
	(7818, 35, 0, 7, 1, 0, 0, 8, 46, NULL, 'Momentinė cos(fi) reikšmė, fiksuojama kas 3 minutes', 83, 1, NULL, NULL),
	(7819, 35, 0, 7, 1, 0, 0, 10, 46, NULL, 'Momentinė cos(fi) reikšmė, fiksuojama kas 5 minutes', 83, 1, NULL, NULL),
	(7820, 35, 0, 7, 1, 0, 0, 12, 46, NULL, 'Momentinė cos(fi) reikšmė, fiksuojama kas 15 minučių', 83, 2, NULL, NULL),
	(7821, 35, 0, 7, 1, 0, 0, 3, 46, NULL, 'Momentinė cos(fi) reikšmė, fiksuojama kas 30 minučių', 83, 2, NULL, NULL),
	(7822, 35, 0, 7, 1, 0, 0, 4, 46, NULL, 'Momentinė cos(fi) reikšmė, fiksuojama kas valandą', 83, 2, NULL, NULL),
	(7823, 35, 0, 7, 1, 0, 0, 5, 46, NULL, 'Momentinė cos(fi) reikšmė, fiksuojama kas parą', 83, 3, NULL, NULL),
	(7824, 36, 0, 7, 1, 0, 0, 1, 47, NULL, 'Momentinis kvadrantas, fiksuojamas kas minutę', 84, 1, NULL, NULL),
	(7825, 36, 0, 7, 1, 0, 0, 8, 47, NULL, 'Momentinis kvadrantas, fiksuojamas kas 3 minutes', 84, 1, NULL, NULL),
	(7826, 36, 0, 7, 1, 0, 0, 10, 47, NULL, 'Momentinis kvadrantas, fiksuojamas kas 5 minutes', 84, 1, NULL, NULL),
	(7827, 36, 0, 7, 1, 0, 0, 12, 47, NULL, 'Momentinis kvadrantas, fiksuojamas kas 15 minučių', 84, 2, NULL, NULL),
	(7828, 36, 0, 7, 1, 0, 0, 3, 47, NULL, 'Momentinis kvadrantas, fiksuojamas kas 30 minučių', 84, 2, NULL, NULL),
	(7829, 36, 0, 7, 1, 0, 0, 4, 47, NULL, 'Momentinis kvadrantas, fiksuojamas kas valandą', 84, 2, NULL, NULL),
	(7830, 36, 0, 7, 1, 0, 0, 5, 47, NULL, 'Momentinis kvadrantas, fiksuojamas kas parą', 84, 3, NULL, NULL),
	(7831, 37, 0, 7, 1, 0, 8, 1, 48, NULL, 'Momentinis dažnis, fiksuojamas kas minutę', 85, 1, NULL, NULL),
	(7832, 37, 0, 7, 1, 0, 8, 10, 48, NULL, 'Momentinis dažnis, fiksuojamas kas 5 minutes', 85, 1, NULL, NULL),
	(7833, 37, 0, 7, 1, 0, 8, 5, 48, NULL, 'Momentinis dažnis, fiksuojamas kas parą', 85, 3, NULL, NULL),
	(7834, 38, 0, 7, 1, 0, 0, 1, 49, NULL, 'Momentinė fazių seka, fiksuojama kas minutę', 86, 1, NULL, NULL),
	(7835, 38, 0, 7, 1, 0, 0, 8, 49, NULL, 'Momentinė fazių seka, fiksuojama kas 3 minutes', 86, 1, NULL, NULL),
	(7836, 38, 0, 7, 1, 0, 0, 10, 49, NULL, 'Momentinė fazių seka, fiksuojama kas 5 minutes', 86, 1, NULL, NULL),
	(7837, 38, 0, 7, 1, 0, 0, 12, 49, NULL, 'Momentinė fazių seka, fiksuojama kas 15 minučių', 86, 2, NULL, NULL),
	(7838, 38, 0, 7, 1, 0, 0, 3, 49, NULL, 'Momentinė fazių seka, fiksuojama kas 30 minučių', 86, 2, NULL, NULL),
	(7839, 38, 0, 7, 1, 0, 0, 4, 49, NULL, 'Momentinė fazių seka, fiksuojama kas valandą', 86, 2, NULL, NULL),
	(7840, 38, 0, 7, 1, 0, 0, 5, 49, NULL, 'Momentinė fazių seka, fiksuojama kas parą', 86, 3, NULL, NULL),
	(7841, 169, 0, 7, 1, 0, 56, 19, 182, NULL, 'Kampas tarp L1 ir L2 fazės įtampų, fiksuojamas kas 30 sekundžių', 91, 7, NULL, NULL),
	(7842, 169, 0, 7, 1, 0, 56, 1, 182, NULL, 'Kampas tarp L1 ir L2 fazės įtampų, fiksuojamas kas minutę', 91, 1, NULL, NULL),
	(7843, 169, 0, 7, 1, 0, 56, 2, 182, NULL, 'Kampas tarp L1 ir L2 fazės įtampų, fiksuojamas kas 2 minutes', 91, 1, NULL, NULL),
	(7844, 169, 0, 7, 1, 0, 56, 10, 182, NULL, 'Kampas tarp L1 ir L2 fazės įtampų, fiksuojamas kas 5 minutes', 91, 1, NULL, NULL),
	(7845, 170, 0, 7, 1, 0, 56, 19, 183, NULL, 'Kampas tarp L2 ir L3 fazės įtampų, fiksuojamas kas 30 sekundžių', 92, 7, NULL, NULL),
	(7846, 170, 0, 7, 1, 0, 56, 1, 183, NULL, 'Kampas tarp L2 ir L3 fazės įtampų, fiksuojamas kas minutę', 92, 1, NULL, NULL),
	(7847, 170, 0, 7, 1, 0, 56, 2, 183, NULL, 'Kampas tarp L2 ir L3 fazės įtampų, fiksuojamas kas 2 minutes', 92, 1, NULL, NULL),
	(7848, 170, 0, 7, 1, 0, 56, 10, 183, NULL, 'Kampas tarp L2 ir L3 fazės įtampų, fiksuojamas kas 5 minutes', 92, 1, NULL, NULL),
	(7849, 170, 0, 7, 1, 0, 56, 5, 183, NULL, 'Kampas tarp L2 ir L3 fazės įtampų, fiksuojamas kas parą', 92, 3, NULL, NULL),
	(7850, 171, 0, 7, 1, 0, 56, 19, 184, NULL, 'Kampas tarp L3 ir L1 fazės įtampų, fiksuojamas kas 30 sekundžių', 93, 7, NULL, NULL),
	(7851, 171, 0, 7, 1, 0, 56, 1, 184, NULL, 'Kampas tarp L3 ir L1 fazės įtampų, fiksuojamas kas minutę', 93, 1, NULL, NULL),
	(7852, 171, 0, 7, 1, 0, 56, 2, 184, NULL, 'Kampas tarp L3 ir L1 fazės įtampų, fiksuojamas kas 2 minutes', 93, 1, NULL, NULL),
	(7853, 171, 0, 7, 1, 0, 56, 10, 184, NULL, 'Kampas tarp L3 ir L1 fazės įtampų, fiksuojamas kas 5 minutes', 93, 1, NULL, NULL),
	(7854, 172, 0, 7, 1, 0, 56, 19, 185, NULL, 'Kampas tarp srovės ir įtampos L1 fazėje, fiksuojamas kas 30 sekundžių', 94, 7, NULL, NULL),
	(7855, 172, 0, 7, 1, 0, 56, 1, 185, NULL, 'Kampas tarp srovės ir įtampos L1 fazėje, fiksuojamas kas minutę', 94, 1, NULL, NULL),
	(7856, 172, 0, 7, 1, 0, 56, 2, 185, NULL, 'Kampas tarp srovės ir įtampos L1 fazėje, fiksuojamas kas 2 minutes', 94, 1, NULL, NULL),
	(7857, 172, 0, 7, 1, 0, 56, 10, 185, NULL, 'Kampas tarp srovės ir įtampos L1 fazėje, fiksuojamas kas 5 minutes', 94, 1, NULL, NULL),
	(7858, 172, 0, 7, 1, 0, 56, 5, 185, NULL, 'Kampas tarp srovės ir įtampos L1 fazėje, fiksuojamas kas parą', 94, 3, NULL, NULL),
	(7859, 173, 0, 7, 1, 0, 56, 19, 186, NULL, 'Kampas tarp srovės ir įtampos L2 fazėje, fiksuojamas kas 30 sekundžių', 95, 7, NULL, NULL),
	(7860, 173, 0, 7, 1, 0, 56, 1, 186, NULL, 'Kampas tarp srovės ir įtampos L2 fazėje, fiksuojamas kas minutę', 95, 1, NULL, NULL),
	(7861, 173, 0, 7, 1, 0, 56, 2, 186, NULL, 'Kampas tarp srovės ir įtampos L2 fazėje, fiksuojamas kas 2 minutes', 95, 1, NULL, NULL),
	(7862, 173, 0, 7, 1, 0, 56, 10, 186, NULL, 'Kampas tarp srovės ir įtampos L2 fazėje, fiksuojamas kas 5 minutes', 95, 1, NULL, NULL),
	(7863, 173, 0, 7, 1, 0, 56, 5, 186, NULL, 'Kampas tarp srovės ir įtampos L2 fazėje, fiksuojamas kas parą', 95, 3, NULL, NULL),
	(7864, 174, 0, 7, 1, 0, 56, 19, 187, NULL, 'Kampas tarp srovės ir įtampos L3 fazėje, fiksuojamas kas 30 sekundžių', 96, 7, NULL, NULL),
	(7865, 174, 0, 7, 1, 0, 56, 1, 187, NULL, 'Kampas tarp srovės ir įtampos L3 fazėje, fiksuojamas kas minutę', 96, 1, NULL, NULL),
	(7866, 174, 0, 7, 1, 0, 56, 2, 187, NULL, 'Kampas tarp srovės ir įtampos L3 fazėje, fiksuojamas kas 2 minutes', 96, 1, NULL, NULL),
	(7867, 174, 0, 7, 1, 0, 56, 10, 187, NULL, 'Kampas tarp srovės ir įtampos L3 fazėje, fiksuojamas kas 5 minutes', 96, 1, NULL, NULL),
	(7868, 174, 0, 7, 1, 0, 56, 5, 187, NULL, 'Kampas tarp srovės ir įtampos L3 fazėje, fiksuojamas kas parą', 96, 3, NULL, NULL),
	(7869, 219, 0, 7, 1, 0, 8, 1, 232, NULL, 'Momentinis dažnis L1 fazėje, fiksuojamas kas minutę', 108, 1, NULL, NULL),
	(7870, 219, 0, 7, 1, 0, 8, 10, 232, NULL, 'Momentinis dažnis L1 fazėje, fiksuojamas kas 5 minutes', 108, 1, NULL, NULL),
	(7871, 219, 0, 7, 1, 0, 8, 5, 232, NULL, 'Momentinis dažnis L1 fazėje, fiksuojamas kas parą', 108, 3, NULL, NULL),
	(7872, 220, 0, 7, 1, 0, 8, 1, 233, NULL, 'Momentinis dažnis L2 fazėje, fiksuojamas kas minutę', 109, 1, NULL, NULL),
	(7873, 220, 0, 7, 1, 0, 8, 10, 233, NULL, 'Momentinis dažnis L2 fazėje, fiksuojamas kas 5 minutes', 109, 1, NULL, NULL),
	(7874, 220, 0, 7, 1, 0, 8, 5, 233, NULL, 'Momentinis dažnis L2 fazėje, fiksuojamas kas parą', 109, 3, NULL, NULL),
	(7875, 221, 0, 7, 1, 0, 8, 1, 234, NULL, 'Momentinis dažnis L3 fazėje, fiksuojamas kas minutę', 110, 1, NULL, NULL),
	(7876, 221, 0, 7, 1, 0, 8, 10, 234, NULL, 'Momentinis dažnis L3 fazėje, fiksuojamas kas 5 minutes', 110, 1, NULL, NULL),
	(7877, 221, 0, 7, 1, 0, 8, 5, 234, NULL, 'Momentinis dažnis L3 fazėje, fiksuojamas kas parą', 110, 3, NULL, NULL),
	(7878, 222, 0, 7, 1, 0, 5, 1, 235, NULL, 'Momentinis srovės stiprumas neutralėje, fiksuojamas kas minutę', 548, 1, NULL, NULL),
	(7879, 222, 0, 7, 1, 0, 5, 2, 235, NULL, 'Momentinis srovės stiprumas neutralėje, fiksuojamas kas 2 minutes', 548, 1, NULL, NULL),
	(7880, 222, 0, 7, 1, 0, 5, 8, 235, NULL, 'Momentinis srovės stiprumas neutralėje, fiksuojamas kas 3 minutes', 548, 1, NULL, NULL),
	(7881, 222, 0, 7, 1, 0, 5, 10, 235, NULL, 'Momentinis srovės stiprumas neutralėje, fiksuojamas kas 5 minutes', 548, 1, NULL, NULL),
	(7882, 222, 0, 7, 1, 0, 5, 12, 235, NULL, 'Momentinis srovės stiprumas neutralėje, fiksuojamas kas 15 minučių', 548, 2, NULL, NULL),
	(7883, 222, 0, 7, 1, 0, 5, 3, 235, NULL, 'Momentinis srovės stiprumas neutralėje, fiksuojamas kas 30 minučių', 548, 2, NULL, NULL),
	(7884, 222, 0, 7, 1, 0, 5, 4, 235, NULL, 'Momentinis srovės stiprumas neutralėje, fiksuojamas kas valandą', 548, 2, NULL, NULL),
	(7885, 222, 0, 7, 1, 0, 5, 5, 235, NULL, 'Momentinis srovės stiprumas neutralėje, fiksuojamas kas parą', 548, 3, NULL, NULL),
	(7886, 266, 0, 7, 1, 0, 1, 19, 279, NULL, 'Momentinė aktyvinė absoliuti galia, fiksuojama kas 30 sekundžių', 775, 7, NULL, NULL),
	(7887, 266, 0, 7, 1, 0, 1, 1, 279, NULL, 'Momentinė aktyvinė absoliuti galia, fiksuojama kas minutę', 775, 1, NULL, NULL),
	(7888, 266, 0, 7, 1, 0, 1, 2, 279, NULL, 'Momentinė aktyvinė absoliuti galia, fiksuojama kas 2 minutes', 775, 1, NULL, NULL),
	(7889, 266, 0, 7, 45, 0, 1, 10, 279, NULL, 'Momentinė aktyvinė absoliuti galia, fiksuojama kas 5 minutes', 775, 1, NULL, NULL),
	(7890, 304, 0, 7, 45, 0, 5, 19, 317, NULL, 'Momentinė 1-os harmonikos srovė L1 fazėje, fiksuojama kas 30 sekundžių', 3123, 7, NULL, NULL),
	(7891, 304, 0, 7, 45, 0, 5, 1, 317, NULL, 'Momentinė 1-os harmonikos srovė L1 fazėje, fiksuojama kas minutę', 3123, 1, NULL, NULL),
	(7892, 304, 0, 7, 45, 0, 5, 2, 317, NULL, 'Momentinė 1-os harmonikos srovė L1 fazėje, fiksuojama kas 2 minutes', 3123, 1, NULL, NULL),
	(7893, 304, 0, 7, 1, 0, 5, 10, 317, NULL, 'Momentinė 1-os harmonikos srovė L1 fazėje, fiksuojama kas 5 minutes', 3123, 1, NULL, NULL),
	(7894, 305, 0, 7, 1, 0, 5, 19, 318, NULL, 'Momentinė 1-os harmonikos srovė L2 fazėje, fiksuojama kas 30 sekundžių', 3124, 7, NULL, NULL),
	(7895, 305, 0, 7, 1, 0, 5, 1, 318, NULL, 'Momentinė 1-os harmonikos srovė L2 fazėje, fiksuojama kas minutę', 3124, 1, NULL, NULL),
	(7896, 305, 0, 7, 1, 0, 5, 2, 318, NULL, 'Momentinė 1-os harmonikos srovė L2 fazėje, fiksuojama kas 2 minutes', 3124, 1, NULL, NULL),
	(7897, 305, 0, 7, 1, 0, 5, 10, 318, NULL, 'Momentinė 1-os harmonikos srovė L2 fazėje, fiksuojama kas 5 minutes', 3124, 1, NULL, NULL),
	(7898, 306, 0, 7, 1, 0, 5, 19, 319, NULL, 'Momentinė 1-os harmonikos srovė L3 fazėje, fiksuojama kas 30 sekundžių', 3125, 7, NULL, NULL),
	(7899, 306, 0, 7, 1, 0, 5, 1, 319, NULL, 'Momentinė 1-os harmonikos srovė L3 fazėje, fiksuojama kas minutę', 3125, 1, NULL, NULL),
	(7900, 306, 0, 7, 1, 0, 5, 2, 319, NULL, 'Momentinė 1-os harmonikos srovė L3 fazėje, fiksuojama kas 2 minutes', 3125, 1, NULL, NULL),
	(7901, 306, 0, 7, 1, 0, 5, 10, 319, NULL, 'Momentinė 1-os harmonikos srovė L3 fazėje, fiksuojama kas 5 minutes', 3125, 1, NULL, NULL),
	(7902, 307, 0, 7, 1, 0, 27, 19, 320, NULL, 'Momentinė išorinė oro temperatūra, fiksuojama kas 30 sekundžių', 1013, 7, NULL, NULL),
	(7903, 307, 0, 7, 1, 0, 27, 1, 320, NULL, 'Momentinė išorinė oro temperatūra, fiksuojama kas minutę', 1013, 1, NULL, NULL),
	(7904, 307, 0, 7, 1, 0, 27, 2, 320, NULL, 'Momentinė išorinė oro temperatūra, fiksuojama kas 2 minutes', 1013, 1, NULL, NULL),
	(7905, 307, 0, 7, 1, 0, 27, 10, 320, NULL, 'Momentinė išorinė oro temperatūra, fiksuojama kas 5 minutes', 1013, 1, NULL, NULL),
	(7906, 55, -4, 1, 2, 0, 31, 1, 74, NULL, 'Pamaitinimo vandens tūrio kiekis per minutę', 1084, 1, NULL, NULL),
	(7907, 55, -4, 1, 3, 0, 32, 1, 73, NULL, 'Vidutinis pamaitinimo vandens tūrio debitas per minutę', 1731, 1, NULL, NULL),
	(7908, 55, -4, 2, 2, 0, 31, 2, 74, NULL, 'Pamaitinimo vandens tūrio kiekis per 2 minutes', 1084, 1, NULL, NULL),
	(7909, 55, -4, 2, 3, 0, 32, 2, 73, NULL, 'Vidutinis pamaitinimo vandens tūrio debitas per 2 minutes', 1731, 1, NULL, NULL),
	(7910, 55, -4, 3, 2, 0, 31, 3, 74, NULL, 'Pamaitinimo vandens tūrio kiekis per 30 minučių', 1084, 2, NULL, NULL),
	(7911, 55, -4, 3, 3, 0, 32, 3, 73, NULL, 'Vidutinis pamaitinimo vandens tūrio debitas per 30 minučių', 1731, 2, NULL, NULL),
	(7912, 55, -4, 4, 3, 0, 32, 4, 73, NULL, 'Vidutinis pamaitinimo vandens tūrio debitas per valandą', 1731, 2, NULL, NULL),
	(7913, 55, -4, 5, 3, 0, 32, 5, 73, NULL, 'Vidutinis pamaitinimo vandens tūrio debitas per parą', 1731, 3, NULL, NULL),
	(7914, 55, -4, 6, 3, 0, 32, 6, 73, NULL, 'Vidutinis pamaitinimo vandens tūrio debitas per mėnesį', 1731, 4, NULL, NULL),
	(7915, 55, -4, 8, 2, 0, 31, 3, 74, NULL, 'Suminis pamaitinimo vandens tūrio kiekis, fiksuojamas kas 30 minučių', 1027, 5, NULL, NULL),
	(7916, 55, -4, 8, 2, 0, 31, 5, 74, NULL, 'Suminis pamaitinimo vandens tūrio kiekis, fiksuojamas kas parą', 1027, 5, NULL, NULL),
	(7917, 55, -4, 8, 2, 0, 31, 6, 74, NULL, 'Suminis pamaitinimo vandens tūrio kiekis, fiksuojamas kas mėnesį', 1027, 5, NULL, NULL),
	(7918, 55, -4, 8, 2, 0, 31, 10, 74, NULL, 'Suminis pamaitinimo vandens tūrio kiekis, fiksuojamas kas 5 minutes', 1027, 5, NULL, NULL),
	(7919, 55, -4, 8, 2, 0, 31, 12, 74, NULL, 'Suminis pamaitinimo vandens tūrio kiekis, fiksuojamas kas 15 minučių', 1027, 5, NULL, NULL),
	(7920, 55, -4, 8, 2, 0, 31, 13, 74, NULL, 'Suminis pamaitinimo vandens tūrio kiekis, fiksuojamas kas 20 minučių', 1027, 5, NULL, NULL),
	(7921, 55, -4, 9, 2, 0, 31, 8, 74, NULL, 'Pamaitinimo vandens tūrio kiekis per 3 minutes', 1084, 1, NULL, NULL),
	(7922, 55, -4, 9, 3, 0, 32, 8, 73, NULL, 'Vidutinis pamaitinimo vandens tūrio debitas per 3 minutes', 1731, 1, NULL, NULL),
	(7923, 55, -4, 10, 2, 0, 31, 9, 74, NULL, 'Pamaitinimo vandens tūrio kiekis per 4 minutes', 1084, 1, NULL, NULL),
	(7924, 55, -4, 10, 3, 0, 32, 9, 73, NULL, 'Vidutinis pamaitinimo vandens tūrio debitas per 4 minutes', 1731, 1, NULL, NULL),
	(7925, 55, -4, 11, 2, 0, 31, 10, 74, NULL, 'Pamaitinimo vandens tūrio kiekis per 5 minutes', 1084, 1, NULL, NULL),
	(7926, 55, -4, 11, 3, 0, 32, 10, 73, NULL, 'Vidutinis pamaitinimo vandens tūrio debitas per 5 minutes', 1731, 1, NULL, NULL),
	(7927, 55, -4, 12, 2, 0, 31, 11, 74, NULL, 'Pamaitinimo vandens tūrio kiekis per 10 minučių', 1084, 1, NULL, NULL),
	(7928, 55, -4, 12, 3, 0, 32, 11, 73, NULL, 'Vidutinis pamaitinimo vandens tūrio debitas per 10 minučių', 1731, 1, NULL, NULL),
	(7929, 55, -4, 13, 2, 0, 31, 12, 74, NULL, 'Pamaitinimo vandens tūrio kiekis per 15 minučių', 1084, 2, NULL, NULL),
	(7930, 55, -4, 13, 3, 0, 32, 12, 73, NULL, 'Vidutinis pamaitinimo vandens tūrio debitas per 15 minučių', 1731, 2, NULL, NULL),
	(7931, 55, -4, 14, 2, 0, 31, 13, 74, NULL, 'Pamaitinimo vandens tūrio kiekis per 20 minučių', 1084, 2, NULL, NULL),
	(7932, 55, -4, 14, 3, 0, 32, 13, 73, NULL, 'Vidutinis pamaitinimo vandens tūrio debitas per 20 minučių', 1731, 2, NULL, NULL),
	(7933, 51, -4, 1, 2, 0, 35, 1, 68, NULL, 'Pamaitinimo vandens masės kiekis per minutę', 1083, 1, NULL, NULL),
	(7934, 51, -4, 1, 3, 0, 36, 1, 67, NULL, 'Vidutinis pamaitinimo vandens masės debitas per minutę', 1733, 1, NULL, NULL),
	(7935, 51, -4, 2, 2, 0, 35, 2, 68, NULL, 'Pamaitinimo vandens masės kiekis per 2 minutes', 1083, 1, NULL, NULL),
	(7936, 51, -4, 2, 3, 0, 36, 2, 67, NULL, 'Vidutinis pamaitinimo vandens masės debitas per 2 minutes', 1733, 1, NULL, NULL),
	(7937, 51, -4, 3, 2, 0, 35, 3, 68, NULL, 'Pamaitinimo vandens masės kiekis per 30 minučių', 1083, 2, NULL, NULL),
	(7938, 51, -4, 3, 3, 0, 36, 3, 67, NULL, 'Vidutinis pamaitinimo vandens masės debitas per 30 minučių', 1733, 2, NULL, NULL),
	(7939, 51, -4, 4, 3, 0, 36, 4, 67, NULL, 'Vidutinis pamaitinimo vandens masės debitas per valandą', 1733, 2, NULL, NULL),
	(7940, 51, -4, 5, 3, 0, 36, 5, 67, NULL, 'Vidutinis pamaitinimo vandens masės debitas per parą', 1733, 3, NULL, NULL),
	(7941, 51, -4, 6, 3, 0, 36, 6, 67, NULL, 'Vidutinis pamaitinimo vandens masės debitas per mėnesį', 1733, 4, NULL, NULL),
	(7942, 51, -4, 8, 2, 0, 35, 3, 68, NULL, 'Suminis pamaitinimo vandens masės kiekis, fiksuojamas kas 30 minučių', 1028, 5, NULL, NULL),
	(7943, 51, -4, 8, 2, 0, 35, 5, 68, NULL, 'Suminis pamaitinimo vandens masės kiekis, fiksuojamas kas parą', 1028, 5, NULL, NULL),
	(7944, 51, -4, 8, 2, 0, 35, 6, 68, NULL, 'Suminis pamaitinimo vandens masės kiekis, fiksuojamas kas mėnesį', 1028, 5, NULL, NULL),
	(7945, 51, -4, 8, 2, 0, 35, 10, 68, NULL, 'Suminis pamaitinimo vandens masės kiekis, fiksuojamas kas 5 minutes', 1028, 5, NULL, NULL),
	(7946, 51, -4, 8, 2, 0, 35, 12, 68, NULL, 'Suminis pamaitinimo vandens masės kiekis, fiksuojamas kas 15 minučių', 1028, 5, NULL, NULL),
	(7947, 51, -4, 8, 2, 0, 35, 13, 68, NULL, 'Suminis pamaitinimo vandens masės kiekis, fiksuojamas kas 20 minučių', 1028, 5, NULL, NULL),
	(7948, 51, -4, 9, 2, 0, 35, 8, 68, NULL, 'Pamaitinimo vandens masės kiekis per 3 minutes', 1083, 1, NULL, NULL),
	(7949, 51, -4, 9, 3, 0, 36, 8, 67, NULL, 'Vidutinis pamaitinimo vandens masės debitas per 3 minutes', 1733, 1, NULL, NULL),
	(7950, 51, -4, 10, 2, 0, 35, 9, 68, NULL, 'Pamaitinimo vandens masės kiekis per 4 minutes', 1083, 1, NULL, NULL),
	(7951, 51, -4, 10, 3, 0, 36, 9, 67, NULL, 'Vidutinis pamaitinimo vandens masės debitas per 4 minutes', 1733, 1, NULL, NULL),
	(7952, 51, -4, 11, 2, 0, 35, 10, 68, NULL, 'Pamaitinimo vandens masės kiekis per 5 minutes', 1083, 1, NULL, NULL),
	(7953, 51, -4, 11, 3, 0, 36, 10, 67, NULL, 'Vidutinis pamaitinimo vandens masės debitas per 5 minutes', 1733, 1, NULL, NULL),
	(7954, 51, -4, 12, 2, 0, 35, 11, 68, NULL, 'Pamaitinimo vandens masės kiekis per 10 minučių', 1083, 1, NULL, NULL),
	(7955, 51, -4, 12, 3, 0, 36, 11, 67, NULL, 'Vidutinis pamaitinimo vandens masės debitas per 10 minučių', 1733, 1, NULL, NULL),
	(7956, 51, -4, 13, 2, 0, 35, 12, 68, NULL, 'Pamaitinimo vandens masės kiekis per 15 minučių', 1083, 2, NULL, NULL),
	(7957, 51, -4, 13, 3, 0, 36, 12, 67, NULL, 'Vidutinis pamaitinimo vandens masės debitas per 15 minučių', 1733, 2, NULL, NULL),
	(7958, 51, -4, 14, 2, 0, 35, 13, 68, NULL, 'Pamaitinimo vandens masės kiekis per 20 minučių', 1083, 2, NULL, NULL),
	(7959, 51, -4, 14, 3, 0, 36, 13, 67, NULL, 'Vidutinis pamaitinimo vandens masės debitas per 20 minučių', 1733, 2, NULL, NULL),
	(7960, 239, 0, 1, 3, 0, 36, 1, 316, NULL, 'Vidutinis šalto vandens masės debitas per minutę', 1219, 1, NULL, NULL),
	(7961, 239, 0, 2, 3, 0, 36, 2, 316, NULL, 'Vidutinis šalto vandens masės debitas per 2 minutes', 1219, 1, NULL, NULL),
	(7962, 239, 0, 3, 3, 0, 36, 3, 316, NULL, 'Vidutinis šalto vandens masės debitas per 30 minučių', 1219, 2, NULL, NULL),
	(7963, 239, 0, 9, 3, 0, 36, 8, 316, NULL, 'Vidutinis šalto vandens masės debitas per 3 minutes', 1219, 1, NULL, NULL),
	(7964, 239, 0, 10, 3, 0, 36, 9, 316, NULL, 'Vidutinis šalto vandens masės debitas per 4 minutes', 1219, 1, NULL, NULL),
	(7965, 239, 0, 11, 3, 0, 36, 10, 316, NULL, 'Vidutinis šalto vandens masės debitas per 5 minutes', 1219, 1, NULL, NULL),
	(7966, 239, 0, 12, 3, 0, 36, 11, 316, NULL, 'Vidutinis šalto vandens masės debitas per 10 minučių', 1219, 1, NULL, NULL),
	(7967, 239, 0, 13, 3, 0, 36, 12, 316, NULL, 'Vidutinis šalto vandens masės debitas per 15 minučių', 1219, 2, NULL, NULL),
	(7968, 239, 0, 14, 3, 0, 36, 13, 316, NULL, 'Vidutinis šalto vandens masės debitas per 20 minučių', 1219, 2, NULL, NULL),
	(7969, 240, 0, 1, 3, 0, 36, 1, 255, NULL, 'Vidutinis karšto vandens masės debitas per minutę', 1219, 1, NULL, NULL),
	(7970, 240, 0, 2, 3, 0, 36, 2, 255, NULL, 'Vidutinis karšto vandens masės debitas per 2 minutes', 1219, 1, NULL, NULL),
	(7971, 240, 0, 3, 3, 0, 36, 3, 255, NULL, 'Vidutinis karšto vandens masės debitas per 30 minučių', 1219, 2, NULL, NULL),
	(7972, 240, 0, 4, 3, 0, 36, 4, 255, NULL, 'Vidutinis karšto vandens masės debitas per valandą', 1219, 2, NULL, NULL),
	(7973, 240, 0, 5, 3, 0, 36, 5, 255, NULL, 'Vidutinis karšto vandens masės debitas per parą', 1219, 3, NULL, NULL),
	(7974, 240, 0, 6, 3, 0, 36, 6, 255, NULL, 'Vidutinis karšto vandens masės debitas per mėnesį', 1219, 4, NULL, NULL),
	(7975, 240, 0, 7, 1, 0, 36, 7, 255, NULL, 'Momentinis karšto vandens masės debitas', 1218, 6, NULL, NULL),
	(7976, 240, 0, 9, 3, 0, 36, 8, 255, NULL, 'Vidutinis karšto vandens masės debitas per 3 minutes', 1219, 1, NULL, NULL),
	(7977, 240, 0, 10, 3, 0, 36, 9, 255, NULL, 'Vidutinis karšto vandens masės debitas per 4 minutes', 1219, 1, NULL, NULL),
	(7978, 240, 0, 11, 3, 0, 36, 10, 255, NULL, 'Vidutinis karšto vandens masės debitas per 5 minutes', 1219, 1, NULL, NULL),
	(7979, 240, 0, 12, 3, 0, 36, 11, 255, NULL, 'Vidutinis karšto vandens masės debitas per 10 minučių', 1219, 1, NULL, NULL),
	(7980, 240, 0, 13, 3, 0, 36, 12, 255, NULL, 'Vidutinis karšto vandens masės debitas per 15 minučių', 1219, 2, NULL, NULL),
	(7981, 240, 0, 14, 3, 0, 36, 13, 255, NULL, 'Vidutinis karšto vandens masės debitas per 20 minučių', 1219, 2, NULL, NULL),
	(7982, 240, 1, 1, 2, 0, 35, 1, 253, NULL, 'Tiekiamo karšto vandens masės kiekis per minutę', 1213, 1, NULL, NULL),
	(7983, 240, 1, 1, 3, 0, 36, 1, 255, NULL, 'Vidutinis tiekiamo karšto vandens masės debitas per minutę', 1219, 1, NULL, NULL),
	(7984, 240, 1, 2, 2, 0, 35, 2, 253, NULL, 'Tiekiamo karšto vandens masės kiekis per 2 minutes', 1213, 1, NULL, NULL),
	(7985, 240, 1, 2, 3, 0, 36, 2, 255, NULL, 'Vidutinis tiekiamo karšto vandens masės debitas per 2 minutes', 1219, 1, NULL, NULL),
	(7986, 240, 1, 3, 2, 0, 35, 3, 253, NULL, 'Tiekiamo karšto vandens masės kiekis per 30 minučių', 1213, 2, NULL, NULL),
	(7987, 240, 1, 3, 3, 0, 36, 3, 255, NULL, 'Vidutinis tiekiamo karšto vandens masės debitas per 30 minučių', 1219, 2, NULL, NULL),
	(7988, 240, 1, 4, 3, 0, 36, 4, 255, NULL, 'Vidutinis tiekiamo karšto vandens masės debitas per valandą', 1219, 2, NULL, NULL),
	(7989, 240, 1, 5, 3, 0, 36, 5, 255, NULL, 'Vidutinis tiekiamo karšto vandens masės debitas per parą', 1219, 3, NULL, NULL),
	(7990, 240, 1, 6, 3, 0, 36, 6, 255, NULL, 'Vidutinis tiekiamo karšto vandens masės debitas per mėnesį', 1219, 4, NULL, NULL),
	(7991, 240, 1, 7, 1, 0, 36, 7, 255, NULL, 'Momentinis tiekiamo karšto vandens masės debitas', 1218, 6, NULL, NULL),
	(7992, 240, 1, 8, 2, 0, 35, 3, 253, NULL, 'Suminis tiekiamo karšto vandens masės kiekis, fiksuojamas kas 30 minučių', 1211, 5, NULL, NULL),
	(7993, 240, 1, 8, 2, 0, 35, 4, 253, NULL, 'Suminis tiekiamo karšto vandens masės kiekis, fiksuojamas kas valandą', 1211, 5, NULL, NULL),
	(7994, 240, 1, 8, 2, 0, 35, 5, 253, NULL, 'Suminis tiekiamo karšto vandens masės kiekis, fiksuojamas kas parą', 1211, 5, NULL, NULL),
	(7995, 240, 1, 8, 2, 0, 35, 6, 253, NULL, 'Suminis tiekiamo karšto vandens masės kiekis, fiksuojamas kas mėnesį', 1211, 5, NULL, NULL),
	(7996, 240, 1, 8, 2, 0, 35, 7, 253, NULL, 'Suminis tiekiamo karšto vandens masės kiekis', 1211, 5, NULL, NULL),
	(7997, 240, 1, 8, 2, 0, 35, 10, 253, NULL, 'Suminis tiekiamo karšto vandens masės kiekis, fiksuojamas kas 5 minutes', 1211, 5, NULL, NULL),
	(7998, 240, 1, 8, 2, 0, 35, 12, 253, NULL, 'Suminis tiekiamo karšto vandens masės kiekis, fiksuojamas kas 15 minučių', 1211, 5, NULL, NULL),
	(7999, 240, 1, 8, 2, 0, 35, 13, 253, NULL, 'Suminis tiekiamo karšto vandens masės kiekis, fiksuojamas kas 20 minučių', 1211, 5, NULL, NULL),
	(8000, 240, 1, 9, 2, 0, 35, 8, 253, NULL, 'Tiekiamo karšto vandens masės kiekis per 3 minutes', 1213, 1, NULL, NULL),
	(8001, 240, 1, 9, 3, 0, 36, 8, 255, NULL, 'Vidutinis tiekiamo karšto vandens masės debitas per 3 minutes', 1219, 1, NULL, NULL),
	(8002, 240, 1, 10, 2, 0, 35, 9, 253, NULL, 'Tiekiamo karšto vandens masės kiekis per 4 minutes', 1213, 1, NULL, NULL),
	(8003, 240, 1, 10, 3, 0, 36, 9, 255, NULL, 'Vidutinis tiekiamo karšto vandens masės debitas per 4 minutes', 1219, 1, NULL, NULL),
	(8004, 240, 1, 11, 2, 0, 35, 10, 253, NULL, 'Tiekiamo karšto vandens masės kiekis per 5 minutes', 1213, 1, NULL, NULL),
	(8005, 240, 1, 11, 3, 0, 36, 10, 255, NULL, 'Vidutinis tiekiamo karšto vandens masės debitas per 5 minutes', 1219, 1, NULL, NULL),
	(8006, 240, 1, 12, 2, 0, 35, 11, 253, NULL, 'Tiekiamo karšto vandens masės kiekis per 10 minučių', 1213, 1, NULL, NULL),
	(8007, 240, 1, 12, 3, 0, 36, 11, 255, NULL, 'Vidutinis tiekiamo karšto vandens masės debitas per 10 minučių', 1219, 1, NULL, NULL),
	(8008, 240, 1, 13, 2, 0, 35, 12, 253, NULL, 'Tiekiamo karšto vandens masės kiekis per 15 minučių', 1213, 2, NULL, NULL),
	(8009, 240, 1, 13, 3, 0, 36, 12, 255, NULL, 'Vidutinis tiekiamo karšto vandens masės debitas per 15 minučių', 1219, 2, NULL, NULL),
	(8010, 240, 1, 14, 2, 0, 35, 13, 253, NULL, 'Tiekiamo karšto vandens masės kiekis per 20 minučių', 1213, 2, NULL, NULL),
	(8011, 240, 1, 14, 3, 0, 36, 13, 255, NULL, 'Vidutinis tiekiamo karšto vandens masės debitas per 20 minučių', 1219, 2, NULL, NULL),
	(8012, 240, 2, 1, 2, 0, 35, 1, 253, NULL, 'Grįžtamo karšto vandens masės kiekis per minutę', 1242, 1, NULL, NULL),
	(8013, 240, 2, 1, 3, 0, 36, 1, 255, NULL, 'Vidutinis grįžtamo karšto vandens masės debitas per minutę', 1246, 1, NULL, NULL),
	(8014, 240, 2, 2, 2, 0, 35, 2, 253, NULL, 'Grįžtamo karšto vandens masės kiekis per 2 minutes', 1242, 1, NULL, NULL),
	(8015, 240, 2, 2, 3, 0, 36, 2, 255, NULL, 'Vidutinis grįžtamo karšto vandens masės debitas per 2 minutes', 1246, 1, NULL, NULL),
	(8016, 240, 2, 3, 2, 0, 35, 3, 253, NULL, 'Grįžtamo karšto vandens masės kiekis per 30 minučių', 1242, 2, NULL, NULL),
	(8017, 240, 2, 3, 3, 0, 36, 3, 255, NULL, 'Vidutinis grįžtamo karšto vandens masės debitas per 30 minučių', 1246, 2, NULL, NULL),
	(8018, 240, 2, 4, 3, 0, 36, 4, 255, NULL, 'Vidutinis grįžtamo karšto vandens masės debitas per valandą', 1246, 2, NULL, NULL),
	(8019, 240, 2, 5, 3, 0, 36, 5, 255, NULL, 'Vidutinis grįžtamo karšto vandens masės debitas per parą', 1246, 3, NULL, NULL),
	(8020, 240, 2, 6, 3, 0, 36, 6, 255, NULL, 'Vidutinis grįžtamo karšto vandens masės debitas per mėnesį', 1246, 4, NULL, NULL),
	(8021, 240, 2, 7, 1, 0, 36, 7, 255, NULL, 'Momentinis grįžtamo karšto vandens masės debitas', 1245, 6, NULL, NULL),
	(8022, 240, 2, 8, 2, 0, 35, 3, 253, NULL, 'Suminis grįžtamo karšto vandens masės kiekis, fiksuojamas kas 30 minučių', 1241, 5, NULL, NULL),
	(8023, 240, 2, 8, 2, 0, 35, 4, 253, NULL, 'Suminis grįžtamo karšto vandens masės kiekis, fiksuojamas kas valandą', 1241, 5, NULL, NULL),
	(8024, 240, 2, 8, 2, 0, 35, 5, 253, NULL, 'Suminis grįžtamo karšto vandens masės kiekis, fiksuojamas kas parą', 1241, 5, NULL, NULL),
	(8025, 240, 2, 8, 2, 0, 35, 6, 253, NULL, 'Suminis grįžtamo karšto vandens masės kiekis, fiksuojamas kas mėnesį', 1241, 5, NULL, NULL),
	(8026, 240, 2, 8, 2, 0, 35, 7, 253, NULL, 'Suminis grįžtamo karšto vandens masės kiekis', 1241, 5, NULL, NULL),
	(8027, 240, 2, 8, 2, 0, 35, 10, 253, NULL, 'Suminis grįžtamo karšto vandens masės kiekis, fiksuojamas kas 5 minutes', 1241, 5, NULL, NULL),
	(8028, 240, 2, 8, 2, 0, 35, 12, 253, NULL, 'Suminis grįžtamo karšto vandens masės kiekis, fiksuojamas kas 15 minučių', 1241, 5, NULL, NULL),
	(8029, 240, 2, 8, 2, 0, 35, 13, 253, NULL, 'Suminis grįžtamo karšto vandens masės kiekis, fiksuojamas kas 20 minučių', 1241, 5, NULL, NULL),
	(8030, 240, 2, 9, 2, 0, 35, 8, 253, NULL, 'Grįžtamo karšto vandens masės kiekis per 3 minutes', 1242, 1, NULL, NULL),
	(8031, 240, 2, 9, 3, 0, 36, 8, 255, NULL, 'Vidutinis grįžtamo karšto vandens masės debitas per 3 minutes', 1246, 1, NULL, NULL),
	(8032, 240, 2, 10, 2, 0, 35, 9, 253, NULL, 'Grįžtamo karšto vandens masės kiekis per 4 minutes', 1242, 1, NULL, NULL),
	(8033, 240, 2, 10, 3, 0, 36, 9, 255, NULL, 'Vidutinis grįžtamo karšto vandens masės debitas per 4 minutes', 1246, 1, NULL, NULL),
	(8034, 240, 2, 11, 2, 0, 35, 10, 253, NULL, 'Grįžtamo karšto vandens masės kiekis per 5 minutes', 1242, 1, NULL, NULL),
	(8035, 240, 2, 11, 3, 0, 36, 10, 255, NULL, 'Vidutinis grįžtamo karšto vandens masės debitas per 5 minutes', 1246, 1, NULL, NULL),
	(8036, 240, 2, 12, 2, 0, 35, 11, 253, NULL, 'Grįžtamo karšto vandens masės kiekis per 10 minučių', 1242, 1, NULL, NULL),
	(8037, 240, 2, 12, 3, 0, 36, 11, 255, NULL, 'Vidutinis grįžtamo karšto vandens masės debitas per 10 minučių', 1246, 1, NULL, NULL),
	(8038, 240, 2, 13, 2, 0, 35, 12, 253, NULL, 'Grįžtamo karšto vandens masės kiekis per 15 minučių', 1242, 2, NULL, NULL),
	(8039, 240, 2, 13, 3, 0, 36, 12, 255, NULL, 'Vidutinis grįžtamo karšto vandens masės debitas per 15 minučių', 1246, 2, NULL, NULL),
	(8040, 240, 2, 14, 2, 0, 35, 13, 253, NULL, 'Grįžtamo karšto vandens masės kiekis per 20 minučių', 1242, 2, NULL, NULL),
	(8041, 240, 2, 14, 3, 0, 36, 13, 255, NULL, 'Vidutinis grįžtamo karšto vandens masės debitas per 20 minučių', 1246, 2, NULL, NULL),
	(8042, 240, 3, 1, 2, 0, 35, 1, 253, NULL, 'Tiekiamo ir grįžtamo karšto vandens masės kiekių skirtumas per minutę', 1280, 1, NULL, NULL),
	(8043, 240, 3, 1, 3, 0, 36, 1, 255, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens masės debito skirtumas per minutę', 1248, 1, NULL, NULL),
	(8044, 240, 3, 2, 2, 0, 35, 2, 253, NULL, 'Tiekiamo ir grįžtamo karšto vandens masės kiekių skirtumas per 2 minutes', 1280, 1, NULL, NULL),
	(8045, 240, 3, 2, 3, 0, 36, 2, 255, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens masės debito skirtumas per 2 minutes', 1248, 1, NULL, NULL),
	(8046, 240, 3, 3, 2, 0, 35, 3, 253, NULL, 'Tiekiamo ir grįžtamo karšto vandens masės kiekių skirtumas per 30 minučių', 1280, 2, NULL, NULL),
	(8047, 240, 3, 3, 3, 0, 36, 3, 255, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens masės debito skirtumas per 30 minučių', 1248, 2, NULL, NULL),
	(8048, 240, 3, 4, 2, 0, 35, 4, 253, NULL, 'Tiekiamo ir grįžtamo karšto vandens masės kiekių skirtumas per valandą', 1280, 2, NULL, NULL),
	(8049, 240, 3, 4, 3, 0, 36, 4, 255, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens masės debito skirtumas per valandą', 1248, 2, NULL, NULL),
	(8050, 240, 3, 5, 2, 0, 35, 5, 253, NULL, 'Tiekiamo ir grįžtamo karšto vandens masės kiekių skirtumas per parą', 1280, 3, NULL, NULL),
	(8051, 240, 3, 5, 3, 0, 36, 5, 255, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens masės debito skirtumas per parą', 1248, 3, NULL, NULL),
	(8052, 240, 3, 6, 2, 0, 35, 6, 253, NULL, 'Tiekiamo ir grįžtamo karšto vandens masės kiekių skirtumas per mėnesį', 1280, 4, NULL, NULL),
	(8053, 240, 3, 6, 3, 0, 36, 6, 255, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens masės debito skirtumas per mėnesį', 1248, 4, NULL, NULL),
	(8054, 240, 3, 7, 1, 0, 36, 7, 255, NULL, 'Momentinis tiekiamo ir grįžtamo karšto vandens masės debito skirtumas', 1247, 6, NULL, NULL),
	(8055, 240, 3, 9, 2, 0, 35, 8, 253, NULL, 'Tiekiamo ir grįžtamo karšto vandens masės kiekių skirtumas per 3 minutes', 1280, 1, NULL, NULL),
	(8056, 240, 3, 9, 3, 0, 36, 8, 255, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens masės debito skirtumas per 3 minutes', 1248, 1, NULL, NULL),
	(8057, 240, 3, 10, 2, 0, 35, 9, 253, NULL, 'Tiekiamo ir grįžtamo karšto vandens masės kiekių skirtumas per 4 minutes', 1280, 1, NULL, NULL),
	(8058, 240, 3, 10, 3, 0, 36, 9, 255, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens masės debito skirtumas per 4 minutes', 1248, 1, NULL, NULL),
	(8059, 240, 3, 11, 2, 0, 35, 10, 253, NULL, 'Tiekiamo ir grįžtamo karšto vandens masės kiekių skirtumas per 5 minutes', 1280, 1, NULL, NULL),
	(8060, 240, 3, 11, 3, 0, 36, 10, 255, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens masės debito skirtumas per 5 minutes', 1248, 1, NULL, NULL),
	(8061, 240, 3, 12, 2, 0, 35, 11, 253, NULL, 'Tiekiamo ir grįžtamo karšto vandens masės kiekių skirtumas per 10 minučių', 1280, 1, NULL, NULL),
	(8062, 240, 3, 12, 3, 0, 36, 11, 255, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens masės debito skirtumas per 10 minučių', 1248, 1, NULL, NULL),
	(8063, 240, 3, 13, 2, 0, 35, 12, 253, NULL, 'Tiekiamo ir grįžtamo karšto vandens masės kiekių skirtumas per 15 minučių', 1280, 2, NULL, NULL),
	(8064, 240, 3, 13, 3, 0, 36, 12, 255, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens masės debito skirtumas per 15 minučių', 1248, 2, NULL, NULL),
	(8065, 240, 3, 14, 2, 0, 35, 13, 253, NULL, 'Tiekiamo ir grįžtamo karšto vandens masės kiekių skirtumas per 20 minučių', 1280, 2, NULL, NULL),
	(8066, 240, 3, 14, 3, 0, 36, 13, 255, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens masės debito skirtumas per 20 minučių', 1248, 2, NULL, NULL),
	(8067, 2, 0, 1, 3, 0, 27, 1, 256, NULL, 'Vidutinis karšto vandens temperatūros svertinis vidurkis per minutę', 1217, 1, NULL, NULL),
	(8068, 2, 0, 2, 3, 0, 27, 2, 256, NULL, 'Vidutinis karšto vandens temperatūros svertinis vidurkis per 2 minutes', 1217, 1, NULL, NULL),
	(8069, 2, 0, 3, 3, 0, 27, 3, 256, NULL, 'Vidutinis karšto vandens temperatūros svertinis vidurkis per 30 minučių', 1217, 2, NULL, NULL),
	(8070, 2, 0, 4, 3, 0, 27, 4, 256, NULL, 'Vidutinis karšto vandens temperatūros svertinis vidurkis per valandą', 1217, 2, NULL, NULL),
	(8071, 2, 0, 5, 3, 0, 27, 5, 256, NULL, 'Vidutinis karšto vandens temperatūros svertinis vidurkis per parą', 1217, 3, NULL, NULL),
	(8072, 2, 0, 6, 3, 0, 27, 6, 256, NULL, 'Vidutinis karšto vandens temperatūros svertinis vidurkis per mėnesį', 1217, 4, NULL, NULL),
	(8073, 2, 0, 7, 1, 0, 27, 7, 256, NULL, 'Momentinis karšto vandens temperatūros svertinis vidurkis', 1263, 6, NULL, NULL),
	(8074, 2, 0, 9, 3, 0, 27, 8, 256, NULL, 'Vidutinis karšto vandens temperatūros svertinis vidurkis per 3 minutes', 1217, 1, NULL, NULL),
	(8075, 2, 0, 10, 3, 0, 27, 9, 256, NULL, 'Vidutinis karšto vandens temperatūros svertinis vidurkis per 4 minutes', 1217, 1, NULL, NULL),
	(8076, 2, 0, 11, 3, 0, 27, 10, 256, NULL, 'Vidutinis karšto vandens temperatūros svertinis vidurkis per 5 minutes', 1217, 1, NULL, NULL),
	(8077, 2, 0, 12, 3, 0, 27, 11, 256, NULL, 'Vidutinis karšto vandens temperatūros svertinis vidurkis per 10 minučių', 1217, 1, NULL, NULL),
	(8078, 2, 0, 13, 3, 0, 27, 12, 256, NULL, 'Vidutinis karšto vandens temperatūros svertinis vidurkis per 15 minučių', 1217, 2, NULL, NULL),
	(8079, 2, 0, 14, 3, 0, 27, 13, 256, NULL, 'Vidutinis karšto vandens temperatūros svertinis vidurkis per 20 minučių', 1217, 2, NULL, NULL),
	(8080, 2, 1, 1, 3, 0, 27, 1, 256, NULL, 'Vidutinis tiekiamo karšto vandens temperatūros svertinis vidurkis per minutę', 1217, 1, NULL, NULL),
	(8081, 2, 1, 2, 3, 0, 27, 2, 256, NULL, 'Vidutinis tiekiamo karšto vandens temperatūros svertinis vidurkis per 2 minutes', 1217, 1, NULL, NULL),
	(8082, 2, 1, 3, 3, 0, 27, 3, 256, NULL, 'Vidutinis tiekiamo karšto vandens temperatūros svertinis vidurkis per 30 minučių', 1217, 2, NULL, NULL),
	(8083, 2, 1, 4, 3, 0, 27, 4, 256, NULL, 'Vidutinis tiekiamo karšto vandens temperatūros svertinis vidurkis per valandą', 1217, 2, NULL, NULL),
	(8084, 2, 1, 4, 4, 0, 27, 5, 256, NULL, 'Maksimalus valandinis tiekiamo karšto vandens temperatūros svertinis vidurkis per parą', NULL, 3, NULL, NULL),
	(8085, 2, 1, 4, 4, 0, 27, 6, 256, NULL, 'Maksimalus valandinis tiekiamo karšto vandens temperatūros svertinis vidurkis per mėnesį', NULL, 4, NULL, NULL),
	(8086, 2, 1, 4, 5, 0, 27, 5, 256, NULL, 'Minimalus valandinis tiekiamo karšto vandens temperatūros svertinis vidurkis per parą', NULL, 3, NULL, NULL),
	(8087, 2, 1, 4, 5, 0, 27, 6, 256, NULL, 'Minimalus valandinis tiekiamo karšto vandens temperatūros svertinis vidurkis per mėnesį', NULL, 4, NULL, NULL),
	(8088, 2, 1, 5, 3, 0, 27, 5, 256, NULL, 'Vidutinis tiekiamo karšto vandens temperatūros svertinis vidurkis per parą', 1217, 3, NULL, NULL),
	(8089, 2, 1, 6, 3, 0, 27, 6, 256, NULL, 'Vidutinis tiekiamo karšto vandens temperatūros svertinis vidurkis per mėnesį', 1217, 4, NULL, NULL),
	(8090, 2, 1, 7, 1, 0, 27, 7, 256, NULL, 'Momentinis tiekiamo karšto vandens temperatūros svertinis vidurkis', 1263, 6, NULL, NULL),
	(8091, 2, 1, 9, 3, 0, 27, 8, 256, NULL, 'Vidutinis tiekiamo karšto vandens temperatūros svertinis vidurkis per 3 minutes', 1217, 1, NULL, NULL),
	(8092, 2, 1, 10, 3, 0, 27, 9, 256, NULL, 'Vidutinis tiekiamo karšto vandens temperatūros svertinis vidurkis per 4 minutes', 1217, 1, NULL, NULL),
	(8093, 2, 1, 11, 3, 0, 27, 10, 256, NULL, 'Vidutinis tiekiamo karšto vandens temperatūros svertinis vidurkis per 5 minutes', 1217, 1, NULL, NULL),
	(8094, 2, 1, 12, 3, 0, 27, 11, 256, NULL, 'Vidutinis tiekiamo karšto vandens temperatūros svertinis vidurkis per 10 minučių', 1217, 1, NULL, NULL),
	(8095, 2, 1, 13, 3, 0, 27, 12, 256, NULL, 'Vidutinis tiekiamo karšto vandens temperatūros svertinis vidurkis per 15 minučių', 1217, 2, NULL, NULL),
	(8096, 2, 1, 14, 3, 0, 27, 13, 256, NULL, 'Vidutinis tiekiamo karšto vandens temperatūros svertinis vidurkis per 20 minučių', 1217, 2, NULL, NULL),
	(8097, 2, 2, 1, 3, 0, 27, 1, 256, NULL, 'Vidutinis grįžtamo karšto vandens temperatūros svertinis vidurkis per minutę', 1265, 1, NULL, NULL),
	(8098, 2, 2, 2, 3, 0, 27, 2, 256, NULL, 'Vidutinis grįžtamo karšto vandens temperatūros svertinis vidurkis per 2 minutes', 1265, 1, NULL, NULL),
	(8099, 2, 2, 3, 3, 0, 27, 3, 256, NULL, 'Vidutinis grįžtamo karšto vandens temperatūros svertinis vidurkis per 30 minučių', 1265, 2, NULL, NULL),
	(8100, 2, 2, 4, 3, 0, 27, 4, 256, NULL, 'Vidutinis grįžtamo karšto vandens temperatūros svertinis vidurkis per valandą', 1265, 2, NULL, NULL),
	(8101, 2, 2, 4, 4, 0, 27, 5, 256, NULL, 'Maksimalus valandinis grįžtamo karšto vandens temperatūros svertinis vidurkis per parą', NULL, 3, NULL, NULL),
	(8102, 2, 2, 4, 4, 0, 27, 6, 256, NULL, 'Maksimalus valandinis grįžtamo karšto vandens temperatūros svertinis vidurkis per mėnesį', NULL, 4, NULL, NULL),
	(8103, 2, 2, 4, 5, 0, 27, 5, 256, NULL, 'Minimalus valandinis grįžtamo karšto vandens temperatūros svertinis vidurkis per parą', NULL, 3, NULL, NULL),
	(8104, 2, 2, 4, 5, 0, 27, 6, 256, NULL, 'Minimalus valandinis grįžtamo karšto vandens temperatūros svertinis vidurkis per mėnesį', NULL, 4, NULL, NULL),
	(8105, 2, 2, 5, 3, 0, 27, 5, 256, NULL, 'Vidutinis grįžtamo karšto vandens temperatūros svertinis vidurkis per parą', 1265, 3, NULL, NULL),
	(8106, 2, 2, 6, 3, 0, 27, 6, 256, NULL, 'Vidutinis grįžtamo karšto vandens temperatūros svertinis vidurkis per mėnesį', 1265, 4, NULL, NULL),
	(8107, 2, 2, 7, 1, 0, 27, 7, 256, NULL, 'Momentinis grįžtamo karšto vandens temperatūros svertinis vidurkis', 1264, 6, NULL, NULL),
	(8108, 2, 2, 9, 3, 0, 27, 8, 256, NULL, 'Vidutinis grįžtamo karšto vandens temperatūros svertinis vidurkis per 3 minutes', 1265, 1, NULL, NULL),
	(8109, 2, 2, 10, 3, 0, 27, 9, 256, NULL, 'Vidutinis grįžtamo karšto vandens temperatūros svertinis vidurkis per 4 minutes', 1265, 1, NULL, NULL),
	(8110, 2, 2, 11, 3, 0, 27, 10, 256, NULL, 'Vidutinis grįžtamo karšto vandens temperatūros svertinis vidurkis per 5 minutes', 1265, 1, NULL, NULL),
	(8111, 2, 2, 12, 3, 0, 27, 11, 256, NULL, 'Vidutinis grįžtamo karšto vandens temperatūros svertinis vidurkis per 10 minučių', 1265, 1, NULL, NULL),
	(8112, 2, 2, 13, 3, 0, 27, 12, 256, NULL, 'Vidutinis grįžtamo karšto vandens temperatūros svertinis vidurkis per 15 minučių', 1265, 2, NULL, NULL),
	(8113, 2, 2, 14, 3, 0, 27, 13, 256, NULL, 'Vidutinis grįžtamo karšto vandens temperatūros svertinis vidurkis per 20 minučių', 1265, 2, NULL, NULL),
	(8114, 2, 3, 1, 3, 0, 27, 1, 256, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens svertinių temperatūrų skirtumas per minutę', NULL, 1, NULL, NULL),
	(8115, 2, 3, 2, 3, 0, 27, 2, 256, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens svertinių temperatūrų skirtumas per 2 minutes', NULL, 1, NULL, NULL),
	(8116, 2, 3, 3, 3, 0, 27, 3, 256, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens svertinių temperatūrų skirtumas per 30 minučių', NULL, 2, NULL, NULL),
	(8117, 2, 3, 4, 3, 0, 27, 4, 256, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens svertinių temperatūrų skirtumas per valandą', NULL, 2, NULL, NULL),
	(8118, 2, 3, 4, 4, 0, 27, 5, 256, NULL, 'Maksimalus valandinių tiekiamo ir grįžtamo karšto vandens svertinių temperatūrų skirtumas per parą', NULL, 3, NULL, NULL),
	(8119, 2, 3, 4, 4, 0, 27, 6, 256, NULL, 'Maksimalus valandinių tiekiamo ir grįžtamo karšto vandens svertinių temperatūrų skirtumas per mėnesį', NULL, 4, NULL, NULL),
	(8120, 2, 3, 4, 5, 0, 27, 5, 256, NULL, 'Minimalus valandinių tiekiamo ir grįžtamo karšto vandens svertinių temperatūrų skirtumas per parą', NULL, 3, NULL, NULL),
	(8121, 2, 3, 4, 5, 0, 27, 6, 256, NULL, 'Minimalus valandinių tiekiamo ir grįžtamo karšto vandens svertinių temperatūrų skirtumas per mėnesį', NULL, 4, NULL, NULL),
	(8122, 2, 3, 5, 3, 0, 27, 5, 256, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens svertinių temperatūrų skirtumas per parą', NULL, 3, NULL, NULL),
	(8123, 2, 3, 6, 3, 0, 27, 6, 256, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens svertinių temperatūrų skirtumas per mėnesį', NULL, 4, NULL, NULL),
	(8124, 2, 3, 7, 1, 0, 27, 7, 256, NULL, 'Momentinis tiekiamo ir grįžtamo karšto vandens svertinių temperatūrų skirtumas', NULL, 6, NULL, NULL),
	(8125, 2, 3, 9, 3, 0, 27, 8, 256, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens svertinių temperatūrų skirtumas per 3 minutes', NULL, 1, NULL, NULL),
	(8126, 2, 3, 10, 3, 0, 27, 9, 256, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens svertinių temperatūrų skirtumas per 4 minutes', NULL, 1, NULL, NULL),
	(8127, 2, 3, 11, 3, 0, 27, 10, 256, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens svertinių temperatūrų skirtumas per 5 minutes', NULL, 1, NULL, NULL),
	(8128, 2, 3, 12, 3, 0, 27, 11, 256, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens svertinių temperatūrų skirtumas per 10 minučių', NULL, 1, NULL, NULL),
	(8129, 2, 3, 13, 3, 0, 27, 12, 256, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens svertinių temperatūrų skirtumas per 15 minučių', NULL, 2, NULL, NULL),
	(8130, 2, 3, 14, 3, 0, 27, 13, 256, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens svertinių temperatūrų skirtumas per 20 minučių', NULL, 2, NULL, NULL),
	(8131, 60, 1, 4, 4, 0, 27, 5, 52, NULL, 'Maksimali valandinė tiekiamo karšto vandens temperatūra per parą', NULL, 3, NULL, NULL),
	(8132, 60, 1, 4, 4, 0, 27, 6, 52, NULL, 'Maksimali valandinė tiekiamo karšto vandens temperatūra per mėnesį', NULL, 4, NULL, NULL),
	(8133, 60, 1, 4, 5, 0, 27, 5, 52, NULL, 'Minimali valandinė tiekiamo karšto vandens temperatūra per parą', NULL, 3, NULL, NULL),
	(8134, 60, 1, 4, 5, 0, 27, 6, 52, NULL, 'Minimali valandinė tiekiamo karšto vandens temperatūra per mėnesį', NULL, 4, NULL, NULL),
	(8135, 60, 2, 4, 4, 0, 27, 5, 52, NULL, 'Maksimali valandinė grįžtamo karšto vandens temperatūra per parą', NULL, 3, NULL, NULL),
	(8136, 60, 2, 4, 4, 0, 27, 6, 52, NULL, 'Maksimali valandinė grįžtamo karšto vandens temperatūra per mėnesį', NULL, 4, NULL, NULL),
	(8137, 60, 2, 4, 5, 0, 27, 5, 52, NULL, 'Minimali valandinė grįžtamo karšto vandens temperatūra per parą', NULL, 3, NULL, NULL),
	(8138, 60, 2, 4, 5, 0, 27, 6, 52, NULL, 'Minimali valandinė grįžtamo karšto vandens temperatūra per mėnesį', NULL, 4, NULL, NULL),
	(8139, 60, 3, 4, 4, 0, 27, 5, 52, NULL, 'Maksimalus valandinių tiekiamo ir grįžtamo karšto vandens temperatūrų skirtumas per parą', NULL, 3, NULL, NULL),
	(8140, 60, 3, 4, 4, 0, 27, 6, 52, NULL, 'Maksimalus valandinių tiekiamo ir grįžtamo karšto vandens temperatūrų skirtumas per mėnesį', NULL, 4, NULL, NULL),
	(8141, 60, 3, 4, 5, 0, 27, 5, 52, NULL, 'Minimalus valandinių tiekiamo ir grįžtamo karšto vandens temperatūrų skirtumas per parą', NULL, 3, NULL, NULL),
	(8142, 60, 3, 4, 5, 0, 27, 6, 52, NULL, 'Minimalus valandinių tiekiamo ir grįžtamo karšto vandens temperatūrų skirtumas per mėnesį', NULL, 4, NULL, NULL),
	(8143, 54, -4, 1, 3, 0, 27, 1, 72, NULL, 'Vidutinė pamaitinimo vandens temperatūra per minutę', 1085, 1, NULL, NULL),
	(8144, 54, -4, 2, 3, 0, 27, 2, 72, NULL, 'Vidutinė pamaitinimo vandens temperatūra per 2 minutes', 1085, 1, NULL, NULL),
	(8145, 54, -4, 3, 3, 0, 27, 3, 72, NULL, 'Vidutinė pamaitinimo vandens temperatūra per 30 minučių', 1085, 2, NULL, NULL),
	(8146, 54, -4, 9, 3, 0, 27, 8, 72, NULL, 'Vidutinė pamaitinimo vandens temperatūra per 3 minutes', 1085, 1, NULL, NULL),
	(8147, 54, -4, 10, 3, 0, 27, 9, 72, NULL, 'Vidutinė pamaitinimo vandens temperatūra per 4 minutes', 1085, 1, NULL, NULL),
	(8148, 54, -4, 11, 3, 0, 27, 10, 72, NULL, 'Vidutinė pamaitinimo vandens temperatūra per 5 minutes', 1085, 1, NULL, NULL),
	(8149, 54, -4, 12, 3, 0, 27, 11, 72, NULL, 'Vidutinė pamaitinimo vandens temperatūra per 10 minučių', 1085, 1, NULL, NULL),
	(8150, 54, -4, 13, 3, 0, 27, 12, 72, NULL, 'Vidutinė pamaitinimo vandens temperatūra per 15 minučių', 1085, 2, NULL, NULL),
	(8151, 54, -4, 14, 3, 0, 27, 13, 72, NULL, 'Vidutinė pamaitinimo vandens temperatūra per 20 minučių', 1085, 2, NULL, NULL),
	(8152, 265, -4, 1, 3, 0, 27, 1, 278, NULL, 'Vidutinis pamaitinimo vandens temperatūros svertinis vidurkis per minutę', NULL, 1, NULL, NULL),
	(8153, 265, -4, 2, 3, 0, 27, 2, 278, NULL, 'Vidutinis pamaitinimo vandens temperatūros svertinis vidurkis per 2 minutes', NULL, 1, NULL, NULL),
	(8154, 265, -4, 3, 3, 0, 27, 3, 278, NULL, 'Vidutinis pamaitinimo vandens temperatūros svertinis vidurkis per 30 minučių', NULL, 2, NULL, NULL),
	(8155, 265, -4, 4, 3, 0, 27, 4, 278, NULL, 'Vidutinis pamaitinimo vandens temperatūros svertinis vidurkis per valandą', NULL, 2, NULL, NULL),
	(8156, 265, -4, 5, 3, 0, 27, 5, 278, NULL, 'Vidutinis pamaitinimo vandens temperatūros svertinis vidurkis per parą', NULL, 3, NULL, NULL),
	(8157, 265, -4, 6, 3, 0, 27, 6, 278, NULL, 'Vidutinis pamaitinimo vandens temperatūros svertinis vidurkis per mėnesį', NULL, 4, NULL, NULL),
	(8158, 265, -4, 7, 1, 0, 27, 7, 278, NULL, 'Momentinis pamaitinimo vandens temperatūros svertinis vidurkis', NULL, 6, NULL, NULL),
	(8159, 265, -4, 9, 3, 0, 27, 8, 278, NULL, 'Vidutinis pamaitinimo vandens temperatūros svertinis vidurkis per 3 minutes', NULL, 1, NULL, NULL),
	(8160, 265, -4, 10, 3, 0, 27, 9, 278, NULL, 'Vidutinis pamaitinimo vandens temperatūros svertinis vidurkis per 4 minutes', NULL, 1, NULL, NULL),
	(8161, 265, -4, 11, 3, 0, 27, 10, 278, NULL, 'Vidutinis pamaitinimo vandens temperatūros svertinis vidurkis per 5 minutes', NULL, 1, NULL, NULL),
	(8162, 265, -4, 12, 3, 0, 27, 11, 278, NULL, 'Vidutinis pamaitinimo vandens temperatūros svertinis vidurkis per 10 minučių', NULL, 1, NULL, NULL),
	(8163, 265, -4, 13, 3, 0, 27, 12, 278, NULL, 'Vidutinis pamaitinimo vandens temperatūros svertinis vidurkis per 15 minučių', NULL, 2, NULL, NULL),
	(8164, 265, -4, 14, 3, 0, 27, 13, 278, NULL, 'Vidutinis pamaitinimo vandens temperatūros svertinis vidurkis per 20 minučių', NULL, 2, NULL, NULL),
	(8165, 301, 0, 1, 3, 0, 27, 1, 314, NULL, 'Vidutinis šalto vandens temperatūros svertinis vidurkis per minutę', 1217, 1, NULL, NULL),
	(8166, 301, 0, 2, 3, 0, 27, 2, 314, NULL, 'Vidutinis šalto vandens temperatūros svertinis vidurkis per 2 minutes', 1217, 1, NULL, NULL),
	(8167, 301, 0, 3, 3, 0, 27, 3, 314, NULL, 'Vidutinis šalto vandens temperatūros svertinis vidurkis per 30 minučių', 1217, 2, NULL, NULL),
	(8168, 301, 0, 4, 3, 0, 27, 4, 314, NULL, 'Vidutinis šalto vandens temperatūros svertinis vidurkis per valandą', 1217, 2, NULL, NULL),
	(8169, 301, 0, 5, 3, 0, 27, 5, 314, NULL, 'Vidutinis šalto vandens temperatūros svertinis vidurkis per parą', 1217, 3, NULL, NULL),
	(8170, 301, 0, 6, 3, 0, 27, 6, 314, NULL, 'Vidutinis šalto vandens temperatūros svertinis vidurkis per mėnesį', 1217, 4, NULL, NULL),
	(8171, 301, 0, 7, 1, 0, 27, 7, 314, NULL, 'Momentinis šalto vandens temperatūros svertinis vidurkis', 1263, 6, NULL, NULL),
	(8172, 301, 0, 9, 3, 0, 27, 8, 314, NULL, 'Vidutinis šalto vandens temperatūros svertinis vidurkis per 3 minutes', 1217, 1, NULL, NULL),
	(8173, 301, 0, 10, 3, 0, 27, 9, 314, NULL, 'Vidutinis šalto vandens temperatūros svertinis vidurkis per 4 minutes', 1217, 1, NULL, NULL),
	(8174, 301, 0, 11, 3, 0, 27, 10, 314, NULL, 'Vidutinis šalto vandens temperatūros svertinis vidurkis per 5 minutes', 1217, 1, NULL, NULL),
	(8175, 301, 0, 12, 3, 0, 27, 11, 314, NULL, 'Vidutinis šalto vandens temperatūros svertinis vidurkis per 10 minučių', 1217, 1, NULL, NULL),
	(8176, 301, 0, 13, 3, 0, 27, 12, 314, NULL, 'Vidutinis šalto vandens temperatūros svertinis vidurkis per 15 minučių', 1217, 2, NULL, NULL),
	(8177, 301, 0, 14, 3, 0, 27, 13, 314, NULL, 'Vidutinis šalto vandens temperatūros svertinis vidurkis per 20 minučių', 1217, 2, NULL, NULL),
	(8178, 4, 0, 1, 3, 0, 28, 1, 257, NULL, 'Vidutinis absoliutus karšto vandens slėgis per minutę', 1224, 1, NULL, NULL),
	(8179, 4, 0, 2, 3, 0, 28, 2, 257, NULL, 'Vidutinis absoliutus karšto vandens slėgis per 2 minutes', 1224, 1, NULL, NULL),
	(8180, 4, 0, 3, 3, 0, 28, 3, 257, NULL, 'Vidutinis absoliutus karšto vandens slėgis per 30 minučių', 1224, 2, NULL, NULL),
	(8181, 4, 0, 4, 3, 0, 28, 4, 257, NULL, 'Vidutinis absoliutus karšto vandens slėgis per valandą', 1224, 2, NULL, NULL),
	(8182, 4, 0, 5, 3, 0, 28, 5, 257, NULL, 'Vidutinis absoliutus karšto vandens slėgis per parą', 1224, 3, NULL, NULL),
	(8183, 4, 0, 6, 3, 0, 28, 6, 257, NULL, 'Vidutinis absoliutus karšto vandens slėgis per mėnesį', 1224, 4, NULL, NULL),
	(8184, 4, 0, 7, 1, 0, 28, 7, 257, NULL, 'Momentinis karšto vandens absoliutus slėgis', 1220, 6, NULL, NULL),
	(8185, 4, 0, 9, 3, 0, 28, 8, 257, NULL, 'Vidutinis absoliutus karšto vandens slėgis per 3 minutes', 1224, 1, NULL, NULL),
	(8186, 4, 0, 10, 3, 0, 28, 9, 257, NULL, 'Vidutinis absoliutus karšto vandens slėgis per 4 minutes', 1224, 1, NULL, NULL),
	(8187, 4, 0, 11, 3, 0, 28, 10, 257, NULL, 'Vidutinis absoliutus karšto vandens slėgis per 5 minutes', 1224, 1, NULL, NULL),
	(8188, 4, 0, 12, 3, 0, 28, 11, 257, NULL, 'Vidutinis absoliutus karšto vandens slėgis per 10 minučių', 1224, 1, NULL, NULL),
	(8189, 4, 0, 13, 3, 0, 28, 12, 257, NULL, 'Vidutinis absoliutus karšto vandens slėgis per 15 minučių', 1224, 2, NULL, NULL),
	(8190, 4, 0, 14, 3, 0, 28, 13, 257, NULL, 'Vidutinis absoliutus karšto vandens slėgis per 20 minučių', 1224, 2, NULL, NULL),
	(8191, 4, 2, 1, 3, 0, 28, 1, 257, NULL, 'Vidutinis grįžtamo karšto vandens absoliutus slėgis per minutę', 1251, 1, NULL, NULL),
	(8192, 4, 2, 2, 3, 0, 28, 2, 257, NULL, 'Vidutinis grįžtamo karšto vandens absoliutus slėgis per 2 minutes', 1251, 1, NULL, NULL),
	(8193, 4, 2, 3, 3, 0, 28, 3, 257, NULL, 'Vidutinis grįžtamo karšto vandens absoliutus slėgis per 30 minučių', 1251, 2, NULL, NULL),
	(8194, 4, 2, 4, 3, 0, 28, 4, 257, NULL, 'Vidutinis grįžtamo karšto vandens absoliutus slėgis per valandą', 1251, 2, NULL, NULL),
	(8195, 4, 2, 5, 3, 0, 28, 5, 257, NULL, 'Vidutinis grįžtamo karšto vandens absoliutus slėgis per parą', 1251, 3, NULL, NULL),
	(8196, 4, 2, 6, 3, 0, 28, 6, 257, NULL, 'Vidutinis grįžtamo karšto vandens absoliutus slėgis per mėnesį', 1251, 4, NULL, NULL),
	(8197, 4, 2, 7, 1, 0, 28, 7, 257, NULL, 'Momentinis grįžtamo karšto vandens absoliutus slėgis', 1250, 6, NULL, NULL),
	(8198, 4, 2, 9, 3, 0, 28, 8, 257, NULL, 'Vidutinis grįžtamo karšto vandens absoliutus slėgis per 3 minutes', 1251, 1, NULL, NULL),
	(8199, 4, 2, 10, 3, 0, 28, 9, 257, NULL, 'Vidutinis grįžtamo karšto vandens absoliutus slėgis per 4 minutes', 1251, 1, NULL, NULL),
	(8200, 4, 2, 11, 3, 0, 28, 10, 257, NULL, 'Vidutinis grįžtamo karšto vandens absoliutus slėgis per 5 minutes', 1251, 1, NULL, NULL),
	(8201, 4, 2, 12, 3, 0, 28, 11, 257, NULL, 'Vidutinis grįžtamo karšto vandens absoliutus slėgis per 10 minučių', 1251, 1, NULL, NULL),
	(8202, 4, 2, 13, 3, 0, 28, 12, 257, NULL, 'Vidutinis grįžtamo karšto vandens absoliutus slėgis per 15 minučių', 1251, 2, NULL, NULL),
	(8203, 4, 2, 14, 3, 0, 28, 13, 257, NULL, 'Vidutinis grįžtamo karšto vandens absoliutus slėgis per 20 minučių', 1251, 2, NULL, NULL),
	(8204, 32, 0, 1, 3, 0, 28, 1, 258, NULL, 'Vidutinis karšto vandens diferencinis slėgis per minutę', 1253, 1, NULL, NULL),
	(8205, 32, 0, 2, 3, 0, 28, 2, 258, NULL, 'Vidutinis karšto vandens diferencinis slėgis per 2 minutes', 1253, 1, NULL, NULL),
	(8206, 32, 0, 3, 3, 0, 28, 3, 258, NULL, 'Vidutinis karšto vandens diferencinis slėgis per 30 minučių', 1253, 2, NULL, NULL),
	(8207, 32, 0, 4, 3, 0, 28, 4, 258, NULL, 'Vidutinis karšto vandens diferencinis slėgis per valandą', 1253, 2, NULL, NULL),
	(8208, 32, 0, 5, 3, 0, 28, 5, 258, NULL, 'Vidutinis karšto vandens diferencinis slėgis per parą', 1253, 3, NULL, NULL),
	(8209, 32, 0, 6, 3, 0, 28, 6, 258, NULL, 'Vidutinis karšto vandens diferencinis slėgis per mėnesį', 1253, 4, NULL, NULL),
	(8210, 32, 0, 7, 1, 0, 28, 7, 258, NULL, 'Momentinis karšto vandens diferencinis slėgis', 1252, 6, NULL, NULL),
	(8211, 32, 0, 9, 3, 0, 28, 8, 258, NULL, 'Vidutinis karšto vandens diferencinis slėgis per 3 minutes', 1253, 1, NULL, NULL),
	(8212, 32, 0, 10, 3, 0, 28, 9, 258, NULL, 'Vidutinis karšto vandens diferencinis slėgis per 4 minutes', 1253, 1, NULL, NULL),
	(8213, 32, 0, 11, 3, 0, 28, 10, 258, NULL, 'Vidutinis karšto vandens diferencinis slėgis per 5 minutes', 1253, 1, NULL, NULL),
	(8214, 32, 0, 12, 3, 0, 28, 11, 258, NULL, 'Vidutinis karšto vandens diferencinis slėgis per 10 minučių', 1253, 1, NULL, NULL),
	(8215, 32, 0, 13, 3, 0, 28, 12, 258, NULL, 'Vidutinis karšto vandens diferencinis slėgis per 15 minučių', 1253, 2, NULL, NULL),
	(8216, 32, 0, 14, 3, 0, 28, 13, 258, NULL, 'Vidutinis karšto vandens diferencinis slėgis per 20 minučių', 1253, 2, NULL, NULL),
	(8217, 32, 1, 1, 3, 0, 28, 1, 258, NULL, 'Vidutinis tiekiamo karšto vandens diferencinis slėgis per minutę', 1253, 1, NULL, NULL),
	(8218, 32, 1, 2, 3, 0, 28, 2, 258, NULL, 'Vidutinis tiekiamo karšto vandens diferencinis slėgis per 2 minutes', 1253, 1, NULL, NULL),
	(8219, 32, 1, 3, 3, 0, 28, 3, 258, NULL, 'Vidutinis tiekiamo karšto vandens diferencinis slėgis per 30 minučių', 1253, 2, NULL, NULL),
	(8220, 32, 1, 4, 3, 0, 28, 4, 258, NULL, 'Vidutinis tiekiamo karšto vandens diferencinis slėgis per valandą', 1253, 2, NULL, NULL),
	(8221, 32, 1, 5, 3, 0, 28, 5, 258, NULL, 'Vidutinis tiekiamo karšto vandens diferencinis slėgis per parą', 1253, 3, NULL, NULL),
	(8222, 32, 1, 6, 3, 0, 28, 6, 258, NULL, 'Vidutinis tiekiamo karšto vandens diferencinis slėgis per mėnesį', 1253, 4, NULL, NULL),
	(8223, 32, 1, 7, 1, 0, 28, 7, 258, NULL, 'Momentinis tiekiamo karšto vandens diferencinis slėgis', 1252, 6, NULL, NULL),
	(8224, 32, 1, 9, 3, 0, 28, 8, 258, NULL, 'Vidutinis tiekiamo karšto vandens diferencinis slėgis per 3 minutes', 1253, 1, NULL, NULL),
	(8225, 32, 1, 10, 3, 0, 28, 9, 258, NULL, 'Vidutinis tiekiamo karšto vandens diferencinis slėgis per 4 minutes', 1253, 1, NULL, NULL),
	(8226, 32, 1, 11, 3, 0, 28, 10, 258, NULL, 'Vidutinis tiekiamo karšto vandens diferencinis slėgis per 5 minutes', 1253, 1, NULL, NULL),
	(8227, 32, 1, 12, 3, 0, 28, 11, 258, NULL, 'Vidutinis tiekiamo karšto vandens diferencinis slėgis per 10 minučių', 1253, 1, NULL, NULL),
	(8228, 32, 1, 13, 3, 0, 28, 12, 258, NULL, 'Vidutinis tiekiamo karšto vandens diferencinis slėgis per 15 minučių', 1253, 2, NULL, NULL),
	(8229, 32, 1, 14, 3, 0, 28, 13, 258, NULL, 'Vidutinis tiekiamo karšto vandens diferencinis slėgis per 20 minučių', 1253, 2, NULL, NULL),
	(8230, 32, 2, 1, 3, 0, 28, 1, 258, NULL, 'Vidutinis grįžtamo karšto vandens diferencinis slėgis per minutę', 1255, 1, NULL, NULL),
	(8231, 32, 2, 2, 3, 0, 28, 2, 258, NULL, 'Vidutinis grįžtamo karšto vandens diferencinis slėgis per 2 minutes', 1255, 1, NULL, NULL),
	(8232, 32, 2, 3, 3, 0, 28, 3, 258, NULL, 'Vidutinis grįžtamo karšto vandens diferencinis slėgis per 30 minučių', 1255, 2, NULL, NULL),
	(8233, 32, 2, 4, 3, 0, 28, 4, 258, NULL, 'Vidutinis grįžtamo karšto vandens diferencinis slėgis per valandą', 1255, 2, NULL, NULL),
	(8234, 32, 2, 5, 3, 0, 28, 5, 258, NULL, 'Vidutinis grįžtamo karšto vandens diferencinis slėgis per parą', 1255, 3, NULL, NULL),
	(8235, 32, 2, 6, 3, 0, 28, 6, 258, NULL, 'Vidutinis grįžtamo karšto vandens diferencinis slėgis per mėnesį', 1255, 4, NULL, NULL),
	(8236, 32, 2, 7, 1, 0, 28, 7, 258, NULL, 'Momentinis grįžtamo karšto vandens diferencinis slėgis', 1254, 6, NULL, NULL),
	(8237, 32, 2, 9, 3, 0, 28, 8, 258, NULL, 'Vidutinis grįžtamo karšto vandens diferencinis slėgis per 3 minutes', 1255, 1, NULL, NULL),
	(8238, 32, 2, 10, 3, 0, 28, 9, 258, NULL, 'Vidutinis grįžtamo karšto vandens diferencinis slėgis per 4 minutes', 1255, 1, NULL, NULL),
	(8239, 32, 2, 11, 3, 0, 28, 10, 258, NULL, 'Vidutinis grįžtamo karšto vandens diferencinis slėgis per 5 minutes', 1255, 1, NULL, NULL),
	(8240, 32, 2, 12, 3, 0, 28, 11, 258, NULL, 'Vidutinis grįžtamo karšto vandens diferencinis slėgis per 10 minučių', 1255, 1, NULL, NULL),
	(8241, 32, 2, 13, 3, 0, 28, 12, 258, NULL, 'Vidutinis grįžtamo karšto vandens diferencinis slėgis per 15 minučių', 1255, 2, NULL, NULL),
	(8242, 32, 2, 14, 3, 0, 28, 13, 258, NULL, 'Vidutinis grįžtamo karšto vandens diferencinis slėgis per 20 minučių', 1255, 2, NULL, NULL),
	(8243, 33, 0, 1, 3, 0, 28, 1, 259, NULL, 'Vidutinis šalto vandens diferencinis slėgis per minutę', 1253, 1, NULL, NULL),
	(8244, 33, 0, 2, 3, 0, 28, 2, 259, NULL, 'Vidutinis šalto vandens diferencinis slėgis per 2 minutes', 1253, 1, NULL, NULL),
	(8245, 33, 0, 3, 3, 0, 28, 3, 259, NULL, 'Vidutinis šalto vandens diferencinis slėgis per 30 minučių', 1253, 2, NULL, NULL),
	(8246, 33, 0, 4, 3, 0, 28, 4, 259, NULL, 'Vidutinis šalto vandens diferencinis slėgis per valandą', 1253, 2, NULL, NULL),
	(8247, 33, 0, 5, 3, 0, 28, 5, 259, NULL, 'Vidutinis šalto vandens diferencinis slėgis per parą', 1253, 3, NULL, NULL),
	(8248, 33, 0, 6, 3, 0, 28, 6, 259, NULL, 'Vidutinis šalto vandens diferencinis slėgis per mėnesį', 1253, 4, NULL, NULL),
	(8249, 33, 0, 7, 1, 0, 28, 7, 259, NULL, 'Momentinis šalto vandens diferencinis slėgis', 1252, 6, NULL, NULL),
	(8250, 33, 0, 9, 3, 0, 28, 8, 259, NULL, 'Vidutinis šalto vandens diferencinis slėgis per 3 minutes', 1253, 1, NULL, NULL),
	(8251, 33, 0, 10, 3, 0, 28, 9, 259, NULL, 'Vidutinis šalto vandens diferencinis slėgis per 4 minutes', 1253, 1, NULL, NULL),
	(8252, 33, 0, 11, 3, 0, 28, 10, 259, NULL, 'Vidutinis šalto vandens diferencinis slėgis per 5 minutes', 1253, 1, NULL, NULL),
	(8253, 33, 0, 12, 3, 0, 28, 11, 259, NULL, 'Vidutinis šalto vandens diferencinis slėgis per 10 minučių', 1253, 1, NULL, NULL),
	(8254, 33, 0, 13, 3, 0, 28, 12, 259, NULL, 'Vidutinis šalto vandens diferencinis slėgis per 15 minučių', 1253, 2, NULL, NULL),
	(8255, 33, 0, 14, 3, 0, 28, 13, 259, NULL, 'Vidutinis šalto vandens diferencinis slėgis per 20 minučių', 1253, 2, NULL, NULL),
	(8256, 143, 3, 1, 3, 0, 28, 1, 156, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens slėgių skirtumas per minutę', NULL, 1, NULL, NULL),
	(8257, 143, 3, 2, 3, 0, 28, 2, 156, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens slėgių skirtumas per 2 minutes', NULL, 1, NULL, NULL),
	(8258, 143, 3, 3, 3, 0, 28, 3, 156, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens slėgių skirtumas per 30 minučių', NULL, 2, NULL, NULL),
	(8259, 143, 3, 4, 3, 0, 28, 4, 156, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens slėgių skirtumas per valandą', NULL, 2, NULL, NULL),
	(8260, 143, 3, 5, 3, 0, 28, 5, 156, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens slėgių skirtumas per parą', NULL, 3, NULL, NULL),
	(8261, 143, 3, 6, 3, 0, 28, 6, 156, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens slėgių skirtumas per mėnesį', NULL, 4, NULL, NULL),
	(8262, 143, 3, 7, 1, 0, 28, 7, 156, NULL, 'Momentinis tiekiamo ir grįžtamo karšto vandens slėgių skirtumas', NULL, 6, NULL, NULL),
	(8263, 143, 3, 9, 3, 0, 28, 8, 156, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens slėgių skirtumas per 3 minutes', NULL, 1, NULL, NULL),
	(8264, 143, 3, 10, 3, 0, 28, 9, 156, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens slėgių skirtumas per 4 minutes', NULL, 1, NULL, NULL),
	(8265, 143, 3, 11, 3, 0, 28, 10, 156, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens slėgių skirtumas per 5 minutes', NULL, 1, NULL, NULL),
	(8266, 143, 3, 12, 3, 0, 28, 11, 156, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens slėgių skirtumas per 10 minučių', NULL, 1, NULL, NULL),
	(8267, 143, 3, 13, 3, 0, 28, 12, 156, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens slėgių skirtumas per 15 minučių', NULL, 2, NULL, NULL),
	(8268, 143, 3, 14, 3, 0, 28, 13, 156, NULL, 'Vidutinis tiekiamo ir grįžtamo karšto vandens slėgių skirtumas per 20 minučių', NULL, 2, NULL, NULL),
	(8269, 52, -4, 1, 3, 0, 28, 1, 69, NULL, 'Vidutinis pamaitinimo vandens slėgis per minutę', 1086, 1, NULL, NULL),
	(8270, 52, -4, 2, 3, 0, 28, 2, 69, NULL, 'Vidutinis pamaitinimo vandens slėgis per 2 minutes', 1086, 1, NULL, NULL),
	(8271, 52, -4, 3, 3, 0, 28, 3, 69, NULL, 'Vidutinis pamaitinimo vandens slėgis per 30 minučių', 1086, 2, NULL, NULL),
	(8272, 52, -4, 9, 3, 0, 28, 8, 69, NULL, 'Vidutinis pamaitinimo vandens slėgis per 3 minutes', 1086, 1, NULL, NULL),
	(8273, 52, -4, 10, 3, 0, 28, 9, 69, NULL, 'Vidutinis pamaitinimo vandens slėgis per 4 minutes', 1086, 1, NULL, NULL),
	(8274, 52, -4, 11, 3, 0, 28, 10, 69, NULL, 'Vidutinis pamaitinimo vandens slėgis per 5 minutes', 1086, 1, NULL, NULL),
	(8275, 52, -4, 12, 3, 0, 28, 11, 69, NULL, 'Vidutinis pamaitinimo vandens slėgis per 10 minučių', 1086, 1, NULL, NULL),
	(8276, 52, -4, 13, 3, 0, 28, 12, 69, NULL, 'Vidutinis pamaitinimo vandens slėgis per 15 minučių', 1086, 2, NULL, NULL),
	(8277, 52, -4, 14, 3, 0, 28, 13, 69, NULL, 'Vidutinis pamaitinimo vandens slėgis per 20 minučių', 1086, 2, NULL, NULL),
	(8278, 59, 3, 8, 2, 0, 2, 7, 51, NULL, 'Suminis sunaudotos karšto vandens šilumos kiekis', 1239, 5, NULL, NULL),
	(8279, 209, 1, 1, 2, 0, 2, 1, 222, NULL, 'Tiekiamo šilumnešio pilnosios šilumos kiekis per minutę', NULL, 1, NULL, NULL),
	(8280, 209, 1, 1, 3, 0, 1, 1, 221, NULL, 'Vidutinė tiekiamo šilumnešio pilnoji šilumos galia per minutę', NULL, 1, NULL, NULL),
	(8281, 209, 1, 2, 2, 0, 2, 2, 222, NULL, 'Tiekiamo šilumnešio pilnosios šilumos kiekis per 2 minutes', NULL, 1, NULL, NULL),
	(8282, 209, 1, 2, 3, 0, 1, 2, 221, NULL, 'Vidutinė tiekiamo šilumnešio pilnoji šilumos galia per 2 minutes', NULL, 1, NULL, NULL),
	(8283, 209, 1, 3, 2, 0, 2, 3, 222, NULL, 'Tiekiamo šilumnešio pilnosios šilumos kiekis per 30 minučių', NULL, 2, NULL, NULL),
	(8284, 209, 1, 3, 3, 0, 1, 3, 221, NULL, 'Vidutinė tiekiamo šilumnešio pilnoji šilumos galia per 30 minučių', NULL, 2, NULL, NULL),
	(8285, 209, 1, 4, 2, 0, 2, 4, 222, NULL, 'Tiekiamo šilumnešio pilnosios šilumos kiekis per valandą', NULL, 2, NULL, NULL),
	(8286, 209, 1, 4, 3, 0, 1, 4, 221, NULL, 'Vidutinė tiekiamo šilumnešio pilnoji šilumos galia per valandą', NULL, 2, NULL, NULL),
	(8287, 209, 1, 5, 2, 0, 2, 5, 222, NULL, 'Tiekiamo šilumnešio pilnosios šilumos kiekis per parą', NULL, 3, NULL, NULL),
	(8288, 209, 1, 5, 3, 0, 1, 5, 221, NULL, 'Vidutinė tiekiamo šilumnešio pilnoji šilumos galia per parą', NULL, 3, NULL, NULL),
	(8289, 209, 1, 6, 2, 0, 2, 6, 222, NULL, 'Tiekiamo šilumnešio pilnosios šilumos kiekis per mėnesį', NULL, 4, NULL, NULL),
	(8290, 209, 1, 6, 3, 0, 1, 6, 221, NULL, 'Vidutinė tiekiamo šilumnešio pilnoji šilumos galia per mėnesį', NULL, 4, NULL, NULL),
	(8291, 209, 1, 7, 1, 0, 1, 7, 221, NULL, 'Momentinė tiekiamo šilumnešio pilnoji šilumos galia', NULL, 6, NULL, NULL),
	(8292, 209, 1, 9, 2, 0, 2, 8, 222, NULL, 'Tiekiamo šilumnešio pilnosios šilumos kiekis per 3 minutes', NULL, 1, NULL, NULL),
	(8293, 209, 1, 9, 3, 0, 1, 8, 221, NULL, 'Vidutinė tiekiamo šilumnešio pilnoji šilumos galia per 3 minutes', NULL, 1, NULL, NULL),
	(8294, 209, 1, 10, 2, 0, 2, 9, 222, NULL, 'Tiekiamo šilumnešio pilnosios šilumos kiekis per 4 minutes', NULL, 1, NULL, NULL),
	(8295, 209, 1, 10, 3, 0, 1, 9, 221, NULL, 'Vidutinė tiekiamo šilumnešio pilnoji šilumos galia per 4 minutes', NULL, 1, NULL, NULL),
	(8296, 209, 1, 11, 2, 0, 2, 10, 222, NULL, 'Tiekiamo šilumnešio pilnosios šilumos kiekis per 5 minutes', NULL, 1, NULL, NULL),
	(8297, 209, 1, 11, 3, 0, 1, 10, 221, NULL, 'Vidutinė tiekiamo šilumnešio pilnoji šilumos galia per 5 minutes', NULL, 1, NULL, NULL),
	(8298, 209, 1, 12, 2, 0, 2, 11, 222, NULL, 'Tiekiamo šilumnešio pilnosios šilumos kiekis per 10 minučių', NULL, 1, NULL, NULL),
	(8299, 209, 1, 12, 3, 0, 1, 11, 221, NULL, 'Vidutinė tiekiamo šilumnešio pilnoji šilumos galia per 10 minučių', NULL, 1, NULL, NULL),
	(8300, 209, 1, 13, 2, 0, 2, 12, 222, NULL, 'Tiekiamo šilumnešio pilnosios šilumos kiekis per 15 minučių', NULL, 2, NULL, NULL),
	(8301, 209, 1, 13, 3, 0, 1, 12, 221, NULL, 'Vidutinė tiekiamo šilumnešio pilnoji šilumos galia per 15 minučių', NULL, 2, NULL, NULL),
	(8302, 209, 1, 14, 2, 0, 2, 13, 222, NULL, 'Tiekiamo šilumnešio pilnosios šilumos kiekis per 20 minučių', NULL, 2, NULL, NULL),
	(8303, 209, 1, 14, 3, 0, 1, 13, 221, NULL, 'Vidutinė tiekiamo šilumnešio pilnoji šilumos galia per 20 minučių', NULL, 2, NULL, NULL),
	(8304, 209, 2, 1, 2, 0, 2, 1, 222, NULL, 'Grįžtamo šilumnešio pilnosios šilumos kiekis per minutę', NULL, 1, NULL, NULL),
	(8305, 209, 2, 1, 3, 0, 1, 1, 221, NULL, 'Vidutinė grįžtamo šilumnešio pilnoji šilumos galia per minutę', NULL, 1, NULL, NULL),
	(8306, 209, 2, 2, 2, 0, 2, 2, 222, NULL, 'Grįžtamo šilumnešio pilnosios šilumos kiekis per 2 minutes', NULL, 1, NULL, NULL),
	(8307, 209, 2, 2, 3, 0, 1, 2, 221, NULL, 'Vidutinė grįžtamo šilumnešio pilnoji šilumos galia per 2 minutes', NULL, 1, NULL, NULL),
	(8308, 209, 2, 3, 2, 0, 2, 3, 222, NULL, 'Grįžtamo šilumnešio pilnosios šilumos kiekis per 30 minučių', NULL, 2, NULL, NULL),
	(8309, 209, 2, 3, 3, 0, 1, 3, 221, NULL, 'Vidutinė grįžtamo šilumnešio pilnoji šilumos galia per 30 minučių', NULL, 2, NULL, NULL),
	(8310, 209, 2, 4, 2, 0, 2, 4, 222, NULL, 'Grįžtamo šilumnešio pilnosios šilumos kiekis per valandą', NULL, 2, NULL, NULL),
	(8311, 209, 2, 4, 3, 0, 1, 4, 221, NULL, 'Vidutinė grįžtamo šilumnešio pilnoji šilumos galia per valandą', NULL, 2, NULL, NULL),
	(8312, 209, 2, 5, 2, 0, 2, 5, 222, NULL, 'Grįžtamo šilumnešio pilnosios šilumos kiekis per parą', NULL, 3, NULL, NULL),
	(8313, 209, 2, 5, 3, 0, 1, 5, 221, NULL, 'Vidutinė grįžtamo šilumnešio pilnoji šilumos galia per parą', NULL, 3, NULL, NULL),
	(8314, 209, 2, 6, 2, 0, 2, 6, 222, NULL, 'Grįžtamo šilumnešio pilnosios šilumos kiekis per mėnesį', NULL, 4, NULL, NULL),
	(8315, 209, 2, 6, 3, 0, 1, 6, 221, NULL, 'Vidutinė grįžtamo šilumnešio pilnoji šilumos galia per mėnesį', NULL, 4, NULL, NULL),
	(8316, 209, 2, 7, 1, 0, 1, 7, 221, NULL, 'Momentinė grįžtamo šilumnešio pilnoji šilumos galia', NULL, 6, NULL, NULL),
	(8317, 209, 2, 9, 2, 0, 2, 8, 222, NULL, 'Grįžtamo šilumnešio pilnosios šilumos kiekis per 3 minutes', NULL, 1, NULL, NULL),
	(8318, 209, 2, 9, 3, 0, 1, 8, 221, NULL, 'Vidutinė grįžtamo šilumnešio pilnoji šilumos galia per 3 minutes', NULL, 1, NULL, NULL),
	(8319, 209, 2, 10, 2, 0, 2, 9, 222, NULL, 'Grįžtamo šilumnešio pilnosios šilumos kiekis per 4 minutes', NULL, 1, NULL, NULL),
	(8320, 209, 2, 10, 3, 0, 1, 9, 221, NULL, 'Vidutinė grįžtamo šilumnešio pilnoji šilumos galia per 4 minutes', NULL, 1, NULL, NULL),
	(8321, 209, 2, 11, 2, 0, 2, 10, 222, NULL, 'Grįžtamo šilumnešio pilnosios šilumos kiekis per 5 minutes', NULL, 1, NULL, NULL),
	(8322, 209, 2, 11, 3, 0, 1, 10, 221, NULL, 'Vidutinė grįžtamo šilumnešio pilnoji šilumos galia per 5 minutes', NULL, 1, NULL, NULL),
	(8323, 209, 2, 12, 2, 0, 2, 11, 222, NULL, 'Grįžtamo šilumnešio pilnosios šilumos kiekis per 10 minučių', NULL, 1, NULL, NULL),
	(8324, 209, 2, 12, 3, 0, 1, 11, 221, NULL, 'Vidutinė grįžtamo šilumnešio pilnoji šilumos galia per 10 minučių', NULL, 1, NULL, NULL),
	(8325, 209, 2, 13, 2, 0, 2, 12, 222, NULL, 'Grįžtamo šilumnešio pilnosios šilumos kiekis per 15 minučių', NULL, 2, NULL, NULL),
	(8326, 209, 2, 13, 3, 0, 1, 12, 221, NULL, 'Vidutinė grįžtamo šilumnešio pilnoji šilumos galia per 15 minučių', NULL, 2, NULL, NULL),
	(8327, 209, 2, 14, 2, 0, 2, 13, 222, NULL, 'Grįžtamo šilumnešio pilnosios šilumos kiekis per 20 minučių', NULL, 2, NULL, NULL),
	(8328, 209, 2, 14, 3, 0, 1, 13, 221, NULL, 'Vidutinė grįžtamo šilumnešio pilnoji šilumos galia per 20 minučių', NULL, 2, NULL, NULL),
	(8329, 209, 3, 1, 2, 0, 2, 1, 222, NULL, 'Sunaudotos šilumnešio pilnosios šilumos kiekis per minutę', NULL, 1, NULL, NULL),
	(8330, 209, 3, 1, 3, 0, 1, 1, 221, NULL, 'Vidutinė sunaudota šilumnešio pilnoji šilumos galia per minutę', NULL, 1, NULL, NULL),
	(8331, 209, 3, 2, 2, 0, 2, 2, 222, NULL, 'Sunaudotos šilumnešio pilnosios šilumos kiekis per 2 minutes', NULL, 1, NULL, NULL),
	(8332, 209, 3, 2, 3, 0, 1, 2, 221, NULL, 'Vidutinė sunaudota šilumnešio pilnoji šilumos galia per 2 minutes', NULL, 1, NULL, NULL),
	(8333, 209, 3, 3, 2, 0, 2, 3, 222, NULL, 'Sunaudotos šilumnešio pilnosios šilumos kiekis per 30 minučių', NULL, 2, NULL, NULL),
	(8334, 209, 3, 3, 3, 0, 1, 3, 221, NULL, 'Vidutinė sunaudota šilumnešio pilnoji šilumos galia per 30 minučių', NULL, 2, NULL, NULL),
	(8335, 209, 3, 4, 2, 0, 2, 4, 222, NULL, 'Sunaudotos šilumnešio pilnosios šilumos kiekis per valandą', NULL, 2, NULL, NULL),
	(8336, 209, 3, 4, 3, 0, 1, 4, 221, NULL, 'Vidutinė sunaudota šilumnešio pilnoji šilumos galia per valandą', NULL, 2, NULL, NULL),
	(8337, 209, 3, 5, 2, 0, 2, 5, 222, NULL, 'Sunaudotos šilumnešio pilnosios šilumos kiekis per parą', NULL, 3, NULL, NULL),
	(8338, 209, 3, 5, 3, 0, 1, 5, 221, NULL, 'Vidutinė sunaudota šilumnešio pilnoji šilumos galia per parą', NULL, 3, NULL, NULL),
	(8339, 209, 3, 6, 2, 0, 2, 6, 222, NULL, 'Sunaudotos šilumnešio pilnosios šilumos kiekis per mėnesį', NULL, 4, NULL, NULL),
	(8340, 209, 3, 6, 3, 0, 1, 6, 221, NULL, 'Vidutinė sunaudota šilumnešio pilnoji šilumos galia per mėnesį', NULL, 4, NULL, NULL),
	(8341, 209, 3, 7, 1, 0, 1, 7, 221, NULL, 'Momentinė sunaudota šilumnešio pilnoji šilumos galia', NULL, 6, NULL, NULL),
	(8342, 209, 3, 8, 2, 0, 2, 7, 222, NULL, 'Suminis sunaudotos šilumnešio pilnosios šilumos kiekis', NULL, 5, NULL, NULL),
	(8343, 209, 3, 9, 2, 0, 2, 8, 222, NULL, 'Sunaudotos šilumnešio pilnosios šilumos kiekis per 3 minutes', NULL, 1, NULL, NULL),
	(8344, 209, 3, 9, 3, 0, 1, 8, 221, NULL, 'Vidutinė sunaudota šilumnešio pilnoji šilumos galia per 3 minutes', NULL, 1, NULL, NULL),
	(8345, 209, 3, 10, 2, 0, 2, 9, 222, NULL, 'Sunaudotos šilumnešio pilnosios šilumos kiekis per 4 minutes', NULL, 1, NULL, NULL),
	(8346, 209, 3, 10, 3, 0, 1, 9, 221, NULL, 'Vidutinė sunaudota šilumnešio pilnoji šilumos galia per 4 minutes', NULL, 1, NULL, NULL),
	(8347, 209, 3, 11, 2, 0, 2, 10, 222, NULL, 'Sunaudotos šilumnešio pilnosios šilumos kiekis per 5 minutes', NULL, 1, NULL, NULL),
	(8348, 209, 3, 11, 3, 0, 1, 10, 221, NULL, 'Vidutinė sunaudota šilumnešio pilnoji šilumos galia per 5 minutes', NULL, 1, NULL, NULL),
	(8349, 209, 3, 12, 2, 0, 2, 11, 222, NULL, 'Sunaudotos šilumnešio pilnosios šilumos kiekis per 10 minučių', NULL, 1, NULL, NULL),
	(8350, 209, 3, 12, 3, 0, 1, 11, 221, NULL, 'Vidutinė sunaudota šilumnešio pilnoji šilumos galia per 10 minučių', NULL, 1, NULL, NULL),
	(8351, 209, 3, 13, 2, 0, 2, 12, 222, NULL, 'Sunaudotos šilumnešio pilnosios šilumos kiekis per 15 minučių', NULL, 2, NULL, NULL),
	(8352, 209, 3, 13, 3, 0, 1, 12, 221, NULL, 'Vidutinė sunaudota šilumnešio pilnoji šilumos galia per 15 minučių', NULL, 2, NULL, NULL),
	(8353, 209, 3, 14, 2, 0, 2, 13, 222, NULL, 'Sunaudotos šilumnešio pilnosios šilumos kiekis per 20 minučių', NULL, 2, NULL, NULL),
	(8354, 209, 3, 14, 3, 0, 1, 13, 221, NULL, 'Vidutinė sunaudota šilumnešio pilnoji šilumos galia per 20 minučių', NULL, 2, NULL, NULL),
	(8355, 53, -4, 1, 2, 0, 2, 1, 71, NULL, 'Pamaitinimo vandens šilumos kiekis per minutę', 1082, 1, NULL, NULL),
	(8356, 53, -4, 1, 3, 0, 1, 1, 70, NULL, 'Vidutinė pamaitinimo vandens šilumos galia per minutę', 1729, 1, NULL, NULL),
	(8357, 53, -4, 2, 2, 0, 2, 2, 71, NULL, 'Pamaitinimo vandens šilumos kiekis per 2 minutes', 1082, 1, NULL, NULL),
	(8358, 53, -4, 2, 3, 0, 1, 2, 70, NULL, 'Vidutinė pamaitinimo vandens šilumos galia per 2 minutes', 1729, 1, NULL, NULL),
	(8359, 53, -4, 3, 2, 0, 2, 3, 71, NULL, 'Pamaitinimo vandens šilumos kiekis per 30 minučių', 1082, 2, NULL, NULL),
	(8360, 53, -4, 3, 3, 0, 1, 3, 70, NULL, 'Vidutinė pamaitinimo vandens šilumos galia per 30 minučių', 1729, 2, NULL, NULL),
	(8361, 53, -4, 4, 3, 0, 1, 4, 70, NULL, 'Vidutinė pamaitinimo vandens šilumos galia per valandą', 1729, 2, NULL, NULL),
	(8362, 53, -4, 5, 3, 0, 1, 5, 70, NULL, 'Vidutinė pamaitinimo vandens šilumos galia per parą', 1729, 3, NULL, NULL),
	(8363, 53, -4, 6, 3, 0, 1, 6, 70, NULL, 'Vidutinė pamaitinimo vandens šilumos galia per mėnesį', 1729, 4, NULL, NULL),
	(8364, 53, -4, 8, 2, 0, 2, 3, 71, NULL, 'Suminis pamaitinimo vandens šilumos kiekis, fiksuojamas kas 30 minučių', 1030, 5, NULL, NULL),
	(8365, 53, -4, 8, 2, 0, 2, 5, 71, NULL, 'Suminis pamaitinimo vandens šilumos kiekis, fiksuojamas kas parą', 1030, 5, NULL, NULL),
	(8366, 53, -4, 8, 2, 0, 2, 6, 71, NULL, 'Suminis pamaitinimo vandens šilumos kiekis, fiksuojamas kas mėnesį', 1030, 5, NULL, NULL),
	(8367, 53, -4, 8, 2, 0, 2, 10, 71, NULL, 'Suminis pamaitinimo vandens šilumos kiekis, fiksuojamas kas 5 minutes', 1030, 5, NULL, NULL),
	(8368, 53, -4, 8, 2, 0, 2, 12, 71, NULL, 'Suminis pamaitinimo vandens šilumos kiekis, fiksuojamas kas 15 minučių', 1030, 5, NULL, NULL),
	(8369, 53, -4, 8, 2, 0, 2, 13, 71, NULL, 'Suminis pamaitinimo vandens šilumos kiekis, fiksuojamas kas 20 minučių', 1030, 5, NULL, NULL),
	(8370, 53, -4, 9, 2, 0, 2, 8, 71, NULL, 'Pamaitinimo vandens šilumos kiekis per 3 minutes', 1082, 1, NULL, NULL),
	(8371, 53, -4, 9, 3, 0, 1, 8, 70, NULL, 'Vidutinė pamaitinimo vandens šilumos galia per 3 minutes', 1729, 1, NULL, NULL),
	(8372, 53, -4, 10, 2, 0, 2, 9, 71, NULL, 'Pamaitinimo vandens šilumos kiekis per 4 minutes', 1082, 1, NULL, NULL),
	(8373, 53, -4, 10, 3, 0, 1, 9, 70, NULL, 'Vidutinė pamaitinimo vandens šilumos galia per 4 minutes', 1729, 1, NULL, NULL),
	(8374, 53, -4, 11, 2, 0, 2, 10, 71, NULL, 'Pamaitinimo vandens šilumos kiekis per 5 minutes', 1082, 1, NULL, NULL),
	(8375, 53, -4, 11, 3, 0, 1, 10, 70, NULL, 'Vidutinė pamaitinimo vandens šilumos galia per 5 minutes', 1729, 1, NULL, NULL),
	(8376, 53, -4, 12, 2, 0, 2, 11, 71, NULL, 'Pamaitinimo vandens šilumos kiekis per 10 minučių', 1082, 1, NULL, NULL),
	(8377, 53, -4, 12, 3, 0, 1, 11, 70, NULL, 'Vidutinė pamaitinimo vandens šilumos galia per 10 minučių', 1729, 1, NULL, NULL),
	(8378, 53, -4, 13, 2, 0, 2, 12, 71, NULL, 'Pamaitinimo vandens šilumos kiekis per 15 minučių', 1082, 2, NULL, NULL),
	(8379, 53, -4, 13, 3, 0, 1, 12, 70, NULL, 'Vidutinė pamaitinimo vandens šilumos galia per 15 minučių', 1729, 2, NULL, NULL),
	(8380, 53, -4, 14, 2, 0, 2, 13, 71, NULL, 'Pamaitinimo vandens šilumos kiekis per 20 minučių', 1082, 2, NULL, NULL),
	(8381, 53, -4, 14, 3, 0, 1, 13, 70, NULL, 'Vidutinė pamaitinimo vandens šilumos galia per 20 minučių', 1729, 2, NULL, NULL),
	(8382, 192, 0, 1, 2, 0, 2, 1, 260, NULL, 'Šilumos kiekis per minutę', 1064, 1, NULL, NULL),
	(8383, 192, 0, 2, 2, 0, 2, 2, 260, NULL, 'Šilumos kiekis per 2 minutes', 1064, 1, NULL, NULL),
	(8384, 192, 0, 3, 2, 0, 2, 3, 260, NULL, 'Šilumos kiekis per 30 minučių', 1064, 2, NULL, NULL),
	(8385, 192, 0, 4, 2, 0, 2, 4, 260, NULL, 'Šilumos kiekis per valandą', 1064, 2, NULL, NULL),
	(8386, 192, 0, 5, 2, 0, 2, 5, 260, NULL, 'Šilumos kiekis per parą', 1064, 3, NULL, NULL),
	(8387, 192, 0, 6, 2, 0, 2, 6, 260, NULL, 'Šilumos kiekis per mėnesį', 1064, 4, NULL, NULL),
	(8388, 192, 0, 8, 2, 0, 2, 3, 260, NULL, 'Suminis šilumos kiekis, fiksuojamas kas 30 minučių', 1001, 5, NULL, NULL),
	(8389, 192, 0, 8, 2, 0, 2, 4, 260, NULL, 'Suminis šilumos kiekis, fiksuojamas kas valandą', 1001, 5, NULL, NULL),
	(8390, 192, 0, 8, 2, 0, 2, 5, 260, NULL, 'Suminis šilumos kiekis, fiksuojamas kas parą', 1001, 5, NULL, NULL),
	(8391, 192, 0, 8, 2, 0, 2, 6, 260, NULL, 'Suminis šilumos kiekis, fiksuojamas kas mėnesį', 1001, 5, NULL, NULL),
	(8392, 192, 0, 8, 2, 0, 2, 7, 260, NULL, 'Suminis šilumos kiekis', 1001, 5, NULL, NULL),
	(8393, 192, 0, 8, 2, 0, 2, 10, 260, NULL, 'Suminis šilumos kiekis, fiksuojamas kas 5 minutes', 1001, 5, NULL, NULL),
	(8394, 192, 0, 8, 2, 0, 2, 12, 260, NULL, 'Suminis šilumos kiekis, fiksuojamas kas 15 minučių', 1001, 5, NULL, NULL),
	(8395, 192, 0, 8, 2, 0, 2, 13, 260, NULL, 'Suminis šilumos kiekis, fiksuojamas kas 20 minučių', 1001, 5, NULL, NULL),
	(8396, 192, 0, 9, 2, 0, 2, 8, 260, NULL, 'Šilumos kiekis per 3 minutes', 1064, 1, NULL, NULL),
	(8397, 192, 0, 10, 2, 0, 2, 9, 260, NULL, 'Šilumos kiekis per 4 minutes', 1064, 1, NULL, NULL),
	(8398, 192, 0, 11, 2, 0, 2, 10, 260, NULL, 'Šilumos kiekis per 5 minutes', 1064, 1, NULL, NULL),
	(8399, 192, 0, 12, 2, 0, 2, 11, 260, NULL, 'Šilumos kiekis per 10 minučių', 1064, 1, NULL, NULL),
	(8400, 192, 0, 13, 2, 0, 2, 12, 260, NULL, 'Šilumos kiekis per 15 minučių', 1064, 2, NULL, NULL),
	(8401, 192, 0, 14, 2, 0, 2, 13, 260, NULL, 'Šilumos kiekis per 20 minučių', 1064, 2, NULL, NULL),
	(8402, 192, 1, 1, 2, 0, 2, 1, 260, NULL, 'Tiekiamos šilumos kiekis per minutę', 1064, 1, NULL, NULL),
	(8403, 192, 1, 2, 2, 0, 2, 2, 260, NULL, 'Tiekiamos šilumos kiekis per 2 minutes', 1064, 1, NULL, NULL),
	(8404, 192, 1, 3, 2, 0, 2, 3, 260, NULL, 'Tiekiamos šilumos kiekis per 30 minučių', 1064, 2, NULL, NULL),
	(8405, 192, 1, 4, 2, 0, 2, 4, 260, NULL, 'Tiekiamos šilumos kiekis per valandą', 1064, 2, NULL, NULL),
	(8406, 192, 1, 5, 2, 0, 2, 5, 260, NULL, 'Tiekiamos šilumos kiekis per parą', 1064, 3, NULL, NULL),
	(8407, 192, 1, 6, 2, 0, 2, 6, 260, NULL, 'Tiekiamos šilumos kiekis per mėnesį', 1064, 4, NULL, NULL),
	(8408, 192, 1, 8, 2, 0, 2, 3, 260, NULL, 'Suminis tiekiamos šilumos kiekis, fiksuojamas kas 30 minučių', 1001, 5, NULL, NULL),
	(8409, 192, 1, 8, 2, 0, 2, 4, 260, NULL, 'Suminis tiekiamos šilumos kiekis, fiksuojamas kas valandą', 1001, 5, NULL, NULL),
	(8410, 192, 1, 8, 2, 0, 2, 5, 260, NULL, 'Suminis tiekiamos šilumos kiekis, fiksuojamas kas parą', 1001, 5, NULL, NULL),
	(8411, 192, 1, 8, 2, 0, 2, 6, 260, NULL, 'Suminis tiekiamos šilumos kiekis, fiksuojamas kas mėnesį', 1001, 5, NULL, NULL),
	(8412, 192, 1, 8, 2, 0, 2, 7, 260, NULL, 'Suminis tiekiamos šilumos kiekis', 1001, 5, NULL, NULL),
	(8413, 192, 1, 8, 2, 0, 2, 10, 260, NULL, 'Suminis tiekiamos šilumos kiekis, fiksuojamas kas 5 minutes', 1001, 5, NULL, NULL),
	(8414, 192, 1, 8, 2, 0, 2, 12, 260, NULL, 'Suminis tiekiamos šilumos kiekis, fiksuojamas kas 15 minučių', 1001, 5, NULL, NULL),
	(8415, 192, 1, 8, 2, 0, 2, 13, 260, NULL, 'Suminis tiekiamos šilumos kiekis, fiksuojamas kas 20 minučių', 1001, 5, NULL, NULL),
	(8416, 192, 1, 9, 2, 0, 2, 8, 260, NULL, 'Tiekiamos šilumos kiekis per 3 minutes', 1064, 1, NULL, NULL),
	(8417, 192, 1, 10, 2, 0, 2, 9, 260, NULL, 'Tiekiamos šilumos kiekis per 4 minutes', 1064, 1, NULL, NULL),
	(8418, 192, 1, 11, 2, 0, 2, 10, 260, NULL, 'Tiekiamos šilumos kiekis per 5 minutes', 1064, 1, NULL, NULL),
	(8419, 192, 1, 12, 2, 0, 2, 11, 260, NULL, 'Tiekiamos šilumos kiekis per 10 minučių', 1064, 1, NULL, NULL),
	(8420, 192, 1, 13, 2, 0, 2, 12, 260, NULL, 'Tiekiamos šilumos kiekis per 15 minučių', 1064, 2, NULL, NULL),
	(8421, 192, 1, 14, 2, 0, 2, 13, 260, NULL, 'Tiekiamos šilumos kiekis per 20 minučių', 1064, 2, NULL, NULL),
	(8422, 192, 2, 1, 2, 0, 2, 1, 260, NULL, 'Grįžtamos šilumos kiekis per minutę', 1076, 1, NULL, NULL),
	(8423, 192, 2, 2, 2, 0, 2, 2, 260, NULL, 'Grįžtamos šilumos kiekis per 2 minutes', 1076, 1, NULL, NULL),
	(8424, 192, 2, 3, 2, 0, 2, 3, 260, NULL, 'Grįžtamos šilumos kiekis per 30 minučių', 1076, 2, NULL, NULL),
	(8425, 192, 2, 4, 2, 0, 2, 4, 260, NULL, 'Grįžtamos šilumos kiekis per valandą', 1076, 2, NULL, NULL),
	(8426, 192, 2, 5, 2, 0, 2, 5, 260, NULL, 'Grįžtamos šilumos kiekis per parą', 1076, 3, NULL, NULL),
	(8427, 192, 2, 6, 2, 0, 2, 6, 260, NULL, 'Grįžtamos šilumos kiekis per mėnesį', 1076, 4, NULL, NULL),
	(8428, 192, 2, 8, 2, 0, 2, 3, 260, NULL, 'Suminis grįžtamos šilumos kiekis, fiksuojamas kas 30 minučių', 1019, 5, NULL, NULL),
	(8429, 192, 2, 8, 2, 0, 2, 4, 260, NULL, 'Suminis grįžtamos šilumos kiekis, fiksuojamas kas valandą', 1019, 5, NULL, NULL),
	(8430, 192, 2, 8, 2, 0, 2, 5, 260, NULL, 'Suminis grįžtamos šilumos kiekis, fiksuojamas kas parą', 1019, 5, NULL, NULL),
	(8431, 192, 2, 8, 2, 0, 2, 6, 260, NULL, 'Suminis grįžtamos šilumos kiekis, fiksuojamas kas mėnesį', 1019, 5, NULL, NULL),
	(8432, 192, 2, 8, 2, 0, 2, 7, 260, NULL, 'Suminis grįžtamos šilumos kiekis', 1019, 5, NULL, NULL),
	(8433, 192, 2, 8, 2, 0, 2, 10, 260, NULL, 'Suminis grįžtamos šilumos kiekis, fiksuojamas kas 5 minutes', 1019, 5, NULL, NULL),
	(8434, 192, 2, 8, 2, 0, 2, 12, 260, NULL, 'Suminis grįžtamos šilumos kiekis, fiksuojamas kas 15 minučių', 1019, 5, NULL, NULL),
	(8435, 192, 2, 8, 2, 0, 2, 13, 260, NULL, 'Suminis grįžtamos šilumos kiekis, fiksuojamas kas 20 minučių', 1019, 5, NULL, NULL),
	(8436, 192, 2, 9, 2, 0, 2, 8, 260, NULL, 'Grįžtamos šilumos kiekis per 3 minutes', 1076, 1, NULL, NULL),
	(8437, 192, 2, 10, 2, 0, 2, 9, 260, NULL, 'Grįžtamos šilumos kiekis per 4 minutes', 1076, 1, NULL, NULL),
	(8438, 192, 2, 11, 2, 0, 2, 10, 260, NULL, 'Grįžtamos šilumos kiekis per 5 minutes', 1076, 1, NULL, NULL),
	(8439, 192, 2, 12, 2, 0, 2, 11, 260, NULL, 'Grįžtamos šilumos kiekis per 10 minučių', 1076, 1, NULL, NULL),
	(8440, 192, 2, 13, 2, 0, 2, 12, 260, NULL, 'Grįžtamos šilumos kiekis per 15 minučių', 1076, 2, NULL, NULL),
	(8441, 192, 2, 14, 2, 0, 2, 13, 260, NULL, 'Grįžtamos šilumos kiekis per 20 minučių', 1076, 2, NULL, NULL),
	(8442, 192, 3, 1, 2, 0, 2, 1, 260, NULL, 'Sunaudotos šilumos kiekis per minutę', 1719, 1, NULL, NULL),
	(8443, 192, 3, 2, 2, 0, 2, 2, 260, NULL, 'Sunaudotos šilumos kiekis per 2 minutes', 1719, 1, NULL, NULL),
	(8444, 192, 3, 3, 2, 0, 2, 3, 260, NULL, 'Sunaudotos šilumos kiekis per 30 minučių', 1719, 2, NULL, NULL),
	(8445, 192, 3, 4, 2, 0, 2, 4, 260, NULL, 'Sunaudotos šilumos kiekis per valandą', 1719, 2, NULL, NULL),
	(8446, 192, 3, 5, 2, 0, 2, 5, 260, NULL, 'Sunaudotos šilumos kiekis per parą', 1719, 3, NULL, NULL),
	(8447, 192, 3, 6, 2, 0, 2, 6, 260, NULL, 'Sunaudotos šilumos kiekis per mėnesį', 1719, 4, NULL, NULL),
	(8448, 192, 3, 8, 2, 0, 2, 7, 260, NULL, 'Suminis sunaudotos šilumos kiekis', 1044, 5, NULL, NULL),
	(8449, 192, 3, 9, 2, 0, 2, 8, 260, NULL, 'Sunaudotos šilumos kiekis per 3 minutes', 1719, 1, NULL, NULL),
	(8450, 192, 3, 10, 2, 0, 2, 9, 260, NULL, 'Sunaudotos šilumos kiekis per 4 minutes', 1719, 1, NULL, NULL),
	(8451, 192, 3, 11, 2, 0, 2, 10, 260, NULL, 'Sunaudotos šilumos kiekis per 5 minutes', 1719, 1, NULL, NULL),
	(8452, 192, 3, 12, 2, 0, 2, 11, 260, NULL, 'Sunaudotos šilumos kiekis per 10 minučių', 1719, 1, NULL, NULL),
	(8453, 192, 3, 13, 2, 0, 2, 12, 260, NULL, 'Sunaudotos šilumos kiekis per 15 minučių', 1719, 2, NULL, NULL),
	(8454, 192, 3, 14, 2, 0, 2, 13, 260, NULL, 'Sunaudotos šilumos kiekis per 20 minučių', 1719, 2, NULL, NULL),
	(8455, 192, 0, 1, 3, 0, 1, 1, 331, NULL, 'Vidutinė šilumos galia per minutę', 1716, 1, NULL, NULL),
	(8456, 192, 0, 2, 3, 0, 1, 2, 331, NULL, 'Vidutinė šilumos galia per 2 minutes', 1716, 1, NULL, NULL),
	(8457, 192, 0, 3, 3, 0, 1, 3, 331, NULL, 'Vidutinė šilumos galia per 30 minučių', 1716, 2, NULL, NULL),
	(8458, 192, 0, 4, 3, 0, 1, 4, 331, NULL, 'Vidutinė šilumos galia per valandą', 1716, 2, NULL, NULL),
	(8459, 192, 0, 5, 3, 0, 1, 5, 331, NULL, 'Vidutinė šilumos galia per parą', 1716, 3, NULL, NULL),
	(8460, 192, 0, 6, 3, 0, 1, 6, 331, NULL, 'Vidutinė šilumos galia per mėnesį', 1716, 4, NULL, NULL),
	(8461, 192, 0, 7, 1, 0, 1, 7, 331, NULL, 'Momentinė šilumos galia', 1002, 6, NULL, NULL),
	(8462, 192, 0, 9, 3, 0, 1, 8, 331, NULL, 'Vidutinė šilumos galia per 3 minutes', 1716, 1, NULL, NULL),
	(8463, 192, 0, 10, 3, 0, 1, 9, 331, NULL, 'Vidutinė šilumos galia per 4 minutes', 1716, 1, NULL, NULL),
	(8464, 192, 0, 11, 3, 0, 1, 10, 331, NULL, 'Vidutinė šilumos galia per 5 minutes', 1716, 1, NULL, NULL),
	(8465, 192, 0, 12, 3, 0, 1, 11, 331, NULL, 'Vidutinė šilumos galia per 10 minučių', 1716, 1, NULL, NULL),
	(8466, 192, 0, 13, 3, 0, 1, 12, 331, NULL, 'Vidutinė šilumos galia per 15 minučių', 1716, 2, NULL, NULL),
	(8467, 192, 0, 14, 3, 0, 1, 13, 331, NULL, 'Vidutinė šilumos galia per 20 minučių', 1716, 2, NULL, NULL),
	(8468, 192, 1, 1, 3, 0, 1, 1, 331, NULL, 'Vidutinė tiekiamos šilumos galia per minutę', 1002, 1, NULL, NULL),
	(8469, 192, 1, 2, 3, 0, 1, 2, 331, NULL, 'Vidutinė tiekiamos šilumos galia per 2 minutes', 1002, 1, NULL, NULL),
	(8470, 192, 1, 3, 3, 0, 1, 3, 331, NULL, 'Vidutinė tiekiamos šilumos galia per 30 minučių', 1002, 2, NULL, NULL),
	(8471, 192, 1, 4, 3, 0, 1, 4, 331, NULL, 'Vidutinė tiekiamos šilumos galia per valandą', 1002, 2, NULL, NULL),
	(8472, 192, 1, 5, 3, 0, 1, 5, 331, NULL, 'Vidutinė tiekiamos šilumos galia per parą', 1002, 3, NULL, NULL),
	(8473, 192, 1, 6, 3, 0, 1, 6, 331, NULL, 'Vidutinė tiekiamos šilumos galia per mėnesį', 1002, 4, NULL, NULL),
	(8474, 192, 1, 7, 1, 0, 1, 7, 331, NULL, 'Momentinė tiekiamos šilumos galia', 1002, 6, NULL, NULL),
	(8475, 192, 1, 9, 3, 0, 1, 8, 331, NULL, 'Vidutinė tiekiamos šilumos galia per 3 minutes', 1002, 1, NULL, NULL),
	(8476, 192, 1, 10, 3, 0, 1, 9, 331, NULL, 'Vidutinė tiekiamos šilumos galia per 4 minutes', 1002, 1, NULL, NULL),
	(8477, 192, 1, 11, 3, 0, 1, 10, 331, NULL, 'Vidutinė tiekiamos šilumos galia per 5 minutes', 1002, 1, NULL, NULL),
	(8478, 192, 1, 12, 3, 0, 1, 11, 331, NULL, 'Vidutinė tiekiamos šilumos galia per 10 minučių', 1002, 1, NULL, NULL),
	(8479, 192, 1, 13, 3, 0, 1, 12, 331, NULL, 'Vidutinė tiekiamos šilumos galia per 15 minučių', 1002, 2, NULL, NULL),
	(8480, 192, 1, 14, 3, 0, 1, 13, 331, NULL, 'Vidutinė tiekiamos šilumos galia per 20 minučių', 1002, 2, NULL, NULL),
	(8481, 192, 2, 1, 3, 0, 1, 1, 331, NULL, 'Vidutinė grįžtamos šilumos galia per minutę', 1020, 1, NULL, NULL),
	(8482, 192, 2, 2, 3, 0, 1, 2, 331, NULL, 'Vidutinė grįžtamos šilumos galia per 2 minutes', 1020, 1, NULL, NULL),
	(8483, 192, 2, 3, 3, 0, 1, 3, 331, NULL, 'Vidutinė grįžtamos šilumos galia per 30 minučių', 1020, 2, NULL, NULL),
	(8484, 192, 2, 4, 3, 0, 1, 4, 331, NULL, 'Vidutinė grįžtamos šilumos galia per valandą', 1020, 2, NULL, NULL),
	(8485, 192, 2, 5, 3, 0, 1, 5, 331, NULL, 'Vidutinė grįžtamos šilumos galia per parą', 1020, 3, NULL, NULL),
	(8486, 192, 2, 6, 3, 0, 1, 6, 331, NULL, 'Vidutinė grįžtamos šilumos galia per mėnesį', 1020, 4, NULL, NULL),
	(8487, 192, 2, 7, 1, 0, 1, 7, 331, NULL, 'Momentinė grįžtamos šilumos galia', 1002, 6, NULL, NULL),
	(8488, 192, 2, 9, 3, 0, 1, 8, 331, NULL, 'Vidutinė grįžtamos šilumos galia per 3 minutes', 1020, 1, NULL, NULL),
	(8489, 192, 2, 10, 3, 0, 1, 9, 331, NULL, 'Vidutinė grįžtamos šilumos galia per 4 minutes', 1020, 1, NULL, NULL),
	(8490, 192, 2, 11, 3, 0, 1, 10, 331, NULL, 'Vidutinė grįžtamos šilumos galia per 5 minutes', 1020, 1, NULL, NULL),
	(8491, 192, 2, 12, 3, 0, 1, 11, 331, NULL, 'Vidutinė grįžtamos šilumos galia per 10 minučių', 1020, 1, NULL, NULL),
	(8492, 192, 2, 13, 3, 0, 1, 12, 331, NULL, 'Vidutinė grįžtamos šilumos galia per 15 minučių', 1020, 2, NULL, NULL),
	(8493, 192, 2, 14, 3, 0, 1, 13, 331, NULL, 'Vidutinė grįžtamos šilumos galia per 20 minučių', 1020, 2, NULL, NULL),
	(8494, 192, 3, 1, 3, 0, 1, 1, 331, NULL, 'Vidutinė sunaudota šilumos galia per minutę', 1002, 1, NULL, NULL),
	(8495, 192, 3, 2, 3, 0, 1, 2, 331, NULL, 'Vidutinė sunaudota šilumos galia per 2 minutes', 1002, 1, NULL, NULL),
	(8496, 192, 3, 3, 3, 0, 1, 3, 331, NULL, 'Vidutinė sunaudota šilumos galia per 30 minučių', 1002, 2, NULL, NULL),
	(8497, 192, 3, 4, 3, 0, 1, 4, 331, NULL, 'Vidutinė sunaudota šilumos galia per valandą', 1002, 2, NULL, NULL),
	(8498, 192, 3, 5, 3, 0, 1, 5, 331, NULL, 'Vidutinė sunaudota šilumos galia per parą', 1002, 3, NULL, NULL),
	(8499, 192, 3, 6, 3, 0, 1, 6, 331, NULL, 'Vidutinė sunaudota šilumos galia per mėnesį', 1002, 4, NULL, NULL),
	(8500, 192, 3, 7, 1, 0, 1, 7, 331, NULL, 'Momentinė sunaudota šilumos galia', 1043, 6, NULL, NULL),
	(8501, 192, 3, 9, 3, 0, 1, 8, 331, NULL, 'Vidutinė sunaudota šilumos galia per 3 minutes', 1002, 1, NULL, NULL),
	(8502, 192, 3, 10, 3, 0, 1, 9, 331, NULL, 'Vidutinė sunaudota šilumos galia per 4 minutes', 1002, 1, NULL, NULL),
	(8503, 192, 3, 11, 3, 0, 1, 10, 331, NULL, 'Vidutinė sunaudota šilumos galia per 5 minutes', 1002, 1, NULL, NULL),
	(8504, 192, 3, 12, 3, 0, 1, 11, 331, NULL, 'Vidutinė sunaudota šilumos galia per 10 minučių', 1002, 1, NULL, NULL),
	(8505, 192, 3, 13, 3, 0, 1, 12, 331, NULL, 'Vidutinė sunaudota šilumos galia per 15 minučių', 1002, 2, NULL, NULL),
	(8506, 192, 3, 14, 3, 0, 1, 13, 331, NULL, 'Vidutinė sunaudota šilumos galia per 20 minučių', 1002, 2, NULL, NULL),
	(8507, 39, 0, 8, 2, 0, 35, 1, 2, NULL, 'Suminis dujų koreguotos masės kiekis, fiksuojamas kas minutę', 1110, 5, NULL, NULL),
	(8508, 40, 0, 8, 2, 0, 31, 1, 4, NULL, 'Suminis dujų koreguoto tūrio kiekis, fiksuojamas kas minutę', 1112, 5, NULL, NULL),
	(8509, 41, 0, 8, 2, 0, 35, 1, 6, NULL, 'Suminis dujų masės kiekis, fiksuojamas kas minutę', 1105, 5, NULL, NULL),
	(8510, 43, 0, 8, 2, 0, 34, 1, 9, NULL, 'Suminis dujų šilumos kiekis, fiksuojamas kas minutę', 1101, 5, NULL, NULL),
	(8511, 45, 0, 8, 2, 0, 31, 1, 12, NULL, 'Suminis dujų tūrio kiekis, fiksuojamas kas minutę', 1107, 5, NULL, NULL),
	(8512, 187, 0, 7, 1, 0, 0, 7, 200, NULL, 'Momentinis rodiklis Nr.1', NULL, 6, NULL, NULL),
	(8513, 334, 0, 8, 2, 0, 29, 7, 346, NULL, 'Suminis sistemos darbo laikas', 1275, 5, NULL, NULL),
	(8514, 334, 0, 4, 2, 0, 29, 4, 346, NULL, 'Sistemos darbo laikas per valandą', 1276, 2, NULL, NULL),
	(8515, 334, 0, 5, 2, 0, 29, 5, 346, NULL, 'Sistemos darbo laikas per parą', 1276, 3, NULL, NULL),
	(8516, 334, 0, 6, 2, 0, 29, 6, 346, NULL, 'Sistemos darbo laikas per mėnesį', 1276, 4, NULL, NULL),
	(8517, 335, 0, 8, 2, 0, 29, 7, 347, NULL, 'Suminis sistemos nedarbo laikas', 1277, 5, NULL, NULL),
	(8518, 335, 0, 4, 2, 0, 29, 4, 347, NULL, 'Sistemos nedarbo laikas per valandą', 1278, 2, NULL, NULL),
	(8519, 335, 0, 5, 2, 0, 29, 5, 347, NULL, 'Sistemos nedarbo laikas per parą', 1278, 3, NULL, NULL),
	(8520, 335, 0, 6, 2, 0, 29, 6, 347, NULL, 'Sistemos nedarbo laikas per mėnesį', 1278, 4, NULL, NULL),
	(8521, 336, 0, 8, 2, 0, 29, 7, 348, NULL, 'Suminis šilumos sistemos darbo laikas', 1742, 5, NULL, NULL),
	(8522, 336, 0, 4, 2, 0, 29, 4, 348, NULL, 'Šilumos sistemos darbo laikas per valandą', 1743, 2, NULL, NULL),
	(8523, 336, 0, 5, 2, 0, 29, 5, 348, NULL, 'Šilumos sistemos darbo laikas per parą', 1743, 3, NULL, NULL),
	(8524, 336, 0, 6, 2, 0, 29, 6, 348, NULL, 'Šilumos sistemos darbo laikas per mėnesį', 1743, 4, NULL, NULL),
	(8525, 337, 0, 8, 2, 0, 29, 7, 349, NULL, 'Suminis šilumos sistemos nedarbo laikas', 1744, 5, NULL, NULL),
	(8526, 337, 0, 4, 2, 0, 29, 4, 349, NULL, 'Šilumos sistemos nedarbo laikas per valandą', 1745, 2, NULL, NULL),
	(8527, 337, 0, 5, 2, 0, 29, 5, 349, NULL, 'Šilumos sistemos nedarbo laikas per parą', 1745, 3, NULL, NULL),
	(8528, 337, 0, 6, 2, 0, 29, 6, 349, NULL, 'Šilumos sistemos nedarbo laikas per mėnesį', 1745, 4, NULL, NULL),
	(8529, 62, 1, 4, 2, 0, 29, 4, 75, NULL, 'Šilumnešio tiekimo vamzdyno darbo laikas per valandą', 1734, 2, NULL, NULL),
	(8530, 62, 1, 5, 2, 0, 29, 5, 75, NULL, 'Šilumnešio tiekimo vamzdyno darbo laikas per parą', 1734, 3, NULL, NULL),
	(8531, 62, 1, 6, 2, 0, 29, 6, 75, NULL, 'Šilumnešio tiekimo vamzdyno darbo laikas per mėnesį', 1734, 4, NULL, NULL),
	(8532, 62, 2, 4, 2, 0, 29, 4, 75, NULL, 'Šilumnešio grąžinimo vamzdyno darbo laikas per valandą', 1735, 2, NULL, NULL),
	(8533, 62, 2, 5, 2, 0, 29, 5, 75, NULL, 'Šilumnešio grąžinimo vamzdyno darbo laikas per parą', 1735, 3, NULL, NULL),
	(8534, 62, 2, 6, 2, 0, 29, 6, 75, NULL, 'Šilumnešio grąžinimo vamzdyno darbo laikas per mėnesį', 1735, 4, NULL, NULL),
	(8535, 338, 1, 8, 2, 0, 29, 7, 350, NULL, 'Suminis šilumnešio tiekimo vamzdyno nedarbo laikas', 1740, 5, NULL, NULL),
	(8536, 338, 1, 4, 2, 0, 29, 4, 350, NULL, 'Šilumnešio tiekimo vamzdyno nedarbo laikas per valandą', 1738, 2, NULL, NULL),
	(8537, 338, 1, 5, 2, 0, 29, 5, 350, NULL, 'Šilumnešio tiekimo vamzdyno nedarbo laikas per parą', 1738, 3, NULL, NULL),
	(8538, 338, 1, 6, 2, 0, 29, 6, 350, NULL, 'Šilumnešio tiekimo vamzdyno nedarbo laikas per mėnesį', 1738, 4, NULL, NULL),
	(8539, 338, 2, 8, 2, 0, 29, 7, 350, NULL, 'Suminis šilumnešio grąžinimo vamzdyno nedarbo laikas', 1741, 5, NULL, NULL),
	(8540, 338, 2, 4, 2, 0, 29, 4, 350, NULL, 'Šilumnešio grąžinimo vamzdyno nedarbo laikas per valandą', 1739, 2, NULL, NULL),
	(8541, 338, 2, 5, 2, 0, 29, 5, 350, NULL, 'Šilumnešio grąžinimo vamzdyno nedarbo laikas per parą', 1739, 3, NULL, NULL),
	(8542, 338, 2, 6, 2, 0, 29, 6, 350, NULL, 'Šilumnešio grąžinimo vamzdyno nedarbo laikas per mėnesį', 1739, 4, NULL, NULL),
	(8543, 340, 1, 8, 2, 0, 29, 7, 352, NULL, 'Suminis šalto vandens tiekimo vamzdyno nedarbo laikas', 1269, 5, NULL, NULL),
	(8544, 340, 1, 4, 2, 0, 29, 4, 352, NULL, 'Šalto vandens tiekimo vamzdyno nedarbo laikas per valandą', 1270, 2, NULL, NULL),
	(8545, 340, 1, 5, 2, 0, 29, 5, 352, NULL, 'Šalto vandens tiekimo vamzdyno nedarbo laikas per parą', 1270, 3, NULL, NULL),
	(8546, 340, 1, 6, 2, 0, 29, 6, 352, NULL, 'Šalto vandens tiekimo vamzdyno nedarbo laikas per mėnesį', 1270, 4, NULL, NULL),
	(8547, 340, 2, 8, 2, 0, 29, 7, 352, NULL, 'Suminis šalto vandens grąžinimo vamzdyno nedarbo laikas', 1271, 5, NULL, NULL),
	(8548, 340, 2, 4, 2, 0, 29, 4, 352, NULL, 'Šalto vandens grąžinimo vamzdyno nedarbo laikas per valandą', 1272, 2, NULL, NULL),
	(8549, 340, 2, 5, 2, 0, 29, 5, 352, NULL, 'Šalto vandens grąžinimo vamzdyno nedarbo laikas per parą', 1272, 3, NULL, NULL),
	(8550, 340, 2, 6, 2, 0, 29, 6, 352, NULL, 'Šalto vandens grąžinimo vamzdyno nedarbo laikas per mėnesį', 1272, 4, NULL, NULL),
	(8551, 342, 0, 8, 2, 0, 29, 7, 354, NULL, 'Suminis šalto vandens skaitiklio nedarbo laikas', 1273, 5, NULL, NULL),
	(8552, 342, 0, 4, 2, 0, 29, 4, 354, NULL, 'Šalto vandens skaitiklio nedarbo laikas per valandą', 1274, 2, NULL, NULL),
	(8553, 342, 0, 5, 2, 0, 29, 5, 354, NULL, 'Šalto vandens skaitiklio nedarbo laikas per parą', 1274, 3, NULL, NULL),
	(8554, 342, 0, 6, 2, 0, 29, 6, 354, NULL, 'Šalto vandens skaitiklio nedarbo laikas per mėnesį', 1274, 4, NULL, NULL),
	(8555, 339, 0, 8, 2, 0, 29, 7, 351, NULL, 'Suminis dujų skaitiklio darbo laikas', 1120, 5, NULL, NULL),
	(8556, 341, 0, 8, 2, 0, 29, 7, 353, NULL, 'Suminis mazgo darbo laikas', 1144, 5, NULL, NULL),
	(8557, 341, 0, 4, 2, 0, 29, 4, 353, NULL, 'Mazgo darbo laikas per valandą', 1145, 2, NULL, NULL),
	(8558, 341, 0, 5, 2, 0, 29, 5, 353, NULL, 'Mazgo darbo laikas per parą', 1145, 3, NULL, NULL),
	(8559, 341, 0, 6, 2, 0, 29, 6, 353, NULL, 'Mazgo darbo laikas per mėnesį', 1145, 4, NULL, NULL),
	(8560, 343, 1, 8, 2, 0, 29, 7, 355, NULL, 'Suminis šalto vandens tiekimo vamzdyno darbo laikas', 1222, 5, NULL, NULL),
	(8561, 343, 1, 4, 2, 0, 29, 4, 355, NULL, 'Šalto vandens tiekimo vamzdyno darbo laikas per valandą', 1266, 2, NULL, NULL),
	(8562, 343, 1, 5, 2, 0, 29, 5, 355, NULL, 'Šalto vandens tiekimo vamzdyno darbo laikas per parą', 1266, 3, NULL, NULL),
	(8563, 343, 1, 6, 2, 0, 29, 6, 355, NULL, 'Šalto vandens tiekimo vamzdyno darbo laikas per mėnesį', 1266, 4, NULL, NULL),
	(8564, 343, 2, 8, 2, 0, 29, 7, 355, NULL, 'Suminis šalto vandens grąžinimo vamzdyno darbo laikas', 1223, 5, NULL, NULL),
	(8565, 343, 2, 4, 2, 0, 29, 4, 355, NULL, 'Šalto vandens grąžinimo vamzdyno darbo laikas per valandą', 1267, 2, NULL, NULL),
	(8566, 343, 2, 5, 2, 0, 29, 5, 355, NULL, 'Šalto vandens grąžinimo vamzdyno darbo laikas per parą', 1267, 3, NULL, NULL),
	(8567, 343, 2, 6, 2, 0, 29, 6, 355, NULL, 'Šalto vandens grąžinimo vamzdyno darbo laikas per mėnesį', 1267, 4, NULL, NULL),
	(8568, 65, 1, 4, 2, 0, 29, 4, 78, NULL, 'Karšto vandens tiekimo vamzdyno darbo laikas per valandą', 1266, 2, NULL, NULL),
	(8569, 65, 1, 5, 2, 0, 29, 5, 78, NULL, 'Karšto vandens tiekimo vamzdyno darbo laikas per parą', 1266, 3, NULL, NULL),
	(8570, 65, 1, 6, 2, 0, 29, 6, 78, NULL, 'Karšto vandens tiekimo vamzdyno darbo laikas per mėnesį', 1266, 4, NULL, NULL),
	(8571, 65, 2, 4, 2, 0, 29, 4, 78, NULL, 'Karšto vandens grąžinimo vamzdyno darbo laikas per valandą', 1267, 2, NULL, NULL),
	(8572, 65, 2, 5, 2, 0, 29, 5, 78, NULL, 'Karšto vandens grąžinimo vamzdyno darbo laikas per parą', 1267, 3, NULL, NULL),
	(8573, 65, 2, 6, 2, 0, 29, 6, 78, NULL, 'Karšto vandens grąžinimo vamzdyno darbo laikas per mėnesį', 1267, 4, NULL, NULL),
	(8574, 301, 1, 1, 3, 0, 27, 1, 314, NULL, 'Vidutinis tiekiamo šalto vandens temperatūros svertinis vidurkis per minutę', 1217, 1, NULL, NULL),
	(8575, 301, 1, 2, 3, 0, 27, 2, 314, NULL, 'Vidutinis tiekiamo šalto vandens temperatūros svertinis vidurkis per 2 minutes', 1217, 1, NULL, NULL),
	(8576, 301, 1, 3, 3, 0, 27, 3, 314, NULL, 'Vidutinis tiekiamo šalto vandens temperatūros svertinis vidurkis per 30 minučių', 1217, 2, NULL, NULL),
	(8577, 301, 1, 4, 3, 0, 27, 4, 314, NULL, 'Vidutinis tiekiamo šalto vandens temperatūros svertinis vidurkis per valandą', 1217, 2, NULL, NULL),
	(8578, 301, 1, 5, 3, 0, 27, 5, 314, NULL, 'Vidutinis tiekiamo šalto vandens temperatūros svertinis vidurkis per parą', 1217, 3, NULL, NULL),
	(8579, 301, 1, 6, 3, 0, 27, 6, 314, NULL, 'Vidutinis tiekiamo šalto vandens temperatūros svertinis vidurkis per mėnesį', 1217, 4, NULL, NULL),
	(8580, 301, 1, 7, 1, 0, 27, 7, 314, NULL, 'Momentinis tiekiamo šalto vandens temperatūros svertinis vidurkis', 1263, 6, NULL, NULL),
	(8581, 301, 1, 9, 3, 0, 27, 8, 314, NULL, 'Vidutinis tiekiamo šalto vandens temperatūros svertinis vidurkis per 3 minutes', 1217, 1, NULL, NULL),
	(8582, 301, 1, 10, 3, 0, 27, 9, 314, NULL, 'Vidutinis tiekiamo šalto vandens temperatūros svertinis vidurkis per 4 minutes', 1217, 1, NULL, NULL),
	(8583, 301, 1, 11, 3, 0, 27, 10, 314, NULL, 'Vidutinis tiekiamo šalto vandens temperatūros svertinis vidurkis per 5 minutes', 1217, 1, NULL, NULL),
	(8584, 301, 1, 12, 3, 0, 27, 11, 314, NULL, 'Vidutinis tiekiamo šalto vandens temperatūros svertinis vidurkis per 10 minučių', 1217, 1, NULL, NULL),
	(8585, 301, 1, 13, 3, 0, 27, 12, 314, NULL, 'Vidutinis tiekiamo šalto vandens temperatūros svertinis vidurkis per 15 minučių', 1217, 2, NULL, NULL),
	(8586, 301, 1, 14, 3, 0, 27, 13, 314, NULL, 'Vidutinis tiekiamo šalto vandens temperatūros svertinis vidurkis per 20 minučių', 1217, 2, NULL, NULL),
	(8587, 301, 2, 1, 3, 0, 27, 1, 314, NULL, 'Vidutinis grįžtamo šalto vandens temperatūros svertinis vidurkis per minutę', 1265, 1, NULL, NULL),
	(8588, 301, 2, 2, 3, 0, 27, 2, 314, NULL, 'Vidutinis grįžtamo šalto vandens temperatūros svertinis vidurkis per 2 minutes', 1265, 1, NULL, NULL),
	(8589, 301, 2, 3, 3, 0, 27, 3, 314, NULL, 'Vidutinis grįžtamo šalto vandens temperatūros svertinis vidurkis per 30 minučių', 1265, 2, NULL, NULL),
	(8590, 301, 2, 4, 3, 0, 27, 4, 314, NULL, 'Vidutinis grįžtamo šalto vandens temperatūros svertinis vidurkis per valandą', 1265, 2, NULL, NULL),
	(8591, 301, 2, 5, 3, 0, 27, 5, 314, NULL, 'Vidutinis grįžtamo šalto vandens temperatūros svertinis vidurkis per parą', 1265, 3, NULL, NULL),
	(8592, 301, 2, 6, 3, 0, 27, 6, 314, NULL, 'Vidutinis grįžtamo šalto vandens temperatūros svertinis vidurkis per mėnesį', 1265, 4, NULL, NULL),
	(8593, 301, 2, 7, 1, 0, 27, 7, 314, NULL, 'Momentinis grįžtamo šalto vandens temperatūros svertinis vidurkis', 1264, 6, NULL, NULL),
	(8594, 301, 2, 9, 3, 0, 27, 8, 314, NULL, 'Vidutinis grįžtamo šalto vandens temperatūros svertinis vidurkis per 3 minutes', 1265, 1, NULL, NULL),
	(8595, 301, 2, 10, 3, 0, 27, 9, 314, NULL, 'Vidutinis grįžtamo šalto vandens temperatūros svertinis vidurkis per 4 minutes', 1265, 1, NULL, NULL),
	(8596, 301, 2, 11, 3, 0, 27, 10, 314, NULL, 'Vidutinis grįžtamo šalto vandens temperatūros svertinis vidurkis per 5 minutes', 1265, 1, NULL, NULL),
	(8597, 301, 2, 12, 3, 0, 27, 11, 314, NULL, 'Vidutinis grįžtamo šalto vandens temperatūros svertinis vidurkis per 10 minučių', 1265, 1, NULL, NULL),
	(8598, 301, 2, 13, 3, 0, 27, 12, 314, NULL, 'Vidutinis grįžtamo šalto vandens temperatūros svertinis vidurkis per 15 minučių', 1265, 2, NULL, NULL),
	(8599, 301, 2, 14, 3, 0, 27, 13, 314, NULL, 'Vidutinis grįžtamo šalto vandens temperatūros svertinis vidurkis per 20 minučių', 1265, 2, NULL, NULL),
	(8600, 323, 2, 11, 3, 0, 28, 10, 336, NULL, 'Vidutinis grįžtamo šalto vandens absoliutus slėgis per 5 minutes', 1251, 1, NULL, NULL),
	(8601, 323, 2, 12, 3, 0, 28, 11, 336, NULL, 'Vidutinis grįžtamo šalto vandens absoliutus slėgis per 10 minučių', 1251, 1, NULL, NULL),
	(8602, 323, 2, 13, 3, 0, 28, 12, 336, NULL, 'Vidutinis grįžtamo šalto vandens absoliutus slėgis per 15 minučių', 1251, 2, NULL, NULL),
	(8603, 323, 2, 14, 3, 0, 28, 13, 336, NULL, 'Vidutinis grįžtamo šalto vandens absoliutus slėgis per 20 minučių', 1251, 2, NULL, NULL),
	(8604, 323, 2, 1, 3, 0, 28, 1, 336, NULL, 'Vidutinis grįžtamo šalto vandens absoliutus slėgis per minutę', 1251, 1, NULL, NULL),
	(8605, 323, 2, 2, 3, 0, 28, 2, 336, NULL, 'Vidutinis grįžtamo šalto vandens absoliutus slėgis per 2 minutes', 1251, 1, NULL, NULL),
	(8606, 323, 2, 3, 3, 0, 28, 3, 336, NULL, 'Vidutinis grįžtamo šalto vandens absoliutus slėgis per 30 minučių', 1251, 2, NULL, NULL),
	(8607, 323, 2, 4, 3, 0, 28, 4, 336, NULL, 'Vidutinis grįžtamo šalto vandens absoliutus slėgis per valandą', 1251, 2, NULL, NULL),
	(8608, 323, 2, 5, 3, 0, 28, 5, 336, NULL, 'Vidutinis grįžtamo šalto vandens absoliutus slėgis per parą', 1251, 3, NULL, NULL),
	(8609, 323, 2, 6, 3, 0, 28, 6, 336, NULL, 'Vidutinis grįžtamo šalto vandens absoliutus slėgis per mėnesį', 1251, 4, NULL, NULL),
	(8610, 323, 2, 7, 1, 0, 28, 7, 336, NULL, 'Momentinis grįžtamo šalto vandens absoliutus slėgis', 1250, 6, NULL, NULL),
	(8611, 323, 2, 9, 3, 0, 28, 8, 336, NULL, 'Vidutinis grįžtamo šalto vandens absoliutus slėgis per 3 minutes', 1251, 1, NULL, NULL),
	(8612, 323, 2, 10, 3, 0, 28, 9, 336, NULL, 'Vidutinis grįžtamo šalto vandens absoliutus slėgis per 4 minutes', 1251, 1, NULL, NULL),
	(8613, 323, 1, 11, 3, 0, 28, 10, 336, NULL, 'Vidutinis tiekiamo šalto vandens absoliutus slėgis per 5 minutes', 1224, 1, NULL, NULL),
	(8614, 323, 1, 12, 3, 0, 28, 11, 336, NULL, 'Vidutinis tiekiamo šalto vandens absoliutus slėgis per 10 minučių', 1224, 1, NULL, NULL),
	(8615, 323, 1, 13, 3, 0, 28, 12, 336, NULL, 'Vidutinis tiekiamo šalto vandens absoliutus slėgis per 15 minučių', 1224, 2, NULL, NULL),
	(8616, 323, 1, 14, 3, 0, 28, 13, 336, NULL, 'Vidutinis tiekiamo šalto vandens absoliutus slėgis per 20 minučių', 1224, 2, NULL, NULL),
	(8617, 323, 1, 1, 3, 0, 28, 1, 336, NULL, 'Vidutinis tiekiamo šalto vandens absoliutus slėgis per minutę', 1224, 1, NULL, NULL),
	(8618, 323, 1, 2, 3, 0, 28, 2, 336, NULL, 'Vidutinis tiekiamo šalto vandens absoliutus slėgis per 2 minutes', 1224, 1, NULL, NULL),
	(8619, 323, 1, 3, 3, 0, 28, 3, 336, NULL, 'Vidutinis tiekiamo šalto vandens absoliutus slėgis per 30 minučių', 1224, 2, NULL, NULL),
	(8620, 323, 1, 4, 3, 0, 28, 4, 336, NULL, 'Vidutinis tiekiamo šalto vandens absoliutus slėgis per valandą', 1224, 2, NULL, NULL),
	(8621, 323, 1, 5, 3, 0, 28, 5, 336, NULL, 'Vidutinis tiekiamo šalto vandens absoliutus slėgis per parą', 1224, 3, NULL, NULL),
	(8622, 323, 1, 6, 3, 0, 28, 6, 336, NULL, 'Vidutinis tiekiamo šalto vandens absoliutus slėgis per mėnesį', 1224, 4, NULL, NULL),
	(8623, 323, 1, 7, 1, 0, 28, 7, 336, NULL, 'Momentinis tiekiamo šalto vandens absoliutus slėgis', 1220, 6, NULL, NULL),
	(8624, 323, 1, 9, 3, 0, 28, 8, 336, NULL, 'Vidutinis tiekiamo šalto vandens absoliutus slėgis per 3 minutes', 1224, 1, NULL, NULL),
	(8625, 323, 1, 10, 3, 0, 28, 9, 336, NULL, 'Vidutinis tiekiamo šalto vandens absoliutus slėgis per 4 minutes', 1224, 1, NULL, NULL),
	(8626, 4, 1, 11, 3, 0, 28, 10, 257, NULL, 'Vidutinis tiekiamo karšto vandens absoliutus slėgis per 5 minutes', 1224, 1, NULL, NULL),
	(8627, 4, 1, 12, 3, 0, 28, 11, 257, NULL, 'Vidutinis tiekiamo karšto vandens absoliutus slėgis per 10 minučių', 1224, 1, NULL, NULL),
	(8628, 4, 1, 13, 3, 0, 28, 12, 257, NULL, 'Vidutinis tiekiamo karšto vandens absoliutus slėgis per 15 minučių', 1224, 2, NULL, NULL),
	(8629, 4, 1, 14, 3, 0, 28, 13, 257, NULL, 'Vidutinis tiekiamo karšto vandens absoliutus slėgis per 20 minučių', 1224, 2, NULL, NULL),
	(8630, 4, 1, 1, 3, 0, 28, 1, 257, NULL, 'Vidutinis tiekiamo karšto vandens absoliutus slėgis per minutę', 1224, 1, NULL, NULL),
	(8631, 4, 1, 2, 3, 0, 28, 2, 257, NULL, 'Vidutinis tiekiamo karšto vandens absoliutus slėgis per 2 minutes', 1224, 1, NULL, NULL),
	(8632, 4, 1, 3, 3, 0, 28, 3, 257, NULL, 'Vidutinis tiekiamo karšto vandens absoliutus slėgis per 30 minučių', 1224, 2, NULL, NULL),
	(8633, 4, 1, 4, 3, 0, 28, 4, 257, NULL, 'Vidutinis tiekiamo karšto vandens absoliutus slėgis per valandą', 1224, 2, NULL, NULL),
	(8634, 4, 1, 5, 3, 0, 28, 5, 257, NULL, 'Vidutinis tiekiamo karšto vandens absoliutus slėgis per parą', 1224, 3, NULL, NULL),
	(8635, 4, 1, 6, 3, 0, 28, 6, 257, NULL, 'Vidutinis tiekiamo karšto vandens absoliutus slėgis per mėnesį', 1224, 4, NULL, NULL),
	(8636, 4, 1, 7, 1, 0, 28, 7, 257, NULL, 'Momentinis tiekiamo karšto vandens absoliutus slėgis', 1220, 6, NULL, NULL),
	(8637, 4, 1, 9, 3, 0, 28, 8, 257, NULL, 'Vidutinis tiekiamo karšto vandens absoliutus slėgis per 3 minutes', 1224, 1, NULL, NULL),
	(8638, 4, 1, 10, 3, 0, 28, 9, 257, NULL, 'Vidutinis tiekiamo karšto vandens absoliutus slėgis per 4 minutes', 1224, 1, NULL, NULL),
	(8639, 33, 1, 1, 3, 0, 28, 1, 259, NULL, 'Vidutinis tiekiamo šalto vandens diferencinis slėgis per minutę', 1253, 1, NULL, NULL),
	(8640, 33, 1, 2, 3, 0, 28, 2, 259, NULL, 'Vidutinis tiekiamo šalto vandens diferencinis slėgis per 2 minutes', 1253, 1, NULL, NULL),
	(8641, 33, 1, 3, 3, 0, 28, 3, 259, NULL, 'Vidutinis tiekiamo šalto vandens diferencinis slėgis per 30 minučių', 1253, 2, NULL, NULL),
	(8642, 33, 1, 4, 3, 0, 28, 4, 259, NULL, 'Vidutinis tiekiamo šalto vandens diferencinis slėgis per valandą', 1253, 2, NULL, NULL),
	(8643, 33, 1, 5, 3, 0, 28, 5, 259, NULL, 'Vidutinis tiekiamo šalto vandens diferencinis slėgis per parą', 1253, 3, NULL, NULL),
	(8644, 33, 1, 6, 3, 0, 28, 6, 259, NULL, 'Vidutinis tiekiamo šalto vandens diferencinis slėgis per mėnesį', 1253, 4, NULL, NULL),
	(8645, 33, 1, 7, 1, 0, 28, 7, 259, NULL, 'Momentinis tiekiamo šalto vandens diferencinis slėgis', 1252, 6, NULL, NULL),
	(8646, 33, 1, 9, 3, 0, 28, 8, 259, NULL, 'Vidutinis tiekiamo šalto vandens diferencinis slėgis per 3 minutes', 1253, 1, NULL, NULL),
	(8647, 33, 1, 10, 3, 0, 28, 9, 259, NULL, 'Vidutinis tiekiamo šalto vandens diferencinis slėgis per 4 minutes', 1253, 1, NULL, NULL),
	(8648, 33, 1, 11, 3, 0, 28, 10, 259, NULL, 'Vidutinis tiekiamo šalto vandens diferencinis slėgis per 5 minutes', 1253, 1, NULL, NULL),
	(8649, 33, 1, 12, 3, 0, 28, 11, 259, NULL, 'Vidutinis tiekiamo šalto vandens diferencinis slėgis per 10 minučių', 1253, 1, NULL, NULL),
	(8650, 33, 1, 13, 3, 0, 28, 12, 259, NULL, 'Vidutinis tiekiamo šalto vandens diferencinis slėgis per 15 minučių', 1253, 2, NULL, NULL),
	(8651, 33, 1, 14, 3, 0, 28, 13, 259, NULL, 'Vidutinis tiekiamo šalto vandens diferencinis slėgis per 20 minučių', 1253, 2, NULL, NULL),
	(8652, 33, 2, 1, 3, 0, 28, 1, 259, NULL, 'Vidutinis grįžtamo šalto vandens diferencinis slėgis per minutę', 1255, 1, NULL, NULL),
	(8653, 33, 2, 2, 3, 0, 28, 2, 259, NULL, 'Vidutinis grįžtamo šalto vandens diferencinis slėgis per 2 minutes', 1255, 1, NULL, NULL),
	(8654, 33, 2, 3, 3, 0, 28, 3, 259, NULL, 'Vidutinis grįžtamo šalto vandens diferencinis slėgis per 30 minučių', 1255, 2, NULL, NULL),
	(8655, 33, 2, 4, 3, 0, 28, 4, 259, NULL, 'Vidutinis grįžtamo šalto vandens diferencinis slėgis per valandą', 1255, 2, NULL, NULL),
	(8656, 33, 2, 5, 3, 0, 28, 5, 259, NULL, 'Vidutinis grįžtamo šalto vandens diferencinis slėgis per parą', 1255, 3, NULL, NULL),
	(8657, 33, 2, 6, 3, 0, 28, 6, 259, NULL, 'Vidutinis grįžtamo šalto vandens diferencinis slėgis per mėnesį', 1255, 4, NULL, NULL),
	(8658, 33, 2, 7, 1, 0, 28, 7, 259, NULL, 'Momentinis grįžtamo šalto vandens diferencinis slėgis', 1254, 6, NULL, NULL),
	(8659, 33, 2, 9, 3, 0, 28, 8, 259, NULL, 'Vidutinis grįžtamo šalto vandens diferencinis slėgis per 3 minutes', 1255, 1, NULL, NULL),
	(8660, 33, 2, 10, 3, 0, 28, 9, 259, NULL, 'Vidutinis grįžtamo šalto vandens diferencinis slėgis per 4 minutes', 1255, 1, NULL, NULL),
	(8661, 33, 2, 11, 3, 0, 28, 10, 259, NULL, 'Vidutinis grįžtamo šalto vandens diferencinis slėgis per 5 minutes', 1255, 1, NULL, NULL),
	(8662, 33, 2, 12, 3, 0, 28, 11, 259, NULL, 'Vidutinis grįžtamo šalto vandens diferencinis slėgis per 10 minučių', 1255, 1, NULL, NULL),
	(8663, 33, 2, 13, 3, 0, 28, 12, 259, NULL, 'Vidutinis grįžtamo šalto vandens diferencinis slėgis per 15 minučių', 1255, 2, NULL, NULL),
	(8664, 33, 2, 14, 3, 0, 28, 13, 259, NULL, 'Vidutinis grįžtamo šalto vandens diferencinis slėgis per 20 minučių', 1255, 2, NULL, NULL),
	(8665, 55, 3, 8, 2, 0, 31, 7, 74, NULL, 'Suminis tiekiamo ir grįžtamo šilumnešio tūrio kiekių skirtumas', 1736, 5, NULL, NULL),
	(8666, 240, 3, 8, 2, 0, 35, 7, 253, NULL, 'Suminis tiekiamo ir grįžtamo karšto vandens masės kiekių skirtumas', 1279, 5, NULL, NULL),
	(8667, 187, 0, 3, 2, 0, 0, 3, 200, NULL, 'Rodiklis Nr.1 per 30 minučių', NULL, 2, NULL, NULL),
	(8668, 187, 0, 4, 2, 0, 0, 4, 200, NULL, 'Rodiklis Nr.1 per valandą', NULL, 2, NULL, NULL),
	(8669, 187, 0, 13, 2, 0, 0, 12, 200, NULL, 'Rodiklis Nr.1 per 15 minučių', NULL, 2, NULL, NULL),
	(8670, 344, 0, 3, 2, 0, 0, 3, 356, NULL, 'Rodiklis Nr.2 per 30 minučių', NULL, 2, NULL, NULL),
	(8671, 344, 0, 4, 2, 0, 0, 4, 356, NULL, 'Rodiklis Nr.2 per valandą1144df', NULL, 2, NULL, NULL),
	(8672, 344, 0, 5, 2, 0, 0, 5, 356, NULL, 'Rodiklis Nr.2 per parą', NULL, 3, NULL, NULL),
	(8673, 344, 0, 6, 2, 0, 0, 6, 356, NULL, 'Rodiklis Nr.2 per mėnesį2244', NULL, 4, NULL, NULL),
	(8674, 344, 0, 7, 1, 0, 0, 7, 356, NULL, 'Momentinis rodiklis Nr.2', NULL, 6, NULL, NULL),
	(8675, 344, 0, 13, 2, 0, 0, 12, 356, NULL, 'Rodiklis Nr.2 per 15 minučių', NULL, 2, NULL, NULL),
	(8676, 345, 0, 3, 2, 0, 0, 3, 357, NULL, 'Rodiklis Nr.3 per 30 minučių', NULL, 2, NULL, NULL),
	(8677, 345, 0, 4, 2, 0, 0, 4, 357, NULL, 'Rodiklis Nr.3 per valandą', NULL, 2, NULL, NULL),
	(8678, 345, 0, 5, 2, 0, 0, 5, 357, NULL, 'Rodiklis Nr.3 per parą', NULL, 3, NULL, NULL),
	(8679, 345, 0, 6, 2, 0, 0, 6, 357, NULL, 'Rodiklis Nr.3 per mėnesį', NULL, 4, NULL, NULL),
	(8680, 345, 0, 7, 1, 0, 0, 7, 357, NULL, 'Momentinis rodiklis Nr.3', NULL, 6, NULL, NULL),
	(8681, 345, 0, 13, 2, 0, 0, 12, 357, NULL, 'Rodiklis Nr.3 per 15 minučių', NULL, 2, NULL, NULL),
	(8682, 346, 0, 3, 2, 0, 0, 3, 358, NULL, 'Rodiklis Nr.4 per 30 minučių', NULL, 2, NULL, NULL),
	(8683, 346, 0, 4, 2, 0, 0, 4, 358, NULL, 'Rodiklis Nr.4 per valandą', NULL, 2, NULL, NULL),
	(8684, 346, 0, 5, 2, 0, 0, 5, 358, NULL, 'Rodiklis Nr.4 per parą', NULL, 3, NULL, NULL),
	(8685, 346, 0, 6, 2, 0, 0, 6, 358, NULL, 'Rodiklis Nr.4 per mėnesį', NULL, 4, NULL, NULL),
	(8686, 346, 0, 7, 1, 0, 0, 7, 358, NULL, 'Momentinis rodiklis Nr.4', NULL, 6, NULL, NULL),
	(8687, 346, 0, 13, 2, 0, 0, 12, 358, NULL, 'Rodiklis Nr.4 per 15 minučių', NULL, 2, NULL, NULL),
	(8688, 347, 0, 3, 2, 0, 0, 3, 359, NULL, 'Rodiklis Nr.5 per 30 minučių', NULL, 2, NULL, NULL),
	(8689, 347, 0, 4, 2, 0, 0, 4, 359, NULL, 'Rodiklis Nr.5 per valandą', NULL, 2, NULL, NULL),
	(8690, 347, 0, 5, 2, 0, 0, 5, 359, NULL, 'Rodiklis Nr.5 per parą', NULL, 3, NULL, NULL),
	(8691, 347, 0, 6, 2, 0, 0, 6, 359, NULL, 'Rodiklis Nr.5 per mėnesį', NULL, 4, NULL, NULL),
	(8692, 347, 0, 7, 1, 0, 0, 7, 359, NULL, 'Momentinis rodiklis Nr.5', NULL, 6, NULL, NULL),
	(8693, 347, 0, 13, 2, 0, 0, 12, 359, NULL, 'Rodiklis Nr.5 per 15 minučių', NULL, 2, NULL, NULL),
	(8694, 348, 0, 3, 3, 0, 0, 3, 360, NULL, 'Vidutinis rodiklis Nr.6 per 30 minučių', NULL, 2, NULL, NULL),
	(8695, 348, 0, 4, 3, 0, 0, 4, 360, NULL, 'Vidutinis rodiklis Nr.6 per valandą', NULL, 2, NULL, NULL),
	(8696, 348, 0, 5, 3, 0, 0, 5, 360, NULL, 'Vidutinis rodiklis Nr.6 per parą', NULL, 3, NULL, NULL),
	(8697, 348, 0, 6, 3, 0, 0, 6, 360, NULL, 'Vidutinis rodiklis Nr.6 per mėnesį', NULL, 4, NULL, NULL),
	(8698, 348, 0, 7, 1, 0, 0, 7, 360, NULL, 'Momentinis rodiklis Nr.6', NULL, 6, NULL, NULL),
	(8699, 348, 0, 13, 3, 0, 0, 12, 360, NULL, 'Vidutinis rodiklis Nr.6 per 15 minučių', NULL, 2, NULL, NULL),
	(8700, 349, 0, 3, 3, 0, 0, 3, 361, NULL, 'Vidutinis rodiklis Nr.7 per 30 minučių', NULL, 2, NULL, NULL),
	(8701, 349, 0, 4, 3, 0, 0, 4, 361, NULL, 'Vidutinis rodiklis Nr.7 per valandą', NULL, 2, NULL, NULL),
	(8702, 349, 0, 5, 3, 0, 0, 5, 361, NULL, 'Vidutinis rodiklis Nr.7 per parą', NULL, 3, NULL, NULL),
	(8703, 349, 0, 6, 3, 0, 0, 6, 361, NULL, 'Vidutinis rodiklis Nr.7 per mėnesį', NULL, 4, NULL, NULL),
	(8704, 349, 0, 7, 1, 0, 0, 7, 361, NULL, 'Momentinis rodiklis Nr.7', NULL, 6, NULL, NULL),
	(8705, 349, 0, 13, 3, 0, 0, 12, 361, NULL, 'Vidutinis rodiklis Nr.7 per 15 minučių', NULL, 2, NULL, NULL),
	(8706, 350, 0, 3, 3, 0, 0, 3, 362, NULL, 'Vidutinis rodiklis Nr.8 per 30 minučių', NULL, 2, NULL, NULL),
	(8707, 350, 0, 4, 3, 0, 0, 4, 362, NULL, 'Vidutinis rodiklis Nr.8 per valandą', NULL, 2, NULL, NULL),
	(8708, 350, 0, 5, 3, 0, 0, 5, 362, NULL, 'Vidutinis rodiklis Nr.8 per parą', NULL, 3, NULL, NULL),
	(8709, 350, 0, 6, 3, 0, 0, 6, 362, NULL, 'Vidutinis rodiklis Nr.8 per mėnesį', NULL, 4, NULL, NULL),
	(8710, 350, 0, 7, 1, 0, 0, 7, 362, NULL, 'Momentinis rodiklis Nr.8', NULL, 6, NULL, NULL),
	(8711, 350, 0, 13, 3, 0, 0, 12, 362, NULL, 'Vidutinis rodiklis Nr.8 per 15 minučių', NULL, 2, NULL, NULL),
	(8712, 351, 0, 3, 3, 0, 0, 3, 363, NULL, 'Vidutinis rodiklis Nr.9 per 30 minučių', NULL, 2, NULL, NULL),
	(8713, 351, 0, 4, 3, 0, 0, 4, 363, NULL, 'Vidutinis rodiklis Nr.9 per valandą', NULL, 2, NULL, NULL),
	(8714, 351, 0, 5, 3, 0, 0, 5, 363, NULL, 'Vidutinis rodiklis Nr.9 per parą', NULL, 3, NULL, NULL),
	(8715, 351, 0, 6, 3, 0, 0, 6, 363, NULL, 'Vidutinis rodiklis Nr.9 per mėnesį', NULL, 4, NULL, NULL),
	(8716, 351, 0, 7, 1, 0, 0, 7, 363, NULL, 'Momentinis rodiklis Nr.9', NULL, 6, NULL, NULL),
	(8717, 351, 0, 13, 3, 0, 0, 12, 363, NULL, 'Vidutinis rodiklis Nr.9 per 15 minučių', NULL, 2, NULL, NULL),
	(8718, 352, 0, 3, 3, 0, 0, 3, 364, NULL, 'Vidutinis rodiklis Nr.10 per 30 minučių', NULL, 2, NULL, NULL),
	(8719, 352, 0, 4, 3, 0, 0, 4, 364, NULL, 'Vidutinis rodiklis Nr.10 per valandą', NULL, 2, NULL, NULL),
	(8720, 352, 0, 5, 3, 0, 0, 5, 364, NULL, 'Vidutinis rodiklis Nr.10 per parą', NULL, 3, NULL, NULL),
	(8721, 352, 0, 6, 3, 0, 0, 6, 364, NULL, 'Vidutinis rodiklis Nr.10 per mėnesį', NULL, 4, NULL, NULL),
	(8722, 352, 0, 7, 1, 0, 0, 7, 364, NULL, 'Momentinis rodiklis Nr.10', NULL, 6, NULL, NULL),
	(8723, 352, 0, 13, 3, 0, 0, 12, 364, NULL, 'Vidutinis rodiklis Nr.10 per 15 minučių', NULL, 2, NULL, NULL),
	(8724, 239, 3, 8, 2, 0, 35, 7, 252, NULL, 'Suminis tiekiamo ir grįžtamo šalto vandens masės kiekių skirtumas', 1279, 5, NULL, NULL),
	(8725, 239, 3, 1, 2, 0, 35, 1, 252, NULL, 'Tiekiamo ir grįžtamo šalto vandens masės kiekių skirtumas per minutę', 1280, 1, NULL, NULL),
	(8726, 239, 3, 2, 2, 0, 35, 2, 252, NULL, 'Tiekiamo ir grįžtamo šalto vandens masės kiekių skirtumas per 2 minutes', 1280, 1, NULL, NULL),
	(8727, 239, 3, 3, 2, 0, 35, 3, 252, NULL, 'Tiekiamo ir grįžtamo šalto vandens masės kiekių skirtumas per 30 minučių', 1280, 2, NULL, NULL),
	(8728, 239, 3, 4, 2, 0, 35, 4, 252, NULL, 'Tiekiamo ir grįžtamo šalto vandens masės kiekių skirtumas per valandą', 1280, 2, NULL, NULL),
	(8729, 239, 3, 5, 2, 0, 35, 5, 252, NULL, 'Tiekiamo ir grįžtamo šalto vandens masės kiekių skirtumas per parą', 1280, 3, NULL, NULL),
	(8730, 239, 3, 6, 2, 0, 35, 6, 252, NULL, 'Tiekiamo ir grįžtamo šalto vandens masės kiekių skirtumas per mėnesį', 1280, 4, NULL, NULL),
	(8731, 239, 3, 9, 2, 0, 35, 8, 252, NULL, 'Tiekiamo ir grįžtamo šalto vandens masės kiekių skirtumas per 3 minutes', 1280, 1, NULL, NULL),
	(8732, 239, 3, 10, 2, 0, 35, 9, 252, NULL, 'Tiekiamo ir grįžtamo šalto vandens masės kiekių skirtumas per 4 minutes', 1280, 1, NULL, NULL),
	(8733, 239, 3, 11, 2, 0, 35, 10, 252, NULL, 'Tiekiamo ir grįžtamo šalto vandens masės kiekių skirtumas per 5 minutes', 1280, 1, NULL, NULL),
	(8734, 239, 3, 12, 2, 0, 35, 11, 252, NULL, 'Tiekiamo ir grįžtamo šalto vandens masės kiekių skirtumas per 10 minučių', 1280, 1, NULL, NULL),
	(8735, 239, 3, 13, 2, 0, 35, 12, 252, NULL, 'Tiekiamo ir grįžtamo šalto vandens masės kiekių skirtumas per 15 minučių', 1280, 2, NULL, NULL),
	(8736, 239, 3, 14, 2, 0, 35, 13, 252, NULL, 'Tiekiamo ir grįžtamo šalto vandens masės kiekių skirtumas per 20 minučių', 1280, 2, NULL, NULL),
	(8737, 334, 0, 8, 2, 0, 29, 4, 346, NULL, 'Suminis sistemos darbo laikas, fiksuojamas kas valandą', 1275, 5, NULL, NULL),
	(8738, 334, 0, 8, 2, 0, 29, 5, 346, NULL, 'Suminis sistemos darbo laikas, fiksuojamas kas parą', 1275, 5, NULL, NULL),
	(8739, 334, 0, 8, 2, 0, 29, 6, 346, NULL, 'Suminis sistemos darbo laikas, fiksuojamas kas mėnesį', 1275, 5, NULL, NULL),
	(8740, 335, 0, 8, 2, 0, 29, 4, 347, NULL, 'Suminis sistemos nedarbo laikas, fiksuojamas kas valandą', 1277, 5, NULL, NULL),
	(8741, 335, 0, 8, 2, 0, 29, 5, 347, NULL, 'Suminis sistemos nedarbo laikas, fiksuojamas kas parą', 1277, 5, NULL, NULL),
	(8742, 335, 0, 8, 2, 0, 29, 6, 347, NULL, 'Suminis sistemos nedarbo laikas, fiksuojamas kas mėnesį', 1277, 5, NULL, NULL),
	(8743, 53, 3, 8, 2, 0, 2, 4, 71, NULL, 'Suminis sunaudotos šilumnešio šilumos kiekis, fiksuojamas kas valandą', 1044, 5, NULL, NULL),
	(8744, 53, 3, 8, 2, 0, 2, 5, 71, NULL, 'Suminis sunaudotos šilumnešio šilumos kiekis, fiksuojamas kas parą', 1044, 5, NULL, NULL),
	(8745, 53, 3, 8, 2, 0, 2, 6, 71, NULL, 'Suminis sunaudotos šilumnešio šilumos kiekis, fiksuojamas kas mėnesį', 1044, 5, NULL, NULL),
	(8746, 59, 3, 8, 2, 0, 2, 4, 51, NULL, 'Suminis sunaudotos karšto vandens šilumos kiekis, fiksuojamas kas valandą', 1239, 5, NULL, NULL),
	(8747, 59, 3, 8, 2, 0, 2, 5, 51, NULL, 'Suminis sunaudotos karšto vandens šilumos kiekis, fiksuojamas kas parą', 1239, 5, NULL, NULL),
	(8748, 59, 3, 8, 2, 0, 2, 6, 51, NULL, 'Suminis sunaudotos karšto vandens šilumos kiekis, fiksuojamas kas mėnesį', 1239, 5, NULL, NULL),
	(8749, 353, 1, 4, 3, 0, 28, 4, 365, NULL, 'Vidutinis tiekiamo karšto vandens slėgio svertinis vidurkis per valandą', 1283, 2, NULL, NULL),
	(8750, 353, 1, 5, 3, 0, 28, 5, 365, NULL, 'Vidutinis tiekiamo karšto vandens slėgio svertinis vidurkis per parą', 1283, 3, NULL, NULL),
	(8751, 353, 1, 6, 3, 0, 28, 6, 365, NULL, 'Vidutinis tiekiamo karšto vandens slėgio svertinis vidurkis per mėnesį', 1283, 4, NULL, NULL),
	(8752, 353, 1, 7, 1, 0, 28, 7, 365, NULL, 'Momentinis tiekiamo karšto vandens slėgio svertinis vidurkis', 1281, 6, NULL, NULL),
	(8753, 353, 2, 4, 3, 0, 28, 4, 365, NULL, 'Vidutinis grįžtamo karšto vandens slėgio svertinis vidurkis per valandą', 1284, 2, NULL, NULL),
	(8754, 353, 2, 5, 3, 0, 28, 5, 365, NULL, 'Vidutinis grįžtamo karšto vandens slėgio svertinis vidurkis per parą', 1284, 3, NULL, NULL),
	(8755, 353, 2, 6, 3, 0, 28, 6, 365, NULL, 'Vidutinis grįžtamo karšto vandens slėgio svertinis vidurkis per mėnesį', 1284, 4, NULL, NULL),
	(8756, 353, 2, 7, 1, 0, 28, 7, 365, NULL, 'Momentinis grįžtamo karšto vandens slėgio svertinis vidurkis', 1282, 6, NULL, NULL),
	(8757, 354, 1, 4, 3, 0, 28, 4, 366, NULL, 'Vidutinis tiekiamo šalto vandens slėgio svertinis vidurkis per valandą', 1283, 2, NULL, NULL),
	(8758, 354, 1, 5, 3, 0, 28, 5, 366, NULL, 'Vidutinis tiekiamo šalto vandens slėgio svertinis vidurkis per parą', 1283, 3, NULL, NULL),
	(8759, 354, 1, 6, 3, 0, 28, 6, 366, NULL, 'Vidutinis tiekiamo šalto vandens slėgio svertinis vidurkis per mėnesį', 1283, 4, NULL, NULL),
	(8760, 354, 1, 7, 1, 0, 28, 7, 366, NULL, 'Momentinis tiekiamo šalto vandens slėgio svertinis vidurkis', 1281, 6, NULL, NULL),
	(8761, 354, 2, 4, 3, 0, 28, 4, 366, NULL, 'Vidutinis grįžtamo šalto vandens slėgio svertinis vidurkis per valandą', 1284, 2, NULL, NULL),
	(8762, 354, 2, 5, 3, 0, 28, 5, 366, NULL, 'Vidutinis grįžtamo šalto vandens slėgio svertinis vidurkis per parą', 1284, 3, NULL, NULL),
	(8763, 354, 2, 6, 3, 0, 28, 6, 366, NULL, 'Vidutinis grįžtamo šalto vandens slėgio svertinis vidurkis per mėnesį', 1284, 4, NULL, NULL),
	(8764, 354, 2, 7, 1, 0, 28, 7, 366, NULL, 'Momentinis grįžtamo šalto vandens slėgio svertinis vidurkis', 1282, 6, NULL, NULL),
	(8766, 355, 1, 4, 3, 0, 28, 4, 367, NULL, 'Tiekiamo šilumnešio slėgio svertinis vidurkis per valandą', 1759, 2, NULL, NULL),
	(8767, 355, 1, 5, 3, 0, 28, 5, 367, NULL, 'Tiekiamo šilumnešio slėgio svertinis vidurkis per parą', 1759, 3, NULL, NULL),
	(8768, 355, 1, 6, 3, 0, 28, 6, 367, NULL, 'Tiekiamo šilumnešio slėgio svertinis vidurkis per mėnesį', 1759, 4, NULL, NULL),
	(8769, 355, 1, 7, 1, 0, 28, 7, 367, NULL, 'Momentinis tiekiamo šilumnešio slėgio svertinis vidurkis', 1756, 6, NULL, NULL),
	(8770, 355, 2, 4, 3, 0, 28, 4, 367, NULL, 'Grįžtamo šilumnešio slėgio svertinis vidurkis per valandą', 1760, 2, NULL, NULL),
	(8771, 355, 2, 5, 3, 0, 28, 5, 367, NULL, 'Grįžtamo šilumnešio slėgio svertinis vidurkis per parą', 1760, 3, NULL, NULL),
	(8772, 355, 2, 6, 3, 0, 28, 6, 367, NULL, 'Grįžtamo šilumnešio slėgio svertinis vidurkis per mėnesį', 1760, 4, NULL, NULL),
	(8773, 355, 2, 7, 1, 0, 28, 7, 367, NULL, 'Momentinis grįžtamo šilumnešio slėgio svertinis vidurkis', 1757, 6, NULL, NULL),
	(8774, 355, -4, 4, 3, 0, 28, 4, 367, NULL, 'Pamaitinimo vandens slėgio svertinis vidurkis per valandą', 1761, 2, NULL, NULL),
	(8775, 355, -4, 5, 3, 0, 28, 5, 367, NULL, 'Pamaitinimo vandens slėgio svertinis vidurkis per parą', 1761, 3, NULL, NULL),
	(8776, 355, -4, 6, 3, 0, 28, 6, 367, NULL, 'Pamaitinimo vandens slėgio svertinis vidurkis per mėnesį', 1761, 4, NULL, NULL),
	(8777, 355, -4, 7, 1, 0, 28, 7, 367, NULL, 'Momentinis pamaitinimo vandens slėgio svertinis vidurkis', 1758, 6, NULL, NULL),
	(8778, 357, 0, 4, 2, 0, 29, 4, 369, NULL, '1-os neįprastos situacijos trukmė šilumos sistemoje per valandą', 1751, 2, NULL, NULL),
	(8779, 357, 0, 5, 2, 0, 29, 5, 369, NULL, '1-os neįprastos situacijos trukmė šilumos sistemoje per parą', 1751, 3, NULL, NULL),
	(8780, 357, 0, 6, 2, 0, 29, 6, 369, NULL, '1-os neįprastos situacijos trukmė šilumos sistemoje per mėnesį', 1751, 4, NULL, NULL),
	(8781, 357, 0, 8, 2, 0, 29, 7, 369, NULL, 'Suminė 1-os neįprastos situacijos trukmė šilumos sistemoje', 1746, 5, NULL, NULL),
	(8782, 358, 0, 4, 2, 0, 29, 4, 370, NULL, '2-os neįprastos situacijos trukmė šilumos sistemoje per valandą', 1752, 2, NULL, NULL),
	(8783, 358, 0, 5, 2, 0, 29, 5, 370, NULL, '2-os neįprastos situacijos trukmė šilumos sistemoje per parą', 1752, 3, NULL, NULL),
	(8784, 358, 0, 6, 2, 0, 29, 6, 370, NULL, '2-os neįprastos situacijos trukmė šilumos sistemoje per mėnesį', 1752, 4, NULL, NULL),
	(8785, 358, 0, 8, 2, 0, 29, 7, 370, NULL, 'Suminė 2-os neįprastos situacijos trukmė šilumos sistemoje', 1747, 5, NULL, NULL),
	(8786, 359, 0, 4, 2, 0, 29, 4, 371, NULL, '3-os neįprastos situacijos trukmė šilumos sistemoje per valandą', 1753, 2, NULL, NULL),
	(8787, 359, 0, 5, 2, 0, 29, 5, 371, NULL, '3-os neįprastos situacijos trukmė šilumos sistemoje per parą', 1753, 3, NULL, NULL),
	(8788, 359, 0, 6, 2, 0, 29, 6, 371, NULL, '3-os neįprastos situacijos trukmė šilumos sistemoje per mėnesį', 1753, 4, NULL, NULL),
	(8789, 359, 0, 8, 2, 0, 29, 7, 371, NULL, 'Suminė 3-os neįprastos situacijos trukmė šilumos sistemoje', 1748, 5, NULL, NULL),
	(8790, 360, 0, 4, 2, 0, 29, 4, 372, NULL, '4-os neįprastos situacijos trukmė šilumos sistemoje per valandą', 1754, 2, NULL, NULL),
	(8791, 360, 0, 5, 2, 0, 29, 5, 372, NULL, '4-os neįprastos situacijos trukmė šilumos sistemoje per parą', 1754, 3, NULL, NULL),
	(8792, 360, 0, 6, 2, 0, 29, 6, 372, NULL, '4-os neįprastos situacijos trukmė šilumos sistemoje per mėnesį', 1754, 4, NULL, NULL),
	(8793, 360, 0, 8, 2, 0, 29, 7, 372, NULL, 'Suminė 4-os neįprastos situacijos trukmė šilumos sistemoje', 1749, 5, NULL, NULL),
	(8794, 361, 0, 4, 2, 0, 29, 4, 373, NULL, '5-os neįprastos situacijos trukmė šilumos sistemoje per valandą', 1755, 2, NULL, NULL),
	(8795, 361, 0, 5, 2, 0, 29, 5, 373, NULL, '5-os neįprastos situacijos trukmė šilumos sistemoje per parą', 1755, 3, NULL, NULL),
	(8796, 361, 0, 6, 2, 0, 29, 6, 373, NULL, '5-os neįprastos situacijos trukmė šilumos sistemoje per mėnesį', 1755, 4, NULL, NULL),
	(8797, 361, 0, 8, 2, 0, 29, 7, 373, NULL, 'Suminė 5-os neįprastos situacijos trukmė šilumos sistemoje', 1750, 5, NULL, NULL),
	(8798, 37, 0, 13, 3, 0, 8, 12, 48, NULL, 'Vidutinis dažnis per 15 minučių', 812, 2, NULL, NULL),
	(8799, 37, 0, 3, 3, 0, 8, 3, 48, NULL, 'Vidutinis dažnis per 30 minučių', 812, 2, NULL, NULL),
	(8800, 37, 0, 4, 3, 0, 8, 4, 48, NULL, 'Vidutinis dažnis per valandą', 812, 2, NULL, NULL),
	(8801, 362, 0, 6, 2, 0, 1, 6, 374, NULL, 'Aktyvios galios 10-s maksimalių reikšmių suma per mėnesį', 3348, 4, NULL, NULL),
	(8802, 363, 0, 6, 2, 0, 3, 6, 375, NULL, 'Reaktyvios galios 10-s maksimalių reikšmių suma per mėnesį', 3349, 4, NULL, NULL),
	(8803, 364, 0, 6, 2, 0, 7, 6, 376, NULL, 'Pilnos galios 10-s maksimalių reikšmių suma per mėnesį', 3350, 4, NULL, NULL),
	(8804, 365, 0, 3, 2, 0, 0, 3, 377, NULL, 'Rodiklis Nr.11 per 30 minučių', NULL, 2, NULL, NULL),
	(8805, 365, 0, 4, 2, 0, 0, 4, 377, NULL, 'Rodiklis Nr.11 per valandą', NULL, 2, NULL, NULL),
	(8806, 365, 0, 5, 2, 0, 0, 5, 377, NULL, 'Rodiklis Nr.11 per parą', NULL, 3, NULL, NULL),
	(8807, 365, 0, 6, 2, 0, 0, 6, 377, NULL, 'Rodiklis Nr.11 per mėnesį', NULL, 4, NULL, NULL),
	(8808, 365, 0, 7, 1, 0, 0, 7, 377, NULL, 'Momentinis rodiklis Nr.11', NULL, 6, NULL, NULL),
	(8809, 365, 0, 13, 2, 0, 0, 12, 377, NULL, 'Rodiklis Nr.11 per 15 minučių', NULL, 2, NULL, NULL),
	(8810, 366, 0, 3, 2, 0, 0, 3, 378, NULL, 'Rodiklis Nr.12 per 30 minučių', NULL, 2, NULL, NULL),
	(8811, 366, 0, 4, 2, 0, 0, 4, 378, NULL, 'Rodiklis Nr.12 per valandą', NULL, 2, NULL, NULL),
	(8812, 366, 0, 5, 2, 0, 0, 5, 378, NULL, 'Rodiklis Nr.12 per parą', NULL, 3, NULL, NULL),
	(8813, 366, 0, 6, 2, 0, 0, 6, 378, NULL, 'Rodiklis Nr.12 per mėnesį', NULL, 4, NULL, NULL),
	(8814, 366, 0, 7, 1, 0, 0, 7, 378, NULL, 'Momentinis rodiklis Nr.12', NULL, 6, NULL, NULL),
	(8815, 366, 0, 13, 2, 0, 0, 12, 378, NULL, 'Rodiklis Nr.12 per 15 minučių', NULL, 2, NULL, NULL),
	(8816, 367, 0, 3, 2, 0, 0, 3, 379, NULL, 'Rodiklis Nr.13 per 30 minučių', NULL, 2, NULL, NULL),
	(8817, 367, 0, 4, 2, 0, 0, 4, 379, NULL, 'Rodiklis Nr.13 per valandą', NULL, 2, NULL, NULL),
	(8818, 367, 0, 5, 2, 0, 0, 5, 379, NULL, 'Rodiklis Nr.13 per parą', NULL, 3, NULL, NULL),
	(8819, 367, 0, 6, 2, 0, 0, 6, 379, NULL, 'Rodiklis Nr.13 per mėnesį', NULL, 4, NULL, NULL),
	(8820, 367, 0, 7, 1, 0, 0, 7, 379, NULL, 'Momentinis rodiklis Nr.13', NULL, 6, NULL, NULL),
	(8821, 367, 0, 13, 2, 0, 0, 12, 379, NULL, 'Rodiklis Nr.13 per 15 minučių', NULL, 2, NULL, NULL),
	(8822, 368, 0, 3, 2, 0, 0, 3, 380, NULL, 'Rodiklis Nr.14 per 30 minučių', NULL, 2, NULL, NULL),
	(8823, 368, 0, 4, 2, 0, 0, 4, 380, NULL, 'Rodiklis Nr.14 per valandą', NULL, 2, NULL, NULL),
	(8824, 368, 0, 5, 2, 0, 0, 5, 380, NULL, 'Rodiklis Nr.14 per parą', NULL, 3, NULL, NULL),
	(8825, 368, 0, 6, 2, 0, 0, 6, 380, NULL, 'Rodiklis Nr.14 per mėnesį', NULL, 4, NULL, NULL),
	(8826, 368, 0, 7, 1, 0, 0, 7, 380, NULL, 'Momentinis rodiklis Nr.14', NULL, 6, NULL, NULL),
	(8827, 368, 0, 13, 2, 0, 0, 12, 380, NULL, 'Rodiklis Nr.14 per 15 minučių', NULL, 2, NULL, NULL),
	(8828, 369, 0, 3, 2, 0, 0, 3, 381, NULL, 'Rodiklis Nr.15 per 30 minučių', NULL, 2, NULL, NULL),
	(8829, 369, 0, 4, 2, 0, 0, 4, 381, NULL, 'Rodiklis Nr.15 per valandą', NULL, 2, NULL, NULL),
	(8830, 369, 0, 5, 2, 0, 0, 5, 381, NULL, 'Rodiklis Nr.15 per parą', NULL, 3, NULL, NULL),
	(8831, 369, 0, 6, 2, 0, 0, 6, 381, NULL, 'Rodiklis Nr.15 per mėnesį', NULL, 4, NULL, NULL),
	(8832, 369, 0, 7, 1, 0, 0, 7, 381, NULL, 'Momentinis rodiklis Nr.15', NULL, 6, NULL, NULL),
	(8833, 369, 0, 13, 2, 0, 0, 12, 381, NULL, 'Rodiklis Nr.15 per 15 minučių', NULL, 2, NULL, NULL),
	(8834, 370, 0, 3, 3, 0, 0, 3, 382, NULL, 'Vidutinis rodiklis Nr.16 per 30 minučių', NULL, 2, NULL, NULL),
	(8835, 370, 0, 4, 3, 0, 0, 4, 382, NULL, 'Vidutinis rodiklis Nr.16 per valandą', NULL, 2, NULL, NULL),
	(8836, 370, 0, 5, 3, 0, 0, 5, 382, NULL, 'Vidutinis rodiklis Nr.16 per parą', NULL, 3, NULL, NULL),
	(8837, 370, 0, 6, 3, 0, 0, 6, 382, NULL, 'Vidutinis rodiklis Nr.16 per mėnesį', NULL, 4, NULL, NULL),
	(8838, 370, 0, 7, 1, 0, 0, 7, 382, NULL, 'Momentinis rodiklis Nr.16', NULL, 6, NULL, NULL),
	(8839, 370, 0, 13, 3, 0, 0, 12, 382, NULL, 'Vidutinis rodiklis Nr.16 per 15 minučių', NULL, 2, NULL, NULL),
	(8840, 371, 0, 3, 3, 0, 0, 3, 383, NULL, 'Vidutinis rodiklis Nr.17 per 30 minučių', NULL, 2, NULL, NULL),
	(8841, 371, 0, 4, 3, 0, 0, 4, 383, NULL, 'Vidutinis rodiklis Nr.17 per valandą', NULL, 2, NULL, NULL),
	(8842, 371, 0, 5, 3, 0, 0, 5, 383, NULL, 'Vidutinis rodiklis Nr.17 per parą', NULL, 3, NULL, NULL),
	(8843, 371, 0, 6, 3, 0, 0, 6, 383, NULL, 'Vidutinis rodiklis Nr.17 per mėnesį', NULL, 4, NULL, NULL),
	(8844, 371, 0, 7, 1, 0, 0, 7, 383, NULL, 'Momentinis rodiklis Nr.17', NULL, 6, NULL, NULL),
	(8845, 371, 0, 13, 3, 0, 0, 12, 383, NULL, 'Vidutinis rodiklis Nr.17 per 15 minučių', NULL, 2, NULL, NULL),
	(8846, 372, 0, 3, 3, 0, 0, 3, 384, NULL, 'Vidutinis rodiklis Nr.18 per 30 minučių', NULL, 2, NULL, NULL),
	(8847, 372, 0, 4, 3, 0, 0, 4, 384, NULL, 'Vidutinis rodiklis Nr.18 per valandą', NULL, 2, NULL, NULL),
	(8848, 372, 0, 5, 3, 0, 0, 5, 384, NULL, 'Vidutinis rodiklis Nr.18 per parą', NULL, 3, NULL, NULL),
	(8849, 372, 0, 6, 3, 0, 0, 6, 384, NULL, 'Vidutinis rodiklis Nr.18 per mėnesį', NULL, 4, NULL, NULL),
	(8850, 372, 0, 7, 1, 0, 0, 7, 384, NULL, 'Momentinis rodiklis Nr.18', NULL, 6, NULL, NULL),
	(8851, 372, 0, 13, 3, 0, 0, 12, 384, NULL, 'Vidutinis rodiklis Nr.18 per 15 minučių', NULL, 2, NULL, NULL),
	(8852, 373, 0, 3, 3, 0, 0, 3, 385, NULL, 'Vidutinis rodiklis Nr.19 per 30 minučių', NULL, 2, NULL, NULL),
	(8853, 373, 0, 4, 3, 0, 0, 4, 385, NULL, 'Vidutinis rodiklis Nr.19 per valandą', NULL, 2, NULL, NULL),
	(8854, 373, 0, 5, 3, 0, 0, 5, 385, NULL, 'Vidutinis rodiklis Nr.19 per parą', NULL, 3, NULL, NULL),
	(8855, 373, 0, 6, 3, 0, 0, 6, 385, NULL, 'Vidutinis rodiklis Nr.19 per mėnesį', NULL, 4, NULL, NULL),
	(8856, 373, 0, 7, 1, 0, 0, 7, 385, NULL, 'Momentinis rodiklis Nr.19', NULL, 6, NULL, NULL),
	(8857, 373, 0, 13, 3, 0, 0, 12, 385, NULL, 'Vidutinis rodiklis Nr.19 per 15 minučių', NULL, 2, NULL, NULL),
	(8858, 374, 0, 3, 3, 0, 0, 3, 386, NULL, 'Vidutinis rodiklis Nr.20 per 30 minučių', NULL, 2, NULL, NULL),
	(8859, 374, 0, 4, 3, 0, 0, 4, 386, NULL, 'Vidutinis rodiklis Nr.20 per valandą', NULL, 2, NULL, NULL),
	(8860, 374, 0, 5, 3, 0, 0, 5, 386, NULL, 'Vidutinis rodiklis Nr.20 per parą', NULL, 3, NULL, NULL),
	(8861, 374, 0, 6, 3, 0, 0, 6, 386, NULL, 'Vidutinis rodiklis Nr.20 per mėnesį', NULL, 4, NULL, NULL),
	(8862, 374, 0, 7, 1, 0, 0, 7, 386, NULL, 'Momentinis rodiklis Nr.20', NULL, 6, NULL, NULL),
	(8863, 374, 0, 13, 3, 0, 0, 12, 386, NULL, 'Vidutinis rodiklis Nr.20 per 15 minučių', NULL, 2, NULL, NULL),
	(8864, 187, 0, 7, 1, 0, 0, 4, 200, NULL, 'Momentinis rodiklis Nr.1, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8865, 344, 0, 7, 1, 0, 0, 4, 356, NULL, 'Momentinis rodiklis Nr.2, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8866, 345, 0, 7, 1, 0, 0, 4, 357, NULL, 'Momentinis rodiklis Nr.3, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8867, 346, 0, 7, 1, 0, 0, 4, 358, NULL, 'Momentinis rodiklis Nr.4, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8868, 347, 0, 7, 1, 0, 0, 4, 359, NULL, 'Momentinis rodiklis Nr.5, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8869, 348, 0, 7, 1, 0, 0, 4, 360, NULL, 'Momentinis rodiklis Nr.6, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8870, 349, 0, 7, 1, 0, 0, 4, 361, NULL, 'Momentinis rodiklis Nr.7, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8871, 350, 0, 7, 1, 0, 0, 4, 362, NULL, 'Momentinis rodiklis Nr.8, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8872, 351, 0, 7, 1, 0, 0, 4, 363, NULL, 'Momentinis rodiklis Nr.9, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8873, 352, 0, 7, 1, 0, 0, 4, 364, NULL, 'Momentinis rodiklis Nr.10, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8874, 365, 0, 7, 1, 0, 0, 4, 377, NULL, 'Momentinis rodiklis Nr.11, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8875, 366, 0, 7, 1, 0, 0, 4, 378, NULL, 'Momentinis rodiklis Nr.12, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8876, 367, 0, 7, 1, 0, 0, 4, 379, NULL, 'Momentinis rodiklis Nr.13, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8877, 368, 0, 7, 1, 0, 0, 4, 380, NULL, 'Momentinis rodiklis Nr.14, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8878, 369, 0, 7, 1, 0, 0, 4, 381, NULL, 'Momentinis rodiklis Nr.15, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8879, 370, 0, 7, 1, 0, 0, 4, 382, NULL, 'Momentinis rodiklis Nr.16, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8880, 371, 0, 7, 1, 0, 0, 4, 383, NULL, 'Momentinis rodiklis Nr.17, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8881, 372, 0, 7, 1, 0, 0, 4, 384, NULL, 'Momentinis rodiklis Nr.18, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8882, 373, 0, 7, 1, 0, 0, 4, 385, NULL, 'Momentinis rodiklis Nr.19, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8883, 374, 0, 7, 1, 0, 0, 4, 386, NULL, 'Momentinis rodiklis Nr.20, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8884, 187, 0, 7, 1, 0, 0, 5, 200, NULL, 'Momentinis rodiklis Nr.1, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8885, 344, 0, 7, 1, 0, 0, 5, 356, NULL, 'Momentinis rodiklis Nr.2, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8886, 345, 0, 7, 1, 0, 0, 5, 357, NULL, 'Momentinis rodiklis Nr.3, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8887, 346, 0, 7, 1, 0, 0, 5, 358, NULL, 'Momentinis rodiklis Nr.4, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8888, 347, 0, 7, 1, 0, 0, 5, 359, NULL, 'Momentinis rodiklis Nr.5, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8889, 348, 0, 7, 1, 0, 0, 5, 360, NULL, 'Momentinis rodiklis Nr.6, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8890, 349, 0, 7, 1, 0, 0, 5, 361, NULL, 'Momentinis rodiklis Nr.7, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8891, 350, 0, 7, 1, 0, 0, 5, 362, NULL, 'Momentinis rodiklis Nr.8, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8892, 351, 0, 7, 1, 0, 0, 5, 363, NULL, 'Momentinis rodiklis Nr.9, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8893, 352, 0, 7, 1, 0, 0, 5, 364, NULL, 'Momentinis rodiklis Nr.10, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8894, 365, 0, 7, 1, 0, 0, 5, 377, NULL, 'Momentinis rodiklis Nr.11, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8895, 366, 0, 7, 1, 0, 0, 5, 378, NULL, 'Momentinis rodiklis Nr.12, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8896, 367, 0, 7, 1, 0, 0, 5, 379, NULL, 'Momentinis rodiklis Nr.13, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8897, 368, 0, 7, 1, 0, 0, 5, 380, NULL, 'Momentinis rodiklis Nr.14, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8898, 369, 0, 7, 1, 0, 0, 5, 381, NULL, 'Momentinis rodiklis Nr.15, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8899, 370, 0, 7, 1, 0, 0, 5, 382, NULL, 'Momentinis rodiklis Nr.16, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8900, 371, 0, 7, 1, 0, 0, 5, 383, NULL, 'Momentinis rodiklis Nr.17, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8901, 372, 0, 7, 1, 0, 0, 5, 384, NULL, 'Momentinis rodiklis Nr.18, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8902, 373, 0, 7, 1, 0, 0, 5, 385, NULL, 'Momentinis rodiklis Nr.19, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8903, 374, 0, 7, 1, 0, 0, 5, 386, NULL, 'Momentinis rodiklis Nr.20, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8904, 375, 0, 3, 2, 0, 0, 3, 387, NULL, 'Rodiklis Nr.21 per 30 minučių', NULL, 2, NULL, NULL),
	(8905, 375, 0, 4, 2, 0, 0, 4, 387, NULL, 'Rodiklis Nr.21 per valandą', NULL, 2, NULL, NULL),
	(8906, 375, 0, 5, 2, 0, 0, 5, 387, NULL, 'Rodiklis Nr.21 per parą', NULL, 3, NULL, NULL),
	(8907, 375, 0, 6, 2, 0, 0, 6, 387, NULL, 'Rodiklis Nr.21 per mėnesį', NULL, 4, NULL, NULL),
	(8908, 375, 0, 7, 1, 0, 0, 7, 387, NULL, 'Andriaus rodiklis', NULL, 6, NULL, NULL),
	(8909, 375, 0, 13, 2, 0, 0, 12, 387, NULL, 'Rodiklis Nr.21 per 15 minučių', NULL, 2, NULL, NULL),
	(8910, 376, 0, 3, 2, 0, 0, 3, 388, NULL, 'Rodiklis Nr.22 per 30 minučių', NULL, 2, NULL, NULL),
	(8911, 376, 0, 4, 2, 0, 0, 4, 388, NULL, 'Rodiklis Nr.22 per valandą', NULL, 2, NULL, NULL),
	(8912, 376, 0, 5, 2, 0, 0, 5, 388, NULL, 'Rodiklis Nr.22 per parą', NULL, 3, NULL, NULL),
	(8913, 376, 0, 6, 2, 0, 0, 6, 388, NULL, 'Rodiklis Nr.22 per mėnesį', NULL, 4, NULL, NULL),
	(8914, 376, 0, 7, 1, 0, 0, 7, 388, NULL, 'Momentinis rodiklis Nr.22', NULL, 6, NULL, NULL),
	(8915, 376, 0, 13, 2, 0, 0, 12, 388, NULL, 'Rodiklis Nr.22 per 15 minučių', NULL, 2, NULL, NULL),
	(8916, 377, 0, 3, 2, 0, 0, 3, 389, NULL, 'Rodiklis Nr.23 per 30 minučių', NULL, 2, NULL, NULL),
	(8917, 377, 0, 4, 2, 0, 0, 4, 389, NULL, 'Rodiklis Nr.23 per valanda', NULL, 2, NULL, NULL),
	(8918, 377, 0, 5, 2, 0, 0, 5, 389, NULL, 'Rodiklis Nr.23 per parą', NULL, 3, NULL, NULL),
	(8919, 377, 0, 6, 2, 0, 0, 6, 389, NULL, 'Rodiklis Nr.23 per mėnesį', NULL, 4, NULL, NULL),
	(8920, 377, 0, 7, 1, 0, 0, 7, 389, NULL, 'Momentinis rodiklis Nr.23', NULL, 6, NULL, NULL),
	(8921, 377, 0, 13, 2, 0, 0, 12, 389, NULL, 'Rodiklis Nr.23 per 15 minuciu', NULL, 2, NULL, NULL),
	(8922, 378, 0, 3, 2, 0, 0, 3, 390, NULL, 'Rodiklis Nr.24 per 30 minučių', NULL, 2, NULL, NULL),
	(8923, 378, 0, 4, 2, 0, 0, 4, 390, NULL, 'Rodiklis Nr.24 per valandą', NULL, 2, NULL, NULL),
	(8924, 378, 0, 5, 2, 0, 0, 5, 390, NULL, 'Rodiklis Nr.24 per parą', NULL, 3, NULL, NULL),
	(8925, 378, 0, 6, 2, 0, 0, 6, 390, NULL, 'Rodiklis Nr.24 per mėnesį', NULL, 4, NULL, NULL),
	(8926, 378, 0, 7, 1, 0, 0, 7, 390, NULL, 'Momentinis rodiklis Nr.24', NULL, 6, NULL, NULL),
	(8927, 378, 0, 13, 2, 0, 0, 12, 390, NULL, 'Rodiklis Nr.24 per 15 minučių', NULL, 2, NULL, NULL),
	(8928, 379, 0, 3, 2, 0, 0, 3, 391, NULL, 'Rodiklis Nr.25 per 30 minučių', NULL, 2, NULL, NULL),
	(8929, 379, 0, 4, 2, 0, 0, 4, 391, NULL, 'Rodiklis Nr.25 per valandą', NULL, 2, NULL, NULL),
	(8930, 379, 0, 5, 2, 0, 0, 5, 391, NULL, 'Rodiklis Nr.25 per parą', NULL, 3, NULL, NULL),
	(8931, 379, 0, 6, 2, 0, 0, 6, 391, NULL, 'Rodiklis Nr.25 per mėnesį', NULL, 4, NULL, NULL),
	(8932, 379, 0, 7, 1, 0, 0, 7, 391, NULL, 'Momentinis rodiklis Nr.25', NULL, 6, NULL, NULL),
	(8933, 379, 0, 13, 2, 0, 0, 12, 391, NULL, 'Rodiklis Nr.25 per 15 minučių', NULL, 2, NULL, NULL),
	(8934, 380, 0, 3, 2, 0, 0, 3, 392, NULL, 'Rodiklis Nr.26 per 30 minučių', NULL, 2, NULL, NULL),
	(8935, 380, 0, 4, 2, 0, 0, 4, 392, NULL, 'Rodiklis Nr.26 per valandą', NULL, 2, NULL, NULL),
	(8936, 380, 0, 5, 2, 0, 0, 5, 392, NULL, 'Rodiklis Nr.26 per parą', NULL, 3, NULL, NULL),
	(8937, 380, 0, 6, 2, 0, 0, 6, 392, NULL, 'Rodiklis Nr.26 per mėnesį', NULL, 4, NULL, NULL),
	(8938, 380, 0, 7, 1, 0, 0, 7, 392, NULL, 'Momentinis rodiklis Nr.26', NULL, 6, NULL, NULL),
	(8939, 380, 0, 13, 2, 0, 0, 12, 392, NULL, 'Rodiklis Nr.26 per 15 minučių', NULL, 2, NULL, NULL),
	(8940, 381, 0, 3, 2, 0, 0, 3, 393, NULL, 'Rodiklis Nr.27 per 30 minučių', NULL, 2, NULL, NULL),
	(8941, 381, 0, 4, 2, 0, 0, 4, 393, NULL, 'Rodiklis Nr.27 per valandą', NULL, 2, NULL, NULL),
	(8942, 381, 0, 5, 2, 0, 0, 5, 393, NULL, 'Rodiklis Nr.27 per parą', NULL, 3, NULL, NULL),
	(8943, 381, 0, 6, 2, 0, 0, 6, 393, NULL, 'Rodiklis Nr.27 per mėnesį', NULL, 4, NULL, NULL),
	(8944, 381, 0, 7, 1, 0, 0, 7, 393, NULL, 'Momentinis rodiklis Nr.27', NULL, 6, NULL, NULL),
	(8945, 381, 0, 13, 2, 0, 0, 12, 393, NULL, 'Rodiklis Nr.27 per 15 minučių', NULL, 2, NULL, NULL),
	(8946, 382, 0, 3, 2, 0, 0, 3, 394, NULL, 'Rodiklis Nr.28 per 30 minučių', NULL, 2, NULL, NULL),
	(8947, 382, 0, 4, 2, 0, 0, 4, 394, NULL, 'Rodiklis Nr.28 per valandą', NULL, 2, NULL, NULL),
	(8948, 382, 0, 5, 2, 0, 0, 5, 394, NULL, 'Rodiklis Nr.28 per parą', NULL, 3, NULL, NULL),
	(8949, 382, 0, 6, 2, 0, 0, 6, 394, NULL, 'Rodiklis Nr.28 per mėnesį', NULL, 4, NULL, NULL),
	(8950, 382, 0, 7, 1, 0, 0, 7, 394, NULL, 'Momentinis rodiklis Nr.28', NULL, 6, NULL, NULL),
	(8951, 382, 0, 13, 2, 0, 0, 12, 394, NULL, 'Rodiklis Nr.28 per 15 minučių', NULL, 2, NULL, NULL),
	(8952, 383, 0, 3, 2, 0, 0, 3, 395, NULL, 'Rodiklis Nr.29 per 30 minučių', NULL, 2, NULL, NULL),
	(8953, 383, 0, 4, 2, 0, 0, 4, 395, NULL, 'Rodiklis Nr.29 per valandą', NULL, 2, NULL, NULL),
	(8954, 383, 0, 5, 2, 0, 0, 5, 395, NULL, 'Rodiklis Nr.29 per parą', NULL, 3, NULL, NULL),
	(8955, 383, 0, 6, 2, 0, 0, 6, 395, NULL, 'Rodiklis Nr.29 per mėnesį', NULL, 4, NULL, NULL),
	(8956, 383, 0, 7, 1, 0, 0, 7, 395, NULL, 'Momentinis rodiklis Nr.29', NULL, 6, NULL, NULL),
	(8957, 383, 0, 13, 2, 0, 0, 12, 395, NULL, 'Rodiklis Nr.29 per 15 minučių', NULL, 2, NULL, NULL),
	(8958, 384, 0, 3, 2, 0, 0, 3, 455, NULL, 'Rodiklis Nr.30 per 30 minučių', NULL, 2, NULL, NULL),
	(8959, 384, 0, 4, 2, 0, 0, 4, 455, NULL, 'Rodiklis Nr.30 per valandą', NULL, 2, NULL, NULL),
	(8960, 384, 0, 5, 2, 0, 0, 5, 455, NULL, 'Rodiklis Nr.30 per parą', NULL, 3, NULL, NULL),
	(8961, 384, 0, 6, 2, 0, 0, 6, 455, NULL, 'Rodiklis Nr.30 per mėnesį', NULL, 4, NULL, NULL),
	(8962, 384, 0, 7, 1, 0, 0, 7, 455, NULL, 'Momentinis rodiklis Nr.30', NULL, 6, NULL, NULL),
	(8963, 384, 0, 13, 2, 0, 0, 12, 455, NULL, 'Rodiklis Nr.30 per 15 minučių', NULL, 2, NULL, NULL),
	(8964, 375, 0, 7, 1, 0, 0, 4, 387, NULL, 'Momentinis rodiklis Nr.21, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8965, 376, 0, 7, 1, 0, 0, 4, 388, NULL, 'tiesiog 22, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8966, 377, 0, 7, 1, 0, 0, 4, 389, NULL, 'Momentinis rodiklis Nr.23, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8967, 378, 0, 7, 1, 0, 0, 4, 390, NULL, 'Momentinis rodiklis Nr.24, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8968, 379, 0, 7, 1, 0, 0, 4, 391, NULL, 'Momentinis rodiklis Nr.25, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8969, 380, 0, 7, 1, 0, 0, 4, 392, NULL, 'Momentinis rodiklis Nr.26, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8970, 381, 0, 7, 1, 0, 0, 4, 393, NULL, 'Momentinis rodiklis Nr.27, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8971, 382, 0, 7, 1, 0, 0, 4, 394, NULL, 'Momentinis rodiklis Nr.28, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8972, 383, 0, 7, 1, 0, 0, 4, 395, NULL, 'Momentinis rodiklis Nr.29, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8973, 384, 0, 7, 1, 0, 0, 4, 455, NULL, 'Momentinis rodiklis Nr.30, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(8974, 375, 0, 7, 1, 0, 0, 5, 387, NULL, 'Momentinis rodiklis Nr.21, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8975, 376, 0, 7, 1, 0, 0, 5, 388, NULL, 'Momentinis rodiklis Nr.22, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8976, 377, 0, 7, 1, 0, 0, 5, 389, NULL, 'Momentinis rodiklis Nr.23, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8977, 378, 0, 7, 1, 0, 0, 5, 390, NULL, 'Momentinis rodiklis Nr.24, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8978, 379, 0, 7, 1, 0, 0, 5, 391, NULL, 'Momentinis rodiklis Nr.25, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8979, 380, 0, 7, 1, 0, 0, 5, 392, NULL, 'Momentinis rodiklis Nr.26, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8980, 381, 0, 7, 1, 0, 0, 5, 393, NULL, 'Momentinis rodiklis Nr.27, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8981, 382, 0, 7, 1, 0, 0, 5, 394, NULL, 'Momentinis rodiklis Nr.28, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8982, 383, 0, 7, 1, 0, 0, 5, 395, NULL, 'Momentinis rodiklis Nr.29, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8983, 384, 0, 7, 1, 0, 0, 5, 455, NULL, 'Momentinis rodiklis Nr.30, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(8984, 385, 0, 7, 1, 1, 1, 6, 396, NULL, 'Kumuliacinė P galia pagal 1 tarifą, fiksuojama kas mėnesį', 3354, 4, NULL, NULL),
	(8985, 385, 0, 7, 1, 2, 1, 6, 396, NULL, 'Kumuliacinė P galia pagal 2 tarifą, fiksuojama kas mėnesį', 3357, 4, NULL, NULL),
	(8986, 385, 0, 7, 1, 3, 1, 6, 396, NULL, 'Kumuliacinė P galia pagal 3 tarifą, fiksuojama kas mėnesį', 3360, 4, NULL, NULL),
	(8987, 385, 0, 7, 1, 4, 1, 6, 396, NULL, 'Kumuliacinė P galia pagal 4 tarifą, fiksuojama kas mėnesį', 3363, 4, NULL, NULL),
	(8988, 385, 0, 7, 1, 0, 1, 6, 396, NULL, 'Kumuliacinė P galia, fiksuojama kas mėnesį', 3406, 4, NULL, NULL),
	(8989, 385, 1, 7, 1, 1, 1, 6, 396, NULL, 'Kumuliacinė P+ galia pagal 1 tarifą, fiksuojama kas mėnesį', 3366, 4, NULL, NULL),
	(8990, 385, 1, 7, 1, 2, 1, 6, 396, NULL, 'Kumuliacinė P+ galia pagal 2 tarifą, fiksuojama kas mėnesį', 3369, 4, NULL, NULL),
	(8991, 385, 1, 7, 1, 3, 1, 6, 396, NULL, 'Kumuliacinė P+ galia pagal 3 tarifą, fiksuojama kas mėnesį', 3372, 4, NULL, NULL),
	(8992, 385, 1, 7, 1, 4, 1, 6, 396, NULL, 'Kumuliacinė P+ galia pagal 4 tarifą, fiksuojama kas mėnesį', 3375, 4, NULL, NULL),
	(8993, 385, 1, 7, 1, 0, 1, 6, 396, NULL, 'Kumuliacinė P+ galia, fiksuojama kas mėnesį', 3409, 4, NULL, NULL),
	(8994, 385, 2, 7, 1, 1, 1, 6, 396, NULL, 'Kumuliacinė P- galia pagal 1 tarifą, fiksuojama kas mėnesį', 3378, 4, NULL, NULL),
	(8995, 385, 2, 7, 1, 2, 1, 6, 396, NULL, 'Kumuliacinė P- galia pagal 2 tarifą, fiksuojama kas mėnesį', 3381, 4, NULL, NULL),
	(8996, 385, 2, 7, 1, 3, 1, 6, 396, NULL, 'Kumuliacinė P- galia pagal 3 tarifą, fiksuojama kas mėnesį', 3384, 4, NULL, NULL),
	(8997, 385, 2, 7, 1, 4, 1, 6, 396, NULL, 'Kumuliacinė P- galia pagal 4 tarifą, fiksuojama kas mėnesį', 3387, 4, NULL, NULL),
	(8998, 385, 2, 7, 1, 0, 1, 6, 396, NULL, 'Kumuliacinė P- galia, fiksuojama kas mėnesį', 3412, 4, NULL, NULL),
	(8999, 386, 0, 7, 1, 1, 7, 6, 397, NULL, 'Kumuliacinė S galia pagal 1 tarifą, fiksuojama kas mėnesį', 3356, 4, NULL, NULL),
	(9000, 386, 0, 7, 1, 2, 7, 6, 397, NULL, 'Kumuliacinė S galia pagal 2 tarifą, fiksuojama kas mėnesį', 3359, 4, NULL, NULL),
	(9001, 386, 0, 7, 1, 3, 7, 6, 397, NULL, 'Kumuliacinė S galia pagal 3 tarifą, fiksuojama kas mėnesį', 3362, 4, NULL, NULL),
	(9002, 386, 0, 7, 1, 4, 7, 6, 397, NULL, 'Kumuliacinė S galia pagal 4 tarifą, fiksuojama kas mėnesį', 3365, 4, NULL, NULL),
	(9003, 386, 0, 7, 1, 0, 7, 6, 397, NULL, 'Kumuliacinė S galia, fiksuojama kas mėnesį', 3408, 4, NULL, NULL),
	(9004, 386, 1, 7, 1, 1, 7, 6, 397, NULL, 'Kumuliacinė S+ galia pagal 1 tarifą, fiksuojama kas mėnesį', 3368, 4, NULL, NULL),
	(9005, 386, 1, 7, 1, 2, 7, 6, 397, NULL, 'Kumuliacinė S+ galia pagal 2 tarifą, fiksuojama kas mėnesį', 3371, 4, NULL, NULL),
	(9006, 386, 1, 7, 1, 3, 7, 6, 397, NULL, 'Kumuliacinė S+ galia pagal 3 tarifą, fiksuojama kas mėnesį', 3374, 4, NULL, NULL),
	(9007, 386, 1, 7, 1, 4, 7, 6, 397, NULL, 'Kumuliacinė S+ galia pagal 4 tarifą, fiksuojama kas mėnesį', 3377, 4, NULL, NULL),
	(9008, 386, 1, 7, 1, 0, 7, 6, 397, NULL, 'Kumuliacinė S+ galia, fiksuojama kas mėnesį', 3411, 4, NULL, NULL),
	(9009, 386, 2, 7, 1, 1, 7, 6, 397, NULL, 'Kumuliacinė S- galia pagal 1 tarifą, fiksuojama kas mėnesį', 3380, 4, NULL, NULL),
	(9010, 386, 2, 7, 1, 2, 7, 6, 397, NULL, 'Kumuliacinė S- galia pagal 2 tarifą, fiksuojama kas mėnesį', 3383, 4, NULL, NULL),
	(9011, 386, 2, 7, 1, 3, 7, 6, 397, NULL, 'Kumuliacinė S- galia pagal 3 tarifą, fiksuojama kas mėnesį', 3386, 4, NULL, NULL),
	(9012, 386, 2, 7, 1, 4, 7, 6, 397, NULL, 'Kumuliacinė S- galia pagal 4 tarifą, fiksuojama kas mėnesį', 3389, 4, NULL, NULL),
	(9013, 386, 2, 7, 1, 0, 7, 6, 397, NULL, 'Kumuliacinė S- galia, fiksuojama kas mėnesį', 3414, 4, NULL, NULL),
	(9014, 387, 0, 7, 1, 1, 3, 6, 398, NULL, 'Kumuliacinė Q galia pagal 1 tarifą, fiksuojama kas mėnesį', 3355, 4, NULL, NULL),
	(9015, 387, 0, 7, 1, 2, 3, 6, 398, NULL, 'Kumuliacinė Q galia pagal 2 tarifą, fiksuojama kas mėnesį', 3358, 4, NULL, NULL),
	(9016, 387, 0, 7, 1, 3, 3, 6, 398, NULL, 'Kumuliacinė Q galia pagal 3 tarifą, fiksuojama kas mėnesį', 3361, 4, NULL, NULL),
	(9017, 387, 0, 7, 1, 4, 3, 6, 398, NULL, 'Kumuliacinė Q galia pagal 4 tarifą, fiksuojama kas mėnesį', 3364, 4, NULL, NULL),
	(9018, 387, 0, 7, 1, 0, 3, 6, 398, NULL, 'Kumuliacinė Q galia, fiksuojama kas mėnesį', 3407, 4, NULL, NULL),
	(9019, 387, 1, 7, 1, 1, 3, 6, 398, NULL, 'Kumuliacinė Q+ galia pagal 1 tarifą, fiksuojama kas mėnesį', 3367, 4, NULL, NULL),
	(9020, 387, 1, 7, 1, 2, 3, 6, 398, NULL, 'Kumuliacinė Q+ galia pagal 2 tarifą, fiksuojama kas mėnesį', 3370, 4, NULL, NULL),
	(9021, 387, 1, 7, 1, 3, 3, 6, 398, NULL, 'Kumuliacinė Q+ galia pagal 3 tarifą, fiksuojama kas mėnesį', 3373, 4, NULL, NULL),
	(9022, 387, 1, 7, 1, 4, 3, 6, 398, NULL, 'Kumuliacinė Q+ galia pagal 4 tarifą, fiksuojama kas mėnesį', 3376, 4, NULL, NULL),
	(9023, 387, 1, 7, 1, 0, 3, 6, 398, NULL, 'Kumuliacinė Q+ galia, fiksuojama kas mėnesį', 3410, 4, NULL, NULL),
	(9024, 387, 2, 7, 1, 1, 3, 6, 398, NULL, 'Kumuliacinė Q- galia pagal 1 tarifą, fiksuojama kas mėnesį', 3379, 4, NULL, NULL),
	(9025, 387, 2, 7, 1, 2, 3, 6, 398, NULL, 'Kumuliacinė Q- galia pagal 2 tarifą, fiksuojama kas mėnesį', 3382, 4, NULL, NULL),
	(9026, 387, 2, 7, 1, 3, 3, 6, 398, NULL, 'Kumuliacinė Q- galia pagal 3 tarifą, fiksuojama kas mėnesį', 3385, 4, NULL, NULL),
	(9027, 387, 2, 7, 1, 4, 3, 6, 398, NULL, 'Kumuliacinė Q- galia pagal 4 tarifą, fiksuojama kas mėnesį', 3388, 4, NULL, NULL),
	(9028, 387, 2, 7, 1, 0, 3, 6, 398, NULL, 'Kumuliacinė Q- galia, fiksuojama kas mėnesį', 3413, 4, NULL, NULL),
	(9029, 387, 5, 7, 1, 1, 3, 6, 398, NULL, 'Kumuliacinė Q1 galia pagal 1 tarifą, fiksuojama kas mėnesį', 3390, 4, NULL, NULL),
	(9030, 387, 5, 7, 1, 2, 3, 6, 398, NULL, 'Kumuliacinė Q1 galia pagal 2 tarifą, fiksuojama kas mėnesį', 3394, 4, NULL, NULL),
	(9031, 387, 5, 7, 1, 3, 3, 6, 398, NULL, 'Kumuliacinė Q1 galia pagal 3 tarifą, fiksuojama kas mėnesį', 3398, 4, NULL, NULL),
	(9032, 387, 5, 7, 1, 4, 3, 6, 398, NULL, 'Kumuliacinė Q1 galia pagal 4 tarifą, fiksuojama kas mėnesį', 3402, 4, NULL, NULL),
	(9033, 387, 5, 7, 1, 0, 3, 6, 398, NULL, 'Kumuliacinė Q1 galia, fiksuojama kas mėnesį', 3415, 4, NULL, NULL),
	(9034, 387, 6, 7, 1, 1, 3, 6, 398, NULL, 'Kumuliacinė Q2 galia pagal 1 tarifą, fiksuojama kas mėnesį', 3391, 4, NULL, NULL),
	(9035, 387, 6, 7, 1, 2, 3, 6, 398, NULL, 'Kumuliacinė Q2 galia pagal 2 tarifą, fiksuojama kas mėnesį', 3395, 4, NULL, NULL),
	(9036, 387, 6, 7, 1, 3, 3, 6, 398, NULL, 'Kumuliacinė Q2 galia pagal 3 tarifą, fiksuojama kas mėnesį', 3399, 4, NULL, NULL),
	(9037, 387, 6, 7, 1, 4, 3, 6, 398, NULL, 'Kumuliacinė Q2 galia pagal 4 tarifą, fiksuojama kas mėnesį', 3403, 4, NULL, NULL),
	(9038, 387, 6, 7, 1, 0, 3, 6, 398, NULL, 'Kumuliacinė Q2 galia, fiksuojama kas mėnesį', 3416, 4, NULL, NULL),
	(9039, 387, 7, 7, 1, 1, 3, 6, 398, NULL, 'Kumuliacinė Q3 galia pagal 1 tarifą, fiksuojama kas mėnesį', 3392, 4, NULL, NULL),
	(9040, 387, 7, 7, 1, 2, 3, 6, 398, NULL, 'Kumuliacinė Q3 galia pagal 2 tarifą, fiksuojama kas mėnesį', 3396, 4, NULL, NULL),
	(9041, 387, 7, 7, 1, 3, 3, 6, 398, NULL, 'Kumuliacinė Q3 galia pagal 3 tarifą, fiksuojama kas mėnesį', 3400, 4, NULL, NULL),
	(9042, 387, 7, 7, 1, 4, 3, 6, 398, NULL, 'Kumuliacinė Q3 galia pagal 4 tarifą, fiksuojama kas mėnesį', 3404, 4, NULL, NULL),
	(9043, 387, 7, 7, 1, 0, 3, 6, 398, NULL, 'Kumuliacinė Q3 galia, fiksuojama kas mėnesį', 3417, 4, NULL, NULL),
	(9044, 387, 8, 7, 1, 1, 3, 6, 398, NULL, 'Kumuliacinė Q4 galia pagal 1 tarifą, fiksuojama kas mėnesį', 3393, 4, NULL, NULL),
	(9045, 387, 8, 7, 1, 2, 3, 6, 398, NULL, 'Kumuliacinė Q4 galia pagal 2 tarifą, fiksuojama kas mėnesį', 3397, 4, NULL, NULL),
	(9046, 387, 8, 7, 1, 3, 3, 6, 398, NULL, 'Kumuliacinė Q4 galia pagal 3 tarifą, fiksuojama kas mėnesį', 3401, 4, NULL, NULL),
	(9047, 387, 8, 7, 1, 4, 3, 6, 398, NULL, 'Kumuliacinė Q4 galia pagal 4 tarifą, fiksuojama kas mėnesį', 3405, 4, NULL, NULL),
	(9048, 387, 8, 7, 1, 0, 3, 6, 398, NULL, 'Kumuliacinė Q4 galia, fiksuojama kas mėnesį', 3418, 4, NULL, NULL),
	(9049, 187, 0, 7, 1, 0, 0, 6, 200, NULL, 'Momentinis rodiklis Nr.1, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9050, 344, 0, 7, 1, 0, 0, 6, 356, NULL, 'Momentinis rodiklis Nr.2, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9051, 345, 0, 7, 1, 0, 0, 6, 357, NULL, 'Momentinis rodiklis Nr.3, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9052, 346, 0, 7, 1, 0, 0, 6, 358, NULL, 'Momentinis rodiklis Nr.4, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9053, 347, 0, 7, 1, 0, 0, 6, 359, NULL, 'Momentinis rodiklis Nr.5, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9054, 348, 0, 7, 1, 0, 0, 6, 360, NULL, 'Momentinis rodiklis Nr.6, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9055, 349, 0, 7, 1, 0, 0, 6, 361, NULL, 'Momentinis rodiklis Nr.7, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9056, 350, 0, 7, 1, 0, 0, 6, 362, NULL, 'Momentinis rodiklis Nr.8, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9057, 351, 0, 7, 1, 0, 0, 6, 363, NULL, 'Momentinis rodiklis Nr.9, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9058, 352, 0, 7, 1, 0, 0, 6, 364, NULL, 'Momentinis rodiklis Nr.10, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9059, 365, 0, 7, 1, 0, 0, 6, 377, NULL, 'Momentinis rodiklis Nr.11, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9060, 366, 0, 7, 1, 0, 0, 6, 378, NULL, 'Momentinis rodiklis Nr.12, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9061, 367, 0, 7, 1, 0, 0, 6, 379, NULL, 'Momentinis rodiklis Nr.13, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9062, 368, 0, 7, 1, 0, 0, 6, 380, NULL, 'Momentinis rodiklis Nr.14, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9063, 369, 0, 7, 1, 0, 0, 6, 381, NULL, 'Momentinis rodiklis Nr.15, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9064, 370, 0, 7, 1, 0, 0, 6, 382, NULL, 'Momentinis rodiklis Nr.16, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9065, 371, 0, 7, 1, 0, 0, 6, 383, NULL, 'Momentinis rodiklis Nr.17, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9066, 372, 0, 7, 1, 0, 0, 6, 384, NULL, 'Momentinis rodiklis Nr.18, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9067, 373, 0, 7, 1, 0, 0, 6, 385, NULL, 'Momentinis rodiklis Nr.19, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9068, 374, 0, 7, 1, 0, 0, 6, 386, NULL, 'Momentinis rodiklis Nr.20, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9069, 375, 0, 7, 1, 0, 0, 6, 387, NULL, 'Momentinis rodiklis Nr.21, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9070, 376, 0, 7, 1, 0, 0, 6, 388, NULL, 'Momentinis rodiklis Nr.22, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9071, 377, 0, 7, 1, 0, 0, 6, 389, NULL, 'Momentinis rodiklis Nr.23, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9072, 378, 0, 7, 1, 0, 0, 6, 390, NULL, 'Momentinis rodiklis Nr.24, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9073, 379, 0, 7, 1, 0, 0, 6, 391, NULL, 'Momentinis rodiklis Nr.25, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9074, 380, 0, 7, 1, 0, 0, 6, 392, NULL, 'Momentinis rodiklis Nr.26, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9075, 381, 0, 7, 1, 0, 0, 6, 393, NULL, 'Momentinis rodiklis Nr.27, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9076, 382, 0, 7, 1, 0, 0, 6, 394, NULL, 'Momentinis rodiklis Nr.28, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9077, 383, 0, 7, 1, 0, 0, 6, 395, NULL, 'Momentinis rodiklis Nr.29, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9078, 384, 0, 7, 1, 0, 0, 6, 455, NULL, 'Momentinis rodiklis Nr.30, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(9079, 1, 1, 11, 4, 0, 1, 6, 13, NULL, 'Maksimali 5 minučių P+ galia per mėnesį', 374, 4, NULL, NULL),
	(9080, 1, 2, 11, 4, 0, 1, 6, 13, NULL, 'Maksimali 5 minučių P- galia per mėnesį', 375, 4, NULL, NULL),
	(9081, 3, 1, 11, 4, 0, 3, 6, 16, NULL, 'Maksimali 5 minučių Q+ galia per mėnesį', 376, 4, NULL, NULL),
	(9082, 3, 2, 11, 4, 0, 3, 6, 16, NULL, 'Maksimali 5 minučių Q- galia per mėnesį', 377, 4, NULL, NULL),
	(9083, 308, 0, 6, 2, 0, 29, 6, 321, NULL, 'Prietaiso darbo laikas per mėnesį', 4000, 4, NULL, NULL),
	(9084, 308, 0, 5, 2, 0, 29, 5, 321, NULL, 'Prietaiso darbo laikas per parą', 4000, 3, NULL, NULL),
	(9085, 308, 0, 4, 2, 0, 29, 4, 321, NULL, 'Prietaiso darbo laikas per valandą', 4000, 2, NULL, NULL),
	(9086, 37, 0, 1, 3, 0, 8, 1, 48, NULL, 'Vidutinis dažnis per minutę', 812, 1, NULL, NULL),
	(9087, 37, 0, 11, 3, 0, 8, 10, 48, NULL, 'Vidutinis dažnis per 5 minutes', 812, 1, NULL, NULL),
	(9088, 37, 0, 9, 3, 0, 8, 8, 48, NULL, 'Vidutinis dažnis per 3 minutes', 812, 1, NULL, NULL),
	(9089, 37, 0, 2, 3, 0, 8, 2, 48, NULL, 'Vidutinis dažnis per 2 minutes', 812, 1, NULL, NULL),
	(9090, 348, 0, 8, 2, 0, 0, 10, 360, NULL, 'Suminis rodiklis Nr.6, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(9091, 348, 0, 8, 2, 0, 0, 3, 360, NULL, 'Suminis rodiklis Nr.6, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(9092, 348, 0, 8, 2, 0, 0, 13, 360, NULL, 'Suminis rodiklis Nr.6, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(9093, 348, 0, 8, 2, 0, 0, 12, 360, NULL, 'Suminis rodiklis Nr.6, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(9094, 348, 0, 8, 2, 0, 0, 4, 360, NULL, 'Suminis rodiklis Nr.6, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(9095, 348, 0, 8, 2, 0, 0, 5, 360, NULL, 'Suminis rodiklis Nr.6, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(9096, 348, 0, 8, 2, 0, 0, 6, 360, NULL, 'Suminis rodiklis Nr.6, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(9097, 348, 0, 8, 2, 0, 0, 7, 360, NULL, 'Suminis rodiklis Nr.6', NULL, 5, NULL, NULL),
	(9098, 388, 0, 7, 1, 0, 0, 7, 399, NULL, 'Reaktyvios galios koeficientas', 3919, 6, NULL, NULL),
	(9099, 389, 0, 7, 1, 0, 0, 7, 400, NULL, 'Reaktyvios galios koeficientas L1 fazėje', 3920, 6, NULL, NULL),
	(9100, 390, 0, 7, 1, 0, 0, 7, 401, NULL, 'Reaktyvios galios koeficientas L2 fazėje', 3921, 6, NULL, NULL),
	(9101, 391, 0, 7, 1, 0, 0, 7, 402, NULL, 'Reaktyvios galios koeficientas L3 fazėje', 3922, 6, NULL, NULL),
	(9102, 392, 0, 7, 1, 0, 0, 7, 403, NULL, 'Aktyvios galios koeficientas', 3923, 6, NULL, NULL),
	(9103, 393, 0, 7, 1, 0, 0, 7, 404, NULL, 'Aktyvios galios koeficientas L1 fazėje', 3924, 6, NULL, NULL),
	(9104, 394, 0, 7, 1, 0, 0, 7, 405, NULL, 'Aktyvios galios koeficientas L2 fazėje', 3925, 6, NULL, NULL),
	(9105, 395, 0, 7, 1, 0, 0, 7, 406, NULL, 'Aktyvios galios koeficientas L3 fazėje', 3926, 6, NULL, NULL),
	(9106, 396, 0, 7, 1, 0, 1, 7, 407, NULL, 'Aktyvinių nuostolių galia', 3927, 6, NULL, NULL),
	(9107, 397, 0, 7, 1, 0, 1, 7, 408, NULL, 'Aktyvinių nuostolių galia L1 fazėje', 3928, 6, NULL, NULL),
	(9108, 398, 0, 7, 1, 0, 1, 7, 409, NULL, 'Aktyvinių nuostolių galia L2 fazėje', 3929, 6, NULL, NULL),
	(9109, 399, 0, 7, 1, 0, 1, 7, 410, NULL, 'Aktyvinių nuostolių galia L3 fazėje', 3930, 6, NULL, NULL),
	(9110, 400, 0, 7, 1, 0, 0, 7, 411, NULL, 'Galios koeficientas (tg)', 3931, 6, NULL, NULL),
	(9111, 401, 0, 7, 1, 0, 0, 7, 412, NULL, 'Galios koeficientas (tg) L1 fazėje', 3932, 6, NULL, NULL),
	(9112, 402, 0, 7, 1, 0, 0, 7, 413, NULL, 'Galios koeficientas (tg) L2 fazėje', 3933, 6, NULL, NULL),
	(9113, 403, 0, 7, 1, 0, 0, 7, 414, NULL, 'Galios koeficientas (tg) L3 fazėje', 3934, 6, NULL, NULL),
	(9114, 1, 1, 3, 4, 5, 1, 5, 13, NULL, 'Maksimali pusvalandinė P+ galia pagal 5 tarifą per parą', 3935, 3, NULL, NULL),
	(9115, 1, 1, 4, 4, 5, 1, 5, 13, NULL, 'Maksimali valandinė P+ galia pagal 5 tarifą per parą', 3935, 3, NULL, NULL),
	(9116, 1, 1, 9, 4, 5, 1, 5, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 5 tarifą per parą', 3935, 3, NULL, NULL),
	(9117, 1, 1, 11, 4, 5, 1, 5, 13, NULL, 'Maksimali 5 minučių P+ galia pagal 5 tarifą per parą', 3935, 3, NULL, NULL),
	(9118, 1, 1, 13, 4, 5, 1, 5, 13, NULL, 'Maksimali 15 minučių P+ galia pagal 5 tarifą per parą', 3935, 3, NULL, NULL),
	(9119, 1, 1, 3, 4, 6, 1, 5, 13, NULL, 'Maksimali pusvalandinė P+ galia pagal 6 tarifą per parą', 3936, 3, NULL, NULL),
	(9120, 1, 1, 4, 4, 6, 1, 5, 13, NULL, 'Maksimali valandinė P+ galia pagal 6 tarifą per parą', 3936, 3, NULL, NULL),
	(9121, 1, 1, 9, 4, 6, 1, 5, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 6 tarifą per parą', 3936, 3, NULL, NULL),
	(9122, 1, 1, 11, 4, 6, 1, 5, 13, NULL, 'Maksimali 5 minučių P+ galia pagal 6 tarifą per parą', 3936, 3, NULL, NULL),
	(9123, 1, 1, 13, 4, 6, 1, 5, 13, NULL, 'Maksimali 15 minučių P+ galia pagal 6 tarifą per parą', 3936, 3, NULL, NULL),
	(9124, 1, 1, 3, 4, 7, 1, 5, 13, NULL, 'Maksimali pusvalandinė P+ galia pagal 7 tarifą per parą', 3937, 3, NULL, NULL),
	(9125, 1, 1, 4, 4, 7, 1, 5, 13, NULL, 'Maksimali valandinė P+ galia pagal 7 tarifą per parą', 3937, 3, NULL, NULL),
	(9126, 1, 1, 9, 4, 7, 1, 5, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 7 tarifą per parą', 3937, 3, NULL, NULL),
	(9127, 1, 1, 11, 4, 7, 1, 5, 13, NULL, 'Maksimali 5 minučių P+ galia pagal 7 tarifą per parą', 3937, 3, NULL, NULL),
	(9128, 1, 1, 13, 4, 7, 1, 5, 13, NULL, 'Maksimali 15 minučių P+ galia pagal 7 tarifą per parą', 3937, 3, NULL, NULL),
	(9129, 1, 1, 3, 4, 8, 1, 5, 13, NULL, 'Maksimali pusvalandinė P+ galia pagal 8 tarifą per parą', 3938, 3, NULL, NULL),
	(9130, 1, 1, 4, 4, 8, 1, 5, 13, NULL, 'Maksimali valandinė P+ galia pagal 8 tarifą per parą', 3938, 3, NULL, NULL),
	(9131, 1, 1, 9, 4, 8, 1, 5, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 8 tarifą per parą', 3938, 3, NULL, NULL),
	(9132, 1, 1, 11, 4, 8, 1, 5, 13, NULL, 'Maksimali 5 minučių P+ galia pagal 8 tarifą per parą', 3938, 3, NULL, NULL),
	(9133, 1, 1, 13, 4, 8, 1, 5, 13, NULL, 'Maksimali 15 minučių P+ galia pagal 8 tarifą per parą', 3938, 3, NULL, NULL),
	(9134, 1, 2, 3, 4, 5, 1, 5, 13, NULL, 'Maksimali pusvalandinė P- galia pagal 5 tarifą per parą', 3939, 3, NULL, NULL),
	(9135, 1, 2, 4, 4, 5, 1, 5, 13, NULL, 'Maksimali valandinė P- galia pagal 5 tarifą per parą', 3939, 3, NULL, NULL),
	(9136, 1, 2, 9, 4, 5, 1, 5, 13, NULL, 'Maksimali 3 minučių P- galia pagal 5 tarifą per parą', 3939, 3, NULL, NULL),
	(9137, 1, 2, 11, 4, 5, 1, 5, 13, NULL, 'Maksimali 5 minučių P- galia pagal 5 tarifą per parą', 3939, 3, NULL, NULL),
	(9138, 1, 2, 13, 4, 5, 1, 5, 13, NULL, 'Maksimali 15 minučių P- galia pagal 5 tarifą per parą', 3939, 3, NULL, NULL),
	(9139, 1, 2, 3, 4, 6, 1, 5, 13, NULL, 'Maksimali pusvalandinė P- galia pagal 6 tarifą per parą', 3940, 3, NULL, NULL),
	(9140, 1, 2, 4, 4, 6, 1, 5, 13, NULL, 'Maksimali valandinė P- galia pagal 6 tarifą per parą', 3940, 3, NULL, NULL),
	(9141, 1, 2, 9, 4, 6, 1, 5, 13, NULL, 'Maksimali 3 minučių P- galia pagal 6 tarifą per parą', 3940, 3, NULL, NULL),
	(9142, 1, 2, 11, 4, 6, 1, 5, 13, NULL, 'Maksimali 5 minučių P- galia pagal 6 tarifą per parą', 3940, 3, NULL, NULL),
	(9143, 1, 2, 13, 4, 6, 1, 5, 13, NULL, 'Maksimali 15 minučių P- galia pagal 6 tarifą per parą', 3940, 3, NULL, NULL),
	(9144, 1, 2, 3, 4, 7, 1, 5, 13, NULL, 'Maksimali pusvalandinė P- galia pagal 7 tarifą per parą', 3941, 3, NULL, NULL),
	(9145, 1, 2, 4, 4, 7, 1, 5, 13, NULL, 'Maksimali valandinė P- galia pagal 7 tarifą per parą', 3941, 3, NULL, NULL),
	(9146, 1, 2, 9, 4, 7, 1, 5, 13, NULL, 'Maksimali 3 minučių P- galia pagal 7 tarifą per parą', 3941, 3, NULL, NULL),
	(9147, 1, 2, 11, 4, 7, 1, 5, 13, NULL, 'Maksimali 5 minučių P- galia pagal 7 tarifą per parą', 3941, 3, NULL, NULL),
	(9148, 1, 2, 13, 4, 7, 1, 5, 13, NULL, 'Maksimali 15 minučių P- galia pagal 7 tarifą per parą', 3941, 3, NULL, NULL),
	(9149, 1, 2, 3, 4, 8, 1, 5, 13, NULL, 'Maksimali pusvalandinė P- galia pagal 8 tarifą per parą', 3942, 3, NULL, NULL),
	(9150, 1, 2, 4, 4, 8, 1, 5, 13, NULL, 'Maksimali valandinė P- galia pagal 8 tarifą per parą', 3942, 3, NULL, NULL),
	(9151, 1, 2, 9, 4, 8, 1, 5, 13, NULL, 'Maksimali 3 minučių P- galia pagal 8 tarifą per parą', 3942, 3, NULL, NULL),
	(9152, 1, 2, 11, 4, 8, 1, 5, 13, NULL, 'Maksimali 5 minučių P- galia pagal 8 tarifą per parą', 3942, 3, NULL, NULL),
	(9153, 1, 2, 13, 4, 8, 1, 5, 13, NULL, 'Maksimali 15 minučių P- galia pagal 8 tarifą per parą', 3942, 3, NULL, NULL),
	(9154, 3, 1, 3, 4, 5, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q+ galia pagal 5 tarifą per parą', 3943, 3, NULL, NULL),
	(9155, 3, 1, 4, 4, 5, 3, 5, 16, NULL, 'Maksimali valandinė Q+ galia pagal 5 tarifą per parą', 3943, 3, NULL, NULL),
	(9156, 3, 1, 9, 4, 5, 3, 5, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 5 tarifą per parą', 3943, 3, NULL, NULL),
	(9157, 3, 1, 11, 4, 5, 3, 5, 16, NULL, 'Maksimali 5 minučių Q+ galia pagal 5 tarifą per parą', 3943, 3, NULL, NULL),
	(9158, 3, 1, 13, 4, 5, 3, 5, 16, NULL, 'Maksimali 15 minučių Q+ galia pagal 5 tarifą per parą', 3943, 3, NULL, NULL),
	(9159, 3, 1, 3, 4, 6, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q+ galia pagal 6 tarifą per parą', 3944, 3, NULL, NULL),
	(9160, 3, 1, 4, 4, 6, 3, 5, 16, NULL, 'Maksimali valandinė Q+ galia pagal 6 tarifą per parą', 3944, 3, NULL, NULL),
	(9161, 3, 1, 9, 4, 6, 3, 5, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 6 tarifą per parą', 3944, 3, NULL, NULL),
	(9162, 3, 1, 11, 4, 6, 3, 5, 16, NULL, 'Maksimali 5 minučių Q+ galia pagal 6 tarifą per parą', 3944, 3, NULL, NULL),
	(9163, 3, 1, 13, 4, 6, 3, 5, 16, NULL, 'Maksimali 15 minučių Q+ galia pagal 6 tarifą per parą', 3944, 3, NULL, NULL),
	(9164, 3, 1, 3, 4, 7, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q+ galia pagal 7 tarifą per parą', 3945, 3, NULL, NULL),
	(9165, 3, 1, 4, 4, 7, 3, 5, 16, NULL, 'Maksimali valandinė Q+ galia pagal 7 tarifą per parą', 3945, 3, NULL, NULL),
	(9166, 3, 1, 9, 4, 7, 3, 5, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 7 tarifą per parą', 3945, 3, NULL, NULL),
	(9167, 3, 1, 11, 4, 7, 3, 5, 16, NULL, 'Maksimali 5 minučių Q+ galia pagal 7 tarifą per parą', 3945, 3, NULL, NULL),
	(9168, 3, 1, 13, 4, 7, 3, 5, 16, NULL, 'Maksimali 15 minučių Q+ galia pagal 7 tarifą per parą', 3945, 3, NULL, NULL),
	(9169, 3, 1, 3, 4, 8, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q+ galia pagal 8 tarifą per parą', 3946, 3, NULL, NULL),
	(9170, 3, 1, 4, 4, 8, 3, 5, 16, NULL, 'Maksimali valandinė Q+ galia pagal 8 tarifą per parą', 3946, 3, NULL, NULL),
	(9171, 3, 1, 9, 4, 8, 3, 5, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 8 tarifą per parą', 3946, 3, NULL, NULL),
	(9172, 3, 1, 11, 4, 8, 3, 5, 16, NULL, 'Maksimali 5 minučių Q+ galia pagal 8 tarifą per parą', 3946, 3, NULL, NULL),
	(9173, 3, 1, 13, 4, 8, 3, 5, 16, NULL, 'Maksimali 15 minučių Q+ galia pagal 8 tarifą per parą', 3946, 3, NULL, NULL),
	(9174, 3, 2, 3, 4, 5, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q- galia pagal 5 tarifą per parą', 3947, 3, NULL, NULL),
	(9175, 3, 2, 4, 4, 5, 3, 5, 16, NULL, 'Maksimali valandinė Q- galia pagal 5 tarifą per parą', 3947, 3, NULL, NULL),
	(9176, 3, 2, 9, 4, 5, 3, 5, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 5 tarifą per parą', 3947, 3, NULL, NULL),
	(9177, 3, 2, 11, 4, 5, 3, 5, 16, NULL, 'Maksimali 5 minučių Q- galia pagal 5 tarifą per parą', 3947, 3, NULL, NULL),
	(9178, 3, 2, 13, 4, 5, 3, 5, 16, NULL, 'Maksimali 15 minučių Q- galia pagal 5 tarifą per parą', 3947, 3, NULL, NULL),
	(9179, 3, 2, 3, 4, 6, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q- galia pagal 6 tarifą per parą', 3948, 3, NULL, NULL),
	(9180, 3, 2, 4, 4, 6, 3, 5, 16, NULL, 'Maksimali valandinė Q- galia pagal 6 tarifą per parą', 3948, 3, NULL, NULL),
	(9181, 3, 2, 9, 4, 6, 3, 5, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 6 tarifą per parą', 3948, 3, NULL, NULL),
	(9182, 3, 2, 11, 4, 6, 3, 5, 16, NULL, 'Maksimali 5 minučių Q- galia pagal 6 tarifą per parą', 3948, 3, NULL, NULL),
	(9183, 3, 2, 13, 4, 6, 3, 5, 16, NULL, 'Maksimali 15 minučių Q- galia pagal 6 tarifą per parą', 3948, 3, NULL, NULL),
	(9184, 3, 2, 3, 4, 7, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q- galia pagal 7 tarifą per parą', 3949, 3, NULL, NULL),
	(9185, 3, 2, 4, 4, 7, 3, 5, 16, NULL, 'Maksimali valandinė Q- galia pagal 7 tarifą per parą', 3949, 3, NULL, NULL),
	(9186, 3, 2, 9, 4, 7, 3, 5, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 7 tarifą per parą', 3949, 3, NULL, NULL),
	(9187, 3, 2, 11, 4, 7, 3, 5, 16, NULL, 'Maksimali 5 minučių Q- galia pagal 7 tarifą per parą', 3949, 3, NULL, NULL),
	(9188, 3, 2, 13, 4, 7, 3, 5, 16, NULL, 'Maksimali 15 minučių Q- galia pagal 7 tarifą per parą', 3949, 3, NULL, NULL),
	(9189, 3, 2, 3, 4, 8, 3, 5, 16, NULL, 'Maksimali pusvalandinė Q- galia pagal 8 tarifą per parą', 3950, 3, NULL, NULL),
	(9190, 3, 2, 4, 4, 8, 3, 5, 16, NULL, 'Maksimali valandinė Q- galia pagal 8 tarifą per parą', 3950, 3, NULL, NULL),
	(9191, 3, 2, 9, 4, 8, 3, 5, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 8 tarifą per parą', 3950, 3, NULL, NULL),
	(9192, 3, 2, 11, 4, 8, 3, 5, 16, NULL, 'Maksimali 5 minučių Q- galia pagal 8 tarifą per parą', 3950, 3, NULL, NULL),
	(9193, 3, 2, 13, 4, 8, 3, 5, 16, NULL, 'Maksimali 15 minučių Q- galia pagal 8 tarifą per parą', 3950, 3, NULL, NULL),
	(9194, 34, 1, 3, 4, 5, 7, 5, 44, NULL, 'Maksimali pusvalandinė S+ galia pagal 5 tarifą per parą', 3951, 3, NULL, NULL),
	(9195, 34, 1, 4, 4, 5, 7, 5, 44, NULL, 'Maksimali valandinė S+ galia pagal 5 tarifą per parą', 3951, 3, NULL, NULL),
	(9196, 34, 1, 9, 4, 5, 7, 5, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 5 tarifą per parą', 3951, 3, NULL, NULL),
	(9197, 34, 1, 11, 4, 5, 7, 5, 44, NULL, 'Maksimali 5 minučių S+ galia pagal 5 tarifą per parą', 3951, 3, NULL, NULL),
	(9198, 34, 1, 13, 4, 5, 7, 5, 44, NULL, 'Maksimali 15 minučių S+ galia pagal 5 tarifą per parą', 3951, 3, NULL, NULL),
	(9199, 34, 1, 3, 4, 6, 7, 5, 44, NULL, 'Maksimali pusvalandinė S+ galia pagal 6 tarifą per parą', 3952, 3, NULL, NULL),
	(9200, 34, 1, 4, 4, 6, 7, 5, 44, NULL, 'Maksimali valandinė S+ galia pagal 6 tarifą per parą', 3952, 3, NULL, NULL),
	(9201, 34, 1, 9, 4, 6, 7, 5, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 6 tarifą per parą', 3952, 3, NULL, NULL),
	(9202, 34, 1, 11, 4, 6, 7, 5, 44, NULL, 'Maksimali 5 minučių S+ galia pagal 6 tarifą per parą', 3952, 3, NULL, NULL),
	(9203, 34, 1, 13, 4, 6, 7, 5, 44, NULL, 'Maksimali 15 minučių S+ galia pagal 6 tarifą per parą', 3952, 3, NULL, NULL),
	(9204, 34, 1, 3, 4, 7, 7, 5, 44, NULL, 'Maksimali pusvalandinė S+ galia pagal 7 tarifą per parą', 3953, 3, NULL, NULL),
	(9205, 34, 1, 4, 4, 7, 7, 5, 44, NULL, 'Maksimali valandinė S+ galia pagal 7 tarifą per parą', 3953, 3, NULL, NULL),
	(9206, 34, 1, 9, 4, 7, 7, 5, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 7 tarifą per parą', 3953, 3, NULL, NULL),
	(9207, 34, 1, 11, 4, 7, 7, 5, 44, NULL, 'Maksimali 5 minučių S+ galia pagal 7 tarifą per parą', 3953, 3, NULL, NULL),
	(9208, 34, 1, 13, 4, 7, 7, 5, 44, NULL, 'Maksimali 15 minučių S+ galia pagal 7 tarifą per parą', 3953, 3, NULL, NULL),
	(9209, 34, 1, 3, 4, 8, 7, 5, 44, NULL, 'Maksimali pusvalandinė S+ galia pagal 8 tarifą per parą', 3954, 3, NULL, NULL),
	(9210, 34, 1, 4, 4, 8, 7, 5, 44, NULL, 'Maksimali valandinė S+ galia pagal 8 tarifą per parą', 3954, 3, NULL, NULL),
	(9211, 34, 1, 9, 4, 8, 7, 5, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 8 tarifą per parą', 3954, 3, NULL, NULL),
	(9212, 34, 1, 11, 4, 8, 7, 5, 44, NULL, 'Maksimali 5 minučių S+ galia pagal 8 tarifą per parą', 3954, 3, NULL, NULL),
	(9213, 34, 1, 13, 4, 8, 7, 5, 44, NULL, 'Maksimali 15 minučių S+ galia pagal 8 tarifą per parą', 3954, 3, NULL, NULL),
	(9214, 34, 2, 3, 4, 5, 7, 5, 44, NULL, 'Maksimali pusvalandinė S- galia pagal 5 tarifą per parą', 3955, 3, NULL, NULL),
	(9215, 34, 2, 4, 4, 5, 7, 5, 44, NULL, 'Maksimali valandinė S- galia pagal 5 tarifą per parą', 3955, 3, NULL, NULL),
	(9216, 34, 2, 9, 4, 5, 7, 5, 44, NULL, 'Maksimali 3 minučių S- galia pagal 5 tarifą per parą', 3955, 3, NULL, NULL),
	(9217, 34, 2, 11, 4, 5, 7, 5, 44, NULL, 'Maksimali 5 minučių S- galia pagal 5 tarifą per parą', 3955, 3, NULL, NULL),
	(9218, 34, 2, 13, 4, 5, 7, 5, 44, NULL, 'Maksimali 15 minučių S- galia pagal 5 tarifą per parą', 3955, 3, NULL, NULL),
	(9219, 34, 2, 3, 4, 6, 7, 5, 44, NULL, 'Maksimali pusvalandinė S- galia pagal 6 tarifą per parą', 3956, 3, NULL, NULL),
	(9220, 34, 2, 4, 4, 6, 7, 5, 44, NULL, 'Maksimali valandinė S- galia pagal 6 tarifą per parą', 3956, 3, NULL, NULL),
	(9221, 34, 2, 9, 4, 6, 7, 5, 44, NULL, 'Maksimali 3 minučių S- galia pagal 6 tarifą per parą', 3956, 3, NULL, NULL),
	(9222, 34, 2, 11, 4, 6, 7, 5, 44, NULL, 'Maksimali 5 minučių S- galia pagal 6 tarifą per parą', 3956, 3, NULL, NULL),
	(9223, 34, 2, 13, 4, 6, 7, 5, 44, NULL, 'Maksimali 15 minučių S- galia pagal 6 tarifą per parą', 3956, 3, NULL, NULL),
	(9224, 34, 2, 3, 4, 7, 7, 5, 44, NULL, 'Maksimali pusvalandinė S- galia pagal 7 tarifą per parą', 3957, 3, NULL, NULL),
	(9225, 34, 2, 4, 4, 7, 7, 5, 44, NULL, 'Maksimali valandinė S- galia pagal 7 tarifą per parą', 3957, 3, NULL, NULL),
	(9226, 34, 2, 9, 4, 7, 7, 5, 44, NULL, 'Maksimali 3 minučių S- galia pagal 7 tarifą per parą', 3957, 3, NULL, NULL),
	(9227, 34, 2, 11, 4, 7, 7, 5, 44, NULL, 'Maksimali 5 minučių S- galia pagal 7 tarifą per parą', 3957, 3, NULL, NULL),
	(9228, 34, 2, 13, 4, 7, 7, 5, 44, NULL, 'Maksimali 15 minučių S- galia pagal 7 tarifą per parą', 3957, 3, NULL, NULL),
	(9229, 34, 2, 3, 4, 8, 7, 5, 44, NULL, 'Maksimali pusvalandinė S- galia pagal 8 tarifą per parą', 3958, 3, NULL, NULL),
	(9230, 34, 2, 4, 4, 8, 7, 5, 44, NULL, 'Maksimali valandinė S- galia pagal 8 tarifą per parą', 3958, 3, NULL, NULL),
	(9231, 34, 2, 9, 4, 8, 7, 5, 44, NULL, 'Maksimali 3 minučių S- galia pagal 8 tarifą per parą', 3958, 3, NULL, NULL),
	(9232, 34, 2, 11, 4, 8, 7, 5, 44, NULL, 'Maksimali 5 minučių S- galia pagal 8 tarifą per parą', 3958, 3, NULL, NULL),
	(9233, 34, 2, 13, 4, 8, 7, 5, 44, NULL, 'Maksimali 15 minučių S- galia pagal 8 tarifą per parą', 3958, 3, NULL, NULL),
	(9234, 1, 1, 3, 4, 5, 1, 6, 13, NULL, 'Maksimali pusvalandinė P+ galia pagal 5 tarifą per mėnesį', 3959, 4, NULL, NULL),
	(9235, 1, 1, 4, 4, 5, 1, 6, 13, NULL, 'Maksimali valandinė P+ galia pagal 5 tarifą per mėnesį', 3959, 4, NULL, NULL),
	(9236, 1, 1, 9, 4, 5, 1, 6, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 5 tarifą per mėnesį', 3959, 4, NULL, NULL),
	(9237, 1, 1, 11, 4, 5, 1, 6, 13, NULL, 'Maksimali 5 minučių P+ galia pagal 5 tarifą per mėnesį', 3959, 4, NULL, NULL),
	(9238, 1, 1, 13, 4, 5, 1, 6, 13, NULL, 'Maksimali 15 minučių P+ galia pagal 5 tarifą per mėnesį', 3959, 4, NULL, NULL),
	(9239, 1, 1, 3, 4, 6, 1, 6, 13, NULL, 'Maksimali pusvalandinė P+ galia pagal 6 tarifą per mėnesį', 3960, 4, NULL, NULL),
	(9240, 1, 1, 4, 4, 6, 1, 6, 13, NULL, 'Maksimali valandinė P+ galia pagal 6 tarifą per mėnesį', 3960, 4, NULL, NULL),
	(9241, 1, 1, 9, 4, 6, 1, 6, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 6 tarifą per mėnesį', 3960, 4, NULL, NULL),
	(9242, 1, 1, 11, 4, 6, 1, 6, 13, NULL, 'Maksimali 5 minučių P+ galia pagal 6 tarifą per mėnesį', 3960, 4, NULL, NULL),
	(9243, 1, 1, 13, 4, 6, 1, 6, 13, NULL, 'Maksimali 15 minučių P+ galia pagal 6 tarifą per mėnesį', 3960, 4, NULL, NULL),
	(9244, 1, 1, 3, 4, 7, 1, 6, 13, NULL, 'Maksimali pusvalandinė P+ galia pagal 7 tarifą per mėnesį', 3961, 4, NULL, NULL),
	(9245, 1, 1, 4, 4, 7, 1, 6, 13, NULL, 'Maksimali valandinė P+ galia pagal 7 tarifą per mėnesį', 3961, 4, NULL, NULL),
	(9246, 1, 1, 9, 4, 7, 1, 6, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 7 tarifą per mėnesį', 3961, 4, NULL, NULL),
	(9247, 1, 1, 11, 4, 7, 1, 6, 13, NULL, 'Maksimali 5 minučių P+ galia pagal 7 tarifą per mėnesį', 3961, 4, NULL, NULL),
	(9248, 1, 1, 13, 4, 7, 1, 6, 13, NULL, 'Maksimali 15 minučių P+ galia pagal 7 tarifą per mėnesį', 3961, 4, NULL, NULL),
	(9249, 1, 1, 3, 4, 8, 1, 6, 13, NULL, 'Maksimali pusvalandinė P+ galia pagal 8 tarifą per mėnesį', 3962, 4, NULL, NULL),
	(9250, 1, 1, 4, 4, 8, 1, 6, 13, NULL, 'Maksimali valandinė P+ galia pagal 8 tarifą per mėnesį', 3962, 4, NULL, NULL),
	(9251, 1, 1, 9, 4, 8, 1, 6, 13, NULL, 'Maksimali 3 minučių P+ galia pagal 8 tarifą per mėnesį', 3962, 4, NULL, NULL),
	(9252, 1, 1, 11, 4, 8, 1, 6, 13, NULL, 'Maksimali 5 minučių P+ galia pagal 8 tarifą per mėnesį', 3962, 4, NULL, NULL),
	(9253, 1, 2, 3, 4, 5, 1, 6, 13, NULL, 'Maksimali pusvalandinė P- galia pagal 5 tarifą per mėnesį', 3963, 4, NULL, NULL),
	(9254, 1, 2, 4, 4, 5, 1, 6, 13, NULL, 'Maksimali valandinė P- galia pagal 5 tarifą per mėnesį', 3963, 4, NULL, NULL),
	(9255, 1, 2, 9, 4, 5, 1, 6, 13, NULL, 'Maksimali 3 minučių P- galia pagal 5 tarifą per mėnesį', 3963, 4, NULL, NULL),
	(9256, 1, 2, 11, 4, 5, 1, 6, 13, NULL, 'Maksimali 5 minučių P- galia pagal 5 tarifą per mėnesį', 3963, 4, NULL, NULL),
	(9257, 1, 2, 13, 4, 5, 1, 6, 13, NULL, 'Maksimali 15 minučių P- galia pagal 5 tarifą per mėnesį', 3963, 4, NULL, NULL),
	(9258, 1, 2, 3, 4, 6, 1, 6, 13, NULL, 'Maksimali pusvalandinė P- galia pagal 6 tarifą per mėnesį', 3964, 4, NULL, NULL),
	(9259, 1, 2, 4, 4, 6, 1, 6, 13, NULL, 'Maksimali valandinė P- galia pagal 6 tarifą per mėnesį', 3964, 4, NULL, NULL),
	(9260, 1, 2, 9, 4, 6, 1, 6, 13, NULL, 'Maksimali 3 minučių P- galia pagal 6 tarifą per mėnesį', 3964, 4, NULL, NULL),
	(9261, 1, 2, 11, 4, 6, 1, 6, 13, NULL, 'Maksimali 5 minučių P- galia pagal 6 tarifą per mėnesį', 3964, 4, NULL, NULL),
	(9262, 1, 2, 13, 4, 6, 1, 6, 13, NULL, 'Maksimali 15 minučių P- galia pagal 6 tarifą per mėnesį', 3964, 4, NULL, NULL),
	(9263, 1, 2, 3, 4, 7, 1, 6, 13, NULL, 'Maksimali pusvalandinė P- galia pagal 7 tarifą per mėnesį', 3965, 4, NULL, NULL),
	(9264, 1, 2, 4, 4, 7, 1, 6, 13, NULL, 'Maksimali valandinė P- galia pagal 7 tarifą per mėnesį', 3965, 4, NULL, NULL),
	(9265, 1, 2, 9, 4, 7, 1, 6, 13, NULL, 'Maksimali 3 minučių P- galia pagal 7 tarifą per mėnesį', 3965, 4, NULL, NULL),
	(9266, 1, 2, 11, 4, 7, 1, 6, 13, NULL, 'Maksimali 5 minučių P- galia pagal 7 tarifą per mėnesį', 3965, 4, NULL, NULL),
	(9267, 1, 2, 13, 4, 7, 1, 6, 13, NULL, 'Maksimali 15 minučių P- galia pagal 7 tarifą per mėnesį', 3965, 4, NULL, NULL),
	(9268, 1, 2, 3, 4, 8, 1, 6, 13, NULL, 'Maksimali pusvalandinė P- galia pagal 8 tarifą per mėnesį', 3966, 4, NULL, NULL),
	(9269, 1, 2, 4, 4, 8, 1, 6, 13, NULL, 'Maksimali valandinė P- galia pagal 8 tarifą per mėnesį', 3966, 4, NULL, NULL),
	(9270, 1, 2, 9, 4, 8, 1, 6, 13, NULL, 'Maksimali 3 minučių P- galia pagal 8 tarifą per mėnesį', 3966, 4, NULL, NULL),
	(9271, 1, 2, 11, 4, 8, 1, 6, 13, NULL, 'Maksimali 5 minučių P- galia pagal 8 tarifą per mėnesį', 3966, 4, NULL, NULL),
	(9272, 1, 2, 13, 4, 8, 1, 6, 13, NULL, 'Maksimali 15 minučių P- galia pagal 8 tarifą per mėnesį', 3966, 4, NULL, NULL),
	(9273, 3, 1, 3, 4, 5, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q+ galia pagal 5 tarifą per mėnesį', 3967, 4, NULL, NULL),
	(9274, 3, 1, 4, 4, 5, 3, 6, 16, NULL, 'Maksimali valandinė Q+ galia pagal 5 tarifą per mėnesį', 3967, 4, NULL, NULL),
	(9275, 3, 1, 9, 4, 5, 3, 6, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 5 tarifą per mėnesį', 3967, 4, NULL, NULL),
	(9276, 3, 1, 11, 4, 5, 3, 6, 16, NULL, 'Maksimali 5 minučių Q+ galia pagal 5 tarifą per mėnesį', 3967, 4, NULL, NULL),
	(9277, 3, 1, 13, 4, 5, 3, 6, 16, NULL, 'Maksimali 15 minučių Q+ galia pagal 5 tarifą per mėnesį', 3967, 4, NULL, NULL),
	(9278, 3, 1, 3, 4, 6, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q+ galia pagal 6 tarifą per mėnesį', 3968, 4, NULL, NULL),
	(9279, 3, 1, 4, 4, 6, 3, 6, 16, NULL, 'Maksimali valandinė Q+ galia pagal 6 tarifą per mėnesį', 3968, 4, NULL, NULL),
	(9280, 3, 1, 9, 4, 6, 3, 6, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 6 tarifą per mėnesį', 3968, 4, NULL, NULL),
	(9281, 3, 1, 11, 4, 6, 3, 6, 16, NULL, 'Maksimali 5 minučių Q+ galia pagal 6 tarifą per mėnesį', 3968, 4, NULL, NULL),
	(9282, 3, 1, 13, 4, 6, 3, 6, 16, NULL, 'Maksimali 15 minučių Q+ galia pagal 6 tarifą per mėnesį', 3968, 4, NULL, NULL),
	(9283, 3, 1, 3, 4, 7, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q+ galia pagal 7 tarifą per mėnesį', 3969, 4, NULL, NULL),
	(9284, 3, 1, 4, 4, 7, 3, 6, 16, NULL, 'Maksimali valandinė Q+ galia pagal 7 tarifą per mėnesį', 3969, 4, NULL, NULL),
	(9285, 3, 1, 9, 4, 7, 3, 6, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 7 tarifą per mėnesį', 3969, 4, NULL, NULL),
	(9286, 3, 1, 11, 4, 7, 3, 6, 16, NULL, 'Maksimali 5 minučių Q+ galia pagal 7 tarifą per mėnesį', 3969, 4, NULL, NULL),
	(9287, 3, 1, 13, 4, 7, 3, 6, 16, NULL, 'Maksimali 15 minučių Q+ galia pagal 7 tarifą per mėnesį', 3969, 4, NULL, NULL),
	(9288, 3, 1, 3, 4, 8, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q+ galia pagal 8 tarifą per mėnesį', 3970, 4, NULL, NULL),
	(9289, 3, 1, 4, 4, 8, 3, 6, 16, NULL, 'Maksimali valandinė Q+ galia pagal 8 tarifą per mėnesį', 3970, 4, NULL, NULL),
	(9290, 3, 1, 9, 4, 8, 3, 6, 16, NULL, 'Maksimali 3 minučių Q+ galia pagal 8 tarifą per mėnesį', 3970, 4, NULL, NULL),
	(9291, 3, 1, 11, 4, 8, 3, 6, 16, NULL, 'Maksimali 5 minučių Q+ galia pagal 8 tarifą per mėnesį', 3970, 4, NULL, NULL),
	(9292, 3, 1, 13, 4, 8, 3, 6, 16, NULL, 'Maksimali 15 minučių Q+ galia pagal 8 tarifą per mėnesį', 3970, 4, NULL, NULL),
	(9293, 3, 2, 3, 4, 5, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q- galia pagal 5 tarifą per mėnesį', 3971, 4, NULL, NULL),
	(9294, 3, 2, 4, 4, 5, 3, 6, 16, NULL, 'Maksimali valandinė Q- galia pagal 5 tarifą per mėnesį', 3971, 4, NULL, NULL),
	(9295, 3, 2, 9, 4, 5, 3, 6, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 5 tarifą per mėnesį', 3971, 4, NULL, NULL),
	(9296, 3, 2, 11, 4, 5, 3, 6, 16, NULL, 'Maksimali 5 minučių Q- galia pagal 5 tarifą per mėnesį', 3971, 4, NULL, NULL),
	(9297, 3, 2, 13, 4, 5, 3, 6, 16, NULL, 'Maksimali 15 minučių Q- galia pagal 5 tarifą per mėnesį', 3971, 4, NULL, NULL),
	(9298, 3, 2, 3, 4, 6, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q- galia pagal 6 tarifą per mėnesį', 3972, 4, NULL, NULL),
	(9299, 3, 2, 4, 4, 6, 3, 6, 16, NULL, 'Maksimali valandinė Q- galia pagal 6 tarifą per mėnesį', 3972, 4, NULL, NULL),
	(9300, 3, 2, 9, 4, 6, 3, 6, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 6 tarifą per mėnesį', 3972, 4, NULL, NULL),
	(9301, 3, 2, 11, 4, 6, 3, 6, 16, NULL, 'Maksimali 5 minučių Q- galia pagal 6 tarifą per mėnesį', 3972, 4, NULL, NULL),
	(9302, 3, 2, 13, 4, 6, 3, 6, 16, NULL, 'Maksimali 15 minučių Q- galia pagal 6 tarifą per mėnesį', 3972, 4, NULL, NULL),
	(9303, 3, 2, 3, 4, 7, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q- galia pagal 7 tarifą per mėnesį', 3973, 4, NULL, NULL),
	(9304, 3, 2, 4, 4, 7, 3, 6, 16, NULL, 'Maksimali valandinė Q- galia pagal 7 tarifą per mėnesį', 3973, 4, NULL, NULL),
	(9305, 3, 2, 9, 4, 7, 3, 6, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 7 tarifą per mėnesį', 3973, 4, NULL, NULL),
	(9306, 3, 2, 11, 4, 7, 3, 6, 16, NULL, 'Maksimali 5 minučių Q- galia pagal 7 tarifą per mėnesį', 3973, 4, NULL, NULL),
	(9307, 3, 2, 13, 4, 7, 3, 6, 16, NULL, 'Maksimali 15 minučių Q- galia pagal 7 tarifą per mėnesį', 3973, 4, NULL, NULL),
	(9308, 3, 2, 3, 4, 8, 3, 6, 16, NULL, 'Maksimali pusvalandinė Q- galia pagal 8 tarifą per mėnesį', 3974, 4, NULL, NULL),
	(9309, 3, 2, 4, 4, 8, 3, 6, 16, NULL, 'Maksimali valandinė Q- galia pagal 8 tarifą per mėnesį', 3974, 4, NULL, NULL),
	(9310, 3, 2, 9, 4, 8, 3, 6, 16, NULL, 'Maksimali 3 minučių Q- galia pagal 8 tarifą per mėnesį', 3974, 4, NULL, NULL),
	(9311, 3, 2, 11, 4, 8, 3, 6, 16, NULL, 'Maksimali 5 minučių Q- galia pagal 8 tarifą per mėnesį', 3974, 4, NULL, NULL),
	(9312, 3, 2, 13, 4, 8, 3, 6, 16, NULL, 'Maksimali 15 minučių Q- galia pagal 8 tarifą per mėnesį', 3974, 4, NULL, NULL),
	(9313, 34, 1, 3, 4, 5, 7, 6, 44, NULL, 'Maksimali pusvalandinė S+ galia pagal 5 tarifą per mėnesį', 3975, 4, NULL, NULL),
	(9314, 34, 1, 4, 4, 5, 7, 6, 44, NULL, 'Maksimali valandinė S+ galia pagal 5 tarifą per mėnesį', 3975, 4, NULL, NULL),
	(9315, 34, 1, 9, 4, 5, 7, 6, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 5 tarifą per mėnesį', 3975, 4, NULL, NULL),
	(9316, 34, 1, 11, 4, 5, 7, 6, 44, NULL, 'Maksimali 5 minučių S+ galia pagal 5 tarifą per mėnesį', 3975, 4, NULL, NULL),
	(9317, 34, 1, 13, 4, 5, 7, 6, 44, NULL, 'Maksimali 15 minučių S+ galia pagal 5 tarifą per mėnesį', 3975, 4, NULL, NULL),
	(9318, 34, 1, 3, 4, 6, 7, 6, 44, NULL, 'Maksimali pusvalandinė S+ galia pagal 6 tarifą per mėnesį', 3976, 4, NULL, NULL),
	(9319, 34, 1, 4, 4, 6, 7, 6, 44, NULL, 'Maksimali valandinė S+ galia pagal 6 tarifą per mėnesį', 3976, 4, NULL, NULL),
	(9320, 34, 1, 9, 4, 6, 7, 6, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 6 tarifą per mėnesį', 3976, 4, NULL, NULL),
	(9321, 34, 1, 11, 4, 6, 7, 6, 44, NULL, 'Maksimali 5 minučių S+ galia pagal 6 tarifą per mėnesį', 3976, 4, NULL, NULL),
	(9322, 34, 1, 13, 4, 6, 7, 6, 44, NULL, 'Maksimali 15 minučių S+ galia pagal 6 tarifą per mėnesį', 3976, 4, NULL, NULL),
	(9323, 34, 1, 3, 4, 7, 7, 6, 44, NULL, 'Maksimali pusvalandinė S+ galia pagal 7 tarifą per mėnesį', 3977, 4, NULL, NULL),
	(9324, 34, 1, 4, 4, 7, 7, 6, 44, NULL, 'Maksimali valandinė S+ galia pagal 7 tarifą per mėnesį', 3977, 4, NULL, NULL),
	(9325, 34, 1, 9, 4, 7, 7, 6, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 7 tarifą per mėnesį', 3977, 4, NULL, NULL),
	(9326, 34, 1, 11, 4, 7, 7, 6, 44, NULL, 'Maksimali 5 minučių S+ galia pagal 7 tarifą per mėnesį', 3977, 4, NULL, NULL),
	(9327, 34, 1, 13, 4, 7, 7, 6, 44, NULL, 'Maksimali 15 minučių S+ galia pagal 7 tarifą per mėnesį', 3977, 4, NULL, NULL),
	(9328, 34, 1, 3, 4, 8, 7, 6, 44, NULL, 'Maksimali pusvalandinė S+ galia pagal 8 tarifą per mėnesį', 3978, 4, NULL, NULL),
	(9329, 34, 1, 4, 4, 8, 7, 6, 44, NULL, 'Maksimali valandinė S+ galia pagal 8 tarifą per mėnesį', 3978, 4, NULL, NULL),
	(9330, 34, 1, 9, 4, 8, 7, 6, 44, NULL, 'Maksimali 3 minučių S+ galia pagal 8 tarifą per mėnesį', 3978, 4, NULL, NULL),
	(9331, 34, 1, 11, 4, 8, 7, 6, 44, NULL, 'Maksimali 5 minučių S+ galia pagal 8 tarifą per mėnesį', 3978, 4, NULL, NULL),
	(9332, 34, 1, 13, 4, 8, 7, 6, 44, NULL, 'Maksimali 15 minučių S+ galia pagal 8 tarifą per mėnesį', 3978, 4, NULL, NULL),
	(9333, 34, 2, 3, 4, 5, 7, 6, 44, NULL, 'Maksimali pusvalandinė S- galia pagal 5 tarifą per mėnesį', 3979, 4, NULL, NULL),
	(9334, 34, 2, 4, 4, 5, 7, 6, 44, NULL, 'Maksimali valandinė S- galia pagal 5 tarifą per mėnesį', 3979, 4, NULL, NULL),
	(9335, 34, 2, 9, 4, 5, 7, 6, 44, NULL, 'Maksimali 3 minučių S- galia pagal 5 tarifą per mėnesį', 3979, 4, NULL, NULL),
	(9336, 34, 2, 11, 4, 5, 7, 6, 44, NULL, 'Maksimali 5 minučių S- galia pagal 5 tarifą per mėnesį', 3979, 4, NULL, NULL),
	(9337, 34, 2, 13, 4, 5, 7, 6, 44, NULL, 'Maksimali 15 minučių S- galia pagal 5 tarifą per mėnesį', 3979, 4, NULL, NULL),
	(9338, 34, 2, 3, 4, 6, 7, 6, 44, NULL, 'Maksimali pusvalandinė S- galia pagal 6 tarifą per mėnesį', 3980, 4, NULL, NULL),
	(9339, 34, 2, 4, 4, 6, 7, 6, 44, NULL, 'Maksimali valandinė S- galia pagal 6 tarifą per mėnesį', 3980, 4, NULL, NULL),
	(9340, 34, 2, 9, 4, 6, 7, 6, 44, NULL, 'Maksimali 3 minučių S- galia pagal 6 tarifą per mėnesį', 3980, 4, NULL, NULL),
	(9341, 34, 2, 11, 4, 6, 7, 6, 44, NULL, 'Maksimali 5 minučių S- galia pagal 6 tarifą per mėnesį', 3980, 4, NULL, NULL),
	(9342, 34, 2, 13, 4, 6, 7, 6, 44, NULL, 'Maksimali 15 minučių S- galia pagal 6 tarifą per mėnesį', 3980, 4, NULL, NULL),
	(9343, 34, 2, 3, 4, 7, 7, 6, 44, NULL, 'Maksimali pusvalandinė S- galia pagal 7 tarifą per mėnesį', 3981, 4, NULL, NULL),
	(9344, 34, 2, 4, 4, 7, 7, 6, 44, NULL, 'Maksimali valandinė S- galia pagal 7 tarifą per mėnesį', 3981, 4, NULL, NULL),
	(9345, 34, 2, 9, 4, 7, 7, 6, 44, NULL, 'Maksimali 3 minučių S- galia pagal 7 tarifą per mėnesį', 3981, 4, NULL, NULL),
	(9346, 34, 2, 11, 4, 7, 7, 6, 44, NULL, 'Maksimali 5 minučių S- galia pagal 7 tarifą per mėnesį', 3981, 4, NULL, NULL),
	(9347, 34, 2, 13, 4, 7, 7, 6, 44, NULL, 'Maksimali 15 minučių S- galia pagal 7 tarifą per mėnesį', 3981, 4, NULL, NULL),
	(9348, 34, 2, 3, 4, 8, 7, 6, 44, NULL, 'Maksimali pusvalandinė S- galia pagal 8 tarifą per mėnesį', 3982, 4, NULL, NULL),
	(9349, 34, 2, 4, 4, 8, 7, 6, 44, NULL, 'Maksimali valandinė S- galia pagal 8 tarifą per mėnesį', 3982, 4, NULL, NULL),
	(9350, 34, 2, 9, 4, 8, 7, 6, 44, NULL, 'Maksimali 3 minučių S- galia pagal 8 tarifą per mėnesį', 3982, 4, NULL, NULL),
	(9351, 34, 2, 11, 4, 8, 7, 6, 44, NULL, 'Maksimali 5 minučių S- galia pagal 8 tarifą per mėnesį', 3982, 4, NULL, NULL),
	(9352, 34, 2, 13, 4, 8, 7, 6, 44, NULL, 'Maksimali 15 minučių S- galia pagal 8 tarifą per mėnesį', 3982, 4, NULL, NULL),
	(9353, 1, 1, 13, 4, 8, 1, 6, 13, NULL, 'Maksimali 15 minučių P+ galia pagal 8 tarifą per mėnesį', 3962, 4, NULL, NULL),
	(9354, 404, 0, 7, 1, 0, 58, 7, 415, NULL, 'Momentinis GSM signalo stiprumas', 4012, 6, NULL, NULL),
	(9355, 405, 0, 7, 1, 0, 65, 7, 416, NULL, 'Momentinė varža', 4005, 6, NULL, NULL),
	(9356, 406, 0, 7, 1, 0, 66, 7, 417, NULL, 'Momentinė savitoji varža', 4006, 6, NULL, NULL),
	(9357, 407, 0, 7, 1, 0, 67, 7, 418, NULL, 'Momentinis laidumas', 4007, 6, NULL, NULL),
	(9358, 408, 0, 7, 1, 0, 68, 7, 419, NULL, 'Momentinis savitasis laidumas', 4008, 6, NULL, NULL),
	(9359, 409, 0, 7, 1, 0, 69, 7, 420, NULL, 'Momentinė talpa', 4009, 6, NULL, NULL),
	(9360, 410, 0, 7, 1, 0, 70, 7, 421, NULL, 'Momentinis induktyvumas', 4010, 6, NULL, NULL),
	(9361, 411, 0, 7, 1, 0, 0, 7, 422, NULL, 'Krovimo būklė', 4011, 6, NULL, NULL),
	(9362, 412, 0, 7, 1, 0, 0, 7, 423, NULL, 'Vartotojo sąsajos (Cl in) būklė', 4013, 6, NULL, NULL),
	(9363, 413, 0, 7, 1, 0, 0, 7, 424, NULL, 'Skaitiklio sąsajos (Cl out) būklė', 4014, 6, NULL, NULL),
	(9364, 414, 0, 7, 1, 0, 0, 7, 425, NULL, 'Maitinimo (AC) būklė', 4015, 6, NULL, NULL),
	(9365, 415, 0, 7, 1, 0, 0, 7, 426, NULL, 'Modemo duomenų laukimo taimautas', 4016, 6, NULL, NULL),
	(9366, 416, 0, 7, 1, 0, 0, 7, 427, NULL, 'Maitinimo (AC) dingimų kiekis', 4017, 6, NULL, NULL),
	(9367, 417, 0, 7, 1, 0, 0, 7, 428, NULL, 'Užkrovimas iš EEPROM', 4018, 6, NULL, NULL),
	(9368, 51, 0, 7, 1, 0, 36, 4, 67, NULL, 'Momentinis šilumnešio masės debitas, fiksuojamas kas valandą', 1006, 2, NULL, NULL),
	(9369, 51, 0, 7, 1, 0, 36, 12, 67, NULL, 'Momentinis šilumnešio masės debitas, fiksuojamas kas 15 minučių', 1006, 2, NULL, NULL),
	(9370, 51, 0, 7, 1, 0, 36, 3, 67, NULL, 'Momentinis šilumnešio masės debitas, fiksuojamas kas 30 minučių', 1006, 2, NULL, NULL),
	(9371, 52, 0, 7, 1, 0, 28, 4, 69, NULL, 'Momentinis šilumnešio slėgis, fiksuojamas kas valandą', 1004, 2, NULL, NULL),
	(9372, 52, 0, 7, 1, 0, 28, 12, 69, NULL, 'Momentinis šilumnešio slėgis, fiksuojamas kas 15 minučių', 1004, 2, NULL, NULL),
	(9373, 52, 0, 7, 1, 0, 28, 3, 69, NULL, 'Momentinis šilumnešio slėgis, fiksuojamas kas 30 minučių', 1004, 2, NULL, NULL),
	(9374, 54, 2, 7, 1, 0, 27, 4, 72, NULL, 'Momentinė grįžtamo šilumnešio temperatūra, fiksuojama kas valandą', 1008, 2, NULL, NULL),
	(9375, 54, 2, 7, 1, 0, 27, 12, 72, NULL, 'Momentinė grįžtamo šilumnešio temperatūra, fiksuojama kas 15 minučių', 1008, 2, NULL, NULL),
	(9376, 54, 2, 7, 1, 0, 27, 3, 72, NULL, 'Momentinė grįžtamo šilumnešio temperatūra, fiksuojama kas 30 minučių', 1008, 2, NULL, NULL),
	(9377, 54, 1, 7, 1, 0, 27, 4, 72, NULL, 'Momentinė tiekiamo šilumnešio temperatūra, fiksuojama kas valandą', 1003, 2, NULL, NULL),
	(9378, 54, 1, 7, 1, 0, 27, 12, 72, NULL, 'Momentinė tiekiamo šilumnešio temperatūra, fiksuojama kas 15 minučių', 1003, 2, NULL, NULL),
	(9379, 54, 1, 7, 1, 0, 27, 3, 72, NULL, 'Momentinė tiekiamo šilumnešio temperatūra, fiksuojama kas 30 minučių', 1003, 2, NULL, NULL),
	(9380, 53, 0, 7, 1, 0, 1, 4, 70, NULL, 'Momentinė šilumnešio šilumos galia, fiksuojama kas valandą', 1002, 2, NULL, NULL),
	(9381, 53, 0, 7, 1, 0, 1, 12, 70, NULL, 'Momentinė šilumnešio šilumos galia, fiksuojama kas 15 minučių', 1002, 2, NULL, NULL),
	(9382, 53, 0, 7, 1, 0, 1, 3, 70, NULL, 'Momentinė šilumnešio šilumos galia, fiksuojama kas 30 minučių', 1002, 2, NULL, NULL),
	(9383, 54, 3, 7, 1, 0, 27, 4, 72, NULL, 'Momentinis tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas, fiksuojamas kas valandą', 1009, 2, NULL, NULL),
	(9384, 54, 3, 7, 1, 0, 27, 12, 72, NULL, 'Momentinis tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas, fiksuojamas kas 15 minučių', 1009, 2, NULL, NULL),
	(9385, 54, 3, 7, 1, 0, 27, 3, 72, NULL, 'Momentinis tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumas, fiksuojamas kas 30 minučių', 1009, 2, NULL, NULL),
	(9386, 3, 5, 7, 1, 0, 3, 7, 16, NULL, 'Momentinė Q1 galia', 3419, 6, NULL, NULL),
	(9387, 3, 5, 7, 1, 0, 3, 1, 16, NULL, 'Momentinė Q1 galia, fiksuojama kas minutę', 3419, 1, NULL, NULL),
	(9388, 3, 5, 7, 1, 0, 3, 5, 16, NULL, 'Momentinė Q1 galia, fiksuojama kas parą', 3419, 3, NULL, NULL),
	(9389, 3, 5, 7, 1, 0, 3, 4, 16, NULL, 'Momentinė Q1 galia, fiksuojama kas valandą', 3419, 2, NULL, NULL),
	(9390, 3, 5, 7, 1, 0, 3, 12, 16, NULL, 'Momentinė Q1 galia, fiksuojama kas 15 minučių', 3419, 2, NULL, NULL),
	(9391, 3, 5, 7, 1, 0, 3, 2, 16, NULL, 'Momentinė Q1 galia, fiksuojama kas 2 minutes', 3419, 1, NULL, NULL),
	(9392, 3, 5, 7, 1, 0, 3, 8, 16, NULL, 'Momentinė Q1 galia, fiksuojama kas 3 minutes', 3419, 1, NULL, NULL),
	(9393, 3, 5, 7, 1, 0, 3, 3, 16, NULL, 'Momentinė Q1 galia, fiksuojama kas 30 minučių', 3419, 2, NULL, NULL),
	(9394, 3, 5, 7, 1, 0, 3, 19, 16, NULL, 'Momentinė Q1 galia, fiksuojama kas 30 sekundžių', 3419, 7, NULL, NULL),
	(9395, 3, 5, 7, 1, 0, 3, 10, 16, NULL, 'Momentinė Q1 galia, fiksuojama kas 5 minutes', 3419, 1, NULL, NULL),
	(9396, 3, 5, 7, 1, 0, 3, 15, 16, NULL, 'Momentinė Q1 galia, fiksuojama kas 5 sekundes', 3419, 7, NULL, NULL),
	(9397, 3, 6, 7, 1, 0, 3, 7, 16, NULL, 'Momentinė Q2 galia', 3423, 6, NULL, NULL),
	(9398, 3, 6, 7, 1, 0, 3, 1, 16, NULL, 'Momentinė Q2 galia, fiksuojama kas minutę', 3423, 1, NULL, NULL),
	(9399, 3, 6, 7, 1, 0, 3, 5, 16, NULL, 'Momentinė Q2 galia, fiksuojama kas parą', 3423, 3, NULL, NULL),
	(9400, 3, 6, 7, 1, 0, 3, 4, 16, NULL, 'Momentinė Q2 galia, fiksuojama kas valandą', 3423, 2, NULL, NULL),
	(9401, 3, 6, 7, 1, 0, 3, 12, 16, NULL, 'Momentinė Q2 galia, fiksuojama kas 15 minučių', 3423, 2, NULL, NULL),
	(9402, 3, 6, 7, 1, 0, 3, 2, 16, NULL, 'Momentinė Q2 galia, fiksuojama kas 2 minutes', 3423, 1, NULL, NULL),
	(9403, 3, 6, 7, 1, 0, 3, 8, 16, NULL, 'Momentinė Q2 galia, fiksuojama kas 3 minutes', 3423, 1, NULL, NULL),
	(9404, 3, 6, 7, 1, 0, 3, 3, 16, NULL, 'Momentinė Q2 galia, fiksuojama kas 30 minučių', 3423, 2, NULL, NULL),
	(9405, 3, 6, 7, 1, 0, 3, 19, 16, NULL, 'Momentinė Q2 galia, fiksuojama kas 30 sekundžių', 3423, 7, NULL, NULL),
	(9406, 3, 6, 7, 1, 0, 3, 10, 16, NULL, 'Momentinė Q2 galia, fiksuojama kas 5 minutes', 3423, 1, NULL, NULL),
	(9407, 3, 6, 7, 1, 0, 3, 15, 16, NULL, 'Momentinė Q2 galia, fiksuojama kas 5 sekundes', 3423, 7, NULL, NULL),
	(9408, 3, 7, 7, 1, 0, 3, 7, 16, NULL, 'Momentinė Q3 galia', 3427, 6, NULL, NULL),
	(9409, 3, 7, 7, 1, 0, 3, 1, 16, NULL, 'Momentinė Q3 galia, fiksuojama kas minutę', 3427, 1, NULL, NULL),
	(9410, 3, 7, 7, 1, 0, 3, 5, 16, NULL, 'Momentinė Q3 galia, fiksuojama kas parą', 3427, 3, NULL, NULL),
	(9411, 3, 7, 7, 1, 0, 3, 4, 16, NULL, 'Momentinė Q3 galia, fiksuojama kas valandą', 3427, 2, NULL, NULL),
	(9412, 3, 7, 7, 1, 0, 3, 12, 16, NULL, 'Momentinė Q3 galia, fiksuojama kas 15 minučių', 3427, 2, NULL, NULL),
	(9413, 3, 7, 7, 1, 0, 3, 2, 16, NULL, 'Momentinė Q3 galia, fiksuojama kas 2 minutes', 3427, 1, NULL, NULL),
	(9414, 3, 7, 7, 1, 0, 3, 8, 16, NULL, 'Momentinė Q3 galia, fiksuojama kas 3 minutes', 3427, 1, NULL, NULL),
	(9415, 3, 7, 7, 1, 0, 3, 3, 16, NULL, 'Momentinė Q3 galia, fiksuojama kas 30 minučių', 3427, 2, NULL, NULL),
	(9416, 3, 7, 7, 1, 0, 3, 19, 16, NULL, 'Momentinė Q3 galia, fiksuojama kas 30 sekundžių', 3427, 7, NULL, NULL),
	(9417, 3, 7, 7, 1, 0, 3, 10, 16, NULL, 'Momentinė Q3 galia, fiksuojama kas 5 minutes', 3427, 1, NULL, NULL),
	(9418, 3, 7, 7, 1, 0, 3, 15, 16, NULL, 'Momentinė Q3 galia, fiksuojama kas 5 sekundes', 3427, 7, NULL, NULL),
	(9419, 3, 8, 7, 1, 0, 3, 7, 16, NULL, 'Momentinė Q4 galia', 3431, 6, NULL, NULL),
	(9420, 3, 8, 7, 1, 0, 3, 1, 16, NULL, 'Momentinė Q4 galia, fiksuojama kas minutę', 3431, 1, NULL, NULL),
	(9421, 3, 8, 7, 1, 0, 3, 5, 16, NULL, 'Momentinė Q4 galia, fiksuojama kas parą', 3431, 3, NULL, NULL),
	(9422, 3, 8, 7, 1, 0, 3, 4, 16, NULL, 'Momentinė Q4 galia, fiksuojama kas valandą', 3431, 2, NULL, NULL),
	(9423, 3, 8, 7, 1, 0, 3, 12, 16, NULL, 'Momentinė Q4 galia, fiksuojama kas 15 minučių', 3431, 2, NULL, NULL),
	(9424, 3, 8, 7, 1, 0, 3, 2, 16, NULL, 'Momentinė Q4 galia, fiksuojama kas 2 minutes', 3431, 1, NULL, NULL),
	(9425, 3, 8, 7, 1, 0, 3, 8, 16, NULL, 'Momentinė Q4 galia, fiksuojama kas 3 minutes', 3431, 1, NULL, NULL),
	(9426, 3, 8, 7, 1, 0, 3, 3, 16, NULL, 'Momentinė Q4 galia, fiksuojama kas 30 minučių', 3431, 2, NULL, NULL),
	(9427, 3, 8, 7, 1, 0, 3, 19, 16, NULL, 'Momentinė Q4 galia, fiksuojama kas 30 sekundžių', 3431, 7, NULL, NULL),
	(9428, 3, 8, 7, 1, 0, 3, 10, 16, NULL, 'Momentinė Q4 galia, fiksuojama kas 5 minutes', 3431, 1, NULL, NULL),
	(9429, 3, 8, 7, 1, 0, 3, 15, 16, NULL, 'Momentinė Q4 galia, fiksuojama kas 5 sekundes', 3431, 7, NULL, NULL),
	(9430, 17, 5, 7, 1, 0, 3, 7, 29, NULL, 'Momentinė Q1 galia L1 fazėje', 3420, 6, NULL, NULL),
	(9431, 17, 5, 7, 1, 0, 3, 1, 29, NULL, 'Momentinė Q1 galia L1 fazėje, fiksuojama kas minutę', 3420, 1, NULL, NULL),
	(9432, 17, 5, 7, 1, 0, 3, 5, 29, NULL, 'Momentinė Q1 galia L1 fazėje, fiksuojama kas parą', 3420, 3, NULL, NULL),
	(9433, 17, 5, 7, 1, 0, 3, 4, 29, NULL, 'Momentinė Q1 galia L1 fazėje, fiksuojama kas valandą', 3420, 2, NULL, NULL),
	(9434, 17, 5, 7, 1, 0, 3, 12, 29, NULL, 'Momentinė Q1 galia L1 fazėje, fiksuojama kas 15 minučių', 3420, 2, NULL, NULL),
	(9435, 17, 5, 7, 1, 0, 3, 2, 29, NULL, 'Momentinė Q1 galia L1 fazėje, fiksuojama kas 2 minutes', 3420, 1, NULL, NULL),
	(9436, 17, 5, 7, 1, 0, 3, 8, 29, NULL, 'Momentinė Q1 galia L1 fazėje, fiksuojama kas 3 minutes', 3420, 1, NULL, NULL),
	(9437, 17, 5, 7, 1, 0, 3, 3, 29, NULL, 'Momentinė Q1 galia L1 fazėje, fiksuojama kas 30 minučių', 3420, 2, NULL, NULL),
	(9438, 17, 5, 7, 1, 0, 3, 19, 29, NULL, 'Momentinė Q1 galia L1 fazėje, fiksuojama kas 30 sekundžių', 3420, 7, NULL, NULL),
	(9439, 17, 5, 7, 1, 0, 3, 10, 29, NULL, 'Momentinė Q1 galia L1 fazėje, fiksuojama kas 5 minutes', 3420, 1, NULL, NULL),
	(9440, 17, 5, 7, 1, 0, 3, 15, 29, NULL, 'Momentinė Q1 galia L1 fazėje, fiksuojama kas 5 sekundes', 3420, 7, NULL, NULL),
	(9441, 18, 5, 7, 1, 0, 3, 7, 30, NULL, 'Momentinė Q1 galia L2 fazėje', 3421, 6, NULL, NULL),
	(9442, 18, 5, 7, 1, 0, 3, 1, 30, NULL, 'Momentinė Q1 galia L2 fazėje, fiksuojama kas minutę', 3421, 1, NULL, NULL),
	(9443, 18, 5, 7, 1, 0, 3, 5, 30, NULL, 'Momentinė Q1 galia L2 fazėje, fiksuojama kas parą', 3421, 3, NULL, NULL),
	(9444, 18, 5, 7, 1, 0, 3, 4, 30, NULL, 'Momentinė Q1 galia L2 fazėje, fiksuojama kas valandą', 3421, 2, NULL, NULL),
	(9445, 18, 5, 7, 1, 0, 3, 12, 30, NULL, 'Momentinė Q1 galia L2 fazėje, fiksuojama kas 15 minučių', 3421, 2, NULL, NULL),
	(9446, 18, 5, 7, 1, 0, 3, 2, 30, NULL, 'Momentinė Q1 galia L2 fazėje, fiksuojama kas 2 minutes', 3421, 1, NULL, NULL),
	(9447, 18, 5, 7, 1, 0, 3, 8, 30, NULL, 'Momentinė Q1 galia L2 fazėje, fiksuojama kas 3 minutes', 3421, 1, NULL, NULL),
	(9448, 18, 5, 7, 1, 0, 3, 3, 30, NULL, 'Momentinė Q1 galia L2 fazėje, fiksuojama kas 30 minučių', 3421, 2, NULL, NULL),
	(9449, 18, 5, 7, 1, 0, 3, 19, 30, NULL, 'Momentinė Q1 galia L2 fazėje, fiksuojama kas 30 sekundžių', 3421, 7, NULL, NULL),
	(9450, 18, 5, 7, 1, 0, 3, 10, 30, NULL, 'Momentinė Q1 galia L2 fazėje, fiksuojama kas 5 minutes', 3421, 1, NULL, NULL),
	(9451, 18, 5, 7, 1, 0, 3, 15, 30, NULL, 'Momentinė Q1 galia L2 fazėje, fiksuojama kas 5 sekundes', 3421, 7, NULL, NULL),
	(9452, 19, 5, 7, 1, 0, 3, 7, 31, NULL, 'Momentinė Q1 galia L3 fazėje', 3422, 6, NULL, NULL),
	(9453, 19, 5, 7, 1, 0, 3, 1, 31, NULL, 'Momentinė Q1 galia L3 fazėje, fiksuojama kas minutę', 3422, 1, NULL, NULL),
	(9454, 19, 5, 7, 1, 0, 3, 5, 31, NULL, 'Momentinė Q1 galia L3 fazėje, fiksuojama kas parą', 3422, 3, NULL, NULL),
	(9455, 19, 5, 7, 1, 0, 3, 4, 31, NULL, 'Momentinė Q1 galia L3 fazėje, fiksuojama kas valandą', 3422, 2, NULL, NULL),
	(9456, 19, 5, 7, 1, 0, 3, 12, 31, NULL, 'Momentinė Q1 galia L3 fazėje, fiksuojama kas 15 minučių', 3422, 2, NULL, NULL),
	(9457, 19, 5, 7, 1, 0, 3, 2, 31, NULL, 'Momentinė Q1 galia L3 fazėje, fiksuojama kas 2 minutes', 3422, 1, NULL, NULL),
	(9458, 19, 5, 7, 1, 0, 3, 8, 31, NULL, 'Momentinė Q1 galia L3 fazėje, fiksuojama kas 3 minutes', 3422, 1, NULL, NULL),
	(9459, 19, 5, 7, 1, 0, 3, 3, 31, NULL, 'Momentinė Q1 galia L3 fazėje, fiksuojama kas 30 minučių', 3422, 2, NULL, NULL),
	(9460, 19, 5, 7, 1, 0, 3, 19, 31, NULL, 'Momentinė Q1 galia L3 fazėje, fiksuojama kas 30 sekundžių', 3422, 7, NULL, NULL),
	(9461, 19, 5, 7, 1, 0, 3, 10, 31, NULL, 'Momentinė Q1 galia L3 fazėje, fiksuojama kas 5 minutes', 3422, 1, NULL, NULL),
	(9462, 19, 5, 7, 1, 0, 3, 15, 31, NULL, 'Momentinė Q1 galia L3 fazėje, fiksuojama kas 5 sekundes', 3422, 7, NULL, NULL),
	(9463, 17, 6, 7, 1, 0, 3, 7, 29, NULL, 'Momentinė Q2 galia L1 fazėje', 3424, 6, NULL, NULL),
	(9464, 17, 6, 7, 1, 0, 3, 1, 29, NULL, 'Momentinė Q2 galia L1 fazėje, fiksuojama kas minutę', 3424, 1, NULL, NULL),
	(9465, 17, 6, 7, 1, 0, 3, 5, 29, NULL, 'Momentinė Q2 galia L1 fazėje, fiksuojama kas parą', 3424, 3, NULL, NULL),
	(9466, 17, 6, 7, 1, 0, 3, 4, 29, NULL, 'Momentinė Q2 galia L1 fazėje, fiksuojama kas valandą', 3424, 2, NULL, NULL),
	(9467, 17, 6, 7, 1, 0, 3, 12, 29, NULL, 'Momentinė Q2 galia L1 fazėje, fiksuojama kas 15 minučių', 3424, 2, NULL, NULL),
	(9468, 17, 6, 7, 1, 0, 3, 2, 29, NULL, 'Momentinė Q2 galia L1 fazėje, fiksuojama kas 2 minutes', 3424, 1, NULL, NULL),
	(9469, 17, 6, 7, 1, 0, 3, 8, 29, NULL, 'Momentinė Q2 galia L1 fazėje, fiksuojama kas 3 minutes', 3424, 1, NULL, NULL),
	(9470, 17, 6, 7, 1, 0, 3, 3, 29, NULL, 'Momentinė Q2 galia L1 fazėje, fiksuojama kas 30 minučių', 3424, 2, NULL, NULL),
	(9471, 17, 6, 7, 1, 0, 3, 19, 29, NULL, 'Momentinė Q2 galia L1 fazėje, fiksuojama kas 30 sekundžių', 3424, 7, NULL, NULL),
	(9472, 17, 6, 7, 1, 0, 3, 10, 29, NULL, 'Momentinė Q2 galia L1 fazėje, fiksuojama kas 5 minutes', 3424, 1, NULL, NULL),
	(9473, 17, 6, 7, 1, 0, 3, 15, 29, NULL, 'Momentinė Q2 galia L1 fazėje, fiksuojama kas 5 sekundes', 3424, 7, NULL, NULL),
	(9474, 18, 6, 7, 1, 0, 3, 7, 30, NULL, 'Momentinė Q2 galia L2 fazėje', 3425, 6, NULL, NULL),
	(9475, 18, 6, 7, 1, 0, 3, 1, 30, NULL, 'Momentinė Q2 galia L2 fazėje, fiksuojama kas minutę', 3425, 1, NULL, NULL),
	(9476, 18, 6, 7, 1, 0, 3, 5, 30, NULL, 'Momentinė Q2 galia L2 fazėje, fiksuojama kas parą', 3425, 3, NULL, NULL),
	(9477, 18, 6, 7, 1, 0, 3, 4, 30, NULL, 'Momentinė Q2 galia L2 fazėje, fiksuojama kas valandą', 3425, 2, NULL, NULL),
	(9478, 18, 6, 7, 1, 0, 3, 12, 30, NULL, 'Momentinė Q2 galia L2 fazėje, fiksuojama kas 15 minučių', 3425, 2, NULL, NULL),
	(9479, 18, 6, 7, 1, 0, 3, 2, 30, NULL, 'Momentinė Q2 galia L2 fazėje, fiksuojama kas 2 minutes', 3425, 1, NULL, NULL),
	(9480, 18, 6, 7, 1, 0, 3, 8, 30, NULL, 'Momentinė Q2 galia L2 fazėje, fiksuojama kas 3 minutes', 3425, 1, NULL, NULL),
	(9481, 18, 6, 7, 1, 0, 3, 3, 30, NULL, 'Momentinė Q2 galia L2 fazėje, fiksuojama kas 30 minučių', 3425, 2, NULL, NULL),
	(9482, 18, 6, 7, 1, 0, 3, 19, 30, NULL, 'Momentinė Q2 galia L2 fazėje, fiksuojama kas 30 sekundžių', 3425, 7, NULL, NULL),
	(9483, 18, 6, 7, 1, 0, 3, 10, 30, NULL, 'Momentinė Q2 galia L2 fazėje, fiksuojama kas 5 minutes', 3425, 1, NULL, NULL),
	(9484, 18, 6, 7, 1, 0, 3, 15, 30, NULL, 'Momentinė Q2 galia L2 fazėje, fiksuojama kas 5 sekundes', 3425, 7, NULL, NULL),
	(9485, 19, 6, 7, 1, 0, 3, 7, 31, NULL, 'Momentinė Q2 galia L3 fazėje', 3426, 6, NULL, NULL),
	(9486, 19, 6, 7, 1, 0, 3, 1, 31, NULL, 'Momentinė Q2 galia L3 fazėje, fiksuojama kas minutę', 3426, 1, NULL, NULL),
	(9487, 19, 6, 7, 1, 0, 3, 5, 31, NULL, 'Momentinė Q2 galia L3 fazėje, fiksuojama kas parą', 3426, 3, NULL, NULL),
	(9488, 19, 6, 7, 1, 0, 3, 4, 31, NULL, 'Momentinė Q2 galia L3 fazėje, fiksuojama kas valandą', 3426, 2, NULL, NULL),
	(9489, 19, 6, 7, 1, 0, 3, 12, 31, NULL, 'Momentinė Q2 galia L3 fazėje, fiksuojama kas 15 minučių', 3426, 2, NULL, NULL),
	(9490, 19, 6, 7, 1, 0, 3, 2, 31, NULL, 'Momentinė Q2 galia L3 fazėje, fiksuojama kas 2 minutes', 3426, 1, NULL, NULL),
	(9491, 19, 6, 7, 1, 0, 3, 8, 31, NULL, 'Momentinė Q2 galia L3 fazėje, fiksuojama kas 3 minutes', 3426, 1, NULL, NULL),
	(9492, 19, 6, 7, 1, 0, 3, 3, 31, NULL, 'Momentinė Q2 galia L3 fazėje, fiksuojama kas 30 minučių', 3426, 2, NULL, NULL),
	(9493, 19, 6, 7, 1, 0, 3, 19, 31, NULL, 'Momentinė Q2 galia L3 fazėje, fiksuojama kas 30 sekundžių', 3426, 7, NULL, NULL),
	(9494, 19, 6, 7, 1, 0, 3, 10, 31, NULL, 'Momentinė Q2 galia L3 fazėje, fiksuojama kas 5 minutes', 3426, 1, NULL, NULL),
	(9495, 19, 6, 7, 1, 0, 3, 15, 31, NULL, 'Momentinė Q2 galia L3 fazėje, fiksuojama kas 5 sekundes', 3426, 7, NULL, NULL),
	(9496, 17, 7, 7, 1, 0, 3, 7, 29, NULL, 'Momentinė Q3 galia L1 fazėje', 3428, 6, NULL, NULL),
	(9497, 17, 7, 7, 1, 0, 3, 1, 29, NULL, 'Momentinė Q3 galia L1 fazėje, fiksuojama kas minutę', 3428, 1, NULL, NULL),
	(9498, 17, 7, 7, 1, 0, 3, 5, 29, NULL, 'Momentinė Q3 galia L1 fazėje, fiksuojama kas parą', 3428, 3, NULL, NULL),
	(9499, 17, 7, 7, 1, 0, 3, 4, 29, NULL, 'Momentinė Q3 galia L1 fazėje, fiksuojama kas valandą', 3428, 2, NULL, NULL),
	(9500, 17, 7, 7, 1, 0, 3, 12, 29, NULL, 'Momentinė Q3 galia L1 fazėje, fiksuojama kas 15 minučių', 3428, 2, NULL, NULL),
	(9501, 17, 7, 7, 1, 0, 3, 2, 29, NULL, 'Momentinė Q3 galia L1 fazėje, fiksuojama kas 2 minutes', 3428, 1, NULL, NULL),
	(9502, 17, 7, 7, 1, 0, 3, 8, 29, NULL, 'Momentinė Q3 galia L1 fazėje, fiksuojama kas 3 minutes', 3428, 1, NULL, NULL),
	(9503, 17, 7, 7, 1, 0, 3, 3, 29, NULL, 'Momentinė Q3 galia L1 fazėje, fiksuojama kas 30 minučių', 3428, 2, NULL, NULL),
	(9504, 17, 7, 7, 1, 0, 3, 19, 29, NULL, 'Momentinė Q3 galia L1 fazėje, fiksuojama kas 30 sekundžių', 3428, 7, NULL, NULL),
	(9505, 17, 7, 7, 1, 0, 3, 10, 29, NULL, 'Momentinė Q3 galia L1 fazėje, fiksuojama kas 5 minutes', 3428, 1, NULL, NULL),
	(9506, 17, 7, 7, 1, 0, 3, 15, 29, NULL, 'Momentinė Q3 galia L1 fazėje, fiksuojama kas 5 sekundes', 3428, 7, NULL, NULL),
	(9507, 18, 7, 7, 1, 0, 3, 15, 30, NULL, 'Momentinė Q3 galia L2 fazėje, fiksuojama kas 5 sekundes', 3429, 7, NULL, NULL),
	(9508, 18, 7, 7, 1, 0, 3, 10, 30, NULL, 'Momentinė Q3 galia L2 fazėje, fiksuojama kas 5 minutes', 3429, 1, NULL, NULL),
	(9509, 18, 7, 7, 1, 0, 3, 19, 30, NULL, 'Momentinė Q3 galia L2 fazėje, fiksuojama kas 30 sekundžių', 3429, 7, NULL, NULL),
	(9510, 18, 7, 7, 1, 0, 3, 3, 30, NULL, 'Momentinė Q3 galia L2 fazėje, fiksuojama kas 30 minučių', 3429, 2, NULL, NULL),
	(9511, 18, 7, 7, 1, 0, 3, 8, 30, NULL, 'Momentinė Q3 galia L2 fazėje, fiksuojama kas 3 minutes', 3429, 1, NULL, NULL),
	(9512, 18, 7, 7, 1, 0, 3, 2, 30, NULL, 'Momentinė Q3 galia L2 fazėje, fiksuojama kas 2 minutes', 3429, 1, NULL, NULL),
	(9513, 18, 7, 7, 1, 0, 3, 12, 30, NULL, 'Momentinė Q3 galia L2 fazėje, fiksuojama kas 15 minučių', 3429, 2, NULL, NULL),
	(9514, 18, 7, 7, 1, 0, 3, 4, 30, NULL, 'Momentinė Q3 galia L2 fazėje, fiksuojama kas valandą', 3429, 2, NULL, NULL),
	(9515, 18, 7, 7, 1, 0, 3, 5, 30, NULL, 'Momentinė Q3 galia L2 fazėje, fiksuojama kas parą', 3429, 3, NULL, NULL),
	(9516, 18, 7, 7, 1, 0, 3, 1, 30, NULL, 'Momentinė Q3 galia L2 fazėje, fiksuojama kas minutę', 3429, 1, NULL, NULL),
	(9517, 18, 7, 7, 1, 0, 3, 7, 30, NULL, 'Momentinė Q3 galia L2 fazėje', 3429, 6, NULL, NULL),
	(9518, 19, 7, 7, 1, 0, 3, 15, 31, NULL, 'Momentinė Q3 galia L3 fazėje, fiksuojama kas 5 sekundes', 3430, 7, NULL, NULL),
	(9519, 19, 7, 7, 1, 0, 3, 10, 31, NULL, 'Momentinė Q3 galia L3 fazėje, fiksuojama kas 5 minutes', 3430, 1, NULL, NULL),
	(9520, 19, 7, 7, 1, 0, 3, 19, 31, NULL, 'Momentinė Q3 galia L3 fazėje, fiksuojama kas 30 sekundžių', 3430, 7, NULL, NULL),
	(9521, 19, 7, 7, 1, 0, 3, 3, 31, NULL, 'Momentinė Q3 galia L3 fazėje, fiksuojama kas 30 minučių', 3430, 2, NULL, NULL),
	(9522, 19, 7, 7, 1, 0, 3, 8, 31, NULL, 'Momentinė Q3 galia L3 fazėje, fiksuojama kas 3 minutes', 3430, 1, NULL, NULL),
	(9523, 19, 7, 7, 1, 0, 3, 2, 31, NULL, 'Momentinė Q3 galia L3 fazėje, fiksuojama kas 2 minutes', 3430, 1, NULL, NULL),
	(9524, 19, 7, 7, 1, 0, 3, 12, 31, NULL, 'Momentinė Q3 galia L3 fazėje, fiksuojama kas 15 minučių', 3430, 2, NULL, NULL),
	(9525, 19, 7, 7, 1, 0, 3, 4, 31, NULL, 'Momentinė Q3 galia L3 fazėje, fiksuojama kas valandą', 3430, 2, NULL, NULL),
	(9526, 19, 7, 7, 1, 0, 3, 5, 31, NULL, 'Momentinė Q3 galia L3 fazėje, fiksuojama kas parą', 3430, 3, NULL, NULL),
	(9527, 19, 7, 7, 1, 0, 3, 1, 31, NULL, 'Momentinė Q3 galia L3 fazėje, fiksuojama kas minutę', 3430, 1, NULL, NULL),
	(9528, 19, 7, 7, 1, 0, 3, 7, 31, NULL, 'Momentinė Q3 galia L3 fazėje', 3430, 6, NULL, NULL),
	(9529, 17, 8, 7, 1, 0, 3, 15, 29, NULL, 'Momentinė Q4 galia L1 fazėje, fiksuojama kas 5 sekundes', 3432, 7, NULL, NULL),
	(9530, 17, 8, 7, 1, 0, 3, 10, 29, NULL, 'Momentinė Q4 galia L1 fazėje, fiksuojama kas 5 minutes', 3432, 1, NULL, NULL),
	(9531, 17, 8, 7, 1, 0, 3, 19, 29, NULL, 'Momentinė Q4 galia L1 fazėje, fiksuojama kas 30 sekundžių', 3432, 7, NULL, NULL),
	(9532, 17, 8, 7, 1, 0, 3, 3, 29, NULL, 'Momentinė Q4 galia L1 fazėje, fiksuojama kas 30 minučių', 3432, 2, NULL, NULL),
	(9533, 17, 8, 7, 1, 0, 3, 8, 29, NULL, 'Momentinė Q4 galia L1 fazėje, fiksuojama kas 3 minutes', 3432, 1, NULL, NULL),
	(9534, 17, 8, 7, 1, 0, 3, 2, 29, NULL, 'Momentinė Q4 galia L1 fazėje, fiksuojama kas 2 minutes', 3432, 1, NULL, NULL),
	(9535, 17, 8, 7, 1, 0, 3, 12, 29, NULL, 'Momentinė Q4 galia L1 fazėje, fiksuojama kas 15 minučių', 3432, 2, NULL, NULL),
	(9536, 17, 8, 7, 1, 0, 3, 4, 29, NULL, 'Momentinė Q4 galia L1 fazėje, fiksuojama kas valandą', 3432, 2, NULL, NULL),
	(9537, 17, 8, 7, 1, 0, 3, 5, 29, NULL, 'Momentinė Q4 galia L1 fazėje, fiksuojama kas parą', 3432, 3, NULL, NULL),
	(9538, 17, 8, 7, 1, 0, 3, 1, 29, NULL, 'Momentinė Q4 galia L1 fazėje, fiksuojama kas minutę', 3432, 1, NULL, NULL),
	(9539, 17, 8, 7, 1, 0, 3, 7, 29, NULL, 'Momentinė Q4 galia L1 fazėje', 3432, 6, NULL, NULL),
	(9540, 18, 8, 7, 1, 0, 3, 15, 30, NULL, 'Momentinė Q4 galia L2 fazėje, fiksuojama kas 5 sekundes', 3433, 7, NULL, NULL),
	(9541, 18, 8, 7, 1, 0, 3, 10, 30, NULL, 'Momentinė Q4 galia L2 fazėje, fiksuojama kas 5 minutes', 3433, 1, NULL, NULL),
	(9542, 18, 8, 7, 1, 0, 3, 19, 30, NULL, 'Momentinė Q4 galia L2 fazėje, fiksuojama kas 30 sekundžių', 3433, 7, NULL, NULL),
	(9543, 18, 8, 7, 1, 0, 3, 3, 30, NULL, 'Momentinė Q4 galia L2 fazėje, fiksuojama kas 30 minučių', 3433, 2, NULL, NULL),
	(9544, 18, 8, 7, 1, 0, 3, 8, 30, NULL, 'Momentinė Q4 galia L2 fazėje, fiksuojama kas 3 minutes', 3433, 1, NULL, NULL),
	(9545, 18, 8, 7, 1, 0, 3, 2, 30, NULL, 'Momentinė Q4 galia L2 fazėje, fiksuojama kas 2 minutes', 3433, 1, NULL, NULL),
	(9546, 18, 8, 7, 1, 0, 3, 12, 30, NULL, 'Momentinė Q4 galia L2 fazėje, fiksuojama kas 15 minučių', 3433, 2, NULL, NULL),
	(9547, 18, 8, 7, 1, 0, 3, 4, 30, NULL, 'Momentinė Q4 galia L2 fazėje, fiksuojama kas valandą', 3433, 2, NULL, NULL),
	(9548, 18, 8, 7, 1, 0, 3, 5, 30, NULL, 'Momentinė Q4 galia L2 fazėje, fiksuojama kas parą', 3433, 3, NULL, NULL),
	(9549, 18, 8, 7, 1, 0, 3, 1, 30, NULL, 'Momentinė Q4 galia L2 fazėje, fiksuojama kas minutę', 3433, 1, NULL, NULL),
	(9550, 18, 8, 7, 1, 0, 3, 7, 30, NULL, 'Momentinė Q4 galia L2 fazėje', 3433, 6, NULL, NULL),
	(9551, 19, 8, 7, 1, 0, 3, 15, 31, NULL, 'Momentinė Q4 galia L3 fazėje, fiksuojama kas 5 sekundes', 3434, 7, NULL, NULL),
	(9552, 19, 8, 7, 1, 0, 3, 10, 31, NULL, 'Momentinė Q4 galia L3 fazėje, fiksuojama kas 5 minutes', 3434, 1, NULL, NULL),
	(9553, 19, 8, 7, 1, 0, 3, 19, 31, NULL, 'Momentinė Q4 galia L3 fazėje, fiksuojama kas 30 sekundžių', 3434, 7, NULL, NULL),
	(9554, 19, 8, 7, 1, 0, 3, 3, 31, NULL, 'Momentinė Q4 galia L3 fazėje, fiksuojama kas 30 minučių', 3434, 2, NULL, NULL),
	(9555, 19, 8, 7, 1, 0, 3, 8, 31, NULL, 'Momentinė Q4 galia L3 fazėje, fiksuojama kas 3 minutes', 3434, 1, NULL, NULL),
	(9556, 19, 8, 7, 1, 0, 3, 2, 31, NULL, 'Momentinė Q4 galia L3 fazėje, fiksuojama kas 2 minutes', 3434, 1, NULL, NULL),
	(9557, 19, 8, 7, 1, 0, 3, 12, 31, NULL, 'Momentinė Q4 galia L3 fazėje, fiksuojama kas 15 minučių', 3434, 2, NULL, NULL),
	(9558, 19, 8, 7, 1, 0, 3, 4, 31, NULL, 'Momentinė Q4 galia L3 fazėje, fiksuojama kas valandą', 3434, 2, NULL, NULL),
	(9559, 19, 8, 7, 1, 0, 3, 5, 31, NULL, 'Momentinė Q4 galia L3 fazėje, fiksuojama kas parą', 3434, 3, NULL, NULL),
	(9560, 19, 8, 7, 1, 0, 3, 1, 31, NULL, 'Momentinė Q4 galia L3 fazėje, fiksuojama kas minutę', 3434, 1, NULL, NULL),
	(9561, 19, 8, 7, 1, 0, 3, 7, 31, NULL, 'Momentinė Q4 galia L3 fazėje', 3434, 6, NULL, NULL),
	(9562, 418, 0, 7, 45, 0, 5, 7, 429, NULL, 'Momentinė 1-os harmonikos srovė', 3435, 6, NULL, NULL),
	(9563, 418, 0, 7, 6, 0, 5, 7, 429, NULL, 'Momentinė 2-os harmonikos srovė', 3436, 6, NULL, NULL),
	(9564, 418, 0, 7, 7, 0, 5, 7, 429, NULL, 'Momentinė 3-os harmonikos srovė', 3437, 6, NULL, NULL),
	(9565, 418, 0, 7, 8, 0, 5, 7, 429, NULL, 'Momentinė 4-os harmonikos srovė', 3438, 6, NULL, NULL),
	(9566, 418, 0, 7, 9, 0, 5, 7, 429, NULL, 'Momentinė 5-os harmonikos srovė', 3439, 6, NULL, NULL),
	(9567, 418, 0, 7, 10, 0, 5, 7, 429, NULL, 'Momentinė 6-os harmonikos srovė', 3440, 6, NULL, NULL),
	(9568, 418, 0, 7, 11, 0, 5, 7, 429, NULL, 'Momentinė 7-os harmonikos srovė', 3441, 6, NULL, NULL),
	(9569, 418, 0, 7, 12, 0, 5, 7, 429, NULL, 'Momentinė 8-os harmonikos srovė', 3442, 6, NULL, NULL),
	(9570, 304, 0, 7, 6, 0, 5, 7, 317, NULL, 'Momentinė 2-os harmonikos srovė L1 fazėje', 3443, 6, NULL, NULL),
	(9571, 304, 0, 7, 7, 0, 5, 7, 317, NULL, 'Momentinė 3-os harmonikos srovė L1 fazėje', 3444, 6, NULL, NULL),
	(9572, 304, 0, 7, 8, 0, 5, 7, 317, NULL, 'Momentinė 4-os harmonikos srovė L1 fazėje', 3445, 6, NULL, NULL),
	(9573, 304, 0, 7, 9, 0, 5, 7, 317, NULL, 'Momentinė 5-os harmonikos srovė L1 fazėje', 3446, 6, NULL, NULL),
	(9574, 304, 0, 7, 10, 0, 5, 7, 317, NULL, 'Momentinė 6-os harmonikos srovė L1 fazėje', 3447, 6, NULL, NULL),
	(9575, 304, 0, 7, 11, 0, 5, 7, 317, NULL, 'Momentinė 7-os harmonikos srovė L1 fazėje', 3448, 6, NULL, NULL),
	(9576, 304, 0, 7, 12, 0, 5, 7, 317, NULL, 'Momentinė 8-os harmonikos srovė L1 fazėje', 3449, 6, NULL, NULL),
	(9577, 305, 0, 7, 6, 0, 5, 7, 318, NULL, 'Momentinė 2-os harmonikos srovė L2 fazėje', 3450, 6, NULL, NULL),
	(9578, 305, 0, 7, 7, 0, 5, 7, 318, NULL, 'Momentinė 3-os harmonikos srovė L2 fazėje', 3451, 6, NULL, NULL),
	(9579, 305, 0, 7, 8, 0, 5, 7, 318, NULL, 'Momentinė 4-os harmonikos srovė L2 fazėje', 3452, 6, NULL, NULL),
	(9580, 305, 0, 7, 9, 0, 5, 7, 318, NULL, 'Momentinė 5-os harmonikos srovė L2 fazėje', 3453, 6, NULL, NULL),
	(9581, 305, 0, 7, 10, 0, 5, 7, 318, NULL, 'Momentinė 6-os harmonikos srovė L2 fazėje', 3454, 6, NULL, NULL),
	(9582, 305, 0, 7, 11, 0, 5, 7, 318, NULL, 'Momentinė 7-os harmonikos srovė L2 fazėje', 3455, 6, NULL, NULL),
	(9583, 305, 0, 7, 12, 0, 5, 7, 318, NULL, 'Momentinė 8-os harmonikos srovė L2 fazėje', 3456, 6, NULL, NULL),
	(9584, 306, 0, 7, 6, 0, 5, 7, 319, NULL, 'Momentinė 2-os harmonikos srovė L3 fazėje', 3457, 6, NULL, NULL),
	(9585, 306, 0, 7, 7, 0, 5, 7, 319, NULL, 'Momentinė 3-os harmonikos srovė L3 fazėje', 3458, 6, NULL, NULL),
	(9586, 306, 0, 7, 8, 0, 5, 7, 319, NULL, 'Momentinė 4-os harmonikos srovė L3 fazėje', 3459, 6, NULL, NULL),
	(9587, 306, 0, 7, 9, 0, 5, 7, 319, NULL, 'Momentinė 5-os harmonikos srovė L3 fazėje', 3460, 6, NULL, NULL),
	(9588, 306, 0, 7, 10, 0, 5, 7, 319, NULL, 'Momentinė 6-os harmonikos srovė L3 fazėje', 3461, 6, NULL, NULL),
	(9589, 306, 0, 7, 11, 0, 5, 7, 319, NULL, 'Momentinė 7-os harmonikos srovė L3 fazėje', 3462, 6, NULL, NULL),
	(9590, 306, 0, 7, 12, 0, 5, 7, 319, NULL, 'Momentinė 8-os harmonikos srovė L3 fazėje', 3463, 6, NULL, NULL),
	(9591, 419, 0, 7, 45, 0, 6, 7, 430, NULL, 'Momentinė 1-os harmonikos įtampa', 3464, 6, NULL, NULL),
	(9592, 419, 0, 7, 6, 0, 6, 7, 430, NULL, 'Momentinė 2-os harmonikos įtampa', 3465, 6, NULL, NULL),
	(9593, 419, 0, 7, 7, 0, 6, 7, 430, NULL, 'Momentinė 3-os harmonikos įtampa', 3466, 6, NULL, NULL),
	(9594, 419, 0, 7, 8, 0, 6, 7, 430, NULL, 'Momentinė 4-os harmonikos įtampa', 3467, 6, NULL, NULL),
	(9595, 419, 0, 7, 9, 0, 6, 7, 430, NULL, 'Momentinė 5-os harmonikos įtampa', 3468, 6, NULL, NULL),
	(9596, 419, 0, 7, 10, 0, 6, 7, 430, NULL, 'Momentinė 6-os harmonikos įtampa', 3469, 6, NULL, NULL),
	(9597, 419, 0, 7, 11, 0, 6, 7, 430, NULL, 'Momentinė 7-os harmonikos įtampa', 3470, 6, NULL, NULL),
	(9598, 419, 0, 7, 12, 0, 6, 7, 430, NULL, 'Momentinė 8-os harmonikos įtampa', 3471, 6, NULL, NULL),
	(9599, 420, 0, 7, 6, 0, 6, 7, 431, NULL, 'Momentinė 2-os harmonikos įtampa L1 fazėje', 3472, 6, NULL, NULL),
	(9600, 420, 0, 7, 7, 0, 6, 7, 431, NULL, 'Momentinė 3-os harmonikos įtampa L1 fazėje', 3473, 6, NULL, NULL),
	(9601, 420, 0, 7, 8, 0, 6, 7, 431, NULL, 'Momentinė 4-os harmonikos įtampa L1 fazėje', 3474, 6, NULL, NULL),
	(9602, 420, 0, 7, 9, 0, 6, 7, 431, NULL, 'Momentinė 5-os harmonikos įtampa L1 fazėje', 3475, 6, NULL, NULL),
	(9603, 420, 0, 7, 10, 0, 6, 7, 431, NULL, 'Momentinė 6-os harmonikos įtampa L1 fazėje', 3476, 6, NULL, NULL),
	(9604, 420, 0, 7, 11, 0, 6, 7, 431, NULL, 'Momentinė 7-os harmonikos įtampa L1 fazėje', 3477, 6, NULL, NULL),
	(9605, 420, 0, 7, 12, 0, 6, 7, 431, NULL, 'Momentinė 8-os harmonikos įtampa L1 fazėje', 3478, 6, NULL, NULL),
	(9606, 421, 0, 7, 6, 0, 6, 7, 432, NULL, 'Momentinė 2-os harmonikos įtampa L2 fazėje', 3479, 6, NULL, NULL),
	(9607, 421, 0, 7, 7, 0, 6, 7, 432, NULL, 'Momentinė 3-os harmonikos įtampa L2 fazėje', 3480, 6, NULL, NULL),
	(9608, 421, 0, 7, 8, 0, 6, 7, 432, NULL, 'Momentinė 4-os harmonikos įtampa L2 fazėje', 3481, 6, NULL, NULL),
	(9609, 421, 0, 7, 9, 0, 6, 7, 432, NULL, 'Momentinė 5-os harmonikos įtampa L2 fazėje', 3482, 6, NULL, NULL),
	(9610, 421, 0, 7, 10, 0, 6, 7, 432, NULL, 'Momentinė 6-os harmonikos įtampa L2 fazėje', 3483, 6, NULL, NULL),
	(9611, 421, 0, 7, 11, 0, 6, 7, 432, NULL, 'Momentinė 7-os harmonikos įtampa L2 fazėje', 3484, 6, NULL, NULL),
	(9612, 421, 0, 7, 12, 0, 6, 7, 432, NULL, 'Momentinė 8-os harmonikos įtampa L2 fazėje', 3485, 6, NULL, NULL),
	(9613, 422, 0, 7, 6, 0, 6, 7, 433, NULL, 'Momentinė 2-os harmonikos įtampa L3 fazėje', 3486, 6, NULL, NULL),
	(9614, 422, 0, 7, 7, 0, 6, 7, 433, NULL, 'Momentinė 3-os harmonikos įtampa L3 fazėje', 3487, 6, NULL, NULL),
	(9615, 422, 0, 7, 8, 0, 6, 7, 433, NULL, 'Momentinė 4-os harmonikos įtampa L3 fazėje', 3488, 6, NULL, NULL),
	(9616, 422, 0, 7, 9, 0, 6, 7, 433, NULL, 'Momentinė 5-os harmonikos įtampa L3 fazėje', 3489, 6, NULL, NULL),
	(9617, 422, 0, 7, 10, 0, 6, 7, 433, NULL, 'Momentinė 6-os harmonikos įtampa L3 fazėje', 3490, 6, NULL, NULL),
	(9618, 422, 0, 7, 11, 0, 6, 7, 433, NULL, 'Momentinė 7-os harmonikos įtampa L3 fazėje', 3491, 6, NULL, NULL),
	(9619, 422, 0, 7, 12, 0, 6, 7, 433, NULL, 'Momentinė 8-os harmonikos įtampa L3 fazėje', 3492, 6, NULL, NULL),
	(9620, 189, 1, 8, 2, 1, 2, 7, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 1 tarifą', 3493, 5, NULL, NULL),
	(9621, 189, 1, 8, 2, 2, 2, 7, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 2 tarifą', 3494, 5, NULL, NULL),
	(9622, 189, 1, 8, 2, 3, 2, 7, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 3 tarifą', 3495, 5, NULL, NULL),
	(9623, 189, 1, 8, 2, 4, 2, 7, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 4 tarifą', 3496, 5, NULL, NULL),
	(9624, 189, 2, 8, 2, 1, 2, 7, 202, NULL, 'Suminė A- energija L1 fazėje pagal 1 tarifą', 3497, 5, NULL, NULL),
	(9625, 189, 2, 8, 2, 2, 2, 7, 202, NULL, 'Suminė A- energija L1 fazėje pagal 2 tarifą', 3498, 5, NULL, NULL),
	(9626, 189, 2, 8, 2, 3, 2, 7, 202, NULL, 'Suminė A- energija L1 fazėje pagal 3 tarifą', 3499, 5, NULL, NULL),
	(9627, 189, 2, 8, 2, 4, 2, 7, 202, NULL, 'Suminė A- energija L1 fazėje pagal 4 tarifą', 3500, 5, NULL, NULL),
	(9628, 193, 1, 8, 2, 1, 4, 7, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 1 tarifą', 3501, 5, NULL, NULL),
	(9629, 193, 1, 8, 2, 2, 4, 7, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 2 tarifą', 3502, 5, NULL, NULL),
	(9630, 193, 1, 8, 2, 3, 4, 7, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 3 tarifą', 3503, 5, NULL, NULL),
	(9631, 193, 1, 8, 2, 4, 4, 7, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 4 tarifą', 3504, 5, NULL, NULL),
	(9632, 193, 2, 8, 2, 1, 4, 7, 205, NULL, 'Suminė R- energija L1 fazėje pagal 1 tarifą', 3505, 5, NULL, NULL),
	(9633, 193, 2, 8, 2, 2, 4, 7, 205, NULL, 'Suminė R- energija L1 fazėje pagal 2 tarifą', 3506, 5, NULL, NULL),
	(9634, 193, 2, 8, 2, 3, 4, 7, 205, NULL, 'Suminė R- energija L1 fazėje pagal 3 tarifą', 3507, 5, NULL, NULL),
	(9635, 193, 2, 8, 2, 4, 4, 7, 205, NULL, 'Suminė R- energija L1 fazėje pagal 4 tarifą', 3508, 5, NULL, NULL),
	(9636, 193, 5, 8, 2, 1, 4, 7, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 1 tarifą', 3509, 5, NULL, NULL),
	(9637, 193, 5, 8, 2, 2, 4, 7, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 2 tarifą', 3510, 5, NULL, NULL),
	(9638, 193, 5, 8, 2, 3, 4, 7, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 3 tarifą', 3511, 5, NULL, NULL),
	(9639, 193, 5, 8, 2, 4, 4, 7, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 4 tarifą', 3512, 5, NULL, NULL),
	(9640, 193, 6, 8, 2, 1, 4, 7, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 1 tarifą', 3513, 5, NULL, NULL),
	(9641, 193, 6, 8, 2, 2, 4, 7, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 2 tarifą', 3514, 5, NULL, NULL),
	(9642, 193, 6, 8, 2, 3, 4, 7, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 3 tarifą', 3515, 5, NULL, NULL),
	(9643, 193, 6, 8, 2, 4, 4, 7, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 4 tarifą', 3516, 5, NULL, NULL),
	(9644, 193, 7, 8, 2, 1, 4, 7, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 1 tarifą', 3517, 5, NULL, NULL),
	(9645, 193, 7, 8, 2, 2, 4, 7, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 2 tarifą', 3518, 5, NULL, NULL),
	(9646, 193, 7, 8, 2, 3, 4, 7, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 3 tarifą', 3519, 5, NULL, NULL),
	(9647, 193, 7, 8, 2, 4, 4, 7, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 4 tarifą', 3520, 5, NULL, NULL),
	(9648, 193, 8, 8, 2, 1, 4, 7, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 1 tarifą', 3521, 5, NULL, NULL),
	(9649, 193, 8, 8, 2, 2, 4, 7, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 2 tarifą', 3522, 5, NULL, NULL),
	(9650, 193, 8, 8, 2, 3, 4, 7, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 3 tarifą', 3523, 5, NULL, NULL),
	(9651, 193, 8, 8, 2, 4, 4, 7, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 4 tarifą', 3524, 5, NULL, NULL),
	(9652, 196, 1, 8, 2, 0, 41, 7, 208, NULL, 'Suminė W+ energija L1 fazėje', 3525, 5, NULL, NULL),
	(9653, 196, 1, 8, 2, 1, 41, 7, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 1 tarifą', 3526, 5, NULL, NULL),
	(9654, 196, 1, 8, 2, 2, 41, 7, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 2 tarifą', 3527, 5, NULL, NULL),
	(9655, 196, 1, 8, 2, 3, 41, 7, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 3 tarifą', 3528, 5, NULL, NULL),
	(9656, 196, 1, 8, 2, 4, 41, 7, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 4 tarifą', 3529, 5, NULL, NULL),
	(9657, 196, 2, 8, 2, 0, 41, 7, 208, NULL, 'Suminė W- energija L1 fazėje', 3530, 5, NULL, NULL),
	(9658, 196, 2, 8, 2, 1, 41, 7, 208, NULL, 'Suminė W- energija L1 fazėje pagal 1 tarifą', 3531, 5, NULL, NULL),
	(9659, 196, 2, 8, 2, 2, 41, 7, 208, NULL, 'Suminė W- energija L1 fazėje pagal 2 tarifą', 3532, 5, NULL, NULL),
	(9660, 196, 2, 8, 2, 3, 41, 7, 208, NULL, 'Suminė W- energija L1 fazėje pagal 3 tarifą', 3533, 5, NULL, NULL),
	(9661, 196, 2, 8, 2, 4, 41, 7, 208, NULL, 'Suminė W- energija L1 fazėje pagal 4 tarifą', 3534, 5, NULL, NULL),
	(9662, 190, 1, 8, 2, 1, 2, 7, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 1 tarifą', 3535, 5, NULL, NULL),
	(9663, 190, 1, 8, 2, 2, 2, 7, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 2 tarifą', 3536, 5, NULL, NULL),
	(9664, 190, 1, 8, 2, 3, 2, 7, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 3 tarifą', 3537, 5, NULL, NULL),
	(9665, 190, 1, 8, 2, 4, 2, 7, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 4 tarifą', 3538, 5, NULL, NULL),
	(9666, 190, 2, 8, 2, 1, 2, 7, 203, NULL, 'Suminė A- energija L2 fazėje pagal 1 tarifą', 3539, 5, NULL, NULL),
	(9667, 190, 2, 8, 2, 2, 2, 7, 203, NULL, 'Suminė A- energija L2 fazėje pagal 2 tarifą', 3540, 5, NULL, NULL),
	(9668, 190, 2, 8, 2, 3, 2, 7, 203, NULL, 'Suminė A- energija L2 fazėje pagal 3 tarifą', 3541, 5, NULL, NULL),
	(9669, 190, 2, 8, 2, 4, 2, 7, 203, NULL, 'Suminė A- energija L2 fazėje pagal 4 tarifą', 3542, 5, NULL, NULL),
	(9670, 194, 1, 8, 2, 1, 4, 7, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 1 tarifą', 3543, 5, NULL, NULL),
	(9671, 194, 1, 8, 2, 2, 4, 7, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 2 tarifą', 3544, 5, NULL, NULL),
	(9672, 194, 1, 8, 2, 3, 4, 7, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 3 tarifą', 3545, 5, NULL, NULL),
	(9673, 194, 1, 8, 2, 4, 4, 7, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 4 tarifą', 3546, 5, NULL, NULL),
	(9674, 194, 2, 8, 2, 1, 4, 7, 206, NULL, 'Suminė R- energija L2 fazėje pagal 1 tarifą', 3547, 5, NULL, NULL),
	(9675, 194, 2, 8, 2, 2, 4, 7, 206, NULL, 'Suminė R- energija L2 fazėje pagal 2 tarifą', 3548, 5, NULL, NULL),
	(9676, 194, 2, 8, 2, 3, 4, 7, 206, NULL, 'Suminė R- energija L2 fazėje pagal 3 tarifą', 3549, 5, NULL, NULL),
	(9677, 194, 2, 8, 2, 4, 4, 7, 206, NULL, 'Suminė R- energija L2 fazėje pagal 4 tarifą', 3550, 5, NULL, NULL),
	(9678, 194, 5, 8, 2, 1, 4, 7, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 1 tarifą', 3551, 5, NULL, NULL),
	(9679, 194, 5, 8, 2, 2, 4, 7, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 2 tarifą', 3552, 5, NULL, NULL),
	(9680, 194, 5, 8, 2, 3, 4, 7, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 3 tarifą', 3553, 5, NULL, NULL),
	(9681, 194, 5, 8, 2, 4, 4, 7, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 4 tarifą', 3554, 5, NULL, NULL),
	(9682, 194, 6, 8, 2, 1, 4, 7, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 1 tarifą', 3555, 5, NULL, NULL),
	(9683, 194, 6, 8, 2, 2, 4, 7, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 2 tarifą', 3556, 5, NULL, NULL),
	(9684, 194, 6, 8, 2, 3, 4, 7, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 3 tarifą', 3557, 5, NULL, NULL),
	(9685, 194, 6, 8, 2, 4, 4, 7, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 4 tarifą', 3558, 5, NULL, NULL),
	(9686, 194, 7, 8, 2, 1, 4, 7, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 1 tarifą', 3559, 5, NULL, NULL),
	(9687, 194, 7, 8, 2, 2, 4, 7, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 2 tarifą', 3560, 5, NULL, NULL),
	(9688, 194, 7, 8, 2, 3, 4, 7, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 3 tarifą', 3561, 5, NULL, NULL),
	(9689, 194, 7, 8, 2, 4, 4, 7, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 4 tarifą', 3562, 5, NULL, NULL),
	(9690, 194, 8, 8, 2, 1, 4, 7, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 1 tarifą', 3563, 5, NULL, NULL),
	(9691, 194, 8, 8, 2, 2, 4, 7, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 2 tarifą', 3564, 5, NULL, NULL),
	(9692, 194, 8, 8, 2, 3, 4, 7, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 3 tarifą', 3565, 5, NULL, NULL),
	(9693, 194, 8, 8, 2, 4, 4, 7, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 4 tarifą', 3566, 5, NULL, NULL),
	(9694, 197, 1, 8, 2, 0, 41, 7, 209, NULL, 'Suminė W+ energija L2 fazėje', 3567, 5, NULL, NULL),
	(9695, 197, 1, 8, 2, 1, 41, 7, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 1 tarifą', 3568, 5, NULL, NULL),
	(9696, 197, 1, 8, 2, 2, 41, 7, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 2 tarifą ', 3569, 5, NULL, NULL),
	(9697, 197, 1, 8, 2, 3, 41, 7, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 3 tarifą', 3570, 5, NULL, NULL),
	(9698, 197, 1, 8, 2, 4, 41, 7, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 4 tarifą', 3571, 5, NULL, NULL),
	(9699, 197, 2, 8, 2, 0, 41, 7, 209, NULL, 'Suminė W- energija L2 fazėje', 3572, 5, NULL, NULL),
	(9700, 197, 2, 8, 2, 1, 41, 7, 209, NULL, 'Suminė W- energija L2 fazėje pagal 1 tarifą', 3573, 5, NULL, NULL),
	(9701, 197, 2, 8, 2, 2, 41, 7, 209, NULL, 'Suminė W- energija L2 fazėje pagal 2 tarifą ', 3574, 5, NULL, NULL),
	(9702, 197, 2, 8, 2, 3, 41, 7, 209, NULL, 'Suminė W- energija L2 fazėje pagal 3 tarifą', 3575, 5, NULL, NULL),
	(9703, 197, 2, 8, 2, 4, 41, 7, 209, NULL, 'Suminė W- energija L2 fazėje pagal 4 tarifą', 3576, 5, NULL, NULL),
	(9704, 191, 1, 8, 2, 1, 2, 7, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 1 tarifą', 3577, 5, NULL, NULL),
	(9705, 191, 1, 8, 2, 2, 2, 7, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 2 tarifą ', 3578, 5, NULL, NULL),
	(9706, 191, 1, 8, 2, 3, 2, 7, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 3 tarifą', 3579, 5, NULL, NULL),
	(9707, 191, 1, 8, 2, 4, 2, 7, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 4 tarifą', 3580, 5, NULL, NULL),
	(9708, 191, 2, 8, 2, 1, 2, 7, 204, NULL, 'Suminė A- energija L3 fazėje pagal 1 tarifą', 3581, 5, NULL, NULL),
	(9709, 191, 2, 8, 2, 2, 2, 7, 204, NULL, 'Suminė A- energija L3 fazėje pagal 2 tarifą ', 3582, 5, NULL, NULL),
	(9710, 191, 2, 8, 2, 3, 2, 7, 204, NULL, 'Suminė A- energija L3 fazėje pagal 3 tarifą', 3583, 5, NULL, NULL),
	(9711, 191, 2, 8, 2, 4, 2, 7, 204, NULL, 'Suminė A- energija L3 fazėje pagal 4 tarifą', 3584, 5, NULL, NULL),
	(9712, 195, 1, 8, 2, 1, 4, 7, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 1 tarifą', 3585, 5, NULL, NULL),
	(9713, 195, 1, 8, 2, 2, 4, 7, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 2 tarifą ', 3586, 5, NULL, NULL),
	(9714, 195, 1, 8, 2, 3, 4, 7, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 3 tarifą', 3587, 5, NULL, NULL),
	(9715, 195, 1, 8, 2, 4, 4, 7, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 4 tarifą', 3588, 5, NULL, NULL),
	(9716, 195, 2, 8, 2, 1, 4, 7, 207, NULL, 'Suminė R- energija L3 fazėje pagal 1 tarifą', 3589, 5, NULL, NULL),
	(9717, 195, 2, 8, 2, 2, 4, 7, 207, NULL, 'Suminė R- energija L3 fazėje pagal 2 tarifą ', 3590, 5, NULL, NULL),
	(9718, 195, 2, 8, 2, 3, 4, 7, 207, NULL, 'Suminė R- energija L3 fazėje pagal 3 tarifą', 3591, 5, NULL, NULL),
	(9719, 195, 2, 8, 2, 4, 4, 7, 207, NULL, 'Suminė R- energija L3 fazėje pagal 4 tarifą', 3592, 5, NULL, NULL),
	(9720, 195, 5, 8, 2, 1, 4, 7, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 1 tarifą', 3593, 5, NULL, NULL),
	(9721, 195, 5, 8, 2, 2, 4, 7, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 2 tarifą ', 3594, 5, NULL, NULL),
	(9722, 195, 5, 8, 2, 3, 4, 7, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 3 tarifą', 3595, 5, NULL, NULL),
	(9723, 195, 5, 8, 2, 4, 4, 7, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 4 tarifą', 3596, 5, NULL, NULL),
	(9724, 195, 6, 8, 2, 1, 4, 7, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 1 tarifą', 3597, 5, NULL, NULL),
	(9725, 195, 6, 8, 2, 2, 4, 7, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 2 tarifą ', 3598, 5, NULL, NULL),
	(9726, 195, 6, 8, 2, 3, 4, 7, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 3 tarifą', 3599, 5, NULL, NULL),
	(9727, 195, 6, 8, 2, 4, 4, 7, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 4 tarifą', 3600, 5, NULL, NULL),
	(9728, 195, 7, 8, 2, 1, 4, 7, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 1 tarifą', 3601, 5, NULL, NULL),
	(9729, 195, 7, 8, 2, 2, 4, 7, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 2 tarifą ', 3602, 5, NULL, NULL),
	(9730, 195, 7, 8, 2, 3, 4, 7, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 3 tarifą', 3603, 5, NULL, NULL),
	(9731, 195, 7, 8, 2, 4, 4, 7, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 4 tarifą', 3604, 5, NULL, NULL),
	(9732, 195, 8, 8, 2, 1, 4, 7, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 1 tarifą', 3605, 5, NULL, NULL),
	(9733, 195, 8, 8, 2, 2, 4, 7, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 2 tarifą ', 3606, 5, NULL, NULL),
	(9734, 195, 8, 8, 2, 3, 4, 7, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 3 tarifą', 3607, 5, NULL, NULL),
	(9735, 195, 8, 8, 2, 4, 4, 7, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 4 tarifą', 3608, 5, NULL, NULL),
	(9736, 198, 1, 8, 2, 0, 41, 7, 210, NULL, 'Suminė W+ energija L3 fazėje', 3609, 5, NULL, NULL),
	(9737, 198, 1, 8, 2, 1, 41, 7, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 1 tarifą', 3610, 5, NULL, NULL),
	(9738, 198, 1, 8, 2, 2, 41, 7, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 2 tarifą ', 3611, 5, NULL, NULL),
	(9739, 198, 1, 8, 2, 3, 41, 7, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 3 tarifą', 3612, 5, NULL, NULL),
	(9740, 198, 1, 8, 2, 4, 41, 7, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 4 tarifą', 3613, 5, NULL, NULL),
	(9741, 198, 2, 8, 2, 0, 41, 7, 210, NULL, 'Suminė W- energija L3 fazėje', 3614, 5, NULL, NULL),
	(9742, 198, 2, 8, 2, 1, 41, 7, 210, NULL, 'Suminė W- energija L3 fazėje pagal 1 tarifą', 3615, 5, NULL, NULL),
	(9743, 198, 2, 8, 2, 2, 41, 7, 210, NULL, 'Suminė W- energija L3 fazėje pagal 2 tarifą ', 3616, 5, NULL, NULL),
	(9744, 198, 2, 8, 2, 3, 41, 7, 210, NULL, 'Suminė W- energija L3 fazėje pagal 3 tarifą', 3617, 5, NULL, NULL),
	(9745, 198, 2, 8, 2, 4, 41, 7, 210, NULL, 'Suminė W- energija L3 fazėje pagal 4 tarifą', 3618, 5, NULL, NULL),
	(9746, 189, 1, 6, 2, 0, 2, 6, 202, NULL, 'A+ energija L1 fazėje per mėnesį', 3619, 4, NULL, NULL),
	(9747, 189, 1, 6, 2, 1, 2, 6, 202, NULL, 'A+ energija L1 fazėje pagal 1 tarifą per mėnesį', 3620, 4, NULL, NULL),
	(9748, 189, 1, 6, 2, 2, 2, 6, 202, NULL, 'A+ energija L1 fazėje pagal 2 tarifą per mėnesį', 3621, 4, NULL, NULL),
	(9749, 189, 1, 6, 2, 3, 2, 6, 202, NULL, 'A+ energija L1 fazėje pagal 3 tarifą per mėnesį', 3622, 4, NULL, NULL),
	(9750, 189, 1, 6, 2, 4, 2, 6, 202, NULL, 'A+ energija L1 fazėje pagal 4 tarifą per mėnesį', 3623, 4, NULL, NULL),
	(9751, 189, 2, 6, 2, 0, 2, 6, 202, NULL, 'A- energija L1 fazėje per mėnesį', 3624, 4, NULL, NULL),
	(9752, 189, 2, 6, 2, 1, 2, 6, 202, NULL, 'A- energija L1 fazėje pagal 1 tarifą per mėnesį', 3625, 4, NULL, NULL),
	(9753, 189, 2, 6, 2, 2, 2, 6, 202, NULL, 'A- energija L1 fazėje pagal 2 tarifą per mėnesį', 3626, 4, NULL, NULL),
	(9754, 189, 2, 6, 2, 3, 2, 6, 202, NULL, 'A- energija L1 fazėje pagal 3 tarifą per mėnesį', 3627, 4, NULL, NULL),
	(9755, 189, 2, 6, 2, 4, 2, 6, 202, NULL, 'A- energija L1 fazėje pagal 4 tarifą per mėnesį', 3628, 4, NULL, NULL),
	(9756, 193, 1, 6, 2, 0, 4, 6, 205, NULL, 'R+ energija L1 fazėje per mėnesį', 3629, 4, NULL, NULL),
	(9757, 193, 1, 6, 2, 1, 4, 6, 205, NULL, 'R+ energija L1 fazėje pagal 1 tarifą per mėnesį', 3630, 4, NULL, NULL),
	(9758, 193, 1, 6, 2, 2, 4, 6, 205, NULL, 'R+ energija L1 fazėje pagal 2 tarifą per mėnesį', 3631, 4, NULL, NULL),
	(9759, 193, 1, 6, 2, 3, 4, 6, 205, NULL, 'R+ energija L1 fazėje pagal 3 tarifą per mėnesį', 3632, 4, NULL, NULL),
	(9760, 193, 1, 6, 2, 4, 4, 6, 205, NULL, 'R+ energija L1 fazėje pagal 4 tarifą per mėnesį', 3633, 4, NULL, NULL),
	(9761, 193, 2, 6, 2, 0, 4, 6, 205, NULL, 'R- energija L1 fazėje per mėnesį', 3634, 4, NULL, NULL),
	(9762, 193, 2, 6, 2, 1, 4, 6, 205, NULL, 'R- energija L1 fazėje pagal 1 tarifą per mėnesį', 3635, 4, NULL, NULL),
	(9763, 193, 2, 6, 2, 2, 4, 6, 205, NULL, 'R- energija L1 fazėje pagal 2 tarifą per mėnesį', 3636, 4, NULL, NULL),
	(9764, 193, 2, 6, 2, 3, 4, 6, 205, NULL, 'R- energija L1 fazėje pagal 3 tarifą per mėnesį', 3637, 4, NULL, NULL),
	(9765, 193, 2, 6, 2, 4, 4, 6, 205, NULL, 'R- energija L1 fazėje pagal 4 tarifą per mėnesį', 3638, 4, NULL, NULL),
	(9766, 193, 5, 6, 2, 0, 4, 6, 205, NULL, 'R1 energija L1 fazėje per mėnesį', 3639, 4, NULL, NULL),
	(9767, 193, 5, 6, 2, 1, 4, 6, 205, NULL, 'R1 energija L1 fazėje pagal 1 tarifą per mėnesį', 3640, 4, NULL, NULL),
	(9768, 193, 5, 6, 2, 2, 4, 6, 205, NULL, 'R1 energija L1 fazėje pagal 2 tarifą per mėnesį', 3641, 4, NULL, NULL),
	(9769, 193, 5, 6, 2, 3, 4, 6, 205, NULL, 'R1 energija L1 fazėje pagal 3 tarifą per mėnesį', 3642, 4, NULL, NULL),
	(9770, 193, 5, 6, 2, 4, 4, 6, 205, NULL, 'R1 energija L1 fazėje pagal 4 tarifą per mėnesį', 3643, 4, NULL, NULL),
	(9771, 193, 6, 6, 2, 0, 4, 6, 205, NULL, 'R2 energija L1 fazėje per mėnesį', 3644, 4, NULL, NULL),
	(9772, 193, 6, 6, 2, 1, 4, 6, 205, NULL, 'R2 energija L1 fazėje pagal 1 tarifą per mėnesį', 3645, 4, NULL, NULL),
	(9773, 193, 6, 6, 2, 2, 4, 6, 205, NULL, 'R2 energija L1 fazėje pagal 2 tarifą per mėnesį', 3646, 4, NULL, NULL),
	(9774, 193, 6, 6, 2, 3, 4, 6, 205, NULL, 'R2 energija L1 fazėje pagal 3 tarifą per mėnesį', 3647, 4, NULL, NULL),
	(9775, 193, 6, 6, 2, 4, 4, 6, 205, NULL, 'R2 energija L1 fazėje pagal 4 tarifą per mėnesį', 3648, 4, NULL, NULL),
	(9776, 193, 7, 6, 2, 0, 4, 6, 205, NULL, 'R3 energija L1 fazėje per mėnesį', 3649, 4, NULL, NULL),
	(9777, 193, 7, 6, 2, 1, 4, 6, 205, NULL, 'R3 energija L1 fazėje pagal 1 tarifą per mėnesį', 3650, 4, NULL, NULL),
	(9778, 193, 7, 6, 2, 2, 4, 6, 205, NULL, 'R3 energija L1 fazėje pagal 2 tarifą per mėnesį', 3651, 4, NULL, NULL),
	(9779, 193, 7, 6, 2, 3, 4, 6, 205, NULL, 'R3 energija L1 fazėje pagal 3 tarifą per mėnesį', 3652, 4, NULL, NULL),
	(9780, 193, 7, 6, 2, 4, 4, 6, 205, NULL, 'R3 energija L1 fazėje pagal 4 tarifą per mėnesį', 3653, 4, NULL, NULL),
	(9781, 193, 8, 6, 2, 0, 4, 6, 205, NULL, 'R4 energija L1 fazėje per mėnesį', 3654, 4, NULL, NULL),
	(9782, 193, 8, 6, 2, 1, 4, 6, 205, NULL, 'R4 energija L1 fazėje pagal 1 tarifą per mėnesį', 3655, 4, NULL, NULL),
	(9783, 193, 8, 6, 2, 2, 4, 6, 205, NULL, 'R4 energija L1 fazėje pagal 2 tarifą per mėnesį', 3656, 4, NULL, NULL),
	(9784, 193, 8, 6, 2, 3, 4, 6, 205, NULL, 'R4 energija L1 fazėje pagal 3 tarifą per mėnesį', 3657, 4, NULL, NULL),
	(9785, 193, 8, 6, 2, 4, 4, 6, 205, NULL, 'R4 energija L1 fazėje pagal 4 tarifą per mėnesį', 3658, 4, NULL, NULL),
	(9786, 196, 1, 6, 2, 0, 41, 6, 208, NULL, 'W+ energija L1 fazėje per mėnesį', 3659, 4, NULL, NULL),
	(9787, 196, 1, 6, 2, 1, 41, 6, 208, NULL, 'W+ energija L1 fazėje pagal 1 tarifą per mėnesį', 3660, 4, NULL, NULL),
	(9788, 196, 1, 6, 2, 2, 41, 6, 208, NULL, 'W+ energija L1 fazėje pagal 2 tarifą per mėnesį', 3661, 4, NULL, NULL),
	(9789, 196, 1, 6, 2, 3, 41, 6, 208, NULL, 'W+ energija L1 fazėje pagal 3 tarifą per mėnesį', 3662, 4, NULL, NULL),
	(9790, 196, 1, 6, 2, 4, 41, 6, 208, NULL, 'W+ energija L1 fazėje pagal 4 tarifą per mėnesį', 3663, 4, NULL, NULL),
	(9791, 196, 2, 6, 2, 0, 41, 6, 208, NULL, 'W- energija L1 fazėje per mėnesį', 3664, 4, NULL, NULL),
	(9792, 196, 2, 6, 2, 1, 41, 6, 208, NULL, 'W- energija L1 fazėje pagal 1 tarifą per mėnesį', 3665, 4, NULL, NULL),
	(9793, 196, 2, 6, 2, 2, 41, 6, 208, NULL, 'W- energija L1 fazėje pagal 2 tarifą per mėnesį', 3666, 4, NULL, NULL),
	(9794, 196, 2, 6, 2, 3, 41, 6, 208, NULL, 'W- energija L1 fazėje pagal 3 tarifą per mėnesį', 3667, 4, NULL, NULL),
	(9795, 196, 2, 6, 2, 4, 41, 6, 208, NULL, 'W- energija L1 fazėje pagal 4 tarifą per mėnesį', 3668, 4, NULL, NULL),
	(9796, 190, 1, 6, 2, 0, 2, 6, 203, NULL, 'A+ energija L2 fazėje per mėnesį', 3669, 4, NULL, NULL),
	(9797, 190, 1, 6, 2, 1, 2, 6, 203, NULL, 'A+ energija L2 fazėje pagal 1 tarifą per mėnesį', 3670, 4, NULL, NULL),
	(9798, 190, 1, 6, 2, 2, 2, 6, 203, NULL, 'A+ energija L2 fazėje pagal 2 tarifą per mėnesį', 3671, 4, NULL, NULL),
	(9799, 190, 1, 6, 2, 3, 2, 6, 203, NULL, 'A+ energija L2 fazėje pagal 3 tarifą per mėnesį', 3672, 4, NULL, NULL),
	(9800, 190, 1, 6, 2, 4, 2, 6, 203, NULL, 'A+ energija L2 fazėje pagal 4 tarifą per mėnesį', 3673, 4, NULL, NULL),
	(9801, 190, 2, 6, 2, 0, 2, 6, 203, NULL, 'A- energija L2 fazėje per mėnesį', 3674, 4, NULL, NULL),
	(9802, 190, 2, 6, 2, 1, 2, 6, 203, NULL, 'A- energija L2 fazėje pagal 1 tarifą per mėnesį', 3675, 4, NULL, NULL),
	(9803, 190, 2, 6, 2, 2, 2, 6, 203, NULL, 'A- energija L2 fazėje pagal 2 tarifą per mėnesį', 3676, 4, NULL, NULL),
	(9804, 190, 2, 6, 2, 3, 2, 6, 203, NULL, 'A- energija L2 fazėje pagal 3 tarifą per mėnesį', 3677, 4, NULL, NULL),
	(9805, 190, 2, 6, 2, 4, 2, 6, 203, NULL, 'A- energija L2 fazėje pagal 4 tarifą per mėnesį', 3678, 4, NULL, NULL),
	(9806, 194, 1, 6, 2, 0, 4, 6, 206, NULL, 'R+ energija L2 fazėje per mėnesį', 3679, 4, NULL, NULL),
	(9807, 194, 1, 6, 2, 1, 4, 6, 206, NULL, 'R+ energija L2 fazėje pagal 1 tarifą per mėnesį', 3680, 4, NULL, NULL),
	(9808, 194, 1, 6, 2, 2, 4, 6, 206, NULL, 'R+ energija L2 fazėje pagal 2 tarifą per mėnesį', 3681, 4, NULL, NULL),
	(9809, 194, 1, 6, 2, 3, 4, 6, 206, NULL, 'R+ energija L2 fazėje pagal 3 tarifą per mėnesį', 3682, 4, NULL, NULL),
	(9810, 194, 1, 6, 2, 4, 4, 6, 206, NULL, 'R+ energija L2 fazėje pagal 4 tarifą per mėnesį', 3683, 4, NULL, NULL),
	(9811, 194, 2, 6, 2, 0, 4, 6, 206, NULL, 'R- energija L2 fazėje per mėnesį', 3684, 4, NULL, NULL),
	(9812, 194, 2, 6, 2, 1, 4, 6, 206, NULL, 'R- energija L2 fazėje pagal 1 tarifą per mėnesį', 3685, 4, NULL, NULL),
	(9813, 194, 2, 6, 2, 2, 4, 6, 206, NULL, 'R- energija L2 fazėje pagal 2 tarifą per mėnesį', 3686, 4, NULL, NULL),
	(9814, 194, 2, 6, 2, 3, 4, 6, 206, NULL, 'R- energija L2 fazėje pagal 3 tarifą per mėnesį', 3687, 4, NULL, NULL),
	(9815, 194, 2, 6, 2, 4, 4, 6, 206, NULL, 'R- energija L2 fazėje pagal 4 tarifą per mėnesį', 3688, 4, NULL, NULL),
	(9816, 194, 5, 6, 2, 0, 4, 6, 206, NULL, 'R1 energija L2 fazėje per mėnesį', 3689, 4, NULL, NULL),
	(9817, 194, 5, 6, 2, 1, 4, 6, 206, NULL, 'R1 energija L2 fazėje pagal 1 tarifą per mėnesį', 3690, 4, NULL, NULL),
	(9818, 194, 5, 6, 2, 2, 4, 6, 206, NULL, 'R1 energija L2 fazėje pagal 2 tarifą per mėnesį', 3691, 4, NULL, NULL),
	(9819, 194, 5, 6, 2, 3, 4, 6, 206, NULL, 'R1 energija L2 fazėje pagal 3 tarifą per mėnesį', 3692, 4, NULL, NULL),
	(9820, 194, 5, 6, 2, 4, 4, 6, 206, NULL, 'R1 energija L2 fazėje pagal 4 tarifą per mėnesį', 3693, 4, NULL, NULL),
	(9821, 194, 6, 6, 2, 0, 4, 6, 206, NULL, 'R2 energija L2 fazėje per mėnesį', 3694, 4, NULL, NULL),
	(9822, 194, 6, 6, 2, 1, 4, 6, 206, NULL, 'R2 energija L2 fazėje pagal 1 tarifą per mėnesį', 3695, 4, NULL, NULL),
	(9823, 194, 6, 6, 2, 2, 4, 6, 206, NULL, 'R2 energija L2 fazėje pagal 2 tarifą per mėnesį', 3696, 4, NULL, NULL),
	(9824, 194, 6, 6, 2, 3, 4, 6, 206, NULL, 'R2 energija L2 fazėje pagal 3 tarifą per mėnesį', 3697, 4, NULL, NULL),
	(9825, 194, 6, 6, 2, 4, 4, 6, 206, NULL, 'R2 energija L2 fazėje pagal 4 tarifą per mėnesį', 3698, 4, NULL, NULL),
	(9826, 194, 7, 6, 2, 0, 4, 6, 206, NULL, 'R3 energija L2 fazėje per mėnesį', 3699, 4, NULL, NULL),
	(9827, 194, 7, 6, 2, 1, 4, 6, 206, NULL, 'R3 energija L2 fazėje pagal 1 tarifą per mėnesį', 3700, 4, NULL, NULL),
	(9828, 194, 7, 6, 2, 2, 4, 6, 206, NULL, 'R3 energija L2 fazėje pagal 2 tarifą per mėnesį', 3701, 4, NULL, NULL),
	(9829, 194, 7, 6, 2, 3, 4, 6, 206, NULL, 'R3 energija L2 fazėje pagal 3 tarifą per mėnesį', 3702, 4, NULL, NULL),
	(9830, 194, 7, 6, 2, 4, 4, 6, 206, NULL, 'R3 energija L2 fazėje pagal 4 tarifą per mėnesį', 3703, 4, NULL, NULL),
	(9831, 194, 8, 6, 2, 0, 4, 6, 206, NULL, 'R4 energija L2 fazėje per mėnesį', 3704, 4, NULL, NULL),
	(9832, 194, 8, 6, 2, 1, 4, 6, 206, NULL, 'R4 energija L2 fazėje pagal 1 tarifą per mėnesį', 3705, 4, NULL, NULL),
	(9833, 194, 8, 6, 2, 2, 4, 6, 206, NULL, 'R4 energija L2 fazėje pagal 2 tarifą per mėnesį', 3706, 4, NULL, NULL),
	(9834, 194, 8, 6, 2, 3, 4, 6, 206, NULL, 'R4 energija L2 fazėje pagal 3 tarifą per mėnesį', 3707, 4, NULL, NULL),
	(9835, 194, 8, 6, 2, 4, 4, 6, 206, NULL, 'R4 energija L2 fazėje pagal 4 tarifą per mėnesį', 3708, 4, NULL, NULL),
	(9836, 197, 1, 6, 2, 0, 41, 6, 209, NULL, 'W+ energija L2 fazėje per mėnesį', 3709, 4, NULL, NULL),
	(9837, 197, 1, 6, 2, 1, 41, 6, 209, NULL, 'W+ energija L2 fazėje pagal 1 tarifą per mėnesį', 3710, 4, NULL, NULL),
	(9838, 197, 1, 6, 2, 2, 41, 6, 209, NULL, 'W+ energija L2 fazėje pagal 2 tarifą per mėnesį', 3711, 4, NULL, NULL),
	(9839, 197, 1, 6, 2, 3, 41, 6, 209, NULL, 'W+ energija L2 fazėje pagal 3 tarifą per mėnesį', 3712, 4, NULL, NULL),
	(9840, 197, 1, 6, 2, 4, 41, 6, 209, NULL, 'W+ energija L2 fazėje pagal 4 tarifą per mėnesį', 3713, 4, NULL, NULL),
	(9841, 197, 2, 6, 2, 0, 41, 6, 209, NULL, 'W- energija L2 fazėje per mėnesį', 3714, 4, NULL, NULL),
	(9842, 197, 2, 6, 2, 1, 41, 6, 209, NULL, 'W- energija L2 fazėje pagal 1 tarifą per mėnesį', 3715, 4, NULL, NULL),
	(9843, 197, 2, 6, 2, 2, 41, 6, 209, NULL, 'W- energija L2 fazėje pagal 2 tarifą per mėnesį', 3716, 4, NULL, NULL),
	(9844, 197, 2, 6, 2, 3, 41, 6, 209, NULL, 'W- energija L2 fazėje pagal 3 tarifą per mėnesį', 3717, 4, NULL, NULL),
	(9845, 197, 2, 6, 2, 4, 41, 6, 209, NULL, 'W- energija L2 fazėje pagal 4 tarifą per mėnesį', 3718, 4, NULL, NULL),
	(9846, 191, 1, 6, 2, 0, 2, 6, 204, NULL, 'A+ energija L3 fazėje per mėnesį', 3719, 4, NULL, NULL),
	(9847, 191, 1, 6, 2, 1, 2, 6, 204, NULL, 'A+ energija L3 fazėje pagal 1 tarifą per mėnesį', 3720, 4, NULL, NULL),
	(9848, 191, 1, 6, 2, 2, 2, 6, 204, NULL, 'A+ energija L3 fazėje pagal 2 tarifą per mėnesį', 3721, 4, NULL, NULL),
	(9849, 191, 1, 6, 2, 3, 2, 6, 204, NULL, 'A+ energija L3 fazėje pagal 3 tarifą per mėnesį', 3722, 4, NULL, NULL),
	(9850, 191, 1, 6, 2, 4, 2, 6, 204, NULL, 'A+ energija L3 fazėje pagal 4 tarifą per mėnesį', 3723, 4, NULL, NULL),
	(9851, 191, 2, 6, 2, 0, 2, 6, 204, NULL, 'A- energija L3 fazėje per mėnesį', 3724, 4, NULL, NULL),
	(9852, 191, 2, 6, 2, 1, 2, 6, 204, NULL, 'A- energija L3 fazėje pagal 1 tarifą per mėnesį', 3725, 4, NULL, NULL),
	(9853, 191, 2, 6, 2, 2, 2, 6, 204, NULL, 'A- energija L3 fazėje pagal 2 tarifą per mėnesį', 3726, 4, NULL, NULL),
	(9854, 191, 2, 6, 2, 3, 2, 6, 204, NULL, 'A- energija L3 fazėje pagal 3 tarifą per mėnesį', 3727, 4, NULL, NULL),
	(9855, 191, 2, 6, 2, 4, 2, 6, 204, NULL, 'A- energija L3 fazėje pagal 4 tarifą per mėnesį', 3728, 4, NULL, NULL),
	(9856, 195, 1, 6, 2, 0, 4, 6, 207, NULL, 'R+ energija L3 fazėje per mėnesį', 3729, 4, NULL, NULL),
	(9857, 195, 1, 6, 2, 1, 4, 6, 207, NULL, 'R+ energija L3 fazėje pagal 1 tarifą per mėnesį', 3730, 4, NULL, NULL),
	(9858, 195, 1, 6, 2, 2, 4, 6, 207, NULL, 'R+ energija L3 fazėje pagal 2 tarifą per mėnesį', 3731, 4, NULL, NULL),
	(9859, 195, 1, 6, 2, 3, 4, 6, 207, NULL, 'R+ energija L3 fazėje pagal 3 tarifą per mėnesį', 3732, 4, NULL, NULL),
	(9860, 195, 1, 6, 2, 4, 4, 6, 207, NULL, 'R+ energija L3 fazėje pagal 4 tarifą per mėnesį', 3733, 4, NULL, NULL),
	(9861, 195, 2, 6, 2, 0, 4, 6, 207, NULL, 'R- energija L3 fazėje per mėnesį', 3734, 4, NULL, NULL),
	(9862, 195, 2, 6, 2, 1, 4, 6, 207, NULL, 'R- energija L3 fazėje pagal 1 tarifą per mėnesį', 3735, 4, NULL, NULL),
	(9863, 195, 2, 6, 2, 2, 4, 6, 207, NULL, 'R- energija L3 fazėje pagal 2 tarifą per mėnesį', 3736, 4, NULL, NULL),
	(9864, 195, 2, 6, 2, 3, 4, 6, 207, NULL, 'R- energija L3 fazėje pagal 3 tarifą per mėnesį', 3737, 4, NULL, NULL),
	(9865, 195, 2, 6, 2, 4, 4, 6, 207, NULL, 'R- energija L3 fazėje pagal 4 tarifą per mėnesį', 3738, 4, NULL, NULL),
	(9866, 195, 5, 6, 2, 0, 4, 6, 207, NULL, 'R1 energija L3 fazėje per mėnesį', 3739, 4, NULL, NULL),
	(9867, 195, 5, 6, 2, 1, 4, 6, 207, NULL, 'R1 energija L3 fazėje pagal 1 tarifą per mėnesį', 3740, 4, NULL, NULL),
	(9868, 195, 5, 6, 2, 2, 4, 6, 207, NULL, 'R1 energija L3 fazėje pagal 2 tarifą per mėnesį', 3741, 4, NULL, NULL),
	(9869, 195, 5, 6, 2, 3, 4, 6, 207, NULL, 'R1 energija L3 fazėje pagal 3 tarifą per mėnesį', 3742, 4, NULL, NULL),
	(9870, 195, 5, 6, 2, 4, 4, 6, 207, NULL, 'R1 energija L3 fazėje pagal 4 tarifą per mėnesį', 3743, 4, NULL, NULL),
	(9871, 195, 6, 6, 2, 0, 4, 6, 207, NULL, 'R2 energija L3 fazėje per mėnesį', 3744, 4, NULL, NULL),
	(9872, 195, 6, 6, 2, 1, 4, 6, 207, NULL, 'R2 energija L3 fazėje pagal 1 tarifą per mėnesį', 3745, 4, NULL, NULL),
	(9873, 195, 6, 6, 2, 2, 4, 6, 207, NULL, 'R2 energija L3 fazėje pagal 2 tarifą per mėnesį', 3746, 4, NULL, NULL),
	(9874, 195, 6, 6, 2, 3, 4, 6, 207, NULL, 'R2 energija L3 fazėje pagal 3 tarifą per mėnesį', 3747, 4, NULL, NULL),
	(9875, 195, 6, 6, 2, 4, 4, 6, 207, NULL, 'R2 energija L3 fazėje pagal 4 tarifą per mėnesį', 3748, 4, NULL, NULL),
	(9876, 195, 7, 6, 2, 0, 4, 6, 207, NULL, 'R3 energija L3 fazėje per mėnesį', 3749, 4, NULL, NULL),
	(9877, 195, 7, 6, 2, 1, 4, 6, 207, NULL, 'R3 energija L3 fazėje pagal 1 tarifą per mėnesį', 3750, 4, NULL, NULL),
	(9878, 195, 7, 6, 2, 2, 4, 6, 207, NULL, 'R3 energija L3 fazėje pagal 2 tarifą per mėnesį', 3751, 4, NULL, NULL),
	(9879, 195, 7, 6, 2, 3, 4, 6, 207, NULL, 'R3 energija L3 fazėje pagal 3 tarifą per mėnesį', 3752, 4, NULL, NULL),
	(9880, 195, 7, 6, 2, 4, 4, 6, 207, NULL, 'R3 energija L3 fazėje pagal 4 tarifą per mėnesį', 3753, 4, NULL, NULL),
	(9881, 195, 8, 6, 2, 0, 4, 6, 207, NULL, 'R4 energija L3 fazėje per mėnesį', 3754, 4, NULL, NULL),
	(9882, 195, 8, 6, 2, 1, 4, 6, 207, NULL, 'R4 energija L3 fazėje pagal 1 tarifą per mėnesį', 3755, 4, NULL, NULL),
	(9883, 195, 8, 6, 2, 2, 4, 6, 207, NULL, 'R4 energija L3 fazėje pagal 2 tarifą per mėnesį', 3756, 4, NULL, NULL),
	(9884, 195, 8, 6, 2, 3, 4, 6, 207, NULL, 'R4 energija L3 fazėje pagal 3 tarifą per mėnesį', 3757, 4, NULL, NULL),
	(9885, 195, 8, 6, 2, 4, 4, 6, 207, NULL, 'R4 energija L3 fazėje pagal 4 tarifą per mėnesį', 3758, 4, NULL, NULL),
	(9886, 198, 1, 6, 2, 0, 41, 6, 210, NULL, 'W+ energija L3 fazėje per mėnesį', 3759, 4, NULL, NULL),
	(9887, 198, 1, 6, 2, 1, 41, 6, 210, NULL, 'W+ energija L3 fazėje pagal 1 tarifą per mėnesį', 3760, 4, NULL, NULL),
	(9888, 198, 1, 6, 2, 2, 41, 6, 210, NULL, 'W+ energija L3 fazėje pagal 2 tarifą per mėnesį', 3761, 4, NULL, NULL),
	(9889, 198, 1, 6, 2, 3, 41, 6, 210, NULL, 'W+ energija L3 fazėje pagal 3 tarifą per mėnesį', 3762, 4, NULL, NULL),
	(9890, 198, 1, 6, 2, 4, 41, 6, 210, NULL, 'W+ energija L3 fazėje pagal 4 tarifą per mėnesį', 3763, 4, NULL, NULL),
	(9891, 198, 2, 6, 2, 0, 41, 6, 210, NULL, 'W- energija L3 fazėje per mėnesį', 3764, 4, NULL, NULL),
	(9892, 198, 2, 6, 2, 1, 41, 6, 210, NULL, 'W- energija L3 fazėje pagal 1 tarifą per mėnesį', 3765, 4, NULL, NULL),
	(9893, 198, 2, 6, 2, 2, 41, 6, 210, NULL, 'W- energija L3 fazėje pagal 2 tarifą per mėnesį', 3766, 4, NULL, NULL),
	(9894, 198, 2, 6, 2, 3, 41, 6, 210, NULL, 'W- energija L3 fazėje pagal 3 tarifą per mėnesį', 3767, 4, NULL, NULL),
	(9895, 198, 2, 6, 2, 4, 41, 6, 210, NULL, 'W- energija L3 fazėje pagal 4 tarifą per mėnesį', 3768, 4, NULL, NULL),
	(9896, 14, 1, 3, 4, 0, 1, 6, 26, NULL, 'Maksimali pusvalandinė P+ galia L1 fazėje per mėnesį', 3769, 4, NULL, NULL),
	(9897, 14, 1, 3, 4, 1, 1, 6, 26, NULL, 'Maksimali pusvalandinė P+ galia L1 fazėje pagal 1 tarifą per mėnesį', 3770, 4, NULL, NULL),
	(9898, 14, 1, 3, 4, 2, 1, 6, 26, NULL, 'Maksimali pusvalandinė P+ galia L1 fazėje pagal 2 tarifą per mėnesį', 3771, 4, NULL, NULL),
	(9899, 14, 1, 3, 4, 3, 1, 6, 26, NULL, 'Maksimali pusvalandinė P+ galia L1 fazėje pagal 3 tarifą per mėnesį', 3772, 4, NULL, NULL),
	(9900, 14, 1, 3, 4, 4, 1, 6, 26, NULL, 'Maksimali pusvalandinė P+ galia L1 fazėje pagal 4 tarifą per mėnesį', 3773, 4, NULL, NULL),
	(9901, 14, 1, 4, 4, 0, 1, 6, 26, NULL, 'Maksimali valandinė P+ galia L1 fazėje per mėnesį', 3769, 4, NULL, NULL),
	(9902, 14, 1, 4, 4, 1, 1, 6, 26, NULL, 'Maksimali valandinė P+ galia L1 fazėje pagal 1 tarifą per mėnesį', 3770, 4, NULL, NULL),
	(9903, 14, 1, 4, 4, 2, 1, 6, 26, NULL, 'Maksimali valandinė P+ galia L1 fazėje pagal 2 tarifą per mėnesį', 3771, 4, NULL, NULL),
	(9904, 14, 1, 4, 4, 3, 1, 6, 26, NULL, 'Maksimali valandinė P+ galia L1 fazėje pagal 3 tarifą per mėnesį', 3772, 4, NULL, NULL),
	(9905, 14, 1, 4, 4, 4, 1, 6, 26, NULL, 'Maksimali valandinė P+ galia L1 fazėje pagal 4 tarifą per mėnesį', 3773, 4, NULL, NULL),
	(9906, 14, 1, 13, 4, 0, 1, 6, 26, NULL, 'Maksimali 15 minučių P+ galia L1 fazėje per mėnesį', 3769, 4, NULL, NULL),
	(9907, 14, 1, 13, 4, 1, 1, 6, 26, NULL, 'Maksimali 15 minučių P+ galia L1 fazėje pagal 1 tarifą per mėnesį', 3770, 4, NULL, NULL),
	(9908, 14, 1, 13, 4, 2, 1, 6, 26, NULL, 'Maksimali 15 minučių P+ galia L1 fazėje pagal 2 tarifą per mėnesį', 3771, 4, NULL, NULL),
	(9909, 14, 1, 13, 4, 3, 1, 6, 26, NULL, 'Maksimali 15 minučių P+ galia L1 fazėje pagal 3 tarifą per mėnesį', 3772, 4, NULL, NULL),
	(9910, 14, 1, 13, 4, 4, 1, 6, 26, NULL, 'Maksimali 15 minučių P+ galia L1 fazėje pagal 4 tarifą per mėnesį', 3773, 4, NULL, NULL),
	(9911, 14, 2, 3, 4, 0, 1, 6, 26, NULL, 'Maksimali pusvalandinė P- galia L1 fazėje per mėnesį', 3774, 4, NULL, NULL),
	(9912, 14, 2, 3, 4, 1, 1, 6, 26, NULL, 'Maksimali pusvalandinė P- galia L1 fazėje pagal 1 tarifą per mėnesį', 3775, 4, NULL, NULL),
	(9913, 14, 2, 3, 4, 2, 1, 6, 26, NULL, 'Maksimali pusvalandinė P- galia L1 fazėje pagal 2 tarifą per mėnesį', 3776, 4, NULL, NULL),
	(9914, 14, 2, 3, 4, 3, 1, 6, 26, NULL, 'Maksimali pusvalandinė P- galia L1 fazėje pagal 3 tarifą per mėnesį', 3777, 4, NULL, NULL),
	(9915, 14, 2, 3, 4, 4, 1, 6, 26, NULL, 'Maksimali pusvalandinė P- galia L1 fazėje pagal 4 tarifą per mėnesį', 3778, 4, NULL, NULL),
	(9916, 14, 2, 4, 4, 0, 1, 6, 26, NULL, 'Maksimali valandinė P- galia L1 fazėje per mėnesį', 3774, 4, NULL, NULL),
	(9917, 14, 2, 4, 4, 1, 1, 6, 26, NULL, 'Maksimali valandinė P- galia L1 fazėje pagal 1 tarifą per mėnesį', 3775, 4, NULL, NULL),
	(9918, 14, 2, 4, 4, 2, 1, 6, 26, NULL, 'Maksimali valandinė P- galia L1 fazėje pagal 2 tarifą per mėnesį', 3776, 4, NULL, NULL),
	(9919, 14, 2, 4, 4, 3, 1, 6, 26, NULL, 'Maksimali valandinė P- galia L1 fazėje pagal 3 tarifą per mėnesį', 3777, 4, NULL, NULL),
	(9920, 14, 2, 4, 4, 4, 1, 6, 26, NULL, 'Maksimali valandinė P- galia L1 fazėje pagal 4 tarifą per mėnesį', 3778, 4, NULL, NULL),
	(9921, 14, 2, 13, 4, 0, 1, 6, 26, NULL, 'Maksimali 15 minučių P- galia L1 fazėje per mėnesį', 3774, 4, NULL, NULL),
	(9922, 14, 2, 13, 4, 1, 1, 6, 26, NULL, 'Maksimali 15 minučių P- galia L1 fazėje pagal 1 tarifą per mėnesį', 3775, 4, NULL, NULL),
	(9923, 14, 2, 13, 4, 2, 1, 6, 26, NULL, 'Maksimali 15 minučių P- galia L1 fazėje pagal 2 tarifą per mėnesį', 3776, 4, NULL, NULL),
	(9924, 14, 2, 13, 4, 3, 1, 6, 26, NULL, 'Maksimali 15 minučių P- galia L1 fazėje pagal 3 tarifą per mėnesį', 3777, 4, NULL, NULL),
	(9925, 14, 2, 13, 4, 4, 1, 6, 26, NULL, 'Maksimali 15 minučių P- galia L1 fazėje pagal 4 tarifą per mėnesį', 3778, 4, NULL, NULL),
	(9926, 17, 1, 3, 4, 0, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q+ galia L1 fazėje per mėnesį', 3779, 4, NULL, NULL),
	(9927, 17, 1, 3, 4, 1, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q+ galia L1 fazėje pagal 1 tarifą per mėnesį', 3780, 4, NULL, NULL),
	(9928, 17, 1, 3, 4, 2, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q+ galia L1 fazėje pagal 2 tarifą per mėnesį', 3781, 4, NULL, NULL),
	(9929, 17, 1, 3, 4, 3, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q+ galia L1 fazėje pagal 3 tarifą per mėnesį', 3782, 4, NULL, NULL),
	(9930, 17, 1, 3, 4, 4, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q+ galia L1 fazėje pagal 4 tarifą per mėnesį', 3783, 4, NULL, NULL),
	(9931, 17, 1, 4, 4, 0, 3, 6, 29, NULL, 'Maksimali valandinė Q+ galia L1 fazėje per mėnesį', 3779, 4, NULL, NULL),
	(9932, 17, 1, 4, 4, 1, 3, 6, 29, NULL, 'Maksimali valandinė Q+ galia L1 fazėje pagal 1 tarifą per mėnesį', 3780, 4, NULL, NULL),
	(9933, 17, 1, 4, 4, 2, 3, 6, 29, NULL, 'Maksimali valandinė Q+ galia L1 fazėje pagal 2 tarifą per mėnesį', 3781, 4, NULL, NULL),
	(9934, 17, 1, 4, 4, 3, 3, 6, 29, NULL, 'Maksimali valandinė Q+ galia L1 fazėje pagal 3 tarifą per mėnesį', 3782, 4, NULL, NULL),
	(9935, 17, 1, 4, 4, 4, 3, 6, 29, NULL, 'Maksimali valandinė Q+ galia L1 fazėje pagal 4 tarifą per mėnesį', 3783, 4, NULL, NULL),
	(9936, 17, 1, 13, 4, 0, 3, 6, 29, NULL, 'Maksimali 15 minučių Q+ galia L1 fazėje per mėnesį', 3779, 4, NULL, NULL),
	(9937, 17, 1, 13, 4, 1, 3, 6, 29, NULL, 'Maksimali 15 minučių Q+ galia L1 fazėje pagal 1 tarifą per mėnesį', 3780, 4, NULL, NULL),
	(9938, 17, 1, 13, 4, 2, 3, 6, 29, NULL, 'Maksimali 15 minučių Q+ galia L1 fazėje pagal 2 tarifą per mėnesį', 3781, 4, NULL, NULL),
	(9939, 17, 1, 13, 4, 3, 3, 6, 29, NULL, 'Maksimali 15 minučių Q+ galia L1 fazėje pagal 3 tarifą per mėnesį', 3782, 4, NULL, NULL),
	(9940, 17, 1, 13, 4, 4, 3, 6, 29, NULL, 'Maksimali 15 minučių Q+ galia L1 fazėje pagal 4 tarifą per mėnesį', 3783, 4, NULL, NULL),
	(9941, 17, 2, 3, 4, 0, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q- galia L1 fazėje per mėnesį', 3784, 4, NULL, NULL),
	(9942, 17, 2, 3, 4, 1, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q- galia L1 fazėje pagal 1 tarifą per mėnesį', 3785, 4, NULL, NULL),
	(9943, 17, 2, 3, 4, 2, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q- galia L1 fazėje pagal 2 tarifą per mėnesį', 3786, 4, NULL, NULL),
	(9944, 17, 2, 3, 4, 3, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q- galia L1 fazėje pagal 3 tarifą per mėnesį', 3787, 4, NULL, NULL),
	(9945, 17, 2, 3, 4, 4, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q- galia L1 fazėje pagal 4 tarifą per mėnesį', 3788, 4, NULL, NULL),
	(9946, 17, 2, 4, 4, 0, 3, 6, 29, NULL, 'Maksimali valandinė Q- galia L1 fazėje per mėnesį', 3784, 4, NULL, NULL),
	(9947, 17, 2, 4, 4, 1, 3, 6, 29, NULL, 'Maksimali valandinė Q- galia L1 fazėje pagal 1 tarifą per mėnesį', 3785, 4, NULL, NULL),
	(9948, 17, 2, 4, 4, 2, 3, 6, 29, NULL, 'Maksimali valandinė Q- galia L1 fazėje pagal 2 tarifą per mėnesį', 3786, 4, NULL, NULL),
	(9949, 17, 2, 4, 4, 3, 3, 6, 29, NULL, 'Maksimali valandinė Q- galia L1 fazėje pagal 3 tarifą per mėnesį', 3787, 4, NULL, NULL),
	(9950, 17, 2, 4, 4, 4, 3, 6, 29, NULL, 'Maksimali valandinė Q- galia L1 fazėje pagal 4 tarifą per mėnesį', 3788, 4, NULL, NULL),
	(9951, 17, 2, 13, 4, 0, 3, 6, 29, NULL, 'Maksimali 15 minučių Q- galia L1 fazėje per mėnesį', 3784, 4, NULL, NULL),
	(9952, 17, 2, 13, 4, 1, 3, 6, 29, NULL, 'Maksimali 15 minučių Q- galia L1 fazėje pagal 1 tarifą per mėnesį', 3785, 4, NULL, NULL),
	(9953, 17, 2, 13, 4, 2, 3, 6, 29, NULL, 'Maksimali 15 minučių Q- galia L1 fazėje pagal 2 tarifą per mėnesį', 3786, 4, NULL, NULL),
	(9954, 17, 2, 13, 4, 3, 3, 6, 29, NULL, 'Maksimali 15 minučių Q- galia L1 fazėje pagal 3 tarifą per mėnesį', 3787, 4, NULL, NULL),
	(9955, 17, 2, 13, 4, 4, 3, 6, 29, NULL, 'Maksimali 15 minučių Q- galia L1 fazėje pagal 4 tarifą per mėnesį', 3788, 4, NULL, NULL),
	(9956, 17, 5, 3, 4, 0, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q1 galia L1 fazėje per mėnesį', 3789, 4, NULL, NULL),
	(9957, 17, 5, 3, 4, 1, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q1 galia L1 fazėje pagal 1 tarifą per mėnesį', 3790, 4, NULL, NULL),
	(9958, 17, 5, 3, 4, 2, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q1 galia L1 fazėje pagal 2 tarifą per mėnesį', 3791, 4, NULL, NULL),
	(9959, 17, 5, 3, 4, 3, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q1 galia L1 fazėje pagal 3 tarifą per mėnesį', 3792, 4, NULL, NULL),
	(9960, 17, 5, 3, 4, 4, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q1 galia L1 fazėje pagal 4 tarifą per mėnesį', 3793, 4, NULL, NULL),
	(9961, 17, 5, 4, 4, 0, 3, 6, 29, NULL, 'Maksimali valandinė Q1 galia L1 fazėje per mėnesį', 3789, 4, NULL, NULL),
	(9962, 17, 5, 4, 4, 1, 3, 6, 29, NULL, 'Maksimali valandinė Q1 galia L1 fazėje pagal 1 tarifą per mėnesį', 3790, 4, NULL, NULL),
	(9963, 17, 5, 4, 4, 2, 3, 6, 29, NULL, 'Maksimali valandinė Q1 galia L1 fazėje pagal 2 tarifą per mėnesį', 3791, 4, NULL, NULL),
	(9964, 17, 5, 4, 4, 3, 3, 6, 29, NULL, 'Maksimali valandinė Q1 galia L1 fazėje pagal 3 tarifą per mėnesį', 3792, 4, NULL, NULL),
	(9965, 17, 5, 4, 4, 4, 3, 6, 29, NULL, 'Maksimali valandinė Q1 galia L1 fazėje pagal 4 tarifą per mėnesį', 3793, 4, NULL, NULL),
	(9966, 17, 5, 13, 4, 0, 3, 6, 29, NULL, 'Maksimali 15 minučių Q1 galia L1 fazėje per mėnesį', 3789, 4, NULL, NULL),
	(9967, 17, 5, 13, 4, 1, 3, 6, 29, NULL, 'Maksimali 15 minučių Q1 galia L1 fazėje pagal 1 tarifą per mėnesį', 3790, 4, NULL, NULL),
	(9968, 17, 5, 13, 4, 2, 3, 6, 29, NULL, 'Maksimali 15 minučių Q1 galia L1 fazėje pagal 2 tarifą per mėnesį', 3791, 4, NULL, NULL),
	(9969, 17, 5, 13, 4, 3, 3, 6, 29, NULL, 'Maksimali 15 minučių Q1 galia L1 fazėje pagal 3 tarifą per mėnesį', 3792, 4, NULL, NULL),
	(9970, 17, 5, 13, 4, 4, 3, 6, 29, NULL, 'Maksimali 15 minučių Q1 galia L1 fazėje pagal 4 tarifą per mėnesį', 3793, 4, NULL, NULL),
	(9971, 17, 6, 3, 4, 0, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q2 galia L1 fazėje per mėnesį', 3794, 4, NULL, NULL),
	(9972, 17, 6, 3, 4, 1, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q2 galia L1 fazėje pagal 1 tarifą per mėnesį', 3795, 4, NULL, NULL),
	(9973, 17, 6, 3, 4, 2, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q2 galia L1 fazėje pagal 2 tarifą per mėnesį', 3796, 4, NULL, NULL),
	(9974, 17, 6, 3, 4, 3, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q2 galia L1 fazėje pagal 3 tarifą per mėnesį', 3797, 4, NULL, NULL),
	(9975, 17, 6, 3, 4, 4, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q2 galia L1 fazėje pagal 4 tarifą per mėnesį', 3798, 4, NULL, NULL),
	(9976, 17, 6, 4, 4, 0, 3, 6, 29, NULL, 'Maksimali valandinė Q2 galia L1 fazėje per mėnesį', 3794, 4, NULL, NULL),
	(9977, 17, 6, 4, 4, 1, 3, 6, 29, NULL, 'Maksimali valandinė Q2 galia L1 fazėje pagal 1 tarifą per mėnesį', 3795, 4, NULL, NULL),
	(9978, 17, 6, 4, 4, 2, 3, 6, 29, NULL, 'Maksimali valandinė Q2 galia L1 fazėje pagal 2 tarifą per mėnesį', 3796, 4, NULL, NULL),
	(9979, 17, 6, 4, 4, 3, 3, 6, 29, NULL, 'Maksimali valandinė Q2 galia L1 fazėje pagal 3 tarifą per mėnesį', 3797, 4, NULL, NULL),
	(9980, 17, 6, 4, 4, 4, 3, 6, 29, NULL, 'Maksimali valandinė Q2 galia L1 fazėje pagal 4 tarifą per mėnesį', 3798, 4, NULL, NULL),
	(9981, 17, 6, 13, 4, 0, 3, 6, 29, NULL, 'Maksimali 15 minučių Q2 galia L1 fazėje per mėnesį', 3794, 4, NULL, NULL),
	(9982, 17, 6, 13, 4, 1, 3, 6, 29, NULL, 'Maksimali 15 minučių Q2 galia L1 fazėje pagal 1 tarifą per mėnesį', 3795, 4, NULL, NULL),
	(9983, 17, 6, 13, 4, 2, 3, 6, 29, NULL, 'Maksimali 15 minučių Q2 galia L1 fazėje pagal 2 tarifą per mėnesį', 3796, 4, NULL, NULL),
	(9984, 17, 6, 13, 4, 3, 3, 6, 29, NULL, 'Maksimali 15 minučių Q2 galia L1 fazėje pagal 3 tarifą per mėnesį', 3797, 4, NULL, NULL),
	(9985, 17, 6, 13, 4, 4, 3, 6, 29, NULL, 'Maksimali 15 minučių Q2 galia L1 fazėje pagal 4 tarifą per mėnesį', 3798, 4, NULL, NULL),
	(9986, 17, 7, 3, 4, 0, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q3 galia L1 fazėje per mėnesį', 3799, 4, NULL, NULL),
	(9987, 17, 7, 3, 4, 1, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q3 galia L1 fazėje pagal 1 tarifą per mėnesį', 3800, 4, NULL, NULL),
	(9988, 17, 7, 3, 4, 2, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q3 galia L1 fazėje pagal 2 tarifą per mėnesį', 3801, 4, NULL, NULL),
	(9989, 17, 7, 3, 4, 3, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q3 galia L1 fazėje pagal 3 tarifą per mėnesį', 3802, 4, NULL, NULL),
	(9990, 17, 7, 3, 4, 4, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q3 galia L1 fazėje pagal 4 tarifą per mėnesį', 3803, 4, NULL, NULL),
	(9991, 17, 7, 4, 4, 0, 3, 6, 29, NULL, 'Maksimali valandinė Q3 galia L1 fazėje per mėnesį', 3799, 4, NULL, NULL),
	(9992, 17, 7, 4, 4, 1, 3, 6, 29, NULL, 'Maksimali valandinė Q3 galia L1 fazėje pagal 1 tarifą per mėnesį', 3800, 4, NULL, NULL),
	(9993, 17, 7, 4, 4, 2, 3, 6, 29, NULL, 'Maksimali valandinė Q3 galia L1 fazėje pagal 2 tarifą per mėnesį', 3801, 4, NULL, NULL),
	(9994, 17, 7, 4, 4, 3, 3, 6, 29, NULL, 'Maksimali valandinė Q3 galia L1 fazėje pagal 3 tarifą per mėnesį', 3802, 4, NULL, NULL),
	(9995, 17, 7, 4, 4, 4, 3, 6, 29, NULL, 'Maksimali valandinė Q3 galia L1 fazėje pagal 4 tarifą per mėnesį', 3803, 4, NULL, NULL),
	(9996, 17, 7, 13, 4, 0, 3, 6, 29, NULL, 'Maksimali 15 minučių Q3 galia L1 fazėje per mėnesį', 3799, 4, NULL, NULL),
	(9997, 17, 7, 13, 4, 1, 3, 6, 29, NULL, 'Maksimali 15 minučių Q3 galia L1 fazėje pagal 1 tarifą per mėnesį', 3800, 4, NULL, NULL),
	(9998, 17, 7, 13, 4, 2, 3, 6, 29, NULL, 'Maksimali 15 minučių Q3 galia L1 fazėje pagal 2 tarifą per mėnesį', 3801, 4, NULL, NULL),
	(9999, 17, 7, 13, 4, 3, 3, 6, 29, NULL, 'Maksimali 15 minučių Q3 galia L1 fazėje pagal 3 tarifą per mėnesį', 3802, 4, NULL, NULL),
	(10000, 17, 7, 13, 4, 4, 3, 6, 29, NULL, 'Maksimali 15 minučių Q3 galia L1 fazėje pagal 4 tarifą per mėnesį', 3803, 4, NULL, NULL),
	(10001, 17, 8, 3, 4, 0, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q4 galia L1 fazėje per mėnesį', 3804, 4, NULL, NULL),
	(10002, 17, 8, 3, 4, 1, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q4 galia L1 fazėje pagal 1 tarifą per mėnesį', 3805, 4, NULL, NULL),
	(10003, 17, 8, 3, 4, 2, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q4 galia L1 fazėje pagal 2 tarifą per mėnesį', 3806, 4, NULL, NULL),
	(10004, 17, 8, 3, 4, 3, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q4 galia L1 fazėje pagal 3 tarifą per mėnesį', 3807, 4, NULL, NULL),
	(10005, 17, 8, 3, 4, 4, 3, 6, 29, NULL, 'Maksimali pusvalandinė Q4 galia L1 fazėje pagal 4 tarifą per mėnesį', 3808, 4, NULL, NULL),
	(10006, 17, 8, 4, 4, 0, 3, 6, 29, NULL, 'Maksimali valandinė Q4 galia L1 fazėje per mėnesį', 3804, 4, NULL, NULL),
	(10007, 17, 8, 4, 4, 1, 3, 6, 29, NULL, 'Maksimali valandinė Q4 galia L1 fazėje pagal 1 tarifą per mėnesį', 3805, 4, NULL, NULL),
	(10008, 17, 8, 4, 4, 2, 3, 6, 29, NULL, 'Maksimali valandinė Q4 galia L1 fazėje pagal 2 tarifą per mėnesį', 3806, 4, NULL, NULL),
	(10009, 17, 8, 4, 4, 3, 3, 6, 29, NULL, 'Maksimali valandinė Q4 galia L1 fazėje pagal 3 tarifą per mėnesį', 3807, 4, NULL, NULL),
	(10010, 17, 8, 4, 4, 4, 3, 6, 29, NULL, 'Maksimali valandinė Q4 galia L1 fazėje pagal 4 tarifą per mėnesį', 3808, 4, NULL, NULL),
	(10011, 17, 8, 13, 4, 0, 3, 6, 29, NULL, 'Maksimali 15 minučių Q4 galia L1 fazėje per mėnesį', 3804, 4, NULL, NULL),
	(10012, 17, 8, 13, 4, 1, 3, 6, 29, NULL, 'Maksimali 15 minučių Q4 galia L1 fazėje pagal 1 tarifą per mėnesį', 3805, 4, NULL, NULL),
	(10013, 17, 8, 13, 4, 2, 3, 6, 29, NULL, 'Maksimali 15 minučių Q4 galia L1 fazėje pagal 2 tarifą per mėnesį', 3806, 4, NULL, NULL),
	(10014, 17, 8, 13, 4, 3, 3, 6, 29, NULL, 'Maksimali 15 minučių Q4 galia L1 fazėje pagal 3 tarifą per mėnesį', 3807, 4, NULL, NULL),
	(10015, 17, 8, 13, 4, 4, 3, 6, 29, NULL, 'Maksimali 15 minučių Q4 galia L1 fazėje pagal 4 tarifą per mėnesį', 3808, 4, NULL, NULL),
	(10016, 20, 1, 3, 4, 0, 7, 6, 32, NULL, 'Maksimali pusvalandinė S+ galia L1 fazėje per mėnesį', 3809, 4, NULL, NULL),
	(10017, 20, 1, 3, 4, 1, 7, 6, 32, NULL, 'Maksimali pusvalandinė S+ galia L1 fazėje pagal 1 tarifą per mėnesį', 3810, 4, NULL, NULL),
	(10018, 20, 1, 3, 4, 2, 7, 6, 32, NULL, 'Maksimali pusvalandinė S+ galia L1 fazėje pagal 2 tarifą per mėnesį', 3811, 4, NULL, NULL),
	(10019, 20, 1, 3, 4, 3, 7, 6, 32, NULL, 'Maksimali pusvalandinė S+ galia L1 fazėje pagal 3 tarifą per mėnesį', 3812, 4, NULL, NULL),
	(10020, 20, 1, 3, 4, 4, 7, 6, 32, NULL, 'Maksimali pusvalandinė S+ galia L1 fazėje pagal 4 tarifą per mėnesį', 3813, 4, NULL, NULL),
	(10021, 20, 1, 4, 4, 0, 7, 6, 32, NULL, 'Maksimali valandinė S+ galia L1 fazėje per mėnesį', 3809, 4, NULL, NULL),
	(10022, 20, 1, 4, 4, 1, 7, 6, 32, NULL, 'Maksimali valandinė S+ galia L1 fazėje pagal 1 tarifą per mėnesį', 3810, 4, NULL, NULL),
	(10023, 20, 1, 4, 4, 2, 7, 6, 32, NULL, 'Maksimali valandinė S+ galia L1 fazėje pagal 2 tarifą per mėnesį', 3811, 4, NULL, NULL),
	(10024, 20, 1, 4, 4, 3, 7, 6, 32, NULL, 'Maksimali valandinė S+ galia L1 fazėje pagal 3 tarifą per mėnesį', 3812, 4, NULL, NULL),
	(10025, 20, 1, 4, 4, 4, 7, 6, 32, NULL, 'Maksimali valandinė S+ galia L1 fazėje pagal 4 tarifą per mėnesį', 3813, 4, NULL, NULL),
	(10026, 20, 1, 13, 4, 0, 7, 6, 32, NULL, 'Maksimali 15 minučių S+ galia L1 fazėje per mėnesį', 3809, 4, NULL, NULL),
	(10027, 20, 1, 13, 4, 1, 7, 6, 32, NULL, 'Maksimali 15 minučių S+ galia L1 fazėje pagal 1 tarifą per mėnesį', 3810, 4, NULL, NULL),
	(10028, 20, 1, 13, 4, 2, 7, 6, 32, NULL, 'Maksimali 15 minučių S+ galia L1 fazėje pagal 2 tarifą per mėnesį', 3811, 4, NULL, NULL),
	(10029, 20, 1, 13, 4, 3, 7, 6, 32, NULL, 'Maksimali 15 minučių S+ galia L1 fazėje pagal 3 tarifą per mėnesį', 3812, 4, NULL, NULL),
	(10030, 20, 1, 13, 4, 4, 7, 6, 32, NULL, 'Maksimali 15 minučių S+ galia L1 fazėje pagal 4 tarifą per mėnesį', 3813, 4, NULL, NULL),
	(10031, 20, 2, 3, 4, 0, 7, 6, 32, NULL, 'Maksimali pusvalandinė S- galia L1 fazėje per mėnesį', 3814, 4, NULL, NULL),
	(10032, 20, 2, 3, 4, 1, 7, 6, 32, NULL, 'Maksimali pusvalandinė S- galia L1 fazėje pagal 1 tarifą per mėnesį', 3815, 4, NULL, NULL),
	(10033, 20, 2, 3, 4, 2, 7, 6, 32, NULL, 'Maksimali pusvalandinė S- galia L1 fazėje pagal 2 tarifą per mėnesį', 3816, 4, NULL, NULL),
	(10034, 20, 2, 3, 4, 3, 7, 6, 32, NULL, 'Maksimali pusvalandinė S- galia L1 fazėje pagal 3 tarifą per mėnesį', 3817, 4, NULL, NULL),
	(10035, 20, 2, 3, 4, 4, 7, 6, 32, NULL, 'Maksimali pusvalandinė S- galia L1 fazėje pagal 4 tarifą per mėnesį', 3818, 4, NULL, NULL),
	(10036, 20, 2, 4, 4, 0, 7, 6, 32, NULL, 'Maksimali valandinė S- galia L1 fazėje per mėnesį', 3814, 4, NULL, NULL),
	(10037, 20, 2, 4, 4, 1, 7, 6, 32, NULL, 'Maksimali valandinė S- galia L1 fazėje pagal 1 tarifą per mėnesį', 3815, 4, NULL, NULL),
	(10038, 20, 2, 4, 4, 2, 7, 6, 32, NULL, 'Maksimali valandinė S- galia L1 fazėje pagal 2 tarifą per mėnesį', 3816, 4, NULL, NULL),
	(10039, 20, 2, 4, 4, 3, 7, 6, 32, NULL, 'Maksimali valandinė S- galia L1 fazėje pagal 3 tarifą per mėnesį', 3817, 4, NULL, NULL),
	(10040, 20, 2, 4, 4, 4, 7, 6, 32, NULL, 'Maksimali valandinė S- galia L1 fazėje pagal 4 tarifą per mėnesį', 3818, 4, NULL, NULL),
	(10041, 20, 2, 13, 4, 0, 7, 6, 32, NULL, 'Maksimali 15 minučių S- galia L1 fazėje per mėnesį', 3814, 4, NULL, NULL),
	(10042, 20, 2, 13, 4, 1, 7, 6, 32, NULL, 'Maksimali 15 minučių S- galia L1 fazėje pagal 1 tarifą per mėnesį', 3815, 4, NULL, NULL),
	(10043, 20, 2, 13, 4, 2, 7, 6, 32, NULL, 'Maksimali 15 minučių S- galia L1 fazėje pagal 2 tarifą per mėnesį', 3816, 4, NULL, NULL),
	(10044, 20, 2, 13, 4, 3, 7, 6, 32, NULL, 'Maksimali 15 minučių S- galia L1 fazėje pagal 3 tarifą per mėnesį', 3817, 4, NULL, NULL),
	(10045, 20, 2, 13, 4, 4, 7, 6, 32, NULL, 'Maksimali 15 minučių S- galia L1 fazėje pagal 4 tarifą per mėnesį', 3818, 4, NULL, NULL),
	(10046, 15, 1, 3, 4, 0, 1, 6, 27, NULL, 'Maksimali pusvalandinė P+ galia L2 fazėje per mėnesį', 3819, 4, NULL, NULL),
	(10047, 15, 1, 3, 4, 1, 1, 6, 27, NULL, 'Maksimali pusvalandinė P+ galia L2 fazėje pagal 1 tarifą per mėnesį', 3820, 4, NULL, NULL),
	(10048, 15, 1, 3, 4, 2, 1, 6, 27, NULL, 'Maksimali pusvalandinė P+ galia L2 fazėje pagal 2 tarifą per mėnesį', 3821, 4, NULL, NULL),
	(10049, 15, 1, 3, 4, 3, 1, 6, 27, NULL, 'Maksimali pusvalandinė P+ galia L2 fazėje pagal 3 tarifą per mėnesį', 3822, 4, NULL, NULL),
	(10050, 15, 1, 3, 4, 4, 1, 6, 27, NULL, 'Maksimali pusvalandinė P+ galia L2 fazėje pagal 4 tarifą per mėnesį', 3823, 4, NULL, NULL),
	(10051, 15, 1, 4, 4, 0, 1, 6, 27, NULL, 'Maksimali valandinė P+ galia L2 fazėje per mėnesį', 3819, 4, NULL, NULL),
	(10052, 15, 1, 4, 4, 1, 1, 6, 27, NULL, 'Maksimali valandinė P+ galia L2 fazėje pagal 1 tarifą per mėnesį', 3820, 4, NULL, NULL),
	(10053, 15, 1, 4, 4, 2, 1, 6, 27, NULL, 'Maksimali valandinė P+ galia L2 fazėje pagal 2 tarifą per mėnesį', 3821, 4, NULL, NULL),
	(10054, 15, 1, 4, 4, 3, 1, 6, 27, NULL, 'Maksimali valandinė P+ galia L2 fazėje pagal 3 tarifą per mėnesį', 3822, 4, NULL, NULL),
	(10055, 15, 1, 4, 4, 4, 1, 6, 27, NULL, 'Maksimali valandinė P+ galia L2 fazėje pagal 4 tarifą per mėnesį', 3823, 4, NULL, NULL),
	(10056, 15, 1, 13, 4, 0, 1, 6, 27, NULL, 'Maksimali 15 minučių P+ galia L2 fazėje per mėnesį', 3819, 4, NULL, NULL),
	(10057, 15, 1, 13, 4, 1, 1, 6, 27, NULL, 'Maksimali 15 minučių P+ galia L2 fazėje pagal 1 tarifą per mėnesį', 3820, 4, NULL, NULL),
	(10058, 15, 1, 13, 4, 2, 1, 6, 27, NULL, 'Maksimali 15 minučių P+ galia L2 fazėje pagal 2 tarifą per mėnesį', 3821, 4, NULL, NULL),
	(10059, 15, 1, 13, 4, 3, 1, 6, 27, NULL, 'Maksimali 15 minučių P+ galia L2 fazėje pagal 3 tarifą per mėnesį', 3822, 4, NULL, NULL),
	(10060, 15, 1, 13, 4, 4, 1, 6, 27, NULL, 'Maksimali 15 minučių P+ galia L2 fazėje pagal 4 tarifą per mėnesį', 3823, 4, NULL, NULL),
	(10061, 15, 2, 3, 4, 0, 1, 6, 27, NULL, 'Maksimali pusvalandinė P- galia L2 fazėje per mėnesį', 3824, 4, NULL, NULL),
	(10062, 15, 2, 3, 4, 1, 1, 6, 27, NULL, 'Maksimali pusvalandinė P- galia L2 fazėje pagal 1 tarifą per mėnesį', 3825, 4, NULL, NULL),
	(10063, 15, 2, 3, 4, 2, 1, 6, 27, NULL, 'Maksimali pusvalandinė P- galia L2 fazėje pagal 2 tarifą per mėnesį', 3826, 4, NULL, NULL),
	(10064, 15, 2, 3, 4, 3, 1, 6, 27, NULL, 'Maksimali pusvalandinė P- galia L2 fazėje pagal 3 tarifą per mėnesį', 3827, 4, NULL, NULL),
	(10065, 15, 2, 3, 4, 4, 1, 6, 27, NULL, 'Maksimali pusvalandinė P- galia L2 fazėje pagal 4 tarifą per mėnesį', 3828, 4, NULL, NULL),
	(10066, 15, 2, 4, 4, 0, 1, 6, 27, NULL, 'Maksimali valandinė P- galia L2 fazėje per mėnesį', 3824, 4, NULL, NULL),
	(10067, 15, 2, 4, 4, 1, 1, 6, 27, NULL, 'Maksimali valandinė P- galia L2 fazėje pagal 1 tarifą per mėnesį', 3825, 4, NULL, NULL),
	(10068, 15, 2, 4, 4, 2, 1, 6, 27, NULL, 'Maksimali valandinė P- galia L2 fazėje pagal 2 tarifą per mėnesį', 3826, 4, NULL, NULL),
	(10069, 15, 2, 4, 4, 3, 1, 6, 27, NULL, 'Maksimali valandinė P- galia L2 fazėje pagal 3 tarifą per mėnesį', 3827, 4, NULL, NULL),
	(10070, 15, 2, 4, 4, 4, 1, 6, 27, NULL, 'Maksimali valandinė P- galia L2 fazėje pagal 4 tarifą per mėnesį', 3828, 4, NULL, NULL),
	(10071, 15, 2, 13, 4, 0, 1, 6, 27, NULL, 'Maksimali 15 minučių P- galia L2 fazėje per mėnesį', 3824, 4, NULL, NULL),
	(10072, 15, 2, 13, 4, 1, 1, 6, 27, NULL, 'Maksimali 15 minučių P- galia L2 fazėje pagal 1 tarifą per mėnesį', 3825, 4, NULL, NULL),
	(10073, 15, 2, 13, 4, 2, 1, 6, 27, NULL, 'Maksimali 15 minučių P- galia L2 fazėje pagal 2 tarifą per mėnesį', 3826, 4, NULL, NULL),
	(10074, 15, 2, 13, 4, 3, 1, 6, 27, NULL, 'Maksimali 15 minučių P- galia L2 fazėje pagal 3 tarifą per mėnesį', 3827, 4, NULL, NULL),
	(10075, 15, 2, 13, 4, 4, 1, 6, 27, NULL, 'Maksimali 15 minučių P- galia L2 fazėje pagal 4 tarifą per mėnesį', 3828, 4, NULL, NULL),
	(10076, 18, 1, 3, 4, 0, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q+ galia L2 fazėje per mėnesį', 3829, 4, NULL, NULL),
	(10077, 18, 1, 3, 4, 1, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q+ galia L2 fazėje pagal 1 tarifą per mėnesį', 3830, 4, NULL, NULL),
	(10078, 18, 1, 3, 4, 2, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q+ galia L2 fazėje pagal 2 tarifą per mėnesį', 3831, 4, NULL, NULL),
	(10079, 18, 1, 3, 4, 3, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q+ galia L2 fazėje pagal 3 tarifą per mėnesį', 3832, 4, NULL, NULL),
	(10080, 18, 1, 3, 4, 4, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q+ galia L2 fazėje pagal 4 tarifą per mėnesį', 3833, 4, NULL, NULL),
	(10081, 18, 1, 4, 4, 0, 3, 6, 30, NULL, 'Maksimali valandinė Q+ galia L2 fazėje per mėnesį', 3829, 4, NULL, NULL),
	(10082, 18, 1, 4, 4, 1, 3, 6, 30, NULL, 'Maksimali valandinė Q+ galia L2 fazėje pagal 1 tarifą per mėnesį', 3830, 4, NULL, NULL),
	(10083, 18, 1, 4, 4, 2, 3, 6, 30, NULL, 'Maksimali valandinė Q+ galia L2 fazėje pagal 2 tarifą per mėnesį', 3831, 4, NULL, NULL),
	(10084, 18, 1, 4, 4, 3, 3, 6, 30, NULL, 'Maksimali valandinė Q+ galia L2 fazėje pagal 3 tarifą per mėnesį', 3832, 4, NULL, NULL),
	(10085, 18, 1, 4, 4, 4, 3, 6, 30, NULL, 'Maksimali valandinė Q+ galia L2 fazėje pagal 4 tarifą per mėnesį', 3833, 4, NULL, NULL),
	(10086, 18, 1, 13, 4, 0, 3, 6, 30, NULL, 'Maksimali 15 minučių Q+ galia L2 fazėje per mėnesį', 3829, 4, NULL, NULL),
	(10087, 18, 1, 13, 4, 1, 3, 6, 30, NULL, 'Maksimali 15 minučių Q+ galia L2 fazėje pagal 1 tarifą per mėnesį', 3830, 4, NULL, NULL),
	(10088, 18, 1, 13, 4, 2, 3, 6, 30, NULL, 'Maksimali 15 minučių Q+ galia L2 fazėje pagal 2 tarifą per mėnesį', 3831, 4, NULL, NULL),
	(10089, 18, 1, 13, 4, 3, 3, 6, 30, NULL, 'Maksimali 15 minučių Q+ galia L2 fazėje pagal 3 tarifą per mėnesį', 3832, 4, NULL, NULL),
	(10090, 18, 1, 13, 4, 4, 3, 6, 30, NULL, 'Maksimali 15 minučių Q+ galia L2 fazėje pagal 4 tarifą per mėnesį', 3833, 4, NULL, NULL),
	(10091, 18, 2, 3, 4, 0, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q- galia L2 fazėje per mėnesį', 3834, 4, NULL, NULL),
	(10092, 18, 2, 3, 4, 1, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q- galia L2 fazėje pagal 1 tarifą per mėnesį', 3835, 4, NULL, NULL),
	(10093, 18, 2, 3, 4, 2, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q- galia L2 fazėje pagal 2 tarifą per mėnesį', 3836, 4, NULL, NULL),
	(10094, 18, 2, 3, 4, 3, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q- galia L2 fazėje pagal 3 tarifą per mėnesį', 3837, 4, NULL, NULL),
	(10095, 18, 2, 3, 4, 4, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q- galia L2 fazėje pagal 4 tarifą per mėnesį', 3838, 4, NULL, NULL),
	(10096, 18, 2, 4, 4, 0, 3, 6, 30, NULL, 'Maksimali valandinė Q- galia L2 fazėje per mėnesį', 3834, 4, NULL, NULL),
	(10097, 18, 2, 4, 4, 1, 3, 6, 30, NULL, 'Maksimali valandinė Q- galia L2 fazėje pagal 1 tarifą per mėnesį', 3835, 4, NULL, NULL),
	(10098, 18, 2, 4, 4, 2, 3, 6, 30, NULL, 'Maksimali valandinė Q- galia L2 fazėje pagal 2 tarifą per mėnesį', 3836, 4, NULL, NULL),
	(10099, 18, 2, 4, 4, 3, 3, 6, 30, NULL, 'Maksimali valandinė Q- galia L2 fazėje pagal 3 tarifą per mėnesį', 3837, 4, NULL, NULL),
	(10100, 18, 2, 4, 4, 4, 3, 6, 30, NULL, 'Maksimali valandinė Q- galia L2 fazėje pagal 4 tarifą per mėnesį', 3838, 4, NULL, NULL),
	(10101, 18, 2, 13, 4, 0, 3, 6, 30, NULL, 'Maksimali 15 minučių Q- galia L2 fazėje per mėnesį', 3834, 4, NULL, NULL),
	(10102, 18, 2, 13, 4, 1, 3, 6, 30, NULL, 'Maksimali 15 minučių Q- galia L2 fazėje pagal 1 tarifą per mėnesį', 3835, 4, NULL, NULL),
	(10103, 18, 2, 13, 4, 2, 3, 6, 30, NULL, 'Maksimali 15 minučių Q- galia L2 fazėje pagal 2 tarifą per mėnesį', 3836, 4, NULL, NULL),
	(10104, 18, 2, 13, 4, 3, 3, 6, 30, NULL, 'Maksimali 15 minučių Q- galia L2 fazėje pagal 3 tarifą per mėnesį', 3837, 4, NULL, NULL),
	(10105, 18, 2, 13, 4, 4, 3, 6, 30, NULL, 'Maksimali 15 minučių Q- galia L2 fazėje pagal 4 tarifą per mėnesį', 3838, 4, NULL, NULL),
	(10106, 18, 5, 3, 4, 0, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q1 galia L2 fazėje per mėnesį', 3839, 4, NULL, NULL),
	(10107, 18, 5, 3, 4, 1, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q1 galia L2 fazėje pagal 1 tarifą per mėnesį', 3840, 4, NULL, NULL),
	(10108, 18, 5, 3, 4, 2, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q1 galia L2 fazėje pagal 2 tarifą per mėnesį', 3841, 4, NULL, NULL),
	(10109, 18, 5, 3, 4, 3, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q1 galia L2 fazėje pagal 3 tarifą per mėnesį', 3842, 4, NULL, NULL),
	(10110, 18, 5, 3, 4, 4, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q1 galia L2 fazėje pagal 4 tarifą per mėnesį', 3843, 4, NULL, NULL),
	(10111, 18, 5, 4, 4, 0, 3, 6, 30, NULL, 'Maksimali valandinė Q1 galia L2 fazėje per mėnesį', 3839, 4, NULL, NULL),
	(10112, 18, 5, 4, 4, 1, 3, 6, 30, NULL, 'Maksimali valandinė Q1 galia L2 fazėje pagal 1 tarifą per mėnesį', 3840, 4, NULL, NULL),
	(10113, 18, 5, 4, 4, 2, 3, 6, 30, NULL, 'Maksimali valandinė Q1 galia L2 fazėje pagal 2 tarifą per mėnesį', 3841, 4, NULL, NULL),
	(10114, 18, 5, 4, 4, 3, 3, 6, 30, NULL, 'Maksimali valandinė Q1 galia L2 fazėje pagal 3 tarifą per mėnesį', 3842, 4, NULL, NULL),
	(10115, 18, 5, 4, 4, 4, 3, 6, 30, NULL, 'Maksimali valandinė Q1 galia L2 fazėje pagal 4 tarifą per mėnesį', 3843, 4, NULL, NULL),
	(10116, 18, 5, 13, 4, 0, 3, 6, 30, NULL, 'Maksimali 15 minučių Q1 galia L2 fazėje per mėnesį', 3839, 4, NULL, NULL),
	(10117, 18, 5, 13, 4, 1, 3, 6, 30, NULL, 'Maksimali 15 minučių Q1 galia L2 fazėje pagal 1 tarifą per mėnesį', 3840, 4, NULL, NULL),
	(10118, 18, 5, 13, 4, 2, 3, 6, 30, NULL, 'Maksimali 15 minučių Q1 galia L2 fazėje pagal 2 tarifą per mėnesį', 3841, 4, NULL, NULL),
	(10119, 18, 5, 13, 4, 3, 3, 6, 30, NULL, 'Maksimali 15 minučių Q1 galia L2 fazėje pagal 3 tarifą per mėnesį', 3842, 4, NULL, NULL),
	(10120, 18, 5, 13, 4, 4, 3, 6, 30, NULL, 'Maksimali 15 minučių Q1 galia L2 fazėje pagal 4 tarifą per mėnesį', 3843, 4, NULL, NULL),
	(10121, 18, 6, 3, 4, 0, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q2 galia L2 fazėje per mėnesį', 3844, 4, NULL, NULL),
	(10122, 18, 6, 3, 4, 1, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q2 galia L2 fazėje pagal 1 tarifą per mėnesį', 3845, 4, NULL, NULL),
	(10123, 18, 6, 3, 4, 2, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q2 galia L2 fazėje pagal 2 tarifą per mėnesį', 3846, 4, NULL, NULL),
	(10124, 18, 6, 3, 4, 3, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q2 galia L2 fazėje pagal 3 tarifą per mėnesį', 3847, 4, NULL, NULL),
	(10125, 18, 6, 3, 4, 4, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q2 galia L2 fazėje pagal 4 tarifą per mėnesį', 3848, 4, NULL, NULL),
	(10126, 18, 6, 4, 4, 0, 3, 6, 30, NULL, 'Maksimali valandinė Q2 galia L2 fazėje per mėnesį', 3844, 4, NULL, NULL),
	(10127, 18, 6, 4, 4, 1, 3, 6, 30, NULL, 'Maksimali valandinė Q2 galia L2 fazėje pagal 1 tarifą per mėnesį', 3845, 4, NULL, NULL),
	(10128, 18, 6, 4, 4, 2, 3, 6, 30, NULL, 'Maksimali valandinė Q2 galia L2 fazėje pagal 2 tarifą per mėnesį', 3846, 4, NULL, NULL),
	(10129, 18, 6, 4, 4, 3, 3, 6, 30, NULL, 'Maksimali valandinė Q2 galia L2 fazėje pagal 3 tarifą per mėnesį', 3847, 4, NULL, NULL),
	(10130, 18, 6, 4, 4, 4, 3, 6, 30, NULL, 'Maksimali valandinė Q2 galia L2 fazėje pagal 4 tarifą per mėnesį', 3848, 4, NULL, NULL),
	(10131, 18, 6, 13, 4, 0, 3, 6, 30, NULL, 'Maksimali 15 minučių Q2 galia L2 fazėje per mėnesį', 3844, 4, NULL, NULL),
	(10132, 18, 6, 13, 4, 1, 3, 6, 30, NULL, 'Maksimali 15 minučių Q2 galia L2 fazėje pagal 1 tarifą per mėnesį', 3845, 4, NULL, NULL),
	(10133, 18, 6, 13, 4, 2, 3, 6, 30, NULL, 'Maksimali 15 minučių Q2 galia L2 fazėje pagal 2 tarifą per mėnesį', 3846, 4, NULL, NULL),
	(10134, 18, 6, 13, 4, 3, 3, 6, 30, NULL, 'Maksimali 15 minučių Q2 galia L2 fazėje pagal 3 tarifą per mėnesį', 3847, 4, NULL, NULL),
	(10135, 18, 6, 13, 4, 4, 3, 6, 30, NULL, 'Maksimali 15 minučių Q2 galia L2 fazėje pagal 4 tarifą per mėnesį', 3848, 4, NULL, NULL),
	(10136, 18, 7, 3, 4, 0, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q3 galia L2 fazėje per mėnesį', 3849, 4, NULL, NULL),
	(10137, 18, 7, 3, 4, 1, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q3 galia L2 fazėje pagal 1 tarifą per mėnesį', 3850, 4, NULL, NULL),
	(10138, 18, 7, 3, 4, 2, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q3 galia L2 fazėje pagal 2 tarifą per mėnesį', 3851, 4, NULL, NULL),
	(10139, 18, 7, 3, 4, 3, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q3 galia L2 fazėje pagal 3 tarifą per mėnesį', 3852, 4, NULL, NULL),
	(10140, 18, 7, 3, 4, 4, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q3 galia L2 fazėje pagal 4 tarifą per mėnesį', 3853, 4, NULL, NULL),
	(10141, 18, 7, 4, 4, 0, 3, 6, 30, NULL, 'Maksimali valandinė Q3 galia L2 fazėje per mėnesį', 3849, 4, NULL, NULL),
	(10142, 18, 7, 4, 4, 1, 3, 6, 30, NULL, 'Maksimali valandinė Q3 galia L2 fazėje pagal 1 tarifą per mėnesį', 3850, 4, NULL, NULL),
	(10143, 18, 7, 4, 4, 2, 3, 6, 30, NULL, 'Maksimali valandinė Q3 galia L2 fazėje pagal 2 tarifą per mėnesį', 3851, 4, NULL, NULL),
	(10144, 18, 7, 4, 4, 3, 3, 6, 30, NULL, 'Maksimali valandinė Q3 galia L2 fazėje pagal 3 tarifą per mėnesį', 3852, 4, NULL, NULL),
	(10145, 18, 7, 4, 4, 4, 3, 6, 30, NULL, 'Maksimali valandinė Q3 galia L2 fazėje pagal 4 tarifą per mėnesį', 3853, 4, NULL, NULL),
	(10146, 18, 7, 13, 4, 0, 3, 6, 30, NULL, 'Maksimali 15 minučių Q3 galia L2 fazėje per mėnesį', 3849, 4, NULL, NULL),
	(10147, 18, 7, 13, 4, 1, 3, 6, 30, NULL, 'Maksimali 15 minučių Q3 galia L2 fazėje pagal 1 tarifą per mėnesį', 3850, 4, NULL, NULL),
	(10148, 18, 7, 13, 4, 2, 3, 6, 30, NULL, 'Maksimali 15 minučių Q3 galia L2 fazėje pagal 2 tarifą per mėnesį', 3851, 4, NULL, NULL),
	(10149, 18, 7, 13, 4, 3, 3, 6, 30, NULL, 'Maksimali 15 minučių Q3 galia L2 fazėje pagal 3 tarifą per mėnesį', 3852, 4, NULL, NULL),
	(10150, 18, 7, 13, 4, 4, 3, 6, 30, NULL, 'Maksimali 15 minučių Q3 galia L2 fazėje pagal 4 tarifą per mėnesį', 3853, 4, NULL, NULL),
	(10151, 18, 8, 3, 4, 0, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q4 galia L2 fazėje per mėnesį', 3854, 4, NULL, NULL),
	(10152, 18, 8, 3, 4, 1, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q4 galia L2 fazėje pagal 1 tarifą per mėnesį', 3855, 4, NULL, NULL),
	(10153, 18, 8, 3, 4, 2, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q4 galia L2 fazėje pagal 2 tarifą per mėnesį', 3856, 4, NULL, NULL),
	(10154, 18, 8, 3, 4, 3, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q4 galia L2 fazėje pagal 3 tarifą per mėnesį', 3857, 4, NULL, NULL),
	(10155, 18, 8, 3, 4, 4, 3, 6, 30, NULL, 'Maksimali pusvalandinė Q4 galia L2 fazėje pagal 4 tarifą per mėnesį', 3858, 4, NULL, NULL),
	(10156, 18, 8, 4, 4, 0, 3, 6, 30, NULL, 'Maksimali valandinė Q4 galia L2 fazėje per mėnesį', 3854, 4, NULL, NULL),
	(10157, 18, 8, 4, 4, 1, 3, 6, 30, NULL, 'Maksimali valandinė Q4 galia L2 fazėje pagal 1 tarifą per mėnesį', 3855, 4, NULL, NULL),
	(10158, 18, 8, 4, 4, 2, 3, 6, 30, NULL, 'Maksimali valandinė Q4 galia L2 fazėje pagal 2 tarifą per mėnesį', 3856, 4, NULL, NULL),
	(10159, 18, 8, 4, 4, 3, 3, 6, 30, NULL, 'Maksimali valandinė Q4 galia L2 fazėje pagal 3 tarifą per mėnesį', 3857, 4, NULL, NULL),
	(10160, 18, 8, 4, 4, 4, 3, 6, 30, NULL, 'Maksimali valandinė Q4 galia L2 fazėje pagal 4 tarifą per mėnesį', 3858, 4, NULL, NULL),
	(10161, 18, 8, 13, 4, 0, 3, 6, 30, NULL, 'Maksimali 15 minučių Q4 galia L2 fazėje per mėnesį', 3854, 4, NULL, NULL),
	(10162, 18, 8, 13, 4, 1, 3, 6, 30, NULL, 'Maksimali 15 minučių Q4 galia L2 fazėje pagal 1 tarifą per mėnesį', 3855, 4, NULL, NULL),
	(10163, 18, 8, 13, 4, 2, 3, 6, 30, NULL, 'Maksimali 15 minučių Q4 galia L2 fazėje pagal 2 tarifą per mėnesį', 3856, 4, NULL, NULL),
	(10164, 18, 8, 13, 4, 3, 3, 6, 30, NULL, 'Maksimali 15 minučių Q4 galia L2 fazėje pagal 3 tarifą per mėnesį', 3857, 4, NULL, NULL),
	(10165, 18, 8, 13, 4, 4, 3, 6, 30, NULL, 'Maksimali 15 minučių Q4 galia L2 fazėje pagal 4 tarifą per mėnesį', 3858, 4, NULL, NULL),
	(10166, 21, 1, 3, 4, 0, 7, 6, 33, NULL, 'Maksimali pusvalandinė S+ galia L2 fazėje per mėnesį', 3859, 4, NULL, NULL),
	(10167, 21, 1, 3, 4, 1, 7, 6, 33, NULL, 'Maksimali pusvalandinė S+ galia L2 fazėje pagal 1 tarifą per mėnesį', 3860, 4, NULL, NULL),
	(10168, 21, 1, 3, 4, 2, 7, 6, 33, NULL, 'Maksimali pusvalandinė S+ galia L2 fazėje pagal 2 tarifą per mėnesį', 3861, 4, NULL, NULL),
	(10169, 21, 1, 3, 4, 3, 7, 6, 33, NULL, 'Maksimali pusvalandinė S+ galia L2 fazėje pagal 3 tarifą per mėnesį', 3862, 4, NULL, NULL),
	(10170, 21, 1, 3, 4, 4, 7, 6, 33, NULL, 'Maksimali pusvalandinė S+ galia L2 fazėje pagal 4 tarifą per mėnesį', 3863, 4, NULL, NULL),
	(10171, 21, 1, 4, 4, 0, 7, 6, 33, NULL, 'Maksimali valandinė S+ galia L2 fazėje per mėnesį', 3859, 4, NULL, NULL),
	(10172, 21, 1, 4, 4, 1, 7, 6, 33, NULL, 'Maksimali valandinė S+ galia L2 fazėje pagal 1 tarifą per mėnesį', 3860, 4, NULL, NULL),
	(10173, 21, 1, 4, 4, 2, 7, 6, 33, NULL, 'Maksimali valandinė S+ galia L2 fazėje pagal 2 tarifą per mėnesį', 3861, 4, NULL, NULL),
	(10174, 21, 1, 4, 4, 3, 7, 6, 33, NULL, 'Maksimali valandinė S+ galia L2 fazėje pagal 3 tarifą per mėnesį', 3862, 4, NULL, NULL),
	(10175, 21, 1, 4, 4, 4, 7, 6, 33, NULL, 'Maksimali valandinė S+ galia L2 fazėje pagal 4 tarifą per mėnesį', 3863, 4, NULL, NULL),
	(10176, 21, 1, 13, 4, 0, 7, 6, 33, NULL, 'Maksimali 15 minučių S+ galia L2 fazėje per mėnesį', 3859, 4, NULL, NULL),
	(10177, 21, 1, 13, 4, 1, 7, 6, 33, NULL, 'Maksimali 15 minučių S+ galia L2 fazėje pagal 1 tarifą per mėnesį', 3860, 4, NULL, NULL),
	(10178, 21, 1, 13, 4, 2, 7, 6, 33, NULL, 'Maksimali 15 minučių S+ galia L2 fazėje pagal 2 tarifą per mėnesį', 3861, 4, NULL, NULL),
	(10179, 21, 1, 13, 4, 3, 7, 6, 33, NULL, 'Maksimali 15 minučių S+ galia L2 fazėje pagal 3 tarifą per mėnesį', 3862, 4, NULL, NULL),
	(10180, 21, 1, 13, 4, 4, 7, 6, 33, NULL, 'Maksimali 15 minučių S+ galia L2 fazėje pagal 4 tarifą per mėnesį', 3863, 4, NULL, NULL),
	(10181, 21, 2, 3, 4, 0, 7, 6, 33, NULL, 'Maksimali pusvalandinė S- galia L2 fazėje per mėnesį', 3864, 4, NULL, NULL),
	(10182, 21, 2, 3, 4, 1, 7, 6, 33, NULL, 'Maksimali pusvalandinė S- galia L2 fazėje pagal 1 tarifą per mėnesį', 3865, 4, NULL, NULL),
	(10183, 21, 2, 3, 4, 2, 7, 6, 33, NULL, 'Maksimali pusvalandinė S- galia L2 fazėje pagal 2 tarifą per mėnesį', 3866, 4, NULL, NULL),
	(10184, 21, 2, 3, 4, 3, 7, 6, 33, NULL, 'Maksimali pusvalandinė S- galia L2 fazėje pagal 3 tarifą per mėnesį', 3867, 4, NULL, NULL),
	(10185, 21, 2, 3, 4, 4, 7, 6, 33, NULL, 'Maksimali pusvalandinė S- galia L2 fazėje pagal 4 tarifą per mėnesį', 3868, 4, NULL, NULL),
	(10186, 21, 2, 4, 4, 0, 7, 6, 33, NULL, 'Maksimali valandinė S- galia L2 fazėje per mėnesį', 3864, 4, NULL, NULL),
	(10187, 21, 2, 4, 4, 1, 7, 6, 33, NULL, 'Maksimali valandinė S- galia L2 fazėje pagal 1 tarifą per mėnesį', 3865, 4, NULL, NULL),
	(10188, 21, 2, 4, 4, 2, 7, 6, 33, NULL, 'Maksimali valandinė S- galia L2 fazėje pagal 2 tarifą per mėnesį', 3866, 4, NULL, NULL),
	(10189, 21, 2, 4, 4, 3, 7, 6, 33, NULL, 'Maksimali valandinė S- galia L2 fazėje pagal 3 tarifą per mėnesį', 3867, 4, NULL, NULL),
	(10190, 21, 2, 4, 4, 4, 7, 6, 33, NULL, 'Maksimali valandinė S- galia L2 fazėje pagal 4 tarifą per mėnesį', 3868, 4, NULL, NULL),
	(10191, 21, 2, 13, 4, 0, 7, 6, 33, NULL, 'Maksimali 15 minučių S- galia L2 fazėje per mėnesį', 3864, 4, NULL, NULL),
	(10192, 21, 2, 13, 4, 1, 7, 6, 33, NULL, 'Maksimali 15 minučių S- galia L2 fazėje pagal 1 tarifą per mėnesį', 3865, 4, NULL, NULL),
	(10193, 21, 2, 13, 4, 2, 7, 6, 33, NULL, 'Maksimali 15 minučių S- galia L2 fazėje pagal 2 tarifą per mėnesį', 3866, 4, NULL, NULL),
	(10194, 21, 2, 13, 4, 3, 7, 6, 33, NULL, 'Maksimali 15 minučių S- galia L2 fazėje pagal 3 tarifą per mėnesį', 3867, 4, NULL, NULL),
	(10195, 21, 2, 13, 4, 4, 7, 6, 33, NULL, 'Maksimali 15 minučių S- galia L2 fazėje pagal 4 tarifą per mėnesį', 3868, 4, NULL, NULL),
	(10196, 16, 1, 3, 4, 0, 1, 6, 28, NULL, 'Maksimali pusvalandinė P+ galia L3 fazėje per mėnesį', 3869, 4, NULL, NULL),
	(10197, 16, 1, 3, 4, 1, 1, 6, 28, NULL, 'Maksimali pusvalandinė P+ galia L3 fazėje pagal 1 tarifą per mėnesį', 3870, 4, NULL, NULL),
	(10198, 16, 1, 3, 4, 2, 1, 6, 28, NULL, 'Maksimali pusvalandinė P+ galia L3 fazėje pagal 2 tarifą per mėnesį', 3871, 4, NULL, NULL),
	(10199, 16, 1, 3, 4, 3, 1, 6, 28, NULL, 'Maksimali pusvalandinė P+ galia L3 fazėje pagal 3 tarifą per mėnesį', 3872, 4, NULL, NULL),
	(10200, 16, 1, 3, 4, 4, 1, 6, 28, NULL, 'Maksimali pusvalandinė P+ galia L3 fazėje pagal 4 tarifą per mėnesį', 3873, 4, NULL, NULL),
	(10201, 16, 1, 4, 4, 0, 1, 6, 28, NULL, 'Maksimali valandinė P+ galia L3 fazėje per mėnesį', 3869, 4, NULL, NULL),
	(10202, 16, 1, 4, 4, 1, 1, 6, 28, NULL, 'Maksimali valandinė P+ galia L3 fazėje pagal 1 tarifą per mėnesį', 3870, 4, NULL, NULL),
	(10203, 16, 1, 4, 4, 2, 1, 6, 28, NULL, 'Maksimali valandinė P+ galia L3 fazėje pagal 2 tarifą per mėnesį', 3871, 4, NULL, NULL),
	(10204, 16, 1, 4, 4, 3, 1, 6, 28, NULL, 'Maksimali valandinė P+ galia L3 fazėje pagal 3 tarifą per mėnesį', 3872, 4, NULL, NULL),
	(10205, 16, 1, 4, 4, 4, 1, 6, 28, NULL, 'Maksimali valandinė P+ galia L3 fazėje pagal 4 tarifą per mėnesį', 3873, 4, NULL, NULL),
	(10206, 16, 1, 13, 4, 0, 1, 6, 28, NULL, 'Maksimali 15 minučių P+ galia L3 fazėje per mėnesį', 3869, 4, NULL, NULL),
	(10207, 16, 1, 13, 4, 1, 1, 6, 28, NULL, 'Maksimali 15 minučių P+ galia L3 fazėje pagal 1 tarifą per mėnesį', 3870, 4, NULL, NULL),
	(10208, 16, 1, 13, 4, 2, 1, 6, 28, NULL, 'Maksimali 15 minučių P+ galia L3 fazėje pagal 2 tarifą per mėnesį', 3871, 4, NULL, NULL),
	(10209, 16, 1, 13, 4, 3, 1, 6, 28, NULL, 'Maksimali 15 minučių P+ galia L3 fazėje pagal 3 tarifą per mėnesį', 3872, 4, NULL, NULL),
	(10210, 16, 1, 13, 4, 4, 1, 6, 28, NULL, 'Maksimali 15 minučių P+ galia L3 fazėje pagal 4 tarifą per mėnesį', 3873, 4, NULL, NULL),
	(10211, 16, 2, 3, 4, 0, 1, 6, 28, NULL, 'Maksimali pusvalandinė P- galia L3 fazėje per mėnesį', 3874, 4, NULL, NULL),
	(10212, 16, 2, 3, 4, 1, 1, 6, 28, NULL, 'Maksimali pusvalandinė P- galia L3 fazėje pagal 1 tarifą per mėnesį', 3875, 4, NULL, NULL),
	(10213, 16, 2, 3, 4, 2, 1, 6, 28, NULL, 'Maksimali pusvalandinė P- galia L3 fazėje pagal 2 tarifą per mėnesį', 3876, 4, NULL, NULL),
	(10214, 16, 2, 3, 4, 3, 1, 6, 28, NULL, 'Maksimali pusvalandinė P- galia L3 fazėje pagal 3 tarifą per mėnesį', 3877, 4, NULL, NULL),
	(10215, 16, 2, 3, 4, 4, 1, 6, 28, NULL, 'Maksimali pusvalandinė P- galia L3 fazėje pagal 4 tarifą per mėnesį', 3878, 4, NULL, NULL),
	(10216, 16, 2, 4, 4, 0, 1, 6, 28, NULL, 'Maksimali valandinė P- galia L3 fazėje per mėnesį', 3874, 4, NULL, NULL),
	(10217, 16, 2, 4, 4, 1, 1, 6, 28, NULL, 'Maksimali valandinė P- galia L3 fazėje pagal 1 tarifą per mėnesį', 3875, 4, NULL, NULL),
	(10218, 16, 2, 4, 4, 2, 1, 6, 28, NULL, 'Maksimali valandinė P- galia L3 fazėje pagal 2 tarifą per mėnesį', 3876, 4, NULL, NULL),
	(10219, 16, 2, 4, 4, 3, 1, 6, 28, NULL, 'Maksimali valandinė P- galia L3 fazėje pagal 3 tarifą per mėnesį', 3877, 4, NULL, NULL),
	(10220, 16, 2, 4, 4, 4, 1, 6, 28, NULL, 'Maksimali valandinė P- galia L3 fazėje pagal 4 tarifą per mėnesį', 3878, 4, NULL, NULL),
	(10221, 16, 2, 13, 4, 0, 1, 6, 28, NULL, 'Maksimali 15 minučių P- galia L3 fazėje per mėnesį', 3874, 4, NULL, NULL),
	(10222, 16, 2, 13, 4, 1, 1, 6, 28, NULL, 'Maksimali 15 minučių P- galia L3 fazėje pagal 1 tarifą per mėnesį', 3875, 4, NULL, NULL),
	(10223, 16, 2, 13, 4, 2, 1, 6, 28, NULL, 'Maksimali 15 minučių P- galia L3 fazėje pagal 2 tarifą per mėnesį', 3876, 4, NULL, NULL),
	(10224, 16, 2, 13, 4, 3, 1, 6, 28, NULL, 'Maksimali 15 minučių P- galia L3 fazėje pagal 3 tarifą per mėnesį', 3877, 4, NULL, NULL),
	(10225, 16, 2, 13, 4, 4, 1, 6, 28, NULL, 'Maksimali 15 minučių P- galia L3 fazėje pagal 4 tarifą per mėnesį', 3878, 4, NULL, NULL),
	(10226, 19, 1, 3, 4, 0, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q+ galia L3 fazėje per mėnesį', 3879, 4, NULL, NULL),
	(10227, 19, 1, 3, 4, 1, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q+ galia L3 fazėje pagal 1 tarifą per mėnesį', 3880, 4, NULL, NULL),
	(10228, 19, 1, 3, 4, 2, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q+ galia L3 fazėje pagal 2 tarifą per mėnesį', 3881, 4, NULL, NULL),
	(10229, 19, 1, 3, 4, 3, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q+ galia L3 fazėje pagal 3 tarifą per mėnesį', 3882, 4, NULL, NULL),
	(10230, 19, 1, 3, 4, 4, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q+ galia L3 fazėje pagal 4 tarifą per mėnesį', 3883, 4, NULL, NULL),
	(10231, 19, 1, 4, 4, 0, 3, 6, 31, NULL, 'Maksimali valandinė Q+ galia L3 fazėje per mėnesį', 3879, 4, NULL, NULL),
	(10232, 19, 1, 4, 4, 1, 3, 6, 31, NULL, 'Maksimali valandinė Q+ galia L3 fazėje pagal 1 tarifą per mėnesį', 3880, 4, NULL, NULL),
	(10233, 19, 1, 4, 4, 2, 3, 6, 31, NULL, 'Maksimali valandinė Q+ galia L3 fazėje pagal 2 tarifą per mėnesį', 3881, 4, NULL, NULL),
	(10234, 19, 1, 4, 4, 3, 3, 6, 31, NULL, 'Maksimali valandinė Q+ galia L3 fazėje pagal 3 tarifą per mėnesį', 3882, 4, NULL, NULL),
	(10235, 19, 1, 4, 4, 4, 3, 6, 31, NULL, 'Maksimali valandinė Q+ galia L3 fazėje pagal 4 tarifą per mėnesį', 3883, 4, NULL, NULL),
	(10236, 19, 1, 13, 4, 0, 3, 6, 31, NULL, 'Maksimali 15 minučių Q+ galia L3 fazėje per mėnesį', 3879, 4, NULL, NULL),
	(10237, 19, 1, 13, 4, 1, 3, 6, 31, NULL, 'Maksimali 15 minučių Q+ galia L3 fazėje pagal 1 tarifą per mėnesį', 3880, 4, NULL, NULL),
	(10238, 19, 1, 13, 4, 2, 3, 6, 31, NULL, 'Maksimali 15 minučių Q+ galia L3 fazėje pagal 2 tarifą per mėnesį', 3881, 4, NULL, NULL),
	(10239, 19, 1, 13, 4, 3, 3, 6, 31, NULL, 'Maksimali 15 minučių Q+ galia L3 fazėje pagal 3 tarifą per mėnesį', 3882, 4, NULL, NULL),
	(10240, 19, 1, 13, 4, 4, 3, 6, 31, NULL, 'Maksimali 15 minučių Q+ galia L3 fazėje pagal 4 tarifą per mėnesį', 3883, 4, NULL, NULL),
	(10241, 19, 2, 3, 4, 0, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q- galia L3 fazėje per mėnesį', 3884, 4, NULL, NULL),
	(10242, 19, 2, 3, 4, 1, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q- galia L3 fazėje pagal 1 tarifą per mėnesį', 3885, 4, NULL, NULL),
	(10243, 19, 2, 3, 4, 2, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q- galia L3 fazėje pagal 2 tarifą per mėnesį', 3886, 4, NULL, NULL),
	(10244, 19, 2, 3, 4, 3, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q- galia L3 fazėje pagal 3 tarifą per mėnesį', 3887, 4, NULL, NULL),
	(10245, 19, 2, 3, 4, 4, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q- galia L3 fazėje pagal 4 tarifą per mėnesį', 3888, 4, NULL, NULL),
	(10246, 19, 2, 4, 4, 0, 3, 6, 31, NULL, 'Maksimali valandinė Q- galia L3 fazėje per mėnesį', 3884, 4, NULL, NULL),
	(10247, 19, 2, 4, 4, 1, 3, 6, 31, NULL, 'Maksimali valandinė Q- galia L3 fazėje pagal 1 tarifą per mėnesį', 3885, 4, NULL, NULL),
	(10248, 19, 2, 4, 4, 2, 3, 6, 31, NULL, 'Maksimali valandinė Q- galia L3 fazėje pagal 2 tarifą per mėnesį', 3886, 4, NULL, NULL),
	(10249, 19, 2, 4, 4, 3, 3, 6, 31, NULL, 'Maksimali valandinė Q- galia L3 fazėje pagal 3 tarifą per mėnesį', 3887, 4, NULL, NULL),
	(10250, 19, 2, 4, 4, 4, 3, 6, 31, NULL, 'Maksimali valandinė Q- galia L3 fazėje pagal 4 tarifą per mėnesį', 3888, 4, NULL, NULL),
	(10251, 19, 2, 13, 4, 0, 3, 6, 31, NULL, 'Maksimali 15 minučių Q- galia L3 fazėje per mėnesį', 3884, 4, NULL, NULL),
	(10252, 19, 2, 13, 4, 1, 3, 6, 31, NULL, 'Maksimali 15 minučių Q- galia L3 fazėje pagal 1 tarifą per mėnesį', 3885, 4, NULL, NULL),
	(10253, 19, 2, 13, 4, 2, 3, 6, 31, NULL, 'Maksimali 15 minučių Q- galia L3 fazėje pagal 2 tarifą per mėnesį', 3886, 4, NULL, NULL),
	(10254, 19, 2, 13, 4, 3, 3, 6, 31, NULL, 'Maksimali 15 minučių Q- galia L3 fazėje pagal 3 tarifą per mėnesį', 3887, 4, NULL, NULL),
	(10255, 19, 2, 13, 4, 4, 3, 6, 31, NULL, 'Maksimali 15 minučių Q- galia L3 fazėje pagal 4 tarifą per mėnesį', 3888, 4, NULL, NULL),
	(10256, 19, 5, 3, 4, 0, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q1 galia L3 fazėje per mėnesį', 3889, 4, NULL, NULL),
	(10257, 19, 5, 3, 4, 1, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q1 galia L3 fazėje pagal 1 tarifą per mėnesį', 3890, 4, NULL, NULL),
	(10258, 19, 5, 3, 4, 2, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q1 galia L3 fazėje pagal 2 tarifą per mėnesį', 3891, 4, NULL, NULL),
	(10259, 19, 5, 3, 4, 3, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q1 galia L3 fazėje pagal 3 tarifą per mėnesį', 3892, 4, NULL, NULL),
	(10260, 19, 5, 3, 4, 4, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q1 galia L3 fazėje pagal 4 tarifą per mėnesį', 3893, 4, NULL, NULL),
	(10261, 19, 5, 4, 4, 0, 3, 6, 31, NULL, 'Maksimali valandinė Q1 galia L3 fazėje per mėnesį', 3889, 4, NULL, NULL),
	(10262, 19, 5, 4, 4, 1, 3, 6, 31, NULL, 'Maksimali valandinė Q1 galia L3 fazėje pagal 1 tarifą per mėnesį', 3890, 4, NULL, NULL),
	(10263, 19, 5, 4, 4, 2, 3, 6, 31, NULL, 'Maksimali valandinė Q1 galia L3 fazėje pagal 2 tarifą per mėnesį', 3891, 4, NULL, NULL),
	(10264, 19, 5, 4, 4, 3, 3, 6, 31, NULL, 'Maksimali valandinė Q1 galia L3 fazėje pagal 3 tarifą per mėnesį', 3892, 4, NULL, NULL),
	(10265, 19, 5, 4, 4, 4, 3, 6, 31, NULL, 'Maksimali valandinė Q1 galia L3 fazėje pagal 4 tarifą per mėnesį', 3893, 4, NULL, NULL),
	(10266, 19, 5, 13, 4, 0, 3, 6, 31, NULL, 'Maksimali 15 minučių Q1 galia L3 fazėje per mėnesį', 3889, 4, NULL, NULL),
	(10267, 19, 5, 13, 4, 1, 3, 6, 31, NULL, 'Maksimali 15 minučių Q1 galia L3 fazėje pagal 1 tarifą per mėnesį', 3890, 4, NULL, NULL),
	(10268, 19, 5, 13, 4, 2, 3, 6, 31, NULL, 'Maksimali 15 minučių Q1 galia L3 fazėje pagal 2 tarifą per mėnesį', 3891, 4, NULL, NULL),
	(10269, 19, 5, 13, 4, 3, 3, 6, 31, NULL, 'Maksimali 15 minučių Q1 galia L3 fazėje pagal 3 tarifą per mėnesį', 3892, 4, NULL, NULL),
	(10270, 19, 5, 13, 4, 4, 3, 6, 31, NULL, 'Maksimali 15 minučių Q1 galia L3 fazėje pagal 4 tarifą per mėnesį', 3893, 4, NULL, NULL),
	(10271, 19, 6, 3, 4, 0, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q2 galia L3 fazėje per mėnesį', 3894, 4, NULL, NULL),
	(10272, 19, 6, 3, 4, 1, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q2 galia L3 fazėje pagal 1 tarifą per mėnesį', 3895, 4, NULL, NULL),
	(10273, 19, 6, 3, 4, 2, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q2 galia L3 fazėje pagal 2 tarifą per mėnesį', 3896, 4, NULL, NULL),
	(10274, 19, 6, 3, 4, 3, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q2 galia L3 fazėje pagal 3 tarifą per mėnesį', 3897, 4, NULL, NULL),
	(10275, 19, 6, 3, 4, 4, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q2 galia L3 fazėje pagal 4 tarifą per mėnesį', 3898, 4, NULL, NULL),
	(10276, 19, 6, 4, 4, 0, 3, 6, 31, NULL, 'Maksimali valandinė Q2 galia L3 fazėje per mėnesį', 3894, 4, NULL, NULL),
	(10277, 19, 6, 4, 4, 1, 3, 6, 31, NULL, 'Maksimali valandinė Q2 galia L3 fazėje pagal 1 tarifą per mėnesį', 3895, 4, NULL, NULL),
	(10278, 19, 6, 4, 4, 2, 3, 6, 31, NULL, 'Maksimali valandinė Q2 galia L3 fazėje pagal 2 tarifą per mėnesį', 3896, 4, NULL, NULL),
	(10279, 19, 6, 4, 4, 3, 3, 6, 31, NULL, 'Maksimali valandinė Q2 galia L3 fazėje pagal 3 tarifą per mėnesį', 3897, 4, NULL, NULL),
	(10280, 19, 6, 4, 4, 4, 3, 6, 31, NULL, 'Maksimali valandinė Q2 galia L3 fazėje pagal 4 tarifą per mėnesį', 3898, 4, NULL, NULL),
	(10281, 19, 6, 13, 4, 0, 3, 6, 31, NULL, 'Maksimali 15 minučių Q2 galia L3 fazėje per mėnesį', 3894, 4, NULL, NULL),
	(10282, 19, 6, 13, 4, 1, 3, 6, 31, NULL, 'Maksimali 15 minučių Q2 galia L3 fazėje pagal 1 tarifą per mėnesį', 3895, 4, NULL, NULL),
	(10283, 19, 6, 13, 4, 2, 3, 6, 31, NULL, 'Maksimali 15 minučių Q2 galia L3 fazėje pagal 2 tarifą per mėnesį', 3896, 4, NULL, NULL),
	(10284, 19, 6, 13, 4, 3, 3, 6, 31, NULL, 'Maksimali 15 minučių Q2 galia L3 fazėje pagal 3 tarifą per mėnesį', 3897, 4, NULL, NULL),
	(10285, 19, 6, 13, 4, 4, 3, 6, 31, NULL, 'Maksimali 15 minučių Q2 galia L3 fazėje pagal 4 tarifą per mėnesį', 3898, 4, NULL, NULL),
	(10286, 19, 7, 3, 4, 0, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q3 galia L3 fazėje per mėnesį', 3899, 4, NULL, NULL),
	(10287, 19, 7, 3, 4, 1, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q3 galia L3 fazėje pagal 1 tarifą per mėnesį', 3900, 4, NULL, NULL),
	(10288, 19, 7, 3, 4, 2, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q3 galia L3 fazėje pagal 2 tarifą per mėnesį', 3901, 4, NULL, NULL),
	(10289, 19, 7, 3, 4, 3, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q3 galia L3 fazėje pagal 3 tarifą per mėnesį', 3902, 4, NULL, NULL),
	(10290, 19, 7, 3, 4, 4, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q3 galia L3 fazėje pagal 4 tarifą per mėnesį', 3903, 4, NULL, NULL),
	(10291, 19, 7, 4, 4, 0, 3, 6, 31, NULL, 'Maksimali valandinė Q3 galia L3 fazėje per mėnesį', 3899, 4, NULL, NULL),
	(10292, 19, 7, 4, 4, 1, 3, 6, 31, NULL, 'Maksimali valandinė Q3 galia L3 fazėje pagal 1 tarifą per mėnesį', 3900, 4, NULL, NULL),
	(10293, 19, 7, 4, 4, 2, 3, 6, 31, NULL, 'Maksimali valandinė Q3 galia L3 fazėje pagal 2 tarifą per mėnesį', 3901, 4, NULL, NULL),
	(10294, 19, 7, 4, 4, 3, 3, 6, 31, NULL, 'Maksimali valandinė Q3 galia L3 fazėje pagal 3 tarifą per mėnesį', 3902, 4, NULL, NULL),
	(10295, 19, 7, 4, 4, 4, 3, 6, 31, NULL, 'Maksimali valandinė Q3 galia L3 fazėje pagal 4 tarifą per mėnesį', 3903, 4, NULL, NULL),
	(10296, 19, 7, 13, 4, 0, 3, 6, 31, NULL, 'Maksimali 15 minučių Q3 galia L3 fazėje per mėnesį', 3899, 4, NULL, NULL),
	(10297, 19, 7, 13, 4, 1, 3, 6, 31, NULL, 'Maksimali 15 minučių Q3 galia L3 fazėje pagal 1 tarifą per mėnesį', 3900, 4, NULL, NULL),
	(10298, 19, 7, 13, 4, 2, 3, 6, 31, NULL, 'Maksimali 15 minučių Q3 galia L3 fazėje pagal 2 tarifą per mėnesį', 3901, 4, NULL, NULL),
	(10299, 19, 7, 13, 4, 3, 3, 6, 31, NULL, 'Maksimali 15 minučių Q3 galia L3 fazėje pagal 3 tarifą per mėnesį', 3902, 4, NULL, NULL),
	(10300, 19, 7, 13, 4, 4, 3, 6, 31, NULL, 'Maksimali 15 minučių Q3 galia L3 fazėje pagal 4 tarifą per mėnesį', 3903, 4, NULL, NULL),
	(10301, 19, 8, 3, 4, 0, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q4 galia L3 fazėje per mėnesį', 3904, 4, NULL, NULL),
	(10302, 19, 8, 3, 4, 1, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q4 galia L3 fazėje pagal 1 tarifą per mėnesį', 3905, 4, NULL, NULL),
	(10303, 19, 8, 3, 4, 2, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q4 galia L3 fazėje pagal 2 tarifą per mėnesį', 3906, 4, NULL, NULL),
	(10304, 19, 8, 3, 4, 3, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q4 galia L3 fazėje pagal 3 tarifą per mėnesį', 3907, 4, NULL, NULL),
	(10305, 19, 8, 3, 4, 4, 3, 6, 31, NULL, 'Maksimali pusvalandinė Q4 galia L3 fazėje pagal 4 tarifą per mėnesį', 3908, 4, NULL, NULL),
	(10306, 19, 8, 4, 4, 0, 3, 6, 31, NULL, 'Maksimali valandinė Q4 galia L3 fazėje per mėnesį', 3904, 4, NULL, NULL),
	(10307, 19, 8, 4, 4, 1, 3, 6, 31, NULL, 'Maksimali valandinė Q4 galia L3 fazėje pagal 1 tarifą per mėnesį', 3905, 4, NULL, NULL),
	(10308, 19, 8, 4, 4, 2, 3, 6, 31, NULL, 'Maksimali valandinė Q4 galia L3 fazėje pagal 2 tarifą per mėnesį', 3906, 4, NULL, NULL),
	(10309, 19, 8, 4, 4, 3, 3, 6, 31, NULL, 'Maksimali valandinė Q4 galia L3 fazėje pagal 3 tarifą per mėnesį', 3907, 4, NULL, NULL),
	(10310, 19, 8, 4, 4, 4, 3, 6, 31, NULL, 'Maksimali valandinė Q4 galia L3 fazėje pagal 4 tarifą per mėnesį', 3908, 4, NULL, NULL),
	(10311, 19, 8, 13, 4, 0, 3, 6, 31, NULL, 'Maksimali 15 minučių Q4 galia L3 fazėje per mėnesį', 3904, 4, NULL, NULL),
	(10312, 19, 8, 13, 4, 1, 3, 6, 31, NULL, 'Maksimali 15 minučių Q4 galia L3 fazėje pagal 1 tarifą per mėnesį', 3905, 4, NULL, NULL),
	(10313, 19, 8, 13, 4, 2, 3, 6, 31, NULL, 'Maksimali 15 minučių Q4 galia L3 fazėje pagal 2 tarifą per mėnesį', 3906, 4, NULL, NULL),
	(10314, 19, 8, 13, 4, 3, 3, 6, 31, NULL, 'Maksimali 15 minučių Q4 galia L3 fazėje pagal 3 tarifą per mėnesį', 3907, 4, NULL, NULL),
	(10315, 19, 8, 13, 4, 4, 3, 6, 31, NULL, 'Maksimali 15 minučių Q4 galia L3 fazėje pagal 4 tarifą per mėnesį', 3908, 4, NULL, NULL),
	(10316, 22, 1, 3, 4, 0, 7, 6, 34, NULL, 'Maksimali pusvalandinė S+ galia L3 fazėje per mėnesį', 3909, 4, NULL, NULL),
	(10317, 22, 1, 3, 4, 1, 7, 6, 34, NULL, 'Maksimali pusvalandinė S+ galia L3 fazėje pagal 1 tarifą per mėnesį', 3910, 4, NULL, NULL),
	(10318, 22, 1, 3, 4, 2, 7, 6, 34, NULL, 'Maksimali pusvalandinė S+ galia L3 fazėje pagal 2 tarifą per mėnesį', 3911, 4, NULL, NULL),
	(10319, 22, 1, 3, 4, 3, 7, 6, 34, NULL, 'Maksimali pusvalandinė S+ galia L3 fazėje pagal 3 tarifą per mėnesį', 3912, 4, NULL, NULL),
	(10320, 22, 1, 3, 4, 4, 7, 6, 34, NULL, 'Maksimali pusvalandinė S+ galia L3 fazėje pagal 4 tarifą per mėnesį', 3913, 4, NULL, NULL),
	(10321, 22, 1, 4, 4, 0, 7, 6, 34, NULL, 'Maksimali valandinė S+ galia L3 fazėje per mėnesį', 3909, 4, NULL, NULL),
	(10322, 22, 1, 4, 4, 1, 7, 6, 34, NULL, 'Maksimali valandinė S+ galia L3 fazėje pagal 1 tarifą per mėnesį', 3910, 4, NULL, NULL),
	(10323, 22, 1, 4, 4, 2, 7, 6, 34, NULL, 'Maksimali valandinė S+ galia L3 fazėje pagal 2 tarifą per mėnesį', 3911, 4, NULL, NULL),
	(10324, 22, 1, 4, 4, 3, 7, 6, 34, NULL, 'Maksimali valandinė S+ galia L3 fazėje pagal 3 tarifą per mėnesį', 3912, 4, NULL, NULL),
	(10325, 22, 1, 4, 4, 4, 7, 6, 34, NULL, 'Maksimali valandinė S+ galia L3 fazėje pagal 4 tarifą per mėnesį', 3913, 4, NULL, NULL),
	(10326, 22, 1, 13, 4, 0, 7, 6, 34, NULL, 'Maksimali 15 minučių S+ galia L3 fazėje per mėnesį', 3909, 4, NULL, NULL),
	(10327, 22, 1, 13, 4, 1, 7, 6, 34, NULL, 'Maksimali 15 minučių S+ galia L3 fazėje pagal 1 tarifą per mėnesį', 3910, 4, NULL, NULL),
	(10328, 22, 1, 13, 4, 2, 7, 6, 34, NULL, 'Maksimali 15 minučių S+ galia L3 fazėje pagal 2 tarifą per mėnesį', 3911, 4, NULL, NULL),
	(10329, 22, 1, 13, 4, 3, 7, 6, 34, NULL, 'Maksimali 15 minučių S+ galia L3 fazėje pagal 3 tarifą per mėnesį', 3912, 4, NULL, NULL),
	(10330, 22, 1, 13, 4, 4, 7, 6, 34, NULL, 'Maksimali 15 minučių S+ galia L3 fazėje pagal 4 tarifą per mėnesį', 3913, 4, NULL, NULL),
	(10331, 22, 2, 3, 4, 0, 7, 6, 34, NULL, 'Maksimali pusvalandinė S- galia L3 fazėje per mėnesį', 3914, 4, NULL, NULL),
	(10332, 22, 2, 3, 4, 1, 7, 6, 34, NULL, 'Maksimali pusvalandinė S- galia L3 fazėje pagal 1 tarifą per mėnesį', 3915, 4, NULL, NULL),
	(10333, 22, 2, 3, 4, 2, 7, 6, 34, NULL, 'Maksimali pusvalandinė S- galia L3 fazėje pagal 2 tarifą per mėnesį', 3916, 4, NULL, NULL),
	(10334, 22, 2, 3, 4, 3, 7, 6, 34, NULL, 'Maksimali pusvalandinė S- galia L3 fazėje pagal 3 tarifą per mėnesį', 3917, 4, NULL, NULL),
	(10335, 22, 2, 3, 4, 4, 7, 6, 34, NULL, 'Maksimali pusvalandinė S- galia L3 fazėje pagal 4 tarifą per mėnesį', 3918, 4, NULL, NULL),
	(10336, 22, 2, 4, 4, 0, 7, 6, 34, NULL, 'Maksimali valandinė S- galia L3 fazėje per mėnesį', 3914, 4, NULL, NULL),
	(10337, 22, 2, 4, 4, 1, 7, 6, 34, NULL, 'Maksimali valandinė S- galia L3 fazėje pagal 1 tarifą per mėnesį', 3915, 4, NULL, NULL),
	(10338, 22, 2, 4, 4, 2, 7, 6, 34, NULL, 'Maksimali valandinė S- galia L3 fazėje pagal 2 tarifą per mėnesį', 3916, 4, NULL, NULL),
	(10339, 22, 2, 4, 4, 3, 7, 6, 34, NULL, 'Maksimali valandinė S- galia L3 fazėje pagal 3 tarifą per mėnesį', 3917, 4, NULL, NULL),
	(10340, 22, 2, 4, 4, 4, 7, 6, 34, NULL, 'Maksimali valandinė S- galia L3 fazėje pagal 4 tarifą per mėnesį', 3918, 4, NULL, NULL),
	(10341, 22, 2, 13, 4, 0, 7, 6, 34, NULL, 'Maksimali 15 minučių S- galia L3 fazėje per mėnesį', 3914, 4, NULL, NULL),
	(10342, 22, 2, 13, 4, 1, 7, 6, 34, NULL, 'Maksimali 15 minučių S- galia L3 fazėje pagal 1 tarifą per mėnesį', 3915, 4, NULL, NULL),
	(10343, 22, 2, 13, 4, 2, 7, 6, 34, NULL, 'Maksimali 15 minučių S- galia L3 fazėje pagal 2 tarifą per mėnesį', 3916, 4, NULL, NULL),
	(10344, 22, 2, 13, 4, 3, 7, 6, 34, NULL, 'Maksimali 15 minučių S- galia L3 fazėje pagal 3 tarifą per mėnesį', 3917, 4, NULL, NULL),
	(10345, 22, 2, 13, 4, 4, 7, 6, 34, NULL, 'Maksimali 15 minučių S- galia L3 fazėje pagal 4 tarifą per mėnesį', 3918, 4, NULL, NULL),
	(10346, 396, 1, 8, 2, 1, 2, 7, 434, NULL, 'Suminė A+ nuostolių energija pagal 1 tarifą', 4055, 5, NULL, NULL),
	(10347, 396, 2, 8, 2, 1, 2, 7, 434, NULL, 'Suminė A- nuostolių energija pagal 1 tarifą', 4056, 5, NULL, NULL),
	(10348, 423, 1, 8, 2, 1, 4, 7, 436, NULL, 'Suminė R+ nuostolių energija pagal 1 tarifą', 4057, 5, NULL, NULL),
	(10349, 423, 2, 8, 2, 1, 4, 7, 436, NULL, 'Suminė R- nuostolių energija pagal 1 tarifą', 4058, 5, NULL, NULL),
	(10350, 396, 1, 8, 2, 2, 2, 7, 434, NULL, 'Suminė A+ nuostolių energija pagal 2 tarifą', 4059, 5, NULL, NULL),
	(10351, 396, 2, 8, 2, 2, 2, 7, 434, NULL, 'Suminė A- nuostolių energija pagal 2 tarifą', 4060, 5, NULL, NULL),
	(10352, 423, 1, 8, 2, 2, 4, 7, 436, NULL, 'Suminė R+ nuostolių energija pagal 2 tarifą', 4061, 5, NULL, NULL),
	(10353, 423, 2, 8, 2, 2, 4, 7, 436, NULL, 'Suminė R- nuostolių energija pagal 2 tarifą', 4062, 5, NULL, NULL),
	(10354, 396, 1, 8, 2, 3, 2, 7, 434, NULL, 'Suminė A+ nuostolių energija pagal 3 tarifą', 4063, 5, NULL, NULL),
	(10355, 396, 2, 8, 2, 3, 2, 7, 434, NULL, 'Suminė A- nuostolių energija pagal 3 tarifą', 4064, 5, NULL, NULL),
	(10356, 423, 1, 8, 2, 3, 4, 7, 436, NULL, 'Suminė R+ nuostolių energija pagal 3 tarifą', 4065, 5, NULL, NULL),
	(10357, 423, 2, 8, 2, 3, 4, 7, 436, NULL, 'Suminė R- nuostolių energija pagal 3 tarifą', 4066, 5, NULL, NULL),
	(10358, 396, 1, 8, 2, 4, 2, 7, 434, NULL, 'Suminė A+ nuostolių energija pagal 4 tarifą', 4067, 5, NULL, NULL),
	(10359, 396, 2, 8, 2, 4, 2, 7, 434, NULL, 'Suminė A- nuostolių energija pagal 4 tarifą', 4068, 5, NULL, NULL),
	(10360, 423, 1, 8, 2, 4, 4, 7, 436, NULL, 'Suminė R+ nuostolių energija pagal 4 tarifą', 4069, 5, NULL, NULL),
	(10361, 423, 2, 8, 2, 4, 4, 7, 436, NULL, 'Suminė R- nuostolių energija pagal 4 tarifą', 4070, 5, NULL, NULL),
	(10362, 396, 1, 8, 2, 5, 2, 7, 434, NULL, 'Suminė A+ nuostolių energija pagal 5 tarifą', 4071, 5, NULL, NULL),
	(10363, 396, 2, 8, 2, 5, 2, 7, 434, NULL, 'Suminė A- nuostolių energija pagal 5 tarifą', 4072, 5, NULL, NULL),
	(10364, 423, 1, 8, 2, 5, 4, 7, 436, NULL, 'Suminė R+ nuostolių energija pagal 5 tarifą', 4073, 5, NULL, NULL),
	(10365, 423, 2, 8, 2, 5, 4, 7, 436, NULL, 'Suminė R- nuostolių energija pagal 5 tarifą', 4074, 5, NULL, NULL),
	(10366, 396, 1, 8, 2, 6, 2, 7, 434, NULL, 'Suminė A+ nuostolių energija pagal 6 tarifą', 4075, 5, NULL, NULL),
	(10367, 396, 2, 8, 2, 6, 2, 7, 434, NULL, 'Suminė A- nuostolių energija pagal 6 tarifą', 4076, 5, NULL, NULL),
	(10368, 423, 1, 8, 2, 6, 4, 7, 436, NULL, 'Suminė R+ nuostolių energija pagal 6 tarifą', 4077, 5, NULL, NULL),
	(10369, 423, 2, 8, 2, 6, 4, 7, 436, NULL, 'Suminė R- nuostolių energija pagal 6 tarifą', 4078, 5, NULL, NULL),
	(10370, 396, 1, 8, 2, 7, 2, 7, 434, NULL, 'Suminė A+ nuostolių energija pagal 7 tarifą', 4079, 5, NULL, NULL),
	(10371, 396, 2, 8, 2, 7, 2, 7, 434, NULL, 'Suminė A- nuostolių energija pagal 7 tarifą', 4080, 5, NULL, NULL),
	(10372, 423, 1, 8, 2, 7, 4, 7, 436, NULL, 'Suminė R+ nuostolių energija pagal 7 tarifą', 4081, 5, NULL, NULL),
	(10373, 423, 2, 8, 2, 7, 4, 7, 436, NULL, 'Suminė R- nuostolių energija pagal 7 tarifą', 4082, 5, NULL, NULL),
	(10374, 396, 1, 8, 2, 8, 2, 7, 434, NULL, 'Suminė A+ nuostolių energija pagal 8 tarifą', 4083, 5, NULL, NULL),
	(10375, 396, 2, 8, 2, 8, 2, 7, 434, NULL, 'Suminė A- nuostolių energija pagal 8 tarifą', 4084, 5, NULL, NULL),
	(10376, 423, 1, 8, 2, 8, 4, 7, 436, NULL, 'Suminė R+ nuostolių energija pagal 8 tarifą', 4085, 5, NULL, NULL),
	(10377, 423, 2, 8, 2, 8, 4, 7, 436, NULL, 'Suminė R- nuostolių energija pagal 8 tarifą', 4086, 5, NULL, NULL),
	(10378, 396, 1, 8, 2, 0, 2, 7, 434, NULL, 'Suminė A+ nuostolių energija', 4087, 5, NULL, NULL),
	(10379, 396, 2, 8, 2, 0, 2, 7, 434, NULL, 'Suminė A- nuostolių energija', 4088, 5, NULL, NULL),
	(10380, 423, 1, 8, 2, 0, 4, 7, 436, NULL, 'Suminė R+ nuostolių energija', 4089, 5, NULL, NULL),
	(10381, 423, 2, 8, 2, 0, 4, 7, 436, NULL, 'Suminė R- nuostolių energija', 4090, 5, NULL, NULL),
	(10382, 396, 1, 5, 2, 1, 2, 5, 434, NULL, 'A+ nuostolių energija pagal 1 tarifą per parą ', 4091, 3, NULL, NULL),
	(10383, 396, 2, 5, 2, 1, 2, 5, 434, NULL, 'A- nuostolių energija pagal 1 tarifą per parą', 4092, 3, NULL, NULL),
	(10384, 423, 1, 5, 2, 1, 4, 5, 436, NULL, 'R+ nuostolių energija pagal 1 tarifą per parą', 4093, 3, NULL, NULL),
	(10385, 423, 2, 5, 2, 1, 4, 5, 436, NULL, 'R- nuostolių energija pagal 1 tarifą per parą', 4094, 3, NULL, NULL),
	(10386, 396, 1, 5, 2, 2, 2, 5, 434, NULL, 'A+ nuostolių energija pagal 2 tarifą per parą', 4095, 3, NULL, NULL),
	(10387, 396, 2, 5, 2, 2, 2, 5, 434, NULL, 'A- nuostolių energija pagal 2 tarifą per parą', 4096, 3, NULL, NULL),
	(10388, 423, 1, 5, 2, 2, 4, 5, 436, NULL, 'R+ nuostolių energija pagal 2 tarifą per parą', 4097, 3, NULL, NULL),
	(10389, 423, 2, 5, 2, 2, 4, 5, 436, NULL, 'R- nuostolių energija pagal 2 tarifą per parą', 4098, 3, NULL, NULL),
	(10390, 396, 1, 5, 2, 3, 2, 5, 434, NULL, 'A+ nuostolių energija pagal 3 tarifą per parą', 4099, 3, NULL, NULL),
	(10391, 396, 2, 5, 2, 3, 2, 5, 434, NULL, 'A- nuostolių energija pagal 3 tarifą per parą', 4100, 3, NULL, NULL),
	(10392, 423, 1, 5, 2, 3, 4, 5, 436, NULL, 'R+ nuostolių energija pagal 3 tarifą per parą', 4101, 3, NULL, NULL),
	(10393, 423, 2, 5, 2, 3, 4, 5, 436, NULL, 'R- nuostolių energija pagal 3 tarifą per parą', 4102, 3, NULL, NULL),
	(10394, 396, 1, 5, 2, 4, 2, 5, 434, NULL, 'A+ nuostolių energija pagal 4 tarifą per parą', 4103, 3, NULL, NULL),
	(10395, 396, 2, 5, 2, 4, 2, 5, 434, NULL, 'A- nuostolių energija pagal 4 tarifą per parą', 4104, 3, NULL, NULL),
	(10396, 423, 1, 5, 2, 4, 4, 5, 436, NULL, 'R+ nuostolių energija pagal 4 tarifą per parą', 4105, 3, NULL, NULL),
	(10397, 423, 2, 5, 2, 4, 4, 5, 436, NULL, 'R- nuostolių energija pagal 4 tarifą per parą', 4106, 3, NULL, NULL),
	(10398, 396, 1, 5, 2, 5, 2, 5, 434, NULL, 'A+ nuostolių energija pagal 5 tarifą per parą', 4107, 3, NULL, NULL),
	(10399, 396, 2, 5, 2, 5, 2, 5, 434, NULL, 'A- nuostolių energija pagal 5 tarifą per parą', 4108, 3, NULL, NULL),
	(10400, 423, 1, 5, 2, 5, 4, 5, 436, NULL, 'R+ nuostolių energija pagal 5 tarifą per parą', 4109, 3, NULL, NULL),
	(10401, 423, 2, 5, 2, 5, 4, 5, 436, NULL, 'R- nuostolių energija pagal 5 tarifą per parą', 4110, 3, NULL, NULL),
	(10402, 396, 1, 5, 2, 6, 2, 5, 434, NULL, 'A+ nuostolių energija pagal 6 tarifą per parą', 4111, 3, NULL, NULL),
	(10403, 396, 2, 5, 2, 6, 2, 5, 434, NULL, 'A- nuostolių energija pagal 6 tarifą per parą', 4112, 3, NULL, NULL),
	(10404, 423, 1, 5, 2, 6, 4, 5, 436, NULL, 'R+ nuostolių energija pagal 6 tarifą per parą', 4113, 3, NULL, NULL),
	(10405, 423, 2, 5, 2, 6, 4, 5, 436, NULL, 'R- nuostolių energija pagal 6 tarifą per parą', 4114, 3, NULL, NULL),
	(10406, 396, 1, 5, 2, 7, 2, 5, 434, NULL, 'A+ nuostolių energija pagal 7 tarifą per parą', 4115, 3, NULL, NULL),
	(10407, 396, 2, 5, 2, 7, 2, 5, 434, NULL, 'A- nuostolių energija pagal 7 tarifą per parą', 4116, 3, NULL, NULL),
	(10408, 423, 1, 5, 2, 7, 4, 5, 436, NULL, 'R+ nuostolių energija pagal 7 tarifą per parą', 4117, 3, NULL, NULL),
	(10409, 423, 2, 5, 2, 7, 4, 5, 436, NULL, 'R- nuostolių energija pagal 7 tarifą per parą', 4118, 3, NULL, NULL),
	(10410, 396, 1, 5, 2, 8, 2, 5, 434, NULL, 'A+ nuostolių energija pagal 8 tarifą per parą', 4119, 3, NULL, NULL),
	(10411, 396, 2, 5, 2, 8, 2, 5, 434, NULL, 'A- nuostolių energija pagal 8 tarifą per parą', 4120, 3, NULL, NULL),
	(10412, 423, 1, 5, 2, 8, 4, 5, 436, NULL, 'R+ nuostolių energija pagal 8 tarifą per parą', 4121, 3, NULL, NULL),
	(10413, 423, 2, 5, 2, 8, 4, 5, 436, NULL, 'R- nuostolių energija pagal 8 tarifą per parą', 4122, 3, NULL, NULL),
	(10414, 396, 1, 5, 2, 0, 2, 5, 434, NULL, 'A+ nuostolių energija per parą', 4123, 3, NULL, NULL),
	(10415, 396, 2, 5, 2, 0, 2, 5, 434, NULL, 'A- nuostolių energija per parą', 4124, 3, NULL, NULL),
	(10416, 423, 1, 5, 2, 0, 4, 5, 436, NULL, 'R+ nuostolių energija per parą', 4125, 3, NULL, NULL),
	(10417, 423, 2, 5, 2, 0, 4, 5, 436, NULL, 'R- nuostolių energija per parą', 4126, 3, NULL, NULL),
	(10418, 396, 1, 6, 2, 1, 2, 6, 434, NULL, 'A+ nuostolių energija pagal 1 tarifą per mėnesį ', 4127, 4, NULL, NULL),
	(10419, 396, 2, 6, 2, 1, 2, 6, 434, NULL, 'A- nuostolių energija pagal 1 tarifą per mėnesį', 4128, 4, NULL, NULL),
	(10420, 423, 1, 6, 2, 1, 4, 6, 436, NULL, 'R+ nuostolių energija pagal 1 tarifą per mėnesį', 4129, 4, NULL, NULL),
	(10421, 423, 2, 6, 2, 1, 4, 6, 436, NULL, 'R- nuostolių energija pagal 1 tarifą per mėnesį', 4130, 4, NULL, NULL),
	(10422, 396, 1, 6, 2, 2, 2, 6, 434, NULL, 'A+ nuostolių energija pagal 2 tarifą per mėnesį', 4131, 4, NULL, NULL),
	(10423, 396, 2, 6, 2, 2, 2, 6, 434, NULL, 'A- nuostolių energija pagal 2 tarifą per mėnesį', 4132, 4, NULL, NULL),
	(10424, 423, 1, 6, 2, 2, 4, 6, 436, NULL, 'R+ nuostolių energija pagal 2 tarifą per mėnesį', 4133, 4, NULL, NULL),
	(10425, 423, 2, 6, 2, 2, 4, 6, 436, NULL, 'R- nuostolių energija pagal 2 tarifą per mėnesį', 4134, 4, NULL, NULL),
	(10426, 396, 1, 6, 2, 3, 2, 6, 434, NULL, 'A+ nuostolių energija pagal 3 tarifą per mėnesį', 4135, 4, NULL, NULL),
	(10427, 396, 2, 6, 2, 3, 2, 6, 434, NULL, 'A- nuostolių energija pagal 3 tarifą per mėnesį', 4136, 4, NULL, NULL),
	(10428, 423, 1, 6, 2, 3, 4, 6, 436, NULL, 'R+ nuostolių energija pagal 3 tarifą per mėnesį', 4137, 4, NULL, NULL),
	(10429, 423, 2, 6, 2, 3, 4, 6, 436, NULL, 'R- nuostolių energija pagal 3 tarifą per mėnesį', 4138, 4, NULL, NULL),
	(10430, 396, 1, 6, 2, 4, 2, 6, 434, NULL, 'A+ nuostolių energija pagal 4 tarifą per mėnesį', 4139, 4, NULL, NULL),
	(10431, 396, 2, 6, 2, 4, 2, 6, 434, NULL, 'A- nuostolių energija pagal 4 tarifą per mėnesį', 4140, 4, NULL, NULL),
	(10432, 423, 1, 6, 2, 4, 4, 6, 436, NULL, 'R+ nuostolių energija pagal 4 tarifą per mėnesį', 4141, 4, NULL, NULL),
	(10433, 423, 2, 6, 2, 4, 4, 6, 436, NULL, 'R- nuostolių energija pagal 4 tarifą per mėnesį', 4142, 4, NULL, NULL),
	(10434, 396, 1, 6, 2, 5, 2, 6, 434, NULL, 'A+ nuostolių energija pagal 5 tarifą per mėnesį', 4143, 4, NULL, NULL),
	(10435, 396, 2, 6, 2, 5, 2, 6, 434, NULL, 'A- nuostolių energija pagal 5 tarifą per mėnesį', 4144, 4, NULL, NULL),
	(10436, 423, 1, 6, 2, 5, 4, 6, 436, NULL, 'R+ nuostolių energija pagal 5 tarifą per mėnesį', 4145, 4, NULL, NULL),
	(10437, 423, 2, 6, 2, 5, 4, 6, 436, NULL, 'R- nuostolių energija pagal 5 tarifą per mėnesį', 4146, 4, NULL, NULL),
	(10438, 396, 1, 6, 2, 6, 2, 6, 434, NULL, 'A+ nuostolių energija pagal 6 tarifą per mėnesį', 4147, 4, NULL, NULL),
	(10439, 396, 2, 6, 2, 6, 2, 6, 434, NULL, 'A- nuostolių energija pagal 6 tarifą per mėnesį', 4148, 4, NULL, NULL),
	(10440, 423, 1, 6, 2, 6, 4, 6, 436, NULL, 'R+ nuostolių energija pagal 6 tarifą per mėnesį', 4149, 4, NULL, NULL),
	(10441, 423, 2, 6, 2, 6, 4, 6, 436, NULL, 'R- nuostolių energija pagal 6 tarifą per mėnesį', 4150, 4, NULL, NULL),
	(10442, 396, 1, 6, 2, 7, 2, 6, 434, NULL, 'A+ nuostolių energija pagal 7 tarifą per mėnesį', 4151, 4, NULL, NULL),
	(10443, 396, 2, 6, 2, 7, 2, 6, 434, NULL, 'A- nuostolių energija pagal 7 tarifą per mėnesį', 4152, 4, NULL, NULL),
	(10444, 423, 1, 6, 2, 7, 4, 6, 436, NULL, 'R+ nuostolių energija pagal 7 tarifą per mėnesį', 4153, 4, NULL, NULL),
	(10445, 423, 2, 6, 2, 7, 4, 6, 436, NULL, 'R- nuostolių energija pagal 7 tarifą per mėnesį', 4154, 4, NULL, NULL),
	(10446, 396, 1, 6, 2, 8, 2, 6, 434, NULL, 'A+ nuostolių energija pagal 8 tarifą per mėnesį', 4155, 4, NULL, NULL),
	(10447, 396, 2, 6, 2, 8, 2, 6, 434, NULL, 'A- nuostolių energija pagal 8 tarifą per mėnesį', 4156, 4, NULL, NULL),
	(10448, 423, 1, 6, 2, 8, 4, 6, 436, NULL, 'R+ nuostolių energija pagal 8 tarifą per mėnesį', 4157, 4, NULL, NULL),
	(10449, 423, 2, 6, 2, 8, 4, 6, 436, NULL, 'R- nuostolių energija pagal 8 tarifą per mėnesį', 4158, 4, NULL, NULL),
	(10450, 396, 1, 6, 2, 0, 2, 6, 434, NULL, 'A+ nuostolių energija per mėnesį', 4159, 4, NULL, NULL),
	(10451, 396, 2, 6, 2, 0, 2, 6, 434, NULL, 'A- nuostolių energija per mėnesį', 4160, 4, NULL, NULL),
	(10452, 423, 1, 6, 2, 0, 4, 6, 436, NULL, 'R+ nuostolių energija per mėnesį', 4161, 4, NULL, NULL),
	(10453, 423, 2, 6, 2, 0, 4, 6, 436, NULL, 'R- nuostolių energija per mėnesį', 4162, 4, NULL, NULL),
	(10454, 423, 0, 7, 1, 0, 3, 7, 435, NULL, 'Q nuostolių galia', 4163, 6, NULL, NULL),
	(10455, 396, 1, 14, 3, 0, 1, 13, 407, NULL, 'Vidutinė P+ nuostolių galia per 20 minučių', 4164, 2, NULL, NULL),
	(10456, 396, 1, 13, 3, 0, 1, 12, 407, NULL, 'Vidutinė P+ nuostolių galia per 15 minučių', 4164, 2, NULL, NULL),
	(10457, 396, 1, 12, 3, 0, 1, 11, 407, NULL, 'Vidutinė P+ nuostolių galia per 10 minučių', 4164, 1, NULL, NULL),
	(10458, 396, 1, 11, 3, 0, 1, 10, 407, NULL, 'Vidutinė P+ nuostolių galia per 5 minutes', 4164, 1, NULL, NULL),
	(10459, 396, 1, 10, 3, 0, 1, 9, 407, NULL, 'Vidutinė P+ nuostolių galia per 4 minutes', 4164, 1, NULL, NULL),
	(10460, 396, 1, 9, 3, 0, 1, 8, 407, NULL, 'Vidutinė P+ nuostolių galia per 3 minutes', 4164, 1, NULL, NULL),
	(10461, 396, 1, 2, 3, 0, 1, 2, 407, NULL, 'Vidutinė P+ nuostolių galia per 2 minutes', 4164, 1, NULL, NULL),
	(10462, 396, 1, 1, 3, 0, 1, 1, 407, NULL, 'Vidutinė P+ nuostolių galia per minutę', 4164, 1, NULL, NULL),
	(10463, 396, 1, 4, 3, 0, 1, 4, 407, NULL, 'Vidutinė P+ nuostolių galia per valandą', 4164, 2, NULL, NULL),
	(10464, 396, 1, 3, 3, 0, 1, 3, 407, NULL, 'Vidutinė P+ nuostolių galia per 30 minučių', 4164, 2, NULL, NULL),
	(10465, 396, 2, 14, 3, 0, 1, 13, 407, NULL, 'Vidutinė P- nuostolių galia per 20 minučių', 4165, 2, NULL, NULL),
	(10466, 396, 2, 13, 3, 0, 1, 12, 407, NULL, 'Vidutinė P- nuostolių galia per 15 minučių', 4165, 2, NULL, NULL),
	(10467, 396, 2, 12, 3, 0, 1, 11, 407, NULL, 'Vidutinė P- nuostolių galia per 10 minučių', 4165, 1, NULL, NULL),
	(10468, 396, 2, 11, 3, 0, 1, 10, 407, NULL, 'Vidutinė P- nuostolių galia per 5 minutes', 4165, 1, NULL, NULL),
	(10469, 396, 2, 10, 3, 0, 1, 9, 407, NULL, 'Vidutinė P- nuostolių galia per 4 minutes', 4165, 1, NULL, NULL),
	(10470, 396, 2, 9, 3, 0, 1, 8, 407, NULL, 'Vidutinė P- nuostolių galia per 3 minutes', 4165, 1, NULL, NULL),
	(10471, 396, 2, 2, 3, 0, 1, 2, 407, NULL, 'Vidutinė P- nuostolių galia per 2 minutes', 4165, 1, NULL, NULL),
	(10472, 396, 2, 1, 3, 0, 1, 1, 407, NULL, 'Vidutinė P- nuostolių galia per minutę', 4165, 1, NULL, NULL),
	(10473, 396, 2, 4, 3, 0, 1, 4, 407, NULL, 'Vidutinė P- nuostolių galia per valandą', 4165, 2, NULL, NULL),
	(10474, 396, 2, 3, 3, 0, 1, 3, 407, NULL, 'Vidutinė P- nuostolių galia per 30 minučių', 4165, 2, NULL, NULL),
	(10475, 423, 1, 14, 3, 0, 3, 13, 435, NULL, 'Vidutinė Q+ nuostolių galia per 20 minučių', 4166, 2, NULL, NULL),
	(10476, 423, 1, 13, 3, 0, 3, 12, 435, NULL, 'Vidutinė Q+ nuostolių galia per 15 minučių', 4166, 2, NULL, NULL),
	(10477, 423, 1, 12, 3, 0, 3, 11, 435, NULL, 'Vidutinė Q+ nuostolių galia per 10 minučių', 4166, 1, NULL, NULL),
	(10478, 423, 1, 11, 3, 0, 3, 10, 435, NULL, 'Vidutinė Q+ nuostolių galia per 5 minutes', 4166, 1, NULL, NULL),
	(10479, 423, 1, 10, 3, 0, 3, 9, 435, NULL, 'Vidutinė Q+ nuostolių galia per 4 minutes', 4166, 1, NULL, NULL),
	(10480, 423, 1, 9, 3, 0, 3, 8, 435, NULL, 'Vidutinė Q+ nuostolių galia per 3 minutes', 4166, 1, NULL, NULL),
	(10481, 423, 1, 2, 3, 0, 3, 2, 435, NULL, 'Vidutinė Q+ nuostolių galia per 2 minutes', 4166, 1, NULL, NULL),
	(10482, 423, 1, 1, 3, 0, 3, 1, 435, NULL, 'Vidutinė Q+ nuostolių galia per minutę', 4166, 1, NULL, NULL),
	(10483, 423, 1, 4, 3, 0, 3, 4, 435, NULL, 'Vidutinė Q+ nuostolių galia per valandą', 4166, 2, NULL, NULL),
	(10484, 423, 1, 3, 3, 0, 3, 3, 435, NULL, 'Vidutinė Q+ nuostolių galia per 30 minučių', 4166, 2, NULL, NULL),
	(10485, 423, 2, 14, 3, 0, 3, 13, 435, NULL, 'Vidutinė Q- nuostolių galia per 20 minučių', 4167, 2, NULL, NULL),
	(10486, 423, 2, 13, 3, 0, 3, 12, 435, NULL, 'Vidutinė Q- nuostolių galia per 15 minučių', 4167, 2, NULL, NULL),
	(10487, 423, 2, 12, 3, 0, 3, 11, 435, NULL, 'Vidutinė Q- nuostolių galia per 10 minučių', 4167, 1, NULL, NULL),
	(10488, 423, 2, 11, 3, 0, 3, 10, 435, NULL, 'Vidutinė Q- nuostolių galia per 5 minutes', 4167, 1, NULL, NULL),
	(10489, 423, 2, 10, 3, 0, 3, 9, 435, NULL, 'Vidutinė Q- nuostolių galia per 4 minutes', 4167, 1, NULL, NULL),
	(10490, 423, 2, 9, 3, 0, 3, 8, 435, NULL, 'Vidutinė Q- nuostolių galia per 3 minutes', 4167, 1, NULL, NULL),
	(10491, 423, 2, 2, 3, 0, 3, 2, 435, NULL, 'Vidutinė Q- nuostolių galia per 2 minutes', 4167, 1, NULL, NULL),
	(10492, 423, 2, 1, 3, 0, 3, 1, 435, NULL, 'Vidutinė Q- nuostolių galia per minutę', 4167, 1, NULL, NULL),
	(10493, 423, 2, 4, 3, 0, 3, 4, 435, NULL, 'Vidutinė Q- nuostolių galia per valandą', 4167, 2, NULL, NULL),
	(10494, 423, 2, 3, 3, 0, 3, 3, 435, NULL, 'Vidutinė Q- nuostolių galia per 30 minučių', 4167, 2, NULL, NULL),
	(10495, 424, -4, 4, 2, 0, 29, 4, 437, NULL, 'Srauto daviklio gedimo trukmė pamaitinimo vandens vamzdyje per valandą', 1764, 2, NULL, NULL),
	(10496, 424, -4, 5, 2, 0, 29, 5, 437, NULL, 'Srauto daviklio gedimo trukmė pamaitinimo vandens vamzdyje per parą', 1764, 3, NULL, NULL),
	(10497, 424, -4, 6, 2, 0, 29, 6, 437, NULL, 'Srauto daviklio gedimo trukmė pamaitinimo vandens vamzdyje per mėnesį', 1764, 4, NULL, NULL),
	(10498, 424, 1, 4, 2, 0, 29, 4, 437, NULL, 'Srauto daviklio gedimo trukmė tiekiamo šilumnešio vamzdyje per valandą', 1764, 2, NULL, NULL),
	(10499, 424, 1, 5, 2, 0, 29, 5, 437, NULL, 'Srauto daviklio gedimo trukmė tiekiamo šilumnešio vamzdyje per parą', 1764, 3, NULL, NULL),
	(10500, 424, 1, 6, 2, 0, 29, 6, 437, NULL, 'Srauto daviklio gedimo trukmė tiekiamo šilumnešio vamzdyje per mėnesį', 1764, 4, NULL, NULL),
	(10501, 424, 2, 4, 2, 0, 29, 4, 437, NULL, 'Srauto daviklio gedimo trukmė grįžtamo šilumnešio vamzdyje per valandą', 1764, 2, NULL, NULL),
	(10502, 424, 2, 5, 2, 0, 29, 5, 437, NULL, 'Srauto daviklio gedimo trukmė grįžtamo šilumnešio vamzdyje per parą', 1764, 3, NULL, NULL),
	(10503, 424, 2, 6, 2, 0, 29, 6, 437, NULL, 'Srauto daviklio gedimo trukmė grįžtamo šilumnešio vamzdyje per mėnesį', 1764, 4, NULL, NULL),
	(10504, 425, -4, 4, 2, 0, 29, 4, 438, NULL, 'Ryšio su kanalu nebuvimo trukmė pamaitinimo vandens vamzdyje per valandą', 1765, 2, NULL, NULL),
	(10505, 425, -4, 5, 2, 0, 29, 5, 438, NULL, 'Ryšio su kanalu nebuvimo trukmė pamaitinimo vandens vamzdyje per parą', 1765, 3, NULL, NULL),
	(10506, 425, -4, 6, 2, 0, 29, 6, 438, NULL, 'Ryšio su kanalu nebuvimo trukmė pamaitinimo vandens vamzdyje per mėnesį', 1765, 4, NULL, NULL),
	(10507, 425, 1, 4, 2, 0, 29, 4, 438, NULL, 'Ryšio su kanalu nebuvimo trukmė tiekiamo šilumnešio vamzdyje per valandą', 1765, 2, NULL, NULL),
	(10508, 425, 1, 5, 2, 0, 29, 5, 438, NULL, 'Ryšio su kanalu nebuvimo trukmė tiekiamo šilumnešio vamzdyje per parą', 1765, 3, NULL, NULL),
	(10509, 425, 1, 6, 2, 0, 29, 6, 438, NULL, 'Ryšio su kanalu nebuvimo trukmė tiekiamo šilumnešio vamzdyje per mėnesį', 1765, 4, NULL, NULL),
	(10510, 425, 2, 4, 2, 0, 29, 4, 438, NULL, 'Ryšio su kanalu nebuvimo trukmė grįžtamo šilumnešio vamzdyje per valandą', 1765, 2, NULL, NULL),
	(10511, 425, 2, 5, 2, 0, 29, 5, 438, NULL, 'Ryšio su kanalu nebuvimo trukmė grįžtamo šilumnešio vamzdyje per parą', 1765, 3, NULL, NULL),
	(10512, 425, 2, 6, 2, 0, 29, 6, 438, NULL, 'Ryšio su kanalu nebuvimo trukmė grįžtamo šilumnešio vamzdyje per mėnesį', 1765, 4, NULL, NULL),
	(10513, 426, -4, 4, 2, 0, 29, 4, 439, NULL, '"Temperatūra daugiau maksimumo" trukmė pamaitinimo vandens vamzdyje per valandą', 1763, 2, NULL, NULL),
	(10514, 426, -4, 5, 2, 0, 29, 5, 439, NULL, '"Temperatūra daugiau maksimumo" trukmė pamaitinimo vandens vamzdyje per parą', 1763, 3, NULL, NULL),
	(10515, 426, -4, 6, 2, 0, 29, 6, 439, NULL, '"Temperatūra daugiau maksimumo" trukmė pamaitinimo vandens vamzdyje per mėnesį', 1763, 4, NULL, NULL),
	(10516, 426, 1, 4, 2, 0, 29, 4, 439, NULL, '"Temperatūra daugiau maksimumo" trukmė tiekiamo šilumnešio vamzdyje per valandą', 1763, 2, NULL, NULL),
	(10517, 426, 1, 5, 2, 0, 29, 5, 439, NULL, '"Temperatūra daugiau maksimumo" trukmė tiekiamo šilumnešio vamzdyje per parą', 1763, 3, NULL, NULL),
	(10518, 426, 1, 6, 2, 0, 29, 6, 439, NULL, '"Temperatūra daugiau maksimumo" trukmė tiekiamo šilumnešio vamzdyje per mėnesį', 1763, 4, NULL, NULL),
	(10519, 426, 2, 4, 2, 0, 29, 4, 439, NULL, '"Temperatūra daugiau maksimumo" trukmė grįžtamo šilumnešio vamzdyje per valandą', 1763, 2, NULL, NULL),
	(10520, 426, 2, 5, 2, 0, 29, 5, 439, NULL, '"Temperatūra daugiau maksimumo" trukmė grįžtamo šilumnešio vamzdyje per parą', 1763, 3, NULL, NULL),
	(10521, 426, 2, 6, 2, 0, 29, 6, 439, NULL, '"Temperatūra daugiau maksimumo" trukmė grįžtamo šilumnešio vamzdyje per mėnesį', 1763, 4, NULL, NULL),
	(10522, 427, -4, 4, 2, 0, 29, 4, 440, NULL, '"Temperatūra mažiau minimumo" trukmė pamaitinimo vandens vamzdyje per valandą', 1762, 2, NULL, NULL),
	(10523, 427, -4, 5, 2, 0, 29, 5, 440, NULL, '"Temperatūra mažiau minimumo" trukmė pamaitinimo vandens vamzdyje per parą', 1762, 3, NULL, NULL),
	(10524, 427, -4, 6, 2, 0, 29, 6, 440, NULL, '"Temperatūra mažiau minimumo" trukmė pamaitinimo vandens vamzdyje per mėnesį', 1762, 4, NULL, NULL),
	(10525, 427, 1, 4, 2, 0, 29, 4, 440, NULL, '"Temperatūra mažiau minimumo" trukmė tiekiamo šilumnešio vamzdyje per valandą', 1762, 2, NULL, NULL),
	(10526, 427, 1, 5, 2, 0, 29, 5, 440, NULL, '"Temperatūra mažiau minimumo" trukmė tiekiamo šilumnešio vamzdyje per parą', 1762, 3, NULL, NULL),
	(10527, 427, 1, 6, 2, 0, 29, 6, 440, NULL, '"Temperatūra mažiau minimumo" trukmė tiekiamo šilumnešio vamzdyje per mėnesį', 1762, 4, NULL, NULL),
	(10528, 427, 2, 4, 2, 0, 29, 4, 440, NULL, '"Temperatūra mažiau minimumo" trukmė grįžtamo šilumnešio vamzdyje per valandą', 1762, 2, NULL, NULL),
	(10529, 427, 2, 5, 2, 0, 29, 5, 440, NULL, '"Temperatūra mažiau minimumo" trukmė grįžtamo šilumnešio vamzdyje per parą', 1762, 3, NULL, NULL),
	(10530, 427, 2, 6, 2, 0, 29, 6, 440, NULL, '"Temperatūra mažiau minimumo" trukmė grįžtamo šilumnešio vamzdyje per mėnesį', 1762, 4, NULL, NULL),
	(10531, 52, 0, 7, 4, 0, 28, 6, 69, NULL, 'Maksimalus momentinis šilumnešio slėgis per mėnesį', 1768, 4, NULL, NULL),
	(10532, 52, 0, 7, 4, 0, 28, 5, 69, NULL, 'Maksimalus momentinis šilumnešio slėgis per parą', 1768, 3, NULL, NULL),
	(10533, 52, 0, 7, 4, 0, 28, 4, 69, NULL, 'Maksimalus momentinis šilumnešio slėgis per valandą', 1768, 2, NULL, NULL),
	(10534, 52, 0, 7, 5, 0, 28, 6, 69, NULL, 'Minimalus momentinis šilumnešio slėgis per mėnesį', 1769, 4, NULL, NULL),
	(10535, 52, 0, 7, 5, 0, 28, 5, 69, NULL, 'Minimalus momentinis šilumnešio slėgis per parą', 1769, 3, NULL, NULL),
	(10536, 52, 0, 7, 5, 0, 28, 4, 69, NULL, 'Minimalus momentinis šilumnešio slėgis per valandą', 1769, 2, NULL, NULL),
	(10537, 52, -4, 7, 4, 0, 28, 6, 69, NULL, 'Maksimalus momentinis pamaitinimo vandens slėgis per mėnesį', 1768, 4, NULL, NULL),
	(10538, 52, -4, 7, 4, 0, 28, 5, 69, NULL, 'Maksimalus momentinis pamaitinimo vandens slėgis per parą', 1768, 3, NULL, NULL),
	(10539, 52, -4, 7, 4, 0, 28, 4, 69, NULL, 'Maksimalus momentinis pamaitinimo vandens slėgis per valandą', 1768, 2, NULL, NULL),
	(10540, 52, -4, 7, 5, 0, 28, 6, 69, NULL, 'Minimalus momentinis pamaitinimo vandens slėgis per mėnesį', 1769, 4, NULL, NULL),
	(10541, 52, -4, 7, 5, 0, 28, 5, 69, NULL, 'Minimalus momentinis pamaitinimo vandens slėgis per parą', 1769, 3, NULL, NULL),
	(10542, 52, -4, 7, 5, 0, 28, 4, 69, NULL, 'Minimalus momentinis pamaitinimo vandens slėgis per valandą', 1769, 2, NULL, NULL),
	(10543, 54, 0, 7, 4, 0, 27, 6, 72, NULL, 'Maksimali momentinė šilumnešio temperatūra per mėnesį', 1766, 4, NULL, NULL),
	(10544, 54, 0, 7, 4, 0, 27, 5, 72, NULL, 'Maksimali momentinė šilumnešio temperatūra per parą', 1766, 3, NULL, NULL),
	(10545, 54, 0, 7, 4, 0, 27, 4, 72, NULL, 'Maksimali momentinė šilumnešio temperatūra per valandą', 1766, 2, NULL, NULL),
	(10546, 54, 0, 7, 5, 0, 27, 6, 72, NULL, 'Minimali momentinė šilumnešio temperatūra per mėnesį', 1767, 4, NULL, NULL),
	(10547, 54, 0, 7, 5, 0, 27, 5, 72, NULL, 'Minimali momentinė šilumnešio temperatūra per parą', 1767, 3, NULL, NULL),
	(10548, 54, 0, 7, 5, 0, 27, 4, 72, NULL, 'Minimali momentinė šilumnešio temperatūra per valandą', 1767, 2, NULL, NULL),
	(10549, 54, -4, 7, 4, 0, 27, 6, 72, NULL, 'Maksimali momentinė pamaitinimo vandens temperatūra per mėnesį', 1766, 4, NULL, NULL),
	(10550, 54, -4, 7, 4, 0, 27, 5, 72, NULL, 'Maksimali momentinė pamaitinimo vandens temperatūra per parą', 1766, 3, NULL, NULL),
	(10551, 54, -4, 7, 4, 0, 27, 4, 72, NULL, 'Maksimali momentinė pamaitinimo vandens temperatūra per valandą', 1766, 2, NULL, NULL),
	(10552, 54, -4, 7, 5, 0, 27, 6, 72, NULL, 'Minimali momentinė pamaitinimo vandens temperatūra per mėnesį', 1767, 4, NULL, NULL),
	(10553, 54, -4, 7, 5, 0, 27, 5, 72, NULL, 'Minimali momentinė pamaitinimo vandens temperatūra per parą', 1767, 3, NULL, NULL),
	(10554, 54, -4, 7, 5, 0, 27, 4, 72, NULL, 'Minimali momentinė pamaitinimo vandens temperatūra per valandą', 1767, 2, NULL, NULL),
	(10555, 428, 3, 8, 2, 0, 2, 3, 441, NULL, 'Suminis šilumos nuostolių kiekis, fiksuojamas kas 30 minučių', 1771, 5, NULL, NULL),
	(10556, 428, 3, 8, 2, 0, 2, 4, 441, NULL, 'Suminis šilumos nuostolių kiekis, fiksuojamas kas valandą', 1771, 5, NULL, NULL),
	(10557, 428, 3, 8, 2, 0, 2, 5, 441, NULL, 'Suminis šilumos nuostolių kiekis, fiksuojamas kas parą', 1771, 5, NULL, NULL),
	(10558, 428, 3, 8, 2, 0, 2, 6, 441, NULL, 'Suminis šilumos nuostolių kiekis, fiksuojamas kas mėnesį', 1771, 5, NULL, NULL),
	(10559, 428, 3, 8, 2, 0, 2, 7, 441, NULL, 'Suminis šilumos nuostolių kiekis', 1771, 5, NULL, NULL),
	(10560, 428, 3, 8, 2, 0, 2, 10, 441, NULL, 'Suminis šilumos nuostolių kiekis, fiksuojamas kas 5 minutes', 1771, 5, NULL, NULL),
	(10561, 428, 3, 8, 2, 0, 2, 12, 441, NULL, 'Suminis šilumos nuostolių kiekis, fiksuojamas kas 15 minučių', 1771, 5, NULL, NULL),
	(10562, 428, 3, 8, 2, 0, 2, 13, 441, NULL, 'Suminis šilumos nuostolių kiekis, fiksuojamas kas 20 minučių', 1771, 5, NULL, NULL),
	(10563, 429, 0, 8, 2, 0, 2, 3, 442, NULL, 'Suminis šilumos kiekis nuo pradinio įjungimo, fiksuojamas kas 30 minučių', 1772, 5, NULL, NULL),
	(10564, 429, 0, 8, 2, 0, 2, 4, 442, NULL, 'Suminis šilumos kiekis nuo pradinio įjungimo, fiksuojamas kas valandą', 1772, 5, NULL, NULL),
	(10565, 429, 0, 8, 2, 0, 2, 5, 442, NULL, 'Suminis šilumos kiekis nuo pradinio įjungimo, fiksuojamas kas parą', 1772, 5, NULL, NULL),
	(10566, 429, 0, 8, 2, 0, 2, 6, 442, NULL, 'Suminis šilumos kiekis nuo pradinio įjungimo, fiksuojamas kas mėnesį', 1772, 5, NULL, NULL),
	(10567, 429, 0, 8, 2, 0, 2, 7, 442, NULL, 'Suminis šilumos kiekis nuo pradinio įjungimo', 1772, 5, NULL, NULL),
	(10568, 429, 0, 8, 2, 0, 2, 10, 442, NULL, 'Suminis šilumos kiekis nuo pradinio įjungimo, fiksuojamas kas 5 minutes', 1772, 5, NULL, NULL),
	(10569, 429, 0, 8, 2, 0, 2, 12, 442, NULL, 'Suminis šilumos kiekis nuo pradinio įjungimo, fiksuojamas kas 15 minučių', 1772, 5, NULL, NULL),
	(10570, 429, 0, 8, 2, 0, 2, 13, 442, NULL, 'Suminis šilumos kiekis nuo pradinio įjungimo, fiksuojamas kas 20 minučių', 1772, 5, NULL, NULL),
	(10662, 1, 3, 9, 3, 0, 1, 8, 13, NULL, 'Vidutinė aktyvinė tinklo galia per 3 minutes', 447, 1, NULL, NULL),
	(10664, 3, 3, 9, 3, 0, 3, 8, 16, NULL, 'Vidutinė reaktyvinė tinklo galia per 3 minutes', 449, 1, NULL, NULL),
	(10666, 3, -2, 9, 3, 0, 3, 8, 16, NULL, 'Vidutinė Q1+Q4 galia per 3 minutes', 452, 1, NULL, NULL),
	(10667, 3, -3, 9, 3, 0, 3, 8, 16, NULL, 'Vidutinė Q2+Q3 galia per 3 minutes', 453, 1, NULL, NULL),
	(10668, 430, 0, 8, 2, 0, 31, 7, 443, NULL, 'Suminis dujų turbulentinio tūrio kiekis', 1153, 5, NULL, NULL),
	(10669, 438, 0, 8, 2, 0, 31, 7, 451, NULL, 'Suminis dujų bendras suvartojimo tūrio kiekis', 1163, 5, NULL, NULL),
	(10670, 438, 0, 6, 2, 0, 31, 6, 451, NULL, 'Dujų bendras suvartojimo tūrio kiekis per mėnesį', 1164, 4, NULL, NULL),
	(10671, 438, 0, 5, 2, 0, 31, 5, 451, NULL, 'Dujų bendras suvartojimo tūrio kiekis per parą', 1164, 3, NULL, NULL),
	(10672, 438, 0, 4, 2, 0, 31, 4, 451, NULL, 'Dujų bendras suvartojimo tūrio kiekis per valandą', 1164, 2, NULL, NULL),
	(10673, 438, 0, 12, 2, 0, 31, 11, 451, NULL, 'Dujų bendras suvartojimo tūrio kiekis per 10 minučių', 1164, 1, NULL, NULL),
	(10674, 438, 0, 13, 2, 0, 31, 12, 451, NULL, 'Dujų bendras suvartojimo tūrio kiekis per 15 minučių', 1164, 2, NULL, NULL),
	(10675, 438, 0, 14, 2, 0, 31, 13, 451, NULL, 'Dujų bendras suvartojimo tūrio kiekis per 20 minučių', 1164, 2, NULL, NULL),
	(10676, 438, 0, 3, 2, 0, 31, 3, 451, NULL, 'Dujų bendras suvartojimo tūrio kiekis per 30 minučių', 1164, 2, NULL, NULL),
	(10677, 438, 0, 11, 2, 0, 31, 10, 451, NULL, 'Dujų bendras suvartojimo tūrio kiekis per 5 minutes', 1164, 1, NULL, NULL),
	(10678, 437, 0, 8, 2, 0, 31, 7, 450, NULL, 'Suminis dujų bendras suvartojimo tūrio kiekis normaliose sąlygose', 1161, 5, NULL, NULL),
	(10679, 437, 0, 6, 2, 0, 31, 6, 450, NULL, 'Dujų bendras suvartojimo tūrio kiekis normaliose sąlygose per mėnesį', 1162, 4, NULL, NULL),
	(10680, 437, 0, 5, 2, 0, 31, 5, 450, NULL, 'Dujų bendras suvartojimo tūrio kiekis normaliose sąlygose per parą', 1162, 3, NULL, NULL),
	(10681, 437, 0, 4, 2, 0, 31, 4, 450, NULL, 'Dujų bendras suvartojimo tūrio kiekis normaliose sąlygose per valandą', 1162, 2, NULL, NULL),
	(10682, 437, 0, 12, 2, 0, 31, 11, 450, NULL, 'Dujų bendras suvartojimo tūrio kiekis normaliose sąlygose per 10 minučių', 1162, 1, NULL, NULL),
	(10683, 437, 0, 13, 2, 0, 31, 12, 450, NULL, 'Dujų bendras suvartojimo tūrio kiekis normaliose sąlygose per 15 minučių', 1162, 2, NULL, NULL),
	(10684, 437, 0, 14, 2, 0, 31, 13, 450, NULL, 'Dujų bendras suvartojimo tūrio kiekis normaliose sąlygose per 20 minučių', 1162, 2, NULL, NULL),
	(10685, 437, 0, 3, 2, 0, 31, 3, 450, NULL, 'Dujų bendras suvartojimo tūrio kiekis normaliose sąlygose per 30 minučių', 1162, 2, NULL, NULL),
	(10686, 437, 0, 11, 2, 0, 31, 10, 450, NULL, 'Dujų bendras suvartojimo tūrio kiekis normaliose sąlygose per 5 minutes', 1162, 1, NULL, NULL),
	(10687, 431, 0, 7, 1, 0, 28, 7, 444, NULL, 'Momentinis dujų slėgis normaliose sąlygose', 1154, 6, NULL, NULL),
	(10688, 439, 0, 7, 1, 0, 28, 7, 452, NULL, 'Momentinis išmatuotas dujų slėgis', 1165, 6, NULL, NULL),
	(10689, 432, 0, 7, 1, 0, 27, 7, 445, NULL, 'Momentinė dujų temperatūra normaliose sąlygose', 1155, 6, NULL, NULL),
	(10690, 440, 0, 7, 1, 0, 27, 7, 453, NULL, 'Momentinė išmatuota dujų temperatūra', 1166, 6, NULL, NULL),
	(10691, 436, 0, 8, 2, 0, 2, 7, 449, NULL, 'Suminis dujų turbulentinis šilumos kiekis', 1160, 5, NULL, NULL),
	(10692, 441, 0, 8, 2, 0, 2, 7, 454, NULL, 'Suminis dujų bendras šilumos kiekis', 1167, 5, NULL, NULL),
	(10693, 441, 0, 6, 2, 0, 2, 6, 454, NULL, 'Dujų bendras šilumos kiekis per mėnesį', 1168, 4, NULL, NULL),
	(10694, 441, 0, 5, 2, 0, 2, 5, 454, NULL, 'Dujų bendras šilumos kiekis per parą', 1168, 3, NULL, NULL),
	(10695, 441, 0, 4, 2, 0, 2, 4, 454, NULL, 'Dujų bendras šilumos kiekis per valandą', 1168, 2, NULL, NULL),
	(10696, 441, 0, 12, 2, 0, 2, 11, 454, NULL, 'Dujų bendras šilumos kiekis per 10 minučių', 1168, 1, NULL, NULL),
	(10697, 441, 0, 13, 2, 0, 2, 12, 454, NULL, 'Dujų bendras šilumos kiekis per 15 minučių', 1168, 2, NULL, NULL),
	(10698, 441, 0, 14, 2, 0, 2, 13, 454, NULL, 'Dujų bendras šilumos kiekis per 20 minučių', 1168, 2, NULL, NULL),
	(10699, 441, 0, 3, 2, 0, 2, 3, 454, NULL, 'Dujų bendras šilumos kiekis per 30 minučių', 1168, 2, NULL, NULL),
	(10700, 441, 0, 11, 2, 0, 2, 10, 454, NULL, 'Dujų bendras šilumos kiekis per 5 minutes', 1168, 1, NULL, NULL),
	(10701, 433, 0, 7, 1, 0, 9, 7, 446, NULL, 'Momentinis vandenilio H2 kiekis', 1156, 6, NULL, NULL),
	(10702, 434, 0, 7, 1, 0, 0, 7, 447, NULL, 'Momentinis dujų suspaudimo koeficientas', 1157, 6, NULL, NULL),
	(10703, 434, 0, 4, 3, 0, 0, 4, 447, NULL, 'Vidutinis dujų suspaudimo koeficientas per valandą', 1158, 2, NULL, NULL),
	(10704, 434, 0, 12, 3, 0, 0, 11, 447, NULL, 'Vidutinis dujų suspaudimo koeficientas per 10 minučių', 1158, 1, NULL, NULL),
	(10705, 434, 0, 13, 3, 0, 0, 12, 447, NULL, 'Vidutinis dujų suspaudimo koeficientas per 15 minučių', 1158, 2, NULL, NULL),
	(10706, 434, 0, 14, 3, 0, 0, 13, 447, NULL, 'Vidutinis dujų suspaudimo koeficientas per 20 minučių', 1158, 2, NULL, NULL),
	(10707, 434, 0, 3, 3, 0, 0, 3, 447, NULL, 'Vidutinis dujų suspaudimo koeficientas per 30 minučių', 1158, 2, NULL, NULL),
	(10708, 434, 0, 11, 3, 0, 0, 10, 447, NULL, 'Vidutinis dujų suspaudimo koeficientas per 5 minutes', 1158, 1, NULL, NULL),
	(10709, 434, 0, 5, 3, 0, 0, 5, 447, NULL, 'Vidutinis dujų suspaudimo koeficientas per parą', 1158, 3, NULL, NULL),
	(10710, 434, 0, 6, 3, 0, 0, 6, 447, NULL, 'Vidutinis dujų suspaudimo koeficientas per mėnesį', 1158, 4, NULL, NULL),
	(10711, 435, 0, 4, 3, 0, 0, 4, 448, NULL, 'Vidutinis dujų korekcijos koeficientas per valandą', 1159, 2, NULL, NULL),
	(10712, 435, 0, 12, 3, 0, 0, 11, 448, NULL, 'Vidutinis dujų korekcijos koeficientas per 10 minučių', 1159, 1, NULL, NULL),
	(10713, 435, 0, 13, 3, 0, 0, 12, 448, NULL, 'Vidutinis dujų korekcijos koeficientas per 15 minučių', 1159, 2, NULL, NULL),
	(10714, 435, 0, 14, 3, 0, 0, 13, 448, NULL, 'Vidutinis dujų korekcijos koeficientas per 20 minučių', 1159, 2, NULL, NULL),
	(10715, 435, 0, 3, 3, 0, 0, 3, 448, NULL, 'Vidutinis dujų korekcijos koeficientas per 30 minučių', 1159, 2, NULL, NULL),
	(10716, 435, 0, 11, 3, 0, 0, 10, 448, NULL, 'Vidutinis dujų korekcijos koeficientas per 5 minutes', 1159, 1, NULL, NULL),
	(10717, 435, 0, 5, 3, 0, 0, 5, 448, NULL, 'Vidutinis dujų korekcijos koeficientas per parą', 1159, 3, NULL, NULL),
	(10718, 435, 0, 6, 3, 0, 0, 6, 448, NULL, 'Vidutinis dujų korekcijos koeficientas per mėnesį', 1159, 4, NULL, NULL),
	(10719, 442, 0, 7, 1, 0, 28, 7, 456, NULL, 'Momentinis absoliutus dujų slėgis', 1141, 6, NULL, NULL),
	(10720, 442, 0, 1, 3, 0, 28, 1, 456, NULL, 'Vidutinis absoliutus dujų slėgis per minutę', 1142, 1, NULL, NULL),
	(10721, 442, 0, 6, 3, 0, 28, 6, 456, NULL, 'Vidutinis absoliutus dujų slėgis per mėnesį', 1142, 4, NULL, NULL),
	(10722, 442, 0, 5, 3, 0, 28, 5, 456, NULL, 'Vidutinis absoliutus dujų slėgis per parą', 1142, 3, NULL, NULL),
	(10723, 442, 0, 4, 3, 0, 28, 4, 456, NULL, 'Vidutinis absoliutus dujų slėgis per valandą', 1142, 2, NULL, NULL),
	(10724, 442, 0, 12, 3, 0, 28, 11, 456, NULL, 'Vidutinis absoliutus dujų slėgis per 10 minučių', 1142, 1, NULL, NULL),
	(10725, 442, 0, 13, 3, 0, 28, 12, 456, NULL, 'Vidutinis absoliutus dujų slėgis per 15 minučių', 1142, 2, NULL, NULL),
	(10726, 442, 0, 2, 3, 0, 28, 2, 456, NULL, 'Vidutinis absoliutus dujų slėgis per 2 minutes', 1142, 1, NULL, NULL),
	(10727, 442, 0, 14, 3, 0, 28, 13, 456, NULL, 'Vidutinis absoliutus dujų slėgis per 20 minučių', 1142, 2, NULL, NULL),
	(10728, 442, 0, 9, 3, 0, 28, 8, 456, NULL, 'Vidutinis absoliutus dujų slėgis per 3 minutes', 1142, 1, NULL, NULL),
	(10729, 442, 0, 3, 3, 0, 28, 3, 456, NULL, 'Vidutinis absoliutus dujų slėgis per 30 minučių', 1142, 2, NULL, NULL),
	(10730, 442, 0, 10, 3, 0, 28, 9, 456, NULL, 'Vidutinis absoliutus dujų slėgis per 4 minutes', 1142, 1, NULL, NULL),
	(10731, 442, 0, 11, 3, 0, 28, 10, 456, NULL, 'Vidutinis absoliutus dujų slėgis per 5 minutes', 1142, 1, NULL, NULL),
	(10732, 443, 0, 7, 1, 0, 59, 7, 457, NULL, 'Momentinis dujų tankis', 1114, 6, NULL, NULL),
	(10733, 443, 0, 6, 2, 0, 59, 6, 457, NULL, 'Dujų tankis per mėnesį', 1152, 4, NULL, NULL),
	(10734, 443, 0, 5, 2, 0, 59, 5, 457, NULL, 'Dujų tankis per parą', 1152, 3, NULL, NULL),
	(10735, 443, 0, 4, 2, 0, 59, 4, 457, NULL, 'Dujų tankis per valandą', 1152, 2, NULL, NULL),
	(10736, 45, 3, 8, 2, 0, 31, 7, 12, NULL, 'Suminis tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas', 1146, 5, NULL, NULL),
	(10737, 45, 3, 8, 2, 0, 31, 1, 12, NULL, 'Suminis tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas, fiksuojamas kas minutę', 1146, 5, NULL, NULL),
	(10738, 45, 3, 8, 2, 0, 31, 6, 12, NULL, 'Suminis tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas, fiksuojamas kas mėnesį', 1146, 5, NULL, NULL),
	(10739, 45, 3, 8, 2, 0, 31, 5, 12, NULL, 'Suminis tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas, fiksuojamas kas parą', 1146, 5, NULL, NULL),
	(10740, 45, 3, 8, 2, 0, 31, 4, 12, NULL, 'Suminis tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas, fiksuojamas kas valandą', 1146, 5, NULL, NULL),
	(10741, 45, 3, 8, 2, 0, 31, 12, 12, NULL, 'Suminis tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas, fiksuojamas kas 15 minučių', 1146, 5, NULL, NULL),
	(10742, 45, 3, 8, 2, 0, 31, 13, 12, NULL, 'Suminis tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas, fiksuojamas kas 20 minučių', 1146, 5, NULL, NULL),
	(10743, 45, 3, 8, 2, 0, 31, 3, 12, NULL, 'Suminis tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas, fiksuojamas kas 30 minučių', 1146, 5, NULL, NULL),
	(10744, 45, 3, 8, 2, 0, 31, 10, 12, NULL, 'Suminis tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas, fiksuojamas kas 5 minutes', 1146, 5, NULL, NULL),
	(10745, 45, 3, 1, 2, 0, 31, 1, 12, NULL, 'Tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas per minutę', 1147, 1, NULL, NULL),
	(10746, 45, 3, 6, 2, 0, 31, 6, 12, NULL, 'Tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas per mėnesį', 1147, 4, NULL, NULL),
	(10747, 45, 3, 5, 2, 0, 31, 5, 12, NULL, 'Tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas per parą', 1147, 3, NULL, NULL),
	(10748, 45, 3, 4, 2, 0, 31, 4, 12, NULL, 'Tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas per valandą', 1147, 2, NULL, NULL),
	(10749, 45, 3, 12, 2, 0, 31, 11, 12, NULL, 'Tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas per 10 minučių', 1147, 1, NULL, NULL),
	(10750, 45, 3, 13, 2, 0, 31, 12, 12, NULL, 'Tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas per 15 minučių', 1147, 2, NULL, NULL),
	(10751, 45, 3, 2, 2, 0, 31, 2, 12, NULL, 'Tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas per 2 minutes', 1147, 1, NULL, NULL),
	(10752, 45, 3, 14, 2, 0, 31, 13, 12, NULL, 'Tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas per 20 minučių', 1147, 2, NULL, NULL),
	(10753, 45, 3, 9, 2, 0, 31, 8, 12, NULL, 'Tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas per 3 minutes', 1147, 1, NULL, NULL),
	(10754, 45, 3, 3, 2, 0, 31, 3, 12, NULL, 'Tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas per 30 minučių', 1147, 2, NULL, NULL),
	(10755, 45, 3, 10, 2, 0, 31, 9, 12, NULL, 'Tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas per 4 minutes', 1147, 1, NULL, NULL),
	(10756, 45, 3, 11, 2, 0, 31, 10, 12, NULL, 'Tiekiamų ir grįžtamų dujų tūrio kiekių skirtumas per 5 minutes', 1147, 1, NULL, NULL),
	(10757, 40, 3, 8, 2, 0, 31, 7, 4, NULL, 'Suminis tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas', 1148, 5, NULL, NULL),
	(10758, 40, 3, 8, 2, 0, 31, 1, 4, NULL, 'Suminis tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas, fiksuojamas kas minutę', 1148, 5, NULL, NULL),
	(10759, 40, 3, 8, 2, 0, 31, 6, 4, NULL, 'Suminis tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas, fiksuojamas kas mėnesį', 1148, 5, NULL, NULL),
	(10760, 40, 3, 8, 2, 0, 31, 5, 4, NULL, 'Suminis tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas, fiksuojamas kas parą', 1148, 5, NULL, NULL),
	(10761, 40, 3, 8, 2, 0, 31, 4, 4, NULL, 'Suminis tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas, fiksuojamas kas valandą', 1148, 5, NULL, NULL),
	(10762, 40, 3, 8, 2, 0, 31, 12, 4, NULL, 'Suminis tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas, fiksuojamas kas 15 minučių', 1148, 5, NULL, NULL),
	(10763, 40, 3, 8, 2, 0, 31, 13, 4, NULL, 'Suminis tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas, fiksuojamas kas 20 minučių', 1148, 5, NULL, NULL),
	(10764, 40, 3, 8, 2, 0, 31, 3, 4, NULL, 'Suminis tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas, fiksuojamas kas 30 minučių', 1148, 5, NULL, NULL),
	(10765, 40, 3, 8, 2, 0, 31, 10, 4, NULL, 'Suminis tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas, fiksuojamas kas 5 minutes', 1148, 5, NULL, NULL),
	(10766, 40, 3, 1, 2, 0, 31, 1, 4, NULL, 'Tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas per minutę', 1149, 1, NULL, NULL),
	(10767, 40, 3, 6, 2, 0, 31, 6, 4, NULL, 'Tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas per mėnesį', 1149, 4, NULL, NULL),
	(10768, 40, 3, 5, 2, 0, 31, 5, 4, NULL, 'Tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas per parą', 1149, 3, NULL, NULL),
	(10769, 40, 3, 4, 2, 0, 31, 4, 4, NULL, 'Tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas per valandą', 1149, 2, NULL, NULL),
	(10770, 40, 3, 12, 2, 0, 31, 11, 4, NULL, 'Tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas per 10 minučių', 1149, 1, NULL, NULL),
	(10771, 40, 3, 13, 2, 0, 31, 12, 4, NULL, 'Tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas per 15 minučių', 1149, 2, NULL, NULL),
	(10772, 40, 3, 2, 2, 0, 31, 2, 4, NULL, 'Tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas per 2 minutes', 1149, 1, NULL, NULL),
	(10773, 40, 3, 14, 2, 0, 31, 13, 4, NULL, 'Tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas per 20 minučių', 1149, 2, NULL, NULL),
	(10774, 40, 3, 9, 2, 0, 31, 8, 4, NULL, 'Tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas per 3 minutes', 1149, 1, NULL, NULL),
	(10775, 40, 3, 3, 2, 0, 31, 3, 4, NULL, 'Tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas per 30 minučių', 1149, 2, NULL, NULL),
	(10776, 40, 3, 10, 2, 0, 31, 9, 4, NULL, 'Tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas per 4 minutes', 1149, 1, NULL, NULL),
	(10777, 40, 3, 11, 2, 0, 31, 10, 4, NULL, 'Tiekiamų ir grįžtamų dujų normalizuoto tūrio kiekių skirtumas per 5 minutes', 1149, 1, NULL, NULL),
	(10778, 444, 0, 4, 2, 0, 59, 4, 458, NULL, 'Dujų tankis normaliose sąlygose per valandą', 1151, 2, NULL, NULL),
	(10779, 444, 0, 5, 2, 0, 59, 5, 458, NULL, 'Dujų tankis normaliose sąlygose per parą', 1151, 3, NULL, NULL),
	(10780, 444, 0, 6, 2, 0, 59, 6, 458, NULL, 'Dujų tankis normaliose sąlygose per mėnesį', 1151, 4, NULL, NULL),
	(10781, 444, 0, 7, 1, 0, 59, 7, 458, NULL, 'Momentinis dujų tankis normaliose sąlygose', 1150, 6, NULL, NULL),
	(10782, 187, 0, 6, 3, 0, 0, 6, 200, NULL, 'Vidutinis rodiklis Nr.1 per mėnesį', NULL, 4, NULL, NULL),
	(10783, 187, 0, 5, 3, 0, 0, 5, 200, NULL, 'Vidutinis rodiklis Nr.1 per parą', NULL, 3, NULL, NULL),
	(10784, 187, 0, 4, 3, 0, 0, 4, 200, NULL, 'Vidutinis rodiklis Nr.1 per valandą', NULL, 2, NULL, NULL),
	(10785, 187, 0, 13, 3, 0, 0, 12, 200, NULL, 'Vidutinis rodiklis Nr.1 per 15 minučių', NULL, 2, NULL, NULL),
	(10786, 187, 0, 3, 3, 0, 0, 3, 200, NULL, 'Vidutinis rodiklis Nr.1 per 30 minučių', NULL, 2, NULL, NULL),
	(10787, 344, 0, 6, 3, 0, 0, 6, 356, NULL, 'Vidutinis rodiklis Nr.2 per mėnesį', NULL, 4, NULL, NULL),
	(10788, 344, 0, 5, 3, 0, 0, 5, 356, NULL, 'Vidutinis rodiklis Nr.2 per parą', NULL, 3, NULL, NULL),
	(10789, 344, 0, 4, 3, 0, 0, 4, 356, NULL, 'Vidutinis rodiklis Nr.2 per valandą', NULL, 2, NULL, NULL),
	(10790, 344, 0, 13, 3, 0, 0, 12, 356, NULL, 'Vidutinis rodiklis Nr.2 per 15 minučių', NULL, 2, NULL, NULL),
	(10791, 344, 0, 3, 3, 0, 0, 3, 356, NULL, 'Vidutinis rodiklis Nr.2 per 30 minučių', NULL, 2, NULL, NULL),
	(10792, 345, 0, 6, 3, 0, 0, 6, 357, NULL, 'Vidutinis rodiklis Nr.3 per mėnesį', NULL, 4, NULL, NULL),
	(10793, 345, 0, 5, 3, 0, 0, 5, 357, NULL, 'Vidutinis rodiklis Nr.3 per parą', NULL, 3, NULL, NULL),
	(10794, 345, 0, 4, 3, 0, 0, 4, 357, NULL, 'Vidutinis rodiklis Nr.3 per valandą', NULL, 2, NULL, NULL),
	(10795, 345, 0, 13, 3, 0, 0, 12, 357, NULL, 'Vidutinis rodiklis Nr.3 per 15 minučių', NULL, 2, NULL, NULL),
	(10796, 345, 0, 3, 3, 0, 0, 3, 357, NULL, 'Vidutinis rodiklis Nr.3 per 30 minučių', NULL, 2, NULL, NULL),
	(10797, 346, 0, 6, 3, 0, 0, 6, 358, NULL, 'Vidutinis rodiklis Nr.4 per mėnesį', NULL, 4, NULL, NULL),
	(10798, 346, 0, 5, 3, 0, 0, 5, 358, NULL, 'Vidutinis rodiklis Nr.4 per parą', NULL, 3, NULL, NULL),
	(10799, 346, 0, 4, 3, 0, 0, 4, 358, NULL, 'Vidutinis rodiklis Nr.4 per valandą', NULL, 2, NULL, NULL),
	(10800, 346, 0, 13, 3, 0, 0, 12, 358, NULL, 'Vidutinis rodiklis Nr.4 per 15 minučių', NULL, 2, NULL, NULL),
	(10801, 346, 0, 3, 3, 0, 0, 3, 358, NULL, 'Vidutinis rodiklis Nr.4 per 30 minučių', NULL, 2, NULL, NULL),
	(10802, 347, 0, 6, 3, 0, 0, 6, 359, NULL, 'Vidutinis rodiklis Nr.5 per mėnesį', NULL, 4, NULL, NULL),
	(10803, 347, 0, 5, 3, 0, 0, 5, 359, NULL, 'Vidutinis rodiklis Nr.5 per parą', NULL, 3, NULL, NULL),
	(10804, 347, 0, 4, 3, 0, 0, 4, 359, NULL, 'Vidutinis rodiklis Nr.5 per valandą', NULL, 2, NULL, NULL),
	(10805, 347, 0, 13, 3, 0, 0, 12, 359, NULL, 'Vidutinis rodiklis Nr.5 per 15 minučių', NULL, 2, NULL, NULL),
	(10806, 347, 0, 3, 3, 0, 0, 3, 359, NULL, 'Vidutinis rodiklis Nr.5 per 30 minučių', NULL, 2, NULL, NULL),
	(10807, 365, 0, 6, 3, 0, 0, 6, 377, NULL, 'Vidutinis rodiklis Nr.11 per mėnesį', NULL, 4, NULL, NULL),
	(10808, 365, 0, 5, 3, 0, 0, 5, 377, NULL, 'Vidutinis rodiklis Nr.11 per parą', NULL, 3, NULL, NULL),
	(10809, 365, 0, 4, 3, 0, 0, 4, 377, NULL, 'Vidutinis rodiklis Nr.11 per valandą', NULL, 2, NULL, NULL),
	(10810, 365, 0, 13, 3, 0, 0, 12, 377, NULL, 'Vidutinis rodiklis Nr.11 per 15 minučių', NULL, 2, NULL, NULL),
	(10811, 365, 0, 3, 3, 0, 0, 3, 377, NULL, 'Vidutinis rodiklis Nr.11 per 30 minučių', NULL, 2, NULL, NULL),
	(10812, 366, 0, 6, 3, 0, 0, 6, 378, NULL, 'Vidutinis rodiklis Nr.12 per mėnesį', NULL, 4, NULL, NULL),
	(10813, 366, 0, 5, 3, 0, 0, 5, 378, NULL, 'Vidutinis rodiklis Nr.12 per parą', NULL, 3, NULL, NULL),
	(10814, 366, 0, 4, 3, 0, 0, 4, 378, NULL, 'Vidutinis rodiklis Nr.12 per valandą', NULL, 2, NULL, NULL),
	(10815, 366, 0, 13, 3, 0, 0, 12, 378, NULL, 'Vidutinis rodiklis Nr.12 per 15 minučių', NULL, 2, NULL, NULL),
	(10816, 366, 0, 3, 3, 0, 0, 3, 378, NULL, 'Vidutinis rodiklis Nr.12 per 30 minučių', NULL, 2, NULL, NULL),
	(10817, 367, 0, 6, 3, 0, 0, 6, 379, NULL, 'Vidutinis rodiklis Nr.13 per mėnesį', NULL, 4, NULL, NULL),
	(10818, 367, 0, 5, 3, 0, 0, 5, 379, NULL, 'Vidutinis rodiklis Nr.13 per parą', NULL, 3, NULL, NULL),
	(10819, 367, 0, 4, 3, 0, 0, 4, 379, NULL, 'Vidutinis rodiklis Nr.13 per valandą', NULL, 2, NULL, NULL),
	(10820, 367, 0, 13, 3, 0, 0, 12, 379, NULL, 'Vidutinis rodiklis Nr.13 per 15 minučių', NULL, 2, NULL, NULL),
	(10821, 367, 0, 3, 3, 0, 0, 3, 379, NULL, 'Vidutinis rodiklis Nr.13 per 30 minučių', NULL, 2, NULL, NULL),
	(10822, 368, 0, 6, 3, 0, 0, 6, 380, NULL, 'Vidutinis rodiklis Nr.14 per mėnesį', NULL, 4, NULL, NULL),
	(10823, 368, 0, 5, 3, 0, 0, 5, 380, NULL, 'Vidutinis rodiklis Nr.14 per parą', NULL, 3, NULL, NULL),
	(10824, 368, 0, 4, 3, 0, 0, 4, 380, NULL, 'Vidutinis rodiklis Nr.14 per valandą', NULL, 2, NULL, NULL),
	(10825, 368, 0, 13, 3, 0, 0, 12, 380, NULL, 'Vidutinis rodiklis Nr.14 per 15 minučių', NULL, 2, NULL, NULL),
	(10826, 368, 0, 3, 3, 0, 0, 3, 380, NULL, 'Vidutinis rodiklis Nr.14 per 30 minučių', NULL, 2, NULL, NULL),
	(10827, 369, 0, 6, 3, 0, 0, 6, 381, NULL, 'Vidutinis rodiklis Nr.15 per mėnesį', NULL, 4, NULL, NULL),
	(10828, 369, 0, 5, 3, 0, 0, 5, 381, NULL, 'Vidutinis rodiklis Nr.15 per parą', NULL, 3, NULL, NULL),
	(10829, 369, 0, 4, 3, 0, 0, 4, 381, NULL, 'Vidutinis rodiklis Nr.15 per valandą', NULL, 2, NULL, NULL),
	(10830, 369, 0, 13, 3, 0, 0, 12, 381, NULL, 'Vidutinis rodiklis Nr.15 per 15 minučių', NULL, 2, NULL, NULL),
	(10831, 369, 0, 3, 3, 0, 0, 3, 381, NULL, 'Vidutinis rodiklis Nr.15 per 30 minučių', NULL, 2, NULL, NULL),
	(10832, 375, 0, 6, 3, 0, 0, 6, 387, NULL, 'Vidutinis rodiklis Nr.21 per mėnesį', NULL, 4, NULL, NULL),
	(10833, 375, 0, 5, 3, 0, 0, 5, 387, NULL, 'Vidutinis rodiklis Nr.21 per parą', NULL, 3, NULL, NULL),
	(10834, 375, 0, 4, 3, 0, 0, 4, 387, NULL, 'Vidutinis rodiklis Nr.21 per valandą', NULL, 2, NULL, NULL),
	(10835, 375, 0, 13, 3, 0, 0, 12, 387, NULL, 'Vidutinis rodiklis Nr.21 per 15 minučių', NULL, 2, NULL, NULL),
	(10836, 375, 0, 3, 3, 0, 0, 3, 387, NULL, 'Vidutinis rodiklis Nr.21 per 30 minučių', NULL, 2, NULL, NULL),
	(10837, 376, 0, 6, 3, 0, 0, 6, 388, NULL, 'Vidutinis rodiklis Nr.22 per mėnesį', NULL, 4, NULL, NULL),
	(10838, 376, 0, 5, 3, 0, 0, 5, 388, NULL, 'Vidutinis rodiklis Nr.22 per parą', NULL, 3, NULL, NULL),
	(10839, 376, 0, 4, 3, 0, 0, 4, 388, NULL, 'Vidutinis rodiklis Nr.22 per valandą', NULL, 2, NULL, NULL),
	(10840, 376, 0, 13, 3, 0, 0, 12, 388, NULL, 'Vidutinis rodiklis Nr.22 per 15 minučių', NULL, 2, NULL, NULL),
	(10841, 376, 0, 3, 3, 0, 0, 3, 388, NULL, 'Vidutinis rodiklis Nr.22 per 30 minučių', NULL, 2, NULL, NULL),
	(10842, 377, 0, 6, 3, 0, 0, 6, 389, NULL, 'Vidutinis rodiklis Nr.23 per mėnesį', NULL, 4, NULL, NULL),
	(10843, 377, 0, 5, 3, 0, 0, 5, 389, NULL, 'Vidutinis rodiklis Nr.23 per parą', NULL, 3, NULL, NULL),
	(10844, 377, 0, 4, 3, 0, 0, 4, 389, NULL, 'Vidutinis rodiklis Nr.23 per valanda', NULL, 2, NULL, NULL),
	(10845, 377, 0, 13, 3, 0, 0, 12, 389, NULL, 'Vidutinis rodiklis Nr.23 per 15 minučių', NULL, 2, NULL, NULL),
	(10846, 377, 0, 3, 3, 0, 0, 3, 389, NULL, 'Vidutinis rodiklis Nr.23 per 30 minučių', NULL, 2, NULL, NULL),
	(10847, 378, 0, 6, 3, 0, 0, 6, 390, NULL, 'Vidutinis rodiklis Nr.24 per mėnesį', NULL, 4, NULL, NULL),
	(10848, 378, 0, 5, 3, 0, 0, 5, 390, NULL, 'Vidutinis rodiklis Nr.24 per parą', NULL, 3, NULL, NULL),
	(10849, 378, 0, 4, 3, 0, 0, 4, 390, NULL, 'Vidutinis rodiklis Nr.24 per valandą', NULL, 2, NULL, NULL),
	(10850, 378, 0, 13, 3, 0, 0, 12, 390, NULL, 'Vidutinis rodiklis Nr.24 per 15 minučių', NULL, 2, NULL, NULL),
	(10851, 378, 0, 3, 3, 0, 0, 3, 390, NULL, 'Vidutinis rodiklis Nr.24 per 30 minučių', NULL, 2, NULL, NULL),
	(10852, 379, 0, 6, 3, 0, 0, 6, 391, NULL, 'Vidutinis rodiklis Nr.25 per mėnesį', NULL, 4, NULL, NULL),
	(10853, 379, 0, 5, 3, 0, 0, 5, 391, NULL, 'Vidutinis rodiklis Nr.25 per parą', NULL, 3, NULL, NULL),
	(10854, 379, 0, 4, 3, 0, 0, 4, 391, NULL, 'Vidutinis rodiklis Nr.25 per valandą', NULL, 2, NULL, NULL),
	(10855, 379, 0, 13, 3, 0, 0, 12, 391, NULL, 'Vidutinis rodiklis Nr.25 per 15 minučių', NULL, 2, NULL, NULL),
	(10856, 379, 0, 3, 3, 0, 0, 3, 391, NULL, 'Vidutinis rodiklis Nr.25 per 30 minučių', NULL, 2, NULL, NULL),
	(10857, 380, 0, 6, 3, 0, 0, 6, 392, NULL, 'Vidutinis rodiklis Nr.26 per mėnesį', NULL, 4, NULL, NULL),
	(10858, 380, 0, 5, 3, 0, 0, 5, 392, NULL, 'Vidutinis rodiklis Nr.26 per parą', NULL, 3, NULL, NULL),
	(10859, 380, 0, 4, 3, 0, 0, 4, 392, NULL, 'Vidutinis rodiklis Nr.26 per valandą', NULL, 2, NULL, NULL),
	(10860, 380, 0, 13, 3, 0, 0, 12, 392, NULL, 'Vidutinis rodiklis Nr.26 per 15 minučių', NULL, 2, NULL, NULL),
	(10861, 380, 0, 3, 3, 0, 0, 3, 392, NULL, 'Vidutinis rodiklis Nr.26 per 30 minučių', NULL, 2, NULL, NULL),
	(10862, 381, 0, 6, 3, 0, 0, 6, 393, NULL, 'Vidutinis rodiklis Nr.27 per mėnesį', NULL, 4, NULL, NULL),
	(10863, 381, 0, 5, 3, 0, 0, 5, 393, NULL, 'Vidutinis rodiklis Nr.27 per parą', NULL, 3, NULL, NULL),
	(10864, 381, 0, 4, 3, 0, 0, 4, 393, NULL, 'Vidutinis rodiklis Nr.27 per valandą', NULL, 2, NULL, NULL),
	(10865, 381, 0, 13, 3, 0, 0, 12, 393, NULL, 'Vidutinis rodiklis Nr.27 per 15 minučių', NULL, 2, NULL, NULL),
	(10866, 381, 0, 3, 3, 0, 0, 3, 393, NULL, 'Vidutinis rodiklis Nr.27 per 30 minučių', NULL, 2, NULL, NULL),
	(10867, 382, 0, 6, 3, 0, 0, 6, 394, NULL, 'Vidutinis rodiklis Nr.28 per mėnesį', NULL, 4, NULL, NULL),
	(10868, 382, 0, 5, 3, 0, 0, 5, 394, NULL, 'Vidutinis rodiklis Nr.28 per parą', NULL, 3, NULL, NULL),
	(10869, 382, 0, 4, 3, 0, 0, 4, 394, NULL, 'Vidutinis rodiklis Nr.28 per valandą', NULL, 2, NULL, NULL),
	(10870, 382, 0, 13, 3, 0, 0, 12, 394, NULL, 'Vidutinis rodiklis Nr.28 per 15 minučių', NULL, 2, NULL, NULL),
	(10871, 382, 0, 3, 3, 0, 0, 3, 394, NULL, 'Vidutinis rodiklis Nr.28 per 30 minučių', NULL, 2, NULL, NULL),
	(10872, 383, 0, 6, 3, 0, 0, 6, 395, NULL, 'Vidutinis rodiklis Nr.29 per mėnesį', NULL, 4, NULL, NULL),
	(10873, 383, 0, 5, 3, 0, 0, 5, 395, NULL, 'Vidutinis rodiklis Nr.29 per parą', NULL, 3, NULL, NULL),
	(10874, 383, 0, 4, 3, 0, 0, 4, 395, NULL, 'Vidutinis rodiklis Nr.29 per valandą', NULL, 2, NULL, NULL),
	(10875, 383, 0, 13, 3, 0, 0, 12, 395, NULL, 'Vidutinis rodiklis Nr.29 per 15 minučių', NULL, 2, NULL, NULL),
	(10876, 383, 0, 3, 3, 0, 0, 3, 395, NULL, 'Vidutinis rodiklis Nr.29 per 30 minučių', NULL, 2, NULL, NULL),
	(10877, 384, 0, 6, 3, 0, 0, 6, 455, NULL, 'Vidutinis rodiklis Nr.30 per mėnesį', NULL, 4, NULL, NULL),
	(10878, 384, 0, 5, 3, 0, 0, 5, 455, NULL, 'Vidutinis rodiklis Nr.30 per parą', NULL, 3, NULL, NULL),
	(10879, 384, 0, 4, 3, 0, 0, 4, 455, NULL, 'Vidutinis rodiklis Nr.30 per valandą', NULL, 2, NULL, NULL),
	(10880, 384, 0, 13, 3, 0, 0, 12, 455, NULL, 'Vidutinis rodiklis Nr.30 per 15 minučių', NULL, 2, NULL, NULL),
	(10881, 384, 0, 3, 3, 0, 0, 3, 455, NULL, 'Vidutinis rodiklis Nr.30 per 30 minučių', NULL, 2, NULL, NULL),
	(10882, 445, 0, 6, 3, 0, 0, 6, 459, NULL, 'Vidutinis rodiklis Nr.31 per mėnesį', NULL, 4, NULL, NULL),
	(10883, 445, 0, 5, 3, 0, 0, 5, 459, NULL, 'Vidutinis rodiklis Nr.31 per parą', NULL, 3, NULL, NULL),
	(10884, 445, 0, 4, 3, 0, 0, 4, 459, NULL, 'Vidutinis rodiklis Nr.31 per valandą', NULL, 2, NULL, NULL),
	(10885, 445, 0, 13, 3, 0, 0, 12, 459, NULL, 'Vidutinis rodiklis Nr.31 per 15 minučių', NULL, 2, NULL, NULL),
	(10886, 445, 0, 3, 3, 0, 0, 3, 459, NULL, 'Vidutinis rodiklis Nr.31 per 30 minučių', NULL, 2, NULL, NULL),
	(10887, 445, 0, 7, 3, 0, 0, 7, 459, NULL, 'Momentinis rodiklis Nr.31', NULL, 6, NULL, NULL),
	(10888, 445, 0, 7, 3, 0, 0, 6, 459, NULL, 'Momentinis rodiklis Nr.31, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(10889, 445, 0, 7, 3, 0, 0, 5, 459, NULL, 'Momentinis rodiklis Nr.31, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(10890, 445, 0, 7, 3, 0, 0, 4, 459, NULL, 'Momentinis rodiklis Nr.31, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(10891, 446, 0, 6, 3, 0, 0, 6, 460, NULL, 'Vidutinis rodiklis Nr.32 per mėnesį', NULL, 4, NULL, NULL),
	(10892, 446, 0, 5, 3, 0, 0, 5, 460, NULL, 'Vidutinis rodiklis Nr.32 per parą', NULL, 3, NULL, NULL),
	(10893, 446, 0, 4, 3, 0, 0, 4, 460, NULL, 'Vidutinis rodiklis Nr.32 per valandą', NULL, 2, NULL, NULL),
	(10894, 446, 0, 13, 3, 0, 0, 12, 460, NULL, 'Vidutinis rodiklis Nr.32 per 15 minučių', NULL, 2, NULL, NULL),
	(10895, 446, 0, 3, 3, 0, 0, 3, 460, NULL, 'Vidutinis rodiklis Nr.32 per 30 minučių', NULL, 2, NULL, NULL),
	(10896, 446, 0, 7, 3, 0, 0, 7, 460, NULL, 'Momentinis rodiklis Nr.32', NULL, 6, NULL, NULL),
	(10897, 446, 0, 7, 3, 0, 0, 6, 460, NULL, 'Momentinis rodiklis Nr.32, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(10898, 446, 0, 7, 3, 0, 0, 5, 460, NULL, 'Momentinis rodiklis Nr.32, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(10899, 446, 0, 7, 3, 0, 0, 4, 460, NULL, 'Momentinis rodiklis Nr.32, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(10900, 447, 0, 6, 3, 0, 0, 6, 461, NULL, 'Vidutinis rodiklis Nr.33 per mėnesį', NULL, 4, NULL, NULL),
	(10901, 447, 0, 5, 3, 0, 0, 5, 461, NULL, 'Vidutinis rodiklis Nr.33 per parą', NULL, 3, NULL, NULL),
	(10902, 447, 0, 4, 3, 0, 0, 4, 461, NULL, 'Vidutinis rodiklis Nr.33 per valandą', NULL, 2, NULL, NULL),
	(10903, 447, 0, 13, 3, 0, 0, 12, 461, NULL, 'Vidutinis rodiklis Nr.33 per 15 minučių', NULL, 2, NULL, NULL),
	(10904, 447, 0, 3, 3, 0, 0, 3, 461, NULL, 'Vidutinis rodiklis Nr.33 per 30 minučių', NULL, 2, NULL, NULL),
	(10905, 447, 0, 7, 3, 0, 0, 7, 461, NULL, 'Momentinis rodiklis Nr.33', NULL, 6, NULL, NULL),
	(10906, 447, 0, 7, 3, 0, 0, 6, 461, NULL, 'Momentinis rodiklis Nr.33, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(10907, 447, 0, 7, 3, 0, 0, 5, 461, NULL, 'Momentinis rodiklis Nr.33, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(10908, 447, 0, 7, 3, 0, 0, 4, 461, NULL, 'Momentinis rodiklis Nr.33, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(10909, 448, 0, 6, 3, 0, 0, 6, 462, NULL, 'Vidutinis rodiklis Nr.34 per mėnesį', NULL, 4, NULL, NULL),
	(10910, 448, 0, 5, 3, 0, 0, 5, 462, NULL, 'Vidutinis rodiklis Nr.34 per parą', NULL, 3, NULL, NULL),
	(10911, 448, 0, 4, 3, 0, 0, 4, 462, NULL, 'Vidutinis rodiklis Nr.34 per valandą', NULL, 2, NULL, NULL),
	(10912, 448, 0, 13, 3, 0, 0, 12, 462, NULL, 'Vidutinis rodiklis Nr.34 per 15 minučių', NULL, 2, NULL, NULL),
	(10913, 448, 0, 3, 3, 0, 0, 3, 462, NULL, 'Vidutinis rodiklis Nr.34 per 30 minučių', NULL, 2, NULL, NULL),
	(10914, 448, 0, 7, 3, 0, 0, 7, 462, NULL, 'Momentinis rodiklis Nr.34', NULL, 6, NULL, NULL),
	(10915, 448, 0, 7, 3, 0, 0, 6, 462, NULL, 'Momentinis rodiklis Nr.34, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(10916, 448, 0, 7, 3, 0, 0, 5, 462, NULL, 'Momentinis rodiklis Nr.34, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(10917, 448, 0, 7, 3, 0, 0, 4, 462, NULL, 'Momentinis rodiklis Nr.34, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(10918, 449, 0, 6, 3, 0, 0, 6, 463, NULL, 'Vidutinis rodiklis Nr.35 per mėnesį', NULL, 4, NULL, NULL),
	(10919, 449, 0, 5, 3, 0, 0, 5, 463, NULL, 'Vidutinis rodiklis Nr.35 per parą', NULL, 3, NULL, NULL),
	(10920, 449, 0, 4, 3, 0, 0, 4, 463, NULL, 'Vidutinis rodiklis Nr.35 per valandą', NULL, 2, NULL, NULL),
	(10921, 449, 0, 13, 3, 0, 0, 12, 463, NULL, 'Vidutinis rodiklis Nr.35 per 15 minučių', NULL, 2, NULL, NULL),
	(10922, 449, 0, 3, 3, 0, 0, 3, 463, NULL, 'Vidutinis rodiklis Nr.35 per 30 minučių', NULL, 2, NULL, NULL),
	(10923, 449, 0, 7, 3, 0, 0, 7, 463, NULL, 'Momentinis rodiklis Nr.35', NULL, 6, NULL, NULL),
	(10924, 449, 0, 7, 3, 0, 0, 6, 463, NULL, 'Momentinis rodiklis Nr.35, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(10925, 449, 0, 7, 3, 0, 0, 5, 463, NULL, 'Momentinis rodiklis Nr.35, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(10926, 449, 0, 7, 3, 0, 0, 4, 463, NULL, 'Momentinis rodiklis Nr.35, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(10927, 450, 0, 6, 3, 0, 0, 6, 464, NULL, 'Vidutinis rodiklis Nr.36 per mėnesį', NULL, 4, NULL, NULL),
	(10928, 450, 0, 5, 3, 0, 0, 5, 464, NULL, 'Vidutinis rodiklis Nr.36 per parą', NULL, 3, NULL, NULL),
	(10929, 450, 0, 4, 3, 0, 0, 4, 464, NULL, 'Vidutinis rodiklis Nr.36 per valandą', NULL, 2, NULL, NULL),
	(10930, 450, 0, 13, 3, 0, 0, 12, 464, NULL, 'Vidutinis rodiklis Nr.36 per 15 minučių', NULL, 2, NULL, NULL),
	(10931, 450, 0, 3, 3, 0, 0, 3, 464, NULL, 'Vidutinis rodiklis Nr.36 per 30 minučių', NULL, 2, NULL, NULL),
	(10932, 450, 0, 7, 3, 0, 0, 7, 464, NULL, 'Momentinis rodiklis Nr.36', NULL, 6, NULL, NULL),
	(10933, 450, 0, 7, 3, 0, 0, 6, 464, NULL, 'Momentinis rodiklis Nr.36, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(10934, 450, 0, 7, 3, 0, 0, 5, 464, NULL, 'Momentinis rodiklis Nr.36, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(10935, 450, 0, 7, 3, 0, 0, 4, 464, NULL, 'Momentinis rodiklis Nr.36, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(10936, 451, 0, 6, 3, 0, 0, 6, 465, NULL, 'Vidutinis rodiklis Nr.37 per mėnesį', NULL, 4, NULL, NULL),
	(10937, 451, 0, 5, 3, 0, 0, 5, 465, NULL, 'Vidutinis rodiklis Nr.37 per parą', NULL, 3, NULL, NULL),
	(10938, 451, 0, 4, 3, 0, 0, 4, 465, NULL, 'Vidutinis rodiklis Nr.37 per valandą', NULL, 2, NULL, NULL),
	(10939, 451, 0, 13, 3, 0, 0, 12, 465, NULL, 'Vidutinis rodiklis Nr.37 per 15 minučių', NULL, 2, NULL, NULL),
	(10940, 451, 0, 3, 3, 0, 0, 3, 465, NULL, 'Vidutinis rodiklis Nr.37 per 30 minučių', NULL, 2, NULL, NULL),
	(10941, 451, 0, 7, 3, 0, 0, 7, 465, NULL, 'Momentinis rodiklis Nr.37', NULL, 6, NULL, NULL),
	(10942, 451, 0, 7, 3, 0, 0, 6, 465, NULL, 'Momentinis rodiklis Nr.37, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(10943, 451, 0, 7, 3, 0, 0, 5, 465, NULL, 'Momentinis rodiklis Nr.37, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(10944, 451, 0, 7, 3, 0, 0, 4, 465, NULL, 'Momentinis rodiklis Nr.37, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(10945, 452, 0, 6, 3, 0, 0, 6, 466, NULL, 'Vidutinis rodiklis Nr.38 per mėnesį', NULL, 4, NULL, NULL),
	(10946, 452, 0, 5, 3, 0, 0, 5, 466, NULL, 'Vidutinis rodiklis Nr.38 per parą', NULL, 3, NULL, NULL),
	(10947, 452, 0, 4, 3, 0, 0, 4, 466, NULL, 'Vidutinis rodiklis Nr.38 per valandą', NULL, 2, NULL, NULL),
	(10948, 452, 0, 13, 3, 0, 0, 12, 466, NULL, 'Vidutinis rodiklis Nr.38 per 15 minučių', NULL, 2, NULL, NULL),
	(10949, 452, 0, 3, 3, 0, 0, 3, 466, NULL, 'Vidutinis rodiklis Nr.38 per 30 minučių', NULL, 2, NULL, NULL),
	(10950, 452, 0, 7, 3, 0, 0, 7, 466, NULL, 'Momentinis rodiklis Nr.38', NULL, 6, NULL, NULL),
	(10951, 452, 0, 7, 3, 0, 0, 6, 466, NULL, 'Momentinis rodiklis Nr.38, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(10952, 452, 0, 7, 3, 0, 0, 5, 466, NULL, 'Momentinis rodiklis Nr.38, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(10953, 452, 0, 7, 3, 0, 0, 4, 466, NULL, 'Momentinis rodiklis Nr.38, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(10954, 453, 0, 6, 3, 0, 0, 6, 467, NULL, 'Vidutinis rodiklis Nr.39 per mėnesį', NULL, 4, NULL, NULL),
	(10955, 453, 0, 5, 3, 0, 0, 5, 467, NULL, 'Vidutinis rodiklis Nr.39 per parą', NULL, 3, NULL, NULL),
	(10956, 453, 0, 4, 3, 0, 0, 4, 467, NULL, 'Vidutinis rodiklis Nr.39 per valandą', NULL, 2, NULL, NULL),
	(10957, 453, 0, 13, 3, 0, 0, 12, 467, NULL, 'Vidutinis rodiklis Nr.39 per 15 minučių', NULL, 2, NULL, NULL),
	(10958, 453, 0, 3, 3, 0, 0, 3, 467, NULL, 'Vidutinis rodiklis Nr.39 per 30 minučių', NULL, 2, NULL, NULL),
	(10959, 453, 0, 7, 3, 0, 0, 7, 467, NULL, 'Momentinis rodiklis Nr.39', NULL, 6, NULL, NULL),
	(10960, 453, 0, 7, 3, 0, 0, 6, 467, NULL, 'Momentinis rodiklis Nr.39, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(10961, 453, 0, 7, 3, 0, 0, 5, 467, NULL, 'Momentinis rodiklis Nr.39, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(10962, 453, 0, 7, 3, 0, 0, 4, 467, NULL, 'Momentinis rodiklis Nr.39, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(10963, 454, 0, 6, 3, 0, 0, 6, 468, NULL, 'Vidutinis rodiklis Nr.40 per mėnesį', NULL, 4, NULL, NULL),
	(10964, 454, 0, 5, 3, 0, 0, 5, 468, NULL, 'Vidutinis rodiklis Nr.40 per parą', NULL, 3, NULL, NULL),
	(10965, 454, 0, 4, 3, 0, 0, 4, 468, NULL, 'Vidutinis rodiklis Nr.40 per valandą', NULL, 2, NULL, NULL),
	(10966, 454, 0, 13, 3, 0, 0, 12, 468, NULL, 'Vidutinis rodiklis Nr.40 per 15 minučių', NULL, 2, NULL, NULL),
	(10967, 454, 0, 3, 3, 0, 0, 3, 468, NULL, 'Vidutinis rodiklis Nr.40 per 30 minučių', NULL, 2, NULL, NULL),
	(10968, 454, 0, 7, 3, 0, 0, 7, 468, NULL, 'Momentinis rodiklis Nr.40', NULL, 6, NULL, NULL),
	(10969, 454, 0, 7, 3, 0, 0, 6, 468, NULL, 'Momentinis rodiklis Nr.40, fiksuojamas kas mėnesį', NULL, 4, NULL, NULL),
	(10970, 454, 0, 7, 3, 0, 0, 5, 468, NULL, 'Momentinis rodiklis Nr.40, fiksuojamas kas parą', NULL, 3, NULL, NULL),
	(10971, 454, 0, 7, 3, 0, 0, 4, 468, NULL, 'Momentinis rodiklis Nr.40, fiksuojamas kas valandą', NULL, 2, NULL, NULL),
	(10972, 339, 0, 4, 2, 0, 29, 4, 351, NULL, 'Dujų skaitiklio darbo laikas per valandą', 1143, 2, NULL, NULL),
	(10973, 339, 0, 5, 2, 0, 29, 5, 351, NULL, 'Dujų skaitiklio darbo laikas per parą', 1143, 3, NULL, NULL),
	(10974, 339, 0, 6, 2, 0, 29, 6, 351, NULL, 'Dujų skaitiklio darbo laikas per mėnesį', 1143, 4, NULL, NULL),
	(10975, 339, 0, 8, 2, 0, 29, 6, 351, NULL, 'Suminis dujų skaitiklio darbo laikas, fiksuojamas kas mėnesį', 1120, 5, NULL, NULL),
	(10976, 339, 0, 8, 2, 0, 29, 5, 351, NULL, 'Suminis dujų skaitiklio darbo laikas, fiksuojamas kas parą', 1120, 5, NULL, NULL),
	(10977, 339, 0, 8, 2, 0, 29, 4, 351, NULL, 'Suminis dujų skaitiklio darbo laikas, fiksuojamas kas valandą', 1120, 5, NULL, NULL),
	(10978, 456, 0, 6, 2, 0, 43, 6, 471, NULL, 'Oro masės kiekis per mėnesį', 1310, 4, NULL, NULL),
	(10979, 456, 0, 5, 2, 0, 43, 5, 471, NULL, 'Oro masės kiekis per parą', 1310, 3, NULL, NULL),
	(10980, 456, 0, 4, 2, 0, 43, 4, 471, NULL, 'Oro masės kiekis per valandą', 1310, 2, NULL, NULL),
	(10981, 456, 0, 13, 2, 0, 43, 12, 471, NULL, 'Oro masės kiekis per 15 minučių', 1310, 2, NULL, NULL),
	(10982, 456, 0, 2, 2, 0, 43, 2, 471, NULL, 'Oro masės kiekis per 2 minutes', 1310, 1, NULL, NULL),
	(10983, 456, 0, 3, 2, 0, 43, 3, 471, NULL, 'Oro masės kiekis per 30 minučių', 1310, 2, NULL, NULL),
	(10984, 455, 0, 6, 2, 0, 31, 6, 469, NULL, 'Oro tūrio kiekis per mėnesį', 1306, 4, NULL, NULL),
	(10985, 455, 0, 5, 2, 0, 31, 5, 469, NULL, 'Oro tūrio kiekis per parą', 1306, 3, NULL, NULL),
	(10986, 455, 0, 4, 2, 0, 31, 4, 469, NULL, 'Oro tūrio kiekis per valandą', 1306, 2, NULL, NULL),
	(10987, 455, 0, 13, 2, 0, 31, 12, 469, NULL, 'Oro tūrio kiekis per 15 minučių', 1306, 2, NULL, NULL),
	(10988, 455, 0, 2, 2, 0, 31, 2, 469, NULL, 'Oro tūrio kiekis per 2 minutes', 1306, 1, NULL, NULL),
	(10989, 455, 0, 3, 2, 0, 31, 3, 469, NULL, 'Oro tūrio kiekis per 30 minučių', 1306, 2, NULL, NULL),
	(10990, 456, 0, 7, 1, 0, 73, 7, 472, NULL, 'Momentinis oro masės srautas', 1309, 6, NULL, NULL),
	(10991, 455, 0, 7, 1, 0, 32, 7, 470, NULL, 'Momentinis oro tūrio srautas', 1305, 6, NULL, NULL),
	(10992, 456, 0, 8, 2, 0, 43, 7, 471, NULL, 'Suminis oro masės kiekis', 1308, 5, NULL, NULL),
	(10993, 456, 0, 8, 2, 0, 43, 6, 471, NULL, 'Suminis oro masės kiekis, fiksuojamas kas mėnesį', 1308, 5, NULL, NULL),
	(10994, 456, 0, 8, 2, 0, 43, 5, 471, NULL, 'Suminis oro masės kiekis, fiksuojamas kas parą', 1308, 5, NULL, NULL),
	(10995, 456, 0, 8, 2, 0, 43, 4, 471, NULL, 'Suminis oro masės kiekis, fiksuojamas kas valandą', 1308, 5, NULL, NULL),
	(10996, 456, 0, 8, 2, 0, 43, 12, 471, NULL, 'Suminis oro masės kiekis, fiksuojamas kas 15 minučių', 1308, 5, NULL, NULL),
	(10997, 456, 0, 8, 2, 0, 43, 3, 471, NULL, 'Suminis oro masės kiekis, fiksuojamas kas 30 minučių', 1308, 5, NULL, NULL),
	(10998, 455, 0, 8, 2, 0, 31, 7, 469, NULL, 'Suminis oro tūrio kiekis', 1304, 5, NULL, NULL),
	(10999, 455, 0, 8, 2, 0, 31, 6, 469, NULL, 'Suminis oro tūrio kiekis, fiksuojamas kas mėnesį', 1304, 5, NULL, NULL),
	(11000, 455, 0, 8, 2, 0, 31, 5, 469, NULL, 'Suminis oro tūrio kiekis, fiksuojamas kas parą', 1304, 5, NULL, NULL),
	(11001, 455, 0, 8, 2, 0, 31, 4, 469, NULL, 'Suminis oro tūrio kiekis, fiksuojamas kas valandą', 1304, 5, NULL, NULL),
	(11002, 455, 0, 8, 2, 0, 31, 12, 469, NULL, 'Suminis oro tūrio kiekis, fiksuojamas kas 15 minučių', 1304, 5, NULL, NULL),
	(11003, 455, 0, 8, 2, 0, 31, 3, 469, NULL, 'Suminis oro tūrio kiekis, fiksuojamas kas 30 minučių', 1304, 5, NULL, NULL),
	(11004, 456, 0, 6, 3, 0, 73, 6, 472, NULL, 'Vidutinis oro masės srautas per mėnesį', 1311, 4, NULL, NULL),
	(11005, 456, 0, 5, 3, 0, 73, 5, 472, NULL, 'Vidutinis oro masės srautas per parą', 1311, 3, NULL, NULL),
	(11006, 456, 0, 4, 3, 0, 73, 4, 472, NULL, 'Vidutinis oro masės srautas per valandą', 1311, 2, NULL, NULL),
	(11007, 456, 0, 13, 3, 0, 73, 12, 472, NULL, 'Vidutinis oro masės srautas per 15 minučių', 1311, 2, NULL, NULL),
	(11008, 456, 0, 2, 3, 0, 73, 2, 472, NULL, 'Vidutinis oro masės srautas per 2 minutes', 1311, 1, NULL, NULL),
	(11009, 456, 0, 3, 3, 0, 73, 3, 472, NULL, 'Vidutinis oro masės srautas per 30 minučių', 1311, 2, NULL, NULL),
	(11010, 455, 0, 6, 3, 0, 32, 6, 470, NULL, 'Vidutinis oro tūrio srautas per mėnesį', 1307, 4, NULL, NULL),
	(11011, 455, 0, 5, 3, 0, 32, 5, 470, NULL, 'Vidutinis oro tūrio srautas per parą', 1307, 3, NULL, NULL),
	(11012, 455, 0, 4, 3, 0, 32, 4, 470, NULL, 'Vidutinis oro tūrio srautas per valandą', 1307, 2, NULL, NULL),
	(11013, 455, 0, 13, 3, 0, 32, 12, 470, NULL, 'Vidutinis oro tūrio srautas per 15 minučių', 1307, 2, NULL, NULL),
	(11014, 455, 0, 2, 3, 0, 32, 2, 470, NULL, 'Vidutinis oro tūrio srautas per 2 minutes', 1307, 1, NULL, NULL),
	(11015, 455, 0, 3, 3, 0, 32, 3, 470, NULL, 'Vidutinis oro tūrio srautas per 30 minučių', 1307, 2, NULL, NULL),
	(11016, 456, 0, 8, 2, 0, 43, 2, 471, NULL, 'Suminis oro masės kiekis, fiksuojamas kas 2 minutes', 1308, 5, NULL, NULL),
	(11017, 455, 0, 8, 2, 0, 31, 2, 469, NULL, 'Suminis oro tūrio kiekis, fiksuojamas kas 2 minutes', 1304, 5, NULL, NULL),
	(11018, 1, 1, 9, 4, 0, 1, 6, 13, NULL, 'Maksimali 3 minučių P+ galia per mėnesį', 374, 4, NULL, NULL),
	(11019, 1, 1, 13, 4, 0, 1, 6, 13, NULL, 'Maksimali 15 minučių P+ galia per mėnesį', 374, 4, NULL, NULL),
	(11020, 1, 2, 13, 4, 0, 1, 6, 13, NULL, 'Maksimali 15 minučių P- galia per mėnesį', 375, 4, NULL, NULL),
	(11021, 1, 2, 9, 4, 0, 1, 6, 13, NULL, 'Maksimali 3 minučių P- galia per mėnesį', 375, 4, NULL, NULL),
	(11022, 3, 1, 9, 4, 0, 3, 6, 16, NULL, 'Maksimali 3 minučių Q+ galia per mėnesį', 376, 4, NULL, NULL),
	(11023, 3, 1, 13, 4, 0, 3, 6, 16, NULL, 'Maksimali 15 minučių Q+ galia per mėnesį', 376, 4, NULL, NULL),
	(11024, 3, 2, 13, 4, 0, 3, 6, 16, NULL, 'Maksimali 15 minučių Q- galia per mėnesį', 377, 4, NULL, NULL),
	(11025, 3, 2, 9, 4, 0, 3, 6, 16, NULL, 'Maksimali 3 minučių Q- galia per mėnesį', 377, 4, NULL, NULL),
	(11026, 1, 1, 11, 4, 0, 1, 5, 13, NULL, 'Maksimali 5 minučių P+ galia per parą', 394, 4, NULL, NULL),
	(11027, 1, 1, 13, 4, 0, 1, 5, 13, NULL, 'Maksimali 15 minučių P+ galia per parą', 394, 4, NULL, NULL),
	(11028, 1, 2, 13, 4, 0, 1, 5, 13, NULL, 'Maksimali 15 minučių P- galia per parą', 395, 4, NULL, NULL),
	(11029, 1, 2, 11, 4, 0, 1, 5, 13, NULL, 'Maksimali 5 minučių P- galia per parą', 395, 4, NULL, NULL),
	(11030, 3, 1, 11, 4, 0, 3, 5, 16, NULL, 'Maksimali 5 minučių Q+ galia per parą', 396, 4, NULL, NULL),
	(11031, 3, 1, 13, 4, 0, 3, 5, 16, NULL, 'Maksimali 15 minučių Q+ galia per parą', 396, 4, NULL, NULL),
	(11032, 3, 2, 13, 4, 0, 3, 5, 16, NULL, 'Maksimali 15 minučių Q- galia per parą', 397, 4, NULL, NULL),
	(11033, 3, 2, 11, 4, 0, 3, 5, 16, NULL, 'Maksimali 5 minučių Q- galia per parą', 397, 4, NULL, NULL),
	(11034, 3, 5, 9, 4, 0, 3, 4, 16, NULL, 'Maksimali 3 minučių Q1 galia per valandą', 659, 2, NULL, NULL),
	(11035, 3, 6, 9, 4, 0, 3, 4, 16, NULL, 'Maksimali 3 minučių Q2 galia per valandą', 660, 2, NULL, NULL),
	(11036, 3, 7, 9, 4, 0, 3, 4, 16, NULL, 'Maksimali 3 minučių Q3 galia per valandą', 661, 2, NULL, NULL),
	(11037, 3, 8, 9, 4, 0, 3, 4, 16, NULL, 'Maksimali 3 minučių Q4 galia per valandą', 662, 2, NULL, NULL),
	(11038, 34, 1, 9, 4, 0, 7, 4, 44, NULL, 'Maksimali 3 minučių S+ galia per valandą', 665, 2, NULL, NULL),
	(11039, 34, 2, 9, 4, 0, 7, 4, 44, NULL, 'Maksimali 3 minučių S- galia per valandą', 666, 2, NULL, NULL),
	(11040, 34, 0, 5, 4, 0, 41, 6, 45, NULL, 'Maksimali paros W energija per mėnesį', NULL, 4, NULL, NULL),
	(11041, 34, 0, 5, 5, 0, 41, 6, 45, NULL, 'Minimali paros W energija per mėnesį', NULL, 4, NULL, NULL),
	(11042, 370, 0, 6, 2, 0, 0, 6, 382, NULL, 'Rodiklis Nr.16 per mėnesį', NULL, 4, NULL, NULL),
	(11043, 371, 0, 6, 2, 0, 0, 6, 383, NULL, 'Rodiklis Nr.17 per mėnesį', NULL, 4, NULL, NULL),
	(11044, 372, 0, 6, 2, 0, 0, 6, 384, NULL, 'Rodiklis Nr.18 per mėnesį', NULL, 4, NULL, NULL),
	(11045, 373, 0, 6, 2, 0, 0, 6, 385, NULL, 'Rodiklis Nr.19 per mėnesį', NULL, 4, NULL, NULL),
	(11046, 374, 0, 6, 2, 0, 0, 6, 386, NULL, 'Rodiklis Nr.20 per mėnesį', NULL, 4, NULL, NULL),
	(11047, 187, 0, 8, 2, 0, 0, 3, 200, NULL, 'Suminis rodiklis Nr.1, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11048, 187, 0, 8, 2, 0, 0, 4, 200, NULL, 'Suminis rodiklis Nr.1, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11049, 187, 0, 8, 2, 0, 0, 5, 200, NULL, 'Suminis rodiklis Nr.1, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11050, 187, 0, 8, 2, 0, 0, 6, 200, NULL, 'Suminis rodiklis Nr.1, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11051, 187, 0, 8, 2, 0, 0, 7, 200, NULL, 'Suminis rodiklis Nr.1', NULL, 5, NULL, NULL),
	(11052, 187, 0, 8, 2, 0, 0, 10, 200, NULL, 'Suminis rodiklis Nr.1, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11053, 187, 0, 8, 2, 0, 0, 12, 200, NULL, 'Suminis rodiklis Nr.1, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11054, 187, 0, 8, 2, 0, 0, 13, 200, NULL, 'Suminis rodiklis Nr.1, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11055, 344, 0, 8, 2, 0, 0, 3, 356, NULL, 'Suminis rodiklis Nr.2, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11056, 344, 0, 8, 2, 0, 0, 4, 356, NULL, 'Suminis rodiklis Nr.2, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11057, 344, 0, 8, 2, 0, 0, 5, 356, NULL, 'Suminis rodiklis Nr.2, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11058, 344, 0, 8, 2, 0, 0, 6, 356, NULL, 'Suminis rodiklis Nr.2, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11059, 344, 0, 8, 2, 0, 0, 7, 356, NULL, 'Suminis rodiklis Nr.2', NULL, 5, NULL, NULL),
	(11060, 344, 0, 8, 2, 0, 0, 10, 356, NULL, 'Suminis rodiklis Nr.2, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11061, 344, 0, 8, 2, 0, 0, 12, 356, NULL, 'Suminis rodiklis Nr.2, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11062, 344, 0, 8, 2, 0, 0, 13, 356, NULL, 'Suminis rodiklis Nr.2, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11063, 345, 0, 8, 2, 0, 0, 3, 357, NULL, 'Suminis rodiklis Nr.3, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11064, 345, 0, 8, 2, 0, 0, 4, 357, NULL, 'Suminis rodiklis Nr.3, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11065, 345, 0, 8, 2, 0, 0, 5, 357, NULL, 'Suminis rodiklis Nr.3, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11066, 345, 0, 8, 2, 0, 0, 6, 357, NULL, 'Suminis rodiklis Nr.3, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11067, 345, 0, 8, 2, 0, 0, 7, 357, NULL, 'Suminis rodiklis Nr.3', NULL, 5, NULL, NULL),
	(11068, 345, 0, 8, 2, 0, 0, 10, 357, NULL, 'Suminis rodiklis Nr.3, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11069, 345, 0, 8, 2, 0, 0, 12, 357, NULL, 'Suminis rodiklis Nr.3, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11070, 345, 0, 8, 2, 0, 0, 13, 357, NULL, 'Suminis rodiklis Nr.3, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11071, 346, 0, 8, 2, 0, 0, 3, 358, NULL, 'Suminis rodiklis Nr.4, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11072, 346, 0, 8, 2, 0, 0, 4, 358, NULL, 'Suminis rodiklis Nr.4, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11073, 346, 0, 8, 2, 0, 0, 5, 358, NULL, 'Suminis rodiklis Nr.4, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11074, 346, 0, 8, 2, 0, 0, 6, 358, NULL, 'Suminis rodiklis Nr.4, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11075, 346, 0, 8, 2, 0, 0, 7, 358, NULL, 'Suminis rodiklis Nr.4', NULL, 5, NULL, NULL),
	(11076, 346, 0, 8, 2, 0, 0, 10, 358, NULL, 'Suminis rodiklis Nr.4, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11077, 346, 0, 8, 2, 0, 0, 12, 358, NULL, 'Suminis rodiklis Nr.4, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11078, 346, 0, 8, 2, 0, 0, 13, 358, NULL, 'Suminis rodiklis Nr.4, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11079, 347, 0, 8, 2, 0, 0, 3, 359, NULL, 'Suminis rodiklis Nr.5, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11080, 347, 0, 8, 2, 0, 0, 4, 359, NULL, 'Suminis rodiklis Nr.5, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11081, 347, 0, 8, 2, 0, 0, 5, 359, NULL, 'Suminis rodiklis Nr.5, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11082, 347, 0, 8, 2, 0, 0, 6, 359, NULL, 'Suminis rodiklis Nr.5, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11083, 347, 0, 8, 2, 0, 0, 7, 359, NULL, 'Suminis rodiklis Nr.5', NULL, 5, NULL, NULL),
	(11084, 347, 0, 8, 2, 0, 0, 10, 359, NULL, 'Suminis rodiklis Nr.5, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11085, 347, 0, 8, 2, 0, 0, 12, 359, NULL, 'Suminis rodiklis Nr.5, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11086, 347, 0, 8, 2, 0, 0, 13, 359, NULL, 'Suminis rodiklis Nr.5, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11087, 365, 0, 8, 2, 0, 0, 3, 377, NULL, 'Suminis rodiklis Nr.11, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11088, 365, 0, 8, 2, 0, 0, 4, 377, NULL, 'Suminis rodiklis Nr.11, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11089, 365, 0, 8, 2, 0, 0, 5, 377, NULL, 'Suminis rodiklis Nr.11, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11090, 365, 0, 8, 2, 0, 0, 6, 377, NULL, 'Suminis rodiklis Nr.11, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11091, 365, 0, 8, 2, 0, 0, 7, 377, NULL, 'Suminis rodiklis Nr.11', NULL, 5, NULL, NULL),
	(11092, 365, 0, 8, 2, 0, 0, 10, 377, NULL, 'Suminis rodiklis Nr.11, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11093, 365, 0, 8, 2, 0, 0, 12, 377, NULL, 'Suminis rodiklis Nr.11, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11094, 365, 0, 8, 2, 0, 0, 13, 377, NULL, 'Suminis rodiklis Nr.11, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11095, 366, 0, 8, 2, 0, 0, 3, 378, NULL, 'Suminis rodiklis Nr.12, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11096, 366, 0, 8, 2, 0, 0, 4, 378, NULL, 'Suminis rodiklis Nr.12, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11097, 366, 0, 8, 2, 0, 0, 5, 378, NULL, 'Suminis rodiklis Nr.12, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11098, 366, 0, 8, 2, 0, 0, 6, 378, NULL, 'Suminis rodiklis Nr.12, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11099, 366, 0, 8, 2, 0, 0, 7, 378, NULL, 'Suminis rodiklis Nr.12', NULL, 5, NULL, NULL),
	(11100, 366, 0, 8, 2, 0, 0, 10, 378, NULL, 'Suminis rodiklis Nr.12, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11101, 366, 0, 8, 2, 0, 0, 12, 378, NULL, 'Suminis rodiklis Nr.12, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11102, 366, 0, 8, 2, 0, 0, 13, 378, NULL, 'Suminis rodiklis Nr.12, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11103, 367, 0, 8, 2, 0, 0, 3, 379, NULL, 'Suminis rodiklis Nr.13, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11104, 367, 0, 8, 2, 0, 0, 4, 379, NULL, 'Suminis rodiklis Nr.13, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11105, 367, 0, 8, 2, 0, 0, 5, 379, NULL, 'Suminis rodiklis Nr.13, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11106, 367, 0, 8, 2, 0, 0, 6, 379, NULL, 'Suminis rodiklis Nr.13, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11107, 367, 0, 8, 2, 0, 0, 7, 379, NULL, 'Suminis rodiklis Nr.13', NULL, 5, NULL, NULL),
	(11108, 367, 0, 8, 2, 0, 0, 10, 379, NULL, 'Suminis rodiklis Nr.13, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11109, 367, 0, 8, 2, 0, 0, 12, 379, NULL, 'Suminis rodiklis Nr.13, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11110, 367, 0, 8, 2, 0, 0, 13, 379, NULL, 'Suminis rodiklis Nr.13, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11111, 368, 0, 8, 2, 0, 0, 3, 380, NULL, 'Suminis rodiklis Nr.14, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11112, 368, 0, 8, 2, 0, 0, 4, 380, NULL, 'Suminis rodiklis Nr.14, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11113, 368, 0, 8, 2, 0, 0, 5, 380, NULL, 'Suminis rodiklis Nr.14, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11114, 368, 0, 8, 2, 0, 0, 6, 380, NULL, 'Suminis rodiklis Nr.14, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11115, 368, 0, 8, 2, 0, 0, 7, 380, NULL, 'Suminis rodiklis Nr.14', NULL, 5, NULL, NULL),
	(11116, 368, 0, 8, 2, 0, 0, 10, 380, NULL, 'Suminis rodiklis Nr.14, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11117, 368, 0, 8, 2, 0, 0, 12, 380, NULL, 'Suminis rodiklis Nr.14, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11118, 368, 0, 8, 2, 0, 0, 13, 380, NULL, 'Suminis rodiklis Nr.14, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11119, 369, 0, 8, 2, 0, 0, 3, 381, NULL, 'Suminis rodiklis Nr.15, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11120, 369, 0, 8, 2, 0, 0, 4, 381, NULL, 'Suminis rodiklis Nr.15, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11121, 369, 0, 8, 2, 0, 0, 5, 381, NULL, 'Suminis rodiklis Nr.15, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11122, 369, 0, 8, 2, 0, 0, 6, 381, NULL, 'Suminis rodiklis Nr.15, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11123, 369, 0, 8, 2, 0, 0, 7, 381, NULL, 'Suminis rodiklis Nr.15', NULL, 5, NULL, NULL),
	(11124, 369, 0, 8, 2, 0, 0, 10, 381, NULL, 'Suminis rodiklis Nr.15, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11125, 369, 0, 8, 2, 0, 0, 12, 381, NULL, 'Suminis rodiklis Nr.15, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11126, 369, 0, 8, 2, 0, 0, 13, 381, NULL, 'Suminis rodiklis Nr.15, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11127, 370, 0, 8, 2, 0, 0, 3, 382, NULL, 'Suminis rodiklis Nr.16, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11128, 370, 0, 8, 2, 0, 0, 4, 382, NULL, 'Suminis rodiklis Nr.16, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11129, 370, 0, 8, 2, 0, 0, 5, 382, NULL, 'Suminis rodiklis Nr.16, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11130, 370, 0, 8, 2, 0, 0, 6, 382, NULL, 'Suminis rodiklis Nr.16, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11131, 370, 0, 8, 2, 0, 0, 7, 382, NULL, 'Suminis rodiklis Nr.16', NULL, 5, NULL, NULL),
	(11132, 370, 0, 8, 2, 0, 0, 10, 382, NULL, 'Suminis rodiklis Nr.16, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11133, 370, 0, 8, 2, 0, 0, 12, 382, NULL, 'Suminis rodiklis Nr.16, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11134, 370, 0, 8, 2, 0, 0, 13, 382, NULL, 'Suminis rodiklis Nr.16, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11135, 371, 0, 8, 2, 0, 0, 3, 383, NULL, 'Suminis rodiklis Nr.17, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11136, 371, 0, 8, 2, 0, 0, 4, 383, NULL, 'Suminis rodiklis Nr.17, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11137, 371, 0, 8, 2, 0, 0, 5, 383, NULL, 'Suminis rodiklis Nr.17, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11138, 371, 0, 8, 2, 0, 0, 6, 383, NULL, 'Suminis rodiklis Nr.17, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11139, 371, 0, 8, 2, 0, 0, 7, 383, NULL, 'Suminis rodiklis Nr.17', NULL, 5, NULL, NULL),
	(11140, 371, 0, 8, 2, 0, 0, 10, 383, NULL, 'Suminis rodiklis Nr.17, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11141, 371, 0, 8, 2, 0, 0, 12, 383, NULL, 'Suminis rodiklis Nr.17, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11142, 371, 0, 8, 2, 0, 0, 13, 383, NULL, 'Suminis rodiklis Nr.17, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11143, 372, 0, 8, 2, 0, 0, 3, 384, NULL, 'Suminis rodiklis Nr.18, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11144, 372, 0, 8, 2, 0, 0, 4, 384, NULL, 'Suminis rodiklis Nr.18, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11145, 372, 0, 8, 2, 0, 0, 5, 384, NULL, 'Suminis rodiklis Nr.18, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11146, 372, 0, 8, 2, 0, 0, 6, 384, NULL, 'Suminis rodiklis Nr.18, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11147, 372, 0, 8, 2, 0, 0, 7, 384, NULL, 'Suminis rodiklis Nr.18', NULL, 5, NULL, NULL),
	(11148, 372, 0, 8, 2, 0, 0, 10, 384, NULL, 'Suminis rodiklis Nr.18, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11149, 372, 0, 8, 2, 0, 0, 12, 384, NULL, 'Suminis rodiklis Nr.18, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11150, 372, 0, 8, 2, 0, 0, 13, 384, NULL, 'Suminis rodiklis Nr.18, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11151, 373, 0, 8, 2, 0, 0, 3, 385, NULL, 'Suminis rodiklis Nr.19, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11152, 373, 0, 8, 2, 0, 0, 4, 385, NULL, 'Suminis rodiklis Nr.19, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11153, 373, 0, 8, 2, 0, 0, 5, 385, NULL, 'Suminis rodiklis Nr.19, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11154, 373, 0, 8, 2, 0, 0, 6, 385, NULL, 'Suminis rodiklis Nr.19, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11155, 373, 0, 8, 2, 0, 0, 7, 385, NULL, 'Suminis rodiklis Nr.19', NULL, 5, NULL, NULL),
	(11156, 373, 0, 8, 2, 0, 0, 10, 385, NULL, 'Suminis rodiklis Nr.19, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11157, 373, 0, 8, 2, 0, 0, 12, 385, NULL, 'Suminis rodiklis Nr.19, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11158, 373, 0, 8, 2, 0, 0, 13, 385, NULL, 'Suminis rodiklis Nr.19, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11159, 374, 0, 8, 2, 0, 0, 3, 386, NULL, 'Suminis rodiklis Nr.20, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11160, 374, 0, 8, 2, 0, 0, 4, 386, NULL, 'Suminis rodiklis Nr.20, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11161, 374, 0, 8, 2, 0, 0, 5, 386, NULL, 'Suminis rodiklis Nr.20, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11162, 374, 0, 8, 2, 0, 0, 6, 386, NULL, 'Suminis rodiklis Nr.20, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11163, 374, 0, 8, 2, 0, 0, 7, 386, NULL, 'Suminis rodiklis Nr.20', NULL, 5, NULL, NULL),
	(11164, 374, 0, 8, 2, 0, 0, 10, 386, NULL, 'Suminis rodiklis Nr.20, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11165, 374, 0, 8, 2, 0, 0, 12, 386, NULL, 'Suminis rodiklis Nr.20, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11166, 374, 0, 8, 2, 0, 0, 13, 386, NULL, 'Suminis rodiklis Nr.20, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11167, 375, 0, 8, 2, 0, 0, 3, 387, NULL, 'Suminis rodiklis Nr.21, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11168, 375, 0, 8, 2, 0, 0, 4, 387, NULL, 'Suminis rodiklis Nr.21, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11169, 375, 0, 8, 2, 0, 0, 5, 387, NULL, 'Suminis rodiklis Nr.21, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11170, 375, 0, 8, 2, 0, 0, 6, 387, NULL, 'Suminis rodiklis Nr.21, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11171, 375, 0, 8, 2, 0, 0, 7, 387, NULL, 'Suminis rodiklis Nr.21', NULL, 5, NULL, NULL),
	(11172, 375, 0, 8, 2, 0, 0, 10, 387, NULL, 'Suminis rodiklis Nr.21, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11173, 375, 0, 8, 2, 0, 0, 12, 387, NULL, 'Suminis rodiklis Nr.21, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11174, 375, 0, 8, 2, 0, 0, 13, 387, NULL, 'Suminis rodiklis Nr.21, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11175, 376, 0, 8, 2, 0, 0, 3, 388, NULL, 'Suminis rodiklis Nr.22, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11176, 376, 0, 8, 2, 0, 0, 4, 388, NULL, 'Suminis rodiklis Nr.22, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11177, 376, 0, 8, 2, 0, 0, 5, 388, NULL, 'Suminis rodiklis Nr.22, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11178, 376, 0, 8, 2, 0, 0, 6, 388, NULL, 'Suminis rodiklis Nr.22, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11179, 376, 0, 8, 2, 0, 0, 7, 388, NULL, 'Suminis rodiklis Nr.22', NULL, 5, NULL, NULL),
	(11180, 376, 0, 8, 2, 0, 0, 10, 388, NULL, 'Suminis rodiklis Nr.22, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11181, 376, 0, 8, 2, 0, 0, 12, 388, NULL, 'Suminis rodiklis Nr.22, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11182, 376, 0, 8, 2, 0, 0, 13, 388, NULL, 'Suminis rodiklis Nr.22, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11183, 377, 0, 8, 2, 0, 0, 3, 389, NULL, 'Suminis rodiklis Nr.23, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11184, 377, 0, 8, 2, 0, 0, 4, 389, NULL, 'Suminis rodiklis Nr.23, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11185, 377, 0, 8, 2, 0, 0, 5, 389, NULL, 'Suminis rodiklis Nr.23, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11186, 377, 0, 8, 2, 0, 0, 6, 389, NULL, 'Suminis rodiklis Nr.23, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11187, 377, 0, 8, 2, 0, 0, 7, 389, NULL, 'Suminis rodiklis Nr.23', NULL, 5, NULL, NULL),
	(11188, 377, 0, 8, 2, 0, 0, 10, 389, NULL, 'Suminis rodiklis Nr.23, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11189, 377, 0, 8, 2, 0, 0, 12, 389, NULL, 'Suminis rodiklis Nr.23, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11190, 377, 0, 8, 2, 0, 0, 13, 389, NULL, 'Suminis rodiklis Nr.23, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11191, 378, 0, 8, 2, 0, 0, 3, 390, NULL, 'Suminis rodiklis Nr.24, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11192, 378, 0, 8, 2, 0, 0, 4, 390, NULL, 'Suminis rodiklis Nr.24, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11193, 378, 0, 8, 2, 0, 0, 5, 390, NULL, 'Suminis rodiklis Nr.24, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11194, 378, 0, 8, 2, 0, 0, 6, 390, NULL, 'Suminis rodiklis Nr.24, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11195, 378, 0, 8, 2, 0, 0, 7, 390, NULL, 'Suminis rodiklis Nr.24', NULL, 5, NULL, NULL),
	(11196, 378, 0, 8, 2, 0, 0, 10, 390, NULL, 'Suminis rodiklis Nr.24, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11197, 378, 0, 8, 2, 0, 0, 12, 390, NULL, 'Suminis rodiklis Nr.24, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11198, 378, 0, 8, 2, 0, 0, 13, 390, NULL, 'Suminis rodiklis Nr.24, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11199, 379, 0, 8, 2, 0, 0, 3, 391, NULL, 'Suminis rodiklis Nr.25, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11200, 379, 0, 8, 2, 0, 0, 4, 391, NULL, 'Suminis rodiklis Nr.25, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11201, 379, 0, 8, 2, 0, 0, 5, 391, NULL, 'Suminis rodiklis Nr.25, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11202, 379, 0, 8, 2, 0, 0, 6, 391, NULL, 'Suminis rodiklis Nr.25, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11203, 379, 0, 8, 2, 0, 0, 7, 391, NULL, 'Suminis rodiklis Nr.25', NULL, 5, NULL, NULL),
	(11204, 379, 0, 8, 2, 0, 0, 10, 391, NULL, 'Suminis rodiklis Nr.25, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11205, 379, 0, 8, 2, 0, 0, 12, 391, NULL, 'Suminis rodiklis Nr.25, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11206, 379, 0, 8, 2, 0, 0, 13, 391, NULL, 'Suminis rodiklis Nr.25, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11207, 380, 0, 8, 2, 0, 0, 3, 392, NULL, 'Suminis rodiklis Nr.26, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11208, 380, 0, 8, 2, 0, 0, 4, 392, NULL, 'Suminis rodiklis Nr.26, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11209, 380, 0, 8, 2, 0, 0, 5, 392, NULL, 'Suminis rodiklis Nr.26, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11210, 380, 0, 8, 2, 0, 0, 6, 392, NULL, 'Suminis rodiklis Nr.26, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11211, 380, 0, 8, 2, 0, 0, 7, 392, NULL, 'Suminis rodiklis Nr.26', NULL, 5, NULL, NULL),
	(11212, 380, 0, 8, 2, 0, 0, 10, 392, NULL, 'Suminis rodiklis Nr.26, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11213, 380, 0, 8, 2, 0, 0, 12, 392, NULL, 'Suminis rodiklis Nr.26, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11214, 380, 0, 8, 2, 0, 0, 13, 392, NULL, 'Suminis rodiklis Nr.26, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11215, 381, 0, 8, 2, 0, 0, 3, 393, NULL, 'Suminis rodiklis Nr.27, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11216, 381, 0, 8, 2, 0, 0, 4, 393, NULL, 'Suminis rodiklis Nr.27, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11217, 381, 0, 8, 2, 0, 0, 5, 393, NULL, 'Suminis rodiklis Nr.27, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11218, 381, 0, 8, 2, 0, 0, 6, 393, NULL, 'Suminis rodiklis Nr.27, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11219, 381, 0, 8, 2, 0, 0, 7, 393, NULL, 'Suminis rodiklis Nr.27', NULL, 5, NULL, NULL),
	(11220, 381, 0, 8, 2, 0, 0, 10, 393, NULL, 'Suminis rodiklis Nr.27, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11221, 381, 0, 8, 2, 0, 0, 12, 393, NULL, 'Suminis rodiklis Nr.27, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11222, 381, 0, 8, 2, 0, 0, 13, 393, NULL, 'Suminis rodiklis Nr.27, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11223, 382, 0, 8, 2, 0, 0, 3, 394, NULL, 'Suminis rodiklis Nr.28, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11224, 382, 0, 8, 2, 0, 0, 4, 394, NULL, 'Suminis rodiklis Nr.28, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11225, 382, 0, 8, 2, 0, 0, 5, 394, NULL, 'Suminis rodiklis Nr.28, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11226, 382, 0, 8, 2, 0, 0, 6, 394, NULL, 'Suminis rodiklis Nr.28, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11227, 382, 0, 8, 2, 0, 0, 7, 394, NULL, 'Suminis rodiklis Nr.28', NULL, 5, NULL, NULL),
	(11228, 382, 0, 8, 2, 0, 0, 10, 394, NULL, 'Suminis rodiklis Nr.28, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11229, 382, 0, 8, 2, 0, 0, 12, 394, NULL, 'Suminis rodiklis Nr.28, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11230, 382, 0, 8, 2, 0, 0, 13, 394, NULL, 'Suminis rodiklis Nr.28, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11231, 383, 0, 8, 2, 0, 0, 3, 395, NULL, 'Suminis rodiklis Nr.29, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11232, 383, 0, 8, 2, 0, 0, 4, 395, NULL, 'Suminis rodiklis Nr.29, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11233, 383, 0, 8, 2, 0, 0, 5, 395, NULL, 'Suminis rodiklis Nr.29, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11234, 383, 0, 8, 2, 0, 0, 6, 395, NULL, 'Suminis rodiklis Nr.29, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11235, 383, 0, 8, 2, 0, 0, 7, 395, NULL, 'Suminis rodiklis Nr.29', NULL, 5, NULL, NULL),
	(11236, 383, 0, 8, 2, 0, 0, 10, 395, NULL, 'Suminis rodiklis Nr.29, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11237, 383, 0, 8, 2, 0, 0, 12, 395, NULL, 'Suminis rodiklis Nr.29, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11238, 383, 0, 8, 2, 0, 0, 13, 395, NULL, 'Suminis rodiklis Nr.29, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11239, 384, 0, 8, 2, 0, 0, 3, 455, NULL, 'Suminis rodiklis Nr.30, fiksuojamas kas 30 minučių', NULL, 5, NULL, NULL),
	(11240, 384, 0, 8, 2, 0, 0, 4, 455, NULL, 'Suminis rodiklis Nr.30, fiksuojamas kas valandą', NULL, 5, NULL, NULL),
	(11241, 384, 0, 8, 2, 0, 0, 5, 455, NULL, 'Suminis rodiklis Nr.30, fiksuojamas kas parą', NULL, 5, NULL, NULL),
	(11242, 384, 0, 8, 2, 0, 0, 6, 455, NULL, 'Suminis rodiklis Nr.30, fiksuojamas kas mėnesį', NULL, 5, NULL, NULL),
	(11243, 384, 0, 8, 2, 0, 0, 7, 455, NULL, 'Suminis rodiklis Nr.30', NULL, 5, NULL, NULL),
	(11244, 384, 0, 8, 2, 0, 0, 10, 455, NULL, 'Suminis rodiklis Nr.30, fiksuojamas kas 5 minutes', NULL, 5, NULL, NULL),
	(11245, 384, 0, 8, 2, 0, 0, 12, 455, NULL, 'Suminis rodiklis Nr.30, fiksuojamas kas 15 minučių', NULL, 5, NULL, NULL),
	(11246, 384, 0, 8, 2, 0, 0, 13, 455, NULL, 'Suminis rodiklis Nr.30, fiksuojamas kas 20 minučių', NULL, 5, NULL, NULL),
	(11247, 370, 0, 5, 2, 0, 0, 5, 382, NULL, 'Rodiklis Nr.16 per parą', NULL, 3, NULL, NULL),
	(11248, 370, 0, 4, 2, 0, 0, 4, 382, NULL, 'Rodiklis Nr.16 per valandą', NULL, 2, NULL, NULL),
	(11249, 370, 0, 13, 2, 0, 0, 12, 382, NULL, 'Rodiklis Nr.16 per 15 minučių', NULL, 2, NULL, NULL),
	(11250, 370, 0, 3, 2, 0, 0, 3, 382, NULL, 'Rodiklis Nr.16 per 30 minučių', NULL, 2, NULL, NULL),
	(11251, 371, 0, 5, 2, 0, 0, 5, 383, NULL, 'Rodiklis Nr.17 per parą', NULL, 3, NULL, NULL),
	(11252, 371, 0, 4, 2, 0, 0, 4, 383, NULL, 'Rodiklis Nr.17 per valandą', NULL, 2, NULL, NULL),
	(11253, 371, 0, 13, 2, 0, 0, 12, 383, NULL, 'Rodiklis Nr.17 per 15 minučių', NULL, 2, NULL, NULL),
	(11254, 371, 0, 3, 2, 0, 0, 3, 383, NULL, 'Rodiklis Nr.17 per 30 minučių', NULL, 2, NULL, NULL),
	(11255, 372, 0, 5, 2, 0, 0, 5, 384, NULL, 'Rodiklis Nr.18 per parą', NULL, 3, NULL, NULL),
	(11256, 372, 0, 4, 2, 0, 0, 4, 384, NULL, 'Rodiklis Nr.18 per valandą', NULL, 2, NULL, NULL),
	(11257, 372, 0, 13, 2, 0, 0, 12, 384, NULL, 'Rodiklis Nr.18 per 15 minučių', NULL, 2, NULL, NULL),
	(11258, 372, 0, 3, 2, 0, 0, 3, 384, NULL, 'Rodiklis Nr.18 per 30 minučių', NULL, 2, NULL, NULL),
	(11259, 373, 0, 5, 2, 0, 0, 5, 385, NULL, 'Rodiklis Nr.19 per parą', NULL, 3, NULL, NULL),
	(11260, 373, 0, 4, 2, 0, 0, 4, 385, NULL, 'Rodiklis Nr.19 per valandą', NULL, 2, NULL, NULL),
	(11261, 373, 0, 13, 2, 0, 0, 12, 385, NULL, 'Rodiklis Nr.19 per 15 minučių', NULL, 2, NULL, NULL),
	(11262, 373, 0, 3, 2, 0, 0, 3, 385, NULL, 'Rodiklis Nr.19 per 30 minučių', NULL, 2, NULL, NULL),
	(11263, 374, 0, 5, 2, 0, 0, 5, 386, NULL, 'Rodiklis Nr.20 per parą', NULL, 3, NULL, NULL),
	(11264, 374, 0, 4, 2, 0, 0, 4, 386, NULL, 'Rodiklis Nr.20 per valandą', NULL, 2, NULL, NULL),
	(11265, 374, 0, 13, 2, 0, 0, 12, 386, NULL, 'Rodiklis Nr.20 per 15 minučių', NULL, 2, NULL, NULL),
	(11266, 374, 0, 3, 2, 0, 0, 3, 386, NULL, 'Rodiklis Nr.20 per 30 minučių', NULL, 2, NULL, NULL),
	(11267, 457, 0, 7, 1, 0, 28, 7, 473, NULL, 'Momentinis dujų slėgių skirtumas', 1139, 6, NULL, NULL),
	(11268, 457, 0, 6, 3, 0, 28, 6, 473, NULL, 'Vidutinis dujų slėgių skirtumas per mėnesį', 1140, 4, NULL, NULL),
	(11269, 457, 0, 1, 3, 0, 28, 1, 473, NULL, 'Vidutinis dujų slėgių skirtumas per minutę', 1140, 1, NULL, NULL),
	(11270, 457, 0, 5, 3, 0, 28, 5, 473, NULL, 'Vidutinis dujų slėgių skirtumas per parą', 1140, 3, NULL, NULL),
	(11271, 457, 0, 4, 3, 0, 28, 4, 473, NULL, 'Vidutinis dujų slėgių skirtumas per valandą', 1140, 2, NULL, NULL),
	(11272, 457, 0, 12, 3, 0, 28, 11, 473, NULL, 'Vidutinis dujų slėgių skirtumas per 10 minučių', 1140, 1, NULL, NULL),
	(11273, 457, 0, 13, 3, 0, 28, 12, 473, NULL, 'Vidutinis dujų slėgių skirtumas per 15 minučių', 1140, 2, NULL, NULL),
	(11274, 457, 0, 2, 3, 0, 28, 2, 473, NULL, 'Vidutinis dujų slėgių skirtumas per 2 minutes', 1140, 1, NULL, NULL),
	(11275, 457, 0, 14, 3, 0, 28, 13, 473, NULL, 'Vidutinis dujų slėgių skirtumas per 20 minučių', 1140, 2, NULL, NULL),
	(11276, 457, 0, 9, 3, 0, 28, 8, 473, NULL, 'Vidutinis dujų slėgių skirtumas per 3 minutes', 1140, 1, NULL, NULL),
	(11277, 457, 0, 3, 3, 0, 28, 3, 473, NULL, 'Vidutinis dujų slėgių skirtumas per 30 minučių', 1140, 2, NULL, NULL),
	(11278, 457, 0, 10, 3, 0, 28, 9, 473, NULL, 'Vidutinis dujų slėgių skirtumas per 4 minutes', 1140, 1, NULL, NULL),
	(11279, 457, 0, 11, 3, 0, 28, 10, 473, NULL, 'Vidutinis dujų slėgių skirtumas per 5 minutes', 1140, 1, NULL, NULL),
	(11280, 458, -4, 8, 2, 0, 31, 7, 474, NULL, 'Suminis avarinio pamaitinimo vandens tūrio kiekis', 1774, 5, NULL, NULL),
	(11281, 458, -4, 8, 2, 0, 31, 6, 474, NULL, 'Suminis avarinio pamaitinimo vandens tūrio kiekis, fiksuojamas kas mėnesį', 1774, 5, NULL, NULL),
	(11282, 458, -4, 8, 2, 0, 31, 5, 474, NULL, 'Suminis avarinio pamaitinimo vandens tūrio kiekis, fiksuojamas kas parą', 1774, 5, NULL, NULL),
	(11283, 458, -4, 8, 2, 0, 31, 4, 474, NULL, 'Suminis avarinio pamaitinimo vandens tūrio kiekis, fiksuojamas kas valandą', 1774, 5, NULL, NULL),
	(11284, 458, -4, 8, 2, 0, 31, 3, 474, NULL, 'Suminis avarinio pamaitinimo vandens tūrio kiekis, fiksuojamas kas 30 minučių', 1774, 5, NULL, NULL),
	(11285, 458, -4, 8, 2, 0, 31, 13, 474, NULL, 'Suminis avarinio pamaitinimo vandens tūrio kiekis, fiksuojamas kas 20 minučių', 1774, 5, NULL, NULL),
	(11286, 458, -4, 8, 2, 0, 31, 12, 474, NULL, 'Suminis avarinio pamaitinimo vandens tūrio kiekis, fiksuojamas kas 15 minučių', 1774, 5, NULL, NULL),
	(11287, 458, -4, 8, 2, 0, 31, 10, 474, NULL, 'Suminis avarinio pamaitinimo vandens tūrio kiekis, fiksuojamas kas 5 minutes', 1774, 5, NULL, NULL),
	(11288, 458, -4, 11, 2, 0, 31, 10, 474, NULL, 'Avarinio pamaitinimo vandens tūrio kiekis per 5 minutes', 1784, 1, NULL, NULL),
	(11289, 458, -4, 12, 2, 0, 31, 11, 474, NULL, 'Avarinio pamaitinimo vandens tūrio kiekis per 10 minučių', 1784, 1, NULL, NULL),
	(11290, 458, -4, 13, 2, 0, 31, 12, 474, NULL, 'Avarinio pamaitinimo vandens tūrio kiekis per 15 minučių', 1784, 2, NULL, NULL),
	(11291, 458, -4, 10, 2, 0, 31, 9, 474, NULL, 'Avarinio pamaitinimo vandens tūrio kiekis per 4 minutes', 1784, 1, NULL, NULL),
	(11292, 458, -4, 9, 2, 0, 31, 8, 474, NULL, 'Avarinio pamaitinimo vandens tūrio kiekis per 3 minutes', 1784, 1, NULL, NULL),
	(11293, 458, -4, 6, 2, 0, 31, 6, 474, NULL, 'Avarinio pamaitinimo vandens tūrio kiekis per mėnesį', 1784, 4, NULL, NULL),
	(11294, 458, -4, 5, 2, 0, 31, 5, 474, NULL, 'Avarinio pamaitinimo vandens tūrio kiekis per parą', 1784, 3, NULL, NULL),
	(11295, 458, -4, 4, 2, 0, 31, 4, 474, NULL, 'Avarinio pamaitinimo vandens tūrio kiekis per valandą', 1784, 2, NULL, NULL),
	(11296, 458, -4, 3, 2, 0, 31, 3, 474, NULL, 'Avarinio pamaitinimo vandens tūrio kiekis per 30 minučių', 1784, 2, NULL, NULL),
	(11297, 458, -4, 14, 2, 0, 31, 13, 474, NULL, 'Avarinio pamaitinimo vandens tūrio kiekis per 20 minučių', 1784, 2, NULL, NULL),
	(11298, 458, -4, 1, 2, 0, 31, 1, 474, NULL, 'Avarinio pamaitinimo vandens tūrio kiekis per minutę', 1784, 1, NULL, NULL),
	(11299, 458, -4, 2, 2, 0, 31, 2, 474, NULL, 'Avarinio pamaitinimo vandens tūrio kiekis per 2 minutes', 1784, 1, NULL, NULL),
	(11300, 458, -4, 14, 3, 0, 32, 13, 475, NULL, 'Vidutinis avarinio pamaitinimo vandens tūrio debitas per 20 minučių', 1785, 2, NULL, NULL),
	(11301, 458, -4, 13, 3, 0, 32, 12, 475, NULL, 'Vidutinis avarinio pamaitinimo vandens tūrio debitas per 15 minučių', 1785, 2, NULL, NULL),
	(11302, 458, -4, 12, 3, 0, 32, 11, 475, NULL, 'Vidutinis avarinio pamaitinimo vandens tūrio debitas per 10 minučių', 1785, 1, NULL, NULL),
	(11303, 458, -4, 11, 3, 0, 32, 10, 475, NULL, 'Vidutinis avarinio pamaitinimo vandens tūrio debitas per 5 minutes', 1785, 1, NULL, NULL),
	(11304, 458, -4, 10, 3, 0, 32, 9, 475, NULL, 'Vidutinis avarinio pamaitinimo vandens tūrio debitas per 4 minutes', 1785, 1, NULL, NULL),
	(11305, 458, -4, 9, 3, 0, 32, 8, 475, NULL, 'Vidutinis avarinio pamaitinimo vandens tūrio debitas per 3 minutes', 1785, 1, NULL, NULL),
	(11306, 458, -4, 6, 3, 0, 32, 6, 475, NULL, 'Vidutinis avarinio pamaitinimo vandens tūrio debitas per mėnesį', 1785, 4, NULL, NULL),
	(11307, 458, -4, 5, 3, 0, 32, 5, 475, NULL, 'Vidutinis avarinio pamaitinimo vandens tūrio debitas per parą', 1785, 3, NULL, NULL),
	(11308, 458, -4, 4, 3, 0, 32, 4, 475, NULL, 'Vidutinis avarinio pamaitinimo vandens tūrio debitas per valandą', 1785, 2, NULL, NULL),
	(11309, 458, -4, 3, 3, 0, 32, 3, 475, NULL, 'Vidutinis avarinio pamaitinimo vandens tūrio debitas per 30 minučių', 1785, 2, NULL, NULL),
	(11310, 458, -4, 2, 3, 0, 32, 2, 475, NULL, 'Vidutinis avarinio pamaitinimo vandens tūrio debitas per 2 minutes', 1785, 1, NULL, NULL),
	(11311, 458, -4, 1, 3, 0, 32, 1, 475, NULL, 'Vidutinis avarinio pamaitinimo vandens tūrio debitas per minutę', 1785, 1, NULL, NULL),
	(11312, 458, -4, 7, 1, 0, 32, 7, 475, NULL, 'Momentinis avarinio pamaitinimo vandens tūrio debitas', 1775, 6, NULL, NULL),
	(11313, 459, -4, 6, 2, 0, 35, 6, 476, NULL, 'Avarinio pamaitinimo vandens masės kiekis per mėnesį', 1786, 4, NULL, NULL),
	(11314, 459, -4, 1, 2, 0, 35, 1, 476, NULL, 'Avarinio pamaitinimo vandens masės kiekis per minutę', 1786, 1, NULL, NULL),
	(11315, 459, -4, 5, 2, 0, 35, 5, 476, NULL, 'Avarinio pamaitinimo vandens masės kiekis per parą', 1786, 3, NULL, NULL),
	(11316, 459, -4, 4, 2, 0, 35, 4, 476, NULL, 'Avarinio pamaitinimo vandens masės kiekis per valandą', 1786, 2, NULL, NULL),
	(11317, 459, -4, 12, 2, 0, 35, 11, 476, NULL, 'Avarinio pamaitinimo vandens masės kiekis per 10 minučių', 1786, 1, NULL, NULL),
	(11318, 459, -4, 13, 2, 0, 35, 12, 476, NULL, 'Avarinio pamaitinimo vandens masės kiekis per 15 minučių', 1786, 2, NULL, NULL),
	(11319, 459, -4, 2, 2, 0, 35, 2, 476, NULL, 'Avarinio pamaitinimo vandens masės kiekis per 2 minutes', 1786, 1, NULL, NULL),
	(11320, 459, -4, 14, 2, 0, 35, 13, 476, NULL, 'Avarinio pamaitinimo vandens masės kiekis per 20 minučių', 1786, 2, NULL, NULL),
	(11321, 459, -4, 9, 2, 0, 35, 8, 476, NULL, 'Avarinio pamaitinimo vandens masės kiekis per 3 minutes', 1786, 1, NULL, NULL),
	(11322, 459, -4, 3, 2, 0, 35, 3, 476, NULL, 'Avarinio pamaitinimo vandens masės kiekis per 30 minučių', 1786, 2, NULL, NULL),
	(11323, 459, -4, 10, 2, 0, 35, 9, 476, NULL, 'Avarinio pamaitinimo vandens masės kiekis per 4 minutes', 1786, 1, NULL, NULL),
	(11324, 459, -4, 11, 2, 0, 35, 10, 476, NULL, 'Avarinio pamaitinimo vandens masės kiekis per 5 minutes', 1786, 1, NULL, NULL),
	(11325, 459, -4, 8, 2, 0, 35, 7, 476, NULL, 'Suminis avarinio pamaitinimo vandens masės kiekis', 1776, 5, NULL, NULL),
	(11326, 459, -4, 8, 2, 0, 35, 6, 476, NULL, 'Suminis avarinio pamaitinimo vandens masės kiekis, fiksuojamas kas mėnesį', 1776, 5, NULL, NULL),
	(11327, 459, -4, 8, 2, 0, 35, 5, 476, NULL, 'Suminis avarinio pamaitinimo vandens masės kiekis, fiksuojamas kas parą', 1776, 5, NULL, NULL),
	(11328, 459, -4, 8, 2, 0, 35, 4, 476, NULL, 'Suminis avarinio pamaitinimo vandens masės kiekis, fiksuojamas kas valandą', 1776, 5, NULL, NULL),
	(11329, 459, -4, 8, 2, 0, 35, 12, 476, NULL, 'Suminis avarinio pamaitinimo vandens masės kiekis, fiksuojamas kas 15 minučių', 1776, 5, NULL, NULL),
	(11330, 459, -4, 8, 2, 0, 35, 13, 476, NULL, 'Suminis avarinio pamaitinimo vandens masės kiekis, fiksuojamas kas 20 minučių', 1776, 5, NULL, NULL),
	(11331, 459, -4, 8, 2, 0, 35, 3, 476, NULL, 'Suminis avarinio pamaitinimo vandens masės kiekis, fiksuojamas kas 30 minučių', 1776, 5, NULL, NULL),
	(11332, 459, -4, 8, 2, 0, 35, 10, 476, NULL, 'Suminis avarinio pamaitinimo vandens masės kiekis, fiksuojamas kas 5 minutes', 1776, 5, NULL, NULL),
	(11333, 459, -4, 7, 1, 0, 36, 7, 477, NULL, 'Momentinis avarinio pamaitinimo vandens masės srautas', 1777, 6, NULL, NULL),
	(11334, 459, -4, 6, 3, 0, 36, 6, 477, NULL, 'Vidutinis avarinio pamaitinimo vandens masės srautas per mėnesį', 1787, 4, NULL, NULL),
	(11335, 459, -4, 1, 3, 0, 36, 1, 477, NULL, 'Vidutinis avarinio pamaitinimo vandens masės srautas per minutę', 1787, 1, NULL, NULL),
	(11336, 459, -4, 5, 3, 0, 36, 5, 477, NULL, 'Vidutinis avarinio pamaitinimo vandens masės srautas per parą', 1787, 3, NULL, NULL),
	(11337, 459, -4, 4, 3, 0, 36, 4, 477, NULL, 'Vidutinis avarinio pamaitinimo vandens masės srautas per valandą', 1787, 2, NULL, NULL),
	(11338, 459, -4, 12, 3, 0, 36, 11, 477, NULL, 'Vidutinis avarinio pamaitinimo vandens masės srautas per 10 minučių', 1787, 1, NULL, NULL),
	(11339, 459, -4, 13, 3, 0, 36, 12, 477, NULL, 'Vidutinis avarinio pamaitinimo vandens masės srautas per 15 minučių', 1787, 2, NULL, NULL),
	(11340, 459, -4, 2, 3, 0, 36, 2, 477, NULL, 'Vidutinis avarinio pamaitinimo vandens masės srautas per 2 minutes', 1787, 1, NULL, NULL),
	(11341, 459, -4, 14, 3, 0, 36, 13, 477, NULL, 'Vidutinis avarinio pamaitinimo vandens masės srautas per 20 minučių', 1787, 2, NULL, NULL),
	(11342, 459, -4, 9, 3, 0, 36, 8, 477, NULL, 'Vidutinis avarinio pamaitinimo vandens masės srautas per 3 minutes', 1787, 1, NULL, NULL),
	(11343, 459, -4, 3, 3, 0, 36, 3, 477, NULL, 'Vidutinis avarinio pamaitinimo vandens masės srautas per 30 minučių', 1787, 2, NULL, NULL),
	(11344, 459, -4, 10, 3, 0, 36, 9, 477, NULL, 'Vidutinis avarinio pamaitinimo vandens masės srautas per 4 minutes', 1787, 1, NULL, NULL),
	(11345, 459, -4, 11, 3, 0, 36, 10, 477, NULL, 'Vidutinis avarinio pamaitinimo vandens masės srautas per 5 minutes', 1787, 1, NULL, NULL),
	(11346, 460, -4, 6, 2, 0, 2, 6, 483, NULL, 'Avarinio pamaitinimo vandens šilumos kiekis per mėnesį', 1788, 4, NULL, NULL),
	(11347, 460, -4, 5, 2, 0, 2, 5, 483, NULL, 'Avarinio pamaitinimo vandens šilumos kiekis per parą', 1788, 3, NULL, NULL),
	(11348, 460, -4, 4, 2, 0, 2, 4, 483, NULL, 'Avarinio pamaitinimo vandens šilumos kiekis per valandą', 1788, 2, NULL, NULL),
	(11349, 460, -4, 1, 2, 0, 2, 1, 483, NULL, 'Avarinio pamaitinimo vandens šilumos kiekis per minutę', 1788, 1, NULL, NULL),
	(11350, 460, -4, 12, 2, 0, 2, 11, 483, NULL, 'Avarinio pamaitinimo vandens šilumos kiekis per 10 minučių', 1788, 1, NULL, NULL),
	(11351, 460, -4, 13, 2, 0, 2, 12, 483, NULL, 'Avarinio pamaitinimo vandens šilumos kiekis per 15 minučių', 1788, 2, NULL, NULL),
	(11352, 460, -4, 2, 2, 0, 2, 2, 483, NULL, 'Avarinio pamaitinimo vandens šilumos kiekis per 2 minutes', 1788, 1, NULL, NULL),
	(11353, 460, -4, 14, 2, 0, 2, 13, 483, NULL, 'Avarinio pamaitinimo vandens šilumos kiekis per 20 minučių', 1788, 2, NULL, NULL),
	(11354, 460, -4, 9, 2, 0, 2, 8, 483, NULL, 'Avarinio pamaitinimo vandens šilumos kiekis per 3 minutes', 1788, 1, NULL, NULL),
	(11355, 460, -4, 3, 2, 0, 2, 3, 483, NULL, 'Avarinio pamaitinimo vandens šilumos kiekis per 30 minučių', 1788, 2, NULL, NULL),
	(11356, 460, -4, 10, 2, 0, 2, 9, 483, NULL, 'Avarinio pamaitinimo vandens šilumos kiekis per 4 minutes', 1788, 1, NULL, NULL),
	(11357, 460, -4, 11, 2, 0, 2, 10, 483, NULL, 'Avarinio pamaitinimo vandens šilumos kiekis per 5 minutes', 1788, 1, NULL, NULL),
	(11358, 460, -4, 8, 2, 0, 2, 7, 483, NULL, 'Suminis avarinio pamaitinimo vandens šilumos kiekis', 1778, 5, NULL, NULL),
	(11359, 460, -4, 8, 2, 0, 2, 4, 483, NULL, 'Suminis avarinio pamaitinimo vandens šilumos kiekis, fiksuojamas kas valandą', 1778, 5, NULL, NULL),
	(11360, 460, -4, 8, 2, 0, 2, 6, 483, NULL, 'Suminis avarinio pamaitinimo vandens šilumos kiekis, fiksuojamas kas mėnesį', 1778, 5, NULL, NULL),
	(11361, 460, -4, 8, 2, 0, 2, 5, 483, NULL, 'Suminis avarinio pamaitinimo vandens šilumos kiekis, fiksuojamas kas parą', 1778, 5, NULL, NULL),
	(11362, 460, -4, 8, 2, 0, 2, 12, 483, NULL, 'Suminis avarinio pamaitinimo vandens šilumos kiekis, fiksuojamas kas 15 minučių', 1778, 5, NULL, NULL),
	(11363, 460, -4, 8, 2, 0, 2, 13, 483, NULL, 'Suminis avarinio pamaitinimo vandens šilumos kiekis, fiksuojamas kas 20 minučių', 1778, 5, NULL, NULL),
	(11364, 460, -4, 8, 2, 0, 2, 3, 483, NULL, 'Suminis avarinio pamaitinimo vandens šilumos kiekis, fiksuojamas kas 30 minučių', 1778, 5, NULL, NULL),
	(11365, 460, -4, 8, 2, 0, 2, 10, 483, NULL, 'Suminis avarinio pamaitinimo vandens šilumos kiekis, fiksuojamas kas 5 minutes', 1778, 5, NULL, NULL),
	(11366, 460, -4, 7, 1, 0, 1, 7, 478, NULL, 'Momentinė avarinio pamaitinimo vandens šilumos galia', 1779, 6, NULL, NULL),
	(11367, 460, -4, 6, 3, 0, 1, 6, 478, NULL, 'Vidutinė avarinio pamaitinimo vandens šilumos galia per mėnesį', 1789, 4, NULL, NULL),
	(11368, 460, -4, 1, 3, 0, 1, 1, 478, NULL, 'Vidutinė avarinio pamaitinimo vandens šilumos galia per minutę', 1789, 1, NULL, NULL),
	(11369, 460, -4, 5, 3, 0, 1, 5, 478, NULL, 'Vidutinė avarinio pamaitinimo vandens šilumos galia per parą', 1789, 3, NULL, NULL),
	(11370, 460, -4, 4, 3, 0, 1, 4, 478, NULL, 'Vidutinė avarinio pamaitinimo vandens šilumos galia per valandą', 1789, 2, NULL, NULL),
	(11371, 460, -4, 12, 3, 0, 1, 11, 478, NULL, 'Vidutinė avarinio pamaitinimo vandens šilumos galia per 10 minučių', 1789, 1, NULL, NULL),
	(11372, 460, -4, 13, 3, 0, 1, 12, 478, NULL, 'Vidutinė avarinio pamaitinimo vandens šilumos galia per 15 minučių', 1789, 2, NULL, NULL),
	(11373, 460, -4, 2, 3, 0, 1, 2, 478, NULL, 'Vidutinė avarinio pamaitinimo vandens šilumos galia per 2 minutes', 1789, 1, NULL, NULL),
	(11374, 460, -4, 14, 3, 0, 1, 13, 478, NULL, 'Vidutinė avarinio pamaitinimo vandens šilumos galia per 20 minučių', 1789, 2, NULL, NULL),
	(11375, 460, -4, 9, 3, 0, 1, 8, 478, NULL, 'Vidutinė avarinio pamaitinimo vandens šilumos galia per 3 minutes', 1789, 1, NULL, NULL),
	(11376, 460, -4, 3, 3, 0, 1, 3, 478, NULL, 'Vidutinė avarinio pamaitinimo vandens šilumos galia per 30 minučių', 1789, 2, NULL, NULL),
	(11377, 460, -4, 10, 3, 0, 1, 9, 478, NULL, 'Vidutinė avarinio pamaitinimo vandens šilumos galia per 4 minutes', 1789, 1, NULL, NULL),
	(11378, 460, -4, 11, 3, 0, 1, 10, 478, NULL, 'Vidutinė avarinio pamaitinimo vandens šilumos galia per 5 minutes', 1789, 1, NULL, NULL),
	(11379, 461, -4, 6, 3, 0, 27, 6, 479, NULL, 'Vidutinė avarinio pamaitinimo vandens temperatūra per mėnesį', 1790, 4, NULL, NULL),
	(11380, 461, -4, 1, 3, 0, 27, 1, 479, NULL, 'Vidutinė avarinio pamaitinimo vandens temperatūra per minutę', 1790, 1, NULL, NULL),
	(11381, 461, -4, 5, 3, 0, 27, 5, 479, NULL, 'Vidutinė avarinio pamaitinimo vandens temperatūra per parą', 1790, 3, NULL, NULL),
	(11382, 461, -4, 4, 3, 0, 27, 4, 479, NULL, 'Vidutinė avarinio pamaitinimo vandens temperatūra per valandą', 1790, 2, NULL, NULL),
	(11383, 461, -4, 12, 3, 0, 27, 11, 479, NULL, 'Vidutinė avarinio pamaitinimo vandens temperatūra per 10 minučių', 1790, 1, NULL, NULL),
	(11384, 461, -4, 13, 3, 0, 27, 12, 479, NULL, 'Vidutinė avarinio pamaitinimo vandens temperatūra per 15 minučių', 1790, 2, NULL, NULL),
	(11385, 461, -4, 2, 3, 0, 27, 2, 479, NULL, 'Vidutinė avarinio pamaitinimo vandens temperatūra per 2 minutes', 1790, 1, NULL, NULL),
	(11386, 461, -4, 14, 3, 0, 27, 13, 479, NULL, 'Vidutinė avarinio pamaitinimo vandens temperatūra per 20 minučių', 1790, 2, NULL, NULL),
	(11387, 461, -4, 9, 3, 0, 27, 8, 479, NULL, 'Vidutinė avarinio pamaitinimo vandens temperatūra per 3 minutes', 1790, 1, NULL, NULL),
	(11388, 461, -4, 3, 3, 0, 27, 3, 479, NULL, 'Vidutinė avarinio pamaitinimo vandens temperatūra per 30 minučių', 1790, 2, NULL, NULL),
	(11389, 461, -4, 10, 3, 0, 27, 9, 479, NULL, 'Vidutinė avarinio pamaitinimo vandens temperatūra per 4 minutes', 1790, 1, NULL, NULL),
	(11390, 461, -4, 11, 3, 0, 27, 10, 479, NULL, 'Vidutinė avarinio pamaitinimo vandens temperatūra per 5 minutes', 1790, 1, NULL, NULL),
	(11391, 461, -4, 7, 1, 0, 27, 7, 479, NULL, 'Momentinė avarinio pamaitinimo vandens temperatūra', 1780, 6, NULL, NULL),
	(11392, 462, -4, 7, 1, 0, 28, 7, 480, NULL, 'Momentinis avarinio pamaitinimo vandens slėgis', 1781, 6, NULL, NULL),
	(11393, 462, -4, 6, 3, 0, 28, 6, 480, NULL, 'Vidutinis avarinio pamaitinimo vandens slėgis per mėnesį', 1791, 4, NULL, NULL),
	(11394, 462, -4, 1, 3, 0, 28, 1, 480, NULL, 'Vidutinis avarinio pamaitinimo vandens slėgis per minutę', 1791, 1, NULL, NULL),
	(11395, 462, -4, 5, 3, 0, 28, 5, 480, NULL, 'Vidutinis avarinio pamaitinimo vandens slėgis per parą', 1791, 3, NULL, NULL),
	(11396, 462, -4, 4, 3, 0, 28, 4, 480, NULL, 'Vidutinis avarinio pamaitinimo vandens slėgis per valandą', 1791, 2, NULL, NULL),
	(11397, 462, -4, 12, 3, 0, 28, 11, 480, NULL, 'Vidutinis avarinio pamaitinimo vandens slėgis per 10 minučių', 1791, 1, NULL, NULL),
	(11398, 462, -4, 13, 3, 0, 28, 12, 480, NULL, 'Vidutinis avarinio pamaitinimo vandens slėgis per 15 minučių', 1791, 2, NULL, NULL),
	(11399, 462, -4, 2, 3, 0, 28, 2, 480, NULL, 'Vidutinis avarinio pamaitinimo vandens slėgis per 2 minutes', 1791, 1, NULL, NULL),
	(11400, 462, -4, 14, 3, 0, 28, 13, 480, NULL, 'Vidutinis avarinio pamaitinimo vandens slėgis per 20 minučių', 1791, 2, NULL, NULL),
	(11401, 462, -4, 9, 3, 0, 28, 8, 480, NULL, 'Vidutinis avarinio pamaitinimo vandens slėgis per 3 minutes', 1791, 1, NULL, NULL),
	(11402, 462, -4, 3, 3, 0, 28, 3, 480, NULL, 'Vidutinis avarinio pamaitinimo vandens slėgis per 30 minučių', 1791, 2, NULL, NULL),
	(11403, 462, -4, 10, 3, 0, 28, 9, 480, NULL, 'Vidutinis avarinio pamaitinimo vandens slėgis per 4 minutes', 1791, 1, NULL, NULL),
	(11404, 462, -4, 11, 3, 0, 28, 10, 480, NULL, 'Vidutinis avarinio pamaitinimo vandens slėgis per 5 minutes', 1791, 1, NULL, NULL),
	(11405, 463, -4, 7, 1, 0, 28, 7, 481, NULL, 'Momentinis avarinio pamaitinimo vandens absoliutus slėgis', 1783, 6, NULL, NULL),
	(11406, 463, -4, 6, 3, 0, 28, 6, 481, NULL, 'Vidutinis avarinio pamaitinimo vandens absoliutus slėgis per mėnesį', 1793, 4, NULL, NULL),
	(11407, 463, -4, 1, 3, 0, 28, 1, 481, NULL, 'Vidutinis avarinio pamaitinimo vandens absoliutus slėgis per minutę', 1793, 1, NULL, NULL),
	(11408, 463, -4, 5, 3, 0, 28, 5, 481, NULL, 'Vidutinis avarinio pamaitinimo vandens absoliutus slėgis per parą', 1793, 3, NULL, NULL),
	(11409, 463, -4, 4, 3, 0, 28, 4, 481, NULL, 'Vidutinis avarinio pamaitinimo vandens absoliutus slėgis per valandą', 1793, 2, NULL, NULL),
	(11410, 463, -4, 12, 3, 0, 28, 11, 481, NULL, 'Vidutinis avarinio pamaitinimo vandens absoliutus slėgis per 10 minučių', 1793, 1, NULL, NULL),
	(11411, 463, -4, 13, 3, 0, 28, 12, 481, NULL, 'Vidutinis avarinio pamaitinimo vandens absoliutus slėgis per 15 minučių', 1793, 2, NULL, NULL),
	(11412, 463, -4, 2, 3, 0, 28, 2, 481, NULL, 'Vidutinis avarinio pamaitinimo vandens absoliutus slėgis per 2 minutes', 1793, 1, NULL, NULL),
	(11413, 463, -4, 14, 3, 0, 28, 13, 481, NULL, 'Vidutinis avarinio pamaitinimo vandens absoliutus slėgis per 20 minučių', 1793, 2, NULL, NULL),
	(11414, 463, -4, 9, 3, 0, 28, 8, 481, NULL, 'Vidutinis avarinio pamaitinimo vandens absoliutus slėgis per 3 minutes', 1793, 1, NULL, NULL),
	(11415, 463, -4, 3, 3, 0, 28, 3, 481, NULL, 'Vidutinis avarinio pamaitinimo vandens absoliutus slėgis per 30 minučių', 1793, 2, NULL, NULL),
	(11416, 463, -4, 10, 3, 0, 28, 9, 481, NULL, 'Vidutinis avarinio pamaitinimo vandens absoliutus slėgis per 4 minutes', 1793, 1, NULL, NULL),
	(11417, 463, -4, 11, 3, 0, 28, 10, 481, NULL, 'Vidutinis avarinio pamaitinimo vandens absoliutus slėgis per 5 minutes', 1793, 1, NULL, NULL),
	(11418, 464, -4, 7, 1, 0, 28, 7, 482, NULL, 'Momentinė avarinio pamaitinimo vandens slėgių skirtumo perskaičiuota reikšmė', 1782, 6, NULL, NULL),
	(11419, 464, -4, 6, 3, 0, 28, 6, 482, NULL, 'Vidutinė avarinio pamaitinimo vandens slėgių skirtumo perskaičiuota reikšmė per mėnesį', 1792, 4, NULL, NULL),
	(11420, 464, -4, 1, 3, 0, 28, 1, 482, NULL, 'Vidutinė avarinio pamaitinimo vandens slėgių skirtumo perskaičiuota reikšmė per minutę', 1792, 1, NULL, NULL),
	(11421, 464, -4, 5, 3, 0, 28, 5, 482, NULL, 'Vidutinė avarinio pamaitinimo vandens slėgių skirtumo perskaičiuota reikšmė per parą', 1792, 3, NULL, NULL),
	(11422, 464, -4, 4, 3, 0, 28, 4, 482, NULL, 'Vidutinė avarinio pamaitinimo vandens slėgių skirtumo perskaičiuota reikšmė per valandą', 1792, 2, NULL, NULL),
	(11423, 464, -4, 12, 3, 0, 28, 11, 482, NULL, 'Vidutinė avarinio pamaitinimo vandens slėgių skirtumo perskaičiuota reikšmė per 10 minučių', 1792, 1, NULL, NULL),
	(11424, 464, -4, 13, 3, 0, 28, 12, 482, NULL, 'Vidutinė avarinio pamaitinimo vandens slėgių skirtumo perskaičiuota reikšmė per 15 minučių', 1792, 2, NULL, NULL),
	(11425, 464, -4, 2, 3, 0, 28, 2, 482, NULL, 'Vidutinė avarinio pamaitinimo vandens slėgių skirtumo perskaičiuota reikšmė per 2 minutes', 1792, 1, NULL, NULL),
	(11426, 464, -4, 14, 3, 0, 28, 13, 482, NULL, 'Vidutinė avarinio pamaitinimo vandens slėgių skirtumo perskaičiuota reikšmė per 20 minučių', 1792, 2, NULL, NULL),
	(11427, 464, -4, 9, 3, 0, 28, 8, 482, NULL, 'Vidutinė avarinio pamaitinimo vandens slėgių skirtumo perskaičiuota reikšmė per 3 minutes', 1792, 1, NULL, NULL),
	(11428, 464, -4, 3, 3, 0, 28, 3, 482, NULL, 'Vidutinė avarinio pamaitinimo vandens slėgių skirtumo perskaičiuota reikšmė per 30 minučių', 1792, 2, NULL, NULL),
	(11429, 464, -4, 10, 3, 0, 28, 9, 482, NULL, 'Vidutinė avarinio pamaitinimo vandens slėgių skirtumo perskaičiuota reikšmė per 4 minutes', 1792, 1, NULL, NULL),
	(11430, 464, -4, 11, 3, 0, 28, 10, 482, NULL, 'Vidutinė avarinio pamaitinimo vandens slėgių skirtumo perskaičiuota reikšmė per 5 minutes', 1792, 1, NULL, NULL),
	(11431, 187, 0, 7, 1, 0, 0, 12, 200, NULL, 'Momentinis rodiklis Nr.1, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11432, 344, 0, 7, 1, 0, 0, 12, 356, NULL, 'Momentinis rodiklis Nr.2, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11433, 345, 0, 7, 1, 0, 0, 12, 357, NULL, 'Momentinis rodiklis Nr.3, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11434, 346, 0, 7, 1, 0, 0, 12, 358, NULL, 'Momentinis rodiklis Nr.4, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11435, 347, 0, 7, 1, 0, 0, 12, 359, NULL, 'Momentinis rodiklis Nr.5, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11436, 348, 0, 7, 1, 0, 0, 12, 360, NULL, 'Momentinis rodiklis Nr.6, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11437, 349, 0, 7, 1, 0, 0, 12, 361, NULL, 'Momentinis rodiklis Nr.7, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11438, 350, 0, 7, 1, 0, 0, 12, 362, NULL, 'Momentinis rodiklis Nr.8, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11439, 351, 0, 7, 1, 0, 0, 12, 363, NULL, 'Momentinis rodiklis Nr.9, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11440, 352, 0, 7, 1, 0, 0, 12, 364, NULL, 'Momentinis rodiklis Nr.10, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11441, 365, 0, 7, 1, 0, 0, 12, 377, NULL, 'Momentinis rodiklis Nr.11, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11442, 366, 0, 7, 1, 0, 0, 12, 378, NULL, 'Momentinis rodiklis Nr.12, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11443, 367, 0, 7, 1, 0, 0, 12, 379, NULL, 'Momentinis rodiklis Nr.13, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11444, 368, 0, 7, 1, 0, 0, 12, 380, NULL, 'Momentinis rodiklis Nr.14, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11445, 369, 0, 7, 1, 0, 0, 12, 381, NULL, 'Momentinis rodiklis Nr.15, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11446, 370, 0, 7, 1, 0, 0, 12, 382, NULL, 'Momentinis rodiklis Nr.16, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11447, 371, 0, 7, 1, 0, 0, 12, 383, NULL, 'Momentinis rodiklis Nr.17, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11448, 372, 0, 7, 1, 0, 0, 12, 384, NULL, 'Momentinis rodiklis Nr.18, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11449, 373, 0, 7, 1, 0, 0, 12, 385, NULL, 'Momentinis rodiklis Nr.19, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11450, 374, 0, 7, 1, 0, 0, 12, 386, NULL, 'Momentinis rodiklis Nr.20, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11451, 375, 0, 7, 1, 0, 0, 12, 387, NULL, 'Momentinis rodiklis Nr.21, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11452, 376, 0, 7, 1, 0, 0, 12, 388, NULL, 'Momentinis rodiklis Nr.22, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11453, 377, 0, 7, 1, 0, 0, 12, 389, NULL, 'Momentinis rodiklis Nr.23, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11454, 378, 0, 7, 1, 0, 0, 12, 390, NULL, 'Momentinis rodiklis Nr.24, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11455, 379, 0, 7, 1, 0, 0, 12, 391, NULL, 'Momentinis rodiklis Nr.25, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11456, 380, 0, 7, 1, 0, 0, 12, 392, NULL, 'Momentinis rodiklis Nr.26, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11457, 381, 0, 7, 1, 0, 0, 12, 393, NULL, 'Momentinis rodiklis Nr.27, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11458, 382, 0, 7, 1, 0, 0, 12, 394, NULL, 'Momentinis rodiklis Nr.28, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11459, 383, 0, 7, 1, 0, 0, 12, 395, NULL, 'Momentinis rodiklis Nr.29, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11460, 384, 0, 7, 1, 0, 0, 12, 455, NULL, 'Momentinis rodiklis Nr.30, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11461, 445, 0, 7, 1, 0, 0, 12, 459, NULL, 'Momentinis rodiklis Nr.31, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11462, 446, 0, 7, 1, 0, 0, 12, 460, NULL, 'Momentinis rodiklis Nr.32, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11463, 447, 0, 7, 1, 0, 0, 12, 461, NULL, 'Momentinis rodiklis Nr.33, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11464, 448, 0, 7, 1, 0, 0, 12, 462, NULL, 'Momentinis rodiklis Nr.34, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11465, 449, 0, 7, 1, 0, 0, 12, 463, NULL, 'Momentinis rodiklis Nr.35, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11466, 450, 0, 7, 1, 0, 0, 12, 464, NULL, 'Momentinis rodiklis Nr.36, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11467, 451, 0, 7, 1, 0, 0, 12, 465, NULL, 'Momentinis rodiklis Nr.37, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11468, 452, 0, 7, 1, 0, 0, 12, 466, NULL, 'Momentinis rodiklis Nr.38, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11469, 453, 0, 7, 1, 0, 0, 12, 467, NULL, 'Momentinis rodiklis Nr.39, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11470, 454, 0, 7, 1, 0, 0, 12, 468, NULL, 'Momentinis rodiklis Nr.40, fiksuojamas kas 15 minučių', NULL, 2, NULL, NULL),
	(11471, 465, 0, 8, 2, 0, 2, 7, 484, NULL, 'Fazės L1 aktyvinių A+ ir A- energijų balansas', 4217, 5, NULL, NULL),
	(11472, 466, 0, 8, 2, 0, 2, 7, 485, NULL, 'Fazės L2 aktyvinių A+ ir A- energijų balansas', 4218, 5, NULL, NULL),
	(11473, 467, 0, 8, 2, 0, 2, 7, 486, NULL, 'Fazės L3 aktyvinių A+ ir A- energijų balansas', 4219, 5, NULL, NULL),
	(11474, 468, 0, 8, 2, 0, 4, 7, 487, NULL, 'Fazės L1 reaktyvinių R+ ir R- energijų balansas', 4220, 5, NULL, NULL),
	(11475, 469, 0, 8, 2, 0, 4, 7, 488, NULL, 'Fazės L2 reaktyvinių R+ ir R- energijų balansas', 4221, 5, NULL, NULL),
	(11476, 470, 0, 8, 2, 0, 4, 7, 489, NULL, 'Fazės L3 reaktyvinių R+ ir R- energijų balansas', 4222, 5, NULL, NULL),
	(11477, 471, 0, 8, 2, 0, 41, 7, 490, NULL, 'Fazės L1 pilnųjų W+ ir W- energijų balansas', 4223, 5, NULL, NULL),
	(11478, 472, 0, 8, 2, 0, 41, 7, 491, NULL, 'Fazės L2 pilnųjų W+ ir W- energijų balansas', 4224, 5, NULL, NULL),
	(11479, 473, 0, 8, 2, 0, 41, 7, 492, NULL, 'Fazės L3 pilnųjų W+ ir W- energijų balansas', 4225, 5, NULL, NULL),
	(11480, 189, 1, 8, 2, 0, 2, 6, 202, NULL, 'Suminė A+ energija L1 fazėje, fiksuojama kas mėnesį', 3161, 5, NULL, NULL),
	(11481, 189, 1, 8, 2, 1, 2, 6, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3493, 5, NULL, NULL),
	(11482, 189, 1, 8, 2, 2, 2, 6, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3494, 5, NULL, NULL),
	(11483, 189, 1, 8, 2, 3, 2, 6, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3495, 5, NULL, NULL),
	(11484, 189, 1, 8, 2, 4, 2, 6, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3496, 5, NULL, NULL),
	(11485, 189, 2, 8, 2, 0, 2, 6, 202, NULL, 'Suminė A- energija L1 fazėje, fiksuojama kas mėnesį', 3164, 5, NULL, NULL),
	(11486, 189, 2, 8, 2, 1, 2, 6, 202, NULL, 'Suminė A- energija L1 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3497, 5, NULL, NULL),
	(11487, 189, 2, 8, 2, 2, 2, 6, 202, NULL, 'Suminė A- energija L1 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3498, 5, NULL, NULL),
	(11488, 189, 2, 8, 2, 3, 2, 6, 202, NULL, 'Suminė A- energija L1 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3499, 5, NULL, NULL),
	(11489, 189, 2, 8, 2, 4, 2, 6, 202, NULL, 'Suminė A- energija L1 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3500, 5, NULL, NULL),
	(11490, 190, 1, 8, 2, 0, 2, 6, 203, NULL, 'Suminė A+ energija L2 fazėje, fiksuojama kas mėnesį', 3162, 5, NULL, NULL),
	(11491, 190, 1, 8, 2, 1, 2, 6, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3535, 5, NULL, NULL),
	(11492, 190, 1, 8, 2, 2, 2, 6, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3536, 5, NULL, NULL),
	(11493, 190, 1, 8, 2, 3, 2, 6, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3537, 5, NULL, NULL),
	(11494, 190, 1, 8, 2, 4, 2, 6, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3538, 5, NULL, NULL),
	(11495, 190, 2, 8, 2, 0, 2, 6, 203, NULL, 'Suminė A- energija L2 fazėje, fiksuojama kas mėnesį', 3165, 5, NULL, NULL),
	(11496, 190, 2, 8, 2, 1, 2, 6, 203, NULL, 'Suminė A- energija L2 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3539, 5, NULL, NULL),
	(11497, 190, 2, 8, 2, 2, 2, 6, 203, NULL, 'Suminė A- energija L2 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3540, 5, NULL, NULL),
	(11498, 190, 2, 8, 2, 3, 2, 6, 203, NULL, 'Suminė A- energija L2 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3541, 5, NULL, NULL),
	(11499, 190, 2, 8, 2, 4, 2, 6, 203, NULL, 'Suminė A- energija L2 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3542, 5, NULL, NULL),
	(11500, 191, 1, 8, 2, 0, 2, 6, 204, NULL, 'Suminė A+ energija L3 fazėje, fiksuojama kas mėnesį', 3163, 5, NULL, NULL),
	(11501, 191, 1, 8, 2, 1, 2, 6, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3577, 5, NULL, NULL),
	(11502, 191, 1, 8, 2, 2, 2, 6, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 2 tarifą , fiksuojama kas mėnesį', 3578, 5, NULL, NULL),
	(11503, 191, 1, 8, 2, 3, 2, 6, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3579, 5, NULL, NULL),
	(11504, 191, 1, 8, 2, 4, 2, 6, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3580, 5, NULL, NULL),
	(11505, 191, 2, 8, 2, 0, 2, 6, 204, NULL, 'Suminė A- energija L3 fazėje, fiksuojama kas mėnesį', 3166, 5, NULL, NULL),
	(11506, 191, 2, 8, 2, 1, 2, 6, 204, NULL, 'Suminė A- energija L3 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3581, 5, NULL, NULL),
	(11507, 191, 2, 8, 2, 2, 2, 6, 204, NULL, 'Suminė A- energija L3 fazėje pagal 2 tarifą , fiksuojama kas mėnesį', 3582, 5, NULL, NULL),
	(11508, 191, 2, 8, 2, 3, 2, 6, 204, NULL, 'Suminė A- energija L3 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3583, 5, NULL, NULL),
	(11509, 191, 2, 8, 2, 4, 2, 6, 204, NULL, 'Suminė A- energija L3 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3584, 5, NULL, NULL),
	(11510, 193, 1, 8, 2, 0, 4, 6, 205, NULL, 'Suminė R+ energija L1 fazėje, fiksuojama kas mėnesį', 3167, 5, NULL, NULL),
	(11511, 193, 1, 8, 2, 1, 4, 6, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3501, 5, NULL, NULL),
	(11512, 193, 1, 8, 2, 2, 4, 6, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3502, 5, NULL, NULL),
	(11513, 193, 1, 8, 2, 3, 4, 6, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3503, 5, NULL, NULL),
	(11514, 193, 1, 8, 2, 4, 4, 6, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3504, 5, NULL, NULL),
	(11515, 193, 2, 8, 2, 0, 4, 6, 205, NULL, 'Suminė R- energija L1 fazėje, fiksuojama kas mėnesį', 3170, 5, NULL, NULL),
	(11516, 193, 2, 8, 2, 1, 4, 6, 205, NULL, 'Suminė R- energija L1 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3505, 5, NULL, NULL),
	(11517, 193, 2, 8, 2, 2, 4, 6, 205, NULL, 'Suminė R- energija L1 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3506, 5, NULL, NULL),
	(11518, 193, 2, 8, 2, 3, 4, 6, 205, NULL, 'Suminė R- energija L1 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3507, 5, NULL, NULL),
	(11519, 193, 2, 8, 2, 4, 4, 6, 205, NULL, 'Suminė R- energija L1 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3508, 5, NULL, NULL),
	(11520, 193, 5, 8, 2, 0, 4, 6, 205, NULL, 'Suminė R1 energija L1 fazėje, fiksuojama kas mėnesį', 3296, 5, NULL, NULL),
	(11521, 193, 5, 8, 2, 1, 4, 6, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3509, 5, NULL, NULL),
	(11522, 193, 5, 8, 2, 2, 4, 6, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3510, 5, NULL, NULL),
	(11523, 193, 5, 8, 2, 3, 4, 6, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3511, 5, NULL, NULL),
	(11524, 193, 5, 8, 2, 4, 4, 6, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3512, 5, NULL, NULL),
	(11525, 193, 6, 8, 2, 0, 4, 6, 205, NULL, 'Suminė R2 energija L1 fazėje, fiksuojama kas mėnesį', 3299, 5, NULL, NULL),
	(11526, 193, 6, 8, 2, 1, 4, 6, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3513, 5, NULL, NULL),
	(11527, 193, 6, 8, 2, 2, 4, 6, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3514, 5, NULL, NULL),
	(11528, 193, 6, 8, 2, 3, 4, 6, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3515, 5, NULL, NULL),
	(11529, 193, 6, 8, 2, 4, 4, 6, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3516, 5, NULL, NULL),
	(11530, 193, 7, 8, 2, 0, 4, 6, 205, NULL, 'Suminė R3 energija L1 fazėje, fiksuojama kas mėnesį', 3302, 5, NULL, NULL),
	(11531, 193, 7, 8, 2, 1, 4, 6, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3517, 5, NULL, NULL),
	(11532, 193, 7, 8, 2, 2, 4, 6, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3518, 5, NULL, NULL),
	(11533, 193, 7, 8, 2, 3, 4, 6, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3519, 5, NULL, NULL),
	(11534, 193, 7, 8, 2, 4, 4, 6, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3520, 5, NULL, NULL),
	(11535, 193, 8, 8, 2, 0, 4, 6, 205, NULL, 'Suminė R4 energija L1 fazėje, fiksuojama kas mėnesį', 3305, 5, NULL, NULL),
	(11536, 193, 8, 8, 2, 1, 4, 6, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3521, 5, NULL, NULL),
	(11537, 193, 8, 8, 2, 2, 4, 6, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3522, 5, NULL, NULL),
	(11538, 193, 8, 8, 2, 3, 4, 6, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3523, 5, NULL, NULL),
	(11539, 193, 8, 8, 2, 4, 4, 6, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3524, 5, NULL, NULL),
	(11540, 194, 1, 8, 2, 0, 4, 6, 206, NULL, 'Suminė R+ energija L2 fazėje, fiksuojama kas mėnesį', 3168, 5, NULL, NULL),
	(11541, 194, 1, 8, 2, 1, 4, 6, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3543, 5, NULL, NULL),
	(11542, 194, 1, 8, 2, 2, 4, 6, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3544, 5, NULL, NULL),
	(11543, 194, 1, 8, 2, 3, 4, 6, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3545, 5, NULL, NULL),
	(11544, 194, 1, 8, 2, 4, 4, 6, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3546, 5, NULL, NULL),
	(11545, 194, 2, 8, 2, 0, 4, 6, 206, NULL, 'Suminė R- energija L2 fazėje, fiksuojama kas mėnesį', 3171, 5, NULL, NULL),
	(11546, 194, 2, 8, 2, 1, 4, 6, 206, NULL, 'Suminė R- energija L2 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3547, 5, NULL, NULL),
	(11547, 194, 2, 8, 2, 2, 4, 6, 206, NULL, 'Suminė R- energija L2 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3548, 5, NULL, NULL),
	(11548, 194, 2, 8, 2, 3, 4, 6, 206, NULL, 'Suminė R- energija L2 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3549, 5, NULL, NULL),
	(11549, 194, 2, 8, 2, 4, 4, 6, 206, NULL, 'Suminė R- energija L2 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3550, 5, NULL, NULL),
	(11550, 194, 5, 8, 2, 0, 4, 6, 206, NULL, 'Suminė R1 energija L2 fazėje, fiksuojama kas mėnesį', 3297, 5, NULL, NULL),
	(11551, 194, 5, 8, 2, 1, 4, 6, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3551, 5, NULL, NULL),
	(11552, 194, 5, 8, 2, 2, 4, 6, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3552, 5, NULL, NULL),
	(11553, 194, 5, 8, 2, 3, 4, 6, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3553, 5, NULL, NULL),
	(11554, 194, 5, 8, 2, 4, 4, 6, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3554, 5, NULL, NULL),
	(11555, 194, 6, 8, 2, 0, 4, 6, 206, NULL, 'Suminė R2 energija L2 fazėje, fiksuojama kas mėnesį', 3300, 5, NULL, NULL),
	(11556, 194, 6, 8, 2, 1, 4, 6, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3555, 5, NULL, NULL),
	(11557, 194, 6, 8, 2, 2, 4, 6, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3556, 5, NULL, NULL),
	(11558, 194, 6, 8, 2, 3, 4, 6, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3557, 5, NULL, NULL),
	(11559, 194, 6, 8, 2, 4, 4, 6, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3558, 5, NULL, NULL),
	(11560, 194, 7, 8, 2, 0, 4, 6, 206, NULL, 'Suminė R3 energija L2 fazėje, fiksuojama kas mėnesį', 3303, 5, NULL, NULL),
	(11561, 194, 7, 8, 2, 1, 4, 6, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3559, 5, NULL, NULL),
	(11562, 194, 7, 8, 2, 2, 4, 6, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3560, 5, NULL, NULL),
	(11563, 194, 7, 8, 2, 3, 4, 6, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3561, 5, NULL, NULL),
	(11564, 194, 7, 8, 2, 4, 4, 6, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3562, 5, NULL, NULL),
	(11565, 194, 8, 8, 2, 0, 4, 6, 206, NULL, 'Suminė R4 energija L2 fazėje, fiksuojama kas mėnesį', 3306, 5, NULL, NULL),
	(11566, 194, 8, 8, 2, 1, 4, 6, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3563, 5, NULL, NULL),
	(11567, 194, 8, 8, 2, 2, 4, 6, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3564, 5, NULL, NULL),
	(11568, 194, 8, 8, 2, 3, 4, 6, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3565, 5, NULL, NULL),
	(11569, 194, 8, 8, 2, 4, 4, 6, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3566, 5, NULL, NULL),
	(11570, 195, 1, 8, 2, 0, 4, 6, 207, NULL, 'Suminė R+ energija L3 fazėje, fiksuojama kas mėnesį', 3169, 5, NULL, NULL),
	(11571, 195, 1, 8, 2, 1, 4, 6, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3585, 5, NULL, NULL),
	(11572, 195, 1, 8, 2, 2, 4, 6, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 2 tarifą , fiksuojama kas mėnesį', 3586, 5, NULL, NULL),
	(11573, 195, 1, 8, 2, 3, 4, 6, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3587, 5, NULL, NULL),
	(11574, 195, 1, 8, 2, 4, 4, 6, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3588, 5, NULL, NULL),
	(11575, 195, 2, 8, 2, 0, 4, 6, 207, NULL, 'Suminė R- energija L3 fazėje, fiksuojama kas mėnesį', 3172, 5, NULL, NULL),
	(11576, 195, 2, 8, 2, 1, 4, 6, 207, NULL, 'Suminė R- energija L3 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3589, 5, NULL, NULL),
	(11577, 195, 2, 8, 2, 2, 4, 6, 207, NULL, 'Suminė R- energija L3 fazėje pagal 2 tarifą , fiksuojama kas mėnesį', 3590, 5, NULL, NULL),
	(11578, 195, 2, 8, 2, 3, 4, 6, 207, NULL, 'Suminė R- energija L3 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3591, 5, NULL, NULL),
	(11579, 195, 2, 8, 2, 4, 4, 6, 207, NULL, 'Suminė R- energija L3 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3592, 5, NULL, NULL),
	(11580, 195, 5, 8, 2, 0, 4, 6, 207, NULL, 'Suminė R1 energija L3 fazėje, fiksuojama kas mėnesį', 3298, 5, NULL, NULL),
	(11581, 195, 5, 8, 2, 1, 4, 6, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3593, 5, NULL, NULL),
	(11582, 195, 5, 8, 2, 2, 4, 6, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 2 tarifą , fiksuojama kas mėnesį', 3594, 5, NULL, NULL),
	(11583, 195, 5, 8, 2, 3, 4, 6, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3595, 5, NULL, NULL),
	(11584, 195, 5, 8, 2, 4, 4, 6, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3596, 5, NULL, NULL),
	(11585, 195, 6, 8, 2, 0, 4, 6, 207, NULL, 'Suminė R2 energija L3 fazėje, fiksuojama kas mėnesį', 3301, 5, NULL, NULL),
	(11586, 195, 6, 8, 2, 1, 4, 6, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3597, 5, NULL, NULL),
	(11587, 195, 6, 8, 2, 2, 4, 6, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 2 tarifą , fiksuojama kas mėnesį', 3598, 5, NULL, NULL),
	(11588, 195, 6, 8, 2, 3, 4, 6, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3599, 5, NULL, NULL),
	(11589, 195, 6, 8, 2, 4, 4, 6, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3600, 5, NULL, NULL),
	(11590, 195, 7, 8, 2, 0, 4, 6, 207, NULL, 'Suminė R3 energija L3 fazėje, fiksuojama kas mėnesį', 3304, 5, NULL, NULL),
	(11591, 195, 7, 8, 2, 1, 4, 6, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3601, 5, NULL, NULL),
	(11592, 195, 7, 8, 2, 2, 4, 6, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 2 tarifą , fiksuojama kas mėnesį', 3602, 5, NULL, NULL),
	(11593, 195, 7, 8, 2, 3, 4, 6, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3603, 5, NULL, NULL),
	(11594, 195, 7, 8, 2, 4, 4, 6, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3604, 5, NULL, NULL),
	(11595, 195, 8, 8, 2, 0, 4, 6, 207, NULL, 'Suminė R4 energija L3 fazėje, fiksuojama kas mėnesį', 3307, 5, NULL, NULL),
	(11596, 195, 8, 8, 2, 1, 4, 6, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3605, 5, NULL, NULL),
	(11597, 195, 8, 8, 2, 2, 4, 6, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 2 tarifą , fiksuojama kas mėnesį', 3606, 5, NULL, NULL),
	(11598, 195, 8, 8, 2, 3, 4, 6, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3607, 5, NULL, NULL),
	(11599, 195, 8, 8, 2, 4, 4, 6, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3608, 5, NULL, NULL),
	(11600, 196, 0, 8, 2, 0, 41, 6, 208, NULL, 'Suminė W energija L1 fazėje, fiksuojama kas mėnesį', 3173, 5, NULL, NULL),
	(11601, 196, 1, 8, 2, 0, 41, 6, 208, NULL, 'Suminė W+ energija L1 fazėje, fiksuojama kas mėnesį', 3525, 5, NULL, NULL),
	(11602, 196, 1, 8, 2, 1, 41, 6, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3526, 5, NULL, NULL),
	(11603, 196, 1, 8, 2, 2, 41, 6, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3527, 5, NULL, NULL),
	(11604, 196, 1, 8, 2, 3, 41, 6, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3528, 5, NULL, NULL),
	(11605, 196, 1, 8, 2, 4, 41, 6, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3529, 5, NULL, NULL),
	(11606, 196, 2, 8, 2, 0, 41, 6, 208, NULL, 'Suminė W- energija L1 fazėje, fiksuojama kas mėnesį', 3530, 5, NULL, NULL),
	(11607, 196, 2, 8, 2, 1, 41, 6, 208, NULL, 'Suminė W- energija L1 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3531, 5, NULL, NULL),
	(11608, 196, 2, 8, 2, 2, 41, 6, 208, NULL, 'Suminė W- energija L1 fazėje pagal 2 tarifą, fiksuojama kas mėnesį', 3532, 5, NULL, NULL),
	(11609, 196, 2, 8, 2, 3, 41, 6, 208, NULL, 'Suminė W- energija L1 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3533, 5, NULL, NULL),
	(11610, 196, 2, 8, 2, 4, 41, 6, 208, NULL, 'Suminė W- energija L1 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3534, 5, NULL, NULL),
	(11611, 197, 0, 8, 2, 0, 41, 6, 209, NULL, 'Suminė W energija L2 fazėje, fiksuojama kas mėnesį', 3174, 5, NULL, NULL),
	(11612, 197, 1, 8, 2, 0, 41, 6, 209, NULL, 'Suminė W+ energija L2 fazėje, fiksuojama kas mėnesį', 3567, 5, NULL, NULL),
	(11613, 197, 1, 8, 2, 1, 41, 6, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3568, 5, NULL, NULL),
	(11614, 197, 1, 8, 2, 2, 41, 6, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 2 tarifą , fiksuojama kas mėnesį', 3569, 5, NULL, NULL),
	(11615, 197, 1, 8, 2, 3, 41, 6, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3570, 5, NULL, NULL),
	(11616, 197, 1, 8, 2, 4, 41, 6, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3571, 5, NULL, NULL),
	(11617, 197, 2, 8, 2, 0, 41, 6, 209, NULL, 'Suminė W- energija L2 fazėje, fiksuojama kas mėnesį', 3572, 5, NULL, NULL),
	(11618, 197, 2, 8, 2, 1, 41, 6, 209, NULL, 'Suminė W- energija L2 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3573, 5, NULL, NULL),
	(11619, 197, 2, 8, 2, 2, 41, 6, 209, NULL, 'Suminė W- energija L2 fazėje pagal 2 tarifą , fiksuojama kas mėnesį', 3574, 5, NULL, NULL),
	(11620, 197, 2, 8, 2, 3, 41, 6, 209, NULL, 'Suminė W- energija L2 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3575, 5, NULL, NULL),
	(11621, 197, 2, 8, 2, 4, 41, 6, 209, NULL, 'Suminė W- energija L2 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3576, 5, NULL, NULL),
	(11622, 198, 0, 8, 2, 0, 41, 6, 210, NULL, 'Suminė W energija L3 fazėje, fiksuojama kas mėnesį', 3175, 5, NULL, NULL),
	(11623, 198, 1, 8, 2, 0, 41, 6, 210, NULL, 'Suminė W+ energija L3 fazėje, fiksuojama kas mėnesį', 3609, 5, NULL, NULL),
	(11624, 198, 1, 8, 2, 1, 41, 6, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3610, 5, NULL, NULL),
	(11625, 198, 1, 8, 2, 2, 41, 6, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 2 tarifą , fiksuojama kas mėnesį', 3611, 5, NULL, NULL),
	(11626, 198, 1, 8, 2, 3, 41, 6, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3612, 5, NULL, NULL),
	(11627, 198, 1, 8, 2, 4, 41, 6, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3613, 5, NULL, NULL),
	(11628, 198, 2, 8, 2, 0, 41, 6, 210, NULL, 'Suminė W- energija L3 fazėje, fiksuojama kas mėnesį', 3614, 5, NULL, NULL),
	(11629, 198, 2, 8, 2, 1, 41, 6, 210, NULL, 'Suminė W- energija L3 fazėje pagal 1 tarifą, fiksuojama kas mėnesį', 3615, 5, NULL, NULL),
	(11630, 198, 2, 8, 2, 2, 41, 6, 210, NULL, 'Suminė W- energija L3 fazėje pagal 2 tarifą , fiksuojama kas mėnesį', 3616, 5, NULL, NULL),
	(11631, 198, 2, 8, 2, 3, 41, 6, 210, NULL, 'Suminė W- energija L3 fazėje pagal 3 tarifą, fiksuojama kas mėnesį', 3617, 5, NULL, NULL),
	(11632, 198, 2, 8, 2, 4, 41, 6, 210, NULL, 'Suminė W- energija L3 fazėje pagal 4 tarifą, fiksuojama kas mėnesį', 3618, 5, NULL, NULL),
	(11633, 189, 1, 8, 2, 0, 2, 5, 202, NULL, 'Suminė A+ energija L1 fazėje, fiksuojama kas parą', 3161, 5, NULL, NULL),
	(11634, 189, 1, 8, 2, 1, 2, 5, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 1 tarifą, fiksuojama kas parą', 3493, 5, NULL, NULL),
	(11635, 189, 1, 8, 2, 2, 2, 5, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 2 tarifą, fiksuojama kas parą', 3494, 5, NULL, NULL),
	(11636, 189, 1, 8, 2, 3, 2, 5, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 3 tarifą, fiksuojama kas parą', 3495, 5, NULL, NULL),
	(11637, 189, 1, 8, 2, 4, 2, 5, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 4 tarifą, fiksuojama kas parą', 3496, 5, NULL, NULL),
	(11638, 189, 2, 8, 2, 0, 2, 5, 202, NULL, 'Suminė A- energija L1 fazėje, fiksuojama kas parą', 3164, 5, NULL, NULL),
	(11639, 189, 2, 8, 2, 1, 2, 5, 202, NULL, 'Suminė A- energija L1 fazėje pagal 1 tarifą, fiksuojama kas parą', 3497, 5, NULL, NULL),
	(11640, 189, 2, 8, 2, 2, 2, 5, 202, NULL, 'Suminė A- energija L1 fazėje pagal 2 tarifą, fiksuojama kas parą', 3498, 5, NULL, NULL),
	(11641, 189, 2, 8, 2, 3, 2, 5, 202, NULL, 'Suminė A- energija L1 fazėje pagal 3 tarifą, fiksuojama kas parą', 3499, 5, NULL, NULL),
	(11642, 189, 2, 8, 2, 4, 2, 5, 202, NULL, 'Suminė A- energija L1 fazėje pagal 4 tarifą, fiksuojama kas parą', 3500, 5, NULL, NULL),
	(11643, 190, 1, 8, 2, 0, 2, 5, 203, NULL, 'Suminė A+ energija L2 fazėje, fiksuojama kas parą', 3162, 5, NULL, NULL),
	(11644, 190, 1, 8, 2, 1, 2, 5, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 1 tarifą, fiksuojama kas parą', 3535, 5, NULL, NULL),
	(11645, 190, 1, 8, 2, 2, 2, 5, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 2 tarifą, fiksuojama kas parą', 3536, 5, NULL, NULL),
	(11646, 190, 1, 8, 2, 3, 2, 5, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 3 tarifą, fiksuojama kas parą', 3537, 5, NULL, NULL),
	(11647, 190, 1, 8, 2, 4, 2, 5, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 4 tarifą, fiksuojama kas parą', 3538, 5, NULL, NULL),
	(11648, 190, 2, 8, 2, 0, 2, 5, 203, NULL, 'Suminė A- energija L2 fazėje, fiksuojama kas parą', 3165, 5, NULL, NULL),
	(11649, 190, 2, 8, 2, 1, 2, 5, 203, NULL, 'Suminė A- energija L2 fazėje pagal 1 tarifą, fiksuojama kas parą', 3539, 5, NULL, NULL),
	(11650, 190, 2, 8, 2, 2, 2, 5, 203, NULL, 'Suminė A- energija L2 fazėje pagal 2 tarifą, fiksuojama kas parą', 3540, 5, NULL, NULL),
	(11651, 190, 2, 8, 2, 3, 2, 5, 203, NULL, 'Suminė A- energija L2 fazėje pagal 3 tarifą, fiksuojama kas parą', 3541, 5, NULL, NULL),
	(11652, 190, 2, 8, 2, 4, 2, 5, 203, NULL, 'Suminė A- energija L2 fazėje pagal 4 tarifą, fiksuojama kas parą', 3542, 5, NULL, NULL),
	(11653, 191, 1, 8, 2, 0, 2, 5, 204, NULL, 'Suminė A+ energija L3 fazėje, fiksuojama kas parą', 3163, 5, NULL, NULL),
	(11654, 191, 1, 8, 2, 1, 2, 5, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 1 tarifą, fiksuojama kas parą', 3577, 5, NULL, NULL),
	(11655, 191, 1, 8, 2, 2, 2, 5, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 2 tarifą , fiksuojama kas parą', 3578, 5, NULL, NULL),
	(11656, 191, 1, 8, 2, 3, 2, 5, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 3 tarifą, fiksuojama kas parą', 3579, 5, NULL, NULL),
	(11657, 191, 1, 8, 2, 4, 2, 5, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 4 tarifą, fiksuojama kas parą', 3580, 5, NULL, NULL),
	(11658, 191, 2, 8, 2, 0, 2, 5, 204, NULL, 'Suminė A- energija L3 fazėje, fiksuojama kas parą', 3166, 5, NULL, NULL),
	(11659, 191, 2, 8, 2, 1, 2, 5, 204, NULL, 'Suminė A- energija L3 fazėje pagal 1 tarifą, fiksuojama kas parą', 3581, 5, NULL, NULL),
	(11660, 191, 2, 8, 2, 2, 2, 5, 204, NULL, 'Suminė A- energija L3 fazėje pagal 2 tarifą , fiksuojama kas parą', 3582, 5, NULL, NULL),
	(11661, 191, 2, 8, 2, 3, 2, 5, 204, NULL, 'Suminė A- energija L3 fazėje pagal 3 tarifą, fiksuojama kas parą', 3583, 5, NULL, NULL),
	(11662, 191, 2, 8, 2, 4, 2, 5, 204, NULL, 'Suminė A- energija L3 fazėje pagal 4 tarifą, fiksuojama kas parą', 3584, 5, NULL, NULL),
	(11663, 193, 1, 8, 2, 0, 4, 5, 205, NULL, 'Suminė R+ energija L1 fazėje, fiksuojama kas parą', 3167, 5, NULL, NULL),
	(11664, 193, 1, 8, 2, 1, 4, 5, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 1 tarifą, fiksuojama kas parą', 3501, 5, NULL, NULL),
	(11665, 193, 1, 8, 2, 2, 4, 5, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 2 tarifą, fiksuojama kas parą', 3502, 5, NULL, NULL),
	(11666, 193, 1, 8, 2, 3, 4, 5, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 3 tarifą, fiksuojama kas parą', 3503, 5, NULL, NULL),
	(11667, 193, 1, 8, 2, 4, 4, 5, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 4 tarifą, fiksuojama kas parą', 3504, 5, NULL, NULL),
	(11668, 193, 2, 8, 2, 0, 4, 5, 205, NULL, 'Suminė R- energija L1 fazėje, fiksuojama kas parą', 3170, 5, NULL, NULL),
	(11669, 193, 2, 8, 2, 1, 4, 5, 205, NULL, 'Suminė R- energija L1 fazėje pagal 1 tarifą, fiksuojama kas parą', 3505, 5, NULL, NULL),
	(11670, 193, 2, 8, 2, 2, 4, 5, 205, NULL, 'Suminė R- energija L1 fazėje pagal 2 tarifą, fiksuojama kas parą', 3506, 5, NULL, NULL),
	(11671, 193, 2, 8, 2, 3, 4, 5, 205, NULL, 'Suminė R- energija L1 fazėje pagal 3 tarifą, fiksuojama kas parą', 3507, 5, NULL, NULL),
	(11672, 193, 2, 8, 2, 4, 4, 5, 205, NULL, 'Suminė R- energija L1 fazėje pagal 4 tarifą, fiksuojama kas parą', 3508, 5, NULL, NULL),
	(11673, 193, 5, 8, 2, 0, 4, 5, 205, NULL, 'Suminė R1 energija L1 fazėje, fiksuojama kas parą', 3296, 5, NULL, NULL),
	(11674, 193, 5, 8, 2, 1, 4, 5, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 1 tarifą, fiksuojama kas parą', 3509, 5, NULL, NULL),
	(11675, 193, 5, 8, 2, 2, 4, 5, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 2 tarifą, fiksuojama kas parą', 3510, 5, NULL, NULL),
	(11676, 193, 5, 8, 2, 3, 4, 5, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 3 tarifą, fiksuojama kas parą', 3511, 5, NULL, NULL),
	(11677, 193, 5, 8, 2, 4, 4, 5, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 4 tarifą, fiksuojama kas parą', 3512, 5, NULL, NULL),
	(11678, 193, 6, 8, 2, 0, 4, 5, 205, NULL, 'Suminė R2 energija L1 fazėje, fiksuojama kas parą', 3299, 5, NULL, NULL),
	(11679, 193, 6, 8, 2, 1, 4, 5, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 1 tarifą, fiksuojama kas parą', 3513, 5, NULL, NULL),
	(11680, 193, 6, 8, 2, 2, 4, 5, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 2 tarifą, fiksuojama kas parą', 3514, 5, NULL, NULL),
	(11681, 193, 6, 8, 2, 3, 4, 5, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 3 tarifą, fiksuojama kas parą', 3515, 5, NULL, NULL),
	(11682, 193, 6, 8, 2, 4, 4, 5, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 4 tarifą, fiksuojama kas parą', 3516, 5, NULL, NULL),
	(11683, 193, 7, 8, 2, 0, 4, 5, 205, NULL, 'Suminė R3 energija L1 fazėje, fiksuojama kas parą', 3302, 5, NULL, NULL),
	(11684, 193, 7, 8, 2, 1, 4, 5, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 1 tarifą, fiksuojama kas parą', 3517, 5, NULL, NULL),
	(11685, 193, 7, 8, 2, 2, 4, 5, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 2 tarifą, fiksuojama kas parą', 3518, 5, NULL, NULL),
	(11686, 193, 7, 8, 2, 3, 4, 5, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 3 tarifą, fiksuojama kas parą', 3519, 5, NULL, NULL),
	(11687, 193, 7, 8, 2, 4, 4, 5, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 4 tarifą, fiksuojama kas parą', 3520, 5, NULL, NULL),
	(11688, 193, 8, 8, 2, 0, 4, 5, 205, NULL, 'Suminė R4 energija L1 fazėje, fiksuojama kas parą', 3305, 5, NULL, NULL),
	(11689, 193, 8, 8, 2, 1, 4, 5, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 1 tarifą, fiksuojama kas parą', 3521, 5, NULL, NULL),
	(11690, 193, 8, 8, 2, 2, 4, 5, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 2 tarifą, fiksuojama kas parą', 3522, 5, NULL, NULL),
	(11691, 193, 8, 8, 2, 3, 4, 5, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 3 tarifą, fiksuojama kas parą', 3523, 5, NULL, NULL),
	(11692, 193, 8, 8, 2, 4, 4, 5, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 4 tarifą, fiksuojama kas parą', 3524, 5, NULL, NULL),
	(11693, 194, 1, 8, 2, 0, 4, 5, 206, NULL, 'Suminė R+ energija L2 fazėje, fiksuojama kas parą', 3168, 5, NULL, NULL),
	(11694, 194, 1, 8, 2, 1, 4, 5, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 1 tarifą, fiksuojama kas parą', 3543, 5, NULL, NULL),
	(11695, 194, 1, 8, 2, 2, 4, 5, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 2 tarifą, fiksuojama kas parą', 3544, 5, NULL, NULL),
	(11696, 194, 1, 8, 2, 3, 4, 5, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 3 tarifą, fiksuojama kas parą', 3545, 5, NULL, NULL),
	(11697, 194, 1, 8, 2, 4, 4, 5, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 4 tarifą, fiksuojama kas parą', 3546, 5, NULL, NULL),
	(11698, 194, 2, 8, 2, 0, 4, 5, 206, NULL, 'Suminė R- energija L2 fazėje, fiksuojama kas parą', 3171, 5, NULL, NULL),
	(11699, 194, 2, 8, 2, 1, 4, 5, 206, NULL, 'Suminė R- energija L2 fazėje pagal 1 tarifą, fiksuojama kas parą', 3547, 5, NULL, NULL),
	(11700, 194, 2, 8, 2, 2, 4, 5, 206, NULL, 'Suminė R- energija L2 fazėje pagal 2 tarifą, fiksuojama kas parą', 3548, 5, NULL, NULL),
	(11701, 194, 2, 8, 2, 3, 4, 5, 206, NULL, 'Suminė R- energija L2 fazėje pagal 3 tarifą, fiksuojama kas parą', 3549, 5, NULL, NULL),
	(11702, 194, 2, 8, 2, 4, 4, 5, 206, NULL, 'Suminė R- energija L2 fazėje pagal 4 tarifą, fiksuojama kas parą', 3550, 5, NULL, NULL),
	(11703, 194, 5, 8, 2, 0, 4, 5, 206, NULL, 'Suminė R1 energija L2 fazėje, fiksuojama kas parą', 3297, 5, NULL, NULL),
	(11704, 194, 5, 8, 2, 1, 4, 5, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 1 tarifą, fiksuojama kas parą', 3551, 5, NULL, NULL),
	(11705, 194, 5, 8, 2, 2, 4, 5, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 2 tarifą, fiksuojama kas parą', 3552, 5, NULL, NULL),
	(11706, 194, 5, 8, 2, 3, 4, 5, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 3 tarifą, fiksuojama kas parą', 3553, 5, NULL, NULL),
	(11707, 194, 5, 8, 2, 4, 4, 5, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 4 tarifą, fiksuojama kas parą', 3554, 5, NULL, NULL),
	(11708, 194, 6, 8, 2, 0, 4, 5, 206, NULL, 'Suminė R2 energija L2 fazėje, fiksuojama kas parą', 3300, 5, NULL, NULL),
	(11709, 194, 6, 8, 2, 1, 4, 5, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 1 tarifą, fiksuojama kas parą', 3555, 5, NULL, NULL),
	(11710, 194, 6, 8, 2, 2, 4, 5, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 2 tarifą, fiksuojama kas parą', 3556, 5, NULL, NULL),
	(11711, 194, 6, 8, 2, 3, 4, 5, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 3 tarifą, fiksuojama kas parą', 3557, 5, NULL, NULL),
	(11712, 194, 6, 8, 2, 4, 4, 5, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 4 tarifą, fiksuojama kas parą', 3558, 5, NULL, NULL),
	(11713, 194, 7, 8, 2, 0, 4, 5, 206, NULL, 'Suminė R3 energija L2 fazėje, fiksuojama kas parą', 3303, 5, NULL, NULL),
	(11714, 194, 7, 8, 2, 1, 4, 5, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 1 tarifą, fiksuojama kas parą', 3559, 5, NULL, NULL),
	(11715, 194, 7, 8, 2, 2, 4, 5, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 2 tarifą, fiksuojama kas parą', 3560, 5, NULL, NULL),
	(11716, 194, 7, 8, 2, 3, 4, 5, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 3 tarifą, fiksuojama kas parą', 3561, 5, NULL, NULL),
	(11717, 194, 7, 8, 2, 4, 4, 5, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 4 tarifą, fiksuojama kas parą', 3562, 5, NULL, NULL),
	(11718, 194, 8, 8, 2, 0, 4, 5, 206, NULL, 'Suminė R4 energija L2 fazėje, fiksuojama kas parą', 3306, 5, NULL, NULL),
	(11719, 194, 8, 8, 2, 1, 4, 5, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 1 tarifą, fiksuojama kas parą', 3563, 5, NULL, NULL),
	(11720, 194, 8, 8, 2, 2, 4, 5, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 2 tarifą, fiksuojama kas parą', 3564, 5, NULL, NULL),
	(11721, 194, 8, 8, 2, 3, 4, 5, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 3 tarifą, fiksuojama kas parą', 3565, 5, NULL, NULL),
	(11722, 194, 8, 8, 2, 4, 4, 5, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 4 tarifą, fiksuojama kas parą', 3566, 5, NULL, NULL),
	(11723, 195, 1, 8, 2, 0, 4, 5, 207, NULL, 'Suminė R+ energija L3 fazėje, fiksuojama kas parą', 3169, 5, NULL, NULL),
	(11724, 195, 1, 8, 2, 1, 4, 5, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 1 tarifą, fiksuojama kas parą', 3585, 5, NULL, NULL),
	(11725, 195, 1, 8, 2, 2, 4, 5, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 2 tarifą , fiksuojama kas parą', 3586, 5, NULL, NULL),
	(11726, 195, 1, 8, 2, 3, 4, 5, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 3 tarifą, fiksuojama kas parą', 3587, 5, NULL, NULL),
	(11727, 195, 1, 8, 2, 4, 4, 5, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 4 tarifą, fiksuojama kas parą', 3588, 5, NULL, NULL),
	(11728, 195, 2, 8, 2, 0, 4, 5, 207, NULL, 'Suminė R- energija L3 fazėje, fiksuojama kas parą', 3172, 5, NULL, NULL),
	(11729, 195, 2, 8, 2, 1, 4, 5, 207, NULL, 'Suminė R- energija L3 fazėje pagal 1 tarifą, fiksuojama kas parą', 3589, 5, NULL, NULL),
	(11730, 195, 2, 8, 2, 2, 4, 5, 207, NULL, 'Suminė R- energija L3 fazėje pagal 2 tarifą , fiksuojama kas parą', 3590, 5, NULL, NULL),
	(11731, 195, 2, 8, 2, 3, 4, 5, 207, NULL, 'Suminė R- energija L3 fazėje pagal 3 tarifą, fiksuojama kas parą', 3591, 5, NULL, NULL),
	(11732, 195, 2, 8, 2, 4, 4, 5, 207, NULL, 'Suminė R- energija L3 fazėje pagal 4 tarifą, fiksuojama kas parą', 3592, 5, NULL, NULL),
	(11733, 195, 5, 8, 2, 0, 4, 5, 207, NULL, 'Suminė R1 energija L3 fazėje, fiksuojama kas parą', 3298, 5, NULL, NULL),
	(11734, 195, 5, 8, 2, 1, 4, 5, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 1 tarifą, fiksuojama kas parą', 3593, 5, NULL, NULL),
	(11735, 195, 5, 8, 2, 2, 4, 5, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 2 tarifą , fiksuojama kas parą', 3594, 5, NULL, NULL),
	(11736, 195, 5, 8, 2, 3, 4, 5, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 3 tarifą, fiksuojama kas parą', 3595, 5, NULL, NULL),
	(11737, 195, 5, 8, 2, 4, 4, 5, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 4 tarifą, fiksuojama kas parą', 3596, 5, NULL, NULL),
	(11738, 195, 6, 8, 2, 0, 4, 5, 207, NULL, 'Suminė R2 energija L3 fazėje, fiksuojama kas parą', 3301, 5, NULL, NULL),
	(11739, 195, 6, 8, 2, 1, 4, 5, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 1 tarifą, fiksuojama kas parą', 3597, 5, NULL, NULL),
	(11740, 195, 6, 8, 2, 2, 4, 5, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 2 tarifą , fiksuojama kas parą', 3598, 5, NULL, NULL),
	(11741, 195, 6, 8, 2, 3, 4, 5, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 3 tarifą, fiksuojama kas parą', 3599, 5, NULL, NULL),
	(11742, 195, 6, 8, 2, 4, 4, 5, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 4 tarifą, fiksuojama kas parą', 3600, 5, NULL, NULL),
	(11743, 195, 7, 8, 2, 0, 4, 5, 207, NULL, 'Suminė R3 energija L3 fazėje, fiksuojama kas parą', 3304, 5, NULL, NULL),
	(11744, 195, 7, 8, 2, 1, 4, 5, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 1 tarifą, fiksuojama kas parą', 3601, 5, NULL, NULL),
	(11745, 195, 7, 8, 2, 2, 4, 5, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 2 tarifą , fiksuojama kas parą', 3602, 5, NULL, NULL),
	(11746, 195, 7, 8, 2, 3, 4, 5, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 3 tarifą, fiksuojama kas parą', 3603, 5, NULL, NULL),
	(11747, 195, 7, 8, 2, 4, 4, 5, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 4 tarifą, fiksuojama kas parą', 3604, 5, NULL, NULL),
	(11748, 195, 8, 8, 2, 0, 4, 5, 207, NULL, 'Suminė R4 energija L3 fazėje, fiksuojama kas parą', 3307, 5, NULL, NULL),
	(11749, 195, 8, 8, 2, 1, 4, 5, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 1 tarifą, fiksuojama kas parą', 3605, 5, NULL, NULL),
	(11750, 195, 8, 8, 2, 2, 4, 5, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 2 tarifą , fiksuojama kas parą', 3606, 5, NULL, NULL),
	(11751, 195, 8, 8, 2, 3, 4, 5, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 3 tarifą, fiksuojama kas parą', 3607, 5, NULL, NULL),
	(11752, 195, 8, 8, 2, 4, 4, 5, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 4 tarifą, fiksuojama kas parą', 3608, 5, NULL, NULL),
	(11753, 196, 0, 8, 2, 0, 41, 5, 208, NULL, 'Suminė W energija L1 fazėje, fiksuojama kas parą', 3173, 5, NULL, NULL),
	(11754, 196, 1, 8, 2, 0, 41, 5, 208, NULL, 'Suminė W+ energija L1 fazėje, fiksuojama kas parą', 3525, 5, NULL, NULL),
	(11755, 196, 1, 8, 2, 1, 41, 5, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 1 tarifą, fiksuojama kas parą', 3526, 5, NULL, NULL),
	(11756, 196, 1, 8, 2, 2, 41, 5, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 2 tarifą, fiksuojama kas parą', 3527, 5, NULL, NULL),
	(11757, 196, 1, 8, 2, 3, 41, 5, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 3 tarifą, fiksuojama kas parą', 3528, 5, NULL, NULL),
	(11758, 196, 1, 8, 2, 4, 41, 5, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 4 tarifą, fiksuojama kas parą', 3529, 5, NULL, NULL),
	(11759, 196, 2, 8, 2, 0, 41, 5, 208, NULL, 'Suminė W- energija L1 fazėje, fiksuojama kas parą', 3530, 5, NULL, NULL),
	(11760, 196, 2, 8, 2, 1, 41, 5, 208, NULL, 'Suminė W- energija L1 fazėje pagal 1 tarifą, fiksuojama kas parą', 3531, 5, NULL, NULL),
	(11761, 196, 2, 8, 2, 2, 41, 5, 208, NULL, 'Suminė W- energija L1 fazėje pagal 2 tarifą, fiksuojama kas parą', 3532, 5, NULL, NULL),
	(11762, 196, 2, 8, 2, 3, 41, 5, 208, NULL, 'Suminė W- energija L1 fazėje pagal 3 tarifą, fiksuojama kas parą', 3533, 5, NULL, NULL),
	(11763, 196, 2, 8, 2, 4, 41, 5, 208, NULL, 'Suminė W- energija L1 fazėje pagal 4 tarifą, fiksuojama kas parą', 3534, 5, NULL, NULL),
	(11764, 197, 0, 8, 2, 0, 41, 5, 209, NULL, 'Suminė W energija L2 fazėje, fiksuojama kas parą', 3174, 5, NULL, NULL),
	(11765, 197, 1, 8, 2, 0, 41, 5, 209, NULL, 'Suminė W+ energija L2 fazėje, fiksuojama kas parą', 3567, 5, NULL, NULL),
	(11766, 197, 1, 8, 2, 1, 41, 5, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 1 tarifą, fiksuojama kas parą', 3568, 5, NULL, NULL),
	(11767, 197, 1, 8, 2, 2, 41, 5, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 2 tarifą , fiksuojama kas parą', 3569, 5, NULL, NULL),
	(11768, 197, 1, 8, 2, 3, 41, 5, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 3 tarifą, fiksuojama kas parą', 3570, 5, NULL, NULL),
	(11769, 197, 1, 8, 2, 4, 41, 5, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 4 tarifą, fiksuojama kas parą', 3571, 5, NULL, NULL),
	(11770, 197, 2, 8, 2, 0, 41, 5, 209, NULL, 'Suminė W- energija L2 fazėje, fiksuojama kas parą', 3572, 5, NULL, NULL),
	(11771, 197, 2, 8, 2, 1, 41, 5, 209, NULL, 'Suminė W- energija L2 fazėje pagal 1 tarifą, fiksuojama kas parą', 3573, 5, NULL, NULL),
	(11772, 197, 2, 8, 2, 2, 41, 5, 209, NULL, 'Suminė W- energija L2 fazėje pagal 2 tarifą , fiksuojama kas parą', 3574, 5, NULL, NULL),
	(11773, 197, 2, 8, 2, 3, 41, 5, 209, NULL, 'Suminė W- energija L2 fazėje pagal 3 tarifą, fiksuojama kas parą', 3575, 5, NULL, NULL),
	(11774, 197, 2, 8, 2, 4, 41, 5, 209, NULL, 'Suminė W- energija L2 fazėje pagal 4 tarifą, fiksuojama kas parą', 3576, 5, NULL, NULL),
	(11775, 198, 0, 8, 2, 0, 41, 5, 210, NULL, 'Suminė W energija L3 fazėje, fiksuojama kas parą', 3175, 5, NULL, NULL),
	(11776, 198, 1, 8, 2, 0, 41, 5, 210, NULL, 'Suminė W+ energija L3 fazėje, fiksuojama kas parą', 3609, 5, NULL, NULL),
	(11777, 198, 1, 8, 2, 1, 41, 5, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 1 tarifą, fiksuojama kas parą', 3610, 5, NULL, NULL),
	(11778, 198, 1, 8, 2, 2, 41, 5, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 2 tarifą , fiksuojama kas parą', 3611, 5, NULL, NULL),
	(11779, 198, 1, 8, 2, 3, 41, 5, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 3 tarifą, fiksuojama kas parą', 3612, 5, NULL, NULL),
	(11780, 198, 1, 8, 2, 4, 41, 5, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 4 tarifą, fiksuojama kas parą', 3613, 5, NULL, NULL),
	(11781, 198, 2, 8, 2, 0, 41, 5, 210, NULL, 'Suminė W- energija L3 fazėje, fiksuojama kas parą', 3614, 5, NULL, NULL),
	(11782, 198, 2, 8, 2, 1, 41, 5, 210, NULL, 'Suminė W- energija L3 fazėje pagal 1 tarifą, fiksuojama kas parą', 3615, 5, NULL, NULL),
	(11783, 198, 2, 8, 2, 2, 41, 5, 210, NULL, 'Suminė W- energija L3 fazėje pagal 2 tarifą , fiksuojama kas parą', 3616, 5, NULL, NULL),
	(11784, 198, 2, 8, 2, 3, 41, 5, 210, NULL, 'Suminė W- energija L3 fazėje pagal 3 tarifą, fiksuojama kas parą', 3617, 5, NULL, NULL),
	(11785, 198, 2, 8, 2, 4, 41, 5, 210, NULL, 'Suminė W- energija L3 fazėje pagal 4 tarifą, fiksuojama kas parą', 3618, 5, NULL, NULL),
	(11786, 189, 1, 8, 2, 0, 2, 4, 202, NULL, 'Suminė A+ energija L1 fazėje, fiksuojama kas valandą', 3161, 5, NULL, NULL),
	(11787, 189, 1, 8, 2, 1, 2, 4, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3493, 5, NULL, NULL),
	(11788, 189, 1, 8, 2, 2, 2, 4, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3494, 5, NULL, NULL),
	(11789, 189, 1, 8, 2, 3, 2, 4, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3495, 5, NULL, NULL),
	(11790, 189, 1, 8, 2, 4, 2, 4, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3496, 5, NULL, NULL),
	(11791, 189, 2, 8, 2, 0, 2, 4, 202, NULL, 'Suminė A- energija L1 fazėje, fiksuojama kas valandą', 3164, 5, NULL, NULL),
	(11792, 189, 2, 8, 2, 1, 2, 4, 202, NULL, 'Suminė A- energija L1 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3497, 5, NULL, NULL),
	(11793, 189, 2, 8, 2, 2, 2, 4, 202, NULL, 'Suminė A- energija L1 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3498, 5, NULL, NULL),
	(11794, 189, 2, 8, 2, 3, 2, 4, 202, NULL, 'Suminė A- energija L1 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3499, 5, NULL, NULL),
	(11795, 189, 2, 8, 2, 4, 2, 4, 202, NULL, 'Suminė A- energija L1 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3500, 5, NULL, NULL),
	(11796, 190, 1, 8, 2, 0, 2, 4, 203, NULL, 'Suminė A+ energija L2 fazėje, fiksuojama kas valandą', 3162, 5, NULL, NULL),
	(11797, 190, 1, 8, 2, 1, 2, 4, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3535, 5, NULL, NULL),
	(11798, 190, 1, 8, 2, 2, 2, 4, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3536, 5, NULL, NULL),
	(11799, 190, 1, 8, 2, 3, 2, 4, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3537, 5, NULL, NULL),
	(11800, 190, 1, 8, 2, 4, 2, 4, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3538, 5, NULL, NULL),
	(11801, 190, 2, 8, 2, 0, 2, 4, 203, NULL, 'Suminė A- energija L2 fazėje, fiksuojama kas valandą', 3165, 5, NULL, NULL),
	(11802, 190, 2, 8, 2, 1, 2, 4, 203, NULL, 'Suminė A- energija L2 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3539, 5, NULL, NULL),
	(11803, 190, 2, 8, 2, 2, 2, 4, 203, NULL, 'Suminė A- energija L2 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3540, 5, NULL, NULL),
	(11804, 190, 2, 8, 2, 3, 2, 4, 203, NULL, 'Suminė A- energija L2 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3541, 5, NULL, NULL),
	(11805, 190, 2, 8, 2, 4, 2, 4, 203, NULL, 'Suminė A- energija L2 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3542, 5, NULL, NULL),
	(11806, 191, 1, 8, 2, 0, 2, 4, 204, NULL, 'Suminė A+ energija L3 fazėje, fiksuojama kas valandą', 3163, 5, NULL, NULL),
	(11807, 191, 1, 8, 2, 1, 2, 4, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3577, 5, NULL, NULL),
	(11808, 191, 1, 8, 2, 2, 2, 4, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 2 tarifą , fiksuojama kas valandą', 3578, 5, NULL, NULL),
	(11809, 191, 1, 8, 2, 3, 2, 4, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3579, 5, NULL, NULL),
	(11810, 191, 1, 8, 2, 4, 2, 4, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3580, 5, NULL, NULL),
	(11811, 191, 2, 8, 2, 0, 2, 4, 204, NULL, 'Suminė A- energija L3 fazėje, fiksuojama kas valandą', 3166, 5, NULL, NULL),
	(11812, 191, 2, 8, 2, 1, 2, 4, 204, NULL, 'Suminė A- energija L3 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3581, 5, NULL, NULL),
	(11813, 191, 2, 8, 2, 2, 2, 4, 204, NULL, 'Suminė A- energija L3 fazėje pagal 2 tarifą , fiksuojama kas valandą', 3582, 5, NULL, NULL),
	(11814, 191, 2, 8, 2, 3, 2, 4, 204, NULL, 'Suminė A- energija L3 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3583, 5, NULL, NULL),
	(11815, 191, 2, 8, 2, 4, 2, 4, 204, NULL, 'Suminė A- energija L3 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3584, 5, NULL, NULL),
	(11816, 193, 1, 8, 2, 0, 4, 4, 205, NULL, 'Suminė R+ energija L1 fazėje, fiksuojama kas valandą', 3167, 5, NULL, NULL),
	(11817, 193, 1, 8, 2, 1, 4, 4, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3501, 5, NULL, NULL),
	(11818, 193, 1, 8, 2, 2, 4, 4, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3502, 5, NULL, NULL),
	(11819, 193, 1, 8, 2, 3, 4, 4, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3503, 5, NULL, NULL),
	(11820, 193, 1, 8, 2, 4, 4, 4, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3504, 5, NULL, NULL),
	(11821, 193, 2, 8, 2, 0, 4, 4, 205, NULL, 'Suminė R- energija L1 fazėje, fiksuojama kas valandą', 3170, 5, NULL, NULL),
	(11822, 193, 2, 8, 2, 1, 4, 4, 205, NULL, 'Suminė R- energija L1 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3505, 5, NULL, NULL),
	(11823, 193, 2, 8, 2, 2, 4, 4, 205, NULL, 'Suminė R- energija L1 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3506, 5, NULL, NULL),
	(11824, 193, 2, 8, 2, 3, 4, 4, 205, NULL, 'Suminė R- energija L1 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3507, 5, NULL, NULL),
	(11825, 193, 2, 8, 2, 4, 4, 4, 205, NULL, 'Suminė R- energija L1 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3508, 5, NULL, NULL),
	(11826, 193, 5, 8, 2, 0, 4, 4, 205, NULL, 'Suminė R1 energija L1 fazėje, fiksuojama kas valandą', 3296, 5, NULL, NULL),
	(11827, 193, 5, 8, 2, 1, 4, 4, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3509, 5, NULL, NULL),
	(11828, 193, 5, 8, 2, 2, 4, 4, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3510, 5, NULL, NULL),
	(11829, 193, 5, 8, 2, 3, 4, 4, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3511, 5, NULL, NULL),
	(11830, 193, 5, 8, 2, 4, 4, 4, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3512, 5, NULL, NULL),
	(11831, 193, 6, 8, 2, 0, 4, 4, 205, NULL, 'Suminė R2 energija L1 fazėje, fiksuojama kas valandą', 3299, 5, NULL, NULL),
	(11832, 193, 6, 8, 2, 1, 4, 4, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3513, 5, NULL, NULL),
	(11833, 193, 6, 8, 2, 2, 4, 4, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3514, 5, NULL, NULL),
	(11834, 193, 6, 8, 2, 3, 4, 4, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3515, 5, NULL, NULL),
	(11835, 193, 6, 8, 2, 4, 4, 4, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3516, 5, NULL, NULL),
	(11836, 193, 7, 8, 2, 0, 4, 4, 205, NULL, 'Suminė R3 energija L1 fazėje, fiksuojama kas valandą', 3302, 5, NULL, NULL),
	(11837, 193, 7, 8, 2, 1, 4, 4, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3517, 5, NULL, NULL),
	(11838, 193, 7, 8, 2, 2, 4, 4, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3518, 5, NULL, NULL),
	(11839, 193, 7, 8, 2, 3, 4, 4, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3519, 5, NULL, NULL),
	(11840, 193, 7, 8, 2, 4, 4, 4, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3520, 5, NULL, NULL),
	(11841, 193, 8, 8, 2, 0, 4, 4, 205, NULL, 'Suminė R4 energija L1 fazėje, fiksuojama kas valandą', 3305, 5, NULL, NULL),
	(11842, 193, 8, 8, 2, 1, 4, 4, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3521, 5, NULL, NULL),
	(11843, 193, 8, 8, 2, 2, 4, 4, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3522, 5, NULL, NULL),
	(11844, 193, 8, 8, 2, 3, 4, 4, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3523, 5, NULL, NULL),
	(11845, 193, 8, 8, 2, 4, 4, 4, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3524, 5, NULL, NULL),
	(11846, 194, 1, 8, 2, 0, 4, 4, 206, NULL, 'Suminė R+ energija L2 fazėje, fiksuojama kas valandą', 3168, 5, NULL, NULL),
	(11847, 194, 1, 8, 2, 1, 4, 4, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3543, 5, NULL, NULL),
	(11848, 194, 1, 8, 2, 2, 4, 4, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3544, 5, NULL, NULL),
	(11849, 194, 1, 8, 2, 3, 4, 4, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3545, 5, NULL, NULL),
	(11850, 194, 1, 8, 2, 4, 4, 4, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3546, 5, NULL, NULL),
	(11851, 194, 2, 8, 2, 0, 4, 4, 206, NULL, 'Suminė R- energija L2 fazėje, fiksuojama kas valandą', 3171, 5, NULL, NULL),
	(11852, 194, 2, 8, 2, 1, 4, 4, 206, NULL, 'Suminė R- energija L2 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3547, 5, NULL, NULL),
	(11853, 194, 2, 8, 2, 2, 4, 4, 206, NULL, 'Suminė R- energija L2 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3548, 5, NULL, NULL),
	(11854, 194, 2, 8, 2, 3, 4, 4, 206, NULL, 'Suminė R- energija L2 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3549, 5, NULL, NULL),
	(11855, 194, 2, 8, 2, 4, 4, 4, 206, NULL, 'Suminė R- energija L2 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3550, 5, NULL, NULL),
	(11856, 194, 5, 8, 2, 0, 4, 4, 206, NULL, 'Suminė R1 energija L2 fazėje, fiksuojama kas valandą', 3297, 5, NULL, NULL),
	(11857, 194, 5, 8, 2, 1, 4, 4, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3551, 5, NULL, NULL),
	(11858, 194, 5, 8, 2, 2, 4, 4, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3552, 5, NULL, NULL),
	(11859, 194, 5, 8, 2, 3, 4, 4, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3553, 5, NULL, NULL),
	(11860, 194, 5, 8, 2, 4, 4, 4, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3554, 5, NULL, NULL),
	(11861, 194, 6, 8, 2, 0, 4, 4, 206, NULL, 'Suminė R2 energija L2 fazėje, fiksuojama kas valandą', 3300, 5, NULL, NULL),
	(11862, 194, 6, 8, 2, 1, 4, 4, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3555, 5, NULL, NULL),
	(11863, 194, 6, 8, 2, 2, 4, 4, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3556, 5, NULL, NULL),
	(11864, 194, 6, 8, 2, 3, 4, 4, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3557, 5, NULL, NULL),
	(11865, 194, 6, 8, 2, 4, 4, 4, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3558, 5, NULL, NULL),
	(11866, 194, 7, 8, 2, 0, 4, 4, 206, NULL, 'Suminė R3 energija L2 fazėje, fiksuojama kas valandą', 3303, 5, NULL, NULL),
	(11867, 194, 7, 8, 2, 1, 4, 4, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3559, 5, NULL, NULL),
	(11868, 194, 7, 8, 2, 2, 4, 4, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3560, 5, NULL, NULL),
	(11869, 194, 7, 8, 2, 3, 4, 4, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3561, 5, NULL, NULL),
	(11870, 194, 7, 8, 2, 4, 4, 4, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3562, 5, NULL, NULL),
	(11871, 194, 8, 8, 2, 0, 4, 4, 206, NULL, 'Suminė R4 energija L2 fazėje, fiksuojama kas valandą', 3306, 5, NULL, NULL),
	(11872, 194, 8, 8, 2, 1, 4, 4, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3563, 5, NULL, NULL),
	(11873, 194, 8, 8, 2, 2, 4, 4, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3564, 5, NULL, NULL),
	(11874, 194, 8, 8, 2, 3, 4, 4, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3565, 5, NULL, NULL),
	(11875, 194, 8, 8, 2, 4, 4, 4, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3566, 5, NULL, NULL),
	(11876, 195, 1, 8, 2, 0, 4, 4, 207, NULL, 'Suminė R+ energija L3 fazėje, fiksuojama kas valandą', 3169, 5, NULL, NULL),
	(11877, 195, 1, 8, 2, 1, 4, 4, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3585, 5, NULL, NULL),
	(11878, 195, 1, 8, 2, 2, 4, 4, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 2 tarifą , fiksuojama kas valandą', 3586, 5, NULL, NULL),
	(11879, 195, 1, 8, 2, 3, 4, 4, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3587, 5, NULL, NULL),
	(11880, 195, 1, 8, 2, 4, 4, 4, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3588, 5, NULL, NULL),
	(11881, 195, 2, 8, 2, 0, 4, 4, 207, NULL, 'Suminė R- energija L3 fazėje, fiksuojama kas valandą', 3172, 5, NULL, NULL),
	(11882, 195, 2, 8, 2, 1, 4, 4, 207, NULL, 'Suminė R- energija L3 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3589, 5, NULL, NULL),
	(11883, 195, 2, 8, 2, 2, 4, 4, 207, NULL, 'Suminė R- energija L3 fazėje pagal 2 tarifą , fiksuojama kas valandą', 3590, 5, NULL, NULL),
	(11884, 195, 2, 8, 2, 3, 4, 4, 207, NULL, 'Suminė R- energija L3 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3591, 5, NULL, NULL),
	(11885, 195, 2, 8, 2, 4, 4, 4, 207, NULL, 'Suminė R- energija L3 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3592, 5, NULL, NULL),
	(11886, 195, 5, 8, 2, 0, 4, 4, 207, NULL, 'Suminė R1 energija L3 fazėje, fiksuojama kas valandą', 3298, 5, NULL, NULL),
	(11887, 195, 5, 8, 2, 1, 4, 4, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3593, 5, NULL, NULL),
	(11888, 195, 5, 8, 2, 2, 4, 4, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 2 tarifą , fiksuojama kas valandą', 3594, 5, NULL, NULL),
	(11889, 195, 5, 8, 2, 3, 4, 4, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3595, 5, NULL, NULL),
	(11890, 195, 5, 8, 2, 4, 4, 4, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3596, 5, NULL, NULL),
	(11891, 195, 6, 8, 2, 0, 4, 4, 207, NULL, 'Suminė R2 energija L3 fazėje, fiksuojama kas valandą', 3301, 5, NULL, NULL),
	(11892, 195, 6, 8, 2, 1, 4, 4, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3597, 5, NULL, NULL),
	(11893, 195, 6, 8, 2, 2, 4, 4, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 2 tarifą , fiksuojama kas valandą', 3598, 5, NULL, NULL),
	(11894, 195, 6, 8, 2, 3, 4, 4, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3599, 5, NULL, NULL),
	(11895, 195, 6, 8, 2, 4, 4, 4, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3600, 5, NULL, NULL),
	(11896, 195, 7, 8, 2, 0, 4, 4, 207, NULL, 'Suminė R3 energija L3 fazėje, fiksuojama kas valandą', 3304, 5, NULL, NULL),
	(11897, 195, 7, 8, 2, 1, 4, 4, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3601, 5, NULL, NULL),
	(11898, 195, 7, 8, 2, 2, 4, 4, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 2 tarifą , fiksuojama kas valandą', 3602, 5, NULL, NULL),
	(11899, 195, 7, 8, 2, 3, 4, 4, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3603, 5, NULL, NULL),
	(11900, 195, 7, 8, 2, 4, 4, 4, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3604, 5, NULL, NULL),
	(11901, 195, 8, 8, 2, 0, 4, 4, 207, NULL, 'Suminė R4 energija L3 fazėje, fiksuojama kas valandą', 3307, 5, NULL, NULL),
	(11902, 195, 8, 8, 2, 1, 4, 4, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3605, 5, NULL, NULL),
	(11903, 195, 8, 8, 2, 2, 4, 4, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 2 tarifą , fiksuojama kas valandą', 3606, 5, NULL, NULL),
	(11904, 195, 8, 8, 2, 3, 4, 4, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3607, 5, NULL, NULL),
	(11905, 195, 8, 8, 2, 4, 4, 4, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3608, 5, NULL, NULL),
	(11906, 196, 0, 8, 2, 0, 41, 4, 208, NULL, 'Suminė W energija L1 fazėje, fiksuojama kas valandą', 3173, 5, NULL, NULL),
	(11907, 196, 1, 8, 2, 0, 41, 4, 208, NULL, 'Suminė W+ energija L1 fazėje, fiksuojama kas valandą', 3525, 5, NULL, NULL),
	(11908, 196, 1, 8, 2, 1, 41, 4, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3526, 5, NULL, NULL),
	(11909, 196, 1, 8, 2, 2, 41, 4, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3527, 5, NULL, NULL),
	(11910, 196, 1, 8, 2, 3, 41, 4, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3528, 5, NULL, NULL),
	(11911, 196, 1, 8, 2, 4, 41, 4, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3529, 5, NULL, NULL),
	(11912, 196, 2, 8, 2, 0, 41, 4, 208, NULL, 'Suminė W- energija L1 fazėje, fiksuojama kas valandą', 3530, 5, NULL, NULL),
	(11913, 196, 2, 8, 2, 1, 41, 4, 208, NULL, 'Suminė W- energija L1 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3531, 5, NULL, NULL),
	(11914, 196, 2, 8, 2, 2, 41, 4, 208, NULL, 'Suminė W- energija L1 fazėje pagal 2 tarifą, fiksuojama kas valandą', 3532, 5, NULL, NULL),
	(11915, 196, 2, 8, 2, 3, 41, 4, 208, NULL, 'Suminė W- energija L1 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3533, 5, NULL, NULL),
	(11916, 196, 2, 8, 2, 4, 41, 4, 208, NULL, 'Suminė W- energija L1 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3534, 5, NULL, NULL),
	(11917, 197, 0, 8, 2, 0, 41, 4, 209, NULL, 'Suminė W energija L2 fazėje, fiksuojama kas valandą', 3174, 5, NULL, NULL),
	(11918, 197, 1, 8, 2, 0, 41, 4, 209, NULL, 'Suminė W+ energija L2 fazėje, fiksuojama kas valandą', 3567, 5, NULL, NULL),
	(11919, 197, 1, 8, 2, 1, 41, 4, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3568, 5, NULL, NULL),
	(11920, 197, 1, 8, 2, 2, 41, 4, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 2 tarifą , fiksuojama kas valandą', 3569, 5, NULL, NULL),
	(11921, 197, 1, 8, 2, 3, 41, 4, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3570, 5, NULL, NULL),
	(11922, 197, 1, 8, 2, 4, 41, 4, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3571, 5, NULL, NULL),
	(11923, 197, 2, 8, 2, 0, 41, 4, 209, NULL, 'Suminė W- energija L2 fazėje, fiksuojama kas valandą', 3572, 5, NULL, NULL),
	(11924, 197, 2, 8, 2, 1, 41, 4, 209, NULL, 'Suminė W- energija L2 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3573, 5, NULL, NULL),
	(11925, 197, 2, 8, 2, 2, 41, 4, 209, NULL, 'Suminė W- energija L2 fazėje pagal 2 tarifą , fiksuojama kas valandą', 3574, 5, NULL, NULL),
	(11926, 197, 2, 8, 2, 3, 41, 4, 209, NULL, 'Suminė W- energija L2 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3575, 5, NULL, NULL),
	(11927, 197, 2, 8, 2, 4, 41, 4, 209, NULL, 'Suminė W- energija L2 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3576, 5, NULL, NULL),
	(11928, 198, 0, 8, 2, 0, 41, 4, 210, NULL, 'Suminė W energija L3 fazėje, fiksuojama kas valandą', 3175, 5, NULL, NULL),
	(11929, 198, 1, 8, 2, 0, 41, 4, 210, NULL, 'Suminė W+ energija L3 fazėje, fiksuojama kas valandą', 3609, 5, NULL, NULL),
	(11930, 198, 1, 8, 2, 1, 41, 4, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3610, 5, NULL, NULL),
	(11931, 198, 1, 8, 2, 2, 41, 4, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 2 tarifą , fiksuojama kas valandą', 3611, 5, NULL, NULL),
	(11932, 198, 1, 8, 2, 3, 41, 4, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3612, 5, NULL, NULL),
	(11933, 198, 1, 8, 2, 4, 41, 4, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3613, 5, NULL, NULL),
	(11934, 198, 2, 8, 2, 0, 41, 4, 210, NULL, 'Suminė W- energija L3 fazėje, fiksuojama kas valandą', 3614, 5, NULL, NULL),
	(11935, 198, 2, 8, 2, 1, 41, 4, 210, NULL, 'Suminė W- energija L3 fazėje pagal 1 tarifą, fiksuojama kas valandą', 3615, 5, NULL, NULL),
	(11936, 198, 2, 8, 2, 2, 41, 4, 210, NULL, 'Suminė W- energija L3 fazėje pagal 2 tarifą , fiksuojama kas valandą', 3616, 5, NULL, NULL),
	(11937, 198, 2, 8, 2, 3, 41, 4, 210, NULL, 'Suminė W- energija L3 fazėje pagal 3 tarifą, fiksuojama kas valandą', 3617, 5, NULL, NULL),
	(11938, 198, 2, 8, 2, 4, 41, 4, 210, NULL, 'Suminė W- energija L3 fazėje pagal 4 tarifą, fiksuojama kas valandą', 3618, 5, NULL, NULL),
	(11939, 189, 1, 8, 2, 0, 2, 12, 202, NULL, 'Suminė A+ energija L1 fazėje, fiksuojama kas 15 minučių', 3161, 5, NULL, NULL),
	(11940, 189, 1, 8, 2, 1, 2, 12, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3493, 5, NULL, NULL),
	(11941, 189, 1, 8, 2, 2, 2, 12, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3494, 5, NULL, NULL),
	(11942, 189, 1, 8, 2, 3, 2, 12, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3495, 5, NULL, NULL),
	(11943, 189, 1, 8, 2, 4, 2, 12, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3496, 5, NULL, NULL),
	(11944, 189, 2, 8, 2, 0, 2, 12, 202, NULL, 'Suminė A- energija L1 fazėje, fiksuojama kas 15 minučių', 3164, 5, NULL, NULL),
	(11945, 189, 2, 8, 2, 1, 2, 12, 202, NULL, 'Suminė A- energija L1 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3497, 5, NULL, NULL),
	(11946, 189, 2, 8, 2, 2, 2, 12, 202, NULL, 'Suminė A- energija L1 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3498, 5, NULL, NULL),
	(11947, 189, 2, 8, 2, 3, 2, 12, 202, NULL, 'Suminė A- energija L1 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3499, 5, NULL, NULL),
	(11948, 189, 2, 8, 2, 4, 2, 12, 202, NULL, 'Suminė A- energija L1 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3500, 5, NULL, NULL),
	(11949, 190, 1, 8, 2, 0, 2, 12, 203, NULL, 'Suminė A+ energija L2 fazėje, fiksuojama kas 15 minučių', 3162, 5, NULL, NULL),
	(11950, 190, 1, 8, 2, 1, 2, 12, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3535, 5, NULL, NULL),
	(11951, 190, 1, 8, 2, 2, 2, 12, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3536, 5, NULL, NULL),
	(11952, 190, 1, 8, 2, 3, 2, 12, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3537, 5, NULL, NULL),
	(11953, 190, 1, 8, 2, 4, 2, 12, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3538, 5, NULL, NULL),
	(11954, 190, 2, 8, 2, 0, 2, 12, 203, NULL, 'Suminė A- energija L2 fazėje, fiksuojama kas 15 minučių', 3165, 5, NULL, NULL),
	(11955, 190, 2, 8, 2, 1, 2, 12, 203, NULL, 'Suminė A- energija L2 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3539, 5, NULL, NULL),
	(11956, 190, 2, 8, 2, 2, 2, 12, 203, NULL, 'Suminė A- energija L2 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3540, 5, NULL, NULL),
	(11957, 190, 2, 8, 2, 3, 2, 12, 203, NULL, 'Suminė A- energija L2 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3541, 5, NULL, NULL),
	(11958, 190, 2, 8, 2, 4, 2, 12, 203, NULL, 'Suminė A- energija L2 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3542, 5, NULL, NULL),
	(11959, 191, 1, 8, 2, 0, 2, 12, 204, NULL, 'Suminė A+ energija L3 fazėje, fiksuojama kas 15 minučių', 3163, 5, NULL, NULL),
	(11960, 191, 1, 8, 2, 1, 2, 12, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3577, 5, NULL, NULL),
	(11961, 191, 1, 8, 2, 2, 2, 12, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 2 tarifą , fiksuojama kas 15 minučių', 3578, 5, NULL, NULL),
	(11962, 191, 1, 8, 2, 3, 2, 12, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3579, 5, NULL, NULL),
	(11963, 191, 1, 8, 2, 4, 2, 12, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3580, 5, NULL, NULL),
	(11964, 191, 2, 8, 2, 0, 2, 12, 204, NULL, 'Suminė A- energija L3 fazėje, fiksuojama kas 15 minučių', 3166, 5, NULL, NULL),
	(11965, 191, 2, 8, 2, 1, 2, 12, 204, NULL, 'Suminė A- energija L3 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3581, 5, NULL, NULL),
	(11966, 191, 2, 8, 2, 2, 2, 12, 204, NULL, 'Suminė A- energija L3 fazėje pagal 2 tarifą , fiksuojama kas 15 minučių', 3582, 5, NULL, NULL),
	(11967, 191, 2, 8, 2, 3, 2, 12, 204, NULL, 'Suminė A- energija L3 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3583, 5, NULL, NULL),
	(11968, 191, 2, 8, 2, 4, 2, 12, 204, NULL, 'Suminė A- energija L3 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3584, 5, NULL, NULL),
	(11969, 193, 1, 8, 2, 0, 4, 12, 205, NULL, 'Suminė R+ energija L1 fazėje, fiksuojama kas 15 minučių', 3167, 5, NULL, NULL),
	(11970, 193, 1, 8, 2, 1, 4, 12, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3501, 5, NULL, NULL),
	(11971, 193, 1, 8, 2, 2, 4, 12, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3502, 5, NULL, NULL),
	(11972, 193, 1, 8, 2, 3, 4, 12, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3503, 5, NULL, NULL),
	(11973, 193, 1, 8, 2, 4, 4, 12, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3504, 5, NULL, NULL),
	(11974, 193, 2, 8, 2, 0, 4, 12, 205, NULL, 'Suminė R- energija L1 fazėje, fiksuojama kas 15 minučių', 3170, 5, NULL, NULL),
	(11975, 193, 2, 8, 2, 1, 4, 12, 205, NULL, 'Suminė R- energija L1 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3505, 5, NULL, NULL),
	(11976, 193, 2, 8, 2, 2, 4, 12, 205, NULL, 'Suminė R- energija L1 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3506, 5, NULL, NULL),
	(11977, 193, 2, 8, 2, 3, 4, 12, 205, NULL, 'Suminė R- energija L1 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3507, 5, NULL, NULL),
	(11978, 193, 2, 8, 2, 4, 4, 12, 205, NULL, 'Suminė R- energija L1 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3508, 5, NULL, NULL),
	(11979, 193, 5, 8, 2, 0, 4, 12, 205, NULL, 'Suminė R1 energija L1 fazėje, fiksuojama kas 15 minučių', 3296, 5, NULL, NULL),
	(11980, 193, 5, 8, 2, 1, 4, 12, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3509, 5, NULL, NULL),
	(11981, 193, 5, 8, 2, 2, 4, 12, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3510, 5, NULL, NULL),
	(11982, 193, 5, 8, 2, 3, 4, 12, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3511, 5, NULL, NULL),
	(11983, 193, 5, 8, 2, 4, 4, 12, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3512, 5, NULL, NULL),
	(11984, 193, 6, 8, 2, 0, 4, 12, 205, NULL, 'Suminė R2 energija L1 fazėje, fiksuojama kas 15 minučių', 3299, 5, NULL, NULL),
	(11985, 193, 6, 8, 2, 1, 4, 12, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3513, 5, NULL, NULL),
	(11986, 193, 6, 8, 2, 2, 4, 12, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3514, 5, NULL, NULL),
	(11987, 193, 6, 8, 2, 3, 4, 12, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3515, 5, NULL, NULL),
	(11988, 193, 6, 8, 2, 4, 4, 12, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3516, 5, NULL, NULL),
	(11989, 193, 7, 8, 2, 0, 4, 12, 205, NULL, 'Suminė R3 energija L1 fazėje, fiksuojama kas 15 minučių', 3302, 5, NULL, NULL),
	(11990, 193, 7, 8, 2, 1, 4, 12, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3517, 5, NULL, NULL),
	(11991, 193, 7, 8, 2, 2, 4, 12, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3518, 5, NULL, NULL),
	(11992, 193, 7, 8, 2, 3, 4, 12, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3519, 5, NULL, NULL),
	(11993, 193, 7, 8, 2, 4, 4, 12, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3520, 5, NULL, NULL),
	(11994, 193, 8, 8, 2, 0, 4, 12, 205, NULL, 'Suminė R4 energija L1 fazėje, fiksuojama kas 15 minučių', 3305, 5, NULL, NULL),
	(11995, 193, 8, 8, 2, 1, 4, 12, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3521, 5, NULL, NULL),
	(11996, 193, 8, 8, 2, 2, 4, 12, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3522, 5, NULL, NULL),
	(11997, 193, 8, 8, 2, 3, 4, 12, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3523, 5, NULL, NULL),
	(11998, 193, 8, 8, 2, 4, 4, 12, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3524, 5, NULL, NULL),
	(11999, 194, 1, 8, 2, 0, 4, 12, 206, NULL, 'Suminė R+ energija L2 fazėje, fiksuojama kas 15 minučių', 3168, 5, NULL, NULL),
	(12000, 194, 1, 8, 2, 1, 4, 12, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3543, 5, NULL, NULL),
	(12001, 194, 1, 8, 2, 2, 4, 12, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3544, 5, NULL, NULL),
	(12002, 194, 1, 8, 2, 3, 4, 12, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3545, 5, NULL, NULL),
	(12003, 194, 1, 8, 2, 4, 4, 12, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3546, 5, NULL, NULL),
	(12004, 194, 2, 8, 2, 0, 4, 12, 206, NULL, 'Suminė R- energija L2 fazėje, fiksuojama kas 15 minučių', 3171, 5, NULL, NULL),
	(12005, 194, 2, 8, 2, 1, 4, 12, 206, NULL, 'Suminė R- energija L2 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3547, 5, NULL, NULL),
	(12006, 194, 2, 8, 2, 2, 4, 12, 206, NULL, 'Suminė R- energija L2 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3548, 5, NULL, NULL),
	(12007, 194, 2, 8, 2, 3, 4, 12, 206, NULL, 'Suminė R- energija L2 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3549, 5, NULL, NULL),
	(12008, 194, 2, 8, 2, 4, 4, 12, 206, NULL, 'Suminė R- energija L2 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3550, 5, NULL, NULL),
	(12009, 194, 5, 8, 2, 0, 4, 12, 206, NULL, 'Suminė R1 energija L2 fazėje, fiksuojama kas 15 minučių', 3297, 5, NULL, NULL),
	(12010, 194, 5, 8, 2, 1, 4, 12, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3551, 5, NULL, NULL),
	(12011, 194, 5, 8, 2, 2, 4, 12, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3552, 5, NULL, NULL),
	(12012, 194, 5, 8, 2, 3, 4, 12, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3553, 5, NULL, NULL),
	(12013, 194, 5, 8, 2, 4, 4, 12, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3554, 5, NULL, NULL),
	(12014, 194, 6, 8, 2, 0, 4, 12, 206, NULL, 'Suminė R2 energija L2 fazėje, fiksuojama kas 15 minučių', 3300, 5, NULL, NULL),
	(12015, 194, 6, 8, 2, 1, 4, 12, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3555, 5, NULL, NULL),
	(12016, 194, 6, 8, 2, 2, 4, 12, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3556, 5, NULL, NULL),
	(12017, 194, 6, 8, 2, 3, 4, 12, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3557, 5, NULL, NULL),
	(12018, 194, 6, 8, 2, 4, 4, 12, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3558, 5, NULL, NULL),
	(12019, 194, 7, 8, 2, 0, 4, 12, 206, NULL, 'Suminė R3 energija L2 fazėje, fiksuojama kas 15 minučių', 3303, 5, NULL, NULL),
	(12020, 194, 7, 8, 2, 1, 4, 12, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3559, 5, NULL, NULL),
	(12021, 194, 7, 8, 2, 2, 4, 12, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3560, 5, NULL, NULL),
	(12022, 194, 7, 8, 2, 3, 4, 12, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3561, 5, NULL, NULL),
	(12023, 194, 7, 8, 2, 4, 4, 12, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3562, 5, NULL, NULL),
	(12024, 194, 8, 8, 2, 0, 4, 12, 206, NULL, 'Suminė R4 energija L2 fazėje, fiksuojama kas 15 minučių', 3306, 5, NULL, NULL),
	(12025, 194, 8, 8, 2, 1, 4, 12, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3563, 5, NULL, NULL),
	(12026, 194, 8, 8, 2, 2, 4, 12, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3564, 5, NULL, NULL),
	(12027, 194, 8, 8, 2, 3, 4, 12, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3565, 5, NULL, NULL),
	(12028, 194, 8, 8, 2, 4, 4, 12, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3566, 5, NULL, NULL),
	(12029, 195, 1, 8, 2, 0, 4, 12, 207, NULL, 'Suminė R+ energija L3 fazėje, fiksuojama kas 15 minučių', 3169, 5, NULL, NULL),
	(12030, 195, 1, 8, 2, 1, 4, 12, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3585, 5, NULL, NULL),
	(12031, 195, 1, 8, 2, 2, 4, 12, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 2 tarifą , fiksuojama kas 15 minučių', 3586, 5, NULL, NULL),
	(12032, 195, 1, 8, 2, 3, 4, 12, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3587, 5, NULL, NULL),
	(12033, 195, 1, 8, 2, 4, 4, 12, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3588, 5, NULL, NULL),
	(12034, 195, 2, 8, 2, 0, 4, 12, 207, NULL, 'Suminė R- energija L3 fazėje, fiksuojama kas 15 minučių', 3172, 5, NULL, NULL),
	(12035, 195, 2, 8, 2, 1, 4, 12, 207, NULL, 'Suminė R- energija L3 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3589, 5, NULL, NULL),
	(12036, 195, 2, 8, 2, 2, 4, 12, 207, NULL, 'Suminė R- energija L3 fazėje pagal 2 tarifą , fiksuojama kas 15 minučių', 3590, 5, NULL, NULL),
	(12037, 195, 2, 8, 2, 3, 4, 12, 207, NULL, 'Suminė R- energija L3 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3591, 5, NULL, NULL),
	(12038, 195, 2, 8, 2, 4, 4, 12, 207, NULL, 'Suminė R- energija L3 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3592, 5, NULL, NULL),
	(12039, 195, 5, 8, 2, 0, 4, 12, 207, NULL, 'Suminė R1 energija L3 fazėje, fiksuojama kas 15 minučių', 3298, 5, NULL, NULL),
	(12040, 195, 5, 8, 2, 1, 4, 12, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3593, 5, NULL, NULL),
	(12041, 195, 5, 8, 2, 2, 4, 12, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 2 tarifą , fiksuojama kas 15 minučių', 3594, 5, NULL, NULL),
	(12042, 195, 5, 8, 2, 3, 4, 12, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3595, 5, NULL, NULL),
	(12043, 195, 5, 8, 2, 4, 4, 12, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3596, 5, NULL, NULL),
	(12044, 195, 6, 8, 2, 0, 4, 12, 207, NULL, 'Suminė R2 energija L3 fazėje, fiksuojama kas 15 minučių', 3301, 5, NULL, NULL),
	(12045, 195, 6, 8, 2, 1, 4, 12, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3597, 5, NULL, NULL),
	(12046, 195, 6, 8, 2, 2, 4, 12, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 2 tarifą , fiksuojama kas 15 minučių', 3598, 5, NULL, NULL),
	(12047, 195, 6, 8, 2, 3, 4, 12, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3599, 5, NULL, NULL),
	(12048, 195, 6, 8, 2, 4, 4, 12, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3600, 5, NULL, NULL),
	(12049, 195, 7, 8, 2, 0, 4, 12, 207, NULL, 'Suminė R3 energija L3 fazėje, fiksuojama kas 15 minučių', 3304, 5, NULL, NULL),
	(12050, 195, 7, 8, 2, 1, 4, 12, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3601, 5, NULL, NULL),
	(12051, 195, 7, 8, 2, 2, 4, 12, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 2 tarifą , fiksuojama kas 15 minučių', 3602, 5, NULL, NULL),
	(12052, 195, 7, 8, 2, 3, 4, 12, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3603, 5, NULL, NULL),
	(12053, 195, 7, 8, 2, 4, 4, 12, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3604, 5, NULL, NULL),
	(12054, 195, 8, 8, 2, 0, 4, 12, 207, NULL, 'Suminė R4 energija L3 fazėje, fiksuojama kas 15 minučių', 3307, 5, NULL, NULL),
	(12055, 195, 8, 8, 2, 1, 4, 12, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3605, 5, NULL, NULL),
	(12056, 195, 8, 8, 2, 2, 4, 12, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 2 tarifą , fiksuojama kas 15 minučių', 3606, 5, NULL, NULL),
	(12057, 195, 8, 8, 2, 3, 4, 12, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3607, 5, NULL, NULL),
	(12058, 195, 8, 8, 2, 4, 4, 12, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3608, 5, NULL, NULL),
	(12059, 196, 0, 8, 2, 0, 41, 12, 208, NULL, 'Suminė W energija L1 fazėje, fiksuojama kas 15 minučių', 3173, 5, NULL, NULL),
	(12060, 196, 1, 8, 2, 0, 41, 12, 208, NULL, 'Suminė W+ energija L1 fazėje, fiksuojama kas 15 minučių', 3525, 5, NULL, NULL),
	(12061, 196, 1, 8, 2, 1, 41, 12, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3526, 5, NULL, NULL),
	(12062, 196, 1, 8, 2, 2, 41, 12, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3527, 5, NULL, NULL),
	(12063, 196, 1, 8, 2, 3, 41, 12, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3528, 5, NULL, NULL),
	(12064, 196, 1, 8, 2, 4, 41, 12, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3529, 5, NULL, NULL),
	(12065, 196, 2, 8, 2, 0, 41, 12, 208, NULL, 'Suminė W- energija L1 fazėje, fiksuojama kas 15 minučių', 3530, 5, NULL, NULL),
	(12066, 196, 2, 8, 2, 1, 41, 12, 208, NULL, 'Suminė W- energija L1 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3531, 5, NULL, NULL),
	(12067, 196, 2, 8, 2, 2, 41, 12, 208, NULL, 'Suminė W- energija L1 fazėje pagal 2 tarifą, fiksuojama kas 15 minučių', 3532, 5, NULL, NULL),
	(12068, 196, 2, 8, 2, 3, 41, 12, 208, NULL, 'Suminė W- energija L1 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3533, 5, NULL, NULL),
	(12069, 196, 2, 8, 2, 4, 41, 12, 208, NULL, 'Suminė W- energija L1 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3534, 5, NULL, NULL),
	(12070, 197, 0, 8, 2, 0, 41, 12, 209, NULL, 'Suminė W energija L2 fazėje, fiksuojama kas 15 minučių', 3174, 5, NULL, NULL),
	(12071, 197, 1, 8, 2, 0, 41, 12, 209, NULL, 'Suminė W+ energija L2 fazėje, fiksuojama kas 15 minučių', 3567, 5, NULL, NULL),
	(12072, 197, 1, 8, 2, 1, 41, 12, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3568, 5, NULL, NULL),
	(12073, 197, 1, 8, 2, 2, 41, 12, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 2 tarifą , fiksuojama kas 15 minučių', 3569, 5, NULL, NULL),
	(12074, 197, 1, 8, 2, 3, 41, 12, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3570, 5, NULL, NULL),
	(12075, 197, 1, 8, 2, 4, 41, 12, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3571, 5, NULL, NULL),
	(12076, 197, 2, 8, 2, 0, 41, 12, 209, NULL, 'Suminė W- energija L2 fazėje, fiksuojama kas 15 minučių', 3572, 5, NULL, NULL),
	(12077, 197, 2, 8, 2, 1, 41, 12, 209, NULL, 'Suminė W- energija L2 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3573, 5, NULL, NULL),
	(12078, 197, 2, 8, 2, 2, 41, 12, 209, NULL, 'Suminė W- energija L2 fazėje pagal 2 tarifą , fiksuojama kas 15 minučių', 3574, 5, NULL, NULL),
	(12079, 197, 2, 8, 2, 3, 41, 12, 209, NULL, 'Suminė W- energija L2 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3575, 5, NULL, NULL),
	(12080, 197, 2, 8, 2, 4, 41, 12, 209, NULL, 'Suminė W- energija L2 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3576, 5, NULL, NULL),
	(12081, 198, 0, 8, 2, 0, 41, 12, 210, NULL, 'Suminė W energija L3 fazėje, fiksuojama kas 15 minučių', 3175, 5, NULL, NULL),
	(12082, 198, 1, 8, 2, 0, 41, 12, 210, NULL, 'Suminė W+ energija L3 fazėje, fiksuojama kas 15 minučių', 3609, 5, NULL, NULL),
	(12083, 198, 1, 8, 2, 1, 41, 12, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3610, 5, NULL, NULL),
	(12084, 198, 1, 8, 2, 2, 41, 12, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 2 tarifą , fiksuojama kas 15 minučių', 3611, 5, NULL, NULL),
	(12085, 198, 1, 8, 2, 3, 41, 12, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3612, 5, NULL, NULL),
	(12086, 198, 1, 8, 2, 4, 41, 12, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3613, 5, NULL, NULL),
	(12087, 198, 2, 8, 2, 0, 41, 12, 210, NULL, 'Suminė W- energija L3 fazėje, fiksuojama kas 15 minučių', 3614, 5, NULL, NULL),
	(12088, 198, 2, 8, 2, 1, 41, 12, 210, NULL, 'Suminė W- energija L3 fazėje pagal 1 tarifą, fiksuojama kas 15 minučių', 3615, 5, NULL, NULL),
	(12089, 198, 2, 8, 2, 2, 41, 12, 210, NULL, 'Suminė W- energija L3 fazėje pagal 2 tarifą , fiksuojama kas 15 minučių', 3616, 5, NULL, NULL),
	(12090, 198, 2, 8, 2, 3, 41, 12, 210, NULL, 'Suminė W- energija L3 fazėje pagal 3 tarifą, fiksuojama kas 15 minučių', 3617, 5, NULL, NULL),
	(12091, 198, 2, 8, 2, 4, 41, 12, 210, NULL, 'Suminė W- energija L3 fazėje pagal 4 tarifą, fiksuojama kas 15 minučių', 3618, 5, NULL, NULL),
	(12092, 189, 1, 8, 2, 0, 2, 3, 202, NULL, 'Suminė A+ energija L1 fazėje, fiksuojama kas 30 minučių', 3161, 5, NULL, NULL),
	(12093, 189, 1, 8, 2, 1, 2, 3, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3493, 5, NULL, NULL),
	(12094, 189, 1, 8, 2, 2, 2, 3, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3494, 5, NULL, NULL),
	(12095, 189, 1, 8, 2, 3, 2, 3, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3495, 5, NULL, NULL),
	(12096, 189, 1, 8, 2, 4, 2, 3, 202, NULL, 'Suminė A+ energija L1 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3496, 5, NULL, NULL),
	(12097, 189, 2, 8, 2, 0, 2, 3, 202, NULL, 'Suminė A- energija L1 fazėje, fiksuojama kas 30 minučių', 3164, 5, NULL, NULL),
	(12098, 189, 2, 8, 2, 1, 2, 3, 202, NULL, 'Suminė A- energija L1 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3497, 5, NULL, NULL),
	(12099, 189, 2, 8, 2, 2, 2, 3, 202, NULL, 'Suminė A- energija L1 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3498, 5, NULL, NULL),
	(12100, 189, 2, 8, 2, 3, 2, 3, 202, NULL, 'Suminė A- energija L1 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3499, 5, NULL, NULL),
	(12101, 189, 2, 8, 2, 4, 2, 3, 202, NULL, 'Suminė A- energija L1 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3500, 5, NULL, NULL),
	(12102, 190, 1, 8, 2, 0, 2, 3, 203, NULL, 'Suminė A+ energija L2 fazėje, fiksuojama kas 30 minučių', 3162, 5, NULL, NULL),
	(12103, 190, 1, 8, 2, 1, 2, 3, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3535, 5, NULL, NULL),
	(12104, 190, 1, 8, 2, 2, 2, 3, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3536, 5, NULL, NULL),
	(12105, 190, 1, 8, 2, 3, 2, 3, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3537, 5, NULL, NULL),
	(12106, 190, 1, 8, 2, 4, 2, 3, 203, NULL, 'Suminė A+ energija L2 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3538, 5, NULL, NULL),
	(12107, 190, 2, 8, 2, 0, 2, 3, 203, NULL, 'Suminė A- energija L2 fazėje, fiksuojama kas 30 minučių', 3165, 5, NULL, NULL),
	(12108, 190, 2, 8, 2, 1, 2, 3, 203, NULL, 'Suminė A- energija L2 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3539, 5, NULL, NULL),
	(12109, 190, 2, 8, 2, 2, 2, 3, 203, NULL, 'Suminė A- energija L2 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3540, 5, NULL, NULL),
	(12110, 190, 2, 8, 2, 3, 2, 3, 203, NULL, 'Suminė A- energija L2 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3541, 5, NULL, NULL),
	(12111, 190, 2, 8, 2, 4, 2, 3, 203, NULL, 'Suminė A- energija L2 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3542, 5, NULL, NULL),
	(12112, 191, 1, 8, 2, 0, 2, 3, 204, NULL, 'Suminė A+ energija L3 fazėje, fiksuojama kas 30 minučių', 3163, 5, NULL, NULL),
	(12113, 191, 1, 8, 2, 1, 2, 3, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3577, 5, NULL, NULL),
	(12114, 191, 1, 8, 2, 2, 2, 3, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 2 tarifą , fiksuojama kas 30 minučių', 3578, 5, NULL, NULL),
	(12115, 191, 1, 8, 2, 3, 2, 3, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3579, 5, NULL, NULL),
	(12116, 191, 1, 8, 2, 4, 2, 3, 204, NULL, 'Suminė A+ energija L3 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3580, 5, NULL, NULL),
	(12117, 191, 2, 8, 2, 0, 2, 3, 204, NULL, 'Suminė A- energija L3 fazėje, fiksuojama kas 30 minučių', 3166, 5, NULL, NULL),
	(12118, 191, 2, 8, 2, 1, 2, 3, 204, NULL, 'Suminė A- energija L3 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3581, 5, NULL, NULL),
	(12119, 191, 2, 8, 2, 2, 2, 3, 204, NULL, 'Suminė A- energija L3 fazėje pagal 2 tarifą , fiksuojama kas 30 minučių', 3582, 5, NULL, NULL),
	(12120, 191, 2, 8, 2, 3, 2, 3, 204, NULL, 'Suminė A- energija L3 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3583, 5, NULL, NULL),
	(12121, 191, 2, 8, 2, 4, 2, 3, 204, NULL, 'Suminė A- energija L3 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3584, 5, NULL, NULL),
	(12122, 193, 1, 8, 2, 0, 4, 3, 205, NULL, 'Suminė R+ energija L1 fazėje, fiksuojama kas 30 minučių', 3167, 5, NULL, NULL),
	(12123, 193, 1, 8, 2, 1, 4, 3, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3501, 5, NULL, NULL),
	(12124, 193, 1, 8, 2, 2, 4, 3, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3502, 5, NULL, NULL),
	(12125, 193, 1, 8, 2, 3, 4, 3, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3503, 5, NULL, NULL),
	(12126, 193, 1, 8, 2, 4, 4, 3, 205, NULL, 'Suminė R+ energija L1 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3504, 5, NULL, NULL),
	(12127, 193, 2, 8, 2, 0, 4, 3, 205, NULL, 'Suminė R- energija L1 fazėje, fiksuojama kas 30 minučių', 3170, 5, NULL, NULL),
	(12128, 193, 2, 8, 2, 1, 4, 3, 205, NULL, 'Suminė R- energija L1 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3505, 5, NULL, NULL),
	(12129, 193, 2, 8, 2, 2, 4, 3, 205, NULL, 'Suminė R- energija L1 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3506, 5, NULL, NULL),
	(12130, 193, 2, 8, 2, 3, 4, 3, 205, NULL, 'Suminė R- energija L1 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3507, 5, NULL, NULL),
	(12131, 193, 2, 8, 2, 4, 4, 3, 205, NULL, 'Suminė R- energija L1 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3508, 5, NULL, NULL),
	(12132, 193, 5, 8, 2, 0, 4, 3, 205, NULL, 'Suminė R1 energija L1 fazėje, fiksuojama kas 30 minučių', 3296, 5, NULL, NULL),
	(12133, 193, 5, 8, 2, 1, 4, 3, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3509, 5, NULL, NULL),
	(12134, 193, 5, 8, 2, 2, 4, 3, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3510, 5, NULL, NULL),
	(12135, 193, 5, 8, 2, 3, 4, 3, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3511, 5, NULL, NULL),
	(12136, 193, 5, 8, 2, 4, 4, 3, 205, NULL, 'Suminė R1 energija L1 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3512, 5, NULL, NULL),
	(12137, 193, 6, 8, 2, 0, 4, 3, 205, NULL, 'Suminė R2 energija L1 fazėje, fiksuojama kas 30 minučių', 3299, 5, NULL, NULL),
	(12138, 193, 6, 8, 2, 1, 4, 3, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3513, 5, NULL, NULL),
	(12139, 193, 6, 8, 2, 2, 4, 3, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3514, 5, NULL, NULL),
	(12140, 193, 6, 8, 2, 3, 4, 3, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3515, 5, NULL, NULL),
	(12141, 193, 6, 8, 2, 4, 4, 3, 205, NULL, 'Suminė R2 energija L1 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3516, 5, NULL, NULL),
	(12142, 193, 7, 8, 2, 0, 4, 3, 205, NULL, 'Suminė R3 energija L1 fazėje, fiksuojama kas 30 minučių', 3302, 5, NULL, NULL),
	(12143, 193, 7, 8, 2, 1, 4, 3, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3517, 5, NULL, NULL),
	(12144, 193, 7, 8, 2, 2, 4, 3, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3518, 5, NULL, NULL),
	(12145, 193, 7, 8, 2, 3, 4, 3, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3519, 5, NULL, NULL),
	(12146, 193, 7, 8, 2, 4, 4, 3, 205, NULL, 'Suminė R3 energija L1 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3520, 5, NULL, NULL),
	(12147, 193, 8, 8, 2, 0, 4, 3, 205, NULL, 'Suminė R4 energija L1 fazėje, fiksuojama kas 30 minučių', 3305, 5, NULL, NULL),
	(12148, 193, 8, 8, 2, 1, 4, 3, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3521, 5, NULL, NULL),
	(12149, 193, 8, 8, 2, 2, 4, 3, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3522, 5, NULL, NULL),
	(12150, 193, 8, 8, 2, 3, 4, 3, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3523, 5, NULL, NULL),
	(12151, 193, 8, 8, 2, 4, 4, 3, 205, NULL, 'Suminė R4 energija L1 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3524, 5, NULL, NULL),
	(12152, 194, 1, 8, 2, 0, 4, 3, 206, NULL, 'Suminė R+ energija L2 fazėje, fiksuojama kas 30 minučių', 3168, 5, NULL, NULL),
	(12153, 194, 1, 8, 2, 1, 4, 3, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3543, 5, NULL, NULL),
	(12154, 194, 1, 8, 2, 2, 4, 3, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3544, 5, NULL, NULL),
	(12155, 194, 1, 8, 2, 3, 4, 3, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3545, 5, NULL, NULL),
	(12156, 194, 1, 8, 2, 4, 4, 3, 206, NULL, 'Suminė R+ energija L2 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3546, 5, NULL, NULL),
	(12157, 194, 2, 8, 2, 0, 4, 3, 206, NULL, 'Suminė R- energija L2 fazėje, fiksuojama kas 30 minučių', 3171, 5, NULL, NULL),
	(12158, 194, 2, 8, 2, 1, 4, 3, 206, NULL, 'Suminė R- energija L2 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3547, 5, NULL, NULL),
	(12159, 194, 2, 8, 2, 2, 4, 3, 206, NULL, 'Suminė R- energija L2 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3548, 5, NULL, NULL),
	(12160, 194, 2, 8, 2, 3, 4, 3, 206, NULL, 'Suminė R- energija L2 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3549, 5, NULL, NULL),
	(12161, 194, 2, 8, 2, 4, 4, 3, 206, NULL, 'Suminė R- energija L2 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3550, 5, NULL, NULL),
	(12162, 194, 5, 8, 2, 0, 4, 3, 206, NULL, 'Suminė R1 energija L2 fazėje, fiksuojama kas 30 minučių', 3297, 5, NULL, NULL),
	(12163, 194, 5, 8, 2, 1, 4, 3, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3551, 5, NULL, NULL),
	(12164, 194, 5, 8, 2, 2, 4, 3, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3552, 5, NULL, NULL),
	(12165, 194, 5, 8, 2, 3, 4, 3, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3553, 5, NULL, NULL),
	(12166, 194, 5, 8, 2, 4, 4, 3, 206, NULL, 'Suminė R1 energija L2 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3554, 5, NULL, NULL),
	(12167, 194, 6, 8, 2, 0, 4, 3, 206, NULL, 'Suminė R2 energija L2 fazėje, fiksuojama kas 30 minučių', 3300, 5, NULL, NULL),
	(12168, 194, 6, 8, 2, 1, 4, 3, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3555, 5, NULL, NULL),
	(12169, 194, 6, 8, 2, 2, 4, 3, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3556, 5, NULL, NULL),
	(12170, 194, 6, 8, 2, 3, 4, 3, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3557, 5, NULL, NULL),
	(12171, 194, 6, 8, 2, 4, 4, 3, 206, NULL, 'Suminė R2 energija L2 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3558, 5, NULL, NULL),
	(12172, 194, 7, 8, 2, 0, 4, 3, 206, NULL, 'Suminė R3 energija L2 fazėje, fiksuojama kas 30 minučių', 3303, 5, NULL, NULL),
	(12173, 194, 7, 8, 2, 1, 4, 3, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3559, 5, NULL, NULL),
	(12174, 194, 7, 8, 2, 2, 4, 3, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3560, 5, NULL, NULL),
	(12175, 194, 7, 8, 2, 3, 4, 3, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3561, 5, NULL, NULL),
	(12176, 194, 7, 8, 2, 4, 4, 3, 206, NULL, 'Suminė R3 energija L2 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3562, 5, NULL, NULL),
	(12177, 194, 8, 8, 2, 0, 4, 3, 206, NULL, 'Suminė R4 energija L2 fazėje, fiksuojama kas 30 minučių', 3306, 5, NULL, NULL),
	(12178, 194, 8, 8, 2, 1, 4, 3, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3563, 5, NULL, NULL),
	(12179, 194, 8, 8, 2, 2, 4, 3, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3564, 5, NULL, NULL),
	(12180, 194, 8, 8, 2, 3, 4, 3, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3565, 5, NULL, NULL),
	(12181, 194, 8, 8, 2, 4, 4, 3, 206, NULL, 'Suminė R4 energija L2 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3566, 5, NULL, NULL),
	(12182, 195, 1, 8, 2, 0, 4, 3, 207, NULL, 'Suminė R+ energija L3 fazėje, fiksuojama kas 30 minučių', 3169, 5, NULL, NULL),
	(12183, 195, 1, 8, 2, 1, 4, 3, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3585, 5, NULL, NULL),
	(12184, 195, 1, 8, 2, 2, 4, 3, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 2 tarifą , fiksuojama kas 30 minučių', 3586, 5, NULL, NULL),
	(12185, 195, 1, 8, 2, 3, 4, 3, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3587, 5, NULL, NULL),
	(12186, 195, 1, 8, 2, 4, 4, 3, 207, NULL, 'Suminė R+ energija L3 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3588, 5, NULL, NULL),
	(12187, 195, 2, 8, 2, 0, 4, 3, 207, NULL, 'Suminė R- energija L3 fazėje, fiksuojama kas 30 minučių', 3172, 5, NULL, NULL),
	(12188, 195, 2, 8, 2, 1, 4, 3, 207, NULL, 'Suminė R- energija L3 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3589, 5, NULL, NULL),
	(12189, 195, 2, 8, 2, 2, 4, 3, 207, NULL, 'Suminė R- energija L3 fazėje pagal 2 tarifą , fiksuojama kas 30 minučių', 3590, 5, NULL, NULL),
	(12190, 195, 2, 8, 2, 3, 4, 3, 207, NULL, 'Suminė R- energija L3 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3591, 5, NULL, NULL),
	(12191, 195, 2, 8, 2, 4, 4, 3, 207, NULL, 'Suminė R- energija L3 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3592, 5, NULL, NULL),
	(12192, 195, 5, 8, 2, 0, 4, 3, 207, NULL, 'Suminė R1 energija L3 fazėje, fiksuojama kas 30 minučių', 3298, 5, NULL, NULL),
	(12193, 195, 5, 8, 2, 1, 4, 3, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3593, 5, NULL, NULL),
	(12194, 195, 5, 8, 2, 2, 4, 3, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 2 tarifą , fiksuojama kas 30 minučių', 3594, 5, NULL, NULL),
	(12195, 195, 5, 8, 2, 3, 4, 3, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3595, 5, NULL, NULL),
	(12196, 195, 5, 8, 2, 4, 4, 3, 207, NULL, 'Suminė R1 energija L3 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3596, 5, NULL, NULL),
	(12197, 195, 6, 8, 2, 0, 4, 3, 207, NULL, 'Suminė R2 energija L3 fazėje, fiksuojama kas 30 minučių', 3301, 5, NULL, NULL),
	(12198, 195, 6, 8, 2, 1, 4, 3, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3597, 5, NULL, NULL),
	(12199, 195, 6, 8, 2, 2, 4, 3, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 2 tarifą , fiksuojama kas 30 minučių', 3598, 5, NULL, NULL),
	(12200, 195, 6, 8, 2, 3, 4, 3, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3599, 5, NULL, NULL),
	(12201, 195, 6, 8, 2, 4, 4, 3, 207, NULL, 'Suminė R2 energija L3 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3600, 5, NULL, NULL),
	(12202, 195, 7, 8, 2, 0, 4, 3, 207, NULL, 'Suminė R3 energija L3 fazėje, fiksuojama kas 30 minučių', 3304, 5, NULL, NULL),
	(12203, 195, 7, 8, 2, 1, 4, 3, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3601, 5, NULL, NULL),
	(12204, 195, 7, 8, 2, 2, 4, 3, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 2 tarifą , fiksuojama kas 30 minučių', 3602, 5, NULL, NULL),
	(12205, 195, 7, 8, 2, 3, 4, 3, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3603, 5, NULL, NULL),
	(12206, 195, 7, 8, 2, 4, 4, 3, 207, NULL, 'Suminė R3 energija L3 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3604, 5, NULL, NULL),
	(12207, 195, 8, 8, 2, 0, 4, 3, 207, NULL, 'Suminė R4 energija L3 fazėje, fiksuojama kas 30 minučių', 3307, 5, NULL, NULL),
	(12208, 195, 8, 8, 2, 1, 4, 3, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3605, 5, NULL, NULL),
	(12209, 195, 8, 8, 2, 2, 4, 3, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 2 tarifą , fiksuojama kas 30 minučių', 3606, 5, NULL, NULL),
	(12210, 195, 8, 8, 2, 3, 4, 3, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3607, 5, NULL, NULL),
	(12211, 195, 8, 8, 2, 4, 4, 3, 207, NULL, 'Suminė R4 energija L3 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3608, 5, NULL, NULL),
	(12212, 196, 0, 8, 2, 0, 41, 3, 208, NULL, 'Suminė W energija L1 fazėje, fiksuojama kas 30 minučių', 3173, 5, NULL, NULL),
	(12213, 196, 1, 8, 2, 0, 41, 3, 208, NULL, 'Suminė W+ energija L1 fazėje, fiksuojama kas 30 minučių', 3525, 5, NULL, NULL),
	(12214, 196, 1, 8, 2, 1, 41, 3, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3526, 5, NULL, NULL),
	(12215, 196, 1, 8, 2, 2, 41, 3, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3527, 5, NULL, NULL),
	(12216, 196, 1, 8, 2, 3, 41, 3, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3528, 5, NULL, NULL),
	(12217, 196, 1, 8, 2, 4, 41, 3, 208, NULL, 'Suminė W+ energija L1 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3529, 5, NULL, NULL),
	(12218, 196, 2, 8, 2, 0, 41, 3, 208, NULL, 'Suminė W- energija L1 fazėje, fiksuojama kas 30 minučių', 3530, 5, NULL, NULL),
	(12219, 196, 2, 8, 2, 1, 41, 3, 208, NULL, 'Suminė W- energija L1 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3531, 5, NULL, NULL),
	(12220, 196, 2, 8, 2, 2, 41, 3, 208, NULL, 'Suminė W- energija L1 fazėje pagal 2 tarifą, fiksuojama kas 30 minučių', 3532, 5, NULL, NULL),
	(12221, 196, 2, 8, 2, 3, 41, 3, 208, NULL, 'Suminė W- energija L1 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3533, 5, NULL, NULL),
	(12222, 196, 2, 8, 2, 4, 41, 3, 208, NULL, 'Suminė W- energija L1 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3534, 5, NULL, NULL),
	(12223, 197, 0, 8, 2, 0, 41, 3, 209, NULL, 'Suminė W energija L2 fazėje, fiksuojama kas 30 minučių', 3174, 5, NULL, NULL),
	(12224, 197, 1, 8, 2, 0, 41, 3, 209, NULL, 'Suminė W+ energija L2 fazėje, fiksuojama kas 30 minučių', 3567, 5, NULL, NULL),
	(12225, 197, 1, 8, 2, 1, 41, 3, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3568, 5, NULL, NULL),
	(12226, 197, 1, 8, 2, 2, 41, 3, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 2 tarifą , fiksuojama kas 30 minučių', 3569, 5, NULL, NULL),
	(12227, 197, 1, 8, 2, 3, 41, 3, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3570, 5, NULL, NULL),
	(12228, 197, 1, 8, 2, 4, 41, 3, 209, NULL, 'Suminė W+ energija L2 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3571, 5, NULL, NULL),
	(12229, 197, 2, 8, 2, 0, 41, 3, 209, NULL, 'Suminė W- energija L2 fazėje, fiksuojama kas 30 minučių', 3572, 5, NULL, NULL),
	(12230, 197, 2, 8, 2, 1, 41, 3, 209, NULL, 'Suminė W- energija L2 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3573, 5, NULL, NULL),
	(12231, 197, 2, 8, 2, 2, 41, 3, 209, NULL, 'Suminė W- energija L2 fazėje pagal 2 tarifą , fiksuojama kas 30 minučių', 3574, 5, NULL, NULL),
	(12232, 197, 2, 8, 2, 3, 41, 3, 209, NULL, 'Suminė W- energija L2 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3575, 5, NULL, NULL),
	(12233, 197, 2, 8, 2, 4, 41, 3, 209, NULL, 'Suminė W- energija L2 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3576, 5, NULL, NULL),
	(12234, 198, 0, 8, 2, 0, 41, 3, 210, NULL, 'Suminė W energija L3 fazėje, fiksuojama kas 30 minučių', 3175, 5, NULL, NULL),
	(12235, 198, 1, 8, 2, 0, 41, 3, 210, NULL, 'Suminė W+ energija L3 fazėje, fiksuojama kas 30 minučių', 3609, 5, NULL, NULL),
	(12236, 198, 1, 8, 2, 1, 41, 3, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3610, 5, NULL, NULL),
	(12237, 198, 1, 8, 2, 2, 41, 3, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 2 tarifą , fiksuojama kas 30 minučių', 3611, 5, NULL, NULL),
	(12238, 198, 1, 8, 2, 3, 41, 3, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3612, 5, NULL, NULL),
	(12239, 198, 1, 8, 2, 4, 41, 3, 210, NULL, 'Suminė W+ energija L3 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3613, 5, NULL, NULL),
	(12240, 198, 2, 8, 2, 0, 41, 3, 210, NULL, 'Suminė W- energija L3 fazėje, fiksuojama kas 30 minučių', 3614, 5, NULL, NULL),
	(12241, 198, 2, 8, 2, 1, 41, 3, 210, NULL, 'Suminė W- energija L3 fazėje pagal 1 tarifą, fiksuojama kas 30 minučių', 3615, 5, NULL, NULL),
	(12242, 198, 2, 8, 2, 2, 41, 3, 210, NULL, 'Suminė W- energija L3 fazėje pagal 2 tarifą , fiksuojama kas 30 minučių', 3616, 5, NULL, NULL),
	(12243, 198, 2, 8, 2, 3, 41, 3, 210, NULL, 'Suminė W- energija L3 fazėje pagal 3 tarifą, fiksuojama kas 30 minučių', 3617, 5, NULL, NULL),
	(12244, 198, 2, 8, 2, 4, 41, 3, 210, NULL, 'Suminė W- energija L3 fazėje pagal 4 tarifą, fiksuojama kas 30 minučių', 3618, 5, NULL, NULL),
	(12245, 53, 0, 7, 4, 0, 1, 4, 70, NULL, 'Maksimali momentinė šilumnešio šilumos galia per valandą', 1002, 2, NULL, NULL),
	(12246, 53, 0, 7, 4, 0, 1, 5, 70, NULL, 'Maksimali momentinė šilumnešio šilumos galia per parą', 1002, 3, NULL, NULL),
	(12247, 53, 0, 7, 4, 0, 1, 6, 70, NULL, 'Maksimali momentinė šilumnešio šilumos galia per mėnesį', 1002, 4, NULL, NULL),
	(12248, 1, 1, 7, 1, 0, 1, 1, 13, NULL, 'Momentinė P+ galia, fiksuojama kas minutę', 3312, 1, NULL, NULL),
	(12249, 1, 1, 7, 1, 0, 1, 2, 13, NULL, 'Momentinė P+ galia, fiksuojama kas 2 minutes', 3312, 1, NULL, NULL),
	(12250, 1, 1, 7, 1, 0, 1, 3, 13, NULL, 'Momentinė P+ galia, fiksuojama kas 30 minučių', 3312, 2, NULL, NULL),
	(12251, 1, 1, 7, 1, 0, 1, 4, 13, NULL, 'Momentinė P+ galia, fiksuojama kas valandą', 3312, 2, NULL, NULL),
	(12252, 1, 1, 7, 1, 0, 1, 5, 13, NULL, 'Momentinė P+ galia, fiksuojama kas parą', 3312, 3, NULL, NULL),
	(12253, 1, 1, 7, 1, 0, 1, 7, 13, NULL, 'Momentinė P+ galia', 3312, 6, NULL, NULL),
	(12254, 1, 1, 7, 1, 0, 1, 8, 13, NULL, 'Momentinė P+ galia, fiksuojama kas 3 minutes', 3312, 1, NULL, NULL),
	(12255, 1, 1, 7, 1, 0, 1, 10, 13, NULL, 'Momentinė P+ galia, fiksuojama kas 5 minutes', 3312, 1, NULL, NULL),
	(12256, 1, 1, 7, 1, 0, 1, 12, 13, NULL, 'Momentinė P+ galia, fiksuojama kas 15 minučių', 3312, 2, NULL, NULL),
	(12257, 1, 1, 7, 1, 0, 1, 15, 13, NULL, 'Momentinė P+ galia, fiksuojama kas 5 sekundes', 3312, 7, NULL, NULL),
	(12258, 1, 1, 7, 1, 0, 1, 19, 13, NULL, 'Momentinė P+ galia, fiksuojama kas 30 sekundžių', 3312, 7, NULL, NULL),
	(12259, 1, 2, 7, 1, 0, 1, 1, 13, NULL, 'Momentinė P- galia, fiksuojama kas minutę', 3313, 1, NULL, NULL),
	(12260, 1, 2, 7, 1, 0, 1, 2, 13, NULL, 'Momentinė P- galia, fiksuojama kas 2 minutes', 3313, 1, NULL, NULL),
	(12261, 1, 2, 7, 1, 0, 1, 3, 13, NULL, 'Momentinė P- galia, fiksuojama kas 30 minučių', 3313, 2, NULL, NULL),
	(12262, 1, 2, 7, 1, 0, 1, 4, 13, NULL, 'Momentinė P- galia, fiksuojama kas valandą', 3313, 2, NULL, NULL),
	(12263, 1, 2, 7, 1, 0, 1, 5, 13, NULL, 'Momentinė P- galia, fiksuojama kas parą', 3313, 3, NULL, NULL),
	(12264, 1, 2, 7, 1, 0, 1, 7, 13, NULL, 'Momentinė P- galia', 3313, 6, NULL, NULL),
	(12265, 1, 2, 7, 1, 0, 1, 8, 13, NULL, 'Momentinė P- galia, fiksuojama kas 3 minutes', 3313, 1, NULL, NULL),
	(12266, 1, 2, 7, 1, 0, 1, 10, 13, NULL, 'Momentinė P- galia, fiksuojama kas 5 minutes', 3313, 1, NULL, NULL),
	(12267, 1, 2, 7, 1, 0, 1, 12, 13, NULL, 'Momentinė P- galia, fiksuojama kas 15 minučių', 3313, 2, NULL, NULL),
	(12268, 1, 2, 7, 1, 0, 1, 15, 13, NULL, 'Momentinė P- galia, fiksuojama kas 5 sekundes', 3313, 7, NULL, NULL),
	(12269, 1, 2, 7, 1, 0, 1, 19, 13, NULL, 'Momentinė P- galia, fiksuojama kas 30 sekundžių', 3313, 7, NULL, NULL),
	(12270, 474, 0, 7, 1, 0, 0, 7, 493, NULL, 'Kredito likutis (pinigai)', 4226, 6, NULL, NULL),
	(12271, 14, 0, 1, 3, 0, 1, 1, 26, NULL, 'Vidutinė P galia per minutę L1 fazėje', 4205, 1, NULL, NULL),
	(12272, 14, 0, 4, 3, 0, 1, 4, 26, NULL, 'Vidutinė P galia per valandą L1 fazėje', 4205, 2, NULL, NULL),
	(12273, 14, 0, 12, 3, 0, 1, 11, 26, NULL, 'Vidutinė P galia per 10 minučių L1 fazėje', 4205, 1, NULL, NULL),
	(12274, 14, 0, 13, 3, 0, 1, 12, 26, NULL, 'Vidutinė P galia per 15 minučių L1 fazėje', 4205, 2, NULL, NULL),
	(12275, 14, 0, 2, 3, 0, 1, 2, 26, NULL, 'Vidutinė P galia per 2 minutes L1 fazėje', 4205, 1, NULL, NULL),
	(12276, 14, 0, 14, 3, 0, 1, 13, 26, NULL, 'Vidutinė P galia per 20 minučių L1 fazėje', 4205, 2, NULL, NULL),
	(12277, 14, 0, 9, 3, 0, 1, 8, 26, NULL, 'Vidutinė P galia per 3 minutes L1 fazėje', 4205, 1, NULL, NULL),
	(12278, 14, 0, 3, 3, 0, 1, 3, 26, NULL, 'Vidutinė P galia per 30 minučių L1 fazėje', 4205, 2, NULL, NULL),
	(12279, 14, 0, 10, 3, 0, 1, 9, 26, NULL, 'Vidutinė P galia per 4 minutes L1 fazėje', 4205, 1, NULL, NULL),
	(12280, 14, 0, 11, 3, 0, 1, 10, 26, NULL, 'Vidutinė P galia per 5 minutes L1 fazėje', 4205, 1, NULL, NULL),
	(12281, 15, 0, 1, 3, 0, 1, 1, 27, NULL, 'Vidutinė P galia per minutę L2 fazėje', 4206, 1, NULL, NULL),
	(12282, 15, 0, 4, 3, 0, 1, 4, 27, NULL, 'Vidutinė P galia per valandą L2 fazėje', 4206, 2, NULL, NULL),
	(12283, 15, 0, 12, 3, 0, 1, 11, 27, NULL, 'Vidutinė P galia per 10 minučių L2 fazėje', 4206, 1, NULL, NULL),
	(12284, 15, 0, 13, 3, 0, 1, 12, 27, NULL, 'Vidutinė P galia per 15 minučių L2 fazėje', 4206, 2, NULL, NULL),
	(12285, 15, 0, 2, 3, 0, 1, 2, 27, NULL, 'Vidutinė P galia per 2 minutes L2 fazėje', 4206, 1, NULL, NULL),
	(12286, 15, 0, 14, 3, 0, 1, 13, 27, NULL, 'Vidutinė P galia per 20 minučių L2 fazėje', 4206, 2, NULL, NULL),
	(12287, 15, 0, 9, 3, 0, 1, 8, 27, NULL, 'Vidutinė P galia per 3 minutes L2 fazėje', 4206, 1, NULL, NULL),
	(12288, 15, 0, 3, 3, 0, 1, 3, 27, NULL, 'Vidutinė P galia per 30 minučių L2 fazėje', 4206, 2, NULL, NULL),
	(12289, 15, 0, 10, 3, 0, 1, 9, 27, NULL, 'Vidutinė P galia per 4 minutes L2 fazėje', 4206, 1, NULL, NULL),
	(12290, 15, 0, 11, 3, 0, 1, 10, 27, NULL, 'Vidutinė P galia per 5 minutes L2 fazėje', 4206, 1, NULL, NULL),
	(12291, 16, 0, 1, 3, 0, 1, 1, 28, NULL, 'Vidutinė P galia per minutę L3 fazėje', 4207, 1, NULL, NULL),
	(12292, 16, 0, 4, 3, 0, 1, 4, 28, NULL, 'Vidutinė P galia per valandą L3 fazėje', 4207, 2, NULL, NULL),
	(12293, 16, 0, 12, 3, 0, 1, 11, 28, NULL, 'Vidutinė P galia per 10 minučių L3 fazėje', 4207, 1, NULL, NULL),
	(12294, 16, 0, 13, 3, 0, 1, 12, 28, NULL, 'Vidutinė P galia per 15 minučių L3 fazėje', 4207, 2, NULL, NULL),
	(12295, 16, 0, 2, 3, 0, 1, 2, 28, NULL, 'Vidutinė P galia per 2 minutes L3 fazėje', 4207, 1, NULL, NULL),
	(12296, 16, 0, 14, 3, 0, 1, 13, 28, NULL, 'Vidutinė P galia per 20 minučių L3 fazėje', 4207, 2, NULL, NULL),
	(12297, 16, 0, 9, 3, 0, 1, 8, 28, NULL, 'Vidutinė P galia per 3 minutes L3 fazėje', 4207, 1, NULL, NULL),
	(12298, 16, 0, 3, 3, 0, 1, 3, 28, NULL, 'Vidutinė P galia per 30 minučių L3 fazėje', 4207, 2, NULL, NULL),
	(12299, 16, 0, 10, 3, 0, 1, 9, 28, NULL, 'Vidutinė P galia per 4 minutes L3 fazėje', 4207, 1, NULL, NULL),
	(12300, 16, 0, 11, 3, 0, 1, 10, 28, NULL, 'Vidutinė P galia per 5 minutes L3 fazėje', 4207, 1, NULL, NULL),
	(12301, 17, 0, 1, 3, 0, 3, 1, 29, NULL, 'Vidutinė Q galia per minutę L1 fazėje', 4209, 1, NULL, NULL),
	(12302, 17, 0, 4, 3, 0, 3, 4, 29, NULL, 'Vidutinė Q galia per valandą L1 fazėje', 4209, 2, NULL, NULL),
	(12303, 17, 0, 12, 3, 0, 3, 11, 29, NULL, 'Vidutinė Q galia per 10 minučių L1 fazėje', 4209, 1, NULL, NULL),
	(12304, 17, 0, 13, 3, 0, 3, 12, 29, NULL, 'Vidutinė Q galia per 15 minučių L1 fazėje', 4209, 2, NULL, NULL),
	(12305, 17, 0, 2, 3, 0, 3, 2, 29, NULL, 'Vidutinė Q galia per 2 minutes L1 fazėje', 4209, 1, NULL, NULL),
	(12306, 17, 0, 14, 3, 0, 3, 13, 29, NULL, 'Vidutinė Q galia per 20 minučių L1 fazėje', 4209, 2, NULL, NULL),
	(12307, 17, 0, 9, 3, 0, 3, 8, 29, NULL, 'Vidutinė Q galia per 3 minutes L1 fazėje', 4209, 1, NULL, NULL),
	(12308, 17, 0, 3, 3, 0, 3, 3, 29, NULL, 'Vidutinė Q galia per 30 minučių L1 fazėje', 4209, 2, NULL, NULL),
	(12309, 17, 0, 10, 3, 0, 3, 9, 29, NULL, 'Vidutinė Q galia per 4 minutes L1 fazėje', 4209, 1, NULL, NULL),
	(12310, 17, 0, 11, 3, 0, 3, 10, 29, NULL, 'Vidutinė Q galia per 5 minutes L1 fazėje', 4209, 1, NULL, NULL),
	(12311, 18, 0, 1, 3, 0, 3, 1, 30, NULL, 'Vidutinė Q galia per minutę L2 fazėje', 4210, 1, NULL, NULL),
	(12312, 18, 0, 4, 3, 0, 3, 4, 30, NULL, 'Vidutinė Q galia per valandą L2 fazėje', 4210, 2, NULL, NULL),
	(12313, 18, 0, 12, 3, 0, 3, 11, 30, NULL, 'Vidutinė Q galia per 10 minučių L2 fazėje', 4210, 1, NULL, NULL),
	(12314, 18, 0, 13, 3, 0, 3, 12, 30, NULL, 'Vidutinė Q galia per 15 minučių L2 fazėje', 4210, 2, NULL, NULL),
	(12315, 18, 0, 2, 3, 0, 3, 2, 30, NULL, 'Vidutinė Q galia per 2 minutes L2 fazėje', 4210, 1, NULL, NULL),
	(12316, 18, 0, 14, 3, 0, 3, 13, 30, NULL, 'Vidutinė Q galia per 20 minučių L2 fazėje', 4210, 2, NULL, NULL),
	(12317, 18, 0, 9, 3, 0, 3, 8, 30, NULL, 'Vidutinė Q galia per 3 minutes L2 fazėje', 4210, 1, NULL, NULL),
	(12318, 18, 0, 3, 3, 0, 3, 3, 30, NULL, 'Vidutinė Q galia per 30 minučių L2 fazėje', 4210, 2, NULL, NULL),
	(12319, 18, 0, 10, 3, 0, 3, 9, 30, NULL, 'Vidutinė Q galia per 4 minutes L2 fazėje', 4210, 1, NULL, NULL),
	(12320, 18, 0, 11, 3, 0, 3, 10, 30, NULL, 'Vidutinė Q galia per 5 minutes L2 fazėje', 4210, 1, NULL, NULL),
	(12321, 19, 0, 1, 3, 0, 3, 1, 31, NULL, 'Vidutinė Q galia per minutę L3 fazėje', 4211, 1, NULL, NULL),
	(12322, 19, 0, 4, 3, 0, 3, 4, 31, NULL, 'Vidutinė Q galia per valandą L3 fazėje', 4211, 2, NULL, NULL),
	(12323, 19, 0, 12, 3, 0, 3, 11, 31, NULL, 'Vidutinė Q galia per 10 minučių L3 fazėje', 4211, 1, NULL, NULL),
	(12324, 19, 0, 13, 3, 0, 3, 12, 31, NULL, 'Vidutinė Q galia per 15 minučių L3 fazėje', 4211, 2, NULL, NULL),
	(12325, 19, 0, 2, 3, 0, 3, 2, 31, NULL, 'Vidutinė Q galia per 2 minutes L3 fazėje', 4211, 1, NULL, NULL),
	(12326, 19, 0, 14, 3, 0, 3, 13, 31, NULL, 'Vidutinė Q galia per 20 minučių L3 fazėje', 4211, 2, NULL, NULL),
	(12327, 19, 0, 9, 3, 0, 3, 8, 31, NULL, 'Vidutinė Q galia per 3 minutes L3 fazėje', 4211, 1, NULL, NULL),
	(12328, 19, 0, 3, 3, 0, 3, 3, 31, NULL, 'Vidutinė Q galia per 30 minučių L3 fazėje', 4211, 2, NULL, NULL),
	(12329, 19, 0, 10, 3, 0, 3, 9, 31, NULL, 'Vidutinė Q galia per 4 minutes L3 fazėje', 4211, 1, NULL, NULL),
	(12330, 19, 0, 11, 3, 0, 3, 10, 31, NULL, 'Vidutinė Q galia per 5 minutes L3 fazėje', 4211, 1, NULL, NULL),
	(12331, 23, 0, 1, 3, 0, 0, 1, 35, NULL, 'Vidutinė cos(fi) reikšmė per minutę L1 fazėje', 4213, 1, NULL, NULL),
	(12332, 23, 0, 4, 3, 0, 0, 4, 35, NULL, 'Vidutinė cos(fi) reikšmė per valandą L1 fazėje', 4213, 2, NULL, NULL),
	(12333, 23, 0, 12, 3, 0, 0, 11, 35, NULL, 'Vidutinė cos(fi) reikšmė per 10 minučių L1 fazėje', 4213, 1, NULL, NULL),
	(12334, 23, 0, 13, 3, 0, 0, 12, 35, NULL, 'Vidutinė cos(fi) reikšmė per 15 minučių L1 fazėje', 4213, 2, NULL, NULL),
	(12335, 23, 0, 2, 3, 0, 0, 2, 35, NULL, 'Vidutinė cos(fi) reikšmė per 2 minutes L1 fazėje', 4213, 1, NULL, NULL),
	(12336, 23, 0, 14, 3, 0, 0, 13, 35, NULL, 'Vidutinė cos(fi) reikšmė per 20 minučių L1 fazėje', 4213, 2, NULL, NULL),
	(12337, 23, 0, 9, 3, 0, 0, 8, 35, NULL, 'Vidutinė cos(fi) reikšmė per 3 minutes L1 fazėje', 4213, 1, NULL, NULL),
	(12338, 23, 0, 3, 3, 0, 0, 3, 35, NULL, 'Vidutinė cos(fi) reikšmė per 30 minučių L1 fazėje', 4213, 2, NULL, NULL),
	(12339, 23, 0, 10, 3, 0, 0, 9, 35, NULL, 'Vidutinė cos(fi) reikšmė per 4 minutes L1 fazėje', 4213, 1, NULL, NULL),
	(12340, 23, 0, 11, 3, 0, 0, 10, 35, NULL, 'Vidutinė cos(fi) reikšmė per 5 minutes L1 fazėje', 4213, 1, NULL, NULL),
	(12341, 24, 0, 1, 3, 0, 0, 1, 36, NULL, 'Vidutinė cos(fi) reikšmė per minutę L2 fazėje', 4214, 1, NULL, NULL),
	(12342, 24, 0, 4, 3, 0, 0, 4, 36, NULL, 'Vidutinė cos(fi) reikšmė per valandą L2 fazėje', 4214, 2, NULL, NULL),
	(12343, 24, 0, 12, 3, 0, 0, 11, 36, NULL, 'Vidutinė cos(fi) reikšmė per 10 minučių L2 fazėje', 4214, 1, NULL, NULL),
	(12344, 24, 0, 13, 3, 0, 0, 12, 36, NULL, 'Vidutinė cos(fi) reikšmė per 15 minučių L2 fazėje', 4214, 2, NULL, NULL),
	(12345, 24, 0, 2, 3, 0, 0, 2, 36, NULL, 'Vidutinė cos(fi) reikšmė per 2 minutes L2 fazėje', 4214, 1, NULL, NULL),
	(12346, 24, 0, 14, 3, 0, 0, 13, 36, NULL, 'Vidutinė cos(fi) reikšmė per 20 minučių L2 fazėje', 4214, 2, NULL, NULL),
	(12347, 24, 0, 9, 3, 0, 0, 8, 36, NULL, 'Vidutinė cos(fi) reikšmė per 3 minutes L2 fazėje', 4214, 1, NULL, NULL),
	(12348, 24, 0, 3, 3, 0, 0, 3, 36, NULL, 'Vidutinė cos(fi) reikšmė per 30 minučių L2 fazėje', 4214, 2, NULL, NULL),
	(12349, 24, 0, 10, 3, 0, 0, 9, 36, NULL, 'Vidutinė cos(fi) reikšmė per 4 minutes L2 fazėje', 4214, 1, NULL, NULL),
	(12350, 24, 0, 11, 3, 0, 0, 10, 36, NULL, 'Vidutinė cos(fi) reikšmė per 5 minutes L2 fazėje', 4214, 1, NULL, NULL),
	(12351, 25, 0, 1, 3, 0, 0, 1, 37, NULL, 'Vidutinė cos(fi) reikšmė per minutę L3 fazėje', 4215, 1, NULL, NULL),
	(12352, 25, 0, 4, 3, 0, 0, 4, 37, NULL, 'Vidutinė cos(fi) reikšmė per valandą L3 fazėje', 4215, 2, NULL, NULL),
	(12353, 25, 0, 12, 3, 0, 0, 11, 37, NULL, 'Vidutinė cos(fi) reikšmė per 10 minučių L3 fazėje', 4215, 1, NULL, NULL),
	(12354, 25, 0, 13, 3, 0, 0, 12, 37, NULL, 'Vidutinė cos(fi) reikšmė per 15 minučių L3 fazėje', 4215, 2, NULL, NULL),
	(12355, 25, 0, 2, 3, 0, 0, 2, 37, NULL, 'Vidutinė cos(fi) reikšmė per 2 minutes L3 fazėje', 4215, 1, NULL, NULL),
	(12356, 25, 0, 14, 3, 0, 0, 13, 37, NULL, 'Vidutinė cos(fi) reikšmė per 20 minučių L3 fazėje', 4215, 2, NULL, NULL),
	(12357, 25, 0, 9, 3, 0, 0, 8, 37, NULL, 'Vidutinė cos(fi) reikšmė per 3 minutes L3 fazėje', 4215, 1, NULL, NULL),
	(12358, 25, 0, 3, 3, 0, 0, 3, 37, NULL, 'Vidutinė cos(fi) reikšmė per 30 minučių L3 fazėje', 4215, 2, NULL, NULL),
	(12359, 25, 0, 10, 3, 0, 0, 9, 37, NULL, 'Vidutinė cos(fi) reikšmė per 4 minutes L3 fazėje', 4215, 1, NULL, NULL),
	(12360, 25, 0, 11, 3, 0, 0, 10, 37, NULL, 'Vidutinė cos(fi) reikšmė per 5 minutes L3 fazėje', 4215, 1, NULL, NULL),
	(12361, 35, 0, 1, 3, 0, 0, 1, 46, NULL, 'Vidutinė cos(fi) reikšmė per minutę', 4216, 1, NULL, NULL),
	(12362, 35, 0, 4, 3, 0, 0, 4, 46, NULL, 'Vidutinė cos(fi) reikšmė per valandą', 4216, 2, NULL, NULL),
	(12363, 35, 0, 12, 3, 0, 0, 11, 46, NULL, 'Vidutinė cos(fi) reikšmė per 10 minučių', 4216, 1, NULL, NULL),
	(12364, 35, 0, 13, 3, 0, 0, 12, 46, NULL, 'Vidutinė cos(fi) reikšmė per 15 minučių', 4216, 2, NULL, NULL),
	(12365, 35, 0, 2, 3, 0, 0, 2, 46, NULL, 'Vidutinė cos(fi) reikšmė per 2 minutes', 4216, 1, NULL, NULL),
	(12366, 35, 0, 14, 3, 0, 0, 13, 46, NULL, 'Vidutinė cos(fi) reikšmė per 20 minučių', 4216, 2, NULL, NULL),
	(12367, 35, 0, 9, 3, 0, 0, 8, 46, NULL, 'Vidutinė cos(fi) reikšmė per 3 minutes', 4216, 1, NULL, NULL),
	(12368, 35, 0, 3, 3, 0, 0, 3, 46, NULL, 'Vidutinė cos(fi) reikšmė per 30 minučių', 4216, 2, NULL, NULL),
	(12369, 35, 0, 10, 3, 0, 0, 9, 46, NULL, 'Vidutinė cos(fi) reikšmė per 4 minutes', 4216, 1, NULL, NULL),
	(12370, 35, 0, 11, 3, 0, 0, 10, 46, NULL, 'Vidutinė cos(fi) reikšmė per 5 minutes', 4216, 1, NULL, NULL),
	(12371, 53, 2, 7, 1, 0, 1, 1, 70, NULL, 'Momentinė grįžtamo šilumnešio šilumos galia, fiksuojama kas minutę', 1020, 1, NULL, NULL),
	(12372, 53, -4, 7, 1, 0, 1, 1, 70, NULL, 'Momentinė pamaitinimo vandens šilumos galia, fiksuojama kas minutę', 1099, 1, NULL, NULL),
	(12373, 53, 3, 7, 1, 0, 1, 1, 70, NULL, 'Momentinė sunaudota šilumnešio šilumos galia, fiksuojama kas minutę', 1043, 1, NULL, NULL),
	(12374, 53, 0, 7, 1, 0, 1, 1, 70, NULL, 'Momentinė šilumnešio šilumos galia, fiksuojama kas minutę', 1002, 1, NULL, NULL),
	(12375, 53, 1, 7, 1, 0, 1, 1, 70, NULL, 'Momentinė tiekiamo šilumnešio šilumos galia, fiksuojama kas minutę', 1002, 1, NULL, NULL),
	(12376, 215, 1, 6, 2, 0, 29, 6, 228, NULL, 'Tiekiamo šilumnešio apskaitos darbo laikas su klaida per mėnesį', 1795, 4, NULL, NULL),
	(12377, 215, 1, 5, 2, 0, 29, 5, 228, NULL, 'Tiekiamo šilumnešio apskaitos darbo laikas su klaida per parą', 1795, 3, NULL, NULL),
	(12378, 215, 1, 4, 2, 0, 29, 4, 228, NULL, 'Tiekiamo šilumnešio apskaitos darbo laikas su klaida per valandą', 1795, 2, NULL, NULL),
	(12379, 475, 1, 6, 2, 0, 31, 6, 494, NULL, 'Tiekiamo šilumnešio atbulinės krypties tūrio kiekis per mėnesį', 1794, 4, NULL, NULL),
	(12380, 475, 1, 5, 2, 0, 31, 5, 494, NULL, 'Tiekiamo šilumnešio atbulinės krypties tūrio kiekis per parą', 1794, 3, NULL, NULL),
	(12381, 475, 1, 4, 2, 0, 31, 4, 494, NULL, 'Tiekiamo šilumnešio atbulinės krypties tūrio kiekis per valandą', 1794, 2, NULL, NULL),
	(12382, 476, 1, 7, 1, 0, 80, 7, 495, NULL, 'Momentinis tiekiamo šilumnešio srauto greitis', 1796, 6, NULL, NULL),
	(12383, 477, 1, 7, 1, 0, 80, 7, 496, NULL, 'Momentinis tiekiamo šilumnešio ultragarsinio signalo greitis', 1797, 6, NULL, NULL),
	(12384, 478, 0, 6, 2, 0, 2, 6, 497, NULL, 'Šilumos kiekis sistemoje per mėnesį', 1798, 4, NULL, NULL),
	(12385, 478, 0, 1, 2, 0, 2, 1, 497, NULL, 'Šilumos kiekis sistemoje per minutę', 1798, 1, NULL, NULL),
	(12386, 478, 0, 5, 2, 0, 2, 5, 497, NULL, 'Šilumos kiekis sistemoje per parą', 1798, 3, NULL, NULL),
	(12387, 478, 0, 4, 2, 0, 2, 4, 497, NULL, 'Šilumos kiekis sistemoje per valandą', 1798, 2, NULL, NULL),
	(12388, 478, 0, 12, 2, 0, 2, 11, 497, NULL, 'Šilumos kiekis sistemoje per 10 minučių', 1798, 1, NULL, NULL),
	(12389, 478, 0, 13, 2, 0, 2, 12, 497, NULL, 'Šilumos kiekis sistemoje per 15 minučių', 1798, 2, NULL, NULL),
	(12390, 478, 0, 2, 2, 0, 2, 2, 497, NULL, 'Šilumos kiekis sistemoje per 2 minutes', 1798, 1, NULL, NULL),
	(12391, 478, 0, 14, 2, 0, 2, 13, 497, NULL, 'Šilumos kiekis sistemoje per 20 minučių', 1798, 2, NULL, NULL),
	(12392, 478, 0, 9, 2, 0, 2, 8, 497, NULL, 'Šilumos kiekis sistemoje per 3 minutes', 1798, 1, NULL, NULL),
	(12393, 478, 0, 3, 2, 0, 2, 3, 497, NULL, 'Šilumos kiekis sistemoje per 30 minučių', 1798, 2, NULL, NULL),
	(12394, 478, 0, 10, 2, 0, 2, 9, 497, NULL, 'Šilumos kiekis sistemoje per 4 minutes', 1798, 1, NULL, NULL),
	(12395, 478, 0, 11, 2, 0, 2, 10, 497, NULL, 'Šilumos kiekis sistemoje per 5 minutes', 1798, 1, NULL, NULL),
	(12396, 324, 0, 4, 2, 0, 57, 4, 337, NULL, 'Šalto vandens entalpija per valandą', 1229, 2, NULL, NULL),
	(12397, 324, 0, 5, 2, 0, 57, 5, 337, NULL, 'Šalto vandens entalpija per parą', 1229, 3, NULL, NULL),
	(12398, 324, 0, 6, 2, 0, 57, 6, 337, NULL, 'Šalto vandens entalpija per mėnesį', 1229, 4, NULL, NULL),
	(12399, 324, 2, 7, 1, 0, 57, 7, 337, NULL, 'Momentinė grįžtamo šalto vandens entalpija', 1230, 6, NULL, NULL),
	(12400, 324, 2, 4, 2, 0, 57, 4, 337, NULL, 'Grįžtamo šalto vandens entalpija per valandą', 1231, 2, NULL, NULL),
	(12401, 324, 2, 5, 2, 0, 57, 5, 337, NULL, 'Grįžtamo šalto vandens entalpija per parą', 1231, 3, NULL, NULL),
	(12402, 324, 2, 6, 2, 0, 57, 6, 337, NULL, 'Grįžtamo šalto vandens entalpija per mėnesį', 1231, 4, NULL, NULL),
	(12403, 479, 0, 8, 2, 0, 31, 7, 498, NULL, 'Suminis dujų nekonvertuotas Vc1err tūrio kiekis', 1176, 5, NULL, NULL),
	(12404, 480, 0, 7, 1, 0, 9, 7, 499, NULL, 'Momentinė azoto dalis dujose                       	', 1115, 6, NULL, NULL),
	(12405, 481, 0, 7, 1, 0, 9, 7, 500, NULL, 'Momentinė CO2 dalis dujose	', 1116, 6, NULL, NULL),
	(12406, 482, 0, 7, 1, 0, 82, 7, 501, NULL, 'Momentinis viršutinis dujų šilumingumas	', 1170, 6, NULL, NULL),
	(12407, 483, 0, 7, 1, 0, 0, 7, 502, NULL, 'Momentinis santykinis dujų tankis	', 1172, 6, NULL, NULL),
	(12408, 480, 0, 7, 1, 0, 9, 4, 499, NULL, 'Momentinė azoto dalis dujose, fiksuojama kas valandą	', 1115, 2, NULL, NULL),
	(12409, 481, 0, 7, 1, 0, 9, 4, 500, NULL, 'Momentinė CO2 dalis dujose, fiksuojama kas valandą	', 1116, 2, NULL, NULL),
	(12410, 482, 0, 7, 1, 0, 82, 4, 501, NULL, 'Momentinis viršutinis dujų šilumingumas, fiksuojamas kas valandą', 1170, 2, NULL, NULL),
	(12411, 483, 0, 7, 1, 0, 0, 4, 502, NULL, 'Momentinis santykinis dujų tankis, fiksuojamas kas valandą	', 1172, 2, NULL, NULL),
	(12412, 3, 0, 8, 2, 1, 4, 7, 15, NULL, 'Suminė R energija pagal 1 tarifą', 4300, 5, NULL, NULL),
	(12413, 3, 0, 8, 2, 2, 4, 7, 15, NULL, 'Suminė R energija pagal 2 tarifą', 4301, 5, NULL, NULL),
	(12414, 3, 0, 8, 2, 3, 4, 7, 15, NULL, 'Suminė R energija pagal 3 tarifą', 4302, 5, NULL, NULL),
	(12415, 3, 0, 8, 2, 4, 4, 7, 15, NULL, 'Suminė R energija pagal 4 tarifą', 4303, 5, NULL, NULL),
	(12416, 3, 0, 8, 2, 4, 4, 4, 15, NULL, 'Suminė R energija pagal 4 tarifą, fiksuojama kas valandą', 4303, 5, NULL, NULL),
	(12417, 3, 0, 8, 2, 4, 4, 5, 15, NULL, 'Suminė R energija pagal 4 tarifą, fiksuojama kas parą', 4303, 5, NULL, NULL),
	(12418, 3, 0, 8, 2, 4, 4, 6, 15, NULL, 'Suminė R energija pagal 4 tarifą, fiksuojama kas mėnesį', 4303, 5, NULL, NULL),
	(12419, 3, 0, 8, 2, 3, 4, 4, 15, NULL, 'Suminė R energija pagal 3 tarifą, fiksuojama kas valandą', 4302, 5, NULL, NULL),
	(12420, 3, 0, 8, 2, 3, 4, 5, 15, NULL, 'Suminė R energija pagal 3 tarifą, fiksuojama kas parą', 4302, 5, NULL, NULL),
	(12421, 3, 0, 8, 2, 3, 4, 6, 15, NULL, 'Suminė R energija pagal 3 tarifą, fiksuojama kas mėnesį', 4302, 5, NULL, NULL),
	(12422, 3, 0, 8, 2, 2, 4, 4, 15, NULL, 'Suminė R energija pagal 2 tarifą, fiksuojama kas valandą', 4301, 5, NULL, NULL),
	(12423, 3, 0, 8, 2, 2, 4, 5, 15, NULL, 'Suminė R energija pagal 2 tarifą, fiksuojama kas parą', 4301, 5, NULL, NULL),
	(12424, 3, 0, 8, 2, 2, 4, 6, 15, NULL, 'Suminė R energija pagal 2 tarifą, fiksuojama kas mėnesį', 4301, 5, NULL, NULL),
	(12425, 3, 0, 8, 2, 1, 4, 4, 15, NULL, 'Suminė R energija pagal 1 tarifą, fiksuojama kas valandą', 4300, 5, NULL, NULL),
	(12426, 3, 0, 8, 2, 1, 4, 5, 15, NULL, 'Suminė R energija pagal 1 tarifą, fiksuojama kas parą', 4300, 5, NULL, NULL),
	(12427, 3, 0, 8, 2, 1, 4, 6, 15, NULL, 'Suminė R energija pagal 1 tarifą, fiksuojama kas mėnesį', 4300, 5, NULL, NULL),
	(12428, 3, 0, 8, 2, 0, 4, 7, 15, NULL, 'Suminė R energija', 4053, 5, NULL, NULL),
	(12429, 3, 0, 8, 2, 0, 4, 4, 15, NULL, 'Suminė R energija, fiksuojama kas valandą', 4053, 5, NULL, NULL),
	(12430, 3, 0, 8, 2, 0, 4, 5, 15, NULL, 'Suminė R energija, fiksuojama kas parą', 4053, 5, NULL, NULL),
	(12431, 3, 0, 8, 2, 0, 4, 6, 15, NULL, 'Suminė R energija, fiksuojama kas mėnesį', 4053, 5, NULL, NULL),
	(12432, 44, 0, 7, 1, 0, 27, 10, 10, NULL, 'Momentinė dujų temperatūra, fiksuojama kas 5 minutes', 1103, 1, NULL, NULL),
	(12433, 430, 0, 8, 2, 0, 31, 5, 443, NULL, 'Suminis dujų turbulentinio tūrio kiekis, fiksuojamas kas parą', 1153, 5, NULL, NULL),
	(12434, 430, 0, 8, 2, 0, 31, 6, 443, NULL, 'Suminis dujų turbulentinio tūrio kiekis, fiksuojamas kas mėnesį', 1153, 5, NULL, NULL),
	(12435, 430, 0, 8, 2, 0, 31, 13, 443, NULL, 'Suminis dujų turbulentinio tūrio kiekis, fiksuojamas kas 20 minučių', 1153, 5, NULL, NULL),
	(12436, 430, 0, 8, 2, 0, 31, 12, 443, NULL, 'Suminis dujų turbulentinio tūrio kiekis, fiksuojamas kas 15 minučių', 1153, 5, NULL, NULL),
	(12437, 430, 0, 8, 2, 0, 31, 4, 443, NULL, 'Suminis dujų turbulentinio tūrio kiekis, fiksuojamas kas valandą', 1153, 5, NULL, NULL),
	(12438, 430, 0, 8, 2, 0, 31, 3, 443, NULL, 'Suminis dujų turbulentinio tūrio kiekis, fiksuojamas kas 30 minučių', 1153, 5, NULL, NULL),
	(12439, 430, 0, 8, 2, 0, 31, 10, 443, NULL, 'Suminis dujų turbulentinio tūrio kiekis, fiksuojamas kas 5 minutes', 1153, 5, NULL, NULL),
	(12440, 430, 0, 8, 2, 0, 31, 1, 443, NULL, 'Suminis dujų turbulentinio tūrio kiekis, fiksuojamas kas minutę', 1153, 5, NULL, NULL),
	(12441, 44, 0, 7, 1, 0, 27, 2, 10, NULL, 'Momentinė dujų temperatūra, fiksuojama kas 2 minutes', 1103, 1, NULL, NULL),
	(12442, 479, 0, 8, 2, 0, 31, 5, 498, NULL, 'Suminis dujų nekonvertuotas Vc1err tūrio kiekis, fiksuojamas kas parą', 1176, 5, NULL, NULL),
	(12443, 479, 0, 8, 2, 0, 31, 6, 498, NULL, 'Suminis dujų nekonvertuotas Vc1err tūrio kiekis, fiksuojamas kas mėnesį', 1176, 5, NULL, NULL),
	(12444, 479, 0, 8, 2, 0, 31, 13, 498, NULL, 'Suminis dujų nekonvertuotas Vc1err tūrio kiekis, fiksuojamas kas 20 minučių', 1176, 5, NULL, NULL),
	(12445, 479, 0, 8, 2, 0, 31, 12, 498, NULL, 'Suminis dujų nekonvertuotas Vc1err tūrio kiekis, fiksuojamas kas 15 minučių', 1176, 5, NULL, NULL),
	(12446, 479, 0, 8, 2, 0, 31, 4, 498, NULL, 'Suminis dujų nekonvertuotas Vc1err tūrio kiekis, fiksuojamas kas valandą', 1176, 5, NULL, NULL),
	(12447, 479, 0, 8, 2, 0, 31, 3, 498, NULL, 'Suminis dujų nekonvertuotas Vc1err tūrio kiekis, fiksuojamas kas 30 minučių', 1176, 5, NULL, NULL),
	(12448, 479, 0, 8, 2, 0, 31, 10, 498, NULL, 'Suminis dujų nekonvertuotas Vc1err tūrio kiekis, fiksuojamas kas 5 minutes', 1176, 5, NULL, NULL),
	(12449, 479, 0, 8, 2, 0, 31, 1, 498, NULL, 'Suminis dujų nekonvertuotas Vc1err tūrio kiekis, fiksuojamas kas minutę', 1176, 5, NULL, NULL),
	(12450, 44, 0, 7, 1, 0, 27, 1, 10, NULL, 'Momentinė dujų temperatūra, fiksuojama kas minutę', 1103, 1, NULL, NULL),
	(12451, 44, 0, 7, 1, 0, 27, 19, 10, NULL, 'Momentinė dujų temperatūra, fiksuojama kas 30 sekundžių', 1103, 7, NULL, NULL),
	(12452, 44, 0, 7, 1, 0, 27, 5, 10, NULL, 'Momentinė dujų temperatūra, fiksuojama kas parą', 1103, 3, NULL, NULL),
	(12453, 44, 0, 7, 1, 0, 27, 4, 10, NULL, 'Momentinė dujų temperatūra, fiksuojama kas valandą', 1103, 2, NULL, NULL),
	(12454, 44, 0, 7, 1, 0, 27, 3, 10, NULL, 'Momentinė dujų temperatūra, fiksuojama kas 30 minučių', 1103, 2, NULL, NULL),
	(12455, 44, 0, 7, 1, 0, 27, 12, 10, NULL, 'Momentinė dujų temperatūra, fiksuojama kas 15 minučių', 1103, 2, NULL, NULL),
	(12456, 44, 0, 7, 1, 0, 27, 8, 10, NULL, 'Momentinė dujų temperatūra, fiksuojama kas 3 minutes', 1103, 1, NULL, NULL),
	(12457, 42, 0, 7, 1, 0, 28, 10, 7, NULL, 'Momentinis dujų slėgis, fiksuojamas kas 5 minutes', 1104, 1, NULL, NULL),
	(12458, 42, 0, 7, 1, 0, 28, 2, 7, NULL, 'Momentinis dujų slėgis, fiksuojamas kas 2 minutes', 1104, 1, NULL, NULL),
	(12459, 42, 0, 7, 1, 0, 28, 1, 7, NULL, 'Momentinis dujų slėgis, fiksuojamas kas minutę', 1104, 1, NULL, NULL),
	(12460, 42, 0, 7, 1, 0, 28, 19, 7, NULL, 'Momentinis dujų slėgis, fiksuojamas kas 30 sekundžių', 1104, 7, NULL, NULL),
	(12461, 42, 0, 7, 1, 0, 28, 5, 7, NULL, 'Momentinis dujų slėgis, fiksuojamas kas parą', 1104, 3, NULL, NULL),
	(12462, 42, 0, 7, 1, 0, 28, 4, 7, NULL, 'Momentinis dujų slėgis, fiksuojamas kas valandą', 1104, 2, NULL, NULL),
	(12463, 42, 0, 7, 1, 0, 28, 3, 7, NULL, 'Momentinis dujų slėgis, fiksuojamas kas 30 minučių', 1104, 2, NULL, NULL),
	(12464, 42, 0, 7, 1, 0, 28, 12, 7, NULL, 'Momentinis dujų slėgis, fiksuojamas kas 15 minučių', 1104, 2, NULL, NULL),
	(12465, 42, 0, 7, 1, 0, 28, 8, 7, NULL, 'Momentinis dujų slėgis, fiksuojamas kas 3 minutes', 1104, 1, NULL, NULL),
	(12466, 40, 0, 7, 1, 0, 32, 10, 3, NULL, 'Momentinis dujų koreguoto tūrio debitas, fiksuojamas kas 5 minutes', 1113, 1, NULL, NULL),
	(12467, 40, 0, 7, 1, 0, 32, 2, 3, NULL, 'Momentinis dujų koreguoto tūrio debitas, fiksuojamas kas 2 minutes', 1113, 1, NULL, NULL),
	(12468, 40, 0, 7, 1, 0, 32, 1, 3, NULL, 'Momentinis dujų koreguoto tūrio debitas, fiksuojamas kas minutę', 1113, 1, NULL, NULL),
	(12469, 40, 0, 7, 1, 0, 32, 19, 3, NULL, 'Momentinis dujų koreguoto tūrio debitas, fiksuojamas kas 30 sekundžių', 1113, 7, NULL, NULL),
	(12470, 40, 0, 7, 1, 0, 32, 5, 3, NULL, 'Momentinis dujų koreguoto tūrio debitas, fiksuojamas kas parą', 1113, 3, NULL, NULL),
	(12471, 40, 0, 7, 1, 0, 32, 4, 3, NULL, 'Momentinis dujų koreguoto tūrio debitas, fiksuojamas kas valandą', 1113, 2, NULL, NULL),
	(12472, 40, 0, 7, 1, 0, 32, 3, 3, NULL, 'Momentinis dujų koreguoto tūrio debitas, fiksuojamas kas 30 minučių', 1113, 2, NULL, NULL),
	(12473, 40, 0, 7, 1, 0, 32, 12, 3, NULL, 'Momentinis dujų koreguoto tūrio debitas, fiksuojamas kas 15 minučių', 1113, 2, NULL, NULL),
	(12474, 40, 0, 7, 1, 0, 32, 8, 3, NULL, 'Momentinis dujų koreguoto tūrio debitas, fiksuojamas kas 3 minutes', 1113, 1, NULL, NULL),
	(12475, 430, 0, 8, 2, 0, 31, 11, 443, NULL, 'Suminis dujų turbulentinio tūrio kiekis, fiksuojamas kas 10 minučių', 1153, 5, NULL, NULL),
	(12476, 479, 0, 8, 2, 0, 31, 11, 498, NULL, 'Suminis dujų nekonvertuotas Vc1err tūrio kiekis, fiksuojamas kas 10 minučių', 1176, 5, NULL, NULL),
	(12477, 44, 0, 7, 1, 0, 27, 11, 10, NULL, 'Momentinė dujų temperatūra, fiksuojama kas 10 minučių', 1103, 1, NULL, NULL),
	(12478, 42, 0, 7, 1, 0, 28, 11, 7, NULL, 'Momentinis dujų slėgis, fiksuojamas kas 10 minučių', 1104, 1, NULL, NULL),
	(12479, 40, 0, 7, 1, 0, 32, 11, 3, NULL, 'Momentinis dujų koreguoto tūrio debitas, fiksuojamas kas 10 minučių', 1113, 1, NULL, NULL);
/*!40000 ALTER TABLE `ml` ENABLE KEYS */;

-- Dumping structure for table emcor.mlf
CREATE TABLE IF NOT EXISTS `mlf` (
  `mlf_id` tinyint(3) unsigned NOT NULL COMMENT 'Matavimų klasifikatoriaus lauko, naudojamo duomenų surinkime, identifikatorius',
  `mlf_code` varchar(30) COLLATE utf8_bin NOT NULL COMMENT 'Matavimų klasifikatoriaus lauko, naudojamo duomenų surinkime, kodas',
  PRIMARY KEY (`mlf_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimų klasifikatoriaus laukai, naudojami duomenų surinkime';

-- Dumping data for table emcor.mlf: ~9 rows (approximately)
/*!40000 ALTER TABLE `mlf` DISABLE KEYS */;
INSERT INTO `mlf` (`mlf_id`, `mlf_code`) VALUES
	(1, 'Env'),
	(2, 'Meas'),
	(3, 'Dir'),
	(4, 'Func'),
	(5, 'AggSg'),
	(6, 'TrNr'),
	(7, 'Phase'),
	(8, 'Scope'),
	(9, 'HrmNr');
/*!40000 ALTER TABLE `mlf` ENABLE KEYS */;

-- Dumping structure for table emcor.mlset
CREATE TABLE IF NOT EXISTS `mlset` (
  `mlset_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Matavimų rinkinio identifikatorius',
  `mlset_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo rinkinio kodas',
  `mlset_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Matavimų rinkinio pavadinimas',
  PRIMARY KEY (`mlset_id`),
  UNIQUE KEY `mlset_code_u` (`mlset_code`),
  UNIQUE KEY `mlset_name_u` (`mlset_name`)
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimų linijų rinkiniai';

-- Dumping data for table emcor.mlset: ~4 rows (approximately)
/*!40000 ALTER TABLE `mlset` DISABLE KEYS */;
INSERT INTO `mlset` (`mlset_id`, `mlset_code`, `mlset_name`) VALUES
	(1, 'LZQM_EPQM_LZKM_INSTANT', 'LZQM, EPQM, LZKM momentiniai'),
	(2, 'EMS_INSTANT', 'EMS momentiniai'),
	(3, 'EPQS_INSTANT', 'EPQS momentiniai'),
	(4, 'NEEDLESS', 'Nepageidaujami automatiniam konfigūravimui matavimai');
/*!40000 ALTER TABLE `mlset` ENABLE KEYS */;

-- Dumping structure for table emcor.mlset_data
CREATE TABLE IF NOT EXISTS `mlset_data` (
  `mlset_id` int(10) unsigned NOT NULL COMMENT 'Matavimų rinkinio identifikatorius',
  `ml_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo linijos identifikatorius',
  PRIMARY KEY (`mlset_id`,`ml_id`),
  KEY `mlset_data_ml_i` (`ml_id`),
  CONSTRAINT `mlset_data_ml_fk` FOREIGN KEY (`ml_id`) REFERENCES `ml` (`ml_id`) ON DELETE CASCADE,
  CONSTRAINT `mlset_data_mlset_fk` FOREIGN KEY (`mlset_id`) REFERENCES `mlset` (`mlset_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimų linijų rinkinių sudėtis';

-- Dumping data for table emcor.mlset_data: ~53 rows (approximately)
/*!40000 ALTER TABLE `mlset_data` DISABLE KEYS */;
INSERT INTO `mlset_data` (`mlset_id`, `ml_id`) VALUES
	(1, 53),
	(1, 54),
	(1, 55),
	(1, 56),
	(1, 57),
	(1, 58),
	(1, 62),
	(1, 63),
	(1, 64),
	(1, 65),
	(1, 66),
	(1, 67),
	(1, 84),
	(1, 85),
	(2, 53),
	(2, 54),
	(2, 55),
	(2, 56),
	(2, 57),
	(2, 58),
	(2, 62),
	(2, 63),
	(2, 64),
	(2, 65),
	(2, 66),
	(2, 67),
	(2, 85),
	(3, 53),
	(3, 54),
	(3, 55),
	(3, 56),
	(3, 57),
	(3, 58),
	(3, 59),
	(3, 60),
	(3, 61),
	(3, 62),
	(3, 63),
	(3, 64),
	(3, 65),
	(3, 66),
	(3, 67),
	(3, 68),
	(3, 69),
	(3, 70),
	(3, 71),
	(3, 72),
	(3, 73),
	(3, 74),
	(3, 75),
	(3, 76),
	(3, 85),
	(3, 86);
/*!40000 ALTER TABLE `mlset_data` ENABLE KEYS */;

-- Dumping structure for table emcor.mlset_ds_data
CREATE TABLE IF NOT EXISTS `mlset_ds_data` (
  `mlset_id` int(10) unsigned NOT NULL COMMENT 'Matavimų rinkinio identifikatorius',
  `ds_type_id` int(10) unsigned NOT NULL COMMENT 'Apskaitos būsenų signalų tipo identifikatorius',
  PRIMARY KEY (`mlset_id`,`ds_type_id`),
  KEY `mlset_ds_data_ds_type_fk` (`ds_type_id`),
  CONSTRAINT `mlset_ds_data_ds_type_fk` FOREIGN KEY (`ds_type_id`) REFERENCES `ds_type` (`ds_type_id`) ON DELETE CASCADE,
  CONSTRAINT `mlset_ds_data_mlset_fk` FOREIGN KEY (`mlset_id`) REFERENCES `mlset` (`mlset_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Diskretinių matavimų rinkinių sudėtis';

-- Dumping data for table emcor.mlset_ds_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `mlset_ds_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `mlset_ds_data` ENABLE KEYS */;

-- Dumping structure for table emcor.mou
CREATE TABLE IF NOT EXISTS `mou` (
  `mou_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Montažo identifikatorius',
  `mou_bt` datetime DEFAULT NULL COMMENT 'Montavimo data',
  `mou_et` datetime DEFAULT NULL COMMENT 'Išmontavimo data',
  `meter_id` int(10) unsigned NOT NULL COMMENT 'Matavimo priemonės identifikatorius',
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `mou_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Pajungimo schemos identifikatorius',
  `mou_bt_db_time` datetime DEFAULT NULL COMMENT 'Montavimo suvedimo data',
  `mou_et_db_time` datetime DEFAULT NULL COMMENT 'Demontavimo suvedimo data',
  `mou_bt_number` varchar(50) COLLATE utf8_bin DEFAULT NULL COMMENT 'Montavimo užduoties numeris',
  `mou_et_number` varchar(50) COLLATE utf8_bin DEFAULT NULL COMMENT 'Demontavimo užduoties numeris',
  PRIMARY KEY (`mou_id`),
  KEY `mou_meter_i` (`meter_id`),
  KEY `mou_mou_type_i` (`mou_type_id`),
  KEY `mou_point_i` (`point_id`,`mou_bt`,`mou_et`),
  CONSTRAINT `mou_meter_fk` FOREIGN KEY (`meter_id`) REFERENCES `meter` (`meter_id`) ON DELETE CASCADE,
  CONSTRAINT `mou_mou_type_fk` FOREIGN KEY (`mou_type_id`) REFERENCES `mou_type` (`mou_type_id`),
  CONSTRAINT `mou_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimo prietaisų montavimų matavimo taškuose istorija';

-- Dumping data for table emcor.mou: ~0 rows (approximately)
/*!40000 ALTER TABLE `mou` DISABLE KEYS */;
/*!40000 ALTER TABLE `mou` ENABLE KEYS */;

-- Dumping structure for table emcor.mou_type
CREATE TABLE IF NOT EXISTS `mou_type` (
  `mou_type_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Pajungimo schemos identifikatorius',
  `mou_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Pajungimo schemos pavadinimas',
  PRIMARY KEY (`mou_type_id`),
  UNIQUE KEY `mou_type_name_u` (`mou_type_name`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Montavimų tipai';

-- Dumping data for table emcor.mou_type: ~0 rows (approximately)
/*!40000 ALTER TABLE `mou_type` DISABLE KEYS */;
INSERT INTO `mou_type` (`mou_type_id`, `mou_type_name`) VALUES
	(1, 'Skaitiklio montavimas');
/*!40000 ALTER TABLE `mou_type` ENABLE KEYS */;

-- Dumping structure for table emcor.mpty
CREATE TABLE IF NOT EXISTS `mpty` (
  `mpty_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Matavimo priemonių savybės identifikatorius',
  `mpty_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo priemonių savybės kodas',
  `mpty_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo priemonių savybės pavadinimas',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  `mpty_type_id` mediumint(8) unsigned NOT NULL DEFAULT 1 COMMENT 'Galimų matavimo prietaisų savybių sąrašų tipo identifikatorius',
  `mpty_nr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Matavimo priemonių savybės eilės numeris rušiavimui',
  PRIMARY KEY (`mpty_id`),
  UNIQUE KEY `mpty_code_u` (`mpty_code`),
  UNIQUE KEY `mpty_name_u` (`mpty_name`),
  KEY `mpty_enum_i` (`enum_id`),
  KEY `mpty_type_id_i` (`mpty_type_id`),
  CONSTRAINT `mpty_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`),
  CONSTRAINT `mpty_type_id_fk` FOREIGN KEY (`mpty_type_id`) REFERENCES `mpty_type` (`mpty_type_id`)
) ENGINE=InnoDB AUTO_INCREMENT=74 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Galimų matavimo prietaisų savybių sąrašas';

-- Dumping data for table emcor.mpty: ~9 rows (approximately)
/*!40000 ALTER TABLE `mpty` DISABLE KEYS */;
INSERT INTO `mpty` (`mpty_id`, `mpty_code`, `mpty_name`, `enum_id`, `mpty_type_id`, `mpty_nr`) VALUES
	(65, 'dstEnabled', 'Žiemos/vasaros laiko pervedimo požymis', NULL, 7, NULL),
	(66, 'loadControl', 'Apkrovos valdymo funkcijos palaikymas', NULL, 7, NULL),
	(67, 'lotNumber', 'Tiekimo partijos numeris', NULL, 7, NULL),
	(68, 'outageReport', 'Sutrikimų registracija', NULL, 7, NULL),
	(69, 'readRequest', 'Galimas rankinis nuskaitymas per šviesolaidinį portą', NULL, 7, NULL),
	(70, 'relayCapable', 'Apkrovos išjungimo relė', NULL, 7, NULL),
	(71, 'reverseFlowHandling', 'Atgalinės srovės apdorojimas', NULL, 7, NULL),
	(72, 'modelNumber', 'Modelio numeris', NULL, 7, NULL),
	(73, 'modelVersion', 'Modelio versija', NULL, 7, NULL);
/*!40000 ALTER TABLE `mpty` ENABLE KEYS */;

-- Dumping structure for table emcor.mpty_type
CREATE TABLE IF NOT EXISTS `mpty_type` (
  `mpty_type_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Galimų matavimo prietaisų savybių sąrašų tipo identifikatorius',
  `mpty_type_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Galimų matavimo prietaisų savybių sąrašų tipo kodas',
  `mpty_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Galimų matavimo prietaisų savybių sąrašų tipo pavadinimas',
  PRIMARY KEY (`mpty_type_id`),
  UNIQUE KEY `mpty_type_code_uniq` (`mpty_type_code`),
  UNIQUE KEY `mpty_type_name_uniq` (`mpty_type_name`)
) ENGINE=InnoDB AUTO_INCREMENT=8 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Galimų matavimo prietaisų savybių sąrašų tipai';

-- Dumping data for table emcor.mpty_type: ~2 rows (approximately)
/*!40000 ALTER TABLE `mpty_type` DISABLE KEYS */;
INSERT INTO `mpty_type` (`mpty_type_id`, `mpty_type_code`, `mpty_type_name`) VALUES
	(1, 'OTHER_PROPS', 'Kitos savybės'),
	(7, 'WS', 'Apskaitos prietaisų savybės WEB-servisui');
/*!40000 ALTER TABLE `mpty_type` ENABLE KEYS */;

-- Dumping structure for table emcor.ms
CREATE TABLE IF NOT EXISTS `ms` (
  `ms_id` smallint(5) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Matavimo identifikatorius',
  `ms_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo kodas',
  `ms_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo pavadinimas',
  `ms_type_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimų tipo identifikatorius',
  `ms_kind_id` mediumint(8) unsigned DEFAULT NULL,
  `phase` tinyint(3) unsigned DEFAULT NULL,
  `scope` varchar(1) COLLATE utf8_bin DEFAULT NULL,
  PRIMARY KEY (`ms_id`),
  UNIQUE KEY `ms_code_u` (`ms_code`),
  UNIQUE KEY `ms_ms_name_u` (`ms_name`),
  KEY `ms_ms_type_i` (`ms_type_id`),
  CONSTRAINT `ms_ms_type_fk` FOREIGN KEY (`ms_type_id`) REFERENCES `ms_type` (`ms_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=484 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimų tipai';

-- Dumping data for table emcor.ms: ~445 rows (approximately)
/*!40000 ALTER TABLE `ms` DISABLE KEYS */;
INSERT INTO `ms` (`ms_id`, `ms_code`, `ms_name`, `ms_type_id`, `ms_kind_id`, `phase`, `scope`) VALUES
	(1, 'P', 'Elektros aktyvinė galia/energija', 1, 1, NULL, NULL),
	(2, 'HWt_WeightAverageTemp', 'Karšto vandens temperatūros svertinis vidurkis', 11, 154, NULL, NULL),
	(3, 'Q', 'Elektros reaktyvinė galia/energija', 1, 2, NULL, NULL),
	(4, 'HWt_AbsolutePress', 'Absoliutus karšto vandens slėgis', 11, 153, NULL, NULL),
	(5, 'I1', 'Elektros srovės stiprumas L1 fazėje', 1, 3, 1, NULL),
	(6, 'U1', 'Elektros įtampa L1 fazėje', 1, 4, 1, NULL),
	(7, 'I2', 'Elektros srovės stiprumas L2 fazėje', 1, 3, 2, NULL),
	(8, 'U2', 'Elektros įtampa L2 fazėje', 1, 4, 2, NULL),
	(9, 'I3', 'Elektros srovės stiprumas L3 fazėje', 1, 3, 3, NULL),
	(10, 'U3', 'Elektros įtampa L3 fazėje', 1, 4, 3, NULL),
	(11, 'UL1', 'Elektros linijinė įtampa L1 fazėje', 1, 5, 1, NULL),
	(12, 'UL2', 'Elektros linijinė įtampa L2 fazėje', 1, 5, 2, NULL),
	(13, 'UL3', 'Elektros linijinė įtampa L3 fazėje', 1, 5, 3, NULL),
	(14, 'P1', 'Elektros aktyvinė galia L1 fazėje', 1, 1, 1, NULL),
	(15, 'P2', 'Elektros aktyvinė galia L2 fazėje', 1, 1, 2, NULL),
	(16, 'P3', 'Elektros aktyvinė galia L3 fazėje', 1, 1, 3, NULL),
	(17, 'Q1', 'Elektros reaktyvinė galia L1 fazėje', 1, 2, 1, NULL),
	(18, 'Q2', 'Elektros reaktyvinė galia L2 fazėje', 1, 2, 2, NULL),
	(19, 'Q3', 'Elektros reaktyvinė galia L3 fazėje', 1, 2, 3, NULL),
	(20, 'S1', 'Elektros pilnoji galia L1 fazėje', 1, 6, 1, NULL),
	(21, 'S2', 'Elektros pilnoji galia L2 fazėje', 1, 6, 2, NULL),
	(22, 'S3', 'Elektros pilnoji galia L3 fazėje', 1, 6, 3, NULL),
	(23, 'Cos1', 'Elektros cos(fi) L1 fazėje', 1, 7, 1, NULL),
	(24, 'Cos2', 'Elektros cos(fi) L2 fazėje', 1, 7, 2, NULL),
	(25, 'Cos3', 'Elektros cos(fi) L3 fazėje', 1, 7, 3, NULL),
	(26, 'Quadrant1', 'Elektros kvadrantas L1 fazėje', 1, 8, 1, NULL),
	(27, 'Quadrant2', 'Elektros kvadrantas L2 fazėje', 1, 8, 2, NULL),
	(28, 'Quadrant3', 'Elektros kvadrantas L3 fazėje', 1, 8, 3, NULL),
	(29, 'I', 'Elektros srovės stiprumas', 1, 3, NULL, NULL),
	(30, 'U', 'Elektros įtampa', 1, 4, NULL, NULL),
	(31, 'UL', 'Elektros linijinė įtampa', 1, 5, NULL, NULL),
	(32, 'HWt_DifferentialPress', 'Diferencinis karšto vandens slėgis', 11, 9, NULL, NULL),
	(33, 'DWt_DifferentialPress', 'Diferencinis šalto vandens slėgis', 8, 9, NULL, NULL),
	(34, 'S', 'Elektros pilnoji galia', 1, 6, NULL, NULL),
	(35, 'Cos', 'Elektros cos(fi)', 1, 7, NULL, NULL),
	(36, 'Quadrant', 'Elektros kvadrantas', 1, 8, NULL, NULL),
	(37, 'F', 'Elektros dažnis', 1, 10, NULL, NULL),
	(38, 'FS', 'Elektros fazių seka', 1, 11, NULL, NULL),
	(39, 'Gas_CorrMass', 'Dujų koreguota masė', 7, 12, NULL, NULL),
	(40, 'Gas_CorrVol', 'Dujų koreguotas tūris', 7, 13, NULL, NULL),
	(41, 'Gas_Mass', 'Dujų masė', 7, 14, NULL, NULL),
	(42, 'Gas_Press', 'Dujų slėgis', 7, 15, NULL, NULL),
	(43, 'Gas_Heat', 'Dujų šiluma', 7, 16, NULL, NULL),
	(44, 'Gas_Temp', 'Dujų temperatūra', 7, 17, NULL, NULL),
	(45, 'Gas_Vol', 'Dujų tūris', 7, 18, NULL, NULL),
	(46, 'Air_Temp', 'Oro temperatūra', 2, 17, NULL, NULL),
	(47, 'Frost_Press', 'Šalčio slėgis', 5, 15, NULL, NULL),
	(48, 'Frost_Energy', 'Šalčio energija', 5, 19, NULL, NULL),
	(49, 'Frost_Temp', 'Šalčio temperatūra', 5, 17, NULL, NULL),
	(50, 'Frost_Vol', 'Šalčio tūris', 5, 18, NULL, NULL),
	(51, 'Ht_Mass', 'Šilumnešio masė', 6, 14, NULL, NULL),
	(52, 'Ht_Press', 'Šilumnešio slėgis', 6, 15, NULL, NULL),
	(53, 'Ht_Heat', 'Šilumnešio šiluma', 6, 16, NULL, NULL),
	(54, 'Ht_Temp', 'Šilumnešio temperatūra', 6, 17, NULL, NULL),
	(55, 'Ht_Vol', 'Šilumnešio tūris', 6, 18, NULL, NULL),
	(56, 'DWt_Heat', 'Šalto vandens šiluma', 8, 16, NULL, NULL),
	(57, 'DWt_Temp', 'Šalto vandens temperatūra', 8, 17, NULL, NULL),
	(58, 'DWt_Vol', 'Šalto vandens tūris', 8, 18, NULL, NULL),
	(59, 'HWt_Heat', 'Karšto vandens šiluma', 11, 16, NULL, NULL),
	(60, 'HWt_Temp', 'Karšto vandens temperatūra', 11, 17, NULL, NULL),
	(61, 'HWt_Vol', 'Karšto vandens tūris', 11, 18, NULL, NULL),
	(62, 'Ht_Work', 'Šilumnešio skaitiklio darbo laikas', 6, 20, NULL, 'D'),
	(63, 'Ht_NotWork', 'Šilumnešio skaitiklio nedarbo laikas', 6, 21, NULL, 'D'),
	(64, 'DWt_Work', 'Šalto vandens skaitiklio darbo laikas', 8, 20, NULL, NULL),
	(65, 'HWt_Work', 'Karšto vandens skaitiklio darbo laikas', 11, 20, NULL, 'D'),
	(66, 'CoefBackwSeq', 'Atvirkštinės sekos nesimetrijos koeficientas', 1, 22, NULL, NULL),
	(67, 'CoefBackwSeqHiHiPrc', 'Atvirkštinės sekos nesimetrijos koeficiento ALN peržengimo %', 1, 23, NULL, NULL),
	(68, 'CoefBackwSeqHiPrc', 'Atvirkštinės sekos nesimetrijos koeficiento NLN peržengimo %', 1, 24, NULL, NULL),
	(69, 'CoefZeroSeq', 'Nulinės sekos nesimetrijos koeficientas', 1, 25, NULL, NULL),
	(70, 'CoefZeroSeqHiHiPrc', 'Nulinės sekos nesimetrijos koeficiento ALN peržengimo %', 1, 26, NULL, NULL),
	(71, 'CoefZeroSeqHiPrc', 'Nulinės sekos nesimetrijos koeficiento NLN peržengimo %', 1, 27, NULL, NULL),
	(72, 'Flicker1', 'Trumpalaikė mirksėjimo dozė L1 fazėje', 1, 28, 1, NULL),
	(73, 'Flicker1HiHiPrc', 'Trumpalaikės mirksėjimo dozės L1 fazėje ALN peržengimo %', 1, 29, 1, NULL),
	(74, 'Flicker2', 'Trumpalaikė mirksėjimo dozė L2 fazėje', 1, 28, 2, NULL),
	(75, 'Flicker2HiHiPrc', 'Trumpalaikės mirksėjimo dozės L2 fazėje ALN peržengimo %', 1, 29, 2, NULL),
	(76, 'Flicker3', 'Trumpalaikė mirksėjimo dozė L3 fazėje', 1, 28, 3, NULL),
	(77, 'Flicker3HiHiPrc', 'Trumpalaikės mirksėjimo dozės L3 fazėje ALN peržengimo %', 1, 29, 3, NULL),
	(78, 'FreqDev', 'Dažnio nukrypimas', 1, 30, NULL, NULL),
	(79, 'FreqDev1', 'Dažnio nukrypimas L1 fazėje', 1, 30, 1, NULL),
	(80, 'FreqDev1HiHiPrc', 'Dažnio nukrypimo L1 fazėje ALN peržengimo %', 1, 31, 1, NULL),
	(81, 'FreqDev1HiPrc', 'Dažnio nukrypimo L1 fazėje NLN peržengimo %', 1, 32, 1, NULL),
	(82, 'FreqDev2', 'Dažnio nukrypimas L2 fazėje', 1, 30, 2, NULL),
	(83, 'FreqDev2HiHiPrc', 'Dažnio nukrypimo L2 fazėje ALN peržengimo %', 1, 31, 2, NULL),
	(84, 'FreqDev2HiPrc', 'Dažnio nukrypimo L2 fazėje NLN peržengimo %', 1, 32, 2, NULL),
	(85, 'FreqDev3', 'Dažnio nukrypimas L3 fazėje', 1, 30, 3, NULL),
	(86, 'FreqDev3HiHiPrc', 'Dažnio nukrypimo L3 fazėje ALN peržengimo %', 1, 31, 3, NULL),
	(87, 'FreqDev3HiPrc', 'Dažnio nukrypimo L3 fazėje NLN peržengimo %', 1, 32, 3, NULL),
	(88, 'FreqDevHiHiPrc', 'Dažnio nukrypimo ALN peržengimo %', 1, 31, NULL, NULL),
	(89, 'FreqDevHiPrc', 'Dažnio nukrypimo NLN peržengimo %', 1, 32, NULL, NULL),
	(90, 'HarmCoef1', 'Įtampos harmonikų koeficientai L1 fazėje', 1, 33, 1, NULL),
	(91, 'HarmCoef1HiHiPrc', 'Harmoninių srovių koeficientų L1 fazėje ALN peržengimo %', 1, 34, 1, NULL),
	(92, 'HarmCoef1HiPrc', 'Harmoninių srovių koeficientų L1 fazėje NLN peržengimo %', 1, 35, 1, NULL),
	(93, 'HarmCoef2', 'Įtampos harmonikų koeficientai L2 fazėje', 1, 33, 2, NULL),
	(94, 'HarmCoef2HiHiPrc', 'Harmoninių srovių koeficientų L2 fazėje ALN peržengimo %', 1, 34, 2, NULL),
	(95, 'HarmCoef2HiPrc', 'Harmoninių srovių koeficientų L2 fazėje NLN peržengimo %', 1, 35, 2, NULL),
	(96, 'HarmCoef3', 'Įtampos harmonikų koeficientai L3 fazėje', 1, 33, 3, NULL),
	(97, 'HarmCoef3HiHiPrc', 'Harmoninių srovių koeficientų L3 fazėje ALN peržengimo %', 1, 34, 3, NULL),
	(98, 'HarmCoef3HiPrc', 'Harmoninių srovių koeficientų L3 fazėje NLN peržengimo %', 1, 35, 3, NULL),
	(99, 'HarmQual1', 'Harmoninių srovių koeficientų kokybė L1 fazėje', 1, 36, 1, NULL),
	(100, 'HarmQual2', 'Harmoninių srovių koeficientų kokybė L2 fazėje', 1, 36, 2, NULL),
	(101, 'HarmQual3', 'Harmoninių srovių koeficientų kokybė L3 fazėje', 1, 36, 3, NULL),
	(102, 'LongFlicker1', 'Ilgalaikė mirksėjimo dozė L1 fazėje', 1, 37, 1, NULL),
	(103, 'LongFlicker1HiHiPrc', 'Ilgalaikės mirksėjimo dozės L1 fazėje ALN peržengimo %', 1, 38, 1, NULL),
	(104, 'LongFlicker2', 'Ilgalaikė mirksėjimo dozė L2 fazėje', 1, 37, 2, NULL),
	(105, 'LongFlicker2HiHiPrc', 'Ilgalaikės mirksėjimo dozės L2 fazėje ALN peržengimo %', 1, 38, 2, NULL),
	(106, 'LongFlicker3', 'Ilgalaikė mirksėjimo dozė L3 fazėje', 1, 37, 3, NULL),
	(107, 'LongFlicker3HiHiPrc', 'Ilgalaikės mirksėjimo dozės L3 fazėje ALN peržengimo %', 1, 38, 3, NULL),
	(108, 'MainHarmValue1', 'Pagrindinės harmoninės srovės dabartinė reikšmė L1 fazėje', 1, 39, 1, NULL),
	(109, 'MainHarmValue2', 'Pagrindinės harmoninės srovės dabartinė reikšmė L2 fazėje', 1, 39, 2, NULL),
	(110, 'MainHarmValue3', 'Pagrindinės harmoninės srovės dabartinė reikšmė L3 fazėje', 1, 39, 3, NULL),
	(111, 'SinDistort1', 'Sinusoidės iškreipimo koeficientas L1 fazėje', 1, 40, 1, NULL),
	(112, 'SinDistort1HiHiPrc', 'Sinusoidės iškreipimo koeficiento L1 fazėje ALN peržengimo %', 1, 41, 1, NULL),
	(113, 'SinDistort1HiPrc', 'Sinusoidės iškreipimo koeficiento L1 fazėje NLN peržengimo %', 1, 42, 1, NULL),
	(114, 'SinDistort2', 'Sinusoidės iškreipimo koeficientas L2 fazėje', 1, 40, 2, NULL),
	(115, 'SinDistort2HiHiPrc', 'Sinusoidės iškreipimo koeficiento L2 fazėje ALN peržengimo %', 1, 41, 2, NULL),
	(116, 'SinDistort2HiPrc', 'Sinusoidės iškreipimo koeficiento L2 fazėje NLN peržengimo %', 1, 42, 2, NULL),
	(117, 'SinDistort3', 'Sinusoidinės iškreipimo koeficientas L3 fazėje', 1, 40, 3, NULL),
	(118, 'SinDistort3HiHiPrc', 'Sinusoidės iškreipimo koeficiento L3 fazėje ALN peržengimo %', 1, 41, 3, NULL),
	(119, 'SinDistort3HiPrc', 'Sinusoidės iškreipimo koeficiento L3 fazėje NLN peržengimo %', 1, 42, 3, NULL),
	(120, 'VoltDev', 'Susidaręs įtampos nukrypimas', 1, 43, NULL, NULL),
	(121, 'VoltDev1', 'Susidaręs įtampos nukrypimas L1 fazėje', 1, 43, 1, NULL),
	(122, 'VoltDev1HiHiPrc', 'Susidarusio įtampos nukrypimo L1 fazėje ALN peržengimo %', 1, 44, 1, NULL),
	(123, 'VoltDev1HiPrc', 'Susidarusio įtampos nukrypimo L1 fazėje NLN peržengimo %', 1, 45, 1, NULL),
	(124, 'VoltDev2', 'Susidaręs įtampos nukrypimas L2 fazėje', 1, 43, 2, NULL),
	(125, 'VoltDev2HiHiPrc', 'Susidarusio įtampos nukrypimo L2 fazėje ALN peržengimo %', 1, 44, 2, NULL),
	(126, 'VoltDev2HiPrc', 'Susidarusio įtampos nukrypimo L2 fazėje NLN peržengimo %', 1, 45, 2, NULL),
	(127, 'VoltDev3', 'Susidaręs įtampos nukrypimas L3 fazėje', 1, 43, 3, NULL),
	(128, 'VoltDev3HiHiPrc', 'Susidarusio įtampos nukrypimo L3 fazėje ALN peržengimo %', 1, 44, 3, NULL),
	(129, 'VoltDev3HiPrc', 'Susidarusio įtampos nukrypimo L3 fazėje NLN peržengimo %', 1, 45, 3, NULL),
	(130, 'VoltDevAmpl1', 'Įtampos pakeitimų diapazono amplitudė L1 fazėje', 1, 46, 1, NULL),
	(131, 'VoltDevAmpl1HiHiPrc', 'Įtampos pakeitimų diapazono amplitudės L1 fazėje ALN peržengimo %', 1, 47, 1, NULL),
	(132, 'VoltDevAmpl2', 'Įtampos pakeitimų diapazono amplitudė L2 fazėje', 1, 46, 2, NULL),
	(133, 'VoltDevAmpl2HiHiPrc', 'Įtampos pakeitimų diapazono amplitudės L2 fazėje ALN peržengimo %', 1, 47, 2, NULL),
	(134, 'VoltDevAmpl3', 'Įtampos pakeitimų diapazono amplitudė L3 fazėje', 1, 46, 3, NULL),
	(135, 'VoltDevAmpl3HiHiPrc', 'Įtampos pakeitimų diapazono amplitudės L3 fazėje ALN peržengimo %', 1, 47, 3, NULL),
	(136, 'VoltDevFreq1', 'Įtampos pakeitimų diapazono kartojimų dažnis L1 fazėje', 1, 48, 1, NULL),
	(137, 'VoltDevFreq2', 'Įtampos pakeitimų diapazono kartojimų dažnis L2 fazėje', 1, 48, 2, NULL),
	(138, 'VoltDevFreq3', 'Įtampos pakeitimų diapazono kartojimų dažnis L3 fazėje', 1, 48, 3, NULL),
	(139, 'VoltDevHiHiPrc', 'Susidarusio įtampos nukrypimo ALN peržengimo %', 1, 44, NULL, NULL),
	(140, 'VoltDevHiPrc', 'Susidarusio įtampos nukrypimo NLN peržengimo %', 1, 45, NULL, NULL),
	(141, 'EngQltInd', 'Energijos kokybės atitikimo standartams rodiklis', 1, 49, NULL, NULL),
	(142, 'DWt_Press', 'Šalto vandens slėgis', 8, 15, NULL, NULL),
	(143, 'HWt_Press', 'Karšto vandens slėgis', 11, 15, NULL, NULL),
	(144, 'ErrorCode', 'Klaidos kodas', 0, 50, NULL, NULL),
	(145, 'VoltageDeviationStand', 'Įtampos nukrypimo neatitikimas standartui', 1, 51, NULL, NULL),
	(146, 'FreqDeviationStand ', 'Dažnio nukrypimo neatitikimas standartui', 1, 52, NULL, NULL),
	(147, 'SinDistortionStand1', 'Sinusoidės iškreipimo L1 fazėje neatitikimas standartui', 1, 53, 1, NULL),
	(148, 'SinDistortionStand2', 'Sinusoidės iškreipimo L2 fazėje neatitikimas standartui', 1, 53, 2, NULL),
	(149, 'SinDistortionStand3', 'Sinusoidės iškreipimo L3 fazėje neatitikimas standartui', 1, 53, 3, NULL),
	(150, 'CoefNonSymU2Stand ', 'U2 nesimetrijos neatitikimas standartui', 1, 54, NULL, NULL),
	(151, 'CoefNonSymU0Stand ', 'U0 nesimetrijos neatitikimas standartui', 1, 55, NULL, NULL),
	(152, 'FlickerPstStand1', 'Pst mirksėjimo dozės L1 fazėje neatitikimas standartui', 1, 56, 1, NULL),
	(153, 'FlickerPstStand2', 'Pst mirksėjimo dozės L2 fazėje neatitikimas standartui', 1, 56, 2, NULL),
	(154, 'FlickerPstStand3', 'Pst mirksėjimo dozės L3 fazėje neatitikimas standartui', 1, 56, 3, NULL),
	(155, 'FlickerPltStand1', 'Plt mirksėjimo dozės L1 fazėje neatitikimas standartui', 1, 57, 1, NULL),
	(156, 'FlickerPltStand2', 'Plt mirksėjimo dozės L2 fazėje neatitikimas standartui', 1, 57, 2, NULL),
	(157, 'FlickerPltStand3', 'Plt mirksėjimo dozės L3 fazėje neatitikimas standartui', 1, 57, 3, NULL),
	(158, 'CoefHarmStand1', 'Harmonikos koeficientų L1 fazėje neatitikimas standartui', 1, 58, 1, NULL),
	(159, 'CoefHarmStand2', 'Harmonikos koeficientų L2 fazėje neatitikimas standartui', 1, 58, 2, NULL),
	(160, 'CoefHarmStand3', 'Harmonikos koeficientų L3 fazėje neatitikimas standartui', 1, 58, 3, NULL),
	(161, 'AngleShiftPhaseU1', 'Įtampos fazių poslinkio kampas L1 fazėje', 1, 59, 1, NULL),
	(162, 'AngleShiftPhaseU2', 'Įtampos fazių poslinkio kampas L2 fazėje', 1, 59, 2, NULL),
	(163, 'AngleShiftPhaseU3', 'Įtampos fazių poslinkio kampas L3 fazėje', 1, 59, 3, NULL),
	(164, 'AngleShiftPhaseI1', 'Srovės fazių poslinkio kampas L1 fazėje', 1, 60, 1, NULL),
	(165, 'AngleShiftPhaseI2', 'Srovės fazių poslinkio kampas L2 fazėje', 1, 60, 2, NULL),
	(166, 'AngleShiftPhaseI3', 'Srovės fazių poslinkio kampas L3 fazėje', 1, 60, 3, NULL),
	(167, 'Frost_Work', 'Šalčio skaitiklio darbo laikas', 5, 20, NULL, NULL),
	(168, 'Frost_NotWork', 'Šalčio skaitiklio nedarbo laikas', 5, 21, NULL, NULL),
	(169, 'Angle_U12_Mom', 'Kampas tarp L1 ir L2 fazės įtampų', 1, 61, NULL, NULL),
	(170, 'Angle_U23_Mom', 'Kampas tarp L2 ir L3 fazės įtampų', 1, 62, NULL, NULL),
	(171, 'Angle_U31_Mom', 'Kampas tarp L3 ir L1 fazės įtampų', 1, 63, NULL, NULL),
	(172, 'Angle_IU1_Mom', 'Kampas tarp srovės ir įtampos L1 fazėje', 1, 64, 1, NULL),
	(173, 'Angle_IU2_Mom', 'Kampas tarp srovės ir įtampos L2 fazėje', 1, 64, 2, NULL),
	(174, 'Angle_IU3_Mom', 'Kampas tarp srovės ir įtampos L3 fazėje', 1, 64, 3, NULL),
	(175, 'PowerFactor1_Mom', 'Galios koeficientas L1 fazėje', 1, 65, NULL, NULL),
	(176, 'PowerFactor2_Mom', 'Galios koeficientas L2 fazėje', 1, 66, NULL, NULL),
	(177, 'PowerFactor3_Mom', 'Galios koeficientas L3 fazėje', 1, 67, NULL, NULL),
	(178, 'THDUF_1', 'Įtampos iškraipymų harmonikos koeficientas L1 fazėje', 1, 68, 1, NULL),
	(179, 'THDUF_2', 'Įtampos iškraipymų harmonikos koeficientas L2 fazėje', 1, 68, 2, NULL),
	(180, 'THDUF_3', 'Įtampos iškraipymų harmonikos koeficientas L3 fazėje', 1, 68, 3, NULL),
	(181, 'THDI_1', 'Srovės iškraipymų harmonikos koeficientas L1 fazėje', 1, 69, 1, NULL),
	(182, 'THDI_2', 'Srovės iškraipymų harmonikos koeficientas L2 fazėje', 1, 69, 2, NULL),
	(183, 'THDI_3', 'Srovės iškraipymų harmonikos koeficientas L3 fazėje', 1, 69, 3, NULL),
	(184, 'THDUFMax', 'Įtampos iškraipymų harmonikos koeficientas', 1, 70, NULL, NULL),
	(185, 'THDIMax', 'Srovės iškraipymų harmonikos koeficientas', 1, 71, NULL, NULL),
	(186, 'Production', 'Produkcija', 0, 72, NULL, NULL),
	(187, 'Indicator1', 'Rodiklis Nr.1', 0, NULL, NULL, NULL),
	(188, 'PowerFactor_Mom', 'Galios koeficientas', 1, 73, NULL, NULL),
	(189, 'A_Phase_1 ', 'Aktyvinė energija L1 fazėje', 1, 1, 1, NULL),
	(190, 'A_Phase_2 ', 'Aktyvinė energija L2 fazėje', 1, 1, 2, NULL),
	(191, 'A_Phase_3 ', 'Aktyvinė energija L3 fazėje', 1, 1, 3, NULL),
	(192, 'Ht_JointHeat', 'Šiluma', 6, 16, NULL, NULL),
	(193, 'R_Phase_1 ', 'Reaktyvinė energija L1 fazėje', 1, 2, 1, NULL),
	(194, 'R_Phase_2 ', 'Reaktyvinė energija L2 fazėje', 1, 2, 2, NULL),
	(195, 'R_Phase_3 ', 'Reaktyvinė energija L3 fazėje', 1, 2, 3, NULL),
	(196, 'W_Phase_1', 'Pilnoji energija L1 fazėje', 1, 6, 1, NULL),
	(197, ' W_Phase_2', 'Pilnoji energija L2 fazėje', 1, 6, 2, NULL),
	(198, 'W_Phase_3', 'Pilnoji energija L3 fazėje', 1, 6, 3, NULL),
	(199, 'AngleShiftPhaseIU1', 'Poslinkio kampas tarp srovės ir įtampos L1 fazėje', 1, 74, 1, NULL),
	(200, 'AngleShiftPhaseIU2', 'Poslinkio kampas tarp srovės ir įtampos L2 fazėje', 1, 74, 2, NULL),
	(201, 'AngleShiftPhaseIU3', 'Poslinkio kampas tarp srovės ir įtampos L3 fazėje', 1, 74, 3, NULL),
	(202, 'Sin', 'Elektros sin(fi)', 1, 75, NULL, NULL),
	(203, 'Sin1', 'Elektros sin(fi) L1 fazėje', 1, 75, 1, NULL),
	(204, 'Sin2', 'Elektros sin(fi) L2 fazėje', 1, 75, 2, NULL),
	(205, 'Sin3', 'Elektros sin(fi) L3 fazėje', 1, 75, 3, NULL),
	(206, 'HarmCoef_I1', 'Srovės harmonikų koeficientai L1 fazėje', 1, 76, 1, NULL),
	(207, 'HarmCoef_I2', 'Srovės harmonikų koeficientai L2 fazėje', 1, 76, 2, NULL),
	(208, 'HarmCoef_I3', 'Srovės harmonikų koeficientai L3 fazėje', 1, 76, 3, NULL),
	(209, 'Ht_Heat_Device', 'Šilumnešio pilnoji šiluma', 6, 77, NULL, NULL),
	(210, 'Ht_MassLoss', 'Šilumnešio masės nuostoliai', 6, 78, NULL, NULL),
	(211, 'Ht_VolLoss', 'Šilumnešio tūrio nuostoliai', 6, 79, NULL, NULL),
	(212, 'UL12', 'Elektros linijinė įtampa tarp L1 ir L2 fazių', 1, 80, NULL, NULL),
	(213, 'UL13', 'Elektros linijinė įtampa tarp L1 ir L3 fazių', 1, 81, NULL, NULL),
	(214, 'UL23', 'Elektros linijinė įtampa tarp L2 ir L3 fazių', 1, 82, NULL, NULL),
	(215, 'Ht_ErrorWork', 'Šilumnešio skaitiklio darbo laikas su klaida', 6, 83, NULL, NULL),
	(216, 'Ht_ErrorWork_Metrology', 'Šilumnešio skaitiklio darbo laikas su metrologine klaida', 6, 84, NULL, NULL),
	(217, 'Ht_ErrorWork_Overflow', 'Šilumnešio skaitiklio darbo laikas su perpildymo klaida', 6, 85, NULL, NULL),
	(218, 'Ht_ErrorWork_Powerfailed', 'Šilumnešio skaitiklio maitinimo dingimo trukmė', 6, 86, NULL, NULL),
	(219, 'Freq1', 'Dažnis L1 fazėje', 1, 87, 1, NULL),
	(220, 'Freq2', 'Dažnis L2 fazėje', 1, 87, 2, NULL),
	(221, 'Freq3', 'Dažnis L3 fazėje', 1, 87, 3, NULL),
	(222, 'INeutral', 'Elektros srovės stiprumas neutralėje', 1, 88, NULL, NULL),
	(223, 'A_Loss_Phase_1', 'Savitoji nuostolių energija srovės grandinėje L1 fazėje', 1, 89, 1, NULL),
	(224, 'A_Loss_Phase_2', 'Savitoji nuostolių energija srovės grandinėje L2 fazėje', 1, 89, 2, NULL),
	(225, 'A_Loss_Phase_3', 'Savitoji nuostolių energija srovės grandinėje L3 fazėje', 1, 89, 3, NULL),
	(226, 'A_Loss_Phase', 'Savitoji nuostolių energija srovės grandinėje', 1, 89, NULL, NULL),
	(239, 'DWt_Mass', 'Šalto vandens masė', 8, 14, NULL, NULL),
	(240, 'HWt_Mass', 'Karšto vandens masė', 11, 14, NULL, NULL),
	(241, 'Ht_SupernumerarySituation', 'Neįprastos situacijos egzistavimas', 6, 94, NULL, NULL),
	(248, 'Qabs2', 'Elektros reaktyvinė absoliuti galia/energija L2 fazėje', 1, 95, 2, NULL),
	(249, 'Qabs3', 'Elektros reaktyvinė absoliuti galia/energija L3 fazėje', 1, 95, 3, NULL),
	(250, 'Sabs', 'Elektros pilnoji absoliuti galia/energija', 1, 96, NULL, NULL),
	(251, 'Sabs1', 'Elektros pilnoji absoliuti galia/energija L1 fazėje', 1, 96, 1, NULL),
	(252, 'Sabs2', 'Elektros pilnoji absoliuti galia/energija L2 fazėje', 1, 96, 2, NULL),
	(253, 'Sabs3', 'Elektros pilnoji absoliuti galia/energija L3 fazėje', 1, 96, 3, NULL),
	(254, 'Ht_ErrorWork_OutWorkMode', 'Prastovos laikas išeinant iš darbinio režimo', 0, 97, NULL, NULL),
	(255, 'HWt_ErrorWork_VolStrmLoCutoff', '"Suvartojimas mažiau už atkirtą" trukmė karšto vandens vamzdyje', 11, 98, NULL, NULL),
	(256, 'HWt_ErrorWork_TransformerConsumption', 'Keitiklio gedimo trukmė tūrio impulsų linijoje karšto vandens vamzdyje', 11, 99, NULL, NULL),
	(257, 'HWt_ErrorWork_TemperatureSensorPowerFail', 'Temperatūros jutiklio gedimo trukmė karšto vandens vamzdyje', 11, 100, NULL, NULL),
	(258, 'HWt_ErrorWork_PressureSensorPowerFail', 'Slėgio jutiklio gedimo trukmė karšto vandens vamzdyje', 11, 101, NULL, NULL),
	(259, 'Ht_ErrorWork_G2_gt_KprG1', 'Avarinės situacijos trukmė, kai G2>Kpr*G1', 0, 102, NULL, NULL),
	(260, 'Ht_ErrorWork_t1_minus_t2_lt_Delta_trc', 'Avarinės situacijos trukmė, kai t1-t2<delta tts', 0, 103, NULL, NULL),
	(261, 'Ht_ErrorWork_G1_lt_G2_lt_KprG1', 'Avarinės situacijos trukmė, kai G1<G2<Kpr*G1', 0, 104, NULL, NULL),
	(262, 'Ht_ErrorWork_G4_gt_KprG3', 'Avarinės situacijos trukmė, kai G4>Kpr*G3', 0, 105, NULL, NULL),
	(263, 'Ht_ErrorWork_t3_minus_t4_lt_Delta_trc', 'Avarinės situacijos trukmė, kai t3-t4<delta tts', 0, 106, NULL, NULL),
	(264, 'Ht_ErrorWork_G3_lt_G3_lt_KprG3', 'Avarinės situacijos trukmė, kai G3<G4<Kpr*G3', 0, 107, NULL, NULL),
	(265, 'Ht_WeightAverageTemp', 'Temperatūros svertinis vidurkis', 6, 154, NULL, NULL),
	(266, 'Pabs', 'Elektros aktyvinė absoliuti galia/energija', 1, 108, NULL, NULL),
	(267, 'Pabs1', 'Elektros aktyvinė absoliuti galia/energija L1 fazėje', 1, 108, 1, NULL),
	(268, 'Pabs2', 'Elektros aktyvinė absoliuti galia/energija L2 fazėje', 1, 108, 2, NULL),
	(269, 'Pabs3', 'Elektros aktyvinė absoliuti galia/energija L3 fazėje', 1, 108, 3, NULL),
	(270, 'Qabs', 'Elektros reaktyvinė absoliuti galia/energija', 1, 95, NULL, NULL),
	(271, 'Qabs1', 'Elektros reaktyvinė absoliuti galia/energija L1 fazėje', 1, 95, 1, NULL),
	(272, 'DWt_ErrorWork_VolStrmLoCutoff', '"Suvartojimas mažiau už atkirtą" trukmė šalto vandens vamzdyje', 8, 98, NULL, NULL),
	(274, 'Ht_ErrorWork_VolStrmLoCutoff', '"Suvartojimas mažiau už atkirtą" trukmė šilumnešio vamzdyje', 6, 98, NULL, NULL),
	(275, 'DWt_ErrorWork_TransformerConsumption', 'Keitiklio gedimo trukmė tūrio impulsų linijoje šalto vandens vamzdyje', 8, 99, NULL, NULL),
	(277, 'Ht_ErrorWork_TransformerConsumption', 'Keitiklio gedimo trukmė tūrio impulsų linijoje šilumnešio vamzdyje', 6, 99, NULL, NULL),
	(278, 'DWt_ErrorWork_TemperatureSensorPowerFail', 'Temperatūros jutiklio gedimo trukmė šalto vandens vamzdyje', 8, 100, NULL, NULL),
	(280, 'Ht_ErrorWork_TemperatureSensorPowerFail', 'Temperatūros jutiklio gedimo trukmė šilumnešio vamzdyje', 6, 100, NULL, NULL),
	(281, 'DWt_ErrorWork_PressureSensorPowerFail', 'Slėgio jutiklio gedimo trukmė šalto vandens vamzdyje', 8, 101, NULL, NULL),
	(283, 'Ht_ErrorWork_PressureSensorPowerFail', 'Slėgio jutiklio gedimo trukmė šilumnešio vamzdyje', 6, 101, NULL, NULL),
	(284, 'HWt_ErrorWork_VolStrmTooLow', 'Skaitiklio darbo laikas su debitu mažesniu už minimumą karšto vandens vamzdyje', 11, 90, NULL, NULL),
	(285, 'HWt_ErrorWork_VolStrmTooHigh', 'Skaitiklio darbo laikas su debitu didesniu už maksimumą karšto vandens vamzdyje', 11, 91, NULL, NULL),
	(286, 'HWt_ErrorWork_SensorPowerFailure', 'Skaitiklio darbo laikas su daviklio gedimu karšto vandens vamzdyje', 11, 92, NULL, NULL),
	(287, 'HWt_ErrorWork_DeltaTemper_LG_2', 'Skaitiklio darbo laikas su dt < 2 karšto vandens vamzdyje', 11, 93, NULL, NULL),
	(288, 'DWt_ErrorWork_VolStrmTooLow', 'Skaitiklio darbo laikas su debitu mažesniu už minimumą šalto vandens vamzdyje', 8, 90, NULL, NULL),
	(289, 'DWt_ErrorWork_VolStrmTooHigh', 'Skaitiklio darbo laikas su debitu didesniu už maksimumą šalto vandens vamzdyje', 8, 91, NULL, NULL),
	(290, 'DWt_ErrorWork_SensorPowerFailure', 'Skaitiklio darbo laikas su daviklio gedimu šalto vandens vamzdyje', 8, 92, NULL, NULL),
	(291, 'DWt_ErrorWork_DeltaTemper_LG_2', 'Skaitiklio darbo laikas su dt < 2 šalto vandens vamzdyje', 8, 93, NULL, NULL),
	(292, 'Ht_ErrorWork_VolStrmTooLow', 'Skaitiklio darbo laikas su debitu mažesniu už minimumą šilumnešio vamzdyje', 6, 90, NULL, NULL),
	(293, 'Ht_ErrorWork_VolStrmTooHigh', 'Skaitiklio darbo laikas su debitu didesniu už maksimumą šilumnešio vamzdyje', 6, 91, NULL, NULL),
	(294, 'Ht_ErrorWork_SensorPowerFailure', 'Skaitiklio darbo laikas su daviklio gedimu šilumnešio vamzdyje', 6, 92, NULL, NULL),
	(295, 'Ht_ErrorWork_DeltaTemper_LG_2', 'Skaitiklio darbo laikas su dt < 2 šilumnešio vamzdyje', 6, 93, NULL, NULL),
	(296, 'HWt_ErrorWork_Powerfailed_InTime', 'Maitinimo gedimo trukmė karšto vandens vamzdyje', 11, 86, NULL, NULL),
	(297, 'DWt_ErrorWork_Powerfailed_InTime', 'Maitinimo gedimo trukmė šalto vandens vamzdyje', 8, 86, NULL, NULL),
	(299, 'Ht_ErrorWork_Powerfailed_InTime', 'Maitinimo gedimo trukmė šilumnešio vamzdyje', 6, 86, NULL, NULL),
	(301, 'DWt_WeightAverageTemp', 'Šalto vandens temperatūros svertinis vidurkis', 8, 154, NULL, NULL),
	(304, 'HarmI1', 'Harmonikos srovė L1 fazėje', 1, 109, 1, NULL),
	(305, 'HarmI2', 'Harmonikos srovė L2 fazėje', 1, 109, 2, NULL),
	(306, 'HarmI3', 'Harmonikos srovė L3 fazėje', 1, 109, 3, NULL),
	(307, 'Ht_Toutside', 'Išorinė oro temperatūra', 0, 17, NULL, NULL),
	(308, 'DevUpTime', 'Prietaiso darbo laikas', 0, 110, NULL, NULL),
	(309, 'DevTempr', 'Prietaiso vidinė temperatūra', 0, 111, NULL, NULL),
	(310, 'GSMSignalQuality_1_31', 'Gauto signalo kokybė', 1, 112, NULL, NULL),
	(311, 'Ht_SupernumerarySituation_1', '1-os neįprastos situacijos trukmė', 0, 113, NULL, NULL),
	(312, 'Ht_SupernumerarySituation_2', '2-os neįprastos situacijos trukmė', 0, 114, NULL, NULL),
	(313, 'Ht_SupernumerarySituation_3', '3-os neįprastos situacijos trukmė', 0, 115, NULL, NULL),
	(314, 'Ht_SupernumerarySituation_4', '4-os neįprastos situacijos trukmė', 0, 116, NULL, NULL),
	(315, 'Ht_SupernumerarySituation_5', '5-os neįprastos situacijos trukmė', 0, 117, NULL, NULL),
	(317, 'Ht_Enthalpy', 'Šilumnešio entalpija', 6, 118, NULL, NULL),
	(320, 'Ht_Density', 'Šilumnešio tankis', 6, 119, NULL, NULL),
	(323, 'DWt_AbsolutePress', 'Absoliutus šalto vandens slėgis', 8, 153, NULL, NULL),
	(324, 'DWt_EntalpyWater', 'Šalto vandens entalpija', 8, 120, NULL, NULL),
	(329, 'Ht_AbsolutePress', 'Šilumnešio absoliutus slėgis', 6, 153, NULL, NULL),
	(330, 'Air_Pressure', 'Oro slėgis', 2, 121, NULL, NULL),
	(331, 'Ht_DifferentialPress', 'Šilumnešio diferencinis slėgis', 6, 9, NULL, NULL),
	(334, 'Wt_Work_System', 'Sistemos darbo laikas', 11, 20, NULL, NULL),
	(335, 'Wt_NotWork_System', 'Sistemos nedarbo laikas', 11, 21, NULL, NULL),
	(336, 'Ht_Work_System', 'Šilumos sistemos darbo laikas', 6, 20, NULL, NULL),
	(337, 'Ht_NotWork_System', 'Šilumos sistemos nedarbo laikas', 6, 21, NULL, NULL),
	(338, 'Ht_NotWork_', 'Šilumnešio vamzdyno nedarbo laikas', 6, 21, NULL, NULL),
	(339, 'Gas_Work_Device', 'Dujų skaitiklio darbo laikas', 7, 20, NULL, 'D'),
	(340, 'Wt_NotWork', 'Šalto vandens vamzdyno nedarbo laikas', 8, 21, NULL, NULL),
	(341, 'Gas_Work', 'Mazgo darbo laikas', 7, 20, NULL, NULL),
	(342, 'Wt_NotWork_Device', 'Šalto vandens skaitiklio nedarbo laikas', 8, 21, NULL, NULL),
	(343, 'Wt_Work', 'Šalto vandens vamzdyno darbo laikas', 8, 20, NULL, NULL),
	(344, 'Indicator2', 'Rodiklis Nr.2', 0, NULL, NULL, NULL),
	(345, 'Indicator3', 'Rodiklis Nr.3', 0, NULL, NULL, NULL),
	(346, 'Indicator4', 'Rodiklis Nr.4', 0, NULL, NULL, NULL),
	(347, 'Indicator5', 'Rodiklis Nr.5', 0, NULL, NULL, NULL),
	(348, 'Indicator6', 'Rodiklis Nr.6', 0, NULL, NULL, NULL),
	(349, 'Indicator7', 'Rodiklis Nr.7', 0, NULL, NULL, NULL),
	(350, 'Indicator8', 'Rodiklis Nr.8', 0, NULL, NULL, NULL),
	(351, 'Indicator9', 'Rodiklis Nr.9', 0, NULL, NULL, NULL),
	(352, 'Indicator10', 'Rodiklis Nr.10', 0, NULL, NULL, NULL),
	(353, 'HWt_WeightAveragePressure', 'Karšto vandens slėgio svertinis vidurkis', 11, 155, NULL, NULL),
	(354, 'Wt_WeightAveragePressure', 'Šalto vandens slėgio svertinis vidurkis', 8, 155, NULL, NULL),
	(355, 'Ht_WeightAveragePressure', 'Šilumnešio slėgio svertinis vidurkis', 6, 155, NULL, NULL),
	(357, 'Ht_ErrorWork_1_System', '1-os neįprastos situacijos trukmė šilumos sistemoje', 6, 122, NULL, NULL),
	(358, 'Ht_ErrorWork_2_System', '2-os neįprastos situacijos trukmė šilumos sistemoje', 6, 123, NULL, NULL),
	(359, 'Ht_ErrorWork_3_System', '3-os neįprastos situacijos trukmė šilumos sistemoje', 6, 124, NULL, NULL),
	(360, 'Ht_ErrorWork_4_System', '4-os neįprastos situacijos trukmė šilumos sistemoje', 6, 125, NULL, NULL),
	(361, 'Ht_ErrorWork_5_System', '5-os neįprastos situacijos trukmė šilumos sistemoje', 6, 126, NULL, NULL),
	(362, 'P_Max_All_Top10Sum', 'Aktyvios galios 10-s maksimalių reikšmių suma', 1, 127, NULL, NULL),
	(363, 'Q_Max_All_Top10Sum', 'Reaktyvios galios 10-s maksimalių reikšmių suma', 1, 128, NULL, NULL),
	(364, 'S_Max_All_Top10Sum', 'Pilnos galios 10-s maksimalių reikšmių suma', 1, 129, NULL, NULL),
	(365, 'Indicator11', 'Rodiklis Nr.11', 0, NULL, NULL, NULL),
	(366, 'Indicator12', 'Rodiklis Nr.12', 0, NULL, NULL, NULL),
	(367, 'Indicator13', 'Rodiklis Nr.13', 0, NULL, NULL, NULL),
	(368, 'Indicator14', 'Rodiklis Nr.14', 0, NULL, NULL, NULL),
	(369, 'Indicator15', 'Rodiklis Nr.15', 0, NULL, NULL, NULL),
	(370, 'Indicator16', 'Rodiklis Nr.16', 0, NULL, NULL, NULL),
	(371, 'Indicator17', 'Rodiklis Nr.17', 0, NULL, NULL, NULL),
	(372, 'Indicator18', 'Rodiklis Nr.18', 0, NULL, NULL, NULL),
	(373, 'Indicator19', 'Rodiklis Nr.19', 0, NULL, NULL, NULL),
	(374, 'Indicator20', 'Rodiklis Nr.20', 0, NULL, NULL, NULL),
	(375, 'Indicator21', 'Andriaus2', 0, NULL, NULL, NULL),
	(376, 'Indicator22', 'Buves 22', 0, NULL, NULL, NULL),
	(377, 'Indicator23', 'Rodiklis Nr.23', 0, NULL, NULL, NULL),
	(378, 'Indicator24', 'Rodiklis Nr.24', 0, NULL, NULL, NULL),
	(379, 'Indicator25', 'Rodiklis Nr.25', 0, NULL, NULL, NULL),
	(380, 'Indicator26', 'Rodiklis Nr.26', 0, NULL, NULL, NULL),
	(381, 'Indicator27', 'Rodiklis Nr.27', 0, NULL, NULL, NULL),
	(382, 'Indicator28', 'Rodiklis Nr.28', 0, NULL, NULL, NULL),
	(383, 'Indicator29', 'Rodiklis Nr.29', 0, NULL, NULL, NULL),
	(384, 'Indicator30', 'Rodiklis Nr.30', 0, NULL, NULL, NULL),
	(385, 'P_Cumulated', 'Elektros aktyvinė kumuliacinė galia/energija', 1, 130, NULL, NULL),
	(386, 'S_Cumulated', 'Elektros pilnoji kumuliacinė galia/energija', 1, 131, NULL, NULL),
	(387, 'Q_Cumulated', 'Elektros reaktyvioji kumuliacinė galia/energija', 1, 132, NULL, NULL),
	(388, 'Q_Coef', 'Reaktyvios galios koeficientas', 1, 133, NULL, NULL),
	(389, 'Q1_Coef', 'Reaktyvios galios koeficientas L1 fazėje', 1, 133, 1, NULL),
	(390, 'Q2_Coef', 'Reaktyvios galios koeficientas L2 fazėje', 1, 133, 2, NULL),
	(391, 'Q3_Coef', 'Reaktyvios galios koeficientas L3 fazėje', 1, 133, 3, NULL),
	(392, 'P_Coef', 'Aktyvios galios koeficientas', 1, 134, NULL, NULL),
	(393, 'P1_Coef', 'Aktyvios galios koeficientas L1 fazėje', 1, 134, 1, NULL),
	(394, 'P2_Coef', 'Aktyvios galios koeficientas L2 fazėje', 1, 134, 2, NULL),
	(395, 'P3_Coef', 'Aktyvios galios koeficientas L3 fazėje', 1, 134, 3, NULL),
	(396, 'P_Loss', 'Elektros aktyvinė nuostolių galia/energija', 1, 135, NULL, NULL),
	(397, 'P1_Loss', 'Aktyvinių nuostolių galia L1 fazėje', 1, 135, 1, NULL),
	(398, 'P2_Loss', 'Aktyvinių nuostolių galia L2 fazėje', 1, 135, 2, NULL),
	(399, 'P3_Loss', 'Aktyvinių nuostolių galia L3 fazėje', 1, 135, 3, NULL),
	(400, 'Tg', 'Galios koeficientas (tg)', 1, 137, NULL, NULL),
	(401, 'Tg1', 'Galios koeficientas (tg) L1 fazėje', 1, 137, 1, NULL),
	(402, 'Tg2', 'Galios koeficientas (tg) L2 fazėje', 1, 137, 2, NULL),
	(403, 'Tg3', 'Galios koeficientas (tg) L3 fazėje', 1, 137, 3, NULL),
	(404, 'GSMSignalStrength_dBm', 'GSM signalo stiprumas', 0, 138, NULL, NULL),
	(405, 'Resistance', 'Varža', 1, 139, NULL, NULL),
	(406, 'ElResistivity', 'Savitoji varža', 1, 140, NULL, NULL),
	(407, 'Permittance', 'Laidumas', 1, 141, NULL, NULL),
	(408, 'ElConductivity', 'Savitasis laidumas', 1, 142, NULL, NULL),
	(409, 'Capacitance', 'Talpa', 1, 143, NULL, NULL),
	(410, 'Inductance', 'Induktyvumas', 1, 144, NULL, NULL),
	(411, 'ChargingStatus', 'Krovimo būklė', 0, 145, NULL, NULL),
	(412, 'CLInStatus', 'Vartotojo sąsajos (Cl in) būklė', 0, 146, NULL, NULL),
	(413, 'CLOUTStatus', 'Skaitiklio sąsajos (Cl out) būklė', 0, 147, NULL, NULL),
	(414, 'ACStatus', 'Maitinimo (AC) būklė', 0, 148, NULL, NULL),
	(415, 'ModemDataWaitTimeOut', 'Modemo duomenų laukimo taimautas', 0, 149, NULL, NULL),
	(416, 'ACFaultCount', 'Maitinimo (AC) dingimų kiekis', 0, 150, NULL, NULL),
	(417, 'BootEEPROM', 'Užkrovimas iš EEPROM', 0, 151, NULL, NULL),
	(418, 'HarmI', 'Harmonikos srovė', 1, 109, NULL, NULL),
	(419, 'HarmU', 'Harmonikos įtampa', 1, 152, NULL, NULL),
	(420, 'HarmU1', 'Harmonikos įtampa L1 fazėje', 1, 152, 1, NULL),
	(421, 'HarmU2', 'Harmonikos įtampa L2 fazėje', 1, 152, 2, NULL),
	(422, 'HarmU3', 'Harmonikos įtampa L3 fazėje', 1, 152, 3, NULL),
	(423, 'Q_Loss', 'Elektros reaktyvinė nuostolių galia/energija', 1, 136, NULL, NULL),
	(424, 'Ht_ErrorWork_Flow_SensorPowerFailure', 'Srauto daviklio gedimo trukmė šilumnešio vamzdyje', 6, 155, NULL, NULL),
	(425, 'Ht_ErrorWork_NoCommunicationWithChannel', 'Ryšio su kanalu nebuvimo trukmė šilumnešio vamzdyje', 6, 156, NULL, NULL),
	(426, 'Ht_ErrorWork_Temperature_TooHigh', '"Temperatūra daugiau maksimumo" trukmė šilumnešio vamzdyje', 6, 157, NULL, NULL),
	(427, 'Ht_ErrorWork_Temperature_TooLow', '"Temperatūra mažiau minimumo" trukmė šilumnešio vamzdyje', 6, 158, NULL, NULL),
	(428, 'Ht_Heat_Leakage', 'Šilumos nuostoliai', 6, 159, NULL, NULL),
	(429, 'Ht_Heat_From_Init', 'Šiluma nuo pradinio įjungimo', 6, 160, NULL, NULL),
	(430, 'Gas_VolQnttAtErr', 'Dujų turbulentinis tūris', 7, 161, NULL, NULL),
	(431, 'Gas_CorrPress', 'Dujų slėgis normaliose sąlygose', 7, 162, NULL, NULL),
	(432, 'Gas_CorrTemper', 'Dujų temperatūra normaliose sąlygose', 7, 163, NULL, NULL),
	(433, 'Gas_ContentH2', 'Vandenilio H2 kiekis', 7, 164, NULL, NULL),
	(434, 'Gas_CompressFactor', 'Dujų suspaudimo koeficientas', 7, 165, NULL, NULL),
	(435, 'Gas_CorrFactor', 'Dujų korekcijos koeficientas', 7, 166, NULL, NULL),
	(436, 'Gas_HeatQnttAtErr', 'Dujų turbulentinis šilumos kiekis', 7, 167, NULL, NULL),
	(437, 'Gas_CorrVolQntt_System', 'Dujų bendras suvartojimo tūris normaliose sąlygose', 7, 169, NULL, NULL),
	(438, 'Gas_VolQntt_System', 'Dujų bendras suvartojimo tūris', 7, 168, NULL, NULL),
	(439, 'Gas_Press_System', 'Išmatuotas dujų slėgis', 7, 170, NULL, NULL),
	(440, 'Gas_Temper_System', 'Išmatuota dujų temperatūra', 7, 171, NULL, NULL),
	(441, 'Gas_HeatQntt_System', 'Dujų bendras šilumos kiekis', 7, 172, NULL, NULL),
	(442, 'Gas_PressAbsolute', 'Absoliutus dujų slėgis', 7, 153, NULL, NULL),
	(443, 'Gas_Density', 'Dujų tankis', 7, 119, NULL, NULL),
	(444, 'Gas_CorrDensity', 'Dujų tankis normaliose sąlygose', 7, 173, NULL, NULL),
	(445, 'Indicator31', 'Rodiklis Nr.31', 0, NULL, NULL, NULL),
	(446, 'Indicator32', 'Rodiklis Nr.32', 0, NULL, NULL, NULL),
	(447, 'Indicator33', 'Rodiklis Nr.33', 0, NULL, NULL, NULL),
	(448, 'Indicator34', 'Rodiklis Nr.34', 0, NULL, NULL, NULL),
	(449, 'Indicator35', 'Rodiklis Nr.35', 0, NULL, NULL, NULL),
	(450, 'Indicator36', 'Rodiklis Nr.36', 0, NULL, NULL, NULL),
	(451, 'Indicator37', 'Rodiklis Nr.37', 0, NULL, NULL, NULL),
	(452, 'Indicator38', 'Rodiklis Nr.38', 0, NULL, NULL, NULL),
	(453, 'Indicator39', 'Rodiklis Nr.39', 0, NULL, NULL, NULL),
	(454, 'Indicator40', 'Rodiklis Nr.40', 0, NULL, NULL, NULL),
	(455, 'Air_Vol', 'Oro tūris', 2, 18, NULL, NULL),
	(456, 'Air_Mass', 'Oro masė', 2, 14, NULL, NULL),
	(457, 'Gas_PressDifferential', 'Dujų slėgių skirtumas', 7, 9, NULL, NULL),
	(458, 'Ht_Vol_Emergency', 'Avarinio pamaitinimo tūris', 6, 174, NULL, NULL),
	(459, 'Ht_Mass_Emergency', 'Avarinio pamaitinimo masė', 6, 175, NULL, NULL),
	(460, 'Ht_Heat_Emergency', 'Avarinio pamaitinimo šiluma', 6, 176, NULL, NULL),
	(461, 'Ht_Temper_Emergency', 'Avarinio pamaitinimo temperatūra', 6, 177, NULL, NULL),
	(462, 'Ht_Press_Emergency', 'Avarinio pamaitinimo slėgis', 6, 178, NULL, NULL),
	(463, 'Ht_PressAbsolute_Emergency', 'Avarinio pamaitinimo absoliutus slėgis', 6, 179, NULL, NULL),
	(464, 'Ht_PressAlteration_Emergency', 'Avarinio pamaitinimo slėgių skirtumo perskaičiuota reikšmė', 6, 180, NULL, NULL),
	(465, 'ApNetm_Phase_1', 'Fazės L1 aktyvinių A+ ir A- energijų balansas', 1, 181, 1, NULL),
	(466, 'ApNetm_Phase_2', 'Fazės L2 aktyvinių A+ ir A- energijų balansas', 1, 181, 2, NULL),
	(467, 'ApNetm_Phase_3', 'Fazės L3 aktyvinių A+ ir A- energijų balansas', 1, 181, 3, NULL),
	(468, 'RpNetm_Phase_1', 'Fazės L1 reaktyvinių R+ ir R- energijų balansas', 1, 182, 1, NULL),
	(469, 'RpNetm_Phase_2', 'Fazės L2 reaktyvinių R+ ir R- energijų balansas', 1, 182, 2, NULL),
	(470, 'RpNetm_Phase_3', 'Fazės L3 reaktyvinių R+ ir R- energijų balansas', 1, 182, 3, NULL),
	(471, 'WpNetm_Phase_1', 'Fazės L1 pilnųjų W+ ir W- energijų balansas', 1, 183, 1, NULL),
	(472, 'WpNetm_Phase_2', 'Fazės L2 pilnųjų W+ ir W- energijų balansas', 1, 183, 2, NULL),
	(473, 'WpNetm_Phase_3', 'Fazės L3 pilnųjų W+ ir W- energijų balansas', 1, 183, 3, NULL),
	(474, 'ResidualCredit', 'Kredito likutis (pinigai)', 0, 184, NULL, NULL),
	(475, 'Ht_VolRev', 'Šilumnešio atbulinės krypties tūris', 6, 185, NULL, NULL),
	(476, 'Ht_FlowRate', 'Šilumnešio srauto greitis', 6, 186, NULL, NULL),
	(477, 'Ht_UltraSoundSpeed', 'Šilumnešio ultragarsinio signalo greitis', 6, 187, NULL, NULL),
	(478, 'Ht_Heat_System', 'Šiluma sistemoje', 6, 172, NULL, NULL),
	(479, 'Gas_VolQnttAtErrCalibration', 'Dujų nekonvertuotas tūris Vc1err', 7, 188, NULL, NULL),
	(480, 'Gas_ContentN2', 'Azoto dalis dujose', 7, 189, NULL, NULL),
	(481, 'Gas_ContentCO2', 'CO2 dalis dujose', 7, 190, NULL, NULL),
	(482, 'Gas_CalorificValueSuperior', 'Viršutinis dujų šilumingumas', 7, 191, NULL, NULL),
	(483, 'Gas_RelativeDensity', 'Santykinis dujų tankis', 7, 192, NULL, NULL);
/*!40000 ALTER TABLE `ms` ENABLE KEYS */;

-- Dumping structure for table emcor.msf
CREATE TABLE IF NOT EXISTS `msf` (
  `msf_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimo su agregavimo funkcija ID',
  `msf_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo su agregavimo funkcija pavadinimas',
  `msf_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo su agregavimo funkcija kodas',
  PRIMARY KEY (`msf_id`),
  UNIQUE KEY `msf_code_u` (`msf_code`),
  UNIQUE KEY `msf_name_u` (`msf_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimai pagal agregavimo funkcijas';

-- Dumping data for table emcor.msf: ~474 rows (approximately)
/*!40000 ALTER TABLE `msf` DISABLE KEYS */;
INSERT INTO `msf` (`msf_id`, `msf_name`, `msf_code`) VALUES
	(1, 'Dujų koreguotos masės debitas', 'Gas_CorrMassRate'),
	(2, 'Dujų koreguotos masės kiekis', 'Gas_CorrMass'),
	(3, 'Dujų koreguoto tūrio debitas', 'Gas_CorrVolRate'),
	(4, 'Dujų koreguoto tūrio kiekis', 'Gas_CorrVol'),
	(5, 'Dujų masės debitas', 'Gas_MassRate'),
	(6, 'Dujų masės kiekis', 'Gas_Mass'),
	(7, 'Dujų slėgis', 'Gas_Press'),
	(8, 'Dujų šilumos galia', 'Gas_HeatRate'),
	(9, 'Dujų šilumos kiekis', 'Gas_Heat'),
	(10, 'Dujų temperatūra', 'Gas_Temp'),
	(11, 'Dujų tūrio debitas', 'Gas_VolRate'),
	(12, 'Dujų tūrio kiekis', 'Gas_Vol'),
	(13, 'P galia', 'P'),
	(14, 'A energija', 'A'),
	(15, 'R energija', 'R'),
	(16, 'Q galia', 'Q'),
	(17, 'Srovės stiprumas L1 fazėje', 'I1'),
	(18, 'Įtampa L1 fazėje', 'U1'),
	(19, 'Srovės stiprumas L2 fazėje', 'I2'),
	(20, 'Įtampa L2 fazėje', 'U2'),
	(21, 'Srovės stiprumas L3 fazėje', 'I3'),
	(22, 'Įtampa L3 fazėje', 'U3'),
	(23, 'Linijinė įtampa L1 fazėje', 'UL1'),
	(24, 'Linijinė įtampa L2 fazėje', 'UL2'),
	(25, 'Linijinė įtampa L3 fazėje', 'UL3'),
	(26, 'Aktyvinė galia L1 fazėje', 'P1'),
	(27, 'Aktyvinė galia L2 fazėje', 'P2'),
	(28, 'Aktyvinė galia L3 fazėje', 'P3'),
	(29, 'Reaktyvinė galia L1 fazėje', 'Q1'),
	(30, 'Reaktyvinė galia L2 fazėje', 'Q2'),
	(31, 'Reaktyvinė galia L3 fazėje', 'Q3'),
	(32, 'Pilnoji galia L1 fazėje', 'S1'),
	(33, 'Pilnoji galia L2 fazėje', 'S2'),
	(34, 'Pilnoji galia L3 fazėje', 'S3'),
	(35, 'Cos(fi) L1 fazėje', 'Cos1'),
	(36, 'Cos(fi) L2 fazėje', 'Cos2'),
	(37, 'Cos(fi) L3 fazėje', 'Cos3'),
	(38, 'Kvadrantas L1 fazėje', 'Quadrant1'),
	(39, 'Kvadrantas L2 fazėje', 'Quadrant2'),
	(40, 'Kvadrantas L3 fazėje', 'Quadrant3'),
	(41, 'Srovės stiprumas', 'I'),
	(42, 'Įtampa', 'U'),
	(43, 'Linijinė įtampa', 'UL'),
	(44, 'S galia', 'S'),
	(45, 'W energija', 'W'),
	(46, 'Cos(fi)', 'Cos'),
	(47, 'Kvadrantas', 'Quadrant'),
	(48, 'Dažnis', 'F'),
	(49, 'Fazių seka', 'FS'),
	(50, 'Karšto vandens šilumos galia', 'HWt_HeatRate'),
	(51, 'Karšto vandens šilumos kiekis', 'HWt_Heat'),
	(52, 'Karšto vandens temperatūra', 'HWt_Temp'),
	(53, 'Karšto vandens tūrio kiekis', 'HWt_Vol'),
	(54, 'Karšto vandens tūrio debitas', 'HWt_VolRate'),
	(55, 'Oro temperatūra', 'Air_Temp'),
	(56, 'Šalto vandens šilumos kiekis', 'DWt_Heat'),
	(57, 'Šalto vandens šilumos galia', 'DWt_HeatRate'),
	(58, 'Šalto vandens temperatūra', 'DWt_Temp'),
	(59, 'Šalto vandens tūrio kiekis', 'DWt_Vol'),
	(60, 'Šalto vandens tūrio debitas', 'DWt_VolRate'),
	(61, 'Šalčio slėgis', 'Frost_Press'),
	(62, 'Šalčio energija', 'Frost_Energy'),
	(63, 'Šalčio galia', 'Frost_Power'),
	(64, 'Šalčio temperatūra', 'Frost_Temp'),
	(65, 'Šalčio tūrio debitas', 'Frost_VolRate'),
	(66, 'Šalčio tūrio kiekis', 'Frost_Vol'),
	(67, 'Šilumnešio masės debitas', 'Ht_MassRate'),
	(68, 'Šilumnešio masės kiekis', 'Ht_Mass'),
	(69, 'Šilumnešio slėgis', 'Ht_Press'),
	(70, 'Šilumnešio šilumos galia', 'Ht_HeatRate'),
	(71, 'Šilumnešio šilumos kiekis', 'Ht_Heat'),
	(72, 'Šilumnešio temperatūra', 'Ht_Temp'),
	(73, 'Šilumnešio tūrio debitas', 'Ht_VolRate'),
	(74, 'Šilumnešio tūrio kiekis', 'Ht_Vol'),
	(75, 'Šilumnešio skaitiklio darbo laikas', 'Ht_Work'),
	(76, 'Šilumnešio skaitiklio nedarbo laikas', 'Ht_NotWork'),
	(77, 'Šalto vandens skaitiklio darbo laikas', 'DWt_Work'),
	(78, 'Karšto vandens skaitiklio darbo laikas', 'HWt_Work'),
	(79, 'Atvirkštinės sekos nesimetrijos koeficientas', 'CoefBackwSeq'),
	(80, 'Atvirkštinės sekos nesimetrijos koeficiento ALN peržengimo %', 'CoefBackwSeqHiHiPrc'),
	(81, 'Atvirkštinės sekos nesimetrijos koeficiento NLN peržengimo %', 'CoefBackwSeqHiPrc'),
	(82, 'Nulinės sekos nesimetrijos koeficientas', 'CoefZeroSeq'),
	(83, 'Nulinės sekos nesimetrijos koeficiento ALN peržengimo %', 'CoefZeroSeqHiHiPrc'),
	(84, 'Nulinės sekos nesimetrijos koeficiento NLN peržengimo %', 'CoefZeroSeqHiPrc'),
	(85, 'Trumpalaikė mirksėjimo dozė L1 fazėje', 'Flicker1'),
	(86, 'Trumpalaikės mirksėjimo dozės L1 fazėje ALN peržengimo %', 'Flicker1HiHiPrc'),
	(87, 'Trumpalaikė mirksėjimo dozė L2 fazėje', 'Flicker2'),
	(88, 'Trumpalaikės mirksėjimo dozės L2 fazėje ALN peržengimo %', 'Flicker2HiHiPrc'),
	(89, 'Trumpalaikė mirksėjimo dozė L3 fazėje', 'Flicker3'),
	(90, 'Trumpalaikės mirksėjimo dozės L3 fazėje ALN peržengimo %', 'Flicker3HiHiPrc'),
	(91, 'Dažnio nukrypimas', 'FreqDev'),
	(92, 'Dažnio nukrypimas L1 fazėje', 'FreqDev1'),
	(93, 'Dažnio nukrypimo L1 fazėje ALN peržengimo %', 'FreqDev1HiHiPrc'),
	(94, 'Dažnio nukrypimo L1 fazėje NLN peržengimo %', 'FreqDev1HiPrc'),
	(95, 'Dažnio nukrypimas L2 fazėje', 'FreqDev2'),
	(96, 'Dažnio nukrypimo L2 fazėje ALN peržengimo %', 'FreqDev2HiHiPrc'),
	(97, 'Dažnio nukrypimo L2 fazėje NLN peržengimo %', 'FreqDev2HiPrc'),
	(98, 'Dažnio nukrypimas L3 fazėje', 'FreqDev3'),
	(99, 'Dažnio nukrypimo L3 fazėje ALN peržengimo %', 'FreqDev3HiHiPrc'),
	(100, 'Dažnio nukrypimo L3 fazėje NLN peržengimo %', 'FreqDev3HiPrc'),
	(101, 'Dažnio nukrypimo ALN peržengimo %', 'FreqDevHiHiPrc'),
	(102, 'Dažnio nukrypimo NLN peržengimo %', 'FreqDevHiPrc'),
	(103, 'Įtampos harmonikų koeficientai L1 fazėje', 'HarmCoef1'),
	(104, 'Harmoninių srovių koeficientų L1 fazėje ALN peržengimo %', 'HarmCoef1HiHiPrc'),
	(105, 'Harmoninių srovių koeficientų L1 fazėje NLN peržengimo %', 'HarmCoef1HiPrc'),
	(106, 'Įtampos harmonikų koeficientai L2 fazėje', 'HarmCoef2'),
	(107, 'Harmoninių srovių koeficientų L2 fazėje ALN peržengimo %', 'HarmCoef2HiHiPrc'),
	(108, 'Harmoninių srovių koeficientų L2 fazėje NLN peržengimo %', 'HarmCoef2HiPrc'),
	(109, 'Įtampos harmonikų koeficientai L3 fazėje', 'HarmCoef3'),
	(110, 'Harmoninių srovių koeficientų L3 fazėje ALN peržengimo %', 'HarmCoef3HiHiPrc'),
	(111, 'Harmoninių srovių koeficientų L3 fazėje NLN peržengimo %', 'HarmCoef3HiPrc'),
	(112, 'Harmoninių srovių koeficientų kokybė L1 fazėje', 'HarmQual1'),
	(113, 'Harmoninių srovių koeficientų kokybė L2 fazėje', 'HarmQual2'),
	(114, 'Harmoninių srovių koeficientų kokybė L3 fazėje', 'HarmQual3'),
	(115, 'Ilgalaikė mirksėjimo dozė L1 fazėje', 'LongFlicker1'),
	(116, 'Ilgalaikės mirksėjimo dozės L1 fazėje ALN peržengimo %', 'LongFlicker1HiHiPrc'),
	(117, 'Ilgalaikė mirksėjimo dozė L2 fazėje', 'LongFlicker2'),
	(118, 'Ilgalaikės mirksėjimo dozės L2 fazėje ALN peržengimo %', 'LongFlicker2HiHiPrc'),
	(119, 'Ilgalaikė mirksėjimo dozė L3 fazėje', 'LongFlicker3'),
	(120, 'Ilgalaikės mirksėjimo dozės L3 fazėje ALN peržengimo %', 'LongFlicker3HiHiPrc'),
	(121, 'Pagrindinės harmoninės srovės dabartinė reikšmė L1 fazėje', 'MainHarmValue1'),
	(122, 'Pagrindinės harmoninės srovės dabartinė reikšmė L2 fazėje', 'MainHarmValue2'),
	(123, 'Pagrindinės harmoninės srovės dabartinė reikšmė L3 fazėje', 'MainHarmValue3'),
	(124, 'Sinusoidės iškreipimo koeficientas L1 fazėje', 'SinDistort1'),
	(125, 'Sinusoidės iškreipimo koeficiento L1 fazėje ALN peržengimo %', 'SinDistort1HiHiPrc'),
	(126, 'Sinusoidės iškreipimo koeficiento L1 fazėje NLN peržengimo %', 'SinDistort1HiPrc'),
	(127, 'Sinusoidės iškreipimo koeficientas L2 fazėje', 'SinDistort2'),
	(128, 'Sinusoidės iškreipimo koeficiento L2 fazėje ALN peržengimo %', 'SinDistort2HiHiPrc'),
	(129, 'Sinusoidės iškreipimo koeficiento L2 fazėje NLN peržengimo %', 'SinDistort2HiPrc'),
	(130, 'Sinusoidinės iškreipimo koeficientas L3 fazėje', 'SinDistort3'),
	(131, 'Sinusoidės iškreipimo koeficiento L3 fazėje ALN peržengimo %', 'SinDistort3HiHiPrc'),
	(132, 'Sinusoidės iškreipimo koeficiento L3 fazėje NLN peržengimo %', 'SinDistort3HiPrc'),
	(133, 'Susidaręs įtampos nukrypimas', 'VoltDev'),
	(134, 'Susidaręs įtampos nukrypimas L1 fazėje', 'VoltDev1'),
	(135, 'Susidarusio įtampos nukrypimo L1 fazėje ALN peržengimo %', 'VoltDev1HiHiPrc'),
	(136, 'Susidarusio įtampos nukrypimo L1 fazėje NLN peržengimo %', 'VoltDev1HiPrc'),
	(137, 'Susidaręs įtampos nukrypimas L2 fazėje', 'VoltDev2'),
	(138, 'Susidarusio įtampos nukrypimo L2 fazėje ALN peržengimo %', 'VoltDev2HiHiPrc'),
	(139, 'Susidarusio įtampos nukrypimo L2 fazėje NLN peržengimo %', 'VoltDev2HiPrc'),
	(140, 'Susidaręs įtampos nukrypimas L3 fazėje', 'VoltDev3'),
	(141, 'Susidarusio įtampos nukrypimo L3 fazėje ALN peržengimo %', 'VoltDev3HiHiPrc'),
	(142, 'Susidarusio įtampos nukrypimo L3 fazėje NLN peržengimo %', 'VoltDev3HiPrc'),
	(143, 'Įtampos pakeitimų diapazono amplitudė L1 fazėje', 'VoltDevAmpl1'),
	(144, 'Įtampos pakeitimų diapazono amplitudės L1 fazėje ALN peržengimo %', 'VoltDevAmpl1HiHiPrc'),
	(145, 'Įtampos pakeitimų diapazono amplitudė L2 fazėje', 'VoltDevAmpl2'),
	(146, 'Įtampos pakeitimų diapazono amplitudės L2 fazėje ALN peržengimo %', 'VoltDevAmpl2HiHiPrc'),
	(147, 'Įtampos pakeitimų diapazono amplitudė L3 fazėje', 'VoltDevAmpl3'),
	(148, 'Įtampos pakeitimų diapazono amplitudės L3 fazėje ALN peržengimo %', 'VoltDevAmpl3HiHiPrc'),
	(149, 'Įtampos pakeitimų diapazono kartojimų dažnis L1 fazėje', 'VoltDevFreq1'),
	(150, 'Įtampos pakeitimų diapazono kartojimų dažnis L2 fazėje', 'VoltDevFreq2'),
	(151, 'Įtampos pakeitimų diapazono kartojimų dažnis L3 fazėje', 'VoltDevFreq3'),
	(152, 'Susidarusio įtampos nukrypimo ALN peržengimo %', 'VoltDevHiHiPrc'),
	(153, 'Susidarusio įtampos nukrypimo NLN peržengimo %', 'VoltDevHiPrc'),
	(154, 'Energijos kokybės atitikimo standartams rodiklis', 'EngQltInd'),
	(155, 'Šalto vandens slėgis', 'DWt_Press'),
	(156, 'Karšto vandens slėgis', 'HWt_Press'),
	(157, 'Klaidos kodas', 'ErrorCode'),
	(158, 'Įtampos nukrypimo neatitikimas standartui', 'VoltageDeviationStand'),
	(159, 'Dažnio nukrypimo neatitikimas standartui', 'FreqDeviationStand '),
	(160, 'Sinusoidės iškreipimo L1 fazėje neatitikimas standartui', 'SinDistortionStand1'),
	(161, 'Sinusoidės iškreipimo L2 fazėje neatitikimas standartui', 'SinDistortionStand2'),
	(162, 'Sinusoidės iškreipimo L3 fazėje neatitikimas standartui', 'SinDistortionStand3'),
	(163, 'U2 nesimetrijos neatitikimas standartui', 'CoefNonSymU2Stand '),
	(164, 'U0 nesimetrijos neatitikimas standartui', 'CoefNonSymU0Stand '),
	(165, 'Pst mirksėjimo dozės L1 fazėje neatitikimas standartui', 'FlickerPstStand1'),
	(166, 'Pst mirksėjimo dozės L2 fazėje neatitikimas standartui', 'FlickerPstStand2'),
	(167, 'Pst mirksėjimo dozės L3 fazėje neatitikimas standartui', 'FlickerPstStand3'),
	(168, 'Plt mirksėjimo dozės L1 fazėje neatitikimas standartui', 'FlickerPltStand1'),
	(169, 'Plt mirksėjimo dozės L2 fazėje neatitikimas standartui', 'FlickerPltStand2'),
	(170, 'Plt mirksėjimo dozės L3 fazėje neatitikimas standartui', 'FlickerPltStand3'),
	(171, 'Harmonikos koeficientų L1 fazėje neatitikimas standartui', 'CoefHarmStand1'),
	(172, 'Harmonikos koeficientų L2 fazėje neatitikimas standartui', 'CoefHarmStand2'),
	(173, 'Harmonikos koeficientų L3 fazėje neatitikimas standartui', 'CoefHarmStand3'),
	(174, 'Įtampos fazių poslinkio kampas L1 fazėje', 'AngleShiftPhaseU1'),
	(175, 'Įtampos fazių poslinkio kampas L2 fazėje', 'AngleShiftPhaseU2'),
	(176, 'Įtampos fazių poslinkio kampas L3 fazėje', 'AngleShiftPhaseU3'),
	(177, 'Srovės fazių poslinkio kampas L1 fazėje', 'AngleShiftPhaseI1'),
	(178, 'Srovės fazių poslinkio kampas L2 fazėje', 'AngleShiftPhaseI2'),
	(179, 'Srovės fazių poslinkio kampas L3 fazėje', 'AngleShiftPhaseI3'),
	(180, 'Šalčio skaitiklio darbo laikas', 'Frost_Work'),
	(181, 'Šalčio skaitiklio nedarbo laikas', 'Frost_NotWork'),
	(182, 'Kampas tarp L1 ir L2 fazės įtampų', 'Angle_U12_Mom'),
	(183, 'Kampas tarp L2 ir L3 fazės įtampų', 'Angle_U23_Mom'),
	(184, 'Kampas tarp L3 ir L1 fazės įtampų', 'Angle_U31_Mom'),
	(185, 'Kampas tarp srovės ir įtampos L1 fazėje', 'Angle_IU1_Mom'),
	(186, 'Kampas tarp srovės ir įtampos L2 fazėje', 'Angle_IU2_Mom'),
	(187, 'Kampas tarp srovės ir įtampos L3 fazėje', 'Angle_IU3_Mom'),
	(188, 'Galios koeficientas L1 fazėje', 'PowerFactor1_Mom'),
	(189, 'Galios koeficientas L2 fazėje', 'PowerFactor2_Mom'),
	(190, 'Galios koeficientas L3 fazėje', 'PowerFactor3_Mom'),
	(191, 'Įtampos iškraipymų harmonikos koeficientas L1 fazėje', 'THDUF_1'),
	(192, 'Įtampos iškraipymų harmonikos koeficientas L2 fazėje', 'THDUF_2'),
	(193, 'Įtampos iškraipymų harmonikos koeficientas L3 fazėje', 'THDUF_3'),
	(194, 'Srovės iškraipymų harmonikos koeficientas L1 fazėje', 'THDI_1'),
	(195, 'Srovės iškraipymų harmonikos koeficientas L2 fazėje', 'THDI_2'),
	(196, 'Srovės iškraipymų harmonikos koeficientas L3 fazėje', 'THDI_3'),
	(197, 'Įtampos iškraipymų harmonikos koeficientas', 'THDUFMax'),
	(198, 'Srovės iškraipymų harmonikos koeficientas', 'THDIMax'),
	(199, 'Produkcija', 'Production'),
	(200, 'Rodiklis Nr.1', 'Indicator1'),
	(201, 'Galios koeficientas', 'PowerFactor_Mom'),
	(202, 'Aktyvinė energija L1 fazėje', 'A_Phase_1'),
	(203, 'Aktyvinė energija L2 fazėje', 'A_Phase_2'),
	(204, 'Aktyvinė energija L3 fazėje', 'A_Phase_3'),
	(205, 'Reaktyvinė energija L1 fazėje', 'R_Phase_1'),
	(206, 'Reaktyvinė energija L2 fazėje', 'R_Phase_2'),
	(207, 'Reaktyvinė energija L3 fazėje', 'R_Phase_3'),
	(208, 'Pilnoji energija L1 fazėje', 'W_Phase_1'),
	(209, 'Pilnoji energija L2 fazėje', 'W_Phase_2'),
	(210, 'Pilnoji energija L3 fazėje', 'W_Phase_3'),
	(211, 'Poslinkio kampas tarp srovės ir įtampos L1 fazėje', 'AngleShiftPhaseIU1'),
	(212, 'Poslinkio kampas tarp srovės ir įtampos L2 fazėje', 'AngleShiftPhaseIU2'),
	(213, 'Poslinkio kampas tarp srovės ir įtampos L3 fazėje', 'AngleShiftPhaseIU3'),
	(214, 'Sin(fi)', 'Sin'),
	(215, 'Sin(fi) L1 fazėje', 'Sin1'),
	(216, 'Sin(fi) L2 fazėje', 'Sin2'),
	(217, 'Sin(fi) L3 fazėje', 'Sin3'),
	(218, 'Srovės harmonikų koeficientai L1 fazėje', 'HarmCoef_I1'),
	(219, 'Srovės harmonikų koeficientai L2 fazėje', 'HarmCoef_I2'),
	(220, 'Srovės harmonikų koeficientai L3 fazėje', 'HarmCoef_I3'),
	(221, 'Šilumnešio pilnoji šilumos galia', 'Ht_HeatRate_Device'),
	(222, 'Šilumnešio pilnoji šiluma', 'Ht_Heat_Device'),
	(223, 'Šilumnešio masės nuostoliai', 'Ht_MassLoss'),
	(224, 'Šilumnešio tūrio nuostoliai', 'Ht_VolLoss'),
	(225, 'Elektros linijinė įtampa tarp L1 ir L2 fazių', 'UL12'),
	(226, 'Elektros linijinė įtampa tarp L1 ir L3 fazių', 'UL13'),
	(227, 'Elektros linijinė įtampa tarp L2 ir L3 fazių', 'UL23'),
	(228, 'Šilumnešio skaitiklio darbo laikas su klaida', 'Ht_ErrorWork'),
	(229, 'Šilumnešio skaitiklio darbo laikas su metrologine klaida', 'Ht_ErrorWork_Metrology'),
	(230, 'Šilumnešio skaitiklio darbo laikas su perpildymo klaida', 'Ht_ErrorWork_Overflow'),
	(231, 'Šilumnešio skaitiklio maitinimo dingimo trukmė', 'Ht_ErrorWork_Powerfailed'),
	(232, 'Dažnis L1 fazėje', 'Freq1'),
	(233, 'Dažnis L2 fazėje', 'Freq2'),
	(234, 'Dažnis L3 fazėje', 'Freq3'),
	(235, 'Srovės stiprumas neutralėje', 'INeutral'),
	(236, 'Savitoji nuostolių energija srovės grandinėje L1 fazėje', 'A_Loss_Phase_1'),
	(237, 'Savitoji nuostolių energija srovės grandinėje L2 fazėje', 'A_Loss_Phase_2'),
	(238, 'Savitoji nuostolių energija srovės grandinėje L3 fazėje', 'A_Loss_Phase_3'),
	(239, 'Savitoji nuostolių energija srovės grandinėje', 'A_Loss_Phase'),
	(245, 'Šilumnešio (karšto, pamaitinimo arba šalto vandens) masės kiekis (M1 ir M2 skirtumas)', 'Ht_MassDelta'),
	(252, 'Šalto vandens masės kiekis', 'DWt_Mass'),
	(253, 'Karšto vandens masės kiekis', 'HWt_Mass'),
	(254, 'Neįprastos situacijos egzistavimas', 'Ht_SupernumerarySituation'),
	(255, 'Karšto vandens masės debitas', 'HWtMassRate'),
	(256, 'Karšto vandens temperatūros svertinis vidurkis', 'HWt_WeightAverageTemp'),
	(257, 'Absoliutus karšto vandens slėgis', 'HWt_AbsolutePress'),
	(258, 'Diferencinis karšto vandens slėgis', 'HWt_DifferentialPress'),
	(259, 'Diferencinis šalto vandens slėgis', 'DWt_DifferentialPress'),
	(260, 'Šilumos kiekis', 'Ht_JointHeat'),
	(261, 'Elektros reaktyvinė absoliuti galia/energija L2 fazėje', 'Qabs2'),
	(262, 'Elektros reaktyvinė absoliuti galia/energija L3 fazėje', 'Qabs3'),
	(263, 'Elektros pilnoji absoliuti galia/energija', 'Sabs'),
	(264, 'Elektros pilnoji absoliuti galia/energija L1 fazėje', 'Sabs1'),
	(265, 'Elektros pilnoji absoliuti galia/energija L2 fazėje', 'Sabs2'),
	(266, 'Elektros pilnoji absoliuti galia/energija L3 fazėje', 'Sabs3'),
	(267, 'Prastovos laikas išeinant iš darbinio režimo', 'Ht_ErrorWork_OutWorkMode'),
	(268, '"Suvartojimas mažiau už atkirtą" trukmė karšto vandens vamzdyje', 'HWt_ErrorWork_VolStrmLoCutoff'),
	(269, 'Keitiklio gedimo trukmė tūrio impulsų linijoje karšto vandens vamzdyje', 'HWt_ErrorWork_TransformerConsumption'),
	(270, 'Temperatūros jutiklio gedimo trukmė karšto vandens vamzdyje', 'HWt_ErrorWork_TemperatureSensorPowerFail'),
	(271, 'Slėgio jutiklio gedimo trukmė karšto vandens vamzdyje', 'HWt_ErrorWork_PressureSensorPowerFail'),
	(272, 'Avarinės situacijos trukmė, kai G2>Kpr*G1', 'Ht_ErrorWork_G2_gt_KprG1'),
	(273, 'Avarinės situacijos trukmė, kai t1-t2<delta tts', 'Ht_ErrorWork_t1_minus_t2_lt_Delta_trc'),
	(274, 'Avarinės situacijos trukmė, kai G1<G2<Kpr*G1', 'Ht_ErrorWork_G1_lt_G2_lt_KprG1'),
	(275, 'Avarinės situacijos trukmė, kai G4>Kpr*G3', 'Ht_ErrorWork_G4_gt_KprG3'),
	(276, 'Avarinės situacijos trukmė, kai t3-t4<delta tts', 'Ht_ErrorWork_t3_minus_t4_lt_Delta_trc'),
	(277, 'Avarinės situacijos trukmė, kai G3<G4<Kpr*G3', 'Ht_ErrorWork_G3_lt_G3_lt_KprG3'),
	(278, 'Temperatūros svertinis vidurkis', 'Ht_WeightAverageTemp'),
	(279, 'Elektros aktyvinė absoliuti galia/energija', 'Pabs'),
	(280, 'Elektros aktyvinė absoliuti galia/energija L1 fazėje', 'Pabs1'),
	(281, 'Elektros aktyvinė absoliuti galia/energija L2 fazėje', 'Pabs2'),
	(282, 'Elektros aktyvinė absoliuti galia/energija L3 fazėje', 'Pabs3'),
	(283, 'Elektros reaktyvinė absoliuti galia/energija', 'Qabs'),
	(284, 'Elektros reaktyvinė absoliuti galia/energija L1 fazėje', 'Qabs1'),
	(285, '"Suvartojimas mažiau už atkirtą" trukmė šalto vandens vamzdyje', 'DWt_ErrorWork_VolStrmLoCutoff'),
	(287, '"Suvartojimas mažiau už atkirtą" trukmė šilumnešio vamzdyje', 'Ht_ErrorWork_VolStrmLoCutoff'),
	(288, 'Keitiklio gedimo trukmė tūrio impulsų linijoje šalto vandens vamzdyje', 'DWt_ErrorWork_TransformerConsumption'),
	(290, 'Keitiklio gedimo trukmė tūrio impulsų linijoje šilumnešio vamzdyje', 'Ht_ErrorWork_TransformerConsumption'),
	(291, 'Temperatūros jutiklio gedimo trukmė šalto vandens vamzdyje', 'DWt_ErrorWork_TemperatureSensorPowerFail'),
	(293, 'Temperatūros jutiklio gedimo trukmė šilumnešio vamzdyje', 'Ht_ErrorWork_TemperatureSensorPowerFail'),
	(294, 'Slėgio jutiklio gedimo trukmė šalto vandens vamzdyje', 'DWt_ErrorWork_PressureSensorPowerFail'),
	(296, 'Slėgio jutiklio gedimo trukmė šilumnešio vamzdyje', 'Ht_ErrorWork_PressureSensorPowerFail'),
	(297, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą karšto vandens vamzdyje', 'HWt_ErrorWork_VolStrmTooLow'),
	(298, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą karšto vandens vamzdyje', 'HWt_ErrorWork_VolStrmTooHigh'),
	(299, 'Skaitiklio darbo laikas su daviklio gedimu karšto vandens vamzdyje', 'HWt_ErrorWork_SensorPowerFailure'),
	(300, 'Skaitiklio darbo laikas su dt < 2 karšto vandens vamzdyje', 'HWt_ErrorWork_DeltaTemper_LG_2'),
	(301, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą šalto vandens vamzdyje', 'DWt_ErrorWork_VolStrmTooLow'),
	(302, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą šalto vandens vamzdyje', 'DWt_ErrorWork_VolStrmTooHigh'),
	(303, 'Skaitiklio darbo laikas su daviklio gedimu šalto vandens vamzdyje', 'DWt_ErrorWork_SensorPowerFailure'),
	(304, 'Skaitiklio darbo laikas su dt < 2 šalto vandens vamzdyje', 'DWt_ErrorWork_DeltaTemper_LG_2'),
	(305, 'Skaitiklio darbo laikas su debitu mažesniu už minimumą šilumnešio vamzdyje', 'Ht_ErrorWork_VolStrmTooLow'),
	(306, 'Skaitiklio darbo laikas su debitu didesniu už maksimumą šilumnešio vamzdyje', 'Ht_ErrorWork_VolStrmTooHigh'),
	(307, 'Skaitiklio darbo laikas su daviklio gedimu šilumnešio vamzdyje', 'Ht_ErrorWork_SensorPowerFailure'),
	(308, 'Skaitiklio darbo laikas su dt < 2 šilumnešio vamzdyje', 'Ht_ErrorWork_DeltaTemper_LG_2'),
	(309, 'Maitinimo gedimo trukmė karšto vandens vamzdyje', 'HWt_ErrorWork_Powerfailed_InTime'),
	(310, 'Maitinimo gedimo trukmė šalto vandens vamzdyje', 'DWt_ErrorWork_Powerfailed_InTime'),
	(312, 'Maitinimo gedimo trukmė šilumnešio vamzdyje', 'Ht_ErrorWork_Powerfailed_InTime'),
	(314, 'Šalto vandens temperatūros svertinis vidurkis', 'DWt_WeightAverageTemp'),
	(316, 'Šalto vandens masės debitas', 'DWt_MassRate'),
	(317, 'Harmonikos srovė L1 fazėje', 'HarmI1'),
	(318, 'Harmonikos srovė L2 fazėje', 'HarmI2'),
	(319, 'Harmonikos srovė L3 fazėje', 'HarmI3'),
	(320, 'Išorinė oro temperatūra', 'Ht_Toutside'),
	(321, 'Prietaiso darbo laikas', 'DevUpTime'),
	(322, 'Prietaiso vidinė temperatūra', 'DevTempr'),
	(323, 'Gauto signalo kokybė', 'GSMSignalQuality_1_31'),
	(324, '1-os neįprastos situacijos trukmė', 'Ht_SupernumerarySituation_1'),
	(325, '2-os neįprastos situacijos trukmė', 'Ht_SupernumerarySituation_2'),
	(326, '3-os neįprastos situacijos trukmė', 'Ht_SupernumerarySituation_3'),
	(327, '4-os neįprastos situacijos trukmė', 'Ht_SupernumerarySituation_4'),
	(328, '5-os neįprastos situacijos trukmė', 'Ht_SupernumerarySituation_5'),
	(330, 'Šilumnešio entalpija', 'Ht_Enthalpy'),
	(331, 'Šilumos galia', 'Ht_JointHeatRate'),
	(333, 'Šilumnešio tankis', 'Ht_Density'),
	(336, 'Absoliutus šalto vandens slėgis', 'DWt_AbsolutePress'),
	(337, 'Šalto vandens entalpija', 'DWt_EntalpyWater'),
	(342, 'Šilumnešio absoliutus slėgis', 'Ht_AbsolutePress'),
	(343, 'Oro slėgis', 'Air_Pressure'),
	(344, 'Šilumnešio diferencinis slėgis', 'Ht_DifferentialPress'),
	(346, 'Sistemos darbo laikas', 'Wt_Work_System'),
	(347, 'Sistemos nedarbo laikas', 'Wt_NotWork_System'),
	(348, 'Šilumos sistemos darbo laikas', 'Ht_Work_System'),
	(349, 'Šilumos sistemos nedarbo laikas', 'Ht_NotWork_System'),
	(350, 'Šilumnešio vamzdyno nedarbo laikas', 'Ht_NotWork_'),
	(351, 'Dujų skaitiklio darbo laikas', 'Gas_Work_Device'),
	(352, 'Šalto vandens vamzdyno nedarbo laikas', 'Wt_NotWork'),
	(353, 'Mazgo darbo laikas', 'Gas_Work'),
	(354, 'Šalto vandens skaitiklio nedarbo laikas', 'Wt_NotWork_Device'),
	(355, 'Šalto vandens vamzdyno darbo laikas', 'Wt_Work'),
	(356, 'Rodiklis Nr.2', 'Indicator2'),
	(357, 'Rodiklis Nr.3', 'Indicator3'),
	(358, 'Rodiklis Nr.4', 'Indicator4'),
	(359, 'Rodiklis Nr.5', 'Indicator5'),
	(360, 'Rodiklis Nr.6', 'Indicator6'),
	(361, 'Rodiklis Nr.7', 'Indicator7'),
	(362, 'Rodiklis Nr.8', 'Indicator8'),
	(363, 'Rodiklis Nr.9', 'Indicator9'),
	(364, 'Rodiklis Nr.10', 'Indicator10'),
	(365, 'Karšto vandens slėgio svertinis vidurkis', 'HWt_WeightAveragePressure'),
	(366, 'Šalto vandens slėgio svertinis vidurkis', 'Wt_WeightAveragePressure'),
	(367, 'Šilumnešio slėgio svertinis vidurkis', 'Ht_WeightAveragePressure'),
	(369, '1-os neįprastos situacijos trukmė šilumos sistemoje', 'Ht_ErrorWork_1_System'),
	(370, '2-os neįprastos situacijos trukmė šilumos sistemoje', 'Ht_ErrorWork_2_System'),
	(371, '3-os neįprastos situacijos trukmė šilumos sistemoje', 'Ht_ErrorWork_3_System'),
	(372, '4-os neįprastos situacijos trukmė šilumos sistemoje', 'Ht_ErrorWork_4_System'),
	(373, '5-os neįprastos situacijos trukmė šilumos sistemoje', 'Ht_ErrorWork_5_System'),
	(374, 'Aktyvios galios 10-s maksimalių reikšmių suma', 'P_Max_All_Top10Sum'),
	(375, 'Reaktyvios galios 10-s maksimalių reikšmių suma', 'Q_Max_All_Top10Sum'),
	(376, 'Pilnos galios 10-s maksimalių reikšmių suma', 'S_Max_All_Top10Sum'),
	(377, 'Rodiklis Nr.11', 'Indicator11'),
	(378, 'Rodiklis Nr.12', 'Indicator12'),
	(379, 'Rodiklis Nr.13', 'Indicator13'),
	(380, 'Rodiklis Nr.14', 'Indicator14'),
	(381, 'Rodiklis Nr.15', 'Indicator15'),
	(382, 'Rodiklis Nr.16', 'Indicator16'),
	(383, 'Rodiklis Nr.17', 'Indicator17'),
	(384, 'Rodiklis Nr.18', 'Indicator18'),
	(385, 'Rodiklis Nr.19', 'Indicator19'),
	(386, 'Rodiklis Nr.20', 'Indicator20'),
	(387, 'Andriaus MSF', 'Indicator21'),
	(388, 'buves 22 m', 'Indicator22'),
	(389, 'Rodiklis Nr.23', 'Indicator23'),
	(390, 'Rodiklis Nr.24', 'Indicator24'),
	(391, 'Rodiklis Nr.25', 'Indicator25'),
	(392, 'Rodiklis Nr.26', 'Indicator26'),
	(393, 'Rodiklis Nr.27', 'Indicator27'),
	(394, 'Rodiklis Nr.28', 'Indicator28'),
	(395, 'Rodiklis Nr.29', 'Indicator29'),
	(396, 'P kumuliacinė galia', 'P_Cumulated'),
	(397, 'S kumuliacinė galia', 'S_Cumulated'),
	(398, 'Q kumuliacinė galia', 'Q_Cumulated'),
	(399, 'Reaktyvios galios koeficientas', 'Q_Coef'),
	(400, 'Reaktyvios galios koeficientas L1 fazėje', 'Q1_Coef'),
	(401, 'Reaktyvios galios koeficientas L2 fazėje', 'Q2_Coef'),
	(402, 'Reaktyvios galios koeficientas L3 fazėje', 'Q3_Coef'),
	(403, 'Aktyvios galios koeficientas', 'P_Coef'),
	(404, 'Aktyvios galios koeficientas L1 fazėje', 'P1_Coef'),
	(405, 'Aktyvios galios koeficientas L2 fazėje', 'P2_Coef'),
	(406, 'Aktyvios galios koeficientas L3 fazėje', 'P3_Coef'),
	(407, 'P nuostolių galia', 'P_Loss'),
	(408, 'Aktyvinių nuostolių galia L1 fazėje', 'P1_Loss'),
	(409, 'Aktyvinių nuostolių galia L2 fazėje', 'P2_Loss'),
	(410, 'Aktyvinių nuostolių galia L3 fazėje', 'P3_Loss'),
	(411, 'Galios koeficientas (tg)', 'Tg'),
	(412, 'Galios koeficientas (tg) L1 fazėje', 'Tg1'),
	(413, 'Galios koeficientas (tg) L2 fazėje', 'Tg2'),
	(414, 'Galios koeficientas (tg) L3 fazėje', 'Tg3'),
	(415, 'GSM signalo stiprumas', 'GSMSignalStrength_dBm'),
	(416, 'Varža', 'Resistance'),
	(417, 'Savitoji varža', 'ElResistivity'),
	(418, 'Laidumas', 'Permittance'),
	(419, 'Savitasis laidumas', 'ElConductivity'),
	(420, 'Talpa', 'Capacitance'),
	(421, 'Induktyvumas', 'Inductance'),
	(422, 'Krovimo būklė', 'ChargingStatus'),
	(423, 'Vartotojo sąsajos (Cl in) būklė', 'CLInStatus'),
	(424, 'Skaitiklio sąsajos (Cl out) būklė', 'CLOUTStatus'),
	(425, 'Maitinimo (AC) būklė', 'ACStatus'),
	(426, 'Modemo duomenų laukimo taimautas', 'ModemDataWaitTimeOut'),
	(427, 'Maitinimo (AC) dingimų kiekis', 'ACFaultCount'),
	(428, 'Užkrovimas iš EEPROM', 'BootEEPROM'),
	(429, 'Harmonikos srovė', 'HarmI'),
	(430, 'Harmonikos įtampa', 'HarmU'),
	(431, 'Harmonikos įtampa L1 fazėje', 'HarmU1'),
	(432, 'Harmonikos įtampa L2 fazėje', 'HarmU2'),
	(433, 'Harmonikos įtampa L3 fazėje', 'HarmU3'),
	(434, 'A nuostolių energija', 'A_Loss'),
	(435, 'Q nuostolių galia', 'Q_Loss'),
	(436, 'R nuostolių energija', 'R_Loss'),
	(437, 'Srauto daviklio gedimo trukmė šilumnešio vamzdyje', 'Ht_ErrorWork_Flow_SensorPowerFailure'),
	(438, 'Ryšio su kanalu nebuvimo trukmė šilumnešio vamzdyje', 'Ht_ErrorWork_NoCommunicationWithChannel'),
	(439, '"Temperatūra daugiau maksimumo" trukmė šilumnešio vamzdyje', 'Ht_ErrorWork_Temperature_TooHigh'),
	(440, '"Temperatūra mažiau minimumo" trukmė šilumnešio vamzdyje', 'Ht_ErrorWork_Temperature_TooLow'),
	(441, 'Šilumos nuostolių kiekis', 'Ht_HeatQntt_Leakage'),
	(442, 'Šilumos kiekis nuo pradinio įjungimo', 'Ht_HeatQntt_From_Init'),
	(443, 'Dujų turbulentinis tūris', 'Gas_VolQnttAtErr'),
	(444, 'Dujų slėgis normaliose sąlygose', 'Gas_CorrPress'),
	(445, 'Dujų temperatūra normaliose sąlygose', 'Gas_CorrTemper'),
	(446, 'Vandenilio H2 kiekis', 'Gas_ContentH2'),
	(447, 'Dujų suspaudimo koeficientas', 'Gas_CompressFactor'),
	(448, 'Dujų korekcijos koeficientas', 'Gas_CorrFactor_InTime'),
	(449, 'Dujų turbulentinis šilumos kiekis', 'Gas_HeatQnttAtErr'),
	(450, 'Dujų bendras suvartojimo tūris normaliose sąlygose', 'Gas_CorrVolQntt_System'),
	(451, 'Dujų bendras suvartojimo tūris', 'Gas_VolQntt_System'),
	(452, 'Išmatuotas dujų slėgis', 'Gas_Press_System'),
	(453, 'Išmatuota dujų temperatūra', 'Gas_Temper_System'),
	(454, 'Dujų bendras šilumos kiekis', 'Gas_HeatQntt_System'),
	(455, 'Rodiklis Nr.30', 'Indicator30'),
	(456, 'Absoliutus dujų slėgis', 'Gas_PressAbsolute'),
	(457, 'Dujų tankis', 'Gas_Density'),
	(458, 'Dujų tankis normaliose sąlygose', 'Gas_CorrDensity'),
	(459, 'Rodiklis Nr.31', 'Indicator31'),
	(460, 'Rodiklis Nr.32', 'Indicator32'),
	(461, 'Rodiklis Nr.33', 'Indicator33'),
	(462, 'Rodiklis Nr.34', 'Indicator34'),
	(463, 'Rodiklis Nr.35', 'Indicator35'),
	(464, 'Rodiklis Nr.36', 'Indicator36'),
	(465, 'Rodiklis Nr.37', 'Indicator37'),
	(466, 'Rodiklis Nr.38', 'Indicator38'),
	(467, 'Rodiklis Nr.39', 'Indicator39'),
	(468, 'Rodiklis Nr.40', 'Indicator40'),
	(469, 'Oro tūrio kiekis', 'Air_Vol'),
	(470, 'Oro tūrio srautas', 'Air_VolRate'),
	(471, 'Oro masės kiekis', 'Air_Mass'),
	(472, 'Oro masės srautas', 'Air_MassRate'),
	(473, 'Dujų slėgių skirtumas', 'Gas_PressDifferential'),
	(474, 'Avarinio pamaitinimo tūrio kiekis', 'Ht_Vol_Emergency'),
	(475, 'Avarinio pamaitinimo tūrio debitas', 'Ht_VolStrm_Emergency'),
	(476, 'Avarinio pamaitinimo masės kiekis', 'Ht_Mass_Emergency'),
	(477, 'Avarinio pamaitinimo masės srautas', 'Ht_MassStrm_Emergency'),
	(478, 'Avarinio pamaitinimo šilumos galia', 'Ht_HeatPwr_Emergency'),
	(479, 'Avarinio pamaitinimo temperatūra', 'Ht_Temper_Emergency'),
	(480, 'Avarinio pamaitinimo slėgis', 'Ht_Press_Emergency'),
	(481, 'Avarinio pamaitinimo absoliutus slėgis', 'Ht_PressAbsolute_Emergency'),
	(482, 'Avarinio pamaitinimo slėgių skirtumo perskaičiuota reikšmė', 'Ht_PressAlteration_Emergency'),
	(483, 'Avarinio pamaitinimo šilumos kiekis', 'Ht_Heat_Emergency'),
	(484, 'Fazės L1 aktyvinių A+ ir A- energijų balansas', 'ApNetm_Phase_1'),
	(485, 'Fazės L2 aktyvinių A+ ir A- energijų balansas', 'ApNetm_Phase_2'),
	(486, 'Fazės L3 aktyvinių A+ ir A- energijų balansas', 'ApNetm_Phase_3'),
	(487, 'Fazės L1 reaktyvinių R+ ir R- energijų balansas', 'RpNetm_Phase_1'),
	(488, 'Fazės L2 reaktyvinių R+ ir R- energijų balansas', 'RpNetm_Phase_2'),
	(489, 'Fazės L3 reaktyvinių R+ ir R- energijų balansas', 'RpNetm_Phase_3'),
	(490, 'Fazės L1 pilnųjų W+ ir W- energijų balansas', 'WpNetm_Phase_1'),
	(491, 'Fazės L2 pilnųjų W+ ir W- energijų balansas', 'WpNetm_Phase_2'),
	(492, 'Fazės L3 pilnųjų W+ ir W- energijų balansas', 'WpNetm_Phase_3'),
	(493, 'Kredito likutis (pinigai)', 'ResidualCredit'),
	(494, 'Šilumnešio atbulinės krypties tūris', 'Ht_VolRev'),
	(495, 'Šilumnešio srauto greitis', 'Ht_FlowRate'),
	(496, 'Šilumnešio ultragarsinio signalo greitis', 'Ht_UltraSoundSpeed'),
	(497, 'Šilumos kiekis sistemoje', 'Ht_Heat_System'),
	(498, 'Dujų nekonvertuotas tūris Vc1err', 'Gas_VolQnttAtErrCalibration'),
	(499, 'Azoto dalis dujose', 'Gas_ContentN2'),
	(500, 'CO2 dalis dujose', 'Gas_ContentCO2'),
	(501, 'Viršutinis dujų šilumingumas', 'Gas_CalorificValueSuperior'),
	(502, 'Santykinis dujų tankis', 'Gas_RelativeDensity');
/*!40000 ALTER TABLE `msf` ENABLE KEYS */;

-- Dumping structure for table emcor.ms_kind
CREATE TABLE IF NOT EXISTS `ms_kind` (
  `ms_kind_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimų rūšies identifikatorius',
  `ms_kind_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Matavimų rūšies kodas',
  PRIMARY KEY (`ms_kind_id`),
  UNIQUE KEY `ms_kind_code_u` (`ms_kind_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimų rūšys';

-- Dumping data for table emcor.ms_kind: ~192 rows (approximately)
/*!40000 ALTER TABLE `ms_kind` DISABLE KEYS */;
INSERT INTO `ms_kind` (`ms_kind_id`, `ms_kind_code`) VALUES
	(150, 'ACFaultCount'),
	(148, 'ACStatus'),
	(89, 'A_Loss'),
	(181, 'A_Net'),
	(153, 'AbsolutePress'),
	(60, 'AngleShiftPhaseI'),
	(74, 'AngleShiftPhaseIU'),
	(59, 'AngleShiftPhaseU'),
	(64, 'Angle_IU_Mom'),
	(61, 'Angle_U12_Mom'),
	(62, 'Angle_U23_Mom'),
	(63, 'Angle_U31_Mom'),
	(151, 'BootEEPROM'),
	(146, 'CLInStatus'),
	(147, 'CLOUTStatus'),
	(191, 'CalorificValueSuperior'),
	(143, 'Capacitance'),
	(145, 'ChargingStatus'),
	(22, 'CoefBackwSeq'),
	(23, 'CoefBackwSeqHiHiPrc'),
	(24, 'CoefBackwSeqHiPrc'),
	(58, 'CoefHarmStand'),
	(55, 'CoefNonSymU0Stand '),
	(54, 'CoefNonSymU2Stand '),
	(25, 'CoefZeroSeq'),
	(26, 'CoefZeroSeqHiHiPrc'),
	(27, 'CoefZeroSeqHiPrc'),
	(165, 'CompressFactor'),
	(190, 'ContentCO2'),
	(164, 'ContentH2'),
	(189, 'ContentN2'),
	(173, 'CorrDensity'),
	(166, 'CorrFactor'),
	(12, 'CorrMass'),
	(162, 'CorrPress'),
	(163, 'CorrTemper'),
	(13, 'CorrVol'),
	(169, 'CorrVolSystem'),
	(7, 'Cos'),
	(119, 'Density'),
	(111, 'DevTempr'),
	(110, 'DevUpTime'),
	(9, 'DifferentialPress'),
	(142, 'ElConductivity'),
	(140, 'ElResistivity'),
	(49, 'EngQltInd'),
	(120, 'EntalpyWater'),
	(118, 'Enthalpy'),
	(50, 'ErrorCode'),
	(83, 'ErrorWork'),
	(122, 'ErrorWork_1'),
	(123, 'ErrorWork_2'),
	(124, 'ErrorWork_3'),
	(125, 'ErrorWork_4'),
	(126, 'ErrorWork_5'),
	(93, 'ErrorWork_DeltaTemper_LG_2'),
	(104, 'ErrorWork_G1_lt_G2_lt_KprG1'),
	(102, 'ErrorWork_G2_gt_KprG1'),
	(107, 'ErrorWork_G3_lt_G3_lt_KprG3'),
	(105, 'ErrorWork_G4_gt_KprG3'),
	(84, 'ErrorWork_Metrology'),
	(156, 'ErrorWork_NoCommunicationWithChannel'),
	(97, 'ErrorWork_OutWorkMode'),
	(85, 'ErrorWork_Overflow'),
	(86, 'ErrorWork_Powerfailed'),
	(101, 'ErrorWork_PressureSensorPowerFail'),
	(92, 'ErrorWork_SensorPowerFailure'),
	(100, 'ErrorWork_TemperatureSensorPowerFail'),
	(157, 'ErrorWork_Temperature_TooHigh'),
	(158, 'ErrorWork_Temperature_TooLow'),
	(99, 'ErrorWork_TransformerConsumption'),
	(98, 'ErrorWork_VolStrmLoCutoff'),
	(91, 'ErrorWork_VolStrmTooHigh'),
	(90, 'ErrorWork_VolStrmTooLow'),
	(103, 'ErrorWork_t1_minus_t2_lt_Delta_trc'),
	(106, 'ErrorWork_t3_minus_t4_lt_Delta_trc'),
	(10, 'F'),
	(11, 'FS'),
	(28, 'Flicker'),
	(29, 'FlickerHiHiPrc'),
	(57, 'FlickerPltStand'),
	(56, 'FlickerPstStand'),
	(87, 'Freq'),
	(30, 'FreqDev'),
	(31, 'FreqDevHiHiPrc'),
	(32, 'FreqDevHiPrc'),
	(52, 'FreqDeviationStand '),
	(19, 'Frost_Energy'),
	(112, 'GSMSignalQuality_1_31'),
	(138, 'GSMSignalStrength_dBm'),
	(33, 'HarmCoef'),
	(34, 'HarmCoefHiHiPrc'),
	(35, 'HarmCoefHiPrc'),
	(76, 'HarmCoef_I'),
	(109, 'HarmI'),
	(36, 'HarmQual'),
	(152, 'HarmU'),
	(16, 'Heat'),
	(167, 'HeatAtErr'),
	(176, 'HeatEmergency'),
	(172, 'HeatSystem'),
	(77, 'Heat_Device'),
	(160, 'Heat_From_Init'),
	(159, 'Heat_Leakage'),
	(3, 'I'),
	(88, 'INeutral'),
	(144, 'Inductance'),
	(37, 'LongFlicker'),
	(38, 'LongFlickerHiHiPrc'),
	(39, 'MainHarmValue'),
	(14, 'Mass'),
	(175, 'MassEmergency'),
	(78, 'MassLoss'),
	(149, 'ModemDataWaitTimeOut'),
	(21, 'NotWork'),
	(1, 'P'),
	(134, 'P_Coef'),
	(130, 'P_Cumulated'),
	(135, 'P_Loss'),
	(127, 'P_Max_All_Top10Sum'),
	(108, 'Pabs'),
	(141, 'Permittance'),
	(65, 'PowerFactor1_Mom'),
	(66, 'PowerFactor2_Mom'),
	(67, 'PowerFactor3_Mom'),
	(73, 'PowerFactor_Mom'),
	(15, 'Press'),
	(179, 'PressAbsoluteEmergency'),
	(180, 'PressAlterationEmergency'),
	(178, 'PressEmergency'),
	(170, 'PressSystem'),
	(121, 'Pressure'),
	(72, 'Production'),
	(2, 'Q'),
	(133, 'Q_Coef'),
	(132, 'Q_Cumulated'),
	(136, 'Q_Loss'),
	(128, 'Q_Max_All_Top10Sum'),
	(95, 'Qabs'),
	(8, 'Quadrant'),
	(182, 'R_Net'),
	(186, 'Rate'),
	(192, 'RelativeDensity'),
	(184, 'ResidualCredit'),
	(139, 'Resistance'),
	(6, 'S'),
	(131, 'S_Cumulated'),
	(129, 'S_Max_All_Top10Sum'),
	(96, 'Sabs'),
	(75, 'Sin'),
	(40, 'SinDistort'),
	(41, 'SinDistortHiHiPrc'),
	(42, 'SinDistortHiPrc'),
	(53, 'SinDistortionStand'),
	(187, 'Speed'),
	(94, 'SupernumerarySituation'),
	(113, 'SupernumerarySituation_1'),
	(114, 'SupernumerarySituation_2'),
	(115, 'SupernumerarySituation_3'),
	(116, 'SupernumerarySituation_4'),
	(117, 'SupernumerarySituation_5'),
	(69, 'THDI'),
	(71, 'THDIMax'),
	(68, 'THDUF'),
	(70, 'THDUFMax'),
	(17, 'Temp'),
	(171, 'TempSystem'),
	(177, 'TemperEmergency'),
	(137, 'Tg'),
	(4, 'U'),
	(5, 'UL'),
	(80, 'UL12'),
	(81, 'UL13'),
	(82, 'UL23'),
	(18, 'Vol'),
	(161, 'VolAtErr'),
	(174, 'VolEmergency'),
	(79, 'VolLoss'),
	(188, 'VolQnttAtErrCalibration'),
	(185, 'VolRev'),
	(168, 'VolSystem'),
	(43, 'VoltDev'),
	(46, 'VoltDevAmpl'),
	(47, 'VoltDevAmplHiHiPrc'),
	(48, 'VoltDevFreq'),
	(44, 'VoltDevHiHiPrc'),
	(45, 'VoltDevHiPrc'),
	(51, 'VoltageDeviationStand'),
	(183, 'W_Net'),
	(155, 'WeightAveragePressure'),
	(154, 'WeightAverageTemp'),
	(20, 'Work');
/*!40000 ALTER TABLE `ms_kind` ENABLE KEYS */;

-- Dumping structure for table emcor.ms_type
CREATE TABLE IF NOT EXISTS `ms_type` (
  `ms_type_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimų tipo identifikatorius',
  `ms_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Matavimų tipo pavadinimas',
  `visible` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Rodymo požymis',
  PRIMARY KEY (`ms_type_id`),
  UNIQUE KEY `ms_type_name_u` (`ms_type_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimų klasės';

-- Dumping data for table emcor.ms_type: ~8 rows (approximately)
/*!40000 ALTER TABLE `ms_type` DISABLE KEYS */;
INSERT INTO `ms_type` (`ms_type_id`, `ms_type_name`, `visible`) VALUES
	(0, 'Kiti matavimai', 1),
	(1, 'Elektra', 1),
	(2, 'Oras', 1),
	(5, 'Šaltis', 1),
	(6, 'Šilumnešis', 1),
	(7, 'Dujos', 1),
	(8, 'Šaltas vanduo', 1),
	(11, 'Karštas vanduo', 1);
/*!40000 ALTER TABLE `ms_type` ENABLE KEYS */;

-- Dumping structure for table emcor.ms_type_ug
CREATE TABLE IF NOT EXISTS `ms_type_ug` (
  `ms_type_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimų tipo identifikatorius',
  `ug_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojų grupės identifikatorius',
  `visible` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Rodymo požymis',
  UNIQUE KEY `ms_type_ug_uk` (`ms_type_id`,`ug_id`),
  KEY `ms_type_ug_ug_fk` (`ug_id`),
  CONSTRAINT `ms_type_ug_ms_type_fk` FOREIGN KEY (`ms_type_id`) REFERENCES `ms_type` (`ms_type_id`),
  CONSTRAINT `ms_type_ug_ug_fk` FOREIGN KEY (`ug_id`) REFERENCES `ug` (`ug_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Vartotojų grupėms pasiekiami matavimų tipai';

-- Dumping data for table emcor.ms_type_ug: ~0 rows (approximately)
/*!40000 ALTER TABLE `ms_type_ug` DISABLE KEYS */;
/*!40000 ALTER TABLE `ms_type_ug` ENABLE KEYS */;

-- Dumping structure for table emcor.mt
CREATE TABLE IF NOT EXISTS `mt` (
  `mt_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Monitoringe naudojamo rodiklio ID',
  `point_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo taško identifikatorius',
  `ml_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Matavimo linijos identifikatorius',
  `sam_id` int(10) unsigned DEFAULT NULL COMMENT 'Šablono identifikatorius',
  `gr_id` int(10) unsigned DEFAULT NULL COMMENT 'Grupės identifikatorius',
  `gmod_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Sugrupuotų duomenų modifikacijos ID',
  `gprc` tinyint(3) unsigned DEFAULT NULL COMMENT 'Grupės procentinės reikšmės naudojimo požymis',
  `ec_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Ekonominės kategorijos identifikatorius',
  `ec_in` tinyint(1) DEFAULT NULL COMMENT 'Ekonominės kategorijos pajamų/išlaidų požymis',
  PRIMARY KEY (`mt_id`),
  UNIQUE KEY `mt_ak` (`point_id`,`ml_id`,`sam_id`,`gr_id`,`gmod_id`,`gprc`,`ec_id`,`ec_in`),
  KEY `mt_ec_i` (`ec_id`),
  KEY `mt_gmod_i` (`gmod_id`),
  KEY `mt_gr_i` (`gr_id`),
  KEY `mt_ml_i` (`ml_id`),
  KEY `mt_sam_i` (`sam_id`),
  CONSTRAINT `mt_ec_fk` FOREIGN KEY (`ec_id`) REFERENCES `ec` (`ec_id`) ON DELETE CASCADE,
  CONSTRAINT `mt_gmod_fk` FOREIGN KEY (`gmod_id`) REFERENCES `gmod` (`gmod_id`) ON DELETE CASCADE,
  CONSTRAINT `mt_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE,
  CONSTRAINT `mt_ml_fk` FOREIGN KEY (`ml_id`) REFERENCES `ml` (`ml_id`) ON DELETE CASCADE,
  CONSTRAINT `mt_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `mt_sam_fk` FOREIGN KEY (`sam_id`) REFERENCES `sam` (`sam_id`) ON DELETE CASCADE,
  CONSTRAINT `MT_NOT_IN_14_CHK` CHECK (`point_id` is not null and `ml_id` is not null and `sam_id` is null and `gr_id` is null and `gmod_id` is null and `gprc` is null and `ec_id` is null and `ec_in` is null or `point_id` is null and `ml_id` is null and `sam_id` is not null and `gr_id` is null and `gmod_id` is null and `gprc` is null and `ec_id` is null and `ec_in` is null or `point_id` is null and `ml_id` is not null and `sam_id` is null and `gr_id` is not null and `gprc` is not null and `gprc` in (0,1,2) and `ec_id` is null and `ec_in` is null or `point_id` is null and `ml_id` is not null and `sam_id` is null and `gr_id` is not null and `gprc` is not null and `gprc` = 0 and `ec_id` is null and `ec_in` is not null and `ec_in` in (0,1) or `point_id` is null and `ml_id` is not null and `sam_id` is null and `gr_id` is not null and `gprc` is not null and `gprc` = 0 and `ec_id` is not null and `ec_in` is null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Monitoringe naudojami rodikliai';

-- Dumping data for table emcor.mt: ~0 rows (approximately)
/*!40000 ALTER TABLE `mt` DISABLE KEYS */;
/*!40000 ALTER TABLE `mt` ENABLE KEYS */;

-- Dumping structure for table emcor.mta
CREATE TABLE IF NOT EXISTS `mta` (
  `ma_id` int(10) unsigned NOT NULL COMMENT 'Monitoringo priskyrimo identifikatorius',
  `ts_id` tinyint(1) NOT NULL COMMENT 'Paskirties požymis',
  `mt_id` int(10) unsigned NOT NULL COMMENT 'Monitoringe naudojamo rodiklio ID',
  PRIMARY KEY (`ma_id`,`ts_id`),
  KEY `mta_mt_i` (`mt_id`,`ts_id`),
  KEY `mta_ts_i` (`ts_id`),
  CONSTRAINT `mta_ma_fk` FOREIGN KEY (`ma_id`) REFERENCES `ma` (`ma_id`) ON DELETE CASCADE,
  CONSTRAINT `mta_mt_fk` FOREIGN KEY (`mt_id`) REFERENCES `mt` (`mt_id`) ON DELETE CASCADE,
  CONSTRAINT `mta_ts_fk` FOREIGN KEY (`ts_id`) REFERENCES `ts` (`ts_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Monitoringo priskyrimo rodikliai';

-- Dumping data for table emcor.mta: ~0 rows (approximately)
/*!40000 ALTER TABLE `mta` DISABLE KEYS */;
/*!40000 ALTER TABLE `mta` ENABLE KEYS */;

-- Dumping structure for table emcor.my_root
CREATE TABLE IF NOT EXISTS `my_root` (
  `user_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojo identifikatorius',
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  PRIMARY KEY (`user_id`),
  KEY `my_root_gr_i` (`gr_id`),
  CONSTRAINT `my_root_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE,
  CONSTRAINT `my_root_user_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Vartotojų pasirinktos šakninės grupės';

-- Dumping data for table emcor.my_root: ~0 rows (approximately)
/*!40000 ALTER TABLE `my_root` DISABLE KEYS */;
/*!40000 ALTER TABLE `my_root` ENABLE KEYS */;

-- Dumping structure for table emcor.opty
CREATE TABLE IF NOT EXISTS `opty` (
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `lpty_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybių tipo identifikatorius',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  `opty_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Parametro kodas',
  `opty_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Parametro pavadinimas',
  `opty_tm` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'TM parametro požymis',
  `opty_default` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Parametro reikšmė pagal nutylėjimą',
  `opty_nr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Parametro eilės numeris rušiavimui',
  PRIMARY KEY (`opty_id`),
  UNIQUE KEY `opty_name_u` (`opty_name`),
  KEY `opty_code_i` (`opty_code`),
  KEY `opty_enum_i` (`enum_id`),
  KEY `opty_lpty_type_i` (`lpty_type_id`),
  CONSTRAINT `opty_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`),
  CONSTRAINT `opty_lpty_type_fk` FOREIGN KEY (`lpty_type_id`) REFERENCES `lpty_type` (`lpty_type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Galimų parametrų sąrašas';

-- Dumping data for table emcor.opty: ~43 rows (approximately)
/*!40000 ALTER TABLE `opty` DISABLE KEYS */;
INSERT INTO `opty` (`opty_id`, `lpty_type_id`, `enum_id`, `opty_code`, `opty_name`, `opty_tm`, `opty_default`, `opty_nr`) VALUES
	(1, 5, NULL, 'Address', 'Registro adresas', 0, NULL, NULL),
	(2, 5, NULL, 'Data_Code_Virt', 'Virtualus kodas', 0, NULL, NULL),
	(3, 5, NULL, 'Count', 'Registrų kiekis', 0, NULL, NULL),
	(4, 5, NULL, 'Value', 'Įrašomo registro reikšmė', 0, NULL, NULL),
	(5, 5, NULL, 'DataType', 'Registro tipas', 0, NULL, NULL),
	(6, 5, 528, 'Action', 'Operacija', 0, NULL, NULL),
	(7, 5, 82, 'All', 'Visų duomenų užklausimo požymis', 0, NULL, NULL),
	(8, 5, NULL, 'GroupNr', 'Grupės numeris', 0, NULL, NULL),
	(9, 5, 588, 'Priority', 'Prioritetas', 0, NULL, NULL),
	(10, 5, NULL, 'Channel', 'Kanalo numeris', 0, NULL, NULL),
	(11, 5, NULL, 'MeterID', 'Skaitiklio identifikatorius', 0, NULL, NULL),
	(12, 5, NULL, 'ObisCode', 'OBIS kodas', 0, NULL, NULL),
	(13, 5, NULL, 'ClassID', 'Duomenų klasės identifikatorius', 0, NULL, NULL),
	(14, 5, NULL, 'AttributeID', 'Atributo identifikatorius', 0, NULL, NULL),
	(15, 5, 636, 'CosemDataType', 'Įrašomų duomenų tipas', 0, NULL, NULL),
	(16, 5, NULL, 'ShortName', 'Objekto trumpasis adresas HEX formatu įrašymui', 0, NULL, NULL),
	(17, 3, NULL, 'AddrSource', 'Šaltinio adresas', 0, NULL, NULL),
	(18, 5, NULL, 'ShortName1', 'Objekto trumpasis adresas HEX formatu įrašymui 1', 0, NULL, NULL),
	(19, 5, NULL, 'ShortName2', 'Objekto trumpasis adresas HEX formatu įrašymui 2', 0, NULL, NULL),
	(20, 5, NULL, 'ShortName3', 'Objekto trumpasis adresas HEX formatu įrašymui 3', 0, NULL, NULL),
	(21, 5, NULL, 'ShortName4', 'Objekto trumpasis adresas HEX formatu įrašymui 4', 0, NULL, NULL),
	(22, 5, NULL, 'ShortName5', 'Objekto trumpasis adresas HEX formatu įrašymui 5', 0, NULL, NULL),
	(23, 5, NULL, 'ShortName6', 'Objekto trumpasis adresas HEX formatu įrašymui 6', 0, NULL, NULL),
	(24, 5, NULL, 'ShortName7', 'Objekto trumpasis adresas HEX formatu įrašymui 7', 0, NULL, NULL),
	(25, 5, NULL, 'ShortName8', 'Objekto trumpasis adresas HEX formatu įrašymui 8', 0, NULL, NULL),
	(26, 5, NULL, 'ShortName9', 'Objekto trumpasis adresas HEX formatu įrašymui 9', 0, NULL, NULL),
	(27, 5, NULL, 'ShortName10', 'Objekto trumpasis adresas HEX formatu įrašymui 10', 0, NULL, NULL),
	(28, 5, NULL, 'ShortName11', 'Objekto trumpasis adresas HEX formatu įrašymui 11', 0, NULL, NULL),
	(29, 5, NULL, 'ShortName12', 'Objekto trumpasis adresas HEX formatu įrašymui 12', 0, NULL, NULL),
	(30, 5, NULL, 'ShortName13', 'Objekto trumpasis adresas HEX formatu įrašymui 13', 0, NULL, NULL),
	(31, 5, NULL, 'ShortName14', 'Objekto trumpasis adresas HEX formatu įrašymui 14', 0, NULL, NULL),
	(32, 5, NULL, 'ShortName15', 'Objekto trumpasis adresas HEX formatu įrašymui 15', 0, NULL, NULL),
	(33, 5, NULL, 'AsyncReq', 'Asinchroninės užklausos funkcija', 0, NULL, NULL),
	(34, 5, NULL, 'ResourceID', 'Resurso identifikatorius', 0, NULL, NULL),
	(35, 5, NULL, 'ResourceURI', 'Resurso URI', 0, NULL, NULL),
	(36, 5, NULL, 'ExpireTime', 'Užduoties galiojimo pabaiga', 0, NULL, NULL),
	(37, 5, NULL, 'Index', 'Indeksas', 0, NULL, NULL),
	(38, 5, NULL, 'GroupID', 'Grupės indeksas', 0, NULL, NULL),
	(39, 5, NULL, 'ParamID', 'Parametro indeksas', 0, NULL, NULL),
	(40, 5, NULL, 'ValueID', 'Reikšmės indeksas', 0, NULL, NULL),
	(41, 5, 817, 'Config', 'Duomenų kategorija', 0, NULL, NULL),
	(42, 5, NULL, 'MeterNumber', 'MeterNumber', 0, NULL, NULL),
	(43, 5, NULL, 'DeviceType', 'DeviceType', 0, NULL, NULL);
/*!40000 ALTER TABLE `opty` ENABLE KEYS */;

-- Dumping structure for table emcor.per
CREATE TABLE IF NOT EXISTS `per` (
  `per_id` tinyint(3) unsigned NOT NULL COMMENT 'Periodo identifikatorius',
  `per_code` varchar(10) COLLATE utf8_bin NOT NULL COMMENT 'Periodo kodas',
  `per_name` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'Periodo pavadinimas',
  PRIMARY KEY (`per_id`),
  UNIQUE KEY `per_code_u` (`per_code`),
  UNIQUE KEY `per_name_u` (`per_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Laiko periodai';

-- Dumping data for table emcor.per: ~6 rows (approximately)
/*!40000 ALTER TABLE `per` DISABLE KEYS */;
INSERT INTO `per` (`per_id`, `per_code`, `per_name`) VALUES
	(1, 'SS', 'Sekundė'),
	(2, 'MI', 'Minutė'),
	(3, 'HH', 'Valanda'),
	(4, 'DD', 'Para'),
	(5, 'MM', 'Mėnuo'),
	(6, 'YYYY', 'Metai');
/*!40000 ALTER TABLE `per` ENABLE KEYS */;

-- Dumping structure for table emcor.ph
CREATE TABLE IF NOT EXISTS `ph` (
  `ph_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Ryšio kanalo identifikatorius',
  `ph_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius',
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `ph_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ryšio kanalo pavadinimas',
  `ph_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Ryšio kanalo naudojimo požymis',
  `ph_deleted` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Ištrinto ryšio kanalo požymis',
  `ph_save_statistics` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Statistikos ryšio kanalui rinkimo požymis',
  `ph_failure_count` smallint(5) unsigned NOT NULL DEFAULT 5 COMMENT 'Nesėkmingų prisijungimo bandymų kiekis, po kurio kanalas laikomas neveikiančiu',
  `costa_g_per_id` tinyint(3) unsigned DEFAULT NULL,
  `costa_g_exp_value` mediumint(8) unsigned DEFAULT NULL,
  `costa_b_per_id` tinyint(3) unsigned DEFAULT NULL,
  `costa_b_exp_value` mediumint(8) unsigned DEFAULT NULL,
  PRIMARY KEY (`ph_id`),
  UNIQUE KEY `ph_dp_u` (`dp_id`,`ph_name`),
  KEY `ph_ph_type_i` (`ph_type_id`),
  CONSTRAINT `ph_dt_fk` FOREIGN KEY (`dp_id`) REFERENCES `dp` (`dp_id`) ON DELETE CASCADE,
  CONSTRAINT `ph_ph_type_fk` FOREIGN KEY (`ph_type_id`) REFERENCES `ph_type` (`ph_type_id`)
) ENGINE=InnoDB AUTO_INCREMENT=594 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ryšio kanalai';

-- Dumping data for table emcor.ph: ~2 rows (approximately)
/*!40000 ALTER TABLE `ph` DISABLE KEYS */;
INSERT INTO `ph` (`ph_id`, `ph_type_id`, `dp_id`, `ph_name`, `ph_enabled`, `ph_deleted`, `ph_save_statistics`, `ph_failure_count`, `costa_g_per_id`, `costa_g_exp_value`, `costa_b_per_id`, `costa_b_exp_value`) VALUES
	(457, 11, 454, 'Be ryšio kanalo', 1, 0, 0, 5, NULL, NULL, NULL, NULL),
	(593, 11, 600, 'Be ryšio kanalo', 1, 0, 1, 5, NULL, NULL, NULL, NULL);
/*!40000 ALTER TABLE `ph` ENABLE KEYS */;

-- Dumping structure for table emcor.ph_etype
CREATE TABLE IF NOT EXISTS `ph_etype` (
  `ph_etype_id` mediumint(8) NOT NULL COMMENT 'Transporto klaidos tipas',
  `ph_etype_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Transporto klaidos kodas',
  `ph_etype_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Transporto klaidos pavadinimas',
  PRIMARY KEY (`ph_etype_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ryšio kanalų klaidų sąrašas';

-- Dumping data for table emcor.ph_etype: ~82 rows (approximately)
/*!40000 ALTER TABLE `ph_etype` DISABLE KEYS */;
INSERT INTO `ph_etype` (`ph_etype_id`, `ph_etype_code`, `ph_etype_name`) VALUES
	(-10000, 'OWE', 'Other Winsock error'),
	(-1, 'PortIsClosed', 'Port Is Closed'),
	(2, 'ERROR_FILE_NOT_FOUND', 'The system cannot find the file specified'),
	(1450, 'NO_SYSTEM_RESOURCES', 'Insufficient system resources exist to complete the requested service'),
	(4099, 'Time_Out', 'Time Out'),
	(4102, 'Get_Error', 'General Critical Error'),
	(4103, 'No_Port', 'Resurso prieigos klaida'),
	(4201, 'Err_ModemNoCarrier', 'Modem No Carrier'),
	(4202, 'Err_ModemError', 'General Modem Error'),
	(4203, 'Err_ModemBusy', 'Modem Busy'),
	(4204, 'Err_ModemNoDialtone', 'Modem No Dialtone'),
	(4205, 'Err_ModemRemoteClosed', 'Remote Modem closed connection'),
	(4206, 'Err_ModemInitError', 'Modem init error'),
	(4207, 'Err_ModemOpTimedOut', 'Modem Answer Waiting Time Out'),
	(4401, 'Err_Proxy_Init', 'Proxy Init Error'),
	(4402, 'Err_Proxy_AfterConnect', 'Proxy AfterConnect Error'),
	(4403, 'Err_Proxy_BeforeDisconnect', 'Proxy BeforeDisconnect Error'),
	(4404, 'Err_Proxy_Run', 'Proxy Run Error'),
	(9991, 'ErrAlreadyOwned', 'Port owned by other process '),
	(9992, 'ErrAlreadyInUse', 'Instance already in use'),
	(9993, 'ErrWrongParameter', 'Wrong paramter at call'),
	(9994, 'ErrPortNotOpen', 'Instance not yet connected'),
	(9995, 'ErrNoDeviceAnswer', 'No device answer detected'),
	(9996, 'ErrMaxBuffer', 'Maximal buffer length exceeded'),
	(9997, 'ErrTimeout', 'Timeout during operation'),
	(9998, 'ErrNotRead', 'Reading of data failed '),
	(9999, 'ErrFrame', 'Receive framing error'),
	(10000, 'ErrOverrun', 'Receive Overrun Error'),
	(10001, 'ErrRxOver', 'Receive Queue overflow'),
	(10002, 'ErrRxParity', 'Receive Parity Error'),
	(10003, 'ErrTxFull', 'Tranceive Queue is full'),
	(10004, 'WSAEINTR', 'Interrupted system call'),
	(10009, 'WSAEBADF', 'Bad file number'),
	(10013, 'WSAEACCES', 'Permission denied'),
	(10014, 'WSAEFAULT', 'Bad address'),
	(10022, 'WSAEINVAL', 'Invalid argument'),
	(10024, 'WSAEMFILE', 'Too many open files'),
	(10035, 'WSAEWOULDBLOCK', 'Operation would block'),
	(10036, 'WSAEINPROGRESS', 'Operation now in progress'),
	(10037, 'WSAEALREADY', 'Operation already in progress'),
	(10038, 'WSAENOTSOCK', 'Socket operation on nonsocket'),
	(10039, 'WSAEDESTADDRREQ', 'Destination address required'),
	(10040, 'WSAEMSGSIZE', 'Message too long'),
	(10041, 'WSAEPROTOTYPE', 'Protocol wrong type for Socket'),
	(10042, 'WSAENOPROTOOPT', 'Protocol not available'),
	(10043, 'WSAEPROTONOSUPPORT', 'Protocol not supported'),
	(10044, 'WSAESOCKTNOSUPPORT', 'Socket not supported'),
	(10045, 'WSAEOPNOTSUPP', 'Operation not supported on Socket'),
	(10046, 'WSAEPFNOSUPPORT', 'Protocol family not supported'),
	(10047, 'WSAEAFNOSUPPORT', 'Address family not supported'),
	(10048, 'WSAEADDRINUSE', 'Address already in use'),
	(10049, 'WSAEADDRNOTAVAIL', 'Cant assign requested address'),
	(10050, 'WSAENETDOWN', 'Network is down'),
	(10051, 'WSAENETUNREACH', 'Network is unreachable'),
	(10052, 'WSAENETRESET', 'Network dropped connection on reset'),
	(10053, 'WSAECONNABORTED', 'Software caused connection abort'),
	(10054, 'WSAECONNRESET', 'Connection reset by peer'),
	(10055, 'WSAENOBUFS', 'No Buffer space available'),
	(10056, 'WSAEISCONN', 'Socket is already connected'),
	(10057, 'WSAENOTCONN', 'Socket is not connected'),
	(10058, 'WSAESHUTDOWN', 'Cant send after Socket shutdown'),
	(10059, 'WSAETOOMANYREFS', 'Too many references cant splice'),
	(10060, 'WSAETIMEDOUT', 'Connection timed out'),
	(10061, 'WSAECONNREFUSED', 'Connection refused'),
	(10062, 'WSAELOOP', 'Too many levels of symbolic links'),
	(10063, 'WSAENAMETOOLONG', 'File name is too long'),
	(10064, 'WSAEHOSTDOWN', 'Host is down'),
	(10065, 'WSAEHOSTUNREACH', 'No route to host'),
	(10066, 'WSAENOTEMPTY', 'Directory is not empty'),
	(10067, 'WSAEPROCLIM', 'Too many processes'),
	(10068, 'WSAEUSERS', 'Too many users'),
	(10069, 'WSAEDQUOT', 'Disk quota exceeded'),
	(10070, 'WSAESTALE', 'Stale NFS file handle'),
	(10071, 'WSAEREMOTE', 'Too many levels of remote in path'),
	(10091, 'WSASYSNOTREADY', 'Network subsystem is unusable'),
	(10092, 'WSAVERNOTSUPPORTED', 'Winsock DLL cannot support this application'),
	(10093, 'WSANOTINITIALISED', 'Winsock not initialized'),
	(10101, 'WSAEDISCON', 'Disconnect'),
	(11001, 'WSAHOST_NOT_FOUND', 'Host not found'),
	(11002, 'WSATRY_AGAIN', 'Non authoritative - host not found'),
	(11003, 'WSANO_RECOVERY', 'Non recoverable error'),
	(11004, 'WSANO_DATA', 'Valid name, no data record of requested type');
/*!40000 ALTER TABLE `ph_etype` ENABLE KEYS */;

-- Dumping structure for table emcor.ph_gr
CREATE TABLE IF NOT EXISTS `ph_gr` (
  `ph_id` int(10) unsigned NOT NULL COMMENT 'Ryšio kanalo identifikatorius',
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  PRIMARY KEY (`ph_id`),
  KEY `ph_gr_i` (`gr_id`),
  CONSTRAINT `ph_gr_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE,
  CONSTRAINT `ph_gr_ph_fk` FOREIGN KEY (`ph_id`) REFERENCES `ph` (`ph_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Ryšio kanalų sąryšiai su apskaitos grupėmis';

-- Dumping data for table emcor.ph_gr: ~0 rows (approximately)
/*!40000 ALTER TABLE `ph_gr` DISABLE KEYS */;
/*!40000 ALTER TABLE `ph_gr` ENABLE KEYS */;

-- Dumping structure for table emcor.ph_layer
CREATE TABLE IF NOT EXISTS `ph_layer` (
  `ph_layer_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio kanalų fizinio sluoksnio identifikatorius',
  `ph_layer_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Ryšių kanalų fizinio sluoksnio kodas',
  `ph_layer_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ryšio kanalų fizinio sluoksnio pavadinimas',
  PRIMARY KEY (`ph_layer_id`),
  UNIQUE KEY `ph_layer_code_u` (`ph_layer_code`),
  UNIQUE KEY `ph_layer_name_u` (`ph_layer_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ryšių kanalų fiziniai sluoksniai';

-- Dumping data for table emcor.ph_layer: ~11 rows (approximately)
/*!40000 ALTER TABLE `ph_layer` DISABLE KEYS */;
INSERT INTO `ph_layer` (`ph_layer_id`, `ph_layer_code`, `ph_layer_name`) VALUES
	(1, 'ETHERNET', 'Ethernet'),
	(2, 'MODEM', 'Modem'),
	(3, 'RAS', 'RAS'),
	(4, 'RS', 'RS'),
	(5, 'IRDA', 'IRDA'),
	(10, 'FILE', 'File'),
	(11, 'TCP VIA WAVECOMTELECOR MODEM', 'TCP via WavecomTelecor modem'),
	(12, 'UDP VIA APC-GPRS (SAYANY)', 'UDP via APC-GPRS (SAYANY)'),
	(13, 'TCP PROXY VIA BARS', 'TCP Proxy via BARS'),
	(14, 'TCP PROXY BY TID', 'TCP Proxy by TID'),
	(15, 'Vzljot TFTP Transport', 'Vzljot TFTP Transport');
/*!40000 ALTER TABLE `ph_layer` ENABLE KEYS */;

-- Dumping structure for table emcor.ph_layer_lpty
CREATE TABLE IF NOT EXISTS `ph_layer_lpty` (
  `ph_layer_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio kanalų fizinio sluoksnio identifikatorius',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `ph_lpty_forced_value` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Ryšio kanalų fizinio sluoksnio savybės reikšmė pagal nutylėjimą',
  `lpty_numeric` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Savybės reikšmė yra skaitinė',
  `lpty_regex` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'Savybės reikšmės raktas',
  `lpty_min` double DEFAULT NULL COMMENT 'Savybės reikšmės minimumas',
  `lpty_max` double DEFAULT NULL COMMENT 'Savybės reikšmės maksimumas',
  PRIMARY KEY (`ph_layer_id`,`lpty_id`),
  KEY `ph_layer_lpty_lpty_i` (`lpty_id`),
  CONSTRAINT `ph_layer_lpty_lpty_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`) ON DELETE CASCADE,
  CONSTRAINT `ph_layer_lpty_ph_layer_fk` FOREIGN KEY (`ph_layer_id`) REFERENCES `ph_layer` (`ph_layer_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ryšių kanalų iš nustatyto fizinio sluoksnio  savybės';

-- Dumping data for table emcor.ph_layer_lpty: ~80 rows (approximately)
/*!40000 ALTER TABLE `ph_layer_lpty` DISABLE KEYS */;
INSERT INTO `ph_layer_lpty` (`ph_layer_id`, `lpty_id`, `ph_lpty_forced_value`, `lpty_numeric`, `lpty_regex`, `lpty_min`, `lpty_max`) VALUES
	(1, 1, NULL, 0, NULL, NULL, NULL),
	(1, 2, NULL, 0, NULL, NULL, NULL),
	(1, 6, NULL, 0, NULL, NULL, NULL),
	(1, 114, NULL, 0, NULL, NULL, NULL),
	(1, 252, NULL, 0, NULL, NULL, NULL),
	(1, 266, NULL, 0, NULL, NULL, NULL),
	(1, 358, 'IP', 0, NULL, NULL, NULL),
	(2, 3, NULL, 0, NULL, NULL, NULL),
	(2, 4, NULL, 0, NULL, NULL, NULL),
	(2, 5, NULL, 0, NULL, NULL, NULL),
	(2, 39, NULL, 0, NULL, NULL, NULL),
	(2, 40, NULL, 0, NULL, NULL, NULL),
	(2, 41, NULL, 0, NULL, NULL, NULL),
	(2, 42, NULL, 0, NULL, NULL, NULL),
	(2, 43, NULL, 0, NULL, NULL, NULL),
	(2, 45, NULL, 0, NULL, NULL, NULL),
	(2, 46, NULL, 0, NULL, NULL, NULL),
	(2, 359, 'TRUE', 0, NULL, NULL, NULL),
	(3, 1, NULL, 0, NULL, NULL, NULL),
	(3, 2, NULL, 0, NULL, NULL, NULL),
	(3, 6, NULL, 0, NULL, NULL, NULL),
	(3, 48, NULL, 0, NULL, NULL, NULL),
	(3, 114, NULL, 0, NULL, NULL, NULL),
	(3, 179, 'TRUE', 0, NULL, NULL, NULL),
	(3, 252, NULL, 0, NULL, NULL, NULL),
	(3, 266, NULL, 0, NULL, NULL, NULL),
	(3, 358, 'IP', 0, NULL, NULL, NULL),
	(4, 3, NULL, 0, NULL, NULL, NULL),
	(4, 4, NULL, 0, NULL, NULL, NULL),
	(4, 39, NULL, 0, NULL, NULL, NULL),
	(4, 40, NULL, 0, NULL, NULL, NULL),
	(4, 41, NULL, 0, NULL, NULL, NULL),
	(4, 42, NULL, 0, NULL, NULL, NULL),
	(4, 43, NULL, 0, NULL, NULL, NULL),
	(4, 44, NULL, 0, NULL, NULL, NULL),
	(4, 81, NULL, 0, NULL, NULL, NULL),
	(4, 82, NULL, 0, NULL, NULL, NULL),
	(4, 114, NULL, 0, NULL, NULL, NULL),
	(11, 1, NULL, 0, NULL, NULL, NULL),
	(11, 2, NULL, 0, NULL, NULL, NULL),
	(11, 6, 'TCP', 0, NULL, NULL, NULL),
	(11, 114, 'Normal', 0, NULL, NULL, NULL),
	(11, 252, NULL, 0, NULL, NULL, NULL),
	(11, 266, NULL, 0, NULL, NULL, NULL),
	(11, 267, NULL, 0, NULL, NULL, NULL),
	(11, 340, NULL, 0, NULL, NULL, NULL),
	(11, 358, 'IP', 0, NULL, NULL, NULL),
	(12, 1, NULL, 0, NULL, NULL, NULL),
	(12, 2, NULL, 0, NULL, NULL, NULL),
	(12, 6, 'UDP', 0, NULL, NULL, NULL),
	(12, 114, 'Normal', 0, NULL, NULL, NULL),
	(12, 252, NULL, 0, NULL, NULL, NULL),
	(12, 340, NULL, 0, NULL, NULL, NULL),
	(12, 358, 'IP', 0, NULL, NULL, NULL),
	(13, 1, NULL, 0, NULL, NULL, NULL),
	(13, 2, NULL, 0, NULL, NULL, NULL),
	(13, 6, 'TCP', 0, NULL, NULL, NULL),
	(13, 114, 'Normal', 0, NULL, NULL, NULL),
	(13, 252, NULL, 0, NULL, NULL, NULL),
	(13, 266, NULL, 0, NULL, NULL, NULL),
	(13, 267, '<FN>STProxyBARS.dll</FN><Ver>1.0</Ver><Par Mode="T" TO="2000"/>', 0, NULL, NULL, NULL),
	(13, 340, NULL, 0, NULL, NULL, NULL),
	(13, 358, 'IP', 0, NULL, NULL, NULL),
	(14, 1, NULL, 0, NULL, NULL, NULL),
	(14, 2, NULL, 0, NULL, NULL, NULL),
	(14, 6, 'TCP', 0, NULL, NULL, NULL),
	(14, 114, 'Normal', 0, NULL, NULL, NULL),
	(14, 252, NULL, 0, NULL, NULL, NULL),
	(14, 266, NULL, 0, NULL, NULL, NULL),
	(14, 267, '<FN>STProxyByTID.dll</FN><Ver>1.0</Ver><Par TO="3000"/>', 0, NULL, NULL, NULL),
	(14, 340, NULL, 0, NULL, NULL, NULL),
	(14, 358, 'IP', 0, NULL, NULL, NULL),
	(15, 1, NULL, 0, NULL, NULL, NULL),
	(15, 2, NULL, 0, NULL, NULL, NULL),
	(15, 6, 'UDP', 0, NULL, NULL, NULL),
	(15, 114, 'Normal', 0, NULL, NULL, NULL),
	(15, 252, NULL, 0, NULL, NULL, NULL),
	(15, 266, NULL, 0, NULL, NULL, NULL),
	(15, 267, '<FN>STTFTPTransport.dll</FN><Ver>1.0</Ver>', 0, NULL, NULL, NULL),
	(15, 358, 'IP', 0, NULL, NULL, NULL);
/*!40000 ALTER TABLE `ph_layer_lpty` ENABLE KEYS */;

-- Dumping structure for table emcor.ph_lpty
CREATE TABLE IF NOT EXISTS `ph_lpty` (
  `ph_id` int(10) unsigned NOT NULL COMMENT 'Ryšio kanalo identifikatorius',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `lpty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ryšio modulių savybės reikšmė',
  PRIMARY KEY (`ph_id`,`lpty_id`),
  KEY `ph_lpty_lpty_i` (`lpty_id`),
  CONSTRAINT `ph_lpty_lpty_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`),
  CONSTRAINT `ph_lpty_ph_fk` FOREIGN KEY (`ph_id`) REFERENCES `ph` (`ph_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ryšio kanalų savybės';

-- Dumping data for table emcor.ph_lpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `ph_lpty` DISABLE KEYS */;
/*!40000 ALTER TABLE `ph_lpty` ENABLE KEYS */;

-- Dumping structure for table emcor.ph_otype
CREATE TABLE IF NOT EXISTS `ph_otype` (
  `ph_otype_id` smallint(5) unsigned NOT NULL COMMENT 'Transporto operacijos tipas',
  `ph_otype_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Transporto operacijos kodas',
  `ph_otype_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Transporto operacijos pavadinimas',
  PRIMARY KEY (`ph_otype_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ryšio kanalų transporto operacijų sąrašas';

-- Dumping data for table emcor.ph_otype: ~8 rows (approximately)
/*!40000 ALTER TABLE `ph_otype` DISABLE KEYS */;
INSERT INTO `ph_otype` (`ph_otype_id`, `ph_otype_code`, `ph_otype_name`) VALUES
	(1, 'Connect', 'Sesijos pradžia'),
	(2, 'Disconnect', 'Sesijos pabaiga'),
	(3, 'Req', 'Apsikeitimas duomenimis su prietaisu'),
	(4, 'StartAck', 'Užklausos tvarkyklei pradžia'),
	(5, 'StopAck', 'Užklausos tvarkyklei pabaiga'),
	(6, 'PauseAck', 'Užklausos tvarkyklei vykdymo pauzė'),
	(7, 'ResumeAck', 'Užklausos tvarkyklei vykdymo tęsimas'),
	(8, 'Optimization', 'Optimizacija');
/*!40000 ALTER TABLE `ph_otype` ENABLE KEYS */;

-- Dumping structure for table emcor.ph_state
CREATE TABLE IF NOT EXISTS `ph_state` (
  `ph_id` int(10) unsigned NOT NULL COMMENT 'Ryšio kanalo identifikatorius',
  `costa_id` tinyint(3) unsigned NOT NULL COMMENT 'Ryšio būsenos ID',
  `costa_from` datetime NOT NULL,
  `costa_last_check` datetime NOT NULL,
  PRIMARY KEY (`ph_id`),
  CONSTRAINT `ph_state_ph_fk` FOREIGN KEY (`ph_id`) REFERENCES `ph` (`ph_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Ryšio kanalų būsenos';

-- Dumping data for table emcor.ph_state: ~0 rows (approximately)
/*!40000 ALTER TABLE `ph_state` DISABLE KEYS */;
/*!40000 ALTER TABLE `ph_state` ENABLE KEYS */;

-- Dumping structure for table emcor.ph_type
CREATE TABLE IF NOT EXISTS `ph_type` (
  `ph_type_id` tinyint(3) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Ryšio kanalų tipo identifikatorius',
  `ph_layer_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio kanalų fizinio sluoksnio identifikatorius',
  `ph_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ryšio kanalo tipo pavadinimas',
  PRIMARY KEY (`ph_type_id`),
  UNIQUE KEY `ph_type_name_u` (`ph_type_name`),
  KEY `ph_type_ph_layer_i` (`ph_layer_id`),
  CONSTRAINT `ph_type_ph_layer_fk` FOREIGN KEY (`ph_layer_id`) REFERENCES `ph_layer` (`ph_layer_id`)
) ENGINE=InnoDB AUTO_INCREMENT=12 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ryšio kanalų tipai';

-- Dumping data for table emcor.ph_type: ~8 rows (approximately)
/*!40000 ALTER TABLE `ph_type` DISABLE KEYS */;
INSERT INTO `ph_type` (`ph_type_id`, `ph_layer_id`, `ph_type_name`) VALUES
	(1, 1, 'LAN (elektra)'),
	(2, 1, 'GPRS (elektra)'),
	(3, 4, 'RS232'),
	(4, 1, 'GPRS (temp.)'),
	(5, 1, 'GPRS (vanduo)'),
	(6, 1, 'LAN (vanduo)'),
	(7, 1, 'LAN (temperatūra)'),
	(11, 10, 'Ryšio kanalai nenaudojami');
/*!40000 ALTER TABLE `ph_type` ENABLE KEYS */;

-- Dumping structure for table emcor.ph_type_lpty
CREATE TABLE IF NOT EXISTS `ph_type_lpty` (
  `ph_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `lpty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ryšio modulių savybės reikšmė',
  PRIMARY KEY (`ph_type_id`,`lpty_id`),
  KEY `ph_type_lpty_lpty_fk` (`lpty_id`),
  CONSTRAINT `ph_type_lpty_lpty_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`) ON DELETE CASCADE,
  CONSTRAINT `ph_type_lpty_ph_type_fk` FOREIGN KEY (`ph_type_id`) REFERENCES `ph_type` (`ph_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Reikšmes pagal nutylėjimą ryšio kanalų tipui';

-- Dumping data for table emcor.ph_type_lpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `ph_type_lpty` DISABLE KEYS */;
/*!40000 ALTER TABLE `ph_type_lpty` ENABLE KEYS */;

-- Dumping structure for table emcor.pl
CREATE TABLE IF NOT EXISTS `pl` (
  `pl_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Matavimo linijos matavimo taške identifikatorius',
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `ml_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo linijos identifikatorius',
  `pl_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Matavimo linijos naudojimo matavimo taške požymis',
  PRIMARY KEY (`pl_id`),
  UNIQUE KEY `pl_ml_u` (`ml_id`,`point_id`),
  UNIQUE KEY `pl_point_u` (`point_id`,`ml_id`),
  CONSTRAINT `pl_ml_fk` FOREIGN KEY (`ml_id`) REFERENCES `ml` (`ml_id`),
  CONSTRAINT `pl_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=39 DEFAULT CHARSET=utf8 COMMENT='Matavimo taškų matavimo linijos';

-- Dumping data for table emcor.pl: ~34 rows (approximately)
/*!40000 ALTER TABLE `pl` DISABLE KEYS */;
INSERT INTO `pl` (`pl_id`, `point_id`, `ml_id`, `pl_enabled`) VALUES
	(1, 1, 8884, 1),
	(2, 1, 8885, 1),
	(3, 1, 4902, 1),
	(4, 1, 8696, 1),
	(5, 1, 8702, 1),
	(6, 1, 8886, 1),
	(7, 1, 8708, 1),
	(8, 1, 8714, 1),
	(9, 1, 8720, 1),
	(10, 1, 8836, 1),
	(11, 1, 8867, 1),
	(12, 1, 8868, 1),
	(13, 1, 8672, 1),
	(14, 1, 8842, 1),
	(15, 1, 8678, 1),
	(16, 1, 8869, 1),
	(17, 1, 8870, 1),
	(18, 1, 8848, 1),
	(19, 1, 8854, 1),
	(20, 1, 8860, 1),
	(21, 1, 8887, 1),
	(26, 1, 8888, 1),
	(27, 1, 8889, 1),
	(28, 1, 8890, 1),
	(29, 1, 8891, 1),
	(30, 1, 8894, 1),
	(31, 1, 8974, 1),
	(32, 1, 8903, 1),
	(33, 1, 8977, 1),
	(34, 1, 8902, 1),
	(35, 1, 8930, 1),
	(36, 1, 8895, 1),
	(37, 1, 8899, 1),
	(38, 1, 8871, 1);
/*!40000 ALTER TABLE `pl` ENABLE KEYS */;

-- Dumping structure for table emcor.plep
CREATE TABLE IF NOT EXISTS `plep` (
  `pl_id` int(10) unsigned NOT NULL,
  `plep_bt` datetime NOT NULL,
  `plep_et` datetime NOT NULL,
  `bc` mediumint(8) unsigned NOT NULL,
  `evl_t` datetime NOT NULL,
  `exp_t` datetime DEFAULT NULL,
  `s_hosf` tinyint(3) unsigned DEFAULT NULL,
  `s_ext` tinyint(3) unsigned DEFAULT NULL,
  `s_any` tinyint(3) unsigned DEFAULT NULL,
  PRIMARY KEY (`pl_id`,`plep_bt`),
  KEY `plep_exp_i` (`exp_t`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Taškų matavimų linijų įvertintų periodų informacija'
 PARTITION BY RANGE (
    to_days(plep_bt))
(PARTITION par_201708 VALUES LESS THAN (736751) ENGINE = InnoDB,
 PARTITION par_201709 VALUES LESS THAN (736758) ENGINE = InnoDB,
 PARTITION par_201710 VALUES LESS THAN (736765) ENGINE = InnoDB);

-- Dumping data for table emcor.plep: ~3 rows (approximately)
/*!40000 ALTER TABLE `plep` DISABLE KEYS */;
/*!40000 ALTER TABLE `plep` ENABLE KEYS */;

-- Dumping structure for table emcor.plu
CREATE TABLE IF NOT EXISTS `plu` (
  `pl_id` int(10) unsigned NOT NULL,
  `harder` tinyint(1) NOT NULL DEFAULT 0,
  `more_unrs` tinyint(1) NOT NULL DEFAULT 0,
  PRIMARY KEY (`pl_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Taškų matavimų linijų atnaujinimo informacija';

-- Dumping data for table emcor.plu: ~0 rows (approximately)
/*!40000 ALTER TABLE `plu` DISABLE KEYS */;
/*!40000 ALTER TABLE `plu` ENABLE KEYS */;

-- Dumping structure for table emcor.plup
CREATE TABLE IF NOT EXISTS `plup` (
  `pl_id` int(10) unsigned NOT NULL,
  `plep_bt` datetime NOT NULL,
  `plep_et` datetime NOT NULL,
  `db_time` datetime NOT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `unrs_t` datetime DEFAULT NULL,
  `fill_t` datetime DEFAULT NULL,
  `ext_t` datetime DEFAULT NULL,
  `any_t` datetime DEFAULT NULL,
  PRIMARY KEY (`pl_id`,`plep_bt`),
  KEY `plup_db_time_i` (`db_time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Taškų matavimų linijų įvertintų periodų atnaujinimo informacija'
 PARTITION BY RANGE (
    to_days(plep_bt))
(PARTITION par_201708 VALUES LESS THAN (736751) ENGINE = InnoDB,
 PARTITION par_201709 VALUES LESS THAN (736758) ENGINE = InnoDB,
 PARTITION par_201710 VALUES LESS THAN (736765) ENGINE = InnoDB);

-- Dumping data for table emcor.plup: ~3 rows (approximately)
/*!40000 ALTER TABLE `plup` DISABLE KEYS */;
/*!40000 ALTER TABLE `plup` ENABLE KEYS */;

-- Dumping structure for table emcor.pl_ah_data
CREATE TABLE IF NOT EXISTS `pl_ah_data` (
  `pl_id` int(10) unsigned NOT NULL,
  `pl_t` datetime NOT NULL COMMENT 'Matavimo linijos matavimo taške duomenų laikas',
  `aggs_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  `sep_id` int(10) unsigned NOT NULL,
  `db_time` datetime NOT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `pl_v` double DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų reikšmė',
  `pck_t` datetime DEFAULT NULL,
  `pl_rt` datetime DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų nuskaitymo laikas',
  `pl_rv` double DEFAULT NULL,
  `dstatus` varbinary(20) DEFAULT NULL,
  `tstatus` tinyint(3) unsigned DEFAULT NULL,
  PRIMARY KEY (`pl_id`,`pl_t`,`aggs_type_id`),
  KEY `pl_ah_data_db_time_i` (`db_time`),
  KEY `pl_ah_data_sep_i` (`sep_id`),
  CONSTRAINT `pl_ah_data_pl_fk` FOREIGN KEY (`pl_id`) REFERENCES `pl` (`pl_id`) ON DELETE CASCADE,
  CONSTRAINT `pl_ah_data_sep_fk` FOREIGN KEY (`sep_id`) REFERENCES `sep` (`sep_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškų matavimo linijų automatiškai parinkti galiojantys duomenys paskutinei vasaros laiko valandai';

-- Dumping data for table emcor.pl_ah_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `pl_ah_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `pl_ah_data` ENABLE KEYS */;

-- Dumping structure for table emcor.pl_ah_data_nv
CREATE TABLE IF NOT EXISTS `pl_ah_data_nv` (
  `pl_id` int(10) unsigned NOT NULL,
  `pl_t` datetime NOT NULL COMMENT 'Matavimo linijos matavimo taške duomenų laikas',
  `db_time` datetime NOT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `aggs_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  `sep_id` int(10) unsigned NOT NULL,
  `pl_v` double DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų reikšmė',
  `pck_t` datetime DEFAULT NULL,
  `pl_rt` datetime DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų nuskaitymo laikas',
  `pl_rv` double DEFAULT NULL,
  `dstatus` varbinary(20) DEFAULT NULL,
  `tstatus` tinyint(3) unsigned DEFAULT NULL,
  PRIMARY KEY (`pl_id`,`pl_t`,`db_time`,`aggs_type_id`),
  KEY `pl_ah_data_nv_db_time_i` (`db_time`),
  KEY `pl_ah_data_nv_sep_i` (`sep_id`),
  CONSTRAINT `pl_ah_data_nv_pl_fk` FOREIGN KEY (`pl_id`) REFERENCES `pl` (`pl_id`) ON DELETE CASCADE,
  CONSTRAINT `pl_ah_data_nv_sep_fk` FOREIGN KEY (`sep_id`) REFERENCES `sep` (`sep_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškų matavimo linijų negaliojantys duomenys paskutinei vasaros laiko valandai';

-- Dumping data for table emcor.pl_ah_data_nv: ~0 rows (approximately)
/*!40000 ALTER TABLE `pl_ah_data_nv` DISABLE KEYS */;
/*!40000 ALTER TABLE `pl_ah_data_nv` ENABLE KEYS */;

-- Dumping structure for table emcor.pl_data
CREATE TABLE IF NOT EXISTS `pl_data` (
  `pl_id` int(10) unsigned NOT NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
  `pl_t` datetime NOT NULL COMMENT 'Matavimo linijos matavimo taške duomenų laikas',
  `aggs_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `db_time` datetime DEFAULT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `pl_v` double DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų reikšmė',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `pl_rt` datetime DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų nuskaitymo laikas',
  `pl_rv` double DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų pirminė reikšmė',
  `dstatus` varbinary(20) DEFAULT NULL COMMENT 'Duomenų statuso kodinė išraiška',
  `tstatus` tinyint(3) unsigned DEFAULT NULL COMMENT 'Transformuotas duomenų statusas',
  PRIMARY KEY (`pl_id`,`pl_t`,`aggs_type_id`),
  KEY `pl_data_db_time_i` (`db_time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškų matavimo linijų automatiškai parinkti galiojantys duomenys'
 PARTITION BY RANGE  COLUMNS(pl_t,aggs_type_id)
(PARTITION par_201701_min VALUES LESS THAN ('2017-02-01',2) ENGINE = InnoDB,
 PARTITION par_201701_pdm VALUES LESS THAN ('2017-02-01',5) ENGINE = InnoDB,
 PARTITION par_201701_tot VALUES LESS THAN ('2017-02-01',6) ENGINE = InnoDB,
 PARTITION par_201701_mom VALUES LESS THAN ('2017-02-01',8) ENGINE = InnoDB,
 PARTITION par_201702_min VALUES LESS THAN ('2017-03-01',2) ENGINE = InnoDB,
 PARTITION par_201702_pdm VALUES LESS THAN ('2017-03-01',5) ENGINE = InnoDB,
 PARTITION par_201702_tot VALUES LESS THAN ('2017-03-01',6) ENGINE = InnoDB,
 PARTITION par_201702_mom VALUES LESS THAN ('2017-03-01',8) ENGINE = InnoDB,
 PARTITION par_201703_min VALUES LESS THAN ('2017-04-01',2) ENGINE = InnoDB,
 PARTITION par_201703_pdm VALUES LESS THAN ('2017-04-01',5) ENGINE = InnoDB,
 PARTITION par_201703_tot VALUES LESS THAN ('2017-04-01',6) ENGINE = InnoDB,
 PARTITION par_201703_mom VALUES LESS THAN ('2017-04-01',8) ENGINE = InnoDB,
 PARTITION par_201704_min VALUES LESS THAN ('2017-05-01',2) ENGINE = InnoDB,
 PARTITION par_201704_pdm VALUES LESS THAN ('2017-05-01',5) ENGINE = InnoDB,
 PARTITION par_201704_tot VALUES LESS THAN ('2017-05-01',6) ENGINE = InnoDB,
 PARTITION par_201704_mom VALUES LESS THAN ('2017-05-01',8) ENGINE = InnoDB);

-- Dumping data for table emcor.pl_data: ~16 rows (approximately)
/*!40000 ALTER TABLE `pl_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `pl_data` ENABLE KEYS */;

-- Dumping structure for table emcor.pl_data_custom
CREATE TABLE IF NOT EXISTS `pl_data_custom` (
  `pl_id` int(10) unsigned NOT NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
  `pl_t` datetime NOT NULL COMMENT 'Matavimo linijos matavimo taške duomenų laikas',
  `db_time` datetime NOT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `aggs_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `pl_v` double DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų reikšmė',
  `pl_rt` datetime DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų nuskaitymo laikas',
  `pl_rv` double DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų pirminė reikšmė',
  `dstatus` varbinary(20) DEFAULT NULL COMMENT 'Duomenų statuso kodinė išraiška',
  PRIMARY KEY (`pl_id`,`pl_t`,`db_time`,`aggs_type_id`),
  KEY `pl_data_custom_db_time_i` (`db_time`),
  KEY `ppp` (`pl_id`,`pl_t`,`aggs_type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškų matavimo linijų specifiniai galiojantys duomenys'
 PARTITION BY RANGE (
    to_days(pl_t))
(PARTITION par_201701 VALUES LESS THAN (736726) ENGINE = InnoDB,
 PARTITION par_201702 VALUES LESS THAN (736754) ENGINE = InnoDB,
 PARTITION par_201703 VALUES LESS THAN (736785) ENGINE = InnoDB,
 PARTITION par_201704 VALUES LESS THAN (736815) ENGINE = InnoDB,
 PARTITION par_201705 VALUES LESS THAN (736846) ENGINE = InnoDB);

-- Dumping data for table emcor.pl_data_custom: ~5 rows (approximately)
/*!40000 ALTER TABLE `pl_data_custom` DISABLE KEYS */;
/*!40000 ALTER TABLE `pl_data_custom` ENABLE KEYS */;

-- Dumping structure for table emcor.pl_data_ext
CREATE TABLE IF NOT EXISTS `pl_data_ext` (
  `pl_id` int(10) unsigned NOT NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
  `pl_t` datetime NOT NULL COMMENT 'Matavimo linijos matavimo taške duomenų laikas',
  `aggs_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  `extreme_t` datetime NOT NULL COMMENT 'Pasiektos ekstremalios reikšmės laiko žymė',
  PRIMARY KEY (`pl_id`,`pl_t`,`aggs_type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškų matavimo linijų pasiektų ekstremalių reikšmių laiko žymės';

-- Dumping data for table emcor.pl_data_ext: ~0 rows (approximately)
/*!40000 ALTER TABLE `pl_data_ext` DISABLE KEYS */;
/*!40000 ALTER TABLE `pl_data_ext` ENABLE KEYS */;

-- Dumping structure for table emcor.pl_data_ext_nv
CREATE TABLE IF NOT EXISTS `pl_data_ext_nv` (
  `pl_id` int(10) unsigned NOT NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
  `pl_t` datetime NOT NULL COMMENT 'Matavimo linijos matavimo taške duomenų laikas',
  `db_time` datetime NOT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `aggs_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  `extreme_t` datetime NOT NULL COMMENT 'Pasiektos ekstremalios reikšmės laiko žymė',
  PRIMARY KEY (`pl_id`,`pl_t`,`db_time`,`aggs_type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškų matavimo linijų negaliojančių duomenų pasiektų ekstremalių reikšmių laiko žymės'
 PARTITION BY RANGE (
    to_days(pl_t))
(PARTITION par_201701 VALUES LESS THAN (736726) ENGINE = InnoDB,
 PARTITION par_201702 VALUES LESS THAN (736754) ENGINE = InnoDB,
 PARTITION par_201703 VALUES LESS THAN (736785) ENGINE = InnoDB,
 PARTITION par_201704 VALUES LESS THAN (736815) ENGINE = InnoDB,
 PARTITION par_201705 VALUES LESS THAN (736846) ENGINE = InnoDB);

-- Dumping data for table emcor.pl_data_ext_nv: ~5 rows (approximately)
/*!40000 ALTER TABLE `pl_data_ext_nv` DISABLE KEYS */;
/*!40000 ALTER TABLE `pl_data_ext_nv` ENABLE KEYS */;

-- Dumping structure for table emcor.pl_data_nv
CREATE TABLE IF NOT EXISTS `pl_data_nv` (
  `pl_id` int(10) unsigned NOT NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
  `pl_t` datetime NOT NULL COMMENT 'Matavimo linijos matavimo taške duomenų laikas',
  `db_time` datetime NOT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `aggs_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `pl_v` double DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų reikšmė',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `pl_rt` datetime DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų nuskaitymo laikas',
  `pl_rv` double DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų pirminė reikšmė',
  `dstatus` varbinary(20) DEFAULT NULL COMMENT 'Duomenų statuso kodinė išraiška',
  `tstatus` tinyint(3) unsigned DEFAULT NULL COMMENT 'Transformuotas duomenų statusas',
  PRIMARY KEY (`pl_id`,`pl_t`,`db_time`,`aggs_type_id`),
  KEY `pl_data_nv_db_time_i` (`db_time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškų matavimo linijų negaliojantys duomenys'
 PARTITION BY RANGE  COLUMNS(pl_t,aggs_type_id)
(PARTITION par_201701_min VALUES LESS THAN ('2017-02-01',2) ENGINE = InnoDB,
 PARTITION par_201701_pdm VALUES LESS THAN ('2017-02-01',5) ENGINE = InnoDB,
 PARTITION par_201701_tot VALUES LESS THAN ('2017-02-01',6) ENGINE = InnoDB,
 PARTITION par_201701_mom VALUES LESS THAN ('2017-02-01',8) ENGINE = InnoDB,
 PARTITION par_201702_min VALUES LESS THAN ('2017-03-01',2) ENGINE = InnoDB,
 PARTITION par_201702_pdm VALUES LESS THAN ('2017-03-01',5) ENGINE = InnoDB,
 PARTITION par_201702_tot VALUES LESS THAN ('2017-03-01',6) ENGINE = InnoDB,
 PARTITION par_201702_mom VALUES LESS THAN ('2017-03-01',8) ENGINE = InnoDB,
 PARTITION par_201703_min VALUES LESS THAN ('2017-04-01',2) ENGINE = InnoDB,
 PARTITION par_201703_pdm VALUES LESS THAN ('2017-04-01',5) ENGINE = InnoDB,
 PARTITION par_201703_tot VALUES LESS THAN ('2017-04-01',6) ENGINE = InnoDB,
 PARTITION par_201703_mom VALUES LESS THAN ('2017-04-01',8) ENGINE = InnoDB,
 PARTITION par_201704_min VALUES LESS THAN ('2017-05-01',2) ENGINE = InnoDB,
 PARTITION par_201704_pdm VALUES LESS THAN ('2017-05-01',5) ENGINE = InnoDB,
 PARTITION par_201704_tot VALUES LESS THAN ('2017-05-01',6) ENGINE = InnoDB,
 PARTITION par_201704_mom VALUES LESS THAN ('2017-05-01',8) ENGINE = InnoDB);

-- Dumping data for table emcor.pl_data_nv: ~16 rows (approximately)
/*!40000 ALTER TABLE `pl_data_nv` DISABLE KEYS */;
/*!40000 ALTER TABLE `pl_data_nv` ENABLE KEYS */;

-- Dumping structure for table emcor.pma_ma_tmpl
CREATE TABLE IF NOT EXISTS `pma_ma_tmpl` (
  `pma_ma_tmpl_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Apskaitos taško monitoringo šablono elemento ID',
  `pma_tmpl_id` mediumint(8) unsigned NOT NULL COMMENT 'Apskaitos taško monitoringo šablono ID',
  `verge_id` smallint(5) unsigned NOT NULL COMMENT 'Kraštinės ID',
  `ma_ab` tinyint(1) NOT NULL COMMENT 'Požymis, ar naudoti tiesinę transformaciją išeities rodiklio reikšmei',
  `ma_a_nom` float DEFAULT NULL COMMENT 'Tiesinės transformacijos daugiklio skaitiklis',
  `ma_a_denom` float DEFAULT NULL COMMENT 'Tiesinės transformacijos daugiklio vardiklis',
  `ma_b` double DEFAULT NULL COMMENT 'Tiesinės transformacijos dėmuo',
  `ppty_ma_a_nom` float DEFAULT NULL COMMENT 'Tiesinės transformacijos daugiklio skaitiklis, nurodytas per taško savybę',
  `ppty_ma_a_denom` float DEFAULT NULL COMMENT 'Tiesinės transformacijos daugiklio vardiklis, nurodytas per taško savybę',
  `ppty_ma_b` double DEFAULT NULL COMMENT 'Tiesinės transformacijos dėmuo, nurodytas per taško savybę',
  `ignore_ma_ab` tinyint(1) NOT NULL COMMENT 'Tiesinės transformacijos atributų ignoravimo požymis',
  `ma_show` tinyint(1) NOT NULL COMMENT 'Priskirtos kraštinės atvaizdavimo požymis',
  `ma_auto_check` tinyint(1) NOT NULL COMMENT 'Požymis, ar automatiškai tikrinti rodiklių atitikimą nurodytuose perioduose',
  `ma_auto_null_act` tinyint(3) unsigned NOT NULL COMMENT 'Požymis, ar automatiškai priskirti nulinį aktą neatitikimo atveju',
  `ma_auto_ccs` tinyint(1) NOT NULL COMMENT 'Požymis, ar automatiškai priskirti nekomercinių duomenų statusą neatitikimo atveju',
  `ma_report_exceeding` tinyint(1) DEFAULT NULL COMMENT 'Požymis, ar tikrinama dėl viršijimo (ar dėl nusileidimo)',
  `ma_lag` mediumint(8) unsigned DEFAULT NULL COMMENT 'Monitoringo priskyrimo poslinkis laike',
  `ma_lag_per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Monitoringo priskyrimo poslinkio periodo identifikatorius',
  `ppty_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Apskaitos taško savybės ID',
  `ltc_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Tiesinės transformacijos koeficiento ID',
  `target_ml_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Paskirties matavimo linija',
  `source_mt_id` int(10) unsigned DEFAULT NULL COMMENT 'Išeities monitoringe naudojamas rodiklis',
  `source_sam_tmpl_id` int(10) unsigned DEFAULT NULL,
  `source_ml_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išeities matavimo linija',
  `rel_type_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Sąryšių tipo identifikatorius',
  `pos_nr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Pozicijos numeris',
  PRIMARY KEY (`pma_ma_tmpl_id`),
  UNIQUE KEY `pma_ma_tmpl_u` (`pma_tmpl_id`,`target_ml_id`,`verge_id`),
  KEY `pma_ma_tmpl_ma_lag_per_i` (`ma_lag_per_id`),
  KEY `pma_ma_tmpl_ppty_i` (`ppty_id`),
  KEY `pma_ma_tmpl_rel_type_i` (`rel_type_id`),
  KEY `pma_ma_tmpl_sam_tmpl_id_i` (`source_sam_tmpl_id`),
  KEY `pma_ma_tmpl_source_ml_i` (`source_ml_id`),
  KEY `pma_ma_tmpl_source_mt_i` (`source_mt_id`),
  KEY `pma_ma_tmpl_target_ml_i` (`target_ml_id`),
  KEY `pma_ma_tmpl_verge_i` (`verge_id`),
  KEY `pma_ma_tmpl_ltc_fk` (`ltc_id`),
  CONSTRAINT `pma_ma_tmpl_fk` FOREIGN KEY (`pma_tmpl_id`) REFERENCES `pma_tmpl` (`pma_tmpl_id`) ON DELETE CASCADE,
  CONSTRAINT `pma_ma_tmpl_ltc_fk` FOREIGN KEY (`ltc_id`) REFERENCES `ltc` (`ltc_id`) ON DELETE SET NULL,
  CONSTRAINT `pma_ma_tmpl_ma_lag_per_fk` FOREIGN KEY (`ma_lag_per_id`) REFERENCES `per` (`per_id`) ON DELETE CASCADE,
  CONSTRAINT `pma_ma_tmpl_ppty_fk` FOREIGN KEY (`ppty_id`) REFERENCES `ppty` (`ppty_id`) ON DELETE SET NULL,
  CONSTRAINT `pma_ma_tmpl_rel_type_fk` FOREIGN KEY (`rel_type_id`) REFERENCES `rel_type` (`rel_type_id`) ON DELETE SET NULL,
  CONSTRAINT `pma_ma_tmpl_sam_tmpl_fk` FOREIGN KEY (`source_sam_tmpl_id`) REFERENCES `sam_tmpl` (`sam_tmpl_id`) ON DELETE CASCADE,
  CONSTRAINT `pma_ma_tmpl_source_ml_fk` FOREIGN KEY (`source_ml_id`) REFERENCES `ml` (`ml_id`) ON DELETE CASCADE,
  CONSTRAINT `pma_ma_tmpl_source_mt_fk` FOREIGN KEY (`source_mt_id`) REFERENCES `mt` (`mt_id`) ON DELETE CASCADE,
  CONSTRAINT `pma_ma_tmpl_target_ml_fk` FOREIGN KEY (`target_ml_id`) REFERENCES `ml` (`ml_id`) ON DELETE CASCADE,
  CONSTRAINT `pma_ma_tmpl_verge_fk` FOREIGN KEY (`verge_id`) REFERENCES `verge` (`verge_id`) ON DELETE CASCADE,
  CONSTRAINT `PMA_MA_TMPL_NOT_IN_14_S_CHK` CHECK (`source_mt_id` is null and `source_sam_tmpl_id` is null and `source_ml_id` is not null or `source_mt_id` is not null and `source_sam_tmpl_id` is null and `source_ml_id` is null or `source_mt_id` is null and `source_sam_tmpl_id` is not null and `source_ml_id` is null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apskaitos taško monitoringo šablonų elementai';

-- Dumping data for table emcor.pma_ma_tmpl: ~0 rows (approximately)
/*!40000 ALTER TABLE `pma_ma_tmpl` DISABLE KEYS */;
/*!40000 ALTER TABLE `pma_ma_tmpl` ENABLE KEYS */;

-- Dumping structure for table emcor.pma_tmpl
CREATE TABLE IF NOT EXISTS `pma_tmpl` (
  `pma_tmpl_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Apskaitos taško monitoringo šablono ID',
  `pma_tmpl_code` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'Apskaitos taško monitoringo šablono kodas',
  `pma_tmpl_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Apskaitos taško monitoringo šablono pavadinimas',
  PRIMARY KEY (`pma_tmpl_id`),
  UNIQUE KEY `pma_tmpl_code_u` (`pma_tmpl_code`),
  UNIQUE KEY `pma_tmpl_name_u` (`pma_tmpl_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apskaitos taško monitoringo šablonai';

-- Dumping data for table emcor.pma_tmpl: ~0 rows (approximately)
/*!40000 ALTER TABLE `pma_tmpl` DISABLE KEYS */;
/*!40000 ALTER TABLE `pma_tmpl` ENABLE KEYS */;

-- Dumping structure for table emcor.point
CREATE TABLE IF NOT EXISTS `point` (
  `point_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Matavimo taško identifikatorius',
  `point_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo taškų tipo identifikatorius',
  `ecp_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Taško ekonominio profilio identifikatorius',
  `point_code` varchar(80) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo taško kodas',
  `point_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo taško pavadinimas',
  `point_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Matavimo taško naudojimo požymis',
  `point_commercial` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Komercinės apskaitos taško požymis',
  `point_internal` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Vidinio taško požymis',
  `point_auto_read_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Duomenų automatinio nuskaitymo požymis',
  `xa_id` int(10) unsigned DEFAULT NULL COMMENT 'Apsikeitimo duomenimis adresato identifikatorius',
  `point_c01` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `point_c02` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `point_c03` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `point_c04` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `point_c05` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `point_c06` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `point_c07` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `point_c08` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `point_c09` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `point_c10` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  PRIMARY KEY (`point_id`),
  UNIQUE KEY `point_code_u` (`point_code`),
  KEY `point_ecp_i` (`ecp_id`),
  KEY `point_point_type_i` (`point_type_id`),
  KEY `point_xa_i` (`xa_id`),
  CONSTRAINT `point_ecp_fk` FOREIGN KEY (`ecp_id`) REFERENCES `ecp` (`ecp_id`) ON DELETE SET NULL,
  CONSTRAINT `point_point_type_fk` FOREIGN KEY (`point_type_id`) REFERENCES `point_type` (`point_type_id`),
  CONSTRAINT `point_xa_fk` FOREIGN KEY (`xa_id`) REFERENCES `xa` (`xa_id`) ON DELETE SET NULL
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimo taškai';

-- Dumping data for table emcor.point: ~0 rows (approximately)
/*!40000 ALTER TABLE `point` DISABLE KEYS */;
INSERT INTO `point` (`point_id`, `point_type_id`, `ecp_id`, `point_code`, `point_name`, `point_enabled`, `point_commercial`, `point_internal`, `point_auto_read_enabled`, `xa_id`, `point_c01`, `point_c02`, `point_c03`, `point_c04`, `point_c05`, `point_c06`, `point_c07`, `point_c08`, `point_c09`, `point_c10`) VALUES
	(1, 1, NULL, 'EMCOS_STATUS', 'EMCOS monitoringas', 1, 0, 1, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
/*!40000 ALTER TABLE `point` ENABLE KEYS */;

-- Dumping structure for table emcor.point_fp
CREATE TABLE IF NOT EXISTS `point_fp` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `fp_id` int(10) unsigned NOT NULL COMMENT 'Užpildymo profilio identifikatorius',
  PRIMARY KEY (`point_id`),
  KEY `point_fp_fp_i` (`fp_id`),
  CONSTRAINT `point_fp_fp_fk` FOREIGN KEY (`fp_id`) REFERENCES `fp` (`fp_id`),
  CONSTRAINT `point_fp_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškams priskirti užpildymo profiliai';

-- Dumping data for table emcor.point_fp: ~0 rows (approximately)
/*!40000 ALTER TABLE `point_fp` DISABLE KEYS */;
/*!40000 ALTER TABLE `point_fp` ENABLE KEYS */;

-- Dumping structure for table emcor.point_mau
CREATE TABLE IF NOT EXISTS `point_mau` (
  `point_id` int(10) unsigned NOT NULL,
  PRIMARY KEY (`point_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.point_mau: ~0 rows (approximately)
/*!40000 ALTER TABLE `point_mau` DISABLE KEYS */;
INSERT INTO `point_mau` (`point_id`) VALUES
	(1);
/*!40000 ALTER TABLE `point_mau` ENABLE KEYS */;

-- Dumping structure for table emcor.point_pma_tmpl
CREATE TABLE IF NOT EXISTS `point_pma_tmpl` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Apskaitos taško identifikatorius',
  `pma_tmpl_id` mediumint(8) unsigned NOT NULL COMMENT 'Apskaitos taško monitoringo šablono ID',
  PRIMARY KEY (`point_id`),
  KEY `point_pma_tmpl_pma_tmpl_i` (`pma_tmpl_id`),
  CONSTRAINT `point_pma_tmpl_pma_tmpl_fk` FOREIGN KEY (`pma_tmpl_id`) REFERENCES `pma_tmpl` (`pma_tmpl_id`) ON DELETE CASCADE,
  CONSTRAINT `point_pma_tmpl_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apskaitos taško monitoringo šablonų priskyrimai';

-- Dumping data for table emcor.point_pma_tmpl: ~0 rows (approximately)
/*!40000 ALTER TABLE `point_pma_tmpl` DISABLE KEYS */;
/*!40000 ALTER TABLE `point_pma_tmpl` ENABLE KEYS */;

-- Dumping structure for table emcor.point_ppty
CREATE TABLE IF NOT EXISTS `point_ppty` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `ppty_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo taškų savybės identifikatorius',
  `ppty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo taško savybės reikšmė',
  PRIMARY KEY (`point_id`,`ppty_id`),
  KEY `point_ppty_ppty_i` (`ppty_id`),
  CONSTRAINT `point_ppty_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `point_ppty_ppty_fk` FOREIGN KEY (`ppty_id`) REFERENCES `ppty` (`ppty_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimo taškų savybės';

-- Dumping data for table emcor.point_ppty: ~0 rows (approximately)
/*!40000 ALTER TABLE `point_ppty` DISABLE KEYS */;
INSERT INTO `point_ppty` (`point_id`, `ppty_id`, `ppty_value`) VALUES
	(1, 86, '11');
/*!40000 ALTER TABLE `point_ppty` ENABLE KEYS */;

-- Dumping structure for table emcor.point_rtp
CREATE TABLE IF NOT EXISTS `point_rtp` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `rtp_id` mediumint(8) unsigned NOT NULL COMMENT 'Realaus laiko matavimų nuskaitymo profilio identifikatorius',
  PRIMARY KEY (`point_id`),
  KEY `point_rtp_rtp_i` (`rtp_id`),
  CONSTRAINT `point_rtp_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `point_rtp_rtp_fk` FOREIGN KEY (`rtp_id`) REFERENCES `rtp` (`rtp_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškams priskirti realaus laiko matavimų nuskaitymo profiliai';

-- Dumping data for table emcor.point_rtp: ~0 rows (approximately)
/*!40000 ALTER TABLE `point_rtp` DISABLE KEYS */;
INSERT INTO `point_rtp` (`point_id`, `rtp_id`) VALUES
	(1, 1);
/*!40000 ALTER TABLE `point_rtp` ENABLE KEYS */;

-- Dumping structure for table emcor.point_tpl
CREATE TABLE IF NOT EXISTS `point_tpl` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `dp_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taškų tipo identifikatorius',
  `ph_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius',
  `dl_type_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų išdėstymo tipo identifikatorius',
  PRIMARY KEY (`point_id`),
  KEY `point_tpl_dl_type_i` (`dl_type_id`),
  KEY `point_tpl_dp_type_i` (`dp_type_id`),
  KEY `point_tpl_ph_type_i` (`ph_type_id`),
  CONSTRAINT `point_tpl_dl_type_fk` FOREIGN KEY (`dl_type_id`) REFERENCES `dl_type` (`dl_type_id`) ON DELETE CASCADE,
  CONSTRAINT `point_tpl_dp_type_fk` FOREIGN KEY (`dp_type_id`) REFERENCES `dp_type` (`dp_type_id`) ON DELETE CASCADE,
  CONSTRAINT `point_tpl_ph_type_fk` FOREIGN KEY (`ph_type_id`) REFERENCES `ph_type` (`ph_type_id`) ON DELETE CASCADE,
  CONSTRAINT `point_tpl_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškų paskutinių sėkmingų nuskaitymų maršrutai';

-- Dumping data for table emcor.point_tpl: ~0 rows (approximately)
/*!40000 ALTER TABLE `point_tpl` DISABLE KEYS */;
/*!40000 ALTER TABLE `point_tpl` ENABLE KEYS */;

-- Dumping structure for table emcor.point_type
CREATE TABLE IF NOT EXISTS `point_type` (
  `point_type_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Matavimo taškų tipo identifikatorius',
  `point_type_code` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo taškų tipo kodas',
  `point_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo taškų tipo pavadinimas',
  PRIMARY KEY (`point_type_id`),
  UNIQUE KEY `point_type_code_u` (`point_type_code`),
  UNIQUE KEY `point_type_name_u` (`point_type_name`)
) ENGINE=InnoDB AUTO_INCREMENT=128 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimo taškų tipai';

-- Dumping data for table emcor.point_type: ~8 rows (approximately)
/*!40000 ALTER TABLE `point_type` DISABLE KEYS */;
INSERT INTO `point_type` (`point_type_id`, `point_type_code`, `point_type_name`) VALUES
	(1, 'ELECTRICITY', 'Elektros apskaita'),
	(41, 'WATER_COLD', 'Šalto vandens apskaita'),
	(61, 'TEMP_OUT', 'Temperatūra lauko'),
	(91, 'TEMP_IN', 'Temperatūra vidaus'),
	(92, 'WATER_HOT', 'Karšto vandens apskaita'),
	(93, 'HEAT', 'Šilumos apskaita'),
	(94, 'GAS', 'Dujų apskaita'),
	(127, 'VIRTUAL', 'Virtualus');
/*!40000 ALTER TABLE `point_type` ENABLE KEYS */;

-- Dumping structure for table emcor.point_type_ppty
CREATE TABLE IF NOT EXISTS `point_type_ppty` (
  `point_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo taškų tipo identifikatorius',
  `ppty_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo taškų savybės identifikatorius',
  PRIMARY KEY (`point_type_id`,`ppty_id`),
  KEY `point_type_ppty_ppty_i` (`ppty_id`),
  CONSTRAINT `point_type_ppty_point_type_fk` FOREIGN KEY (`point_type_id`) REFERENCES `point_type` (`point_type_id`) ON DELETE CASCADE,
  CONSTRAINT `point_type_ppty_ppty_fk` FOREIGN KEY (`ppty_id`) REFERENCES `ppty` (`ppty_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Taškų savybės pagal taškų tipus';

-- Dumping data for table emcor.point_type_ppty: ~17 rows (approximately)
/*!40000 ALTER TABLE `point_type_ppty` DISABLE KEYS */;
INSERT INTO `point_type_ppty` (`point_type_id`, `ppty_id`) VALUES
	(1, 47),
	(1, 72),
	(1, 73),
	(1, 74),
	(1, 85),
	(1, 86),
	(41, 47),
	(41, 86),
	(61, 86),
	(91, 86),
	(92, 72),
	(92, 86),
	(93, 86),
	(94, 74),
	(94, 85),
	(94, 86),
	(127, 86);
/*!40000 ALTER TABLE `point_type_ppty` ENABLE KEYS */;

-- Dumping structure for table emcor.point_vp
CREATE TABLE IF NOT EXISTS `point_vp` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `vp_id` int(10) unsigned NOT NULL COMMENT 'Verifikacijos profilio identifikatorius',
  PRIMARY KEY (`point_id`),
  KEY `point_vp_vp_i` (`vp_id`),
  CONSTRAINT `point_vp_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `point_vp_vp_fk` FOREIGN KEY (`vp_id`) REFERENCES `vp` (`vp_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškams priskirti verifikacijos profiliai';

-- Dumping data for table emcor.point_vp: ~0 rows (approximately)
/*!40000 ALTER TABLE `point_vp` DISABLE KEYS */;
/*!40000 ALTER TABLE `point_vp` ENABLE KEYS */;

-- Dumping structure for table emcor.ppty
CREATE TABLE IF NOT EXISTS `ppty` (
  `ppty_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Matavimo taškų savybės identifikatorius',
  `ppty_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo taškų savybės kodas',
  `ppty_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Matavimo taškų savybės pavadinimas',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  `ppty_type_id` mediumint(8) unsigned NOT NULL DEFAULT 1 COMMENT 'Galimų matavimo taškų savybių sąrašų tipo identifikatorius',
  `ppty_numeric` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Požymis, ar taško savybės reikšmė turi būti skaitmeninė',
  `ppty_nr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Matavimo taškų savybės eilės numeris rušiavimui',
  PRIMARY KEY (`ppty_id`),
  UNIQUE KEY `ppty_code_u` (`ppty_code`),
  UNIQUE KEY `ppty_name_u` (`ppty_name`),
  KEY `ppty_enum_i` (`enum_id`),
  KEY `ppty_type_id_i` (`ppty_type_id`),
  CONSTRAINT `ppty_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`),
  CONSTRAINT `ppty_type_id_fk` FOREIGN KEY (`ppty_type_id`) REFERENCES `ppty_type` (`ppty_type_id`)
) ENGINE=InnoDB AUTO_INCREMENT=87 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Galimų matavimo taškų savybių sarašas';

-- Dumping data for table emcor.ppty: ~6 rows (approximately)
/*!40000 ALTER TABLE `ppty` DISABLE KEYS */;
INSERT INTO `ppty` (`ppty_id`, `ppty_code`, `ppty_name`, `enum_id`, `ppty_type_id`, `ppty_numeric`, `ppty_nr`) VALUES
	(47, 'OUTPUT_TO_BILLING', 'Duomenys perduodami į bilingo sistemą', 82, 1, 0, NULL),
	(72, 'POINT_LOCATION_CODE', 'Patalpos kodas/indeksas', NULL, 1, 0, NULL),
	(73, 'POINT_LOCATION_DESC', 'Apskaitos taško vietos aprašymas', NULL, 1, 0, NULL),
	(74, 'POINT_SUPL_CODE', 'Kodas tiekėjo  sistemoje', NULL, 1, 0, NULL),
	(85, 'IMC_BIAS', 'Komplekso paklaida', NULL, 1, 1, NULL),
	(86, 'MAJOR_ISSUE', 'Esminė problema', 818, 1, 1, NULL);
/*!40000 ALTER TABLE `ppty` ENABLE KEYS */;

-- Dumping structure for table emcor.ppty_type
CREATE TABLE IF NOT EXISTS `ppty_type` (
  `ppty_type_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Galimų matavimo taškų savybių sąrašų tipo identifikatorius',
  `ppty_type_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Galimų matavimo taškų savybių sąrašų tipo kodas',
  `ppty_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Galimų matavimo taškų savybių sąrašų tipo pavadinimas',
  PRIMARY KEY (`ppty_type_id`),
  UNIQUE KEY `ppty_type_code_uniq` (`ppty_type_code`),
  UNIQUE KEY `ppty_type_name_uniq` (`ppty_type_name`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Galimų matavimo taškų savybių sąrašų tipai';

-- Dumping data for table emcor.ppty_type: ~0 rows (approximately)
/*!40000 ALTER TABLE `ppty_type` DISABLE KEYS */;
INSERT INTO `ppty_type` (`ppty_type_id`, `ppty_type_code`, `ppty_type_name`) VALUES
	(1, 'OTHER_PROPS', 'Kitos savybės');
/*!40000 ALTER TABLE `ppty_type` ENABLE KEYS */;

-- Dumping structure for table emcor.prqs
CREATE TABLE IF NOT EXISTS `prqs` (
  `prqs_id` smallint(5) unsigned NOT NULL COMMENT 'Pirminės užklausos būsenos identifikatorius',
  `prqs_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Pirminės užklausos kodas',
  `prqs_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Pirminės užklausos pavadinimas',
  PRIMARY KEY (`prqs_id`),
  UNIQUE KEY `prqs_code_u` (`prqs_code`),
  UNIQUE KEY `prqs_name_u` (`prqs_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Pirminių užklausų būsenos';

-- Dumping data for table emcor.prqs: ~5 rows (approximately)
/*!40000 ALTER TABLE `prqs` DISABLE KEYS */;
INSERT INTO `prqs` (`prqs_id`, `prqs_code`, `prqs_name`) VALUES
	(1, 'WAITING', 'Laukia eilėje'),
	(2, 'RUNNING', 'Vykdoma'),
	(3, 'DONE', 'Įvykdyta sėkmingai'),
	(4, 'REJECTED', 'Atmesta'),
	(5, 'ERROR', 'Klaida');
/*!40000 ALTER TABLE `prqs` ENABLE KEYS */;

-- Dumping structure for table emcor.ptp
CREATE TABLE IF NOT EXISTS `ptp` (
  `ptp_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Nustatyto tarifo plano identifikatorius matavimo taškui',
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `tp_id` mediumint(8) unsigned NOT NULL COMMENT 'Tarifų plano identifikatorius',
  `ptp_bt` datetime DEFAULT NULL COMMENT 'Tarifinio plano priskyrimo taškui pradžia',
  `ptp_et` datetime DEFAULT NULL COMMENT 'Tarifinio plano priskyrimo taškui pabaiga',
  `aggf_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Agregavimo funkcijos identifikatorius',
  PRIMARY KEY (`ptp_id`),
  UNIQUE KEY `ptp_ak` (`point_id`,`aggf_id`,`ptp_bt`,`ptp_et`),
  KEY `ptp_tp_i` (`tp_id`),
  KEY `ptp_aggf_fk` (`aggf_id`),
  CONSTRAINT `ptp_aggf_fk` FOREIGN KEY (`aggf_id`) REFERENCES `aggf` (`aggf_id`),
  CONSTRAINT `ptp_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `ptp_tp_fk` FOREIGN KEY (`tp_id`) REFERENCES `tp` (`tp_id`),
  CONSTRAINT `PTP_AGGF_CHK` CHECK (`aggf_id` is null or `aggf_id` is not null and `aggf_id` in (2,3))
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškams priskirti tarifų planai';

-- Dumping data for table emcor.ptp: ~0 rows (approximately)
/*!40000 ALTER TABLE `ptp` DISABLE KEYS */;
/*!40000 ALTER TABLE `ptp` ENABLE KEYS */;

-- Dumping structure for table emcor.pw0_buf
CREATE TABLE IF NOT EXISTS `pw0_buf` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `req_from` datetime NOT NULL,
  `req_to` datetime DEFAULT NULL,
  `pw_rt` datetime DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `req_withe_id` mediumint(8) unsigned DEFAULT NULL,
  PRIMARY KEY (`point_id`,`withe_id`,`req_from`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Tarpinė lentelė matavimo taškų duomenų vytelių nuskaitytiems periodams be įrašų';

-- Dumping data for table emcor.pw0_buf: ~0 rows (approximately)
/*!40000 ALTER TABLE `pw0_buf` DISABLE KEYS */;
/*!40000 ALTER TABLE `pw0_buf` ENABLE KEYS */;

-- Dumping structure for table emcor.pwl
CREATE TABLE IF NOT EXISTS `pwl` (
  `pwl_id` int(10) unsigned NOT NULL COMMENT 'Taškų ryšio savybių užpildymo pagal konfigūracinius parametrus taisyklės identifikatorius',
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `lm_id` smallint(5) unsigned NOT NULL COMMENT 'Paieškos prietaisų konfigūraciniuose parametruose metodo identifikatorius',
  `catalog_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Katalogo identifikatorius',
  `catalog_scope_code` varchar(1) COLLATE utf8_bin DEFAULT NULL,
  `p1` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `p2` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `p3` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  PRIMARY KEY (`pwl_id`),
  KEY `pwl_src_type_mod_i` (`src_type_id`,`src_type_mod_nr`,`lpty_id`,`lm_id`,`catalog_id`),
  KEY `pwl_catalog_fk` (`catalog_id`),
  KEY `pwl_lm_fk` (`lm_id`),
  KEY `pwl_lpty_fk` (`lpty_id`),
  CONSTRAINT `pwl_catalog_fk` FOREIGN KEY (`catalog_id`) REFERENCES `catalog` (`catalog_id`) ON DELETE CASCADE,
  CONSTRAINT `pwl_lm_fk` FOREIGN KEY (`lm_id`) REFERENCES `lm` (`lm_id`) ON DELETE CASCADE,
  CONSTRAINT `pwl_lpty_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`) ON DELETE CASCADE,
  CONSTRAINT `pwl_src_type_mod_fk` FOREIGN KEY (`src_type_id`, `src_type_mod_nr`) REFERENCES `src_type_mod` (`src_type_id`, `src_type_mod_nr`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Taškų ryšio savybių užpildymo pagal konfigūracinius parametrus taisyklės';

-- Dumping data for table emcor.pwl: ~109 rows (approximately)
/*!40000 ALTER TABLE `pwl` DISABLE KEYS */;
INSERT INTO `pwl` (`pwl_id`, `src_type_id`, `src_type_mod_nr`, `lpty_id`, `lm_id`, `catalog_id`, `catalog_scope_code`, `p1`, `p2`, `p3`) VALUES
	(1, 140, 1, 292, 5, NULL, NULL, '0.0.1.0.0.255', NULL, NULL),
	(2, 209, 1, 292, 5, NULL, NULL, '0.0.1.0.0.255', NULL, NULL),
	(3, 140, 1, 260, 2, 5, 'S', NULL, NULL, NULL),
	(4, 209, 1, 260, 2, 5, 'S', NULL, NULL, NULL),
	(5, 140, 1, 260, 13, 5, 'M', '1.0.99.1.0.255', NULL, NULL),
	(6, 209, 1, 260, 13, 5, 'M', '1.0.99.1.0.255', NULL, NULL),
	(7, 140, 1, 260, 3, 5, 'M', '1.0.98.1.0.126', '6', NULL),
	(8, 209, 1, 260, 3, 5, 'M', '1.0.98.1.0.126', '6', NULL),
	(9, 140, 1, 257, 13, 5, 'M', '1.0.99.1.0.255', NULL, NULL),
	(10, 209, 1, 257, 13, 5, 'M', '1.0.99.1.0.255', NULL, NULL),
	(11, 140, 1, 257, 3, 5, 'M', '1.0.98.1.0.126', '6', NULL),
	(12, 209, 1, 257, 3, 5, 'M', '1.0.98.1.0.126', '6', NULL),
	(13, 140, 1, 18, 14, 5, 'M', NULL, NULL, NULL),
	(14, 209, 1, 18, 14, 5, 'M', NULL, NULL, NULL),
	(15, 140, 1, 18, 4, 5, 'M', '6', NULL, NULL),
	(16, 209, 1, 18, 4, 5, 'M', '6', NULL, NULL),
	(17, 140, 1, 260, 11, 5, 'M', '7', NULL, NULL),
	(18, 209, 1, 260, 11, 5, 'M', '7', NULL, NULL),
	(19, 140, 1, 257, 11, 5, 'M', '7', NULL, NULL),
	(20, 209, 1, 257, 11, 5, 'M', '7', NULL, NULL),
	(21, 140, 1, 278, 8, NULL, 'S', '1.0.99.98.32.255', '2', NULL),
	(22, 140, 1, 279, 8, NULL, 'S', '1.0.99.98.40.255', '2', NULL),
	(23, 140, 1, 281, 8, NULL, 'S', '1.0.99.98.50.255', '2', NULL),
	(24, 140, 1, 276, 8, NULL, 'S', '1.0.99.98.30.255', '2', NULL),
	(25, 140, 1, 277, 8, NULL, 'S', '1.0.99.98.31.255', '2', NULL),
	(26, 140, 1, 275, 8, NULL, 'S', '1.0.99.98.22.255', '2', NULL),
	(27, 140, 1, 271, 8, NULL, 'S', '1.0.99.98.12.255', '2', NULL),
	(28, 140, 1, 280, 8, NULL, 'S', '1.0.99.98.41.255', '2', NULL),
	(29, 140, 1, 270, 8, NULL, 'S', '1.0.99.98.11.255', '2', NULL),
	(30, 140, 1, 269, 8, NULL, 'S', '1.0.99.97.0.255', '2', NULL),
	(31, 140, 1, 273, 8, NULL, 'S', '1.0.99.98.20.255', '2', NULL),
	(32, 140, 1, 336, 8, NULL, 'S', '1.0.99.98.14.255', '2', NULL),
	(33, 140, 1, 274, 8, NULL, 'S', '1.0.99.98.21.255', '2', NULL),
	(34, 140, 1, 272, 8, NULL, 'S', '1.0.99.98.13.255', '2', NULL),
	(35, 209, 1, 278, 8, NULL, 'S', '1.0.99.98.32.255', '2', NULL),
	(36, 209, 1, 279, 8, NULL, 'S', '1.0.99.98.40.255', '2', NULL),
	(37, 209, 1, 281, 8, NULL, 'S', '1.0.99.98.50.255', '2', NULL),
	(38, 209, 1, 276, 8, NULL, 'S', '1.0.99.98.30.255', '2', NULL),
	(39, 209, 1, 277, 8, NULL, 'S', '1.0.99.98.31.255', '2', NULL),
	(40, 209, 1, 275, 8, NULL, 'S', '1.0.99.98.22.255', '2', NULL),
	(41, 209, 1, 271, 8, NULL, 'S', '1.0.99.98.12.255', '2', NULL),
	(42, 209, 1, 280, 8, NULL, 'S', '1.0.99.98.41.255', '2', NULL),
	(43, 209, 1, 270, 8, NULL, 'S', '1.0.99.98.11.255', '2', NULL),
	(44, 209, 1, 269, 8, NULL, 'S', '1.0.99.97.0.255', '2', NULL),
	(45, 209, 1, 273, 8, NULL, 'S', '1.0.99.98.20.255', '2', NULL),
	(46, 209, 1, 336, 8, NULL, 'S', '1.0.99.98.14.255', '2', NULL),
	(47, 209, 1, 274, 8, NULL, 'S', '1.0.99.98.21.255', '2', NULL),
	(48, 209, 1, 272, 8, NULL, 'S', '1.0.99.98.13.255', '2', NULL),
	(49, 140, 1, 259, 15, 5, 'M', NULL, NULL, NULL),
	(50, 209, 1, 259, 15, 5, 'M', NULL, NULL, NULL),
	(51, 140, 1, 259, 6, 5, 'M', '6', NULL, NULL),
	(52, 209, 1, 259, 6, 5, 'M', '6', NULL, NULL),
	(53, 140, 1, 278, 8, NULL, 'S', '1.0.99.98.32.255', '22', NULL),
	(54, 140, 1, 279, 8, NULL, 'S', '1.0.99.98.40.255', '22', NULL),
	(55, 140, 1, 281, 8, NULL, 'S', '1.0.99.98.50.255', '22', NULL),
	(56, 140, 1, 276, 8, NULL, 'S', '1.0.99.98.30.255', '22', NULL),
	(57, 140, 1, 277, 8, NULL, 'S', '1.0.99.98.31.255', '22', NULL),
	(58, 140, 1, 275, 8, NULL, 'S', '1.0.99.98.22.255', '22', NULL),
	(59, 140, 1, 271, 8, NULL, 'S', '1.0.99.98.12.255', '22', NULL),
	(60, 140, 1, 280, 8, NULL, 'S', '1.0.99.98.41.255', '22', NULL),
	(61, 140, 1, 270, 8, NULL, 'S', '1.0.99.98.11.255', '22', NULL),
	(62, 140, 1, 269, 8, NULL, 'S', '1.0.99.97.0.255', '22', NULL),
	(63, 140, 1, 273, 8, NULL, 'S', '1.0.99.98.20.255', '22', NULL),
	(64, 140, 1, 336, 8, NULL, 'S', '1.0.99.98.14.255', '22', NULL),
	(65, 140, 1, 274, 8, NULL, 'S', '1.0.99.98.21.255', '22', NULL),
	(66, 140, 1, 272, 8, NULL, 'S', '1.0.99.98.13.255', '22', NULL),
	(67, 209, 1, 278, 8, NULL, 'S', '1.0.99.98.32.255', '22', NULL),
	(68, 209, 1, 279, 8, NULL, 'S', '1.0.99.98.40.255', '22', NULL),
	(69, 209, 1, 281, 8, NULL, 'S', '1.0.99.98.50.255', '22', NULL),
	(70, 209, 1, 276, 8, NULL, 'S', '1.0.99.98.30.255', '22', NULL),
	(71, 209, 1, 277, 8, NULL, 'S', '1.0.99.98.31.255', '22', NULL),
	(72, 209, 1, 275, 8, NULL, 'S', '1.0.99.98.22.255', '22', NULL),
	(73, 209, 1, 271, 8, NULL, 'S', '1.0.99.98.12.255', '22', NULL),
	(74, 209, 1, 280, 8, NULL, 'S', '1.0.99.98.41.255', '22', NULL),
	(75, 209, 1, 270, 8, NULL, 'S', '1.0.99.98.11.255', '22', NULL),
	(76, 209, 1, 269, 8, NULL, 'S', '1.0.99.97.0.255', '22', NULL),
	(77, 209, 1, 273, 8, NULL, 'S', '1.0.99.98.20.255', '22', NULL),
	(78, 209, 1, 336, 8, NULL, 'S', '1.0.99.98.14.255', '22', NULL),
	(79, 209, 1, 274, 8, NULL, 'S', '1.0.99.98.21.255', '22', NULL),
	(80, 209, 1, 272, 8, NULL, 'S', '1.0.99.98.13.255', '22', NULL),
	(81, 140, 1, 339, 8, NULL, 'S', '1.0.96.90.10.255', '10010', NULL),
	(82, 209, 1, 339, 8, NULL, 'S', '1.0.96.90.10.255', '10010', NULL),
	(83, 33, 1, 109, 1, NULL, NULL, NULL, NULL, NULL),
	(84, 33, 1, 110, 1, NULL, NULL, NULL, NULL, NULL),
	(85, 33, 1, 20, 1, NULL, NULL, NULL, NULL, NULL),
	(86, 33, 1, 111, 1, NULL, NULL, NULL, NULL, NULL),
	(87, 33, 1, 112, 1, NULL, NULL, NULL, NULL, NULL),
	(88, 140, 1, 18, 17, 5, 'M', '6', '4', '2'),
	(89, 140, 1, 360, 17, 5, 'M', '6', '4', '5'),
	(90, 209, 1, 360, 17, 5, 'M', '6', '4', '2'),
	(91, 209, 1, 18, 17, 5, 'M', '6', '4', '5'),
	(92, 283, 1, 429, 1, NULL, NULL, NULL, NULL, NULL),
	(93, 288, 1, 429, 1, NULL, NULL, NULL, NULL, NULL),
	(94, 25, 1, 20, 1, NULL, NULL, NULL, NULL, NULL),
	(95, 25, 1, 105, 1, NULL, NULL, NULL, NULL, NULL),
	(96, 25, 2, 20, 1, NULL, NULL, NULL, NULL, NULL),
	(97, 25, 2, 105, 1, NULL, NULL, NULL, NULL, NULL),
	(98, 25, 3, 20, 1, NULL, NULL, NULL, NULL, NULL),
	(99, 25, 3, 105, 1, NULL, NULL, NULL, NULL, NULL),
	(100, 127, 1, 20, 1, NULL, NULL, NULL, NULL, NULL),
	(101, 127, 1, 105, 1, NULL, NULL, NULL, NULL, NULL),
	(102, 35, 1, 476, 1, NULL, NULL, NULL, NULL, NULL),
	(103, 209, 1, 474, 2, 5, 'M', NULL, NULL, NULL),
	(104, 209, 1, 475, 2, 5, 'M', NULL, NULL, NULL),
	(105, 140, 1, 474, 2, 5, 'M', NULL, NULL, NULL),
	(106, 140, 1, 475, 2, 5, 'M', NULL, NULL, NULL),
	(107, 39, 1, 18, 22, 11, NULL, 'Enr', NULL, NULL),
	(108, 39, 1, 491, 22, 11, NULL, 'Val', NULL, NULL),
	(109, 39, 1, 259, 22, 11, NULL, 'Val', NULL, NULL);
/*!40000 ALTER TABLE `pwl` ENABLE KEYS */;

-- Dumping structure for table emcor.pwl_withe
CREATE TABLE IF NOT EXISTS `pwl_withe` (
  `pwl_id` int(10) unsigned NOT NULL COMMENT 'Taškų ryšio savybių užpildymo pagal konfigūracinius parametrus taisyklės identifikatorius',
  `pwl_nr` tinyint(3) unsigned NOT NULL COMMENT 'Taškų ryšio savybių užpildymo pagal konfigūracinius parametrus taisyklės duomenų vytelės numeris',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  PRIMARY KEY (`pwl_id`,`pwl_nr`),
  KEY `pwl_withe_withe_i` (`withe_id`),
  CONSTRAINT `pwl_withe_pwl_fk` FOREIGN KEY (`pwl_id`) REFERENCES `pwl` (`pwl_id`) ON DELETE CASCADE,
  CONSTRAINT `pwl_withe_withe_fk` FOREIGN KEY (`withe_id`) REFERENCES `withe` (`withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Taškų ryšio savybių užpildymo pagal konfigūracinius parametrus taisyklių vytelės';

-- Dumping data for table emcor.pwl_withe: ~166 rows (approximately)
/*!40000 ALTER TABLE `pwl_withe` DISABLE KEYS */;
INSERT INTO `pwl_withe` (`pwl_id`, `pwl_nr`, `withe_id`) VALUES
	(92, 1, -50691),
	(93, 1, -50691),
	(88, 3, -50499),
	(89, 3, -50499),
	(90, 3, -50499),
	(91, 3, -50499),
	(7, 1, -50497),
	(8, 1, -50497),
	(11, 1, -50497),
	(12, 1, -50497),
	(15, 1, -50497),
	(16, 1, -50497),
	(51, 1, -50497),
	(52, 1, -50497),
	(88, 1, -50497),
	(89, 1, -50497),
	(90, 1, -50497),
	(91, 1, -50497),
	(5, 1, -50493),
	(6, 1, -50493),
	(9, 1, -50493),
	(10, 1, -50493),
	(13, 1, -50493),
	(14, 1, -50493),
	(49, 1, -50493),
	(50, 1, -50493),
	(107, 1, -50493),
	(108, 1, -50493),
	(49, 3, -50491),
	(50, 3, -50491),
	(51, 3, -50491),
	(52, 3, -50491),
	(109, 1, -50491),
	(1, 2, -50490),
	(2, 2, -50490),
	(3, 2, -50490),
	(4, 2, -50490),
	(5, 3, -50490),
	(6, 3, -50490),
	(7, 3, -50490),
	(8, 3, -50490),
	(17, 2, -50490),
	(18, 2, -50490),
	(21, 2, -50490),
	(22, 2, -50490),
	(23, 2, -50490),
	(24, 2, -50490),
	(25, 2, -50490),
	(26, 2, -50490),
	(27, 2, -50490),
	(28, 2, -50490),
	(29, 2, -50490),
	(30, 2, -50490),
	(31, 2, -50490),
	(32, 2, -50490),
	(33, 2, -50490),
	(34, 2, -50490),
	(35, 2, -50490),
	(36, 2, -50490),
	(37, 2, -50490),
	(38, 2, -50490),
	(39, 2, -50490),
	(40, 2, -50490),
	(41, 2, -50490),
	(42, 2, -50490),
	(43, 2, -50490),
	(44, 2, -50490),
	(45, 2, -50490),
	(46, 2, -50490),
	(47, 2, -50490),
	(48, 2, -50490),
	(81, 2, -50490),
	(82, 2, -50490),
	(103, 2, -50490),
	(105, 2, -50490),
	(9, 3, -50489),
	(10, 3, -50489),
	(11, 3, -50489),
	(12, 3, -50489),
	(19, 2, -50489),
	(20, 2, -50489),
	(104, 2, -50489),
	(106, 2, -50489),
	(1, 1, -50488),
	(2, 1, -50488),
	(3, 1, -50488),
	(4, 1, -50488),
	(5, 2, -50488),
	(6, 2, -50488),
	(7, 2, -50488),
	(8, 2, -50488),
	(9, 2, -50488),
	(10, 2, -50488),
	(11, 2, -50488),
	(12, 2, -50488),
	(17, 1, -50488),
	(18, 1, -50488),
	(19, 1, -50488),
	(20, 1, -50488),
	(21, 1, -50488),
	(22, 1, -50488),
	(23, 1, -50488),
	(24, 1, -50488),
	(25, 1, -50488),
	(26, 1, -50488),
	(27, 1, -50488),
	(28, 1, -50488),
	(29, 1, -50488),
	(30, 1, -50488),
	(31, 1, -50488),
	(32, 1, -50488),
	(33, 1, -50488),
	(34, 1, -50488),
	(35, 1, -50488),
	(36, 1, -50488),
	(37, 1, -50488),
	(38, 1, -50488),
	(39, 1, -50488),
	(40, 1, -50488),
	(41, 1, -50488),
	(42, 1, -50488),
	(43, 1, -50488),
	(44, 1, -50488),
	(45, 1, -50488),
	(46, 1, -50488),
	(47, 1, -50488),
	(48, 1, -50488),
	(49, 2, -50488),
	(50, 2, -50488),
	(51, 2, -50488),
	(52, 2, -50488),
	(81, 1, -50488),
	(82, 1, -50488),
	(103, 1, -50488),
	(104, 1, -50488),
	(105, 1, -50488),
	(106, 1, -50488),
	(107, 2, -50304),
	(108, 2, -50304),
	(109, 2, -50304),
	(102, 1, -50073),
	(87, 1, -12),
	(86, 1, -11),
	(84, 1, -10),
	(83, 1, -9),
	(5, 4, -8),
	(6, 4, -8),
	(9, 4, -8),
	(10, 4, -8),
	(13, 2, -8),
	(14, 2, -8),
	(49, 4, -8),
	(50, 4, -8),
	(88, 2, -8),
	(89, 2, -8),
	(90, 2, -8),
	(91, 2, -8),
	(95, 1, -7),
	(97, 1, -7),
	(99, 1, -7),
	(101, 1, -7),
	(85, 1, -3),
	(94, 1, -3),
	(96, 1, -3),
	(98, 1, -3),
	(100, 1, -3);
/*!40000 ALTER TABLE `pwl_withe` ENABLE KEYS */;

-- Dumping structure for table emcor.pwm
CREATE TABLE IF NOT EXISTS `pwm` (
  `pwm_id` int(10) unsigned NOT NULL COMMENT 'Taškų matavimo linijų užpildymo pagal konfigūracinius parametrus taisyklės identifikatorius',
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `lm_id` smallint(5) unsigned NOT NULL COMMENT 'Paieškos prietaisų konfigūraciniuose parametruose metodo identifikatorius',
  `catalog_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Katalogo identifikatorius',
  `p1` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `p2` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `p3` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  PRIMARY KEY (`pwm_id`),
  KEY `pwm_src_type_mod_i` (`src_type_id`,`src_type_mod_nr`,`lm_id`,`catalog_id`),
  KEY `pwm_catalog_fk` (`catalog_id`),
  KEY `pwm_lm_fk` (`lm_id`),
  CONSTRAINT `pwm_catalog_fk` FOREIGN KEY (`catalog_id`) REFERENCES `catalog` (`catalog_id`) ON DELETE CASCADE,
  CONSTRAINT `pwm_lm_fk` FOREIGN KEY (`lm_id`) REFERENCES `lm` (`lm_id`) ON DELETE CASCADE,
  CONSTRAINT `pwm_src_type_mod_fk` FOREIGN KEY (`src_type_id`, `src_type_mod_nr`) REFERENCES `src_type_mod` (`src_type_id`, `src_type_mod_nr`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Taškų matavimo linijų užpildymo pagal konfigūracinius parametrus taisyklės';

-- Dumping data for table emcor.pwm: ~46 rows (approximately)
/*!40000 ALTER TABLE `pwm` DISABLE KEYS */;
INSERT INTO `pwm` (`pwm_id`, `src_type_id`, `src_type_mod_nr`, `lm_id`, `catalog_id`, `p1`, `p2`, `p3`) VALUES
	(1, 209, 1, 9, 5, '7', NULL, NULL),
	(2, 209, 1, 10, 5, NULL, NULL, NULL),
	(3, 209, 1, 9, 5, '6', NULL, NULL),
	(4, 140, 1, 9, 5, '7', NULL, NULL),
	(5, 140, 1, 10, 5, NULL, NULL, NULL),
	(6, 140, 1, 9, 5, '6', NULL, NULL),
	(7, 140, 1, 17, 5, '6', '4', '2'),
	(8, 209, 1, 17, 5, '6', '4', '2'),
	(9, 25, 1, 19, 6, '^0$', 'A', NULL),
	(10, 25, 1, 19, 6, '^(3[2-9]|4[0-8])$', 'B', NULL),
	(11, 25, 1, 19, 6, '^(8[1-9]|9[0-5])$', 'C', NULL),
	(12, 25, 1, 19, 6, '^96$', 'D', NULL),
	(13, 25, 1, 19, 6, '^(9[7-9]|[1-9][0-9]{2})$', 'E', NULL),
	(14, 25, 2, 19, 6, '^0$', 'A', NULL),
	(15, 25, 2, 19, 6, '^(3[2-9]|4[0-8])$', 'B', NULL),
	(16, 25, 2, 19, 6, '^(8[1-9]|9[0-5])$', 'C', NULL),
	(17, 25, 2, 19, 6, '^96$', 'D', NULL),
	(18, 25, 2, 19, 6, '^(9[7-9]|[1-9][0-9]{2})$', 'E', NULL),
	(19, 25, 3, 19, 6, '^0$', 'A', NULL),
	(20, 25, 3, 19, 6, '^(3[2-9]|4[0-8])$', 'B', NULL),
	(21, 25, 3, 19, 6, '^(8[1-9]|9[0-5])$', 'C', NULL),
	(22, 25, 3, 19, 6, '^96$', 'D', NULL),
	(23, 25, 3, 19, 6, '^(9[7-9]|[1-9][0-9]{2})$', 'E', NULL),
	(24, 1, 1, 20, 7, '1', NULL, NULL),
	(25, 1, 1, 20, 7, '2', NULL, NULL),
	(26, 1, 1, 21, 7, '3', NULL, NULL),
	(27, 1, 1, 21, 7, '4', NULL, NULL),
	(28, 30, 1, 20, 7, '1', NULL, NULL),
	(29, 30, 1, 20, 7, '2', NULL, NULL),
	(30, 30, 1, 21, 7, '3', NULL, NULL),
	(31, 30, 1, 21, 7, '4', NULL, NULL),
	(32, 51, 1, 20, 7, '1', NULL, NULL),
	(33, 51, 1, 20, 7, '2', NULL, NULL),
	(34, 51, 1, 21, 7, '3', NULL, NULL),
	(35, 51, 1, 21, 7, '4', NULL, NULL),
	(36, 33, 1, 19, 10, '^([0-1]d{6}|[2][0]{4}[0-2]d|[2][0]{4}[3][0])$', 'A', NULL),
	(37, 33, 1, 19, 10, '^([2]d{4}[3][1-9]|[2]d{4}[4-9]d|[2][0]{2}[1-9]d{3}|[2][0][1-9]d{4}|[2][1-9]d{5}|[3-9]d{6}|[2][0]{3}[1-9]d{2})$', 'B', NULL),
	(38, 25, 1, 19, 6, '^(6[5-9]|7[0-9]|80)$', 'F', NULL),
	(39, 25, 2, 19, 6, '^(6[5-9]|7[0-9]|80)$', 'F', NULL),
	(40, 25, 3, 19, 6, '^(6[5-9]|7[0-9]|80)$', 'F', NULL),
	(41, 25, 1, 19, 6, '^(49|5[0-9]|6[0-4])$', 'G', NULL),
	(42, 25, 2, 19, 6, '^(49|5[0-9]|6[0-4])$', 'G', NULL),
	(43, 25, 3, 19, 6, '^(49|5[0-9]|6[0-4])$', 'G', NULL),
	(44, 39, 1, 22, 11, NULL, NULL, NULL),
	(45, 384, 1, 23, 13, 'A', NULL, NULL),
	(46, 384, 1, 24, 13, 'B', NULL, NULL);
/*!40000 ALTER TABLE `pwm` ENABLE KEYS */;

-- Dumping structure for table emcor.pwm_withe
CREATE TABLE IF NOT EXISTS `pwm_withe` (
  `pwm_id` int(10) unsigned NOT NULL COMMENT 'Taškų matavimo linijų užpildymo pagal konfigūracinius parametrus taisyklės identifikatorius',
  `pwm_nr` tinyint(3) unsigned NOT NULL COMMENT 'Taškų matavimo linijų užpildymo pagal konfigūracinius parametrus taisyklės duomenų vytelės numeris',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  PRIMARY KEY (`pwm_id`,`pwm_nr`),
  KEY `pwm_withe_withe_i` (`withe_id`),
  CONSTRAINT `pwm_withe_pwm_fk` FOREIGN KEY (`pwm_id`) REFERENCES `pwm` (`pwm_id`) ON DELETE CASCADE,
  CONSTRAINT `pwm_withe_withe_fk` FOREIGN KEY (`withe_id`) REFERENCES `withe` (`withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Taškų matavimų linijų užpildymo pagal konfigūracinius parametrus taisyklių vytelės';

-- Dumping data for table emcor.pwm_withe: ~69 rows (approximately)
/*!40000 ALTER TABLE `pwm_withe` DISABLE KEYS */;
INSERT INTO `pwm_withe` (`pwm_id`, `pwm_nr`, `withe_id`) VALUES
	(7, 3, -50499),
	(8, 3, -50499),
	(3, 1, -50497),
	(6, 1, -50497),
	(7, 1, -50497),
	(8, 1, -50497),
	(2, 1, -50493),
	(5, 1, -50493),
	(44, 1, -50493),
	(1, 1, -50488),
	(4, 1, -50488),
	(44, 2, -50304),
	(2, 2, -8),
	(5, 2, -8),
	(7, 2, -8),
	(8, 2, -8),
	(9, 2, -8),
	(10, 2, -8),
	(11, 2, -8),
	(12, 2, -8),
	(13, 2, -8),
	(14, 2, -8),
	(15, 2, -8),
	(16, 2, -8),
	(17, 2, -8),
	(18, 2, -8),
	(19, 2, -8),
	(20, 2, -8),
	(21, 2, -8),
	(22, 2, -8),
	(23, 2, -8),
	(26, 1, -8),
	(27, 1, -8),
	(30, 1, -8),
	(31, 1, -8),
	(34, 1, -8),
	(35, 1, -8),
	(36, 2, -8),
	(37, 2, -8),
	(38, 2, -8),
	(39, 2, -8),
	(40, 2, -8),
	(41, 2, -8),
	(42, 2, -8),
	(43, 2, -8),
	(46, 1, -8),
	(9, 1, -3),
	(10, 1, -3),
	(11, 1, -3),
	(12, 1, -3),
	(13, 1, -3),
	(14, 1, -3),
	(15, 1, -3),
	(16, 1, -3),
	(17, 1, -3),
	(18, 1, -3),
	(19, 1, -3),
	(20, 1, -3),
	(21, 1, -3),
	(22, 1, -3),
	(23, 1, -3),
	(36, 1, -3),
	(37, 1, -3),
	(38, 1, -3),
	(39, 1, -3),
	(40, 1, -3),
	(41, 1, -3),
	(42, 1, -3),
	(43, 1, -3);
/*!40000 ALTER TABLE `pwm_withe` ENABLE KEYS */;

-- Dumping structure for table emcor.pwo
CREATE TABLE IF NOT EXISTS `pwo` (
  `pwo_id` int(10) unsigned NOT NULL COMMENT 'Taškų užsakymų savybių užpildymo pagal konfigūracinius parametrus taisyklės identifikatorius',
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `lm_id` smallint(5) unsigned NOT NULL COMMENT 'Paieškos prietaisų konfigūraciniuose parametruose metodo identifikatorius',
  `catalog_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Katalogo identifikatorius',
  `rc_in` tinyint(1) DEFAULT NULL COMMENT 'Nuskaitymo užklausų požymis',
  `p1` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `p2` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `p3` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  PRIMARY KEY (`pwo_id`),
  KEY `pwo_src_type_mod_i` (`src_type_id`,`src_type_mod_nr`,`opty_id`,`lm_id`,`catalog_id`),
  KEY `pwo_catalog_fk` (`catalog_id`),
  KEY `pwo_lm_fk` (`lm_id`),
  KEY `pwo_opty_fk` (`opty_id`),
  CONSTRAINT `pwo_catalog_fk` FOREIGN KEY (`catalog_id`) REFERENCES `catalog` (`catalog_id`) ON DELETE CASCADE,
  CONSTRAINT `pwo_lm_fk` FOREIGN KEY (`lm_id`) REFERENCES `lm` (`lm_id`) ON DELETE CASCADE,
  CONSTRAINT `pwo_opty_fk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE,
  CONSTRAINT `pwo_src_type_mod_fk` FOREIGN KEY (`src_type_id`, `src_type_mod_nr`) REFERENCES `src_type_mod` (`src_type_id`, `src_type_mod_nr`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Taškų užsakymų savybių užpildymo pagal konfigūracinius parametrus taisyklės';

-- Dumping data for table emcor.pwo: ~260 rows (approximately)
/*!40000 ALTER TABLE `pwo` DISABLE KEYS */;
INSERT INTO `pwo` (`pwo_id`, `src_type_id`, `src_type_mod_nr`, `opty_id`, `lm_id`, `catalog_id`, `rc_in`, `p1`, `p2`, `p3`) VALUES
	(1, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(2, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(3, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(4, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(5, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(7, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(8, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(9, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(10, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(11, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(12, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(13, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(14, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(15, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(16, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(17, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(18, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(19, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(20, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(21, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(22, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(23, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(24, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(25, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(26, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(27, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(28, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(29, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(30, 140, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(31, 140, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(32, 140, 1, 16, 5, NULL, 0, '1.0.0.2.2.255', NULL, NULL),
	(33, 140, 1, 16, 5, NULL, 0, '1.0.96.55.2.255', NULL, NULL),
	(34, 140, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(35, 140, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(36, 140, 1, 16, 5, NULL, 0, '1.0.96.50.3.0', NULL, NULL),
	(37, 140, 1, 16, 5, NULL, 0, '1.0.96.52.3.0', NULL, NULL),
	(38, 140, 1, 18, 5, NULL, 0, '1.0.96.50.3.1', NULL, NULL),
	(39, 140, 1, 18, 5, NULL, 0, '1.0.96.52.3.1', NULL, NULL),
	(40, 140, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(41, 140, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(42, 140, 1, 16, 5, NULL, 0, '1.0.96.50.3.0', NULL, NULL),
	(43, 140, 1, 16, 5, NULL, 0, '1.0.96.52.3.0', NULL, NULL),
	(44, 140, 1, 18, 5, NULL, 0, '1.0.96.50.3.1', NULL, NULL),
	(45, 140, 1, 18, 5, NULL, 0, '1.0.96.52.3.1', NULL, NULL),
	(46, 140, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(47, 140, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(48, 140, 1, 16, 5, NULL, 0, '1.0.96.50.2.0', NULL, NULL),
	(49, 140, 1, 16, 5, NULL, 0, '1.0.96.52.2.0', NULL, NULL),
	(50, 140, 1, 18, 5, NULL, 0, '1.0.96.50.2.1', NULL, NULL),
	(51, 140, 1, 18, 5, NULL, 0, '1.0.96.52.2.1', NULL, NULL),
	(52, 140, 1, 19, 5, NULL, 0, '1.0.96.50.2.2', NULL, NULL),
	(53, 140, 1, 19, 5, NULL, 0, '1.0.96.52.2.2', NULL, NULL),
	(54, 140, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(55, 140, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(56, 140, 1, 16, 5, NULL, 0, '1.0.96.50.1.0', NULL, NULL),
	(57, 140, 1, 16, 5, NULL, 0, '1.0.96.52.1.0', NULL, NULL),
	(58, 140, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(59, 140, 1, 16, 5, NULL, 0, '1.0.96.55.1.255', NULL, NULL),
	(60, 140, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(61, 140, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(62, 140, 1, 16, 5, NULL, 0, '1.0.96.130.5.255', NULL, NULL),
	(63, 140, 1, 16, 5, NULL, 0, '1.0.96.130.5.255', NULL, NULL),
	(64, 140, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(65, 140, 1, 16, 5, NULL, 0, '1.0.96.130.5.255', NULL, NULL),
	(66, 140, 1, 16, 7, NULL, NULL, '0.1.24.1.0.255', '1', NULL),
	(67, 140, 1, 16, 7, NULL, NULL, '0.2.24.1.0.255', '2', NULL),
	(68, 140, 1, 16, 7, NULL, NULL, '0.3.24.1.0.255', '3', NULL),
	(69, 140, 1, 16, 7, NULL, NULL, '0.4.24.1.0.255', '4', NULL),
	(70, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(71, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(72, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(73, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(74, 140, 1, 13, 2, 5, NULL, NULL, NULL, NULL),
	(75, 140, 1, 13, 2, 5, NULL, NULL, NULL, NULL),
	(76, 140, 1, 13, 2, 5, NULL, NULL, NULL, NULL),
	(77, 140, 1, 13, 2, 5, NULL, NULL, NULL, NULL),
	(78, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(79, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(80, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(81, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(82, 140, 1, 13, 2, 5, NULL, NULL, NULL, NULL),
	(83, 140, 1, 13, 2, 5, NULL, NULL, NULL, NULL),
	(84, 140, 1, 13, 2, 5, NULL, NULL, NULL, NULL),
	(85, 140, 1, 13, 2, 5, NULL, NULL, NULL, NULL),
	(86, 140, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(87, 140, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(88, 140, 1, 16, 5, NULL, 0, '1.0.96.50.1.0', NULL, NULL),
	(89, 140, 1, 16, 5, NULL, 0, '1.0.96.52.1.0', NULL, NULL),
	(90, 140, 1, 18, 5, NULL, 0, '1.0.96.50.1.1', NULL, NULL),
	(91, 140, 1, 19, 5, NULL, 0, '1.0.96.50.1.2', NULL, NULL),
	(92, 140, 1, 20, 5, NULL, 0, '1.0.96.50.1.3', NULL, NULL),
	(93, 140, 1, 21, 5, NULL, 0, '1.0.96.50.1.4', NULL, NULL),
	(94, 140, 1, 22, 5, NULL, 0, '1.0.96.50.1.5', NULL, NULL),
	(95, 140, 1, 23, 5, NULL, 0, '1.0.96.50.1.6', NULL, NULL),
	(96, 140, 1, 24, 5, NULL, 0, '1.0.96.50.1.7', NULL, NULL),
	(97, 140, 1, 25, 5, NULL, 0, '1.0.96.50.1.8', NULL, NULL),
	(98, 140, 1, 26, 5, NULL, 0, '1.0.96.50.1.9', NULL, NULL),
	(99, 140, 1, 27, 5, NULL, 0, '1.0.96.50.1.10', NULL, NULL),
	(100, 140, 1, 28, 5, NULL, 0, '1.0.96.50.1.11', NULL, NULL),
	(101, 140, 1, 29, 5, NULL, 0, '1.0.96.50.1.12', NULL, NULL),
	(102, 140, 1, 30, 5, NULL, 0, '1.0.96.50.1.13', NULL, NULL),
	(103, 140, 1, 31, 5, NULL, 0, '1.0.96.50.1.14', NULL, NULL),
	(104, 140, 1, 32, 5, NULL, 0, '1.0.96.50.1.15', NULL, NULL),
	(105, 140, 1, 18, 5, NULL, 0, '1.0.96.52.1.1', NULL, NULL),
	(106, 140, 1, 19, 5, NULL, 0, '1.0.96.52.1.2', NULL, NULL),
	(107, 140, 1, 20, 5, NULL, 0, '1.0.96.52.1.3', NULL, NULL),
	(108, 140, 1, 21, 5, NULL, 0, '1.0.96.52.1.4', NULL, NULL),
	(109, 140, 1, 22, 5, NULL, 0, '1.0.96.52.1.5', NULL, NULL),
	(110, 140, 1, 23, 5, NULL, 0, '1.0.96.52.1.6', NULL, NULL),
	(111, 140, 1, 24, 5, NULL, 0, '1.0.96.52.1.7', NULL, NULL),
	(112, 140, 1, 25, 5, NULL, 0, '1.0.96.52.1.8', NULL, NULL),
	(113, 140, 1, 26, 5, NULL, 0, '1.0.96.52.1.9', NULL, NULL),
	(114, 140, 1, 27, 5, NULL, 0, '1.0.96.52.1.10', NULL, NULL),
	(115, 140, 1, 28, 5, NULL, 0, '1.0.96.52.1.11', NULL, NULL),
	(116, 140, 1, 29, 5, NULL, 0, '1.0.96.52.1.12', NULL, NULL),
	(117, 140, 1, 30, 5, NULL, 0, '1.0.96.52.1.13', NULL, NULL),
	(118, 140, 1, 31, 5, NULL, 0, '1.0.96.52.1.14', NULL, NULL),
	(119, 140, 1, 32, 5, NULL, 0, '1.0.96.52.1.15', NULL, NULL),
	(120, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(121, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(122, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(123, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(124, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(126, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(127, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(128, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(129, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(130, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(131, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(132, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(133, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(134, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(135, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(136, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(137, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(138, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(139, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(140, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(141, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(142, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(143, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(144, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(145, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(146, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(147, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(148, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(149, 209, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(150, 209, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(151, 209, 1, 16, 5, NULL, 0, '1.0.0.2.2.255', NULL, NULL),
	(152, 209, 1, 16, 5, NULL, 0, '1.0.96.55.2.255', NULL, NULL),
	(153, 209, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(154, 209, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(155, 209, 1, 16, 5, NULL, 0, '1.0.96.50.3.0', NULL, NULL),
	(156, 209, 1, 16, 5, NULL, 0, '1.0.96.52.3.0', NULL, NULL),
	(157, 209, 1, 18, 5, NULL, 0, '1.0.96.50.3.1', NULL, NULL),
	(158, 209, 1, 18, 5, NULL, 0, '1.0.96.52.3.1', NULL, NULL),
	(159, 209, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(160, 209, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(161, 209, 1, 16, 5, NULL, 0, '1.0.96.50.3.0', NULL, NULL),
	(162, 209, 1, 16, 5, NULL, 0, '1.0.96.52.3.0', NULL, NULL),
	(163, 209, 1, 18, 5, NULL, 0, '1.0.96.50.3.1', NULL, NULL),
	(164, 209, 1, 18, 5, NULL, 0, '1.0.96.52.3.1', NULL, NULL),
	(165, 209, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(166, 209, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(167, 209, 1, 16, 5, NULL, 0, '1.0.96.50.2.0', NULL, NULL),
	(168, 209, 1, 16, 5, NULL, 0, '1.0.96.52.2.0', NULL, NULL),
	(169, 209, 1, 18, 5, NULL, 0, '1.0.96.50.2.1', NULL, NULL),
	(170, 209, 1, 18, 5, NULL, 0, '1.0.96.52.2.1', NULL, NULL),
	(171, 209, 1, 19, 5, NULL, 0, '1.0.96.50.2.2', NULL, NULL),
	(172, 209, 1, 19, 5, NULL, 0, '1.0.96.52.2.2', NULL, NULL),
	(173, 209, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(174, 209, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(175, 209, 1, 16, 5, NULL, 0, '1.0.96.50.1.0', NULL, NULL),
	(176, 209, 1, 16, 5, NULL, 0, '1.0.96.52.1.0', NULL, NULL),
	(177, 209, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(178, 209, 1, 16, 5, NULL, 0, '1.0.96.55.1.255', NULL, NULL),
	(179, 209, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(180, 209, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(181, 209, 1, 16, 5, NULL, 0, '1.0.96.130.5.255', NULL, NULL),
	(182, 209, 1, 16, 5, NULL, 0, '1.0.96.130.5.255', NULL, NULL),
	(183, 209, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(184, 209, 1, 16, 5, NULL, 0, '1.0.96.130.5.255', NULL, NULL),
	(185, 209, 1, 16, 7, NULL, NULL, '0.1.24.1.0.255', '1', NULL),
	(186, 209, 1, 16, 7, NULL, NULL, '0.2.24.1.0.255', '2', NULL),
	(187, 209, 1, 16, 7, NULL, NULL, '0.3.24.1.0.255', '3', NULL),
	(188, 209, 1, 16, 7, NULL, NULL, '0.4.24.1.0.255', '4', NULL),
	(189, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(190, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(191, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(192, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(193, 209, 1, 13, 2, 5, NULL, NULL, NULL, NULL),
	(194, 209, 1, 13, 2, 5, NULL, NULL, NULL, NULL),
	(195, 209, 1, 13, 2, 5, NULL, NULL, NULL, NULL),
	(196, 209, 1, 13, 2, 5, NULL, NULL, NULL, NULL),
	(197, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(198, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(199, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(200, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(201, 209, 1, 13, 2, 5, NULL, NULL, NULL, NULL),
	(202, 209, 1, 13, 2, 5, NULL, NULL, NULL, NULL),
	(203, 209, 1, 13, 2, 5, NULL, NULL, NULL, NULL),
	(204, 209, 1, 13, 2, 5, NULL, NULL, NULL, NULL),
	(205, 209, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(206, 209, 1, 16, 2, 5, 1, NULL, NULL, NULL),
	(207, 209, 1, 16, 5, NULL, 0, '1.0.96.50.1.0', NULL, NULL),
	(208, 209, 1, 16, 5, NULL, 0, '1.0.96.52.1.0', NULL, NULL),
	(209, 209, 1, 18, 5, NULL, 0, '1.0.96.50.1.1', NULL, NULL),
	(210, 209, 1, 19, 5, NULL, 0, '1.0.96.50.1.2', NULL, NULL),
	(211, 209, 1, 20, 5, NULL, 0, '1.0.96.50.1.3', NULL, NULL),
	(212, 209, 1, 21, 5, NULL, 0, '1.0.96.50.1.4', NULL, NULL),
	(213, 209, 1, 22, 5, NULL, 0, '1.0.96.50.1.5', NULL, NULL),
	(214, 209, 1, 23, 5, NULL, 0, '1.0.96.50.1.6', NULL, NULL),
	(215, 209, 1, 24, 5, NULL, 0, '1.0.96.50.1.7', NULL, NULL),
	(216, 209, 1, 25, 5, NULL, 0, '1.0.96.50.1.8', NULL, NULL),
	(217, 209, 1, 26, 5, NULL, 0, '1.0.96.50.1.9', NULL, NULL),
	(218, 209, 1, 27, 5, NULL, 0, '1.0.96.50.1.10', NULL, NULL),
	(219, 209, 1, 28, 5, NULL, 0, '1.0.96.50.1.11', NULL, NULL),
	(220, 209, 1, 29, 5, NULL, 0, '1.0.96.50.1.12', NULL, NULL),
	(221, 209, 1, 30, 5, NULL, 0, '1.0.96.50.1.13', NULL, NULL),
	(222, 209, 1, 31, 5, NULL, 0, '1.0.96.50.1.14', NULL, NULL),
	(223, 209, 1, 32, 5, NULL, 0, '1.0.96.50.1.15', NULL, NULL),
	(224, 209, 1, 18, 5, NULL, 0, '1.0.96.52.1.1', NULL, NULL),
	(225, 209, 1, 19, 5, NULL, 0, '1.0.96.52.1.2', NULL, NULL),
	(226, 209, 1, 20, 5, NULL, 0, '1.0.96.52.1.3', NULL, NULL),
	(227, 209, 1, 21, 5, NULL, 0, '1.0.96.52.1.4', NULL, NULL),
	(228, 209, 1, 22, 5, NULL, 0, '1.0.96.52.1.5', NULL, NULL),
	(229, 209, 1, 23, 5, NULL, 0, '1.0.96.52.1.6', NULL, NULL),
	(230, 209, 1, 24, 5, NULL, 0, '1.0.96.52.1.7', NULL, NULL),
	(231, 209, 1, 25, 5, NULL, 0, '1.0.96.52.1.8', NULL, NULL),
	(232, 209, 1, 26, 5, NULL, 0, '1.0.96.52.1.9', NULL, NULL),
	(233, 209, 1, 27, 5, NULL, 0, '1.0.96.52.1.10', NULL, NULL),
	(234, 209, 1, 28, 5, NULL, 0, '1.0.96.52.1.11', NULL, NULL),
	(235, 209, 1, 29, 5, NULL, 0, '1.0.96.52.1.12', NULL, NULL),
	(236, 209, 1, 30, 5, NULL, 0, '1.0.96.52.1.13', NULL, NULL),
	(237, 209, 1, 31, 5, NULL, 0, '1.0.96.52.1.14', NULL, NULL),
	(238, 209, 1, 32, 5, NULL, 0, '1.0.96.52.1.15', NULL, NULL),
	(239, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(240, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(241, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(242, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(243, 232, 1, 12, 16, 5, NULL, NULL, NULL, NULL),
	(244, 232, 1, 12, 16, 5, NULL, NULL, NULL, NULL),
	(252, 232, 1, 12, 16, 5, NULL, NULL, NULL, NULL),
	(253, 232, 1, 12, 16, 5, NULL, NULL, NULL, NULL),
	(254, 232, 1, 12, 16, 5, NULL, NULL, NULL, NULL),
	(255, 232, 1, 12, 16, 5, NULL, NULL, NULL, NULL),
	(260, 232, 1, 12, 16, 5, NULL, NULL, NULL, NULL),
	(261, 232, 1, 12, 16, 5, NULL, NULL, NULL, NULL),
	(264, 248, 1, 12, 16, 5, NULL, NULL, NULL, NULL),
	(265, 248, 1, 12, 16, 5, NULL, NULL, NULL, NULL),
	(273, 248, 1, 12, 16, 5, NULL, NULL, NULL, NULL),
	(274, 248, 1, 12, 16, 5, NULL, NULL, NULL, NULL),
	(275, 248, 1, 12, 16, 5, NULL, NULL, NULL, NULL),
	(276, 248, 1, 12, 16, 5, NULL, NULL, NULL, NULL),
	(281, 248, 1, 12, 16, 5, NULL, NULL, NULL, NULL),
	(282, 248, 1, 12, 16, 5, NULL, NULL, NULL, NULL),
	(283, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(284, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(285, 140, 1, 16, 2, 5, NULL, NULL, NULL, NULL),
	(286, 209, 1, 16, 2, 5, NULL, NULL, NULL, NULL);
/*!40000 ALTER TABLE `pwo` ENABLE KEYS */;

-- Dumping structure for table emcor.pwo_withe
CREATE TABLE IF NOT EXISTS `pwo_withe` (
  `pwo_id` int(10) unsigned NOT NULL COMMENT 'Taškų užsakymų savybių užpildymo pagal konfigūracinius parametrus taisyklės identifikatorius',
  `pwo_nr` tinyint(3) unsigned NOT NULL COMMENT 'Taškų užsakymų savybių užpildymo pagal konfigūracinius parametrus taisyklės duomenų vytelės numeris',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  PRIMARY KEY (`pwo_id`,`pwo_nr`),
  KEY `pwo_withe_withe_i` (`withe_id`),
  CONSTRAINT `pwo_withe_pwo_fk` FOREIGN KEY (`pwo_id`) REFERENCES `pwo` (`pwo_id`) ON DELETE CASCADE,
  CONSTRAINT `pwo_withe_withe_fk` FOREIGN KEY (`withe_id`) REFERENCES `withe` (`withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Taškų užsakymų savybių užpildymo pagal konfigūracinius parametrus taisyklių vytelės';

-- Dumping data for table emcor.pwo_withe: ~764 rows (approximately)
/*!40000 ALTER TABLE `pwo_withe` DISABLE KEYS */;
INSERT INTO `pwo_withe` (`pwo_id`, `pwo_nr`, `withe_id`) VALUES
	(240, 0, -50511),
	(241, 0, -50511),
	(261, 0, -50511),
	(282, 0, -50511),
	(81, 0, -50500),
	(85, 0, -50500),
	(200, 0, -50500),
	(204, 0, -50500),
	(255, 0, -50500),
	(276, 0, -50500),
	(80, 0, -50499),
	(84, 0, -50499),
	(199, 0, -50499),
	(203, 0, -50499),
	(254, 0, -50499),
	(275, 0, -50499),
	(79, 0, -50498),
	(83, 0, -50498),
	(198, 0, -50498),
	(202, 0, -50498),
	(253, 0, -50498),
	(274, 0, -50498),
	(78, 0, -50497),
	(82, 0, -50497),
	(197, 0, -50497),
	(201, 0, -50497),
	(252, 0, -50497),
	(273, 0, -50497),
	(73, 0, -50496),
	(77, 0, -50496),
	(192, 0, -50496),
	(196, 0, -50496),
	(72, 0, -50495),
	(76, 0, -50495),
	(191, 0, -50495),
	(195, 0, -50495),
	(71, 0, -50494),
	(75, 0, -50494),
	(190, 0, -50494),
	(194, 0, -50494),
	(70, 0, -50493),
	(74, 0, -50493),
	(189, 0, -50493),
	(193, 0, -50493),
	(244, 0, -50493),
	(265, 0, -50493),
	(1, 2, -50490),
	(2, 2, -50490),
	(3, 2, -50490),
	(4, 2, -50490),
	(5, 2, -50490),
	(7, 2, -50490),
	(8, 2, -50490),
	(9, 2, -50490),
	(10, 2, -50490),
	(11, 2, -50490),
	(12, 2, -50490),
	(13, 2, -50490),
	(14, 2, -50490),
	(15, 2, -50490),
	(16, 2, -50490),
	(17, 2, -50490),
	(18, 2, -50490),
	(19, 2, -50490),
	(20, 2, -50490),
	(21, 2, -50490),
	(22, 2, -50490),
	(23, 2, -50490),
	(24, 2, -50490),
	(25, 2, -50490),
	(26, 2, -50490),
	(27, 2, -50490),
	(28, 2, -50490),
	(29, 2, -50490),
	(30, 2, -50490),
	(31, 2, -50490),
	(32, 2, -50490),
	(33, 2, -50490),
	(34, 2, -50490),
	(35, 2, -50490),
	(36, 2, -50490),
	(37, 2, -50490),
	(38, 2, -50490),
	(39, 2, -50490),
	(40, 2, -50490),
	(41, 2, -50490),
	(42, 2, -50490),
	(43, 2, -50490),
	(44, 2, -50490),
	(45, 2, -50490),
	(46, 2, -50490),
	(47, 2, -50490),
	(48, 2, -50490),
	(49, 2, -50490),
	(50, 2, -50490),
	(51, 2, -50490),
	(52, 2, -50490),
	(53, 2, -50490),
	(54, 2, -50490),
	(55, 2, -50490),
	(56, 2, -50490),
	(57, 2, -50490),
	(58, 2, -50490),
	(59, 2, -50490),
	(60, 2, -50490),
	(61, 2, -50490),
	(62, 2, -50490),
	(63, 2, -50490),
	(64, 2, -50490),
	(65, 2, -50490),
	(66, 2, -50490),
	(67, 2, -50490),
	(68, 2, -50490),
	(69, 2, -50490),
	(70, 2, -50490),
	(71, 2, -50490),
	(72, 2, -50490),
	(73, 2, -50490),
	(78, 2, -50490),
	(79, 2, -50490),
	(80, 2, -50490),
	(81, 2, -50490),
	(86, 2, -50490),
	(87, 2, -50490),
	(88, 2, -50490),
	(89, 2, -50490),
	(90, 2, -50490),
	(91, 2, -50490),
	(92, 2, -50490),
	(93, 2, -50490),
	(94, 2, -50490),
	(95, 2, -50490),
	(96, 2, -50490),
	(97, 2, -50490),
	(98, 2, -50490),
	(99, 2, -50490),
	(100, 2, -50490),
	(101, 2, -50490),
	(102, 2, -50490),
	(103, 2, -50490),
	(104, 2, -50490),
	(105, 2, -50490),
	(106, 2, -50490),
	(107, 2, -50490),
	(108, 2, -50490),
	(109, 2, -50490),
	(110, 2, -50490),
	(111, 2, -50490),
	(112, 2, -50490),
	(113, 2, -50490),
	(114, 2, -50490),
	(115, 2, -50490),
	(116, 2, -50490),
	(117, 2, -50490),
	(118, 2, -50490),
	(119, 2, -50490),
	(120, 2, -50490),
	(121, 2, -50490),
	(122, 2, -50490),
	(123, 2, -50490),
	(124, 2, -50490),
	(126, 2, -50490),
	(127, 2, -50490),
	(128, 2, -50490),
	(129, 2, -50490),
	(130, 2, -50490),
	(131, 2, -50490),
	(132, 2, -50490),
	(133, 2, -50490),
	(134, 2, -50490),
	(135, 2, -50490),
	(136, 2, -50490),
	(137, 2, -50490),
	(138, 2, -50490),
	(139, 2, -50490),
	(140, 2, -50490),
	(141, 2, -50490),
	(142, 2, -50490),
	(143, 2, -50490),
	(144, 2, -50490),
	(145, 2, -50490),
	(146, 2, -50490),
	(147, 2, -50490),
	(148, 2, -50490),
	(149, 2, -50490),
	(150, 2, -50490),
	(151, 2, -50490),
	(152, 2, -50490),
	(153, 2, -50490),
	(154, 2, -50490),
	(155, 2, -50490),
	(156, 2, -50490),
	(157, 2, -50490),
	(158, 2, -50490),
	(159, 2, -50490),
	(160, 2, -50490),
	(161, 2, -50490),
	(162, 2, -50490),
	(163, 2, -50490),
	(164, 2, -50490),
	(165, 2, -50490),
	(166, 2, -50490),
	(167, 2, -50490),
	(168, 2, -50490),
	(169, 2, -50490),
	(170, 2, -50490),
	(171, 2, -50490),
	(172, 2, -50490),
	(173, 2, -50490),
	(174, 2, -50490),
	(175, 2, -50490),
	(176, 2, -50490),
	(177, 2, -50490),
	(178, 2, -50490),
	(179, 2, -50490),
	(180, 2, -50490),
	(181, 2, -50490),
	(182, 2, -50490),
	(183, 2, -50490),
	(184, 2, -50490),
	(185, 2, -50490),
	(186, 2, -50490),
	(187, 2, -50490),
	(188, 2, -50490),
	(189, 2, -50490),
	(190, 2, -50490),
	(191, 2, -50490),
	(192, 2, -50490),
	(197, 2, -50490),
	(198, 2, -50490),
	(199, 2, -50490),
	(200, 2, -50490),
	(205, 2, -50490),
	(206, 2, -50490),
	(207, 2, -50490),
	(208, 2, -50490),
	(209, 2, -50490),
	(210, 2, -50490),
	(211, 2, -50490),
	(212, 2, -50490),
	(213, 2, -50490),
	(214, 2, -50490),
	(215, 2, -50490),
	(216, 2, -50490),
	(217, 2, -50490),
	(218, 2, -50490),
	(219, 2, -50490),
	(220, 2, -50490),
	(221, 2, -50490),
	(222, 2, -50490),
	(223, 2, -50490),
	(224, 2, -50490),
	(225, 2, -50490),
	(226, 2, -50490),
	(227, 2, -50490),
	(228, 2, -50490),
	(229, 2, -50490),
	(230, 2, -50490),
	(231, 2, -50490),
	(232, 2, -50490),
	(233, 2, -50490),
	(234, 2, -50490),
	(235, 2, -50490),
	(236, 2, -50490),
	(237, 2, -50490),
	(238, 2, -50490),
	(239, 2, -50490),
	(240, 2, -50490),
	(241, 2, -50490),
	(242, 2, -50490),
	(283, 2, -50490),
	(284, 2, -50490),
	(285, 2, -50490),
	(286, 2, -50490),
	(74, 2, -50489),
	(75, 2, -50489),
	(76, 2, -50489),
	(77, 2, -50489),
	(82, 2, -50489),
	(83, 2, -50489),
	(84, 2, -50489),
	(85, 2, -50489),
	(193, 2, -50489),
	(194, 2, -50489),
	(195, 2, -50489),
	(196, 2, -50489),
	(201, 2, -50489),
	(202, 2, -50489),
	(203, 2, -50489),
	(204, 2, -50489),
	(1, 1, -50488),
	(2, 1, -50488),
	(3, 1, -50488),
	(4, 1, -50488),
	(5, 1, -50488),
	(7, 1, -50488),
	(8, 1, -50488),
	(9, 1, -50488),
	(10, 1, -50488),
	(11, 1, -50488),
	(12, 1, -50488),
	(13, 1, -50488),
	(14, 1, -50488),
	(15, 1, -50488),
	(16, 1, -50488),
	(17, 1, -50488),
	(18, 1, -50488),
	(19, 1, -50488),
	(20, 1, -50488),
	(21, 1, -50488),
	(22, 1, -50488),
	(23, 1, -50488),
	(24, 1, -50488),
	(25, 1, -50488),
	(26, 1, -50488),
	(27, 1, -50488),
	(28, 1, -50488),
	(29, 1, -50488),
	(30, 1, -50488),
	(31, 1, -50488),
	(32, 1, -50488),
	(33, 1, -50488),
	(34, 1, -50488),
	(35, 1, -50488),
	(36, 1, -50488),
	(37, 1, -50488),
	(38, 1, -50488),
	(39, 1, -50488),
	(40, 1, -50488),
	(41, 1, -50488),
	(42, 1, -50488),
	(43, 1, -50488),
	(44, 1, -50488),
	(45, 1, -50488),
	(46, 1, -50488),
	(47, 1, -50488),
	(48, 1, -50488),
	(49, 1, -50488),
	(50, 1, -50488),
	(51, 1, -50488),
	(52, 1, -50488),
	(53, 1, -50488),
	(54, 1, -50488),
	(55, 1, -50488),
	(56, 1, -50488),
	(57, 1, -50488),
	(58, 1, -50488),
	(59, 1, -50488),
	(60, 1, -50488),
	(61, 1, -50488),
	(62, 1, -50488),
	(63, 1, -50488),
	(64, 1, -50488),
	(65, 1, -50488),
	(66, 1, -50488),
	(67, 1, -50488),
	(68, 1, -50488),
	(69, 1, -50488),
	(70, 1, -50488),
	(71, 1, -50488),
	(72, 1, -50488),
	(73, 1, -50488),
	(74, 1, -50488),
	(75, 1, -50488),
	(76, 1, -50488),
	(77, 1, -50488),
	(78, 1, -50488),
	(79, 1, -50488),
	(80, 1, -50488),
	(81, 1, -50488),
	(82, 1, -50488),
	(83, 1, -50488),
	(84, 1, -50488),
	(85, 1, -50488),
	(86, 1, -50488),
	(87, 1, -50488),
	(88, 1, -50488),
	(89, 1, -50488),
	(90, 1, -50488),
	(91, 1, -50488),
	(92, 1, -50488),
	(93, 1, -50488),
	(94, 1, -50488),
	(95, 1, -50488),
	(96, 1, -50488),
	(97, 1, -50488),
	(98, 1, -50488),
	(99, 1, -50488),
	(100, 1, -50488),
	(101, 1, -50488),
	(102, 1, -50488),
	(103, 1, -50488),
	(104, 1, -50488),
	(105, 1, -50488),
	(106, 1, -50488),
	(107, 1, -50488),
	(108, 1, -50488),
	(109, 1, -50488),
	(110, 1, -50488),
	(111, 1, -50488),
	(112, 1, -50488),
	(113, 1, -50488),
	(114, 1, -50488),
	(115, 1, -50488),
	(116, 1, -50488),
	(117, 1, -50488),
	(118, 1, -50488),
	(119, 1, -50488),
	(120, 1, -50488),
	(121, 1, -50488),
	(122, 1, -50488),
	(123, 1, -50488),
	(124, 1, -50488),
	(126, 1, -50488),
	(127, 1, -50488),
	(128, 1, -50488),
	(129, 1, -50488),
	(130, 1, -50488),
	(131, 1, -50488),
	(132, 1, -50488),
	(133, 1, -50488),
	(134, 1, -50488),
	(135, 1, -50488),
	(136, 1, -50488),
	(137, 1, -50488),
	(138, 1, -50488),
	(139, 1, -50488),
	(140, 1, -50488),
	(141, 1, -50488),
	(142, 1, -50488),
	(143, 1, -50488),
	(144, 1, -50488),
	(145, 1, -50488),
	(146, 1, -50488),
	(147, 1, -50488),
	(148, 1, -50488),
	(149, 1, -50488),
	(150, 1, -50488),
	(151, 1, -50488),
	(152, 1, -50488),
	(153, 1, -50488),
	(154, 1, -50488),
	(155, 1, -50488),
	(156, 1, -50488),
	(157, 1, -50488),
	(158, 1, -50488),
	(159, 1, -50488),
	(160, 1, -50488),
	(161, 1, -50488),
	(162, 1, -50488),
	(163, 1, -50488),
	(164, 1, -50488),
	(165, 1, -50488),
	(166, 1, -50488),
	(167, 1, -50488),
	(168, 1, -50488),
	(169, 1, -50488),
	(170, 1, -50488),
	(171, 1, -50488),
	(172, 1, -50488),
	(173, 1, -50488),
	(174, 1, -50488),
	(175, 1, -50488),
	(176, 1, -50488),
	(177, 1, -50488),
	(178, 1, -50488),
	(179, 1, -50488),
	(180, 1, -50488),
	(181, 1, -50488),
	(182, 1, -50488),
	(183, 1, -50488),
	(184, 1, -50488),
	(185, 1, -50488),
	(186, 1, -50488),
	(187, 1, -50488),
	(188, 1, -50488),
	(189, 1, -50488),
	(190, 1, -50488),
	(191, 1, -50488),
	(192, 1, -50488),
	(193, 1, -50488),
	(194, 1, -50488),
	(195, 1, -50488),
	(196, 1, -50488),
	(197, 1, -50488),
	(198, 1, -50488),
	(199, 1, -50488),
	(200, 1, -50488),
	(201, 1, -50488),
	(202, 1, -50488),
	(203, 1, -50488),
	(204, 1, -50488),
	(205, 1, -50488),
	(206, 1, -50488),
	(207, 1, -50488),
	(208, 1, -50488),
	(209, 1, -50488),
	(210, 1, -50488),
	(211, 1, -50488),
	(212, 1, -50488),
	(213, 1, -50488),
	(214, 1, -50488),
	(215, 1, -50488),
	(216, 1, -50488),
	(217, 1, -50488),
	(218, 1, -50488),
	(219, 1, -50488),
	(220, 1, -50488),
	(221, 1, -50488),
	(222, 1, -50488),
	(223, 1, -50488),
	(224, 1, -50488),
	(225, 1, -50488),
	(226, 1, -50488),
	(227, 1, -50488),
	(228, 1, -50488),
	(229, 1, -50488),
	(230, 1, -50488),
	(231, 1, -50488),
	(232, 1, -50488),
	(233, 1, -50488),
	(234, 1, -50488),
	(235, 1, -50488),
	(236, 1, -50488),
	(237, 1, -50488),
	(238, 1, -50488),
	(239, 1, -50488),
	(240, 1, -50488),
	(241, 1, -50488),
	(242, 1, -50488),
	(243, 1, -50488),
	(244, 1, -50488),
	(252, 1, -50488),
	(253, 1, -50488),
	(254, 1, -50488),
	(255, 1, -50488),
	(260, 1, -50488),
	(261, 1, -50488),
	(264, 1, -50488),
	(265, 1, -50488),
	(273, 1, -50488),
	(274, 1, -50488),
	(275, 1, -50488),
	(276, 1, -50488),
	(281, 1, -50488),
	(282, 1, -50488),
	(283, 1, -50488),
	(284, 1, -50488),
	(285, 1, -50488),
	(286, 1, -50488),
	(25, 0, -50416),
	(144, 0, -50416),
	(21, 0, -50415),
	(140, 0, -50415),
	(20, 0, -50414),
	(139, 0, -50414),
	(19, 0, -50413),
	(138, 0, -50413),
	(18, 0, -50412),
	(137, 0, -50412),
	(17, 0, -50411),
	(136, 0, -50411),
	(16, 0, -50410),
	(135, 0, -50410),
	(15, 0, -50409),
	(134, 0, -50409),
	(14, 0, -50408),
	(133, 0, -50408),
	(13, 0, -50407),
	(132, 0, -50407),
	(12, 0, -50406),
	(131, 0, -50406),
	(11, 0, -50405),
	(130, 0, -50405),
	(10, 0, -50404),
	(129, 0, -50404),
	(9, 0, -50403),
	(128, 0, -50403),
	(8, 0, -50402),
	(127, 0, -50402),
	(7, 0, -50388),
	(126, 0, -50388),
	(285, 0, -50359),
	(286, 0, -50359),
	(283, 0, -50358),
	(284, 0, -50358),
	(58, 0, -50357),
	(59, 0, -50357),
	(177, 0, -50357),
	(178, 0, -50357),
	(55, 0, -50356),
	(57, 0, -50356),
	(174, 0, -50356),
	(176, 0, -50356),
	(54, 0, -50355),
	(56, 0, -50355),
	(173, 0, -50355),
	(175, 0, -50355),
	(87, 0, -50352),
	(89, 0, -50352),
	(105, 0, -50352),
	(106, 0, -50352),
	(107, 0, -50352),
	(108, 0, -50352),
	(109, 0, -50352),
	(110, 0, -50352),
	(111, 0, -50352),
	(112, 0, -50352),
	(113, 0, -50352),
	(114, 0, -50352),
	(115, 0, -50352),
	(116, 0, -50352),
	(117, 0, -50352),
	(118, 0, -50352),
	(119, 0, -50352),
	(206, 0, -50352),
	(208, 0, -50352),
	(224, 0, -50352),
	(225, 0, -50352),
	(226, 0, -50352),
	(227, 0, -50352),
	(228, 0, -50352),
	(229, 0, -50352),
	(230, 0, -50352),
	(231, 0, -50352),
	(232, 0, -50352),
	(233, 0, -50352),
	(234, 0, -50352),
	(235, 0, -50352),
	(236, 0, -50352),
	(237, 0, -50352),
	(238, 0, -50352),
	(86, 0, -50351),
	(88, 0, -50351),
	(90, 0, -50351),
	(91, 0, -50351),
	(92, 0, -50351),
	(93, 0, -50351),
	(94, 0, -50351),
	(95, 0, -50351),
	(96, 0, -50351),
	(97, 0, -50351),
	(98, 0, -50351),
	(99, 0, -50351),
	(100, 0, -50351),
	(101, 0, -50351),
	(102, 0, -50351),
	(103, 0, -50351),
	(104, 0, -50351),
	(205, 0, -50351),
	(207, 0, -50351),
	(209, 0, -50351),
	(210, 0, -50351),
	(211, 0, -50351),
	(212, 0, -50351),
	(213, 0, -50351),
	(214, 0, -50351),
	(215, 0, -50351),
	(216, 0, -50351),
	(217, 0, -50351),
	(218, 0, -50351),
	(219, 0, -50351),
	(220, 0, -50351),
	(221, 0, -50351),
	(222, 0, -50351),
	(223, 0, -50351),
	(47, 0, -50348),
	(49, 0, -50348),
	(51, 0, -50348),
	(53, 0, -50348),
	(166, 0, -50348),
	(168, 0, -50348),
	(170, 0, -50348),
	(172, 0, -50348),
	(46, 0, -50347),
	(48, 0, -50347),
	(50, 0, -50347),
	(52, 0, -50347),
	(165, 0, -50347),
	(167, 0, -50347),
	(169, 0, -50347),
	(171, 0, -50347),
	(41, 0, -50344),
	(43, 0, -50344),
	(45, 0, -50344),
	(160, 0, -50344),
	(162, 0, -50344),
	(164, 0, -50344),
	(40, 0, -50343),
	(42, 0, -50343),
	(44, 0, -50343),
	(159, 0, -50343),
	(161, 0, -50343),
	(163, 0, -50343),
	(35, 0, -50342),
	(37, 0, -50342),
	(39, 0, -50342),
	(154, 0, -50342),
	(156, 0, -50342),
	(158, 0, -50342),
	(34, 0, -50341),
	(36, 0, -50341),
	(38, 0, -50341),
	(153, 0, -50341),
	(155, 0, -50341),
	(157, 0, -50341),
	(31, 0, -50338),
	(33, 0, -50338),
	(150, 0, -50338),
	(152, 0, -50338),
	(30, 0, -50337),
	(32, 0, -50337),
	(149, 0, -50337),
	(151, 0, -50337),
	(23, 0, -50336),
	(142, 0, -50336),
	(22, 0, -50319),
	(141, 0, -50319),
	(239, 0, -50304),
	(242, 0, -50304),
	(260, 0, -50304),
	(281, 0, -50304),
	(26, 0, -50222),
	(145, 0, -50222),
	(27, 0, -50217),
	(146, 0, -50217),
	(66, 0, -50163),
	(67, 0, -50163),
	(68, 0, -50163),
	(69, 0, -50163),
	(185, 0, -50163),
	(186, 0, -50163),
	(187, 0, -50163),
	(188, 0, -50163),
	(64, 0, -50079),
	(65, 0, -50079),
	(183, 0, -50079),
	(184, 0, -50079),
	(29, 0, -50078),
	(148, 0, -50078),
	(4, 0, -50077),
	(123, 0, -50077),
	(1, 0, -50073),
	(120, 0, -50073),
	(28, 0, -50022),
	(147, 0, -50022),
	(243, 0, -50022),
	(264, 0, -50022),
	(61, 0, -50003),
	(63, 0, -50003),
	(180, 0, -50003),
	(182, 0, -50003),
	(60, 0, -50002),
	(62, 0, -50002),
	(179, 0, -50002),
	(181, 0, -50002),
	(24, 0, -8),
	(143, 0, -8),
	(3, 0, -7),
	(122, 0, -7),
	(2, 0, -5),
	(121, 0, -5),
	(5, 0, 10881),
	(124, 0, 10881);
/*!40000 ALTER TABLE `pwo_withe` ENABLE KEYS */;

-- Dumping structure for table emcor.pww
CREATE TABLE IF NOT EXISTS `pww` (
  `pww_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Matavimo taškų prietaisų konfigūracinių parametrų keitimo apribojimo identifikatorius',
  `gr_id` int(10) unsigned DEFAULT NULL,
  `witheset_id` int(10) unsigned DEFAULT NULL,
  `src_type_id` int(10) DEFAULT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `ug_id` mediumint(8) unsigned DEFAULT NULL,
  `pww_desc` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Matavimo taškų prietaisų konfigūracinių parametrų keitimo apribojimo aprašymas',
  PRIMARY KEY (`pww_id`),
  KEY `pww_gr_i` (`gr_id`),
  KEY `pww_src_type_i` (`src_type_id`),
  KEY `pww_ug_i` (`ug_id`),
  KEY `pww_witheset_i` (`witheset_id`),
  CONSTRAINT `pww_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`),
  CONSTRAINT `pww_src_type_fk` FOREIGN KEY (`src_type_id`) REFERENCES `src_type` (`src_type_id`),
  CONSTRAINT `pww_ug_fk` FOREIGN KEY (`ug_id`) REFERENCES `ug` (`ug_id`),
  CONSTRAINT `pww_witheset_fk` FOREIGN KEY (`witheset_id`) REFERENCES `witheset` (`witheset_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimo taškų prietaisų konfigūracinių parametrų keitimo apribojimai';

-- Dumping data for table emcor.pww: ~0 rows (approximately)
/*!40000 ALTER TABLE `pww` DISABLE KEYS */;
/*!40000 ALTER TABLE `pww` ENABLE KEYS */;

-- Dumping structure for table emcor.pw_buf
CREATE TABLE IF NOT EXISTS `pw_buf` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `pw_v` varbinary(1024) DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų reikšmė',
  `pw_rt` datetime DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `pw_t` datetime(3) NOT NULL,
  `req_from` datetime DEFAULT NULL,
  `req_to` datetime DEFAULT NULL,
  `req_withe_id` mediumint(8) unsigned DEFAULT NULL,
  PRIMARY KEY (`point_id`,`withe_id`,`pw_t`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Tarpinė lentelė matavimo taškų nuskaitytoms duomenų vytelėms';

-- Dumping data for table emcor.pw_buf: ~0 rows (approximately)
/*!40000 ALTER TABLE `pw_buf` DISABLE KEYS */;
/*!40000 ALTER TABLE `pw_buf` ENABLE KEYS */;

-- Dumping structure for table emcor.pw_data
CREATE TABLE IF NOT EXISTS `pw_data` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `pw_t` datetime(3) NOT NULL COMMENT 'Matavimo taško vytelės duomenų laikas',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `pw_v` varbinary(1024) DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų reikšmė',
  `pw_rt` datetime DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  PRIMARY KEY (`point_id`,`withe_id`,`pw_t`),
  KEY `pw_data_db_time_i` (`db_time`),
  KEY `pw_data_point_i` (`point_id`,`pw_t`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškų vytelių duomenys'
 PARTITION BY RANGE (
    to_days(pw_t))
(PARTITION par_189912 VALUES LESS THAN (693961) ENGINE = InnoDB,
 PARTITION par_201701 VALUES LESS THAN (736726) ENGINE = InnoDB,
 PARTITION par_201702 VALUES LESS THAN (736754) ENGINE = InnoDB,
 PARTITION par_201703 VALUES LESS THAN (736785) ENGINE = InnoDB,
 PARTITION par_201704 VALUES LESS THAN (736815) ENGINE = InnoDB,
 PARTITION par_201705 VALUES LESS THAN (736846) ENGINE = InnoDB);

-- Dumping data for table emcor.pw_data: ~6 rows (approximately)
/*!40000 ALTER TABLE `pw_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `pw_data` ENABLE KEYS */;

-- Dumping structure for table emcor.pw_data_nv
CREATE TABLE IF NOT EXISTS `pw_data_nv` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `pw_t` datetime(3) NOT NULL COMMENT 'Matavimo taško vytelės duomenų laikas',
  `db_time` datetime NOT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `pw_v` varbinary(1024) DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų reikšmė',
  `pw_rt` datetime DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  PRIMARY KEY (`point_id`,`withe_id`,`pw_t`,`db_time`),
  KEY `pw_data_nv_db_time_i` (`db_time`),
  KEY `pw_data_nv_sep_i` (`sep_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškų vytelių negaliojantys duomenys'
 PARTITION BY RANGE (
    to_days(pw_t))
(PARTITION par_201701 VALUES LESS THAN (736726) ENGINE = InnoDB,
 PARTITION par_201702 VALUES LESS THAN (736754) ENGINE = InnoDB,
 PARTITION par_201703 VALUES LESS THAN (736785) ENGINE = InnoDB,
 PARTITION par_201704 VALUES LESS THAN (736815) ENGINE = InnoDB,
 PARTITION par_201705 VALUES LESS THAN (736846) ENGINE = InnoDB);

-- Dumping data for table emcor.pw_data_nv: ~5 rows (approximately)
/*!40000 ALTER TABLE `pw_data_nv` DISABLE KEYS */;
/*!40000 ALTER TABLE `pw_data_nv` ENABLE KEYS */;

-- Dumping structure for table emcor.pw_mbuf
CREATE TABLE IF NOT EXISTS `pw_mbuf` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `enr` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus elemento numeris',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `pw_v` varbinary(1024) DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų reikšmė',
  `pw_rt` datetime DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  PRIMARY KEY (`point_id`,`withe_id`,`ind1`,`ind2`,`ind3`,`enr`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Tarpinė lentelė matavimo taškų prietaisų konfigūraciniams masyviniams parametrams';

-- Dumping data for table emcor.pw_mbuf: ~0 rows (approximately)
/*!40000 ALTER TABLE `pw_mbuf` DISABLE KEYS */;
/*!40000 ALTER TABLE `pw_mbuf` ENABLE KEYS */;

-- Dumping structure for table emcor.pw_msetting
CREATE TABLE IF NOT EXISTS `pw_msetting` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `enr` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus elemento numeris',
  `pw_t` datetime(3) NOT NULL COMMENT 'Matavimo taško vytelės duomenų laikas',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `pw_v` varbinary(1024) DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų reikšmė',
  `pw_rt` datetime DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `pw_last_rt` datetime DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų paskutinio nuskaitymo laikas',
  `user_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Vartotojo identifikatorius',
  `pck_last_t` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės paskutinio duomenų nuskaitymo paketo laiko žymė',
  PRIMARY KEY (`point_id`,`withe_id`,`ind1`,`ind2`,`ind3`,`enr`),
  KEY `pw_msetting_db_time_i` (`db_time`),
  KEY `pw_msetting_sep_i` (`sep_id`),
  KEY `pw_msetting_user_i` (`user_id`),
  CONSTRAINT `pw_msetting_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `pw_msetting_sep_fk` FOREIGN KEY (`sep_id`) REFERENCES `sep` (`sep_id`) ON DELETE CASCADE,
  CONSTRAINT `pw_msetting_users_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškų prietaisų konfigūracinių masyvinių parametrų duomenys';

-- Dumping data for table emcor.pw_msetting: ~0 rows (approximately)
/*!40000 ALTER TABLE `pw_msetting` DISABLE KEYS */;
/*!40000 ALTER TABLE `pw_msetting` ENABLE KEYS */;

-- Dumping structure for table emcor.pw_msetting_history
CREATE TABLE IF NOT EXISTS `pw_msetting_history` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `enr` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus elemento numeris',
  `pw_t` datetime(3) NOT NULL COMMENT 'Matavimo taško vytelės duomenų laikas',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `pw_v` varbinary(1024) DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų reikšmė',
  `pw_rt` datetime DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `pw_last_rt` datetime DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų paskutinio nuskaitymo laikas',
  `user_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Vartotojo identifikatorius',
  `pck_last_t` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės paskutinio duomenų nuskaitymo paketo laiko žymė',
  PRIMARY KEY (`point_id`,`withe_id`,`ind1`,`ind2`,`ind3`,`enr`,`pw_t`),
  KEY `pw_msetting_history_db_time_i` (`db_time`),
  KEY `pw_msetting_history_point_i` (`point_id`,`pw_t`),
  KEY `pw_msetting_history_pw_t_i` (`pw_t`),
  KEY `pw_msetting_history_sep_i` (`sep_id`),
  KEY `pw_msetting_history_user_i` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškų prietaisų konfigūracinių masyvinių parametrų istoriniai duomenys'
 PARTITION BY RANGE (
    to_days(pw_t))
(PARTITION par_189912 VALUES LESS THAN (693961) ENGINE = InnoDB,
 PARTITION par_201701 VALUES LESS THAN (736726) ENGINE = InnoDB,
 PARTITION par_201702 VALUES LESS THAN (736754) ENGINE = InnoDB,
 PARTITION par_201703 VALUES LESS THAN (736785) ENGINE = InnoDB,
 PARTITION par_201704 VALUES LESS THAN (736815) ENGINE = InnoDB,
 PARTITION par_201705 VALUES LESS THAN (736846) ENGINE = InnoDB);

-- Dumping data for table emcor.pw_msetting_history: ~6 rows (approximately)
/*!40000 ALTER TABLE `pw_msetting_history` DISABLE KEYS */;
/*!40000 ALTER TABLE `pw_msetting_history` ENABLE KEYS */;

-- Dumping structure for table emcor.pw_setting
CREATE TABLE IF NOT EXISTS `pw_setting` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `pw_t` datetime(3) NOT NULL COMMENT 'Matavimo taško vytelės duomenų laikas',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `pw_v` varbinary(1024) DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų reikšmė',
  `pw_rt` datetime DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `pw_last_rt` datetime DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų paskutinio nuskaitymo laikas',
  `user_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Vartotojo identifikatorius',
  `pck_last_t` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės paskutinio duomenų nuskaitymo paketo laiko žymė',
  PRIMARY KEY (`point_id`,`withe_id`),
  KEY `pw_setting_db_time_i` (`db_time`),
  KEY `pw_setting_sep_i` (`sep_id`),
  KEY `pw_setting_user_i` (`user_id`),
  CONSTRAINT `pw_setting_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `pw_setting_sep_fk` FOREIGN KEY (`sep_id`) REFERENCES `sep` (`sep_id`) ON DELETE CASCADE,
  CONSTRAINT `pw_setting_users_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškų prietaisų konfigūracinių parametrų duomenys';

-- Dumping data for table emcor.pw_setting: ~0 rows (approximately)
/*!40000 ALTER TABLE `pw_setting` DISABLE KEYS */;
/*!40000 ALTER TABLE `pw_setting` ENABLE KEYS */;

-- Dumping structure for table emcor.pw_setting_history
CREATE TABLE IF NOT EXISTS `pw_setting_history` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `pw_t` datetime(3) NOT NULL COMMENT 'Matavimo taško vytelės duomenų laikas',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `pw_v` varbinary(1024) DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų reikšmė',
  `pw_rt` datetime DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `pw_last_rt` datetime DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų paskutinio nuskaitymo laikas',
  `user_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Vartotojo identifikatorius',
  `pck_last_t` datetime DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės paskutinio duomenų nuskaitymo paketo laiko žymė',
  PRIMARY KEY (`point_id`,`withe_id`,`pw_t`),
  KEY `pw_setting_history_db_time_i` (`db_time`),
  KEY `pw_setting_history_point_i` (`point_id`,`pw_t`),
  KEY `pw_setting_history_pw_t_i` (`pw_t`),
  KEY `pw_setting_history_sep_i` (`sep_id`),
  KEY `pw_setting_history_user_i` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškų prietaisų konfigūracinių parametrų istoriniai duomenys'
 PARTITION BY RANGE (
    to_days(pw_t))
(PARTITION par_189912 VALUES LESS THAN (693961) ENGINE = InnoDB,
 PARTITION par_201701 VALUES LESS THAN (736726) ENGINE = InnoDB,
 PARTITION par_201702 VALUES LESS THAN (736754) ENGINE = InnoDB,
 PARTITION par_201703 VALUES LESS THAN (736785) ENGINE = InnoDB,
 PARTITION par_201704 VALUES LESS THAN (736815) ENGINE = InnoDB,
 PARTITION par_201705 VALUES LESS THAN (736846) ENGINE = InnoDB);

-- Dumping data for table emcor.pw_setting_history: ~6 rows (approximately)
/*!40000 ALTER TABLE `pw_setting_history` DISABLE KEYS */;
/*!40000 ALTER TABLE `pw_setting_history` ENABLE KEYS */;

-- Dumping structure for table emcor.pw_state
CREATE TABLE IF NOT EXISTS `pw_state` (
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `pw_t` datetime(3) NOT NULL COMMENT 'Matavimo taško vytelės duomenų laikas',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `pw_v` varbinary(1024) DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų reikšmė',
  `pw_rt` datetime DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  PRIMARY KEY (`point_id`,`withe_id`),
  KEY `pw_state_db_time_i` (`db_time`),
  KEY `pw_state_point_i` (`point_id`,`pw_t`),
  CONSTRAINT `pw_state_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimo taškų vytelių duomenys';

-- Dumping data for table emcor.pw_state: ~0 rows (approximately)
/*!40000 ALTER TABLE `pw_state` DISABLE KEYS */;
/*!40000 ALTER TABLE `pw_state` ENABLE KEYS */;

-- Dumping structure for table emcor.rc
CREATE TABLE IF NOT EXISTS `rc` (
  `rc_id` tinyint(3) unsigned NOT NULL COMMENT 'Užklausų priežasties identifikatorius',
  `rc_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Užklausų priežasties kodas',
  `rc_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Užklausų priežasties pavadinimas',
  `rc_in` tinyint(1) NOT NULL COMMENT 'Nuskaitymo užklausų požymis',
  `rc_manual` tinyint(1) NOT NULL COMMENT 'Rankinio iniciavimo užklausų požymis',
  `req_type_code` varchar(20) COLLATE utf8_bin DEFAULT NULL COMMENT 'Užklausų tipo kodas',
  PRIMARY KEY (`rc_id`),
  UNIQUE KEY `rc_code_u` (`rc_code`),
  UNIQUE KEY `rc_name_u` (`rc_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Užklausų priežastys';

-- Dumping data for table emcor.rc: ~14 rows (approximately)
/*!40000 ALTER TABLE `rc` DISABLE KEYS */;
INSERT INTO `rc` (`rc_id`, `rc_code`, `rc_name`, `rc_in`, `rc_manual`, `req_type_code`) VALUES
	(2, 'READ_SCHEDULED', 'Automatinis duomenų nuskaitymas iš prietaiso', 1, 0, 'FON'),
	(3, 'SHOW_BY_DEMAND', 'Vartotojo inicijuota peržiūra', 1, 1, 'SHOW'),
	(4, 'HOLES_FILL_SCHEDULED', 'Skylių pildymas', 1, 0, 'HOLES'),
	(5, 'HOLES_FILL_BY_DEMAND', 'Vartotojo inicijuotas skylių pildymas', 1, 1, 'AUTO_ARJ'),
	(6, 'WRITE_AUTO', 'Automatinis duomenų įrašymas į prietaisą', 0, 0, 'PARAM_Programm'),
	(7, 'WRITE_BY_DEMAND', 'Vartotojo inicijuotas duomenų įrašymas į prietaisą', 0, 1, 'PARAM'),
	(8, 'FORCED_READ_BY_DEMAND', 'Vartotojo inicijuotas priverstinis duomenų perrinkimas iš prietaiso', 1, 1, 'ARJ'),
	(9, 'READ_BY_ALERT', 'Duomenų nuskaitymas pagal signalą iš prietaiso', 1, 0, 'DEVICE'),
	(10, 'FREQUENT_READ', 'Realaus laiko duomenų nuskaitymas iš prietaiso', 1, 0, 'SCADA'),
	(11, 'READ_SCHEDULED_FOR_SERVER_OPERATION', 'Periodinis nuskaitymas, susijęs su serverio operacijomis', 1, 0, '4SERVER'),
	(14, 'RECENT_HOLES_FILL_SCHEDULED', 'Nesenų skylių pildymas', 1, 0, 'RECENT_HOLES'),
	(15, 'READ_BY_DEMAND', 'Vartotojo inicijuotas įprastinis duomenų perrinkimas iš prietaiso', 1, 1, 'ARJ'),
	(16, 'HOLES_FILL_BY_EVENT', 'Skylių pildymas pagal įvykį', 1, 0, 'HOLES_BY_EV'),
	(17, 'READ_BY_EVENT', 'Nuskaitymas pagal įvykį', 1, 0, 'READ_BY_EVENT');
/*!40000 ALTER TABLE `rc` ENABLE KEYS */;

-- Dumping structure for table emcor.rel
CREATE TABLE IF NOT EXISTS `rel` (
  `rel_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Sąryšio identifikatorius',
  `rel_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Sąryšių tipo identifikatorius',
  `rel_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Sąryšio naudojimo požymis',
  PRIMARY KEY (`rel_id`),
  KEY `rel_rel_type_i` (`rel_type_id`),
  CONSTRAINT `rel_rel_type_fk` FOREIGN KEY (`rel_type_id`) REFERENCES `rel_type` (`rel_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Sąryšiai';

-- Dumping data for table emcor.rel: ~0 rows (approximately)
/*!40000 ALTER TABLE `rel` DISABLE KEYS */;
/*!40000 ALTER TABLE `rel` ENABLE KEYS */;

-- Dumping structure for table emcor.rel_epty
CREATE TABLE IF NOT EXISTS `rel_epty` (
  `rel_id` int(10) unsigned NOT NULL COMMENT 'Sąryšio identifikatorius',
  `epty_id` mediumint(8) unsigned NOT NULL COMMENT 'Sąryšių savybės identifikatorius',
  `epty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Sąryšio savybės reikšmė',
  PRIMARY KEY (`rel_id`,`epty_id`),
  KEY `rel_epty_epty_i` (`epty_id`),
  CONSTRAINT `rel_epty_epty_fk` FOREIGN KEY (`epty_id`) REFERENCES `epty` (`epty_id`),
  CONSTRAINT `rel_epty_rel_fk` FOREIGN KEY (`rel_id`) REFERENCES `rel` (`rel_id`) ON DELETE CASCADE,
  CONSTRAINT `REL_EPTY_SYMBOL_CHECK` CHECK (nullif(regexp_replace(`epty_value`,'([[:print:]])+',''),'') is null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Sąryšių savybės';

-- Dumping data for table emcor.rel_epty: ~0 rows (approximately)
/*!40000 ALTER TABLE `rel_epty` DISABLE KEYS */;
/*!40000 ALTER TABLE `rel_epty` ENABLE KEYS */;

-- Dumping structure for table emcor.rel_pos
CREATE TABLE IF NOT EXISTS `rel_pos` (
  `rel_id` int(10) unsigned NOT NULL COMMENT 'Sąryšio identifikatorius',
  `pos_nr` smallint(5) unsigned NOT NULL COMMENT 'Pozicijos numeris',
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  PRIMARY KEY (`rel_id`,`pos_nr`),
  KEY `rel_pos_point_i` (`point_id`),
  CONSTRAINT `rel_pos_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `rel_pos_rel_fk` FOREIGN KEY (`rel_id`) REFERENCES `rel` (`rel_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Sąryšių pozicijos';

-- Dumping data for table emcor.rel_pos: ~0 rows (approximately)
/*!40000 ALTER TABLE `rel_pos` DISABLE KEYS */;
/*!40000 ALTER TABLE `rel_pos` ENABLE KEYS */;

-- Dumping structure for table emcor.rel_type
CREATE TABLE IF NOT EXISTS `rel_type` (
  `rel_type_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Sąryšių tipo identifikatorius',
  `rel_type_code` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'Sąryšių tipo kodas',
  `rel_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Sąryšių tipo pavadinimas',
  PRIMARY KEY (`rel_type_id`),
  UNIQUE KEY `rel_type_code_u` (`rel_type_code`),
  UNIQUE KEY `rel_type_name_u` (`rel_type_name`)
) ENGINE=InnoDB AUTO_INCREMENT=53 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Sąryšių tipai';

-- Dumping data for table emcor.rel_type: ~7 rows (approximately)
/*!40000 ALTER TABLE `rel_type` DISABLE KEYS */;
INSERT INTO `rel_type` (`rel_type_id`, `rel_type_code`, `rel_type_name`) VALUES
	(46, 'DELIVERY_POINT_TO_2_INLETS_WITH_TRANSFORMERS', 'Tiekimo taškas už 2 įvadų su transformatoriais'),
	(47, 'DELIVERY_POINT_TO_2_INLETS_WITH_TRAN_2ND_LINE_LOSS', 'Tiekimo taškas už 2 įvadų su transformatoriais, 2 įvadas nutolęs per liniją'),
	(48, 'DELIVERY_POINT_TO_TRANSFORMER_AND_2_INLETS', 'Tiekimo taškas už 2 įvadų ir transformatoriaus'),
	(49, 'DELIVERY_POINT_TO_MS_POINT_CONSIDERING_TRANSFORMER', 'Tiekimo taškas už transformatoriaus'),
	(50, 'DELIVERY_POINT_TO_MS_POINT_CONSIDERING_LINE_LOSS', 'Tiekimo taškas nutolęs nuo apskaitos taško per liniją'),
	(51, 'DELIVERY_POINT_TO_2_INLETS_WITH_TRAN_AND_LINE_LOSS', 'Tiekimo taškas nutolęs per liniją, už 2 įvadų su transformatoriais'),
	(52, 'DELIVERY_POINT_TO_MS_POINT_WITH_TRAN_AND_LINE_LOSS', 'Tiekimo taškas nutolęs nuo apskaitos taško per liniją su transformatoriumi');
/*!40000 ALTER TABLE `rel_type` ENABLE KEYS */;

-- Dumping structure for table emcor.rel_type_epty
CREATE TABLE IF NOT EXISTS `rel_type_epty` (
  `rel_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Sąryšių tipo identifikatorius',
  `epty_id` mediumint(8) unsigned NOT NULL COMMENT 'Sąryšių savybės identifikatorius',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  `epty_nr` smallint(5) unsigned DEFAULT NULL COMMENT 'Sąryšių savybės eilės numeris',
  PRIMARY KEY (`rel_type_id`,`epty_id`),
  KEY `rel_type_epty_enum_i` (`enum_id`),
  KEY `rel_type_epty_epty_i` (`epty_id`),
  CONSTRAINT `rel_type_epty_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`),
  CONSTRAINT `rel_type_epty_epty_fk` FOREIGN KEY (`epty_id`) REFERENCES `epty` (`epty_id`) ON DELETE CASCADE,
  CONSTRAINT `rel_type_epty_rel_type_fk` FOREIGN KEY (`rel_type_id`) REFERENCES `rel_type` (`rel_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nurodyto tipo sąryšių galimos savybės';

-- Dumping data for table emcor.rel_type_epty: ~50 rows (approximately)
/*!40000 ALTER TABLE `rel_type_epty` DISABLE KEYS */;
INSERT INTO `rel_type_epty` (`rel_type_id`, `epty_id`, `enum_id`, `epty_nr`) VALUES
	(46, 34, NULL, NULL),
	(46, 35, NULL, NULL),
	(46, 36, NULL, NULL),
	(46, 37, NULL, NULL),
	(46, 38, NULL, NULL),
	(46, 39, NULL, NULL),
	(46, 40, NULL, NULL),
	(47, 31, NULL, NULL),
	(47, 34, NULL, NULL),
	(47, 35, NULL, NULL),
	(47, 36, NULL, NULL),
	(47, 37, NULL, NULL),
	(47, 38, NULL, NULL),
	(47, 39, NULL, NULL),
	(47, 40, NULL, NULL),
	(47, 42, NULL, NULL),
	(47, 44, NULL, NULL),
	(47, 46, NULL, NULL),
	(47, 48, NULL, NULL),
	(48, 28, NULL, NULL),
	(48, 29, NULL, NULL),
	(48, 30, NULL, NULL),
	(49, 28, NULL, NULL),
	(49, 29, NULL, NULL),
	(49, 30, NULL, NULL),
	(50, 31, NULL, NULL),
	(50, 32, NULL, NULL),
	(50, 33, NULL, NULL),
	(50, 34, NULL, NULL),
	(51, 31, NULL, NULL),
	(51, 32, NULL, NULL),
	(51, 33, NULL, NULL),
	(51, 35, NULL, NULL),
	(51, 36, NULL, NULL),
	(51, 37, NULL, NULL),
	(51, 38, NULL, NULL),
	(51, 39, NULL, NULL),
	(51, 40, NULL, NULL),
	(51, 41, NULL, NULL),
	(51, 42, NULL, NULL),
	(51, 43, NULL, NULL),
	(51, 44, NULL, NULL),
	(52, 26, NULL, NULL),
	(52, 27, NULL, NULL),
	(52, 28, NULL, NULL),
	(52, 29, NULL, NULL),
	(52, 30, NULL, NULL),
	(52, 31, NULL, NULL),
	(52, 32, NULL, NULL),
	(52, 33, NULL, NULL);
/*!40000 ALTER TABLE `rel_type_epty` ENABLE KEYS */;

-- Dumping structure for table emcor.rel_type_pos
CREATE TABLE IF NOT EXISTS `rel_type_pos` (
  `rel_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Sąryšių tipo identifikatorius',
  `pos_nr` smallint(5) unsigned NOT NULL COMMENT 'Pozicijos numeris',
  `pos_code` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'Pozicijos kodas',
  `pos_desc` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Pozicijos aprašymas',
  PRIMARY KEY (`rel_type_id`,`pos_nr`),
  UNIQUE KEY `rel_type_pos_code_u` (`rel_type_id`,`pos_code`),
  CONSTRAINT `rel_type_pos_rel_type_fk` FOREIGN KEY (`rel_type_id`) REFERENCES `rel_type` (`rel_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Sąryšių tipo pozicijos';

-- Dumping data for table emcor.rel_type_pos: ~18 rows (approximately)
/*!40000 ALTER TABLE `rel_type_pos` DISABLE KEYS */;
INSERT INTO `rel_type_pos` (`rel_type_id`, `pos_nr`, `pos_code`, `pos_desc`) VALUES
	(46, 1, 'TARGET', 'Tiekimo taškas'),
	(46, 2, 'INLET1', 'Įvadas 1'),
	(46, 3, 'INLET2', 'Įvadas 2'),
	(47, 1, 'TARGET', 'Tiekimo taškas'),
	(47, 2, 'INLET1', 'Įvadas 1'),
	(47, 3, 'INLET2', 'Įvadas 2'),
	(48, 1, 'TARGET', 'Tiekimo taškas'),
	(48, 2, 'INLET1', 'Įvadas 1'),
	(48, 3, 'INLET2', 'Įvadas 2'),
	(49, 1, 'TARGET', 'Tiekimo taškas'),
	(49, 2, 'MS_POINT', 'Apskaitos taškas'),
	(50, 1, 'TARGET', 'Tiekimo taškas'),
	(50, 2, 'MS_POINT', 'Apskaitos taškas'),
	(51, 1, 'TARGET', 'Tiekimo taškas'),
	(51, 2, 'INLET1', 'Įvadas 1'),
	(51, 3, 'INLET2', 'Įvadas 2'),
	(52, 1, 'TARGET', 'Tiekimo taškas'),
	(52, 2, 'MS_POINT', 'Apskaitos taškas');
/*!40000 ALTER TABLE `rel_type_pos` ENABLE KEYS */;

-- Dumping structure for table emcor.rmdr_gr
CREATE TABLE IF NOT EXISTS `rmdr_gr` (
  `da` date NOT NULL COMMENT 'Diena',
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  `ml_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo linijos identifikatorius',
  `rmdr_val` double NOT NULL COMMENT 'Perkeliama likučio reikšmė',
  `db_time` datetime DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  PRIMARY KEY (`da`,`gr_id`,`ml_id`),
  KEY `rmdr_gr_gr_i` (`gr_id`),
  CONSTRAINT `rmdr_gr_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Grupių matavimų apvalinimų likučiai';

-- Dumping data for table emcor.rmdr_gr: ~0 rows (approximately)
/*!40000 ALTER TABLE `rmdr_gr` DISABLE KEYS */;
/*!40000 ALTER TABLE `rmdr_gr` ENABLE KEYS */;

-- Dumping structure for table emcor.rmdr_point
CREATE TABLE IF NOT EXISTS `rmdr_point` (
  `da` date NOT NULL COMMENT 'Diena',
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `ml_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo linijos identifikatorius',
  `rmdr_val` double NOT NULL COMMENT 'Perkeliama likučio reikšmė',
  `db_time` datetime DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  PRIMARY KEY (`da`,`point_id`,`ml_id`),
  KEY `rmdr_point_point_i` (`point_id`),
  CONSTRAINT `rmdr_point_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Taškų matavimų apvalinimų likučiai';

-- Dumping data for table emcor.rmdr_point: ~0 rows (approximately)
/*!40000 ALTER TABLE `rmdr_point` DISABLE KEYS */;
/*!40000 ALTER TABLE `rmdr_point` ENABLE KEYS */;

-- Dumping structure for table emcor.rodo
CREATE TABLE IF NOT EXISTS `rodo` (
  `rodo_id` int(10) unsigned NOT NULL COMMENT 'Užsakymo ID',
  `rodo_nr` mediumint(8) unsigned NOT NULL COMMENT 'Užsakymo elemento numeris',
  `db_time` datetime NOT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `user_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojo identifikatorius',
  `rc_id` tinyint(3) unsigned NOT NULL COMMENT 'Užklausų priežasties identifikatorius',
  `di_id` int(10) unsigned NOT NULL COMMENT 'Nuskaitomų duomenų elemento identifikatorius',
  `rodo_bt` datetime DEFAULT NULL COMMENT 'Duomenų laiko intervalo pradžia',
  `rodo_et` datetime DEFAULT NULL COMMENT 'Duomenų laiko intervalo pabaiga',
  `src_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `sep_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `write2device` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo reikšmė',
  `withe_id` mediumint(8) DEFAULT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `enr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus elemento numeris',
  PRIMARY KEY (`rodo_id`,`rodo_nr`,`db_time`),
  KEY `rodo1_db_time_i` (`db_time`),
  KEY `rodo1_di_i` (`di_id`,`db_time`),
  KEY `rodo1_sep_i` (`sep_id`),
  KEY `rodo1_user_i` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Nuskaitymų pagal pareikalavimą užsakymai'
 PARTITION BY RANGE (
   to_days(db_time))
(PARTITION par_201701 VALUES LESS THAN (736695) ENGINE = InnoDB,
 PARTITION par_201702 VALUES LESS THAN (736702) ENGINE = InnoDB,
 PARTITION par_201703 VALUES LESS THAN (736709) ENGINE = InnoDB);

-- Dumping data for table emcor.rodo: ~3 rows (approximately)
/*!40000 ALTER TABLE `rodo` DISABLE KEYS */;
/*!40000 ALTER TABLE `rodo` ENABLE KEYS */;

-- Dumping structure for table emcor.rodo_opty
CREATE TABLE IF NOT EXISTS `rodo_opty` (
  `rodo_id` int(10) unsigned NOT NULL COMMENT 'Užsakymo ID',
  `rodo_nr` mediumint(8) unsigned NOT NULL COMMENT 'Užsakymo elemento numeris',
  `db_time` datetime NOT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`rodo_id`,`rodo_nr`,`db_time`,`opty_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Nuskaitymų pagal pareikalavimą užsakymų parametrai'
 PARTITION BY RANGE (
   to_days(db_time))
(PARTITION par_201701 VALUES LESS THAN (736695) ENGINE = InnoDB,
 PARTITION par_201702 VALUES LESS THAN (736702) ENGINE = InnoDB,
 PARTITION par_201703 VALUES LESS THAN (736709) ENGINE = InnoDB);

-- Dumping data for table emcor.rodo_opty: ~3 rows (approximately)
/*!40000 ALTER TABLE `rodo_opty` DISABLE KEYS */;
/*!40000 ALTER TABLE `rodo_opty` ENABLE KEYS */;

-- Dumping structure for table emcor.rp
CREATE TABLE IF NOT EXISTS `rp` (
  `rp_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Ataskaitos identifikatorius',
  `rp_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Ataskaitos tipo identifikatorius',
  `user_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojo identifikatorius',
  `rp_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ataskaitos pavadinimas',
  `rp_public` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Viešos ataskaitos požymis',
  `rp_description` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Ataskaitos aprašymas',
  `rpf_id` mediumint(8) unsigned NOT NULL DEFAULT 1 COMMENT 'Ataskaitos formato identifikatorius',
  `rp_log_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Įrašų apie automatizuotą ataskaitą registravimo žurnale požymis',
  `rp_formula` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Formulių ataskaitos požymis',
  PRIMARY KEY (`rp_id`),
  UNIQUE KEY `rp_name_u` (`rp_name`),
  KEY `rp_rpf_i` (`rpf_id`),
  KEY `rp_rp_type_i` (`rp_type_id`),
  KEY `rp_user_i` (`user_id`),
  CONSTRAINT `rp_rp_type_fk` FOREIGN KEY (`rp_type_id`) REFERENCES `rp_type` (`rp_type_id`),
  CONSTRAINT `rp_rpf_fk` FOREIGN KEY (`rpf_id`) REFERENCES `rpf` (`rpf_id`),
  CONSTRAINT `rp_user_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=64 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ataskaitos ';

-- Dumping data for table emcor.rp: ~43 rows (approximately)
/*!40000 ALTER TABLE `rp` DISABLE KEYS */;
INSERT INTO `rp` (`rp_id`, `rp_type_id`, `user_id`, `rp_name`, `rp_public`, `rp_description`, `rpf_id`, `rp_log_enabled`, `rp_formula`) VALUES
	(1, 1, 0, 'Užblokuoti sistemos vartotojai', 0, NULL, 2, 0, 0),
	(6, 6, 0, 'DB sesijų monitoringas', 0, NULL, 1, 0, 0),
	(11, 1, 0, 'Nesekmingų bandymų prisijungti prie sistemos', 0, NULL, 1, 0, 0),
	(12, 1, 0, 'Vartotojų sesijų audito įjungimas', 0, NULL, 2, 0, 0),
	(13, 1, 0, 'Vartotojų sesijų audito išjungimas', 0, NULL, 2, 0, 0),
	(14, 1, 0, 'Vatrotojų sesijų informacijos trynimas', 0, NULL, 2, 0, 0),
	(16, 11, 0, 'Senų duomenų trynimo monitoringas', 0, NULL, 1, 0, 0),
	(17, 12, 0, 'Užimtos EMCOS_IND tablespace vietos procentas', 0, NULL, 1, 0, 0),
	(18, 12, 0, 'Užimtos EMCOS_TAB tablespace vietos procentas', 0, NULL, 1, 0, 0),
	(19, 12, 0, 'Taškų matavimų galiojančių išsaugojimų kiekis per parą', 0, NULL, 1, 0, 0),
	(20, 12, 0, 'Taškų matavimų galiojančių išsaugojimų procentas per parą', 0, NULL, 1, 0, 0),
	(21, 12, 0, 'Turinčių diskretiškumą taškų matavimų išsaugojimų procentas per parą', 0, NULL, 1, 0, 0),
	(22, 12, 0, 'Suvestų apskaitos taškų kiekis', 0, NULL, 1, 0, 0),
	(23, 12, 0, 'Turinčių diskretiškumą taškų matavimų be skylių procentas', 0, NULL, 1, 0, 0),
	(24, 12, 0, 'Ryšio kanalų unikalių sesijų kiekis per parą', 0, NULL, 1, 0, 0),
	(25, 12, 0, 'Ryšio kanalų unikalių sesijų be transporto lygio klaidų procentas per parą', 0, NULL, 1, 0, 0),
	(26, 12, 0, 'Uždarytų taškų procentas per parą', 0, NULL, 1, 0, 0),
	(27, 12, 0, 'Įrašų kiekis taškų matavimų saugotinų nuskaitymų buferyje', 0, NULL, 1, 0, 0),
	(28, 12, 0, 'Įrašų kiekis taškų matavimų nesaugotinų nuskaitymų buferyje', 0, NULL, 1, 0, 0),
	(29, 12, 0, 'Svarbių Oracle pranešimų kiekis įvykių registre per parą', 0, NULL, 1, 0, 0),
	(30, 12, 0, 'Maksimalus eilės dydis per parą', 0, NULL, 1, 0, 0),
	(31, 12, 0, 'Suformuotų automatizuotų ataskaitų kiekis per parą', 0, NULL, 1, 0, 0),
	(32, 12, 0, 'Naudojamų ryšio kanalų kiekis', 0, NULL, 1, 0, 0),
	(33, 12, 0, 'Naudojamų ryšio kanalų, su kuriais yra ryšys, procentas', 0, NULL, 1, 0, 0),
	(34, 12, 0, 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą', 0, NULL, 1, 0, 0),
	(35, 12, 0, 'Turinčių diskretiškumą galiojančių saugotinų nepagerinamų išsaugojimų procentas per parą', 0, NULL, 1, 0, 0),
	(36, 12, 0, 'Neturinčių diskretiškumo galiojančių saugotinų nepagerinamų išsaugojimų procentas per parą', 0, NULL, 1, 0, 0),
	(41, 16, 0, 'Laisvos vietos sekimas EMCOS_IND.', 0, NULL, 1, 0, 0),
	(42, 16, 0, 'Laisvos vietos sekimas EMCOS_TAB.', 0, NULL, 1, 0, 0),
	(46, 12, 0, 'Źīėč÷åńņāī ąāņīģąņčēčšīāąķķūõ ņī÷åź ó÷åņą', 0, NULL, 1, 0, 0),
	(51, 12, 0, 'Beviltiškų taškų procentas', 0, NULL, 1, 0, 0),
	(52, 12, 0, 'Beviltiškų taškų skylių užsakymų eilučių procentas nuo bendro kiekio', 0, NULL, 1, 0, 0),
	(53, 12, 0, 'Beviltiškų skylių užsakymų eilučių kiekis', 0, NULL, 1, 0, 0),
	(54, 12, 0, 'Lentelės PL_DATA apimties procentas nuo visų EMCOS_TAB segmentų', 0, NULL, 1, 0, 0),
	(55, 12, 0, 'Taškų su skylėmis procentas', 0, NULL, 1, 0, 0),
	(56, 12, 0, 'Nuskaitymo taškų, su kuriais nėra ryšio, procentas nuo galiojančių', 0, NULL, 1, 0, 0),
	(57, 12, 0, 'Galiojančių ryšio kanalų be ryšio kiekis', 0, NULL, 1, 0, 0),
	(58, 12, 0, 'Sėkmingai išsiųstų eksporto formų procentas', 0, NULL, 1, 0, 0),
	(59, 12, 0, 'Sėkmingų sugrupuotų užklausų procentas', 0, NULL, 1, 0, 0),
	(60, 12, 0, 'Įvykio registro pranešimų kiekis per parą', 0, NULL, 1, 0, 0),
	(61, 12, 0, 'Bendra EMCOS segmentų apimtis (GB)', 0, NULL, 1, 0, 0),
	(62, 12, 0, 'Negaliojančių rodmenų nuskaitymų lentelės PL_DATA_NV apimtis procentais', 0, NULL, 1, 0, 0),
	(63, 12, 0, 'Įrašų kiekis taškų vytelių buferyje', 0, NULL, 1, 0, 0);
/*!40000 ALTER TABLE `rp` ENABLE KEYS */;

-- Dumping structure for table emcor.rpa
CREATE TABLE IF NOT EXISTS `rpa` (
  `rpa_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Automatizuotos ataskaitos identifikatorius',
  `rp_id` int(10) unsigned NOT NULL COMMENT 'Ataskaitos identifikatorius',
  `rpp_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Automatizuotos ataskaitos protokolo identifikatorius',
  `sch_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Tvarkaraščio identifikatorius',
  `rpa_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Automatizuotos ataskaitos pavadinimas',
  `folder` varchar(200) COLLATE utf8_bin DEFAULT NULL COMMENT 'Automatizuotos ataskaitos katalogas',
  `rpa_enabled` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Automatizuotos ataskaitos galiojimo požymis',
  `rpa_log_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Loginimo požymis',
  `form_if_empty` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Formuoti tuscia ataskaita',
  `rpa_delay_delivery` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Atidėto automatizuotos ataskaitos siuntimo požymis',
  `user_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojo identifikatorius',
  PRIMARY KEY (`rpa_id`),
  UNIQUE KEY `rpa_rp_name_u` (`rpa_name`),
  KEY `rpa_rp_i` (`rp_id`),
  KEY `rpa_rpp_i` (`rpp_id`),
  KEY `rpa_sch_i` (`sch_id`),
  KEY `rpa_user_i` (`user_id`),
  CONSTRAINT `rpa_rp_fk` FOREIGN KEY (`rp_id`) REFERENCES `rp` (`rp_id`) ON DELETE CASCADE,
  CONSTRAINT `rpa_rpp_fk` FOREIGN KEY (`rpp_id`) REFERENCES `rpp` (`rpp_id`),
  CONSTRAINT `rpa_sch_fk` FOREIGN KEY (`sch_id`) REFERENCES `sch` (`sch_id`),
  CONSTRAINT `rpa_user_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=23 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Automatizuotos ataskaitos';

-- Dumping data for table emcor.rpa: ~6 rows (approximately)
/*!40000 ALTER TABLE `rpa` DISABLE KEYS */;
INSERT INTO `rpa` (`rpa_id`, `rp_id`, `rpp_id`, `sch_id`, `rpa_name`, `folder`, `rpa_enabled`, `rpa_log_enabled`, `form_if_empty`, `rpa_delay_delivery`, `user_id`) VALUES
	(1, 1, 1, 42, 'Užblokuoti sistemos vartotojai', NULL, 1, 0, 0, 1, 0),
	(6, 6, 1, 62, 'DB sesijų monitoringas', NULL, 1, 1, 0, 0, 0),
	(11, 14, 1, 43, 'Vatrotojų sesijų informacijos trynimas', NULL, 0, 1, 1, 1, 0),
	(16, 16, 1, 43, 'Senų duomenų trynimo monitoringas', NULL, 1, 1, 0, 0, 0),
	(21, 41, 1, 43, 'Laisvos vietos sekimas EMCOS_IND.', NULL, 1, 1, 0, 0, 0),
	(22, 42, 1, 43, 'Laisvos vietos sekimas EMCOS_TAB.', NULL, 1, 1, 0, 0, 0);
/*!40000 ALTER TABLE `rpa` ENABLE KEYS */;

-- Dumping structure for table emcor.rpapv
CREATE TABLE IF NOT EXISTS `rpapv` (
  `rpapv_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Automatizuotos ataskaitos  užklausos sąlygos identifikatorius',
  `rpa_id` int(10) unsigned NOT NULL COMMENT 'Automatizuotos ataskaitos identifikatorius',
  `rpqf_id` int(10) unsigned NOT NULL COMMENT 'Ataskaitos užklausos sąlygos identifikatorius',
  `rpqf_value` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Užklausos sąlygos reikšmė',
  `rpqf_desc` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Sąlygos aprašymas',
  PRIMARY KEY (`rpapv_id`),
  KEY `rpapv_rpa_i` (`rpa_id`),
  KEY `rpapv_rpqf_i` (`rpqf_id`),
  CONSTRAINT `rpapv_rpa_fk` FOREIGN KEY (`rpa_id`) REFERENCES `rpa` (`rpa_id`) ON DELETE CASCADE,
  CONSTRAINT `rpapv_rpqf_fk` FOREIGN KEY (`rpqf_id`) REFERENCES `rpqf` (`rpqf_id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=13 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Automatizuotos ataskaitos užklausos sąlygos';

-- Dumping data for table emcor.rpapv: ~3 rows (approximately)
/*!40000 ALTER TABLE `rpapv` DISABLE KEYS */;
INSERT INTO `rpapv` (`rpapv_id`, `rpa_id`, `rpqf_id`, `rpqf_value`, `rpqf_desc`) VALUES
	(6, 6, 6, '60', 'Sesijos vykdymo limitas'),
	(7, 11, 11, '30', 'Poslinkis valandomis (trinami irasai, senesni uz nurodyta valandu kieki)'),
	(12, 16, 16, '2', 'Laiko skirtumo limitas, dienų');
/*!40000 ALTER TABLE `rpapv` ENABLE KEYS */;

-- Dumping structure for table emcor.rpaug
CREATE TABLE IF NOT EXISTS `rpaug` (
  `rpa_id` int(10) unsigned NOT NULL COMMENT 'Automatizuotos ataskaitos identifikatorius',
  `ug_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojų grupės identifikatorius',
  PRIMARY KEY (`rpa_id`,`ug_id`),
  KEY `rpaug_ug_i` (`ug_id`),
  CONSTRAINT `rpaug_rpa_fk` FOREIGN KEY (`rpa_id`) REFERENCES `rpa` (`rpa_id`) ON DELETE CASCADE,
  CONSTRAINT `rpaug_ug_fk` FOREIGN KEY (`ug_id`) REFERENCES `ug` (`ug_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Automatizuotų ataskaitų gavėjų grupės';

-- Dumping data for table emcor.rpaug: ~0 rows (approximately)
/*!40000 ALTER TABLE `rpaug` DISABLE KEYS */;
/*!40000 ALTER TABLE `rpaug` ENABLE KEYS */;

-- Dumping structure for table emcor.rpauser
CREATE TABLE IF NOT EXISTS `rpauser` (
  `rpa_id` int(10) unsigned NOT NULL COMMENT 'Automatizuotos ataskaitos identifikatorius',
  `user_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojo identifikatorius',
  PRIMARY KEY (`rpa_id`,`user_id`),
  KEY `rpauser_users_i` (`user_id`),
  CONSTRAINT `rpagr_rpa_fk` FOREIGN KEY (`rpa_id`) REFERENCES `rpa` (`rpa_id`) ON DELETE CASCADE,
  CONSTRAINT `rpauser_users_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Automatizuotų ataskaitų gavėjai';

-- Dumping data for table emcor.rpauser: ~0 rows (approximately)
/*!40000 ALTER TABLE `rpauser` DISABLE KEYS */;
/*!40000 ALTER TABLE `rpauser` ENABLE KEYS */;

-- Dumping structure for table emcor.rpa_rpty
CREATE TABLE IF NOT EXISTS `rpa_rpty` (
  `rpa_id` int(10) unsigned NOT NULL COMMENT 'Automatizuotos ataskaitos identifikatorius',
  `rpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo savybės identifikatorius',
  `rpty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Automatizuotos ataskaitos savybės reikšmė',
  PRIMARY KEY (`rpa_id`,`rpty_id`),
  KEY `rpa_rpty_rpty_i` (`rpty_id`),
  CONSTRAINT `rpa_rpty_rpa_fk` FOREIGN KEY (`rpa_id`) REFERENCES `rpa` (`rpa_id`) ON DELETE CASCADE,
  CONSTRAINT `rpa_rpty_rpty_fk` FOREIGN KEY (`rpty_id`) REFERENCES `rpty` (`rpty_id`),
  CONSTRAINT `RPA_RPTY_SYMBOL_CHECK` CHECK (nullif(regexp_replace(`rpty_value`,'([[:print:]])+',''),'') is null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Protokolo savybės automatizuotoje ataskaitoje';

-- Dumping data for table emcor.rpa_rpty: ~4 rows (approximately)
/*!40000 ALTER TABLE `rpa_rpty` DISABLE KEYS */;
INSERT INTO `rpa_rpty` (`rpa_id`, `rpty_id`, `rpty_value`) VALUES
	(16, 3, 'DB serveryje užregistruotas duomenų trynimo vėlavimas.'),
	(16, 5, '0'),
	(21, 3, 'Oracle serveryje (EMCOS_IND) baigiasi vieta'),
	(22, 3, 'Oracle serveryje (EMCOS_TAB) baigiasi vieta');
/*!40000 ALTER TABLE `rpa_rpty` ENABLE KEYS */;

-- Dumping structure for table emcor.rpf
CREATE TABLE IF NOT EXISTS `rpf` (
  `rpf_id` mediumint(8) unsigned NOT NULL COMMENT 'Ataskaitos formato identifikatorius',
  `rpf_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Ataskaitos formato kodas',
  `rpf_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ataskaitos formato pavadinimas',
  `rpf_enabled` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Ataskaitos formato galiojimo požymis',
  PRIMARY KEY (`rpf_id`),
  UNIQUE KEY `rpf_code_u` (`rpf_code`),
  UNIQUE KEY `rpf_name_u` (`rpf_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ataskaitų formatai';

-- Dumping data for table emcor.rpf: ~7 rows (approximately)
/*!40000 ALTER TABLE `rpf` DISABLE KEYS */;
INSERT INTO `rpf` (`rpf_id`, `rpf_code`, `rpf_name`, `rpf_enabled`) VALUES
	(1, 'XLS', 'Excel failas', 1),
	(2, 'TXT', 'Tekstinis failas', 1),
	(3, 'PDF', 'PDF failas', 1),
	(4, 'MHT', 'MHT failas', 1),
	(5, 'XPS', 'XPS failas', 1),
	(6, 'HTML', 'HTML failas', 1),
	(7, 'CSV', 'CSV failas', 1);
/*!40000 ALTER TABLE `rpf` ENABLE KEYS */;

-- Dumping structure for table emcor.rpf_fpty
CREATE TABLE IF NOT EXISTS `rpf_fpty` (
  `rpf_id` mediumint(8) unsigned NOT NULL COMMENT 'Ataskaitos formato identifikatorius',
  `fpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ataskaitos formato savybės identifikatorius',
  PRIMARY KEY (`rpf_id`,`fpty_id`),
  KEY `rpf_fpty_fpty_i` (`fpty_id`),
  CONSTRAINT `rpf_fpty_fpty_fk` FOREIGN KEY (`fpty_id`) REFERENCES `fpty` (`fpty_id`),
  CONSTRAINT `rpf_fpty_rpf_fk` FOREIGN KEY (`rpf_id`) REFERENCES `rpf` (`rpf_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Ataskaitos galimos formato savybės';

-- Dumping data for table emcor.rpf_fpty: ~44 rows (approximately)
/*!40000 ALTER TABLE `rpf_fpty` DISABLE KEYS */;
INSERT INTO `rpf_fpty` (`rpf_id`, `fpty_id`) VALUES
	(1, 1),
	(1, 2),
	(1, 3),
	(1, 4),
	(1, 5),
	(1, 7),
	(1, 8),
	(1, 9),
	(2, 6),
	(2, 7),
	(2, 8),
	(2, 9),
	(3, 1),
	(3, 2),
	(3, 3),
	(3, 4),
	(3, 5),
	(3, 7),
	(3, 8),
	(3, 9),
	(4, 1),
	(4, 2),
	(4, 3),
	(4, 4),
	(4, 5),
	(4, 7),
	(4, 8),
	(4, 9),
	(5, 1),
	(5, 2),
	(5, 3),
	(5, 4),
	(5, 5),
	(5, 7),
	(5, 8),
	(5, 9),
	(6, 7),
	(6, 8),
	(6, 9),
	(7, 7),
	(7, 8),
	(7, 9),
	(7, 10),
	(7, 11);
/*!40000 ALTER TABLE `rpf_fpty` ENABLE KEYS */;

-- Dumping structure for table emcor.rpind
CREATE TABLE IF NOT EXISTS `rpind` (
  `rpind_id` mediumint(8) unsigned NOT NULL COMMENT 'Netiesioginio parametro identifikatorius',
  `rpind_name` varchar(100) COLLATE utf8_bin NOT NULL COMMENT 'Netiesioginio parametro pavadinimas',
  `formula` varchar(4000) COLLATE utf8_bin NOT NULL COMMENT 'Netiesioginio parametro formulė',
  PRIMARY KEY (`rpind_id`),
  UNIQUE KEY `rpind_name_u` (`rpind_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Reikšmė netiesioginiam parametrui';

-- Dumping data for table emcor.rpind: ~29 rows (approximately)
/*!40000 ALTER TABLE `rpind` DISABLE KEYS */;
INSERT INTO `rpind` (`rpind_id`, `rpind_name`, `formula`) VALUES
	(1, 'Šiandien', 'trunc(sysdate)'),
	(2, 'Vakar', 'trunc(sysdate - 1)'),
	(3, 'Užvakar', 'trunc(sysdate - 2)'),
	(4, 'Einamųjų metų pirma diena', 'trunc(sysdate, \'Y\')'),
	(5, 'Praeitų metų pirma diena', 'trunc(trunc(sysdate, \'Y\')-1,\'Y\')'),
	(6, 'Praeitų metų paskutinė diena', 'trunc(sysdate, \'Y\')-1'),
	(7, 'Einamojo kvartalo pirma diena', 'trunc(sysdate, \'Q\')'),
	(8, 'Praeito kvartalo pirma diena', 'trunc(trunc(sysdate, \'Q\')-1,\'Q\')'),
	(9, 'Praeito kvartalo paskutinė diena', 'trunc(sysdate, \'Q\')-1'),
	(10, 'Einamojo mėnesio pirma diena', 'trunc(sysdate, \'MM\')'),
	(11, 'Praeito mėnesio pirma diena', 'trunc(trunc(sysdate, \'MM\')-1,\'MM\')'),
	(12, 'Praeito mėnesio paskutinė diena', 'trunc(sysdate, \'MM\')-1'),
	(13, 'Einamosios savaitės pirma diena', 'trunc(sysdate, \'IW\')'),
	(14, 'Praeitos savaitės pirma diena', 'trunc(trunc(sysdate, \'IW\')-1,\'IW\')'),
	(15, 'Praeitos savaitės paskutinė diena', 'trunc(sysdate, \'IW\')-1'),
	(16, 'Prieš 1 savaitę', 'trunc(sysdate - 7)'),
	(17, 'Prieš 2 savaites', 'trunc(sysdate - 14)'),
	(18, 'Prieš mėnesį', 'add_months(sysdate, -1)'),
	(19, 'Prieš 2 mėnesius', 'add_months(sysdate, -2)'),
	(20, 'Prieš 3 mėnesius', 'add_months(sysdate, -3)'),
	(21, 'Prieš 4 mėnesius', 'add_months(sysdate, -4)'),
	(22, 'Prieš 6 mėnesius', 'add_months(sysdate, -6)'),
	(23, 'Prieš 8 mėnesius', 'add_months(sysdate, -8)'),
	(24, 'Prieš 10 mėnesių', 'add_months(sysdate, -10)'),
	(25, 'Prieš metus', 'add_months(sysdate, -12)'),
	(26, 'Prieš metus ir 6 mėnesius', 'add_months(sysdate, -18)'),
	(27, 'Prieš 2 metus', 'add_months(sysdate, -24)'),
	(28, 'Prieš 3 metus', 'add_months(sysdate, -36)'),
	(29, 'Užpraeito mėnesio paskutinė diena', 'add_months(trunc(sysdate,\'MM\'),-1)-1');
/*!40000 ALTER TABLE `rpind` ENABLE KEYS */;

-- Dumping structure for table emcor.rpp
CREATE TABLE IF NOT EXISTS `rpp` (
  `rpp_id` mediumint(8) unsigned NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo identifikatorius',
  `rpp_code` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo kodas',
  `rpp_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo pavadinimas',
  `rpp_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Automatizuotos ataskaitos protokolo galiojimas',
  PRIMARY KEY (`rpp_id`),
  UNIQUE KEY `rpp_code_u` (`rpp_code`),
  UNIQUE KEY `rpp_name_u` (`rpp_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Automatizuotos ataskaitos protokolas';

-- Dumping data for table emcor.rpp: ~15 rows (approximately)
/*!40000 ALTER TABLE `rpp` DISABLE KEYS */;
INSERT INTO `rpp` (`rpp_id`, `rpp_code`, `rpp_name`, `rpp_enabled`) VALUES
	(1, 'SMTP', 'Elektroniniu paštu', 1),
	(2, 'SMS_SMTP', 'SMS per el.paštą', 1),
	(3, 'WS', 'Web tarnyba', 1),
	(4, 'FTP', 'FTP', 1),
	(5, 'SFTP', 'SFTP (Saugus)', 1),
	(6, 'SMS_DIRECT', 'SMS per modemą', 1),
	(7, 'CRYPTO_SMTP', 'El.paštu per CryptoSendMail', 1),
	(8, 'SAVE_TO_FOLDER', 'Bylos išsaugojimas kataloge', 1),
	(9, 'Socket_UkrUPPD', 'UPPD paketais per soketą', 1),
	(10, 'SNMP_Trap', 'Paprastasis tinklo valdymo protokolas (Simple Network Management Protocol) su gaudyklių panaudojimu (Traps)', 1),
	(11, 'TNS', 'TNS protokolas', 1),
	(12, 'HTTP_Globos', 'HTTP_Globos protokolas', 1),
	(13, 'Diadoc', 'Diadoc protokolas', 1),
	(14, 'SMS_SMPP', 'SMS per trumpųjų žinučių protokolą (Short Message Peer to Peer Protocol)', 1),
	(15, 'WSSmartTech', 'Web tarnyba SmartTech', 1);
/*!40000 ALTER TABLE `rpp` ENABLE KEYS */;

-- Dumping structure for table emcor.rpp_rpty
CREATE TABLE IF NOT EXISTS `rpp_rpty` (
  `rpp_id` mediumint(8) unsigned NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo identifikatorius',
  `rpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo savybės identifikatorius',
  `rpty_default_value` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Protokolo savybės reikšmė pagal nutylėjimą',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  `rpty_nr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Protokolo savybės eilės numeris rušiavimui',
  PRIMARY KEY (`rpp_id`,`rpty_id`),
  KEY `rpp_rpty_enum_i` (`enum_id`),
  KEY `rpp_rpty_rpty_i` (`rpty_id`),
  CONSTRAINT `rpp_rpty_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`) ON DELETE SET NULL,
  CONSTRAINT `rpp_rpty_rpp_fk` FOREIGN KEY (`rpp_id`) REFERENCES `rpp` (`rpp_id`),
  CONSTRAINT `rpp_rpty_rpty_fk` FOREIGN KEY (`rpty_id`) REFERENCES `rpty` (`rpty_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Automatizuotos ataskaitos galimos protokolo savybės';

-- Dumping data for table emcor.rpp_rpty: ~104 rows (approximately)
/*!40000 ALTER TABLE `rpp_rpty` DISABLE KEYS */;
INSERT INTO `rpp_rpty` (`rpp_id`, `rpty_id`, `rpty_default_value`, `enum_id`, `rpty_nr`) VALUES
	(1, 1, NULL, NULL, NULL),
	(1, 2, NULL, NULL, NULL),
	(1, 3, NULL, NULL, NULL),
	(1, 4, NULL, NULL, NULL),
	(1, 5, NULL, NULL, NULL),
	(1, 9, NULL, NULL, NULL),
	(1, 13, NULL, NULL, NULL),
	(1, 14, NULL, NULL, NULL),
	(1, 15, NULL, NULL, NULL),
	(1, 16, NULL, NULL, NULL),
	(1, 68, NULL, NULL, NULL),
	(2, 1, NULL, NULL, NULL),
	(2, 2, NULL, NULL, NULL),
	(2, 3, NULL, NULL, NULL),
	(2, 4, NULL, NULL, NULL),
	(2, 6, NULL, NULL, NULL),
	(2, 7, NULL, NULL, NULL),
	(2, 14, NULL, NULL, NULL),
	(2, 44, NULL, NULL, NULL),
	(3, 8, NULL, NULL, NULL),
	(3, 9, NULL, NULL, NULL),
	(3, 10, NULL, NULL, NULL),
	(3, 11, NULL, NULL, NULL),
	(3, 12, NULL, NULL, NULL),
	(3, 13, NULL, NULL, NULL),
	(3, 14, NULL, NULL, NULL),
	(4, 9, NULL, NULL, NULL),
	(4, 13, NULL, NULL, NULL),
	(4, 17, NULL, NULL, NULL),
	(4, 18, NULL, NULL, NULL),
	(4, 19, NULL, NULL, NULL),
	(4, 20, NULL, NULL, NULL),
	(4, 69, '21', NULL, NULL),
	(4, 70, NULL, 82, NULL),
	(4, 71, NULL, 895, NULL),
	(5, 9, NULL, NULL, NULL),
	(5, 13, NULL, NULL, NULL),
	(5, 17, NULL, NULL, NULL),
	(5, 18, NULL, NULL, NULL),
	(5, 19, NULL, NULL, NULL),
	(5, 20, NULL, NULL, NULL),
	(5, 69, '21', NULL, NULL),
	(5, 70, NULL, 82, NULL),
	(5, 71, NULL, 895, NULL),
	(6, 7, NULL, NULL, NULL),
	(6, 21, NULL, NULL, NULL),
	(6, 22, NULL, NULL, NULL),
	(6, 23, NULL, NULL, NULL),
	(6, 24, NULL, NULL, NULL),
	(6, 25, NULL, NULL, NULL),
	(6, 26, NULL, NULL, NULL),
	(6, 27, NULL, NULL, NULL),
	(6, 28, NULL, NULL, NULL),
	(6, 44, NULL, NULL, NULL),
	(7, 1, NULL, NULL, NULL),
	(7, 2, NULL, NULL, NULL),
	(7, 3, NULL, NULL, NULL),
	(7, 4, NULL, NULL, NULL),
	(7, 5, NULL, NULL, NULL),
	(7, 9, NULL, NULL, NULL),
	(7, 13, NULL, NULL, NULL),
	(7, 14, NULL, NULL, NULL),
	(7, 15, NULL, NULL, NULL),
	(7, 16, NULL, NULL, NULL),
	(7, 29, NULL, NULL, NULL),
	(8, 9, NULL, NULL, NULL),
	(8, 13, NULL, NULL, NULL),
	(8, 30, NULL, NULL, NULL),
	(9, 10, NULL, NULL, NULL),
	(9, 11, NULL, NULL, NULL),
	(9, 31, NULL, NULL, NULL),
	(9, 32, NULL, NULL, NULL),
	(9, 33, NULL, NULL, NULL),
	(9, 34, NULL, NULL, NULL),
	(10, 35, NULL, NULL, NULL),
	(10, 36, NULL, NULL, NULL),
	(10, 37, NULL, NULL, NULL),
	(10, 38, NULL, NULL, NULL),
	(10, 39, NULL, NULL, NULL),
	(10, 40, NULL, NULL, NULL),
	(10, 41, NULL, NULL, NULL),
	(10, 42, NULL, NULL, NULL),
	(12, 43, NULL, NULL, NULL),
	(12, 48, NULL, NULL, NULL),
	(12, 49, NULL, NULL, NULL),
	(13, 50, NULL, NULL, NULL),
	(13, 54, NULL, NULL, NULL),
	(13, 55, NULL, NULL, NULL),
	(13, 58, NULL, NULL, NULL),
	(13, 59, NULL, NULL, NULL),
	(13, 60, NULL, 82, NULL),
	(13, 61, NULL, 82, NULL),
	(14, 11, NULL, NULL, NULL),
	(14, 34, NULL, NULL, NULL),
	(14, 44, NULL, NULL, NULL),
	(14, 62, NULL, NULL, NULL),
	(14, 63, NULL, NULL, NULL),
	(14, 64, NULL, NULL, NULL),
	(14, 65, NULL, NULL, NULL),
	(14, 66, NULL, 82, NULL),
	(14, 67, NULL, 82, NULL),
	(15, 8, NULL, NULL, NULL),
	(15, 10, NULL, NULL, NULL),
	(15, 11, NULL, NULL, NULL);
/*!40000 ALTER TABLE `rpp_rpty` ENABLE KEYS */;

-- Dumping structure for table emcor.rpq
CREATE TABLE IF NOT EXISTS `rpq` (
  `rpq_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Ataskaitos užklausos identifikatorius',
  `rpq_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ataskaitos užklausos pavadinimas',
  `rp_id` int(10) unsigned NOT NULL COMMENT 'Ataskaitos identifikatorius',
  `table_name` varchar(50) COLLATE utf8_bin DEFAULT NULL COMMENT 'Lentelės vardas',
  `rpq_distinct` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Tik nepasikartojančių įrašų išrinkimo požymis',
  `rpq_maxrows` mediumint(8) unsigned DEFAULT NULL COMMENT 'Užklausos įrašų kiekio apribojimas',
  `rpq_slc` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'Tiesiogiai įvesta SQL užklausa',
  `rpq_advanced` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Tiesiogiai įvestos SQL užklausos naudojimo požymis',
  PRIMARY KEY (`rpq_id`),
  UNIQUE KEY `rpq_name_u` (`rpq_name`,`rp_id`),
  KEY `rpq_rp_i` (`rp_id`),
  KEY `rpq_table_i` (`table_name`),
  CONSTRAINT `rpq_rp_fk` FOREIGN KEY (`rp_id`) REFERENCES `rp` (`rp_id`) ON DELETE CASCADE,
  CONSTRAINT `RPQ_ADVANCED_CHK` CHECK (`rpq_advanced` = 0 and `table_name` is not null or `rpq_advanced` = 1 and `rpq_slc` is not null)
) ENGINE=InnoDB AUTO_INCREMENT=64 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ataskaitos užklausos';

-- Dumping data for table emcor.rpq: ~43 rows (approximately)
/*!40000 ALTER TABLE `rpq` DISABLE KEYS */;
INSERT INTO `rpq` (`rpq_id`, `rpq_name`, `rp_id`, `table_name`, `rpq_distinct`, `rpq_maxrows`, `rpq_slc`, `rpq_advanced`) VALUES
	(1, 'Užblokuotų sistemos vartotojų ataskaita', 1, NULL, 0, NULL, 'SELECT f.column_value FROM (\nSELECT\nDISTINCT d.column_value\nFROM\n(SELECT b.dbu dbu,\na.account_status,\na.lock_date\nFROM dba_users a\nJOIN users b\nON (a.username=b.dbu)\nWHERE lock_date>(SELECT Nvl((SELECT amp FROM tmst WHERE tmst_code=\'CHECK_LOCKED_USERS\'),DATE\'1899-12-30\') FROM dual)\n) c,\nTABLE(exe(\n\'0; event_i(5,18,168,1,sysdate,\'\'\'||GETCAPTION(230, c.dbu, TO_CHAR(c.lock_date, getcaption(190)))||\'\'\',3, null, null, null, null, null, null, null, null); commit;\'\n)) d\n) e\n,TABLE(exe(\ne.column_value||\'; merge INTO tmst y USING (SELECT \'\'CHECK_LOCKED_USERS\'\' tmst_code FROM dual) u ON (y.tmst_code=u.tmst_code) \'||\n\'WHEN MATCHED THEN UPDATE SET \'||\n\'y.amp = sysdate \'||\n\'WHEN NOT MATCHED THEN INSERT \'||\n\' (\'||\n\' y.tmst_code\'||\n\',y.amp\'||\n\') values (\'||\n\' u.tmst_code\'||\n\',sysdate\'||\n\');\'||Chr(10)||\n\'commit;\'\n    )) f\nWHERE\n  f.column_value IS NULL', 1),
	(6, 'DB ilgai veikiančių sesijų paieška', 6, NULL, 0, NULL, 'SELECT sql_fulltext, Round(c.sofar/c.totalwork*100,1) progress\n,ddifc(SYSDATE,SYSDATE+a.last_call_et/86400) "Last call duration"\n,a.last_call_et\n,a.sid\n,d.job JOB_ID\n,d.what JOB_WHAT\n,a.username\n,a.status\n,c.message\n,a.schemaname\n,a.osuser\n,a.machine\n,a.terminal\n,a.program\n,a."TYPE"\n,a.logon_time\n,a.blocking_session_status\n,a.event\n,a.wait_class\n,a.wait_time\n,a.seconds_in_wait\n,a.state\nFROM sys.v_$session a\nleft join sys.v_$sql b ON (a.sql_id=b.sql_id)\nleft join sys.v_$session_longops c ON (a.sid=c.sid AND a.serial#=c.serial# AND c.sofar<c.totalwork)\nleft join (select j.sid,\n       j.log_user,\n       j.job,\n       j.broken,\n       j.failures,\n       j.this_date||\':\'||j.this_sec this_date,\n       j.what\nfrom (select djr.SID,\n             dj.LOG_USER, dj.JOB job, dj.BROKEN, dj.FAILURES,\n             dj.LAST_DATE, dj.LAST_SEC, dj.THIS_DATE, dj.THIS_SEC,\n             dj.NEXT_DATE, dj.NEXT_SEC, dj.INTERVAL, dj.WHAT what\n        from dba_jobs dj, dba_jobs_running djr\n       where dj.job = djr.job ) j,\n     (select p.spid, s.sid, s.serial#\nfrom v$process p, v$session s\nwhere p.addr  = s.paddr ) s\nwhere j.sid = s.sid) d ON a.sid=d.sid\nWHERE a.status = \'ACTIVE\' and SCHEMANAME NOT IN (\'SYS\') and sql_fulltext not like \'%alter index%shrink%\' and a.last_call_et > 60*$$N:=:timemax$$', 1),
	(11, 'Nesekmingų bandymų prisijungti prie sistemos ataskaita', 11, NULL, 0, NULL, 'select to_char(timestamp,\'DD-MON-YYYY HH24:MI:SS\') "Data", os_username "OS vartotojas", username "Sistemos vartotojas", userhost "Host", terminal "Terminalas", action_name "Veiksmo tipas"\nfrom dba_audit_session\nwhere returncode<>0', 1),
	(12, 'Vartotojų sesijų audito įjungimas ataskaita', 12, NULL, 0, NULL, 'SELECT\ncase\nwhen b.VALUE=\'NONE\' THEN \'Kad pabaigti audito ijungimą, reikia perkrovineti DB.\'||(SELECT a FROM (SELECT column_value a FROM TABLE(exe(\'0; execute immediate \'\'alter system set AUDIT_TRAIL=DB scope=spfile\'\';\')))WHERE a IS null)||(SELECT a FROM (SELECT column_value a FROM TABLE(exe(\'0; execute immediate \'\'audit session\'\';\'))) WHERE a IS null)\nWHEN c.audit_option=\'CREATE SESSION\' THEN \'Vartotojų sesijų auditas jau yra ijungtas.\'\nWHEN c.audit_option IS NULL THEN \'Vartotojų sesijų auditas ijungtas.\'||(SELECT a FROM (SELECT column_value a FROM TABLE(exe(\'0; execute immediate \'\'audit session\'\';\'))) WHERE a IS null)\nend answer\nFROM v$parameter b left join DBA_STMT_AUDIT_OPTS c on (b.name=\'audit_trail\')\nWHERE b.name=\'audit_trail\'', 1),
	(13, 'Vartotojų sesijų audito išjungimas ataskaita', 13, NULL, 0, NULL, 'SELECT\ncase\nWHEN cnt=0 THEN \'Vartotojų sesijų auditas jau yra išjungtas.\'\nWHEN cnt=1 THEN \'Vartotojų sesijų auditas išjungtas.\'||(SELECT a FROM (SELECT column_value a FROM TABLE(exe(\'0; execute immediate \'\'noaudit session\'\';\'))) WHERE a IS null)\nend answer\nFROM (select count(*) cnt from DBA_STMT_AUDIT_OPTS where audit_option=\'CREATE SESSION\') c', 1),
	(14, 'Vatrotojų sesijų informacijos trynimas ataskaita', 14, NULL, 0, NULL, 'SELECT * FROM (\nSELECT column_value a FROM TABLE(exe(\'0; execute immediate \'\'delete from sys.AUD$ where CAST((from_tz(ntimestamp#,\'\'\'\'00:00\'\'\'\') at local) AS DATE)< sysdate-\'||TO_CHAR($$N:=:DEPTH$$)||\'\'\'; commit;\'))\n) WHERE a IS null', 1),
	(16, 'Senų duomenų trynimo monitoringas', 16, NULL, 0, NULL, 'SELECT\nTMST_CODE "Foninės užduoties tipo kodas",\nbga_name "Foninės užduoties pavadinimas",\nbga_param_value "Numatytas trynimo gylis",\nunit "Matavimo vienetas",\ncurrAMP "Laiko žymė, pagal užduotą gylį",\nAMP as "Faktinė laiko žymė",\ndiff "Laiko skirtumas"\nFROM (\nselect TMST_CODE,\nbga_name,\nbga_param_value,\nCASE WHEN BGA_TYPE_PARAM_KEY=\'N:=:MONTH_COUNT\' THEN ADD_MONTHS(sysdate, -TO_NUMBER(BGA_PARAM_VALUE))\n WHEN BGA_TYPE_PARAM_KEY=\'N:=:DAY_COUNT\' THEN sysdate-TO_NUMBER(BGA_PARAM_VALUE)\n WHEN BGA_TYPE_PARAM_KEY=\'N:=:HOUR_COUNT\' THEN sysdate-TO_NUMBER(BGA_PARAM_VALUE)/24\n  WHEN BGA_TYPE_PARAM_KEY=\'N:=:SECONDS_COUNT\' THEN sysdate-TO_NUMBER(BGA_PARAM_VALUE)/86400\nEND as currAMP,\nCASE WHEN BGA_TYPE_PARAM_KEY=\'N:=:MONTH_COUNT\' THEN \'mėnesis\'\n WHEN BGA_TYPE_PARAM_KEY=\'N:=:DAY_COUNT\' THEN \'diena\'\n WHEN BGA_TYPE_PARAM_KEY=\'N:=:HOUR_COUNT\' THEN \'valanda\'\n  WHEN BGA_TYPE_PARAM_KEY=\'N:=:SECONDS_COUNT\' THEN \'sekundė\'\nEND as unit,\na.AMP,\nddifc(a.AMP, CASE WHEN BGA_TYPE_PARAM_KEY=\'N:=:MONTH_COUNT\' THEN ADD_MONTHS(sysdate, -TO_NUMBER(BGA_PARAM_VALUE))\nWHEN BGA_TYPE_PARAM_KEY=\'N:=:DAY_COUNT\'   THEN sysdate-TO_NUMBER(BGA_PARAM_VALUE)\nWHEN BGA_TYPE_PARAM_KEY=\'N:=:HOUR_COUNT\' THEN sysdate-TO_NUMBER(BGA_PARAM_VALUE)/24\nWHEN BGA_TYPE_PARAM_KEY=\'N:=:SECONDS_COUNT\' THEN sysdate-TO_NUMBER(BGA_PARAM_VALUE)/86400\n END) diff\nfrom tmst a\nleft join ST_BGA_PARAM b on (a.TMST_CODE=b.BGA_TYPE_CODE)\nwhere BGA_CLASS_ID in (select bga_class_id  from bga_class where BGA_CLASS_CODE = \'AUTO_DELETE_OLD_DATA\')\nand b.BGA_TYPE_PARAM_KEY  in (\'N:=:MONTH_COUNT\', \'N:=:DAY_COUNT\', \'N:=:HOUR_COUNT\',\'N:=:SECONDS_COUNT\')\nand b.bga_enabled=1) c\nwhere currAMP-AMP>nvl($$N:=:deltalimit$$, 2)', 1),
	(17, 'Užimtos EMCOS_IND tablespace vietos procentas', 17, NULL, 0, NULL, 'SELECT\nsysdate dt,\nround((Max(o)-Max(r))/Max(m)*100,2) val\nFROM\n(SELECT tablespace_name, Sum(bytes) o,Greatest(Sum(bytes),Sum(maxbytes)) m FROM dba_data_files  WHERE tablespace_name = \'EMCOS_IND\' GROUP BY tablespace_name) t\nleft join (SELECT tablespace_name, Sum(bytes) r FROM dba_free_space WHERE tablespace_name = \'EMCOS_IND\' GROUP BY tablespace_name) f ON (t.tablespace_name = f.tablespace_name)\nGROUP BY t.tablespace_name', 1),
	(18, 'Užimtos EMCOS_TAB tablespace vietos procentas', 18, NULL, 0, NULL, 'SELECT\nsysdate dt,\nround((Max(o)-Max(r))/Max(m)*100,2) val\nFROM\n(SELECT tablespace_name, Sum(bytes) o,Greatest(Sum(bytes),Sum(maxbytes)) m FROM dba_data_files  WHERE tablespace_name = \'EMCOS_TAB\' GROUP BY tablespace_name) t\nleft join (SELECT tablespace_name, Sum(bytes) r FROM dba_free_space WHERE tablespace_name = \'EMCOS_TAB\' GROUP BY tablespace_name) f ON (t.tablespace_name = f.tablespace_name)\nGROUP BY t.tablespace_name', 1),
	(19, 'Taškų matavimų galiojančių išsaugojimų kiekis per parą', 19, NULL, 0, NULL, 'SELECT sysdate dt, COUNT(*) val FROM PL_DATA WHERE DB_TIME >= TRUNC(SYSDATE-1) AND DB_TIME < TRUNC(SYSDATE)', 1),
	(20, 'Taškų matavimų galiojančių išsaugojimų procentas per parą', 20, NULL, 0, NULL, 'SELECT sysdate dt, Sum(Decode(rnk,1,1))/Nvl(nullif(Sum(Decode(rnk,1,1)) + Sum(Decode(db_time,null,null,1)),0),1)*100 val FROM (\nSELECT b.db_time, Rank() over (PARTITION BY a.pl_id,a.pl_t ORDER BY b.db_time) rnk\nFROM PL_DATA a\nleft join pl_data_nv b ON (a.pl_id=b.pl_id AND a.pl_t=b.pl_t)\nWHERE a.db_time >= trunc(sysdate-1) and a.db_time < trunc(sysdate)\n)', 1),
	(21, 'Turinčių diskretiškumą taškų matavimų išsaugojimų procentas per parą', 21, NULL, 0, NULL, 'WITH s as (select /*+MATERIALIZE*/a.pl_id from pl a left join point p on (a.point_id=p.point_id) join ml r on (a.ml_id=r.ml_id) join pl c on (a.pl_id=c.pl_id) join di d on (a.pl_id=d.pl_id) WHERE p.point_enabled=1 AND a.pl_enabled=1 AND d.di_enabled=1 AND NOT r.md_id=7)\n,d AS (SELECT /*+materialize*/ pl_id, Count(*) cnt FROM PL_DATA WHERE DB_TIME >= TRUNC(SYSDATE-1) AND DB_TIME < TRUNC(SYSDATE) GROUP BY pl_id)\nSELECT sysdate dt, Sum(Decode(s.pl_id,NULL,NULL,cnt))/Nvl(nullif(Sum(cnt),0),1)*100 val FROM\nd left join s ON (d.pl_id=s.pl_id)', 1),
	(22, 'Suvestų apskaitos taškų kiekis', 22, NULL, 0, NULL, 'Select sysdate dt, count(*) val from point where not point_code = \'EMCOS_STATUS\'', 1),
	(23, 'Turinčių diskretiškumą taškų matavimų be skylių procentas', 23, NULL, 0, NULL, 'WITH s as (select /*+MATERIALIZE*/a.pl_id from pl a join point p on (a.point_id=p.point_id)\njoin ml r on (a.ml_id=r.ml_id) join pl c on (a.pl_id=c.pl_id) join di d on (a.pl_id=d.pl_id)\nWHERE p.point_enabled=1 AND a.pl_enabled=1 AND d.di_enabled=1 AND NOT r.md_id=7)\nSELECT sysdate dt, Sum(CASE WHEN mh>1 THEN 1 end)/Nvl(nullif(Count(*),0),1)*100 val FROM\n(\nSELECT /*+ parallel(a)*/pl_id, MIN(S_HOSF) mh\nFROM PLEP a WHERE PLEP_BT>=TRUNC(SYSDATE-2) AND PLEP_BT<TRUNC(SYSDATE)\nGROUP BY pl_id\n) join s using (pl_id)', 1),
	(24, 'Ryšio kanalų unikalių sesijų kiekis per parą', 24, NULL, 0, NULL, 'select TRUNC(sysdate-1) dt, count(*) val from (\nselect distinct ses_time,das_id,ses_nr from sta_ph_data where ses_time >= TRUNC(sysdate-1) and ses_time < TRUNC(sysdate))', 1),
	(25, 'Ryšio kanalų unikalių sesijų be transporto lygio klaidų procentas per parą', 25, NULL, 0, NULL, 'SELECT sysdate dt, (b.cnt-a.cnt)/DECODE(b.cnt,0,1,b.cnt)*100 val from\n(SELECT Count(*) cnt FROM (select distinct ses_time,das_id,ses_nr from sta_ph_data WHERE not sta_ph_data.ph_etype_id is null and ses_time >= TRUNC(sysdate-1) and ses_time < TRUNC(sysdate))) a,\n(SELECT Count(*) cnt FROM (select distinct ses_time,das_id,ses_nr from sta_ph_data where ses_time >= TRUNC(sysdate-1) and ses_time < TRUNC(sysdate))) b', 1),
	(26, 'Uždarytų taškų procentas per parą', 26, NULL, 0, NULL, 'select sysdate, nvl(sum(decode(cl,1,1)),0)/count(*)*100 from (\nselect\na.point_id\n,min(nvl(c.cp_enabled,0)) cl\nfrom\npoint_fp a\njoin point b on (a.point_id=b.point_id)\ncross join (select trunc(sysdate)-7-level da from dual connect by level<=7) d\nleft join cp c on (c.per_id = 4 and c.point_id = a.point_id and c.cp_t=d.da)\n where point_enabled = 1\ngroup by a.point_id\n)\nhaving not count(*)=0', 1),
	(27, 'Taškų matavimų saugotinų nuskaitymų kiekis buferyje', 27, NULL, 0, NULL, 'select /*+parallel(a)*/ sysdate dt, count(*) val from STORE_PL_BUF a', 1),
	(28, 'Taškų matavimų nesaugotinų nuskaitymų kiekis buferyje', 28, NULL, 0, NULL, 'select /*+parallel(a)*/ sysdate dt, count(*) val from STORE_PL_BUF_NV a', 1),
	(29, 'Svarbių Oracle pranešimų kiekis įvykių registre per parą', 29, NULL, 0, NULL, 'select sysdate dt, count(*) val from ev where evc_id = 1 AND ev_priority=1 and EV_TIME >= TRUNC(SYSDATE-1) AND EV_TIME < TRUNC(SYSDATE)', 1),
	(30, 'Maksimalus eilės dydis per parą', 30, NULL, 0, NULL, 'SELECT Trunc(SYSDATE)-1 dt, max(To_Number(a.cnt)) val from (\nSELECT\nIS_NUMERIC(SUBSTR(SUBSTR(EV_MSG, INSTR(EV_MSG, \'Items in line: \')),\n16, CASE WHEN INSTR(SUBSTR(EV_MSG, INSTR(EV_MSG, \'Items in line: \')), \',\')=0\nTHEN LENGTH (SUBSTR(EV_MSG, INSTR(EV_MSG, \'Items in line: \'))) ELSE INSTR(SUBSTR(EV_MSG, INSTR(EV_MSG, \'Items in line: \')), \',\')-16 END )) isnum,\nSUBSTR(SUBSTR(EV_MSG, INSTR(EV_MSG, \'Items in line: \')),\n16, CASE WHEN INSTR(SUBSTR(EV_MSG, INSTR(EV_MSG, \'Items in line: \')), \',\')=0\nTHEN LENGTH (SUBSTR(EV_MSG, INSTR(EV_MSG, \'Items in line: \'))) ELSE INSTR(SUBSTR(EV_MSG, INSTR(EV_MSG, \'Items in line: \')), \',\')-16 END ) cnt\nfrom ev where evc_id =4 AND evt_id = 20 AND ev_msg LIKE \'%Items in line%\' and ev_time>=Trunc(SYSDATE)-1 AND ev_time<Trunc(SYSDATE)) a\nWHERE a.isnum=1', 1),
	(31, 'Suformuotų automatizuotų ataskaitų kiekis per parą', 31, NULL, 0, NULL, 'select sysdate dt, count(rpa_id) val from rp_log where DB_TIME >= TRUNC(SYSDATE-1) AND DB_TIME < TRUNC(SYSDATE) and form =0', 1),
	(32, 'Naudojamų ryšio kanalų kiekis', 32, NULL, 0, NULL, 'SELECT sysdate dt, count(distinct ph_id) val\nFROM spac join sepac USING (dp_id, sp_id)\nWHERE\ndp_enabled=1\nand src_enabled=1\nand ph_enabled=1\nAND di_enabled = 1\nAND sep_enabled = 1\nAND Nvl(point_auto_read_enabled,1)=1', 1),
	(33, 'Naudojamų ryšio kanalų, su kuriais yra ryšys, procentas', 33, NULL, 0, NULL, 'WITH a AS\n(\nSELECT DISTINCT ph_id\nFROM spac join sepac USING (dp_id, sp_id)\nWHERE\ndp_enabled=1\nand src_enabled=1\nand ph_enabled=1\nAND di_enabled = 1\nAND sep_enabled = 1\nAND Nvl(point_auto_read_enabled,1)=1\n)\nSELECT\nsysdate dt, Sum(Decode(b.costa_id,1,1))/nullif(Count(*),0)*100 val\nfrom a\nleft join ph_state b ON (a.ph_id=b.ph_id)', 1),
	(34, 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą', 34, NULL, 0, NULL, 'WITH t AS (SELECT /*+materialize*/pl_id FROM pl join ml USING (ml_id) WHERE NOT md_id=7)\nSELECT Trunc(SYSDATE)-1 dt, Nvl(Sum(Decode(pl_v,NULL,0,1)),0)/Nvl(nullif(Count(*),0),1)*100\nFROM PL_DATA join t using (pl_id)\nWHERE db_time>=Trunc(SYSDATE)-1 AND db_time<Trunc(SYSDATE)', 1),
	(35, 'Turinčių diskretiškumą galiojančių saugotinų nepagerinamų išsaugojimų procentas per parą', 35, NULL, 0, NULL, 'WITH t AS (SELECT /*+materialize*/pl_id FROM pl join ml USING (ml_id) WHERE NOT md_id=7)\nSELECT Trunc(SYSDATE)-1 dt, Nvl(Sum(CASE WHEN not PL_V is null\nand CASE WHEN tstatus IS NULL THEN 0 ELSE To_Number(bitand(tstatus,1)) END=0 THEN 1 end),0)/Nvl(nullif(Count(*),0),1)*100\nFROM PL_DATA join t using (pl_id)\nWHERE db_time>=Trunc(SYSDATE)-1 AND db_time<Trunc(SYSDATE)', 1),
	(36, 'Neturinčių diskretiškumo galiojančių saugotinų nepagerinamų išsaugojimų procentas per parą', 36, NULL, 0, NULL, 'WITH t AS (SELECT /*+materialize*/pl_id FROM pl join ml USING (ml_id) WHERE md_id=7)\nSELECT Trunc(SYSDATE)-1 dt, Nvl(Sum(CASE WHEN not PL_V is null\nand CASE WHEN tstatus IS NULL THEN 0 ELSE To_Number(bitand(tstatus,1)) END=0 THEN 1 end),0)/Nvl(nullif(Count(*),0),1)*100\nFROM PL_DATA join t using (pl_id)\nWHERE db_time>=Trunc(SYSDATE)-1 AND db_time<Trunc(SYSDATE)', 1),
	(41, 'Laisvos vietos sekimas EMCOS_IND.', 41, NULL, 0, NULL, 'SELECT \'EMCOS_IND tablespace is \'\n  ||ROUND((o-r)/m*100,2)\n  ||\'% full, \'\n  ||ROUND((m+r-o)/1048576,1)\n  ||\'Mb left, \'\n  ||ROUND((o)/1048576,1)\n  ||\'Mb taken, \'\n  ||ROUND(e/1048576,1)\n  ||\'Mb reclaimable, \'\n  ||ROUND(r/1048576,1)\n  ||\'Mb free space inside, \'\n  ||ROUND((m-o)/1048576,1)\n  ||\'Mb outside\' text\nFROM\n  (SELECT SUM(bytes) r FROM dba_free_space WHERE tablespace_name=\'EMCOS_IND\'\n  ) f ,\n  (SELECT SUM(reclaimable_space) e\n  FROM TABLE(sys.DBMS_SPACE.ASA_RECOMMENDATIONS)\n  ) g ,\n  (SELECT SUM(bytes) o,\n    Greatest(SUM(bytes),SUM(maxbytes)) m\n  FROM dba_data_files\n  WHERE tablespace_name=\'EMCOS_IND\'\n  ) t\nWhere (o-r)/m*100>95', 1),
	(42, 'Laisvos vietos sekimas EMCOS_TAB.', 42, NULL, 0, NULL, 'SELECT \'EMCOS_TAB tablespace is \'\n  ||ROUND((o-r)/m*100,2)\n  ||\'% full, \'\n  ||ROUND((m+r-o)/1048576,1)\n  ||\'Mb left, \'\n  ||ROUND((o)/1048576,1)\n  ||\'Mb taken, \'\n  ||ROUND(e/1048576,1)\n  ||\'Mb reclaimable, \'\n  ||ROUND(r/1048576,1)\n  ||\'Mb free space inside, \'\n  ||ROUND((m-o)/1048576,1)\n  ||\'Mb outside\' text\nFROM\n  (SELECT SUM(bytes) r FROM dba_free_space WHERE tablespace_name=\'EMCOS_TAB\'\n  ) f ,\n  (SELECT SUM(reclaimable_space) e\n  FROM TABLE(sys.DBMS_SPACE.ASA_RECOMMENDATIONS)\n  ) g ,\n  (SELECT SUM(bytes) o,\n    Greatest(SUM(bytes),SUM(maxbytes)) m\n  FROM dba_data_files\n  WHERE tablespace_name=\'EMCOS_TAB\'\n  ) t\nWhere (o-r)/m*100>95', 1),
	(46, 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą', 46, NULL, 0, NULL, 'Select sysdate dt, count(*) val from point where not point_code=\'EMCOS_STATUS\' and point_enabled=1 and point_auto_read_enabled=1', 1),
	(51, 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą', 51, NULL, 0, NULL, 'select sysdate dt, round(hpl_cnt/Nvl(nullif(cnt,0),1)*100,2) h_prc from (select count(*) hpl_cnt from st_grp where gr_code = \'HOPELESS\'),(select count(*)-1 cnt from st_point)', 1),
	(52, 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą', 52, NULL, 0, NULL, 'with h as (select /*+materialize*/ point_id \nfrom st_grp where gr_code = \'HOPELESS\')\n,d as (select /*+materialize*/ di_id from st_di where point_id in (select * from h))\nselect sysdate dt, round(hpl_cnt4/Nvl(nullif(cnt4,0),1)*100,2) hopeless_holes_prc \nfrom (select count(*) hpl_cnt from h),(select count(*)-1 cnt from st_point)\n,(select sum(decode(d.di_id,null,null,1)) hpl_cnt4, count(*) cnt4 \nfrom rodo a left join d on (a.di_id=d.di_id) where db_time> sysdate-2 and rc_id in (4,5,14))', 1),
	(53, 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą', 53, NULL, 0, NULL, 'with h as (select /*+materialize*/ point_id \nfrom st_grp where gr_code = \'HOPELESS\')\n,d as (select /*+materialize*/ di_id from st_di where point_id in (select * from h))\nselect sysdate dt, cnt4 hopeless_holes_cnt \nfrom (select count(*) hpl_cnt from h),(select count(*)-1 cnt from st_point)\n,(select sum(decode(d.di_id,null,null,1)) hpl_cnt4, count(*) cnt4 \nfrom rodo a left join d on (a.di_id=d.di_id) where db_time> sysdate-2 and rc_id in (4,5,14))', 1),
	(54, 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą', 54, NULL, 0, NULL, 'SELECT sysdate dt, Sum(Decode(segment_name,\'PL_DATA\',bytes))/Nvl(nullif(Sum(bytes),0),1)*100 val FROM user_segments\nWHERE tablespace_name = \'EMCOS_TAB\' OR segment_type LIKE \'TABLE%\'', 1),
	(55, 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą', 55, NULL, 0, NULL, 'WITH s as (select /*+materialize*/a.pl_id,a.point_id from pl a join point p on (a.point_id=p.point_id)\njoin ml r on (a.ml_id=r.ml_id) join pl c on (a.pl_id=c.pl_id) join di d on (a.pl_id=d.pl_id)\nWHERE p.point_enabled=1 AND a.pl_enabled=1 AND d.di_enabled=1)\nSELECT sysdate dt, Sum(CASE WHEN mh=1 THEN 1 end)/Nvl(nullif(Count(*),0),1)*100 val FROM\n(\nSELECT /*+ parallel*/point_id, MIN(S_HOSF) mh\nFROM PLEP join s using (pl_id) WHERE PLEP_BT>=TRUNC(SYSDATE-2) AND PLEP_BT<TRUNC(SYSDATE)\nGROUP BY point_id\n)', 1),
	(56, 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą', 56, NULL, 0, NULL, 'SELECT sysdate dt, Sum(CASE WHEN ok IS null THEN 1 end)/Nvl(nullif(Count(*),0),1)*100 val FROM\n(\nSELECT\na.dp_id\n,Max(\nCASE WHEN s.costa_id=1 AND SYSDATE<=\n CASE nvl(a0.COSTA_G_PER_ID,4)\n   WHEN 6 THEN Add_Months(s.costa_last_check,12*a0.COSTA_G_EXP_VALUE)\n   WHEN 5 THEN Add_Months(s.costa_last_check,a0.COSTA_G_EXP_VALUE)\n   WHEN 4 THEN s.costa_last_check+Nvl(a0.COSTA_G_EXP_VALUE,1)\n   WHEN 3 THEN s.costa_last_check+a0.COSTA_G_EXP_VALUE/24\n   WHEN 2 THEN s.costa_last_check+a0.COSTA_G_EXP_VALUE/1440\n   WHEN 1 THEN s.costa_last_check+a0.COSTA_G_EXP_VALUE/86400\n END\nTHEN 1 END\n) ok\n FROM spac a\njoin ph a0 ON (a.ph_id = a0.ph_id)\nleft join ph_state s ON (a.ph_id=s.ph_id)\n WHERE a.ph_enabled=1 AND dp_enabled=1\nGROUP BY a.dp_id\n)', 1),
	(57, 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą', 57, NULL, 0, NULL, 'SELECT sysdate dt, Sum(CASE WHEN ok IS null THEN 1 end) val FROM\n(\nSELECT\na.ph_id\n,Max(\nCASE WHEN s.costa_id=1 AND SYSDATE<=\n CASE nvl(a0.COSTA_G_PER_ID,4)\n   WHEN 6 THEN Add_Months(s.costa_last_check,12*a0.COSTA_G_EXP_VALUE)\n   WHEN 5 THEN Add_Months(s.costa_last_check,a0.COSTA_G_EXP_VALUE)\n   WHEN 4 THEN s.costa_last_check+Nvl(a0.COSTA_G_EXP_VALUE,1)\n   WHEN 3 THEN s.costa_last_check+a0.COSTA_G_EXP_VALUE/24\n   WHEN 2 THEN s.costa_last_check+a0.COSTA_G_EXP_VALUE/1440\n   WHEN 1 THEN s.costa_last_check+a0.COSTA_G_EXP_VALUE/86400\n END\nTHEN 1 END\n) ok\n FROM spac a\njoin ph a0 ON (a.ph_id = a0.ph_id)\nleft join ph_state s ON (a.ph_id=s.ph_id)\n WHERE a.ph_enabled=1 AND dp_enabled=1\nGROUP BY a.ph_id\n)', 1),
	(58, 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą', 58, NULL, 0, NULL, 'WITH h AS\n(\nSELECT xf_id,xf_enabled, xa_enabled,xf_type_delivery\nFROM xf f\njoin xf_type t ON (f.xf_type_id=t.xf_type_id)\njoin xa b ON (f.xa_id=b.xa_id)\nWHERE f.xf_import=0 AND (xf_type_delivery =\'FORM\' AND t.per_id=4  OR xf_type_delivery =\'ELEMENT\')\n)\n,d AS\n(SELECT h.xf_id\n,c.xfe_id\n,CASE WHEN\nh.xf_enabled=1\nAND h.xa_enabled=1\nAND a.xfa_enabled=1\nAND b.xfau_enabled=1\nAND c.xfe_enabled=1\nTHEN 1\nEND overall_enabled\n,Nvl(e.md_cnt,1) md_cnt\nFROM h\njoin xfa a ON (a.xf_id=h.xf_id)\njoin xfau b ON (a.xfa_id=b.xfa_id)\njoin xfe c ON (b.xfau_id=c.xfau_id)\njoin ml d ON (c.ml_id=d.ml_id)\njoin md e ON (d.md_id=e.md_id)\nWHERE h.xf_type_delivery=\'ELEMENT\'\nAND NOT b.point_id IS NULL\nAND NOT Nvl(e.md_id,1)=6\n)\n,g AS\n(SELECT d.*\n,Trunc(SYSDATE)-1 + (i.nr-1)/d.md_cnt bt\n,Trunc(SYSDATE)-1 + i.nr/d.md_cnt et\nFROM d\n,iger i\nWHERE d.md_cnt>=i.nr\n)\nselect\nTrunc(SYSDATE)-1 dt, (1-cnt_bad/Nvl(nullif(cnt_all,0),1))*100 val\nFROM ( SELECT Count(*) cnt_bad FROM\n(\nSELECT\ng.xf_id\nFROM g\nleft join xfe_pl_data b ON (g.xfe_id=b.xfe_id AND g.bt<=b.xfe_t AND b.xfe_t<b.xfe_t AND b.xs_id IN (1,6,7) AND b.improvable=0)\nWHERE b.xfe_id IS NULL\nGROUP BY g.xf_id\nHAVING Max(overall_enabled)=1\nUNION ALL\nSELECT h.xf_id\nFROM h\nleft join xo o ON (h.xf_id=o.xf_id AND o.xo_time>Trunc(SYSDATE) AND o.xo_bt<=Trunc(SYSDATE)-1 AND o.xo_et>Trunc(SYSDATE)-1 AND o.xo_type_id IN (1,5))\nWHERE h.xf_type_delivery=\'FORM\'\nAND o.xo_id IS NULL\n)\n)\n,(SELECT Count(*) cnt_all\nFROM (\nSELECT xf_id FROM d GROUP BY xf_id\nUNION ALL\nSELECT h.xf_id\nFROM h\nWHERE h.xf_type_delivery=\'FORM\'\n)\n)', 1),
	(59, 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą', 59, NULL, 0, NULL, 'WITH\nr AS (SELECT\n Trunc(SYSDATE)-1 - grq_max_duration/1440 d0\n,Trunc(SYSDATE)-1 d1\n,Trunc(SYSDATE) d2\nFROM\n(SELECT Nvl((SELECT To_Number(Nvl(spty_value,spty_default)) FROM spty WHERE spty_id = 52),180) grq_max_duration FROM dual)\n)\n,f as\n(SELECT src_atime, das_id, src_anr\nFROM sta_prq_data,r\nWHERE src_atime BETWEEN d0 AND d2-1/86400\nAND NOT evc_id IS NULL\n)\n,e AS\n(\nSELECT grq_time, das_id, grq_nr FROM\n(SELECT grq_time, das_id, grq_nr\nFROM sta_src_data,r\nWHERE src_atime BETWEEN d0 AND d2-1/86400\nAND NOT evc_id IS NULL\nUNION ALL\nSELECT grq_time, das_id, grq_nr\nFROM r cross join sta_src_data join f USING (src_atime, das_id, src_anr)\nWHERE src_atime BETWEEN d0 AND d2-1/86400\n)\nGROUP BY grq_time, das_id, grq_nr\n)\n,d as\n(SELECT grq_time, das_id, grq_nr\n,Max(CASE WHEN NOT evc_id IS NULL THEN 1 END) E\n  FROM sta_grq_data,r\n  WHERE grq_time BETWEEN d0 AND d2-1/86400\nGROUP BY grq_time,das_id,grq_nr\nHAVING Max(CASE WHEN grq_otype_id IN (4,5,6,7,9,10) THEN grq_otime end) BETWEEN Max(d1) AND Max(d2)-1/86400\n  )\n,c AS\n(SELECT grq_time, das_id, grq_nr FROM (\nSELECT grq_time, das_id, grq_nr\nFROM d WHERE NOT e IS NULL\nUNION ALL\nSELECT grq_time, das_id, grq_nr\nFROM d join e USING (grq_time, das_id, grq_nr)\n)\nGROUP BY grq_time, das_id, grq_nr\n)\nSELECT /*+parallel*/Trunc(SYSDATE)-1 dt,(1-cnt_bad/nullif(cnt_all,0))*100 val FROM\n(SELECT Count(*) cnt_all FROM d)\n,(SELECT Count(*) cnt_bad FROM c)', 1),
	(60, 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą', 60, NULL, 0, NULL, 'SELECT /*+parallel*/Trunc(SYSDATE)-1 dt, Count(*) val FROM\nev WHERE ev_time>=Trunc(SYSDATE)-1 AND ev_time<Trunc(SYSDATE)', 1),
	(61, 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą', 61, NULL, 0, NULL, 'SELECT sysdate dt, Sum(bytes)/1024/1024/1024 val FROM user_segments', 1),
	(62, 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą', 62, NULL, 0, NULL, 'SELECT sysdate dt, Sum(Decode(segment_name,\'PL_DATA_NV\',bytes))/Nvl(nullif(Sum(bytes),0),1)*100 val FROM user_segments\nWHERE tablespace_name = \'EMCOS_TAB\' OR segment_type LIKE \'TABLE%\'', 1),
	(63, 'Turinčių diskretiškumą galiojančių saugotinų išsaugojimų procentas per parą', 63, NULL, 0, NULL, 'SELECT /*+parallel(a) full(a)*/sysdate dt, count(*) val FROM store_pw_buf a', 1);
/*!40000 ALTER TABLE `rpq` ENABLE KEYS */;

-- Dumping structure for table emcor.rpqc
CREATE TABLE IF NOT EXISTS `rpqc` (
  `rpqc_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Užklausos stulpelio identifikatorius',
  `rpq_id` int(10) unsigned NOT NULL COMMENT 'Ataskaitos užklausos identifikatorius',
  `rpqc_nr` smallint(5) unsigned NOT NULL COMMENT 'Ataskaitos užklausos lauko numeris',
  `rpqu_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Užklausos funkcijos identifikatorius',
  `column_name` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Lentelės laukas',
  `rpqc_asc` tinyint(1) DEFAULT NULL COMMENT 'Rūšiavimo didėjančia tvarka požymis',
  PRIMARY KEY (`rpqc_id`),
  KEY `rpqc_rqnr_u` (`rpq_id`,`rpqc_nr`),
  KEY `rpqc_rqu_i` (`rpqu_id`),
  CONSTRAINT `rpqc_rpq_fk` FOREIGN KEY (`rpq_id`) REFERENCES `rpq` (`rpq_id`) ON DELETE CASCADE,
  CONSTRAINT `rpqc_rpqu_fk` FOREIGN KEY (`rpqu_id`) REFERENCES `rpqu` (`rpqu_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ataskaitos užklausos laukai';

-- Dumping data for table emcor.rpqc: ~0 rows (approximately)
/*!40000 ALTER TABLE `rpqc` DISABLE KEYS */;
/*!40000 ALTER TABLE `rpqc` ENABLE KEYS */;

-- Dumping structure for table emcor.rpqf
CREATE TABLE IF NOT EXISTS `rpqf` (
  `rpqf_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Ataskaitos užklausos sąlygos identifikatorius',
  `rpq_id` int(10) unsigned NOT NULL COMMENT 'Ataskaitos užklausos identifikatorius',
  `rpqo_id` smallint(5) unsigned NOT NULL COMMENT 'Užklausos sąlygų operatoriaus identifikatorius',
  `column_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Lentelės laukas',
  `rpqf_value` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Užklausos sąlygos reikšmė',
  `rpqf_essential` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Būtinos sąlygos požymis',
  `rpqf_inv` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Invertavimo požymis',
  `rpqf_desc` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Sąlygos aprašymas',
  `rpqf_nr` smallint(5) unsigned NOT NULL DEFAULT 1 COMMENT 'Parametro eilės numeris',
  `rpqf_allow_empty_values` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Parametro tuščios reikšmės naudojimo požymis',
  `data_type` varchar(20) COLLATE utf8_bin DEFAULT NULL COMMENT 'Duomenų tipas',
  PRIMARY KEY (`rpqf_id`),
  KEY `rpqf_rpq_i` (`rpq_id`),
  KEY `rpqf_rqo_i` (`rpqo_id`),
  CONSTRAINT `rpqf_rpq_fk` FOREIGN KEY (`rpq_id`) REFERENCES `rpq` (`rpq_id`) ON DELETE CASCADE,
  CONSTRAINT `rpqf_rpqo_fk` FOREIGN KEY (`rpqo_id`) REFERENCES `rpqo` (`rpqo_id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=17 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ataskaitos užklausos sąlygos';

-- Dumping data for table emcor.rpqf: ~3 rows (approximately)
/*!40000 ALTER TABLE `rpqf` DISABLE KEYS */;
INSERT INTO `rpqf` (`rpqf_id`, `rpq_id`, `rpqo_id`, `column_name`, `rpqf_value`, `rpqf_essential`, `rpqf_inv`, `rpqf_desc`, `rpqf_nr`, `rpqf_allow_empty_values`, `data_type`) VALUES
	(6, 6, 1, 'timemax', NULL, 1, 0, NULL, 1, 0, 'NUMBER'),
	(11, 14, 1, 'DEPTH', NULL, 1, 0, NULL, 1, 0, 'NUMBER'),
	(16, 16, 1, 'deltalimit', NULL, 1, 0, NULL, 1, 0, 'NUMBER');
/*!40000 ALTER TABLE `rpqf` ENABLE KEYS */;

-- Dumping structure for table emcor.rpqo
CREATE TABLE IF NOT EXISTS `rpqo` (
  `rpqo_id` smallint(5) unsigned NOT NULL COMMENT 'Užklausos sąlygų operatoriaus identifikatorius',
  `rpqo_code` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'Užklausos sąlygų operatoriaus kodas',
  PRIMARY KEY (`rpqo_id`),
  UNIQUE KEY `rpqo_code_u` (`rpqo_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Užklausos sąlygų operatoriai';

-- Dumping data for table emcor.rpqo: ~8 rows (approximately)
/*!40000 ALTER TABLE `rpqo` DISABLE KEYS */;
INSERT INTO `rpqo` (`rpqo_id`, `rpqo_code`) VALUES
	(4, '<'),
	(5, '<='),
	(22, '<>'),
	(1, '='),
	(2, '>'),
	(3, '>='),
	(27, 'IN'),
	(28, 'NOT IN');
/*!40000 ALTER TABLE `rpqo` ENABLE KEYS */;

-- Dumping structure for table emcor.rpqu
CREATE TABLE IF NOT EXISTS `rpqu` (
  `rpqu_id` smallint(5) unsigned NOT NULL COMMENT 'Užklausos funkcijos identifikatorius',
  `rpqu_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Užklausos funkcijos pavadinimas',
  `rpqu_start` varchar(50) COLLATE utf8_bin DEFAULT NULL COMMENT 'Funkcijos pradžia',
  `rpqu_end` varchar(50) COLLATE utf8_bin DEFAULT NULL COMMENT 'Funkcijos pabaiga',
  `rpqu_advanced` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Funkcijos, prieinamos patyrusiems vartotojams, požymis',
  `rpqu_aggr` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Agregavimo funkcijos požymis',
  PRIMARY KEY (`rpqu_id`),
  UNIQUE KEY `rpqu_name_u` (`rpqu_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ataskaitos užklausos funkcijos';

-- Dumping data for table emcor.rpqu: ~8 rows (approximately)
/*!40000 ALTER TABLE `rpqu` DISABLE KEYS */;
INSERT INTO `rpqu` (`rpqu_id`, `rpqu_name`, `rpqu_start`, `rpqu_end`, `rpqu_advanced`, `rpqu_aggr`) VALUES
	(1, 'SUM', 'SUM(', ')', 0, 1),
	(2, 'AVG', 'AVG(', ')', 0, 1),
	(23, 'MIN', 'MIN(', ')', 0, 1),
	(24, 'MAX', 'MAX(', ')', 0, 1),
	(25, 'COUNT', 'COUNT(', ')', 0, 1),
	(26, 'COUNT DISTINCT', 'COUNT(DISTINCT ', ')', 1, 1),
	(27, 'SUM DISTINCT', 'SUM(DISTINCT ', ')', 1, 1),
	(28, 'TRUNC', 'TRUNC(', ')', 1, 0);
/*!40000 ALTER TABLE `rpqu` ENABLE KEYS */;

-- Dumping structure for table emcor.rpty
CREATE TABLE IF NOT EXISTS `rpty` (
  `rpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo savybės identifikatorius',
  `rpty_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo savybės kodas',
  `rpty_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo savybės pavadinimas',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  `rpty_nr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Automatizuotos ataskaitos protokolo savybės eilės numeris rušiavimui',
  PRIMARY KEY (`rpty_id`),
  UNIQUE KEY `rpty_code_u` (`rpty_code`),
  UNIQUE KEY `rpty_name_u` (`rpty_name`),
  KEY `rpty_enum_i` (`enum_id`),
  CONSTRAINT `rpty_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Automatizuotos ataskaitos protokolo savybės';

-- Dumping data for table emcor.rpty: ~63 rows (approximately)
/*!40000 ALTER TABLE `rpty` DISABLE KEYS */;
INSERT INTO `rpty` (`rpty_id`, `rpty_code`, `rpty_name`, `enum_id`, `rpty_nr`) VALUES
	(1, 'Unic', 'Unicode požymis', 82, NULL),
	(2, 'FromName', 'Iš vardo', NULL, NULL),
	(3, 'Subject', 'Tema', NULL, NULL),
	(4, 'FromAddr', 'Iš adreso', NULL, NULL),
	(5, 'Attach', 'Ar prijungti ataskaitą kaip atskirą bylą', 82, NULL),
	(6, 'SMSServer', 'SMS serverio pavadinimas', NULL, NULL),
	(7, 'SMSTran', 'SMS transliteracija', 82, NULL),
	(8, 'URI', 'URI', NULL, NULL),
	(9, 'Compressed_File_Name', 'Supakuoto failo vardas', NULL, NULL),
	(10, 'User', 'Prisijungimo vardas', NULL, NULL),
	(11, 'Password', 'Prisijungimo slaptažodis', NULL, NULL),
	(12, 'AttType', 'Priedo formatas', 96, NULL),
	(13, 'Compression', 'Ar suspausti duomenis', 82, NULL),
	(14, 'OUTPUT_FILENAME_PREFIX', 'Suformuotos bylos pavadinimo priešdėlis', NULL, NULL),
	(15, 'CS_XMAIL', 'Elektroninio pašto adresas', NULL, NULL),
	(16, 'CC', 'Elektroninio pašto adresas, kuriuo turi būti išsiųsta kopija', NULL, NULL),
	(17, 'FTP_HOSTNAME', 'FTP HOSTNAME', NULL, NULL),
	(18, 'FTP_USERNAME', 'FTP USERNAME', NULL, NULL),
	(19, 'FTP_PASSWORD', 'FTP PASSWORD', NULL, NULL),
	(20, 'FTP_REMOTEDIR', 'FTP REMOTE DIR', NULL, NULL),
	(21, 'PortNumber', 'Porto numeris', NULL, NULL),
	(22, 'BaudRate', 'Perdavimo greitis, bodais', 8, NULL),
	(23, 'ByteSize', 'Ilgis, baitais', NULL, NULL),
	(24, 'Parity', 'Lyginumas', 4, NULL),
	(25, 'StopBits', 'STOP bitai', 2, NULL),
	(26, 'ConnectString', 'Prisijungimo eilutė', NULL, NULL),
	(27, 'SMSPDU', 'SMS-žinutės siuntimas PDU režime', 82, NULL),
	(28, 'SMSCenter', 'SMS-žinutės perdavimo centro numeris', NULL, NULL),
	(29, 'ConfigFileName', 'Konfigūracinės bylos vardas', NULL, NULL),
	(30, 'FOLDER', 'Katalogas', NULL, NULL),
	(31, 'IPAddress', 'IP adresas', NULL, NULL),
	(32, 'IPPort', 'IP prievadas', NULL, NULL),
	(33, 'ResendCount', 'Duomenų perdavimo pakartojimų skaičius', NULL, NULL),
	(34, 'TimeoutSec', 'Atsakomojo paketo laukimo laikas sekundėmis', NULL, NULL),
	(35, 'SNMP_Trap_HostFrom', 'Siuntėjo IP adresas', NULL, NULL),
	(36, 'SNMP_Trap_HostTo', 'Gavėjo IP adresas', NULL, NULL),
	(37, 'SNMP_Trap_Community', 'Community,- bendrijos pavadinimas', NULL, NULL),
	(38, 'SNMP_Trap_Generic', 'Generic,- gaudyklės tipas', NULL, NULL),
	(39, 'SNMP_Trap_Specific', 'Specific,- numeris tam tikrai gaudyklei', NULL, NULL),
	(40, 'SNMP_Trap_Enterprise', 'Enterprise, - pilnas įmonės OID gaudyklėi', NULL, NULL),
	(41, 'SNMP_Trap_Seconds', 'Laikas', NULL, NULL),
	(42, 'SNMP_Trap_MIBName', 'MIB pavadinimas (Management Information Base)', NULL, NULL),
	(43, 'Url_zip', 'Zip formato archyvinio failo gavimo scripto adresas', NULL, NULL),
	(44, 'SMS_FORCED', 'Priverstinis pranešimo išsiuntimas pasiekus limitą', 82, NULL),
	(48, 'HTTP_Globos_Username', 'Vartotojo vardas', NULL, NULL),
	(49, 'HTTP_Globos_Password', 'Vartotojo slaptažodis', NULL, NULL),
	(50, 'FromBox_INN', 'Pranešimo siuntėjo dežutės organizacijos INN', NULL, NULL),
	(54, 'ToBox_INN', 'Pranešimo gavėjo dežutės organizacijos INN', NULL, NULL),
	(55, 'ToBox_KPP', 'Pranešimo gavėjo dežutės organizacijos KPP', NULL, NULL),
	(58, 'Certificate_Name', 'Sertifikato savininko pavadinimas', NULL, NULL),
	(59, 'Certificate_Thumbprint', 'Sertifikato atspaudas', NULL, NULL),
	(60, 'Signature', 'Elektroninis parašas', NULL, NULL),
	(61, 'NeedRecipientSignature', 'Siunčiamo dokumento gavėjo parašo užklausimas', NULL, NULL),
	(62, 'TargetHost', 'SMSC serverio pavadinimas arba IP adresas', NULL, NULL),
	(63, 'TargetPort', 'SMSC serverio portas', NULL, NULL),
	(64, 'Username', 'SMSC serverio vartotojo vardas', NULL, NULL),
	(65, 'Source_Addr', 'Išeities adresas', NULL, NULL),
	(66, 'UsingFileForDestination', 'Ataskaitos .txt failo naudojimas gavėjo numerio ir siunčiamo pranešimo nustatymui', NULL, NULL),
	(67, 'Unicode', 'Koduotės UCS2 (Unicode) naudojimas', NULL, NULL),
	(68, 'BodyFilename', 'Byla su papildomu laiško tekstu', NULL, NULL),
	(69, 'FTP_PORT', 'Ftp portas', NULL, NULL),
	(70, 'FTP_PASSIVE', 'Pasyvus režimas', NULL, NULL),
	(71, 'FTP_TRANSFERMODE', 'Perdavimo režimas', NULL, NULL);
/*!40000 ALTER TABLE `rpty` ENABLE KEYS */;

-- Dumping structure for table emcor.rp_das
CREATE TABLE IF NOT EXISTS `rp_das` (
  `rp_id` int(10) unsigned NOT NULL COMMENT 'Ataskaitos identifikatorius',
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  `atom_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Atomo naudojimo požymis',
  `atom_activated` datetime NOT NULL DEFAULT '1899-12-30 00:00:00' COMMENT 'Atomo paskutinio aktyvavimo data',
  PRIMARY KEY (`rp_id`),
  KEY `rp_das_das_fk` (`das_id`),
  CONSTRAINT `rp_das_das_fk` FOREIGN KEY (`das_id`) REFERENCES `das` (`das_id`) ON DELETE CASCADE,
  CONSTRAINT `rp_das_rp_fk` FOREIGN KEY (`rp_id`) REFERENCES `rp` (`rp_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Ataskaitų automatinis priskyrimas duomenų surinkimo serveriams';

-- Dumping data for table emcor.rp_das: ~0 rows (approximately)
/*!40000 ALTER TABLE `rp_das` DISABLE KEYS */;
/*!40000 ALTER TABLE `rp_das` ENABLE KEYS */;

-- Dumping structure for table emcor.rp_das_frc
CREATE TABLE IF NOT EXISTS `rp_das_frc` (
  `rp_id` int(10) unsigned NOT NULL COMMENT 'Ataskaitos identifikatorius',
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  PRIMARY KEY (`rp_id`,`das_id`),
  KEY `rp_das_frc_das_fk` (`das_id`),
  CONSTRAINT `rp_das_frc_das_fk` FOREIGN KEY (`das_id`) REFERENCES `das` (`das_id`) ON DELETE CASCADE,
  CONSTRAINT `rp_das_frc_rp_fk` FOREIGN KEY (`rp_id`) REFERENCES `rp` (`rp_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Ataskaitų priverstinis priskyrimas duomenų surinkimo serveriams';

-- Dumping data for table emcor.rp_das_frc: ~0 rows (approximately)
/*!40000 ALTER TABLE `rp_das_frc` DISABLE KEYS */;
/*!40000 ALTER TABLE `rp_das_frc` ENABLE KEYS */;

-- Dumping structure for table emcor.rp_das_log
CREATE TABLE IF NOT EXISTS `rp_das_log` (
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `atom_log_id` mediumint(8) unsigned NOT NULL COMMENT 'Atomų priskyrimo duomenų surinkimo serveriams istorijos įrašo ID',
  `rp_id` int(10) unsigned NOT NULL COMMENT 'Ataskaitos identifikatorius',
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  `atom_enabled` tinyint(1) NOT NULL COMMENT 'Atomo naudojimo požymis',
  `atom_activated` datetime NOT NULL COMMENT 'Atomo paskutinio aktyvavimo data',
  PRIMARY KEY (`db_time`,`atom_log_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Ataskaitų automatinio priskyrimo duomenų surinkimo serveriams istorija';

-- Dumping data for table emcor.rp_das_log: ~0 rows (approximately)
/*!40000 ALTER TABLE `rp_das_log` DISABLE KEYS */;
/*!40000 ALTER TABLE `rp_das_log` ENABLE KEYS */;

-- Dumping structure for table emcor.rp_fpty
CREATE TABLE IF NOT EXISTS `rp_fpty` (
  `rp_id` int(10) unsigned NOT NULL COMMENT 'Ataskaitos identifikatorius',
  `fpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ataskaitos formato savybės identifikatorius',
  `fpty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ataskaitos formato savybės reikšmė',
  PRIMARY KEY (`rp_id`,`fpty_id`),
  KEY `rp_fpty_fpty_i` (`fpty_id`),
  CONSTRAINT `rp_fpty_fpty_fk` FOREIGN KEY (`fpty_id`) REFERENCES `fpty` (`fpty_id`),
  CONSTRAINT `rp_fpty_rp_fk` FOREIGN KEY (`rp_id`) REFERENCES `rp` (`rp_id`) ON DELETE CASCADE,
  CONSTRAINT `RP_FPTY_SYMBOL_CHECK` CHECK (nullif(regexp_replace(`fpty_value`,'([[:print:]])+',''),'') is null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Formato savybės ataskaitai ';

-- Dumping data for table emcor.rp_fpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `rp_fpty` DISABLE KEYS */;
/*!40000 ALTER TABLE `rp_fpty` ENABLE KEYS */;

-- Dumping structure for table emcor.rp_log
CREATE TABLE IF NOT EXISTS `rp_log` (
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `log_id` mediumint(8) unsigned NOT NULL COMMENT 'Identifikatorius',
  `rp_id` int(10) unsigned NOT NULL COMMENT 'Ataskaitos identifikatorius',
  `rpa_id` int(10) unsigned DEFAULT NULL COMMENT 'Automatizuotos ataskaitos identifikatorius',
  `fill` tinyint(3) unsigned DEFAULT NULL COMMENT 'Ataskaitos užpildymo statusas (0 - gerai, NULL - nereikėjo)',
  `form` tinyint(3) unsigned DEFAULT NULL COMMENT 'Ataskaitos formavimo statusas (0 - gerai, NULL - nereikėjo)',
  `send` tinyint(3) unsigned DEFAULT NULL COMMENT 'Ataskaitos siuntimo statusas (0 - gerai, NULL - nereikėjo)',
  `xml_name` varchar(200) COLLATE utf8_bin DEFAULT NULL COMMENT 'XML failo pavadinimas',
  `report_name` varchar(200) COLLATE utf8_bin DEFAULT NULL COMMENT 'Ataskaitos pavadinimas',
  `from_da` datetime DEFAULT NULL COMMENT 'Ataskaitos laiko intervalo pradžia',
  `to_da` datetime DEFAULT NULL COMMENT 'Ataskaitos laiko intervalo pabaiga',
  `fill_bt` datetime DEFAULT NULL COMMENT 'Ataskaitos užpildymo pradžia',
  `fill_et` datetime DEFAULT NULL COMMENT 'Ataskaitos užpildymo pabaiga',
  `form_bt` datetime DEFAULT NULL COMMENT 'Ataskaitos formavimo pradžia',
  `form_et` datetime DEFAULT NULL COMMENT 'Ataskaitos formavimo pabaiga',
  `send_bt` datetime DEFAULT NULL COMMENT 'Ataskaitos siuntimo pradžia',
  `send_et` datetime DEFAULT NULL COMMENT 'Ataskaitos siuntimo pabaiga',
  `ev_time` datetime DEFAULT NULL COMMENT 'Įvykio laikas',
  `ev_id` bigint(20) unsigned DEFAULT NULL COMMENT 'Įvykio ID',
  `eva_id` int(10) unsigned DEFAULT NULL COMMENT 'Įvykių atvejo identifikatorius',
  `gr_id` int(10) unsigned DEFAULT NULL COMMENT 'Grupės identifikatorius',
  `log_comment` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Ataskaitos komentaras',
  `user_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Vartotojo identifikatorius',
  `rp_repeat` tinyint(3) unsigned DEFAULT NULL COMMENT 'Ataskaitos pakartojimo numeris',
  `das_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  PRIMARY KEY (`db_time`,`log_id`),
  KEY `rp_log_rpa_i` (`rpa_id`,`db_time`),
  KEY `rp_log_rp_i` (`rp_id`,`db_time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ataskaitų formavimo ir siuntimo žurnalas'
 PARTITION BY RANGE (
    to_days(db_time))
(PARTITION par_201708 VALUES LESS THAN (736751) ENGINE = InnoDB,
 PARTITION par_201709 VALUES LESS THAN (736758) ENGINE = InnoDB,
 PARTITION par_201710 VALUES LESS THAN (736765) ENGINE = InnoDB);

-- Dumping data for table emcor.rp_log: ~3 rows (approximately)
/*!40000 ALTER TABLE `rp_log` DISABLE KEYS */;
/*!40000 ALTER TABLE `rp_log` ENABLE KEYS */;

-- Dumping structure for table emcor.rp_type
CREATE TABLE IF NOT EXISTS `rp_type` (
  `rp_type_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Ataskaitos tipo identifikatorius',
  `rp_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ataskaitos tipo pavadinimas',
  PRIMARY KEY (`rp_type_id`),
  UNIQUE KEY `rp_type_name_u` (`rp_type_name`)
) ENGINE=InnoDB AUTO_INCREMENT=17 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ataskaitos tipai';

-- Dumping data for table emcor.rp_type: ~6 rows (approximately)
/*!40000 ALTER TABLE `rp_type` DISABLE KEYS */;
INSERT INTO `rp_type` (`rp_type_id`, `rp_type_name`) VALUES
	(6, 'DB sesijų monitoringas'),
	(13, 'DB session monitoring'),
	(12, 'EMCOS monitoringas'),
	(11, 'Senų duomenų trynimo monitoringas'),
	(16, 'Sistemos gamintojams'),
	(1, 'Vartotojų informacija');
/*!40000 ALTER TABLE `rp_type` ENABLE KEYS */;

-- Dumping structure for table emcor.rp_ug
CREATE TABLE IF NOT EXISTS `rp_ug` (
  `rp_id` int(10) unsigned NOT NULL COMMENT 'Ataskaitos identifikatorius',
  `ug_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojų grupės identifikatorius',
  `al_id` tinyint(3) unsigned NOT NULL DEFAULT 0 COMMENT 'Prieigos lygis (0-peržiūra,1-redagavimas)',
  PRIMARY KEY (`rp_id`,`ug_id`),
  KEY `rp_ug_ug_i` (`ug_id`),
  CONSTRAINT `rp_ug_rp_fk` FOREIGN KEY (`rp_id`) REFERENCES `rp` (`rp_id`) ON DELETE CASCADE,
  CONSTRAINT `rp_ug_ug_fk` FOREIGN KEY (`ug_id`) REFERENCES `ug` (`ug_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Vartotojų grupėms pasiekiamos ataskaitos';

-- Dumping data for table emcor.rp_ug: ~0 rows (approximately)
/*!40000 ALTER TABLE `rp_ug` DISABLE KEYS */;
/*!40000 ALTER TABLE `rp_ug` ENABLE KEYS */;

-- Dumping structure for table emcor.rtp
CREATE TABLE IF NOT EXISTS `rtp` (
  `rtp_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Realaus laiko matavimų nuskaitymo profilio identifikatorius',
  `rtp_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Realaus laiko matavimų nuskaitymo profilio kodas',
  `rtp_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Realaus laiko matavimų nuskaitymo profilio pavadinimas',
  PRIMARY KEY (`rtp_id`),
  UNIQUE KEY `rtp_code_u` (`rtp_code`),
  UNIQUE KEY `rtp_name_u` (`rtp_name`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Realaus laiko matavimų nuskaitymo profiliai';

-- Dumping data for table emcor.rtp: ~0 rows (approximately)
/*!40000 ALTER TABLE `rtp` DISABLE KEYS */;
INSERT INTO `rtp` (`rtp_id`, `rtp_code`, `rtp_name`) VALUES
	(1, 'EMCOS_STATUS_PROFILE', 'EMCOS_STATUS profilis');
/*!40000 ALTER TABLE `rtp` ENABLE KEYS */;

-- Dumping structure for table emcor.rtp_data
CREATE TABLE IF NOT EXISTS `rtp_data` (
  `rtp_id` mediumint(8) unsigned NOT NULL COMMENT 'Realaus laiko matavimų nuskaitymo profilio identifikatorius',
  `ml_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo linijos identifikatorius',
  `rtp_ml_enabled` tinyint(1) NOT NULL COMMENT 'Matavimo linijos naudojimo realaus laiko matavimų profilyje požymis',
  `per_id` tinyint(3) unsigned NOT NULL COMMENT 'Periodo identifikatorius',
  `rtp_int_value` mediumint(8) unsigned NOT NULL COMMENT 'Periodų kiekis apibrėžiantis trukmę, kurią matavimo reikšmė laikoma dabartine',
  PRIMARY KEY (`rtp_id`,`ml_id`),
  KEY `rtp_data_ml_i` (`ml_id`),
  KEY `rtp_data_per_i` (`per_id`),
  CONSTRAINT `rtp_data_ml_fk` FOREIGN KEY (`ml_id`) REFERENCES `ml` (`ml_id`) ON DELETE CASCADE,
  CONSTRAINT `rtp_data_per_fk` FOREIGN KEY (`per_id`) REFERENCES `per` (`per_id`) ON DELETE CASCADE,
  CONSTRAINT `rtp_data_rtp_fk` FOREIGN KEY (`rtp_id`) REFERENCES `rtp` (`rtp_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Realaus laiko matavimų nuskaitymo profilių duomenys';

-- Dumping data for table emcor.rtp_data: ~34 rows (approximately)
/*!40000 ALTER TABLE `rtp_data` DISABLE KEYS */;
INSERT INTO `rtp_data` (`rtp_id`, `ml_id`, `rtp_ml_enabled`, `per_id`, `rtp_int_value`) VALUES
	(1, 4902, 1, 3, 36),
	(1, 8672, 1, 3, 36),
	(1, 8678, 1, 3, 36),
	(1, 8696, 1, 3, 36),
	(1, 8702, 1, 3, 36),
	(1, 8708, 1, 3, 36),
	(1, 8714, 1, 3, 36),
	(1, 8720, 1, 3, 36),
	(1, 8836, 1, 3, 36),
	(1, 8842, 1, 3, 36),
	(1, 8848, 1, 3, 36),
	(1, 8854, 1, 3, 36),
	(1, 8860, 1, 3, 36),
	(1, 8867, 1, 2, 90),
	(1, 8868, 1, 2, 90),
	(1, 8869, 1, 2, 90),
	(1, 8870, 1, 2, 90),
	(1, 8871, 1, 2, 90),
	(1, 8884, 1, 3, 36),
	(1, 8885, 1, 3, 36),
	(1, 8886, 1, 3, 36),
	(1, 8887, 1, 3, 36),
	(1, 8888, 1, 3, 36),
	(1, 8889, 1, 3, 36),
	(1, 8890, 1, 3, 36),
	(1, 8891, 1, 3, 36),
	(1, 8894, 1, 3, 36),
	(1, 8895, 1, 3, 36),
	(1, 8899, 1, 3, 36),
	(1, 8902, 1, 3, 36),
	(1, 8903, 1, 3, 36),
	(1, 8930, 1, 3, 36),
	(1, 8974, 1, 3, 36),
	(1, 8977, 1, 3, 36);
/*!40000 ALTER TABLE `rtp_data` ENABLE KEYS */;

-- Dumping structure for table emcor.rt_pl
CREATE TABLE IF NOT EXISTS `rt_pl` (
  `pl_id` int(10) unsigned NOT NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
  `sep_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `pl_t` datetime NOT NULL COMMENT 'Matavimo linijos matavimo taške duomenų laikas',
  `pl_v` double NOT NULL COMMENT 'Matavimo linijos matavimo taške duomenų reikšmė',
  `pl_rt` datetime DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų nuskaitymo laikas',
  `pl_rv` double DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų pirminė reikšmė',
  `pck_t` datetime NOT NULL COMMENT 'Duomenų paketo laiko žymė',
  `pck_n` smallint(5) unsigned DEFAULT NULL COMMENT 'Duomenų paketo numeris',
  `db_time` datetime NOT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `manual_input` tinyint(1) NOT NULL COMMENT 'Rankinio įvedimo požymis',
  `improvable` tinyint(1) NOT NULL COMMENT 'Požymis, ar galimi geresni duomenys',
  `hi_v` double DEFAULT NULL COMMENT 'Viršutinės įspėjamosios ribos reikšmė',
  `lo_v` double DEFAULT NULL COMMENT 'Apatinės įspėjamosios ribos reikšmė',
  `dstatus` varbinary(20) DEFAULT NULL COMMENT 'Duomenų statuso kodinė išraiška',
  `exp_t` datetime DEFAULT NULL,
  PRIMARY KEY (`pl_id`),
  KEY `rt_pl_db_time_i` (`db_time`),
  KEY `rt_pl_sep_i` (`sep_id`),
  CONSTRAINT `rt_pl_pl_fk` FOREIGN KEY (`pl_id`) REFERENCES `pl` (`pl_id`) ON DELETE CASCADE,
  CONSTRAINT `rt_pl_sep_fk` FOREIGN KEY (`sep_id`) REFERENCES `sep` (`sep_id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Taškų realaus laiko matavimų duomenys';

-- Dumping data for table emcor.rt_pl: ~26 rows (approximately)
/*!40000 ALTER TABLE `rt_pl` DISABLE KEYS */;
INSERT INTO `rt_pl` (`pl_id`, `sep_id`, `pl_t`, `pl_v`, `pl_rt`, `pl_rv`, `pck_t`, `pck_n`, `db_time`, `manual_input`, `improvable`, `hi_v`, `lo_v`, `dstatus`, `exp_t`) VALUES
	(1, 1, '2017-04-02 00:00:00', 0.28, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:00:00'),
	(2, 2, '2017-04-02 00:00:00', 0.24, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:00:00'),
	(3, 3, '2017-04-02 00:00:00', 118, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:02:09'),
	(4, 8, '2017-04-01 00:00:00', 0, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:00:00'),
	(5, 9, '2017-04-02 00:00:00', 0, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:02:09'),
	(6, 6, '2017-04-02 00:00:00', 0, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:00:00'),
	(9, 4, '2017-04-02 00:00:00', 11800, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:02:09'),
	(10, 5, '2017-04-02 00:00:00', 100, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:02:09'),
	(11, 14, '2017-04-02 20:00:00', 3, '2017-04-02 20:31:00', NULL, '2017-04-02 20:31:00', NULL, '2017-04-02 20:31:00', 0, 0, NULL, NULL, NULL, '2017-04-02 21:30:00'),
	(12, 15, '2017-04-02 20:00:00', 0, '2017-04-02 20:31:00', NULL, '2017-04-02 20:31:01', NULL, '2017-04-02 20:31:01', 0, 0, NULL, NULL, NULL, '2017-04-02 21:30:00'),
	(13, 11, '2017-04-02 00:00:00', 6, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:02:09'),
	(14, 7, '2017-04-02 00:00:00', 100, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:02:09'),
	(15, 13, '2017-04-02 00:00:00', 0, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:02:09'),
	(16, 16, '2017-04-02 20:00:00', 0, '2017-04-02 20:31:00', NULL, '2017-04-02 20:31:01', NULL, '2017-04-02 20:31:01', 0, 0, NULL, NULL, NULL, '2017-04-02 21:30:00'),
	(18, 18, '2017-04-01 00:00:00', 100, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:00:00'),
	(19, 19, '2017-04-01 00:00:00', 100, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:00:00'),
	(20, 20, '2017-04-01 00:00:00', 0, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:00:00'),
	(21, 21, '2017-04-02 00:00:00', 0, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:00:00'),
	(26, 26, '2017-04-02 00:00:00', 0, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:00:00'),
	(28, 28, '2017-04-02 00:00:00', 0, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:00:00'),
	(29, 29, '2017-04-02 00:00:00', 2.498048, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', NULL, '2017-04-02 00:02:09', 0, 0, NULL, NULL, NULL, '2017-04-03 12:00:00'),
	(33, 33, '2017-04-01 00:00:00', 100, '2017-04-02 00:02:02', NULL, '2017-04-02 00:02:06', NULL, '2017-04-02 00:02:06', 0, 0, NULL, NULL, NULL, '2017-04-02 12:00:00'),
	(35, 35, '2017-04-01 00:00:00', 6, '2017-04-02 00:02:00', NULL, '2017-04-02 00:02:01', NULL, '2017-04-02 00:02:01', 0, 0, NULL, NULL, NULL, '2017-04-03 12:00:00'),
	(36, 36, '2017-04-02 00:00:00', 0.17041, '2017-04-02 00:02:00', NULL, '2017-04-02 00:02:02', NULL, '2017-04-02 00:02:02', 0, 0, NULL, NULL, NULL, '2017-04-03 12:00:00'),
	(37, 37, '2017-04-02 00:00:00', 0.156128, '2017-04-02 00:02:00', NULL, '2017-04-02 00:02:01', NULL, '2017-04-02 00:02:01', 0, 0, NULL, NULL, NULL, '2017-04-03 12:00:00'),
	(38, 38, '2017-04-02 20:00:00', 0, '2017-04-02 20:31:00', NULL, '2017-04-02 20:31:01', NULL, '2017-04-02 20:31:01', 0, 0, NULL, NULL, NULL, '2017-04-02 21:30:00');
/*!40000 ALTER TABLE `rt_pl` ENABLE KEYS */;

-- Dumping structure for table emcor.sam
CREATE TABLE IF NOT EXISTS `sam` (
  `sam_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Šablono identifikatorius',
  `sam_code` varchar(80) COLLATE utf8_bin NOT NULL COMMENT 'Šablono kodas',
  `sam_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Šablono pavadinimas',
  `sam_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Šablonų tipo ID',
  `md_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimo diskretiškumo identifikatorius',
  `hld_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Šventinių dienų rinkinio identifikatorius',
  `use_const_val` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Pastovios reikšmės naudojimo požymis',
  `const_val` double NOT NULL DEFAULT 0 COMMENT 'Pastovi reikšmė',
  `sam_cyclic` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar šablono periodai sudaro pastovų metų ciklą',
  `sam_tmpl_id` int(10) unsigned DEFAULT NULL COMMENT 'Šablono atnaujinimo modelio identifikatorius',
  `src_mt_id` int(10) unsigned DEFAULT NULL COMMENT 'Išeities monitoringo rodiklio identifikatorius',
  `sam_auto_calc` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar šablonas bus automatiškai perskaičiuojamas',
  PRIMARY KEY (`sam_id`),
  UNIQUE KEY `sam_code_u` (`sam_code`),
  UNIQUE KEY `sam_name_u` (`sam_name`),
  UNIQUE KEY `sam_tmpl_mt_un` (`sam_tmpl_id`,`src_mt_id`),
  KEY `sam_hld_i` (`hld_id`),
  KEY `sam_md_i` (`md_id`),
  KEY `sam_sam_type_i` (`sam_type_id`),
  KEY `sam_sam_tmpl_i` (`sam_tmpl_id`),
  KEY `sam_src_mt_i` (`src_mt_id`),
  CONSTRAINT `sam_hld_fk` FOREIGN KEY (`hld_id`) REFERENCES `hld` (`hld_id`),
  CONSTRAINT `sam_md_fk` FOREIGN KEY (`md_id`) REFERENCES `md` (`md_id`) ON DELETE CASCADE,
  CONSTRAINT `sam_sam_tmpl_fk` FOREIGN KEY (`sam_tmpl_id`) REFERENCES `sam_tmpl` (`sam_tmpl_id`) ON DELETE SET NULL,
  CONSTRAINT `sam_sam_type_fk` FOREIGN KEY (`sam_type_id`) REFERENCES `sam_type` (`sam_type_id`),
  CONSTRAINT `sam_src_mt_fk` FOREIGN KEY (`src_mt_id`) REFERENCES `mt` (`mt_id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Šablonai';

-- Dumping data for table emcor.sam: ~0 rows (approximately)
/*!40000 ALTER TABLE `sam` DISABLE KEYS */;
/*!40000 ALTER TABLE `sam` ENABLE KEYS */;

-- Dumping structure for table emcor.samd
CREATE TABLE IF NOT EXISTS `samd` (
  `samd_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Šablono dienos programos ID',
  `samd_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Šablono dienos programos pavadinimas',
  `md_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimo diskretiškumo identifikatorius',
  `samd_common` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Bendro naudojimo dienos programos požymis',
  PRIMARY KEY (`samd_id`),
  UNIQUE KEY `samd_name_u` (`samd_name`),
  KEY `samd_common_i` (`samd_common`),
  KEY `samd_md_i` (`md_id`),
  CONSTRAINT `samd_md_fk` FOREIGN KEY (`md_id`) REFERENCES `md` (`md_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Šablonų dienos programos';

-- Dumping data for table emcor.samd: ~0 rows (approximately)
/*!40000 ALTER TABLE `samd` DISABLE KEYS */;
/*!40000 ALTER TABLE `samd` ENABLE KEYS */;

-- Dumping structure for table emcor.samd_data
CREATE TABLE IF NOT EXISTS `samd_data` (
  `samd_id` int(10) unsigned NOT NULL COMMENT 'Šablono dienos programos ID',
  `nr` smallint(5) unsigned NOT NULL COMMENT 'Numeris',
  `sam_v` double DEFAULT NULL COMMENT 'Šablono elemento reikšmė',
  PRIMARY KEY (`samd_id`,`nr`),
  CONSTRAINT `samd_data_samd_fk` FOREIGN KEY (`samd_id`) REFERENCES `samd` (`samd_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Šablono dienos programos duomenys';

-- Dumping data for table emcor.samd_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `samd_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `samd_data` ENABLE KEYS */;

-- Dumping structure for table emcor.samp
CREATE TABLE IF NOT EXISTS `samp` (
  `samp_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Šablono periodo ID',
  `sam_id` int(10) unsigned NOT NULL COMMENT 'Šablono identifikatorius',
  `bmm` tinyint(3) unsigned DEFAULT NULL COMMENT 'Periodo pradžios mėnuo',
  `bdd` tinyint(3) unsigned DEFAULT NULL COMMENT 'Periodo pradžios diena',
  `emm` tinyint(3) unsigned DEFAULT NULL COMMENT 'Pabaigos mėnuo',
  `edd` tinyint(3) unsigned DEFAULT NULL COMMENT 'Pabaigos diena',
  `samw_id` int(10) unsigned NOT NULL COMMENT 'Šablono savaitės programos ID',
  `bt` datetime DEFAULT NULL COMMENT 'Periodo pradžia',
  `et` datetime DEFAULT NULL COMMENT 'Periodo pabaiga',
  PRIMARY KEY (`samp_id`),
  UNIQUE KEY `samp_sam_u` (`sam_id`,`bmm`,`bdd`,`emm`,`edd`,`bt`,`et`),
  KEY `samp_samw_i` (`samw_id`),
  CONSTRAINT `samp_sam_fk` FOREIGN KEY (`sam_id`) REFERENCES `sam` (`sam_id`) ON DELETE CASCADE,
  CONSTRAINT `samp_samw_fk` FOREIGN KEY (`samw_id`) REFERENCES `samw` (`samw_id`),
  CONSTRAINT `SAMP_NOT_IN_2_CHK` CHECK (`bmm` is not null and `bdd` is not null and `emm` is not null and `edd` is not null and `bt` is null and `et` is null or `bmm` is null and `bdd` is null and `emm` is null and `edd` is null and `bt` is not null and `et` is not null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Šablono periodai';

-- Dumping data for table emcor.samp: ~0 rows (approximately)
/*!40000 ALTER TABLE `samp` DISABLE KEYS */;
/*!40000 ALTER TABLE `samp` ENABLE KEYS */;

-- Dumping structure for table emcor.samp_state
CREATE TABLE IF NOT EXISTS `samp_state` (
  `samp_id` int(10) unsigned NOT NULL COMMENT 'Šablono periodo identifikatorius',
  `sam_calc_date` datetime DEFAULT NULL COMMENT 'Šablono periodo reikšmių paskutinio perskaičiavimo data',
  `sam_calc_date_req` datetime DEFAULT NULL COMMENT 'Šablono periodo reikšmių perskaičiavimo užsakymo data',
  `sam_crs` double NOT NULL COMMENT 'Šablono periodo reikšmių kontrolinė suma',
  PRIMARY KEY (`samp_id`),
  CONSTRAINT `samp_state_samp_fk` FOREIGN KEY (`samp_id`) REFERENCES `samp` (`samp_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Šablono periodų reikšmių būklės';

-- Dumping data for table emcor.samp_state: ~0 rows (approximately)
/*!40000 ALTER TABLE `samp_state` DISABLE KEYS */;
/*!40000 ALTER TABLE `samp_state` ENABLE KEYS */;

-- Dumping structure for table emcor.samu
CREATE TABLE IF NOT EXISTS `samu` (
  `mt_id` int(10) unsigned NOT NULL COMMENT 'Monitoringe naudojamo rodiklio ID',
  `samu_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Automatinio šablonų atnaujinimo pagal monitoringo rodiklių istoriją užduočių tipo identifikatorius',
  `sam_id` int(10) unsigned NOT NULL COMMENT 'Šablono identifikatorius',
  `samu_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Automatinio šablono atnaujinimo pagal monitoringo rodiklio istoriją užduoties naudojimo požymis',
  `samp_per_id` tinyint(3) unsigned NOT NULL DEFAULT 5 COMMENT 'Periodų, kuriais nusakoma šablono periodo trukmė, identifikatorius',
  `samp_int_value` mediumint(8) unsigned NOT NULL DEFAULT 1 COMMENT 'Periodų kiekis, nusakantis šablono periodo trukmę',
  `samw_type_id` tinyint(3) unsigned NOT NULL DEFAULT 1 COMMENT 'Šablonų savaitės programų tipo identifikatorius',
  `samu_lag_per_id` tinyint(3) unsigned NOT NULL DEFAULT 4 COMMENT 'Periodų, kuriais nusakomas nuskaitomos monitoringo rodiklio istorijos poslinkis, identifikatorius',
  `samu_lag` mediumint(8) unsigned NOT NULL DEFAULT 1 COMMENT 'Periodų kiekis, nusakantis nuskaitomos monitoringo rodiklio istorijos poslinkį',
  `samu_depth_per_id` tinyint(3) unsigned NOT NULL DEFAULT 5 COMMENT 'Periodų, kuriais nusakomas nuskaitomos monitoringo rodiklio istorijos gylis, identifikatorius',
  `samu_depth` mediumint(8) unsigned NOT NULL DEFAULT 1 COMMENT 'Periodų kiekis, nusakantis nuskaitomos monitoringo rodiklio istorijos gylį',
  `sch_id` mediumint(8) unsigned NOT NULL COMMENT 'Tvarkaraščio identifikatorius',
  PRIMARY KEY (`mt_id`,`samu_type_id`),
  KEY `samu_depth_per_i` (`samu_depth_per_id`),
  KEY `samu_lag_per_i` (`samu_lag_per_id`),
  KEY `samu_sam_i` (`sam_id`),
  KEY `samu_samp_per_i` (`samp_per_id`),
  KEY `samu_samu_type_i` (`samu_type_id`),
  KEY `samu_samw_type_i` (`samw_type_id`),
  KEY `samu_sch_i` (`sch_id`),
  CONSTRAINT `samu_depth_per_fk` FOREIGN KEY (`samu_depth_per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `samu_lag_per_fk` FOREIGN KEY (`samu_lag_per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `samu_mt_fk` FOREIGN KEY (`mt_id`) REFERENCES `mt` (`mt_id`) ON DELETE CASCADE,
  CONSTRAINT `samu_sam_fk` FOREIGN KEY (`sam_id`) REFERENCES `sam` (`sam_id`) ON DELETE CASCADE,
  CONSTRAINT `samu_samp_per_fk` FOREIGN KEY (`samp_per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `samu_samu_type_fk` FOREIGN KEY (`samu_type_id`) REFERENCES `samu_type` (`samu_type_id`),
  CONSTRAINT `samu_samw_type_fk` FOREIGN KEY (`samw_type_id`) REFERENCES `samw_type` (`samw_type_id`),
  CONSTRAINT `samu_sch_fk` FOREIGN KEY (`sch_id`) REFERENCES `sch` (`sch_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Automatinio šablonų atnaujinimo pagal monitoringo rodiklių istoriją užduotys';

-- Dumping data for table emcor.samu: ~0 rows (approximately)
/*!40000 ALTER TABLE `samu` DISABLE KEYS */;
/*!40000 ALTER TABLE `samu` ENABLE KEYS */;

-- Dumping structure for table emcor.samu_state
CREATE TABLE IF NOT EXISTS `samu_state` (
  `mt_id` int(10) unsigned NOT NULL COMMENT 'Monitoringe naudojamo rodiklio ID',
  `samu_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Automatinio šablonų atnaujinimo pagal monitoringo rodiklių istoriją užduočių tipo identifikatorius',
  `samu_running` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Požymis, ar automatinio šablonų atnaujinimo pagal monitoringo rodiklių istoriją užduotis dabar vykdoma',
  `samu_last_exec_start` datetime DEFAULT NULL COMMENT 'Automatinio šablonų atnaujinimo pagal monitoringo rodiklių istoriją užduoties paskutinio vykdymo pradžia',
  `samu_last_exec_end` datetime DEFAULT NULL COMMENT 'Automatinio šablonų atnaujinimo pagal monitoringo rodiklių istoriją užduoties paskutinio vykdymo pabaiga',
  `samu_curr_exec_start` datetime DEFAULT NULL COMMENT 'Automatinio šablonų atnaujinimo pagal monitoringo rodiklių istoriją užduoties esamo vykdymo pradžia',
  PRIMARY KEY (`mt_id`,`samu_type_id`),
  CONSTRAINT `samu_state_sanu_fk` FOREIGN KEY (`mt_id`, `samu_type_id`) REFERENCES `samu` (`mt_id`, `samu_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Automatinio šablonų atnaujinimo pagal monitoringo rodiklių istoriją užduočių būsenos';

-- Dumping data for table emcor.samu_state: ~0 rows (approximately)
/*!40000 ALTER TABLE `samu_state` DISABLE KEYS */;
/*!40000 ALTER TABLE `samu_state` ENABLE KEYS */;

-- Dumping structure for table emcor.samu_type
CREATE TABLE IF NOT EXISTS `samu_type` (
  `samu_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Automatinio šablonų atnaujinimo pagal monitoringo rodiklių istoriją užduočių tipo identifikatorius',
  `samu_type_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Automatinio šablonų atnaujinimo pagal monitoringo rodiklių istoriją užduočių tipo kodas',
  `samu_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Automatinio šablonų atnaujinimo pagal monitoringo rodiklių istoriją užduočių tipo pavadinimas',
  PRIMARY KEY (`samu_type_id`),
  UNIQUE KEY `samu_type_code_u` (`samu_type_code`),
  UNIQUE KEY `samu_type_name_u` (`samu_type_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Automatinio šablonų atnaujinimo pagal monitoringo rodiklių istoriją užduočių tipai';

-- Dumping data for table emcor.samu_type: ~0 rows (approximately)
/*!40000 ALTER TABLE `samu_type` DISABLE KEYS */;
/*!40000 ALTER TABLE `samu_type` ENABLE KEYS */;

-- Dumping structure for table emcor.samw
CREATE TABLE IF NOT EXISTS `samw` (
  `samw_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Šablono savaitės programos ID',
  `samw_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Šablono savaitės programos pavadinimas',
  `md_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimo diskretiškumo identifikatorius',
  `samw_common` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Bendro naudojimo savaitės programos požymis',
  PRIMARY KEY (`samw_id`),
  UNIQUE KEY `samw_name_u` (`samw_name`),
  KEY `samw_common_i` (`samw_common`),
  KEY `samw_md_i` (`md_id`),
  CONSTRAINT `samw_md_fk` FOREIGN KEY (`md_id`) REFERENCES `md` (`md_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Šablonų savaitės programos';

-- Dumping data for table emcor.samw: ~0 rows (approximately)
/*!40000 ALTER TABLE `samw` DISABLE KEYS */;
/*!40000 ALTER TABLE `samw` ENABLE KEYS */;

-- Dumping structure for table emcor.samw_data
CREATE TABLE IF NOT EXISTS `samw_data` (
  `samw_id` int(10) unsigned NOT NULL COMMENT 'Šablono savaitės programos ID',
  `wd` tinyint(3) unsigned NOT NULL COMMENT 'Savaitės dienos numeris',
  `samd_id` int(10) unsigned NOT NULL COMMENT 'Šablono dienos programos ID',
  PRIMARY KEY (`samw_id`,`wd`),
  KEY `samw_data_samd_i` (`samd_id`),
  CONSTRAINT `samw_data_samd_fk` FOREIGN KEY (`samd_id`) REFERENCES `samd` (`samd_id`),
  CONSTRAINT `samw_data_samw_fk` FOREIGN KEY (`samw_id`) REFERENCES `samw` (`samw_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Šablono savaitės programos duomenys';

-- Dumping data for table emcor.samw_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `samw_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `samw_data` ENABLE KEYS */;

-- Dumping structure for table emcor.samw_type
CREATE TABLE IF NOT EXISTS `samw_type` (
  `samw_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Šablonų savaitės programų tipo identifikatorius',
  `samw_type_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Šablonų savaitės programų tipo kodas',
  `samw_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Šablonų savaitės programų tipo pavadinimas',
  PRIMARY KEY (`samw_type_id`),
  UNIQUE KEY `samw_type_code_u` (`samw_type_code`),
  UNIQUE KEY `samw_type_name_u` (`samw_type_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Šablonų savaitės programų tipai';

-- Dumping data for table emcor.samw_type: ~7 rows (approximately)
/*!40000 ALTER TABLE `samw_type` DISABLE KEYS */;
INSERT INTO `samw_type` (`samw_type_id`, `samw_type_code`, `samw_type_name`) VALUES
	(1, '1-8', 'Viena dienos programa visoms dienoms'),
	(2, '1-5,6-8', '5 dienų darbo savaitė, šventės'),
	(3, '1-5,6,7-8', '5 dienų darbo savaitė, šeštadienis, šventės'),
	(4, '1-5,6,7,8', '5 dienų darbo savaitė, šeštadienis, sekmadienis, šventės'),
	(5, '1-5,6-7,8', '5 dienų darbo savaitė, savaitgalis, šventės'),
	(6, '1,2,3,4,5,6,7-8', 'Dienos programos atskiros kiekvienai savaitės dienai, šventės kaip sekmadienis'),
	(7, '1,2,3,4,5,6,7,8', 'Dienos programos atskiros kiekvienai savaitės dienai ir šventėms');
/*!40000 ALTER TABLE `samw_type` ENABLE KEYS */;

-- Dumping structure for table emcor.sam_const_val_state
CREATE TABLE IF NOT EXISTS `sam_const_val_state` (
  `sam_id` int(10) unsigned NOT NULL COMMENT 'Šablono identifikatorius',
  `sam_const_val_calc_date` datetime DEFAULT NULL COMMENT 'Šablono pastovios reikšmės paskutinio perskaičiavimo data',
  `sam_const_val_calc_date_req` datetime DEFAULT NULL COMMENT 'Šablono pastovios reikšmės perskaičiavimo užsakymo data',
  PRIMARY KEY (`sam_id`),
  CONSTRAINT `sam_const_val_state_sam_fk` FOREIGN KEY (`sam_id`) REFERENCES `sam` (`sam_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Šablono pastovių reikšmų būklės';

-- Dumping data for table emcor.sam_const_val_state: ~0 rows (approximately)
/*!40000 ALTER TABLE `sam_const_val_state` DISABLE KEYS */;
/*!40000 ALTER TABLE `sam_const_val_state` ENABLE KEYS */;

-- Dumping structure for table emcor.sam_dc
CREATE TABLE IF NOT EXISTS `sam_dc` (
  `sam_id` int(10) unsigned NOT NULL COMMENT 'Šablono identifikatorius',
  `mt_id` int(10) unsigned NOT NULL COMMENT 'Monitoringe naudojamo rodiklio ID',
  `per_id` tinyint(3) unsigned NOT NULL COMMENT 'Periodo identifikatorius',
  `week` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Požymis, kad periodas - savaitė',
  `dc_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Dinaminio monitoringo šablonų atnaujinimo galiojimo požymis',
  PRIMARY KEY (`sam_id`),
  KEY `sam_dc_mt_id_i` (`mt_id`),
  KEY `sam_dc_per_id_i` (`per_id`),
  CONSTRAINT `sam_dc_per_fk` FOREIGN KEY (`per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `sam_dk_mt_fk` FOREIGN KEY (`mt_id`) REFERENCES `mt` (`mt_id`) ON DELETE CASCADE,
  CONSTRAINT `sam_dk_sam_fk` FOREIGN KEY (`sam_id`) REFERENCES `sam` (`sam_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Dinaminio monitoringo šablonų atnaujinimo konfiguracija';

-- Dumping data for table emcor.sam_dc: ~0 rows (approximately)
/*!40000 ALTER TABLE `sam_dc` DISABLE KEYS */;
/*!40000 ALTER TABLE `sam_dc` ENABLE KEYS */;

-- Dumping structure for table emcor.sam_tmpl
CREATE TABLE IF NOT EXISTS `sam_tmpl` (
  `sam_tmpl_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Šablono atnaujinimo modelio identifikatorius',
  `sam_tmpl_code` varchar(80) COLLATE utf8_bin NOT NULL COMMENT 'Šablono atnaujinimo modelio kodas',
  `sam_tmpl_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Šablono atnaujinimo modelio pavadinimas',
  `sam_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Šablonų tipo identifikatorius',
  `samw_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Šablonų savaitės programų tipo identifikatorius',
  `sam_cyclic` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar šablono periodai sudaro pastovų metų ciklą',
  `sam_tmpl_prep_per_id` tinyint(3) unsigned NOT NULL COMMENT 'Periodų, kuriais nusakoma šablono paruošimo trukmę, identifikatorius',
  `sam_tmpl_prep` smallint(5) unsigned NOT NULL COMMENT 'Periodu kiekis, nusakantys šablono paruošimo trukmę',
  `sam_tmpl_depth_per_id` tinyint(3) unsigned NOT NULL COMMENT 'Periodų, kuriais nusakomas šablono taikymo gylis, identifikatorius',
  `sam_tmpl_depth` smallint(5) unsigned NOT NULL COMMENT 'Periodu kiekis, nusakantys šablono taikymo gylį',
  `sam_tmpl_calc_sch_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Tvarkaraščio, pagal kurį bus vykdomas šablono perskaičiavimas, identifikatorius',
  `calc_lag_per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Periodu kuriais nusakomas šablono skaičiavimo poslinkis, identifikatorius',
  `calc_lag` smallint(5) unsigned DEFAULT NULL COMMENT 'Periodu kiekis, nusakantys skaičiavimo poslinkį',
  `md_id_for_instant` smallint(5) unsigned DEFAULT NULL COMMENT 'Matavimo diskretiškumo identifikatorius realaus laiko rodikliui',
  `use_const_val` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Pastovios reikšmės naudojimo požymis',
  `const_val` double NOT NULL DEFAULT 0 COMMENT 'Pastovi reikšmė',
  `hld_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Šventinių dienų rinkinio identifikatorius',
  `passed_samp_count` smallint(5) unsigned DEFAULT NULL COMMENT 'Šablono periodų kiekis, nusakantys, kiek periodų į praeitį reikia sukurti kuriant naują šabloną',
  PRIMARY KEY (`sam_tmpl_id`),
  UNIQUE KEY `sam_tmpl_code_u` (`sam_tmpl_code`),
  UNIQUE KEY `sam_tmpl_name_u` (`sam_tmpl_name`),
  KEY `calc_lag_per_i` (`calc_lag_per_id`),
  KEY `sam_tmpl_calc_sch_i` (`sam_tmpl_calc_sch_id`),
  KEY `sam_tmpl_depth_per_i` (`sam_tmpl_depth_per_id`),
  KEY `sam_tmpl_hld_i` (`hld_id`),
  KEY `sam_tmpl_md_i` (`md_id_for_instant`),
  KEY `sam_tmpl_prep_per_i` (`sam_tmpl_prep_per_id`),
  KEY `sam_tmpl_samw_type_i` (`samw_type_id`),
  KEY `sam_tmpl_type_i` (`sam_type_id`),
  CONSTRAINT `sam_tmpl_calc_per_fk` FOREIGN KEY (`calc_lag_per_id`) REFERENCES `per` (`per_id`) ON DELETE CASCADE,
  CONSTRAINT `sam_tmpl_depth_per_fk` FOREIGN KEY (`sam_tmpl_depth_per_id`) REFERENCES `per` (`per_id`) ON DELETE CASCADE,
  CONSTRAINT `sam_tmpl_hld_fk` FOREIGN KEY (`hld_id`) REFERENCES `hld` (`hld_id`) ON DELETE SET NULL,
  CONSTRAINT `sam_tmpl_md_fk` FOREIGN KEY (`md_id_for_instant`) REFERENCES `md` (`md_id`) ON DELETE CASCADE,
  CONSTRAINT `sam_tmpl_prep_per_fk` FOREIGN KEY (`sam_tmpl_prep_per_id`) REFERENCES `per` (`per_id`) ON DELETE CASCADE,
  CONSTRAINT `sam_tmpl_samw_type_fk` FOREIGN KEY (`samw_type_id`) REFERENCES `samw_type` (`samw_type_id`) ON DELETE CASCADE,
  CONSTRAINT `sam_tmpl_sch_fk` FOREIGN KEY (`sam_tmpl_calc_sch_id`) REFERENCES `sch` (`sch_id`) ON DELETE CASCADE,
  CONSTRAINT `sam_tmpl_type_fk` FOREIGN KEY (`sam_type_id`) REFERENCES `sam_type` (`sam_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Šablono atnaujinimo modeliai';

-- Dumping data for table emcor.sam_tmpl: ~0 rows (approximately)
/*!40000 ALTER TABLE `sam_tmpl` DISABLE KEYS */;
/*!40000 ALTER TABLE `sam_tmpl` ENABLE KEYS */;

-- Dumping structure for table emcor.sam_tmpl_ai
CREATE TABLE IF NOT EXISTS `sam_tmpl_ai` (
  `sam_tmpl_id` int(10) unsigned NOT NULL COMMENT 'Šablono atnaujinimo modelio identifikatorius',
  `sam_tmpl_ai_nr` smallint(5) unsigned NOT NULL COMMENT 'Vidurkinimo intervalo numeris',
  `ai_lag_per_id` tinyint(3) unsigned NOT NULL COMMENT 'Periodų, kuriais nusakomas šablono vidurkinimo intervalo poslinkis, identifikatorius',
  `ai_lag` smallint(5) unsigned NOT NULL DEFAULT 0 COMMENT 'Periodu kiekis, nusakantys šablono vidurkinimo intervalo poslinkio trukmę',
  `ai_depth_per_id` tinyint(3) unsigned NOT NULL COMMENT 'Periodų, kuriais nusakomas šablono vidurkinimo intervalo gylis, identifikatorius',
  `ai_depth` smallint(5) unsigned NOT NULL COMMENT 'Periodu kiekis, nusakantys šablono vidurkinimo intervalo gylį',
  `ai_weight` double NOT NULL DEFAULT 1 COMMENT 'Intervalo reikšmės svoris',
  PRIMARY KEY (`sam_tmpl_id`,`sam_tmpl_ai_nr`),
  KEY `sam_tmpl_ai_depth_per_i` (`ai_depth_per_id`),
  KEY `sam_tmpl_ai_lag_per_i` (`ai_lag_per_id`),
  CONSTRAINT `sam_tmpl_ai_depth_per_fk` FOREIGN KEY (`ai_depth_per_id`) REFERENCES `per` (`per_id`) ON DELETE CASCADE,
  CONSTRAINT `sam_tmpl_ai_lag_per_fk` FOREIGN KEY (`ai_lag_per_id`) REFERENCES `per` (`per_id`) ON DELETE CASCADE,
  CONSTRAINT `sam_tmpl_ai_sam_tmpl_fk` FOREIGN KEY (`sam_tmpl_id`) REFERENCES `sam_tmpl` (`sam_tmpl_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Šablono atnaujinimo modelių vidurkinimo intervalai';

-- Dumping data for table emcor.sam_tmpl_ai: ~0 rows (approximately)
/*!40000 ALTER TABLE `sam_tmpl_ai` DISABLE KEYS */;
/*!40000 ALTER TABLE `sam_tmpl_ai` ENABLE KEYS */;

-- Dumping structure for table emcor.sam_type
CREATE TABLE IF NOT EXISTS `sam_type` (
  `sam_type_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Šablonų tipo ID',
  `sam_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Šablonų tipo pavadinimas',
  PRIMARY KEY (`sam_type_id`),
  UNIQUE KEY `sam_type_name_u` (`sam_type_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Šablonų tipai';

-- Dumping data for table emcor.sam_type: ~0 rows (approximately)
/*!40000 ALTER TABLE `sam_type` DISABLE KEYS */;
/*!40000 ALTER TABLE `sam_type` ENABLE KEYS */;

-- Dumping structure for table emcor.sbst
CREATE TABLE IF NOT EXISTS `sbst` (
  `pl_id` int(10) unsigned NOT NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
  `sbst_pl_id` int(10) unsigned DEFAULT NULL COMMENT 'Pakaitai naudojamos matavimo linijos matavimo taške identifikatorius',
  `sam_id` int(10) unsigned DEFAULT NULL COMMENT 'Šablono identifikatorius',
  `sbst_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Pakaitos naudojimo požymis',
  `sbst_sf` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar pakaitos duomenis pažymėti specialiu duomenų statuso požymiu',
  `sbst_ab` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Pakaitos duomenų tiesinio transformavimo požymis',
  `sbst_a` double DEFAULT NULL COMMENT 'Pakaitos duomenų daugiklis',
  `sbst_b` double DEFAULT NULL COMMENT 'Pakaitos duomenų dedamoji',
  `per_id` tinyint(3) unsigned NOT NULL DEFAULT 2 COMMENT 'Periodo identifikatorius',
  `sbst_lag` mediumint(8) unsigned DEFAULT NULL COMMENT 'Periodų kiekis, apibrėžiantis pakaitos užlaikymą',
  `sbst_improvable` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar galimi geresni nei pakaitos duomenys',
  `sbst_fln` tinyint(3) unsigned NOT NULL DEFAULT 1 COMMENT 'Pakaitos siekinys (1-pirmas, 2-paskutinis, 3-artimiausias nuskaitymas)',
  `sbst_radius` mediumint(8) unsigned DEFAULT NULL COMMENT 'Pakaitos spindulys',
  `sbst_radius_per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Periodų, kuriais nustatomas pakaitos spindulys, identifikatorius',
  `sbst_offset` mediumint(8) unsigned DEFAULT NULL COMMENT 'Pakaitos poslinkis',
  `sbst_offset_per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Periodų, kuriais nustatomas pakaitos poslinkis, identifikatorius',
  `sbst_alter_read_time` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Pakaitos duomenų laiko išvedimas vietoj nuskaitymo laiko',
  `sbst_exclude_fln` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Pakaitos siekinio laiko žymės neįtraukimo požymis',
  PRIMARY KEY (`pl_id`),
  KEY `sbst_sam_i` (`sam_id`),
  KEY `sbst_sbst_pl_i` (`sbst_pl_id`),
  KEY `sbst_offset_per_fk` (`sbst_offset_per_id`),
  KEY `sbst_per_fk` (`per_id`),
  KEY `sbst_radius_per_fk` (`sbst_radius_per_id`),
  CONSTRAINT `sbst_offset_per_fk` FOREIGN KEY (`sbst_offset_per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `sbst_per_fk` FOREIGN KEY (`per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `sbst_pl_fk` FOREIGN KEY (`pl_id`) REFERENCES `pl` (`pl_id`) ON DELETE CASCADE,
  CONSTRAINT `sbst_radius_per_fk` FOREIGN KEY (`sbst_radius_per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `sbst_sam_fk` FOREIGN KEY (`sam_id`) REFERENCES `sam` (`sam_id`) ON DELETE CASCADE,
  CONSTRAINT `sbst_sbst_pl_fk` FOREIGN KEY (`sbst_pl_id`) REFERENCES `pl` (`pl_id`) ON DELETE CASCADE,
  CONSTRAINT `SBST_NOT_BY_ITSELF_CHK` CHECK (`sbst_pl_id` is null or `sbst_pl_id` <> `pl_id` or `sbst_offset` is not null and `sbst_offset_per_id` is not null or `sbst_exclude_fln` <> 0),
  CONSTRAINT `SBST_AB_NOT_NULL_CHK` CHECK (`sbst_ab` = 0 or `sbst_ab` = 1 and `sbst_a` is not null and `sbst_b` is not null),
  CONSTRAINT `SBST_PL_OR_SAM_CHK` CHECK (`sbst_pl_id` is not null and `sam_id` is null or `sbst_pl_id` is null and `sam_id` is not null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Taškų matavimų pakaitos konfigūracija';

-- Dumping data for table emcor.sbst: ~0 rows (approximately)
/*!40000 ALTER TABLE `sbst` DISABLE KEYS */;
/*!40000 ALTER TABLE `sbst` ENABLE KEYS */;

-- Dumping structure for table emcor.sch
CREATE TABLE IF NOT EXISTS `sch` (
  `sch_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Tvarkaraščio identifikatorius',
  `sch_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Tvarkaraščio pavadinimas',
  PRIMARY KEY (`sch_id`),
  UNIQUE KEY `sch_name_u` (`sch_name`)
) ENGINE=InnoDB AUTO_INCREMENT=311 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Tvarkaraščiai';

-- Dumping data for table emcor.sch: ~10 rows (approximately)
/*!40000 ALTER TABLE `sch` DISABLE KEYS */;
INSERT INTO `sch` (`sch_id`, `sch_name`) VALUES
	(42, 'Kas 10 min'),
	(22, 'Kas 15 min'),
	(103, 'Kas 20 min'),
	(238, 'Kas 4 valandas'),
	(44, 'Kas 5 minutes'),
	(310, 'Kas 6 valandas'),
	(303, 'Kas mėnesį'),
	(43, 'Kas parą'),
	(167, 'Kas pusvalandį'),
	(62, 'Kas valandą');
/*!40000 ALTER TABLE `sch` ENABLE KEYS */;

-- Dumping structure for table emcor.schi
CREATE TABLE IF NOT EXISTS `schi` (
  `sch_id` mediumint(8) unsigned NOT NULL COMMENT 'Tvarkaraščio identifikatorius',
  `schi_nr` smallint(5) unsigned NOT NULL DEFAULT 1 COMMENT 'Paprasto tvarkaraščio numeris',
  `sch_repeat` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Paprasto tvarkaraščio pakartojimų požymis',
  `sch_repeat_times` tinyint(3) unsigned NOT NULL DEFAULT 1 COMMENT 'Paprasto tvarkaraščio pakartojimų kiekis',
  `hld_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Šventinių dienų rinkinio identifikatorius',
  `wd_specific` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Požymis, ar vykdyti specifiškai pagal savaitės dienas',
  `wd1` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti pirmadieniais',
  `wd2` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti antradieniais',
  `wd3` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti trečiadieniais',
  `wd4` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti ketvirtadieniais',
  `wd5` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti penktadieniais',
  `wd6` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti šeštadieniais',
  `wd7` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti sekmadieniais',
  `wd8` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti šventinėmis dienomis',
  `mo_specific` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Požymis, ar vykdyti specifiškai pagal mėnesius',
  `mo1` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti sausį',
  `mo2` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti vasarį',
  `mo3` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti kovą',
  `mo4` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti balandį',
  `mo5` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti gegužę',
  `mo6` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti birželį',
  `mo7` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti liepą',
  `mo8` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti rugpjūtį',
  `mo9` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti rugsėjį',
  `mo10` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti spalį',
  `mo11` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti lapkritį',
  `mo12` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti gruodį',
  `hh_specific` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Požymis, ar vykdyti specifiškai pagal valandas',
  `hh1` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 1-ą valandą',
  `hh2` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 2-ą valandą',
  `hh3` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 3-ą valandą',
  `hh4` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 4-ą valandą',
  `hh5` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 5-ą valandą',
  `hh6` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 6-ą valandą',
  `hh7` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 7-ą valandą',
  `hh8` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 8-ą valandą',
  `hh9` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 9-ą valandą',
  `hh10` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 10-ą valandą',
  `hh11` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 11-ą valandą',
  `hh12` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 12-ą valandą',
  `hh13` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 13-ą valandą',
  `hh14` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 14-ą valandą',
  `hh15` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 15-ą valandą',
  `hh16` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 16-ą valandą',
  `hh17` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 17-ą valandą',
  `hh18` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 18-ą valandą',
  `hh19` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 19-ą valandą',
  `hh20` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 20-ą valandą',
  `hh21` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 21-ą valandą',
  `hh22` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 22-ą valandą',
  `hh23` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 23-ą valandą',
  `hh24` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar vykdyti 24-ą valandą',
  PRIMARY KEY (`sch_id`,`schi_nr`),
  KEY `schi_hld_i` (`hld_id`),
  CONSTRAINT `schi_hld_fk` FOREIGN KEY (`hld_id`) REFERENCES `hld` (`hld_id`),
  CONSTRAINT `schi_sch_fk` FOREIGN KEY (`sch_id`) REFERENCES `sch` (`sch_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Paprasti tvarkaraščiai';

-- Dumping data for table emcor.schi: ~10 rows (approximately)
/*!40000 ALTER TABLE `schi` DISABLE KEYS */;
INSERT INTO `schi` (`sch_id`, `schi_nr`, `sch_repeat`, `sch_repeat_times`, `hld_id`, `wd_specific`, `wd1`, `wd2`, `wd3`, `wd4`, `wd5`, `wd6`, `wd7`, `wd8`, `mo_specific`, `mo1`, `mo2`, `mo3`, `mo4`, `mo5`, `mo6`, `mo7`, `mo8`, `mo9`, `mo10`, `mo11`, `mo12`, `hh_specific`, `hh1`, `hh2`, `hh3`, `hh4`, `hh5`, `hh6`, `hh7`, `hh8`, `hh9`, `hh10`, `hh11`, `hh12`, `hh13`, `hh14`, `hh15`, `hh16`, `hh17`, `hh18`, `hh19`, `hh20`, `hh21`, `hh22`, `hh23`, `hh24`) VALUES
	(22, 1, 1, 2, NULL, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
	(42, 1, 1, 1, NULL, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
	(43, 1, 0, 1, NULL, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
	(44, 1, 0, 1, NULL, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
	(62, 1, 0, 2, NULL, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
	(103, 1, 0, 1, NULL, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
	(167, 1, 0, 1, NULL, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
	(238, 1, 0, 5, NULL, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
	(303, 1, 0, 1, NULL, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1),
	(310, 1, 0, 5, NULL, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1);
/*!40000 ALTER TABLE `schi` ENABLE KEYS */;

-- Dumping structure for table emcor.schi_data
CREATE TABLE IF NOT EXISTS `schi_data` (
  `sch_id` mediumint(8) unsigned NOT NULL COMMENT 'Tvarkaraščio identifikatorius',
  `schi_nr` smallint(5) unsigned NOT NULL COMMENT 'Paprasto tvarkaraščio numeris',
  `sch_int_id` tinyint(3) unsigned NOT NULL COMMENT 'Tvarkaraščių intervalo identifikatorius',
  `per_id` tinyint(3) unsigned NOT NULL COMMENT 'Periodo identifikatorius',
  `sch_int_value` mediumint(8) unsigned NOT NULL COMMENT 'Laiko vienetų kiekis',
  PRIMARY KEY (`sch_id`,`schi_nr`,`sch_int_id`),
  KEY `schi_data_per_i` (`per_id`),
  KEY `schi_data_sch_int_i` (`sch_int_id`),
  CONSTRAINT `schi_data_per_fk` FOREIGN KEY (`per_id`) REFERENCES `per` (`per_id`) ON DELETE CASCADE,
  CONSTRAINT `schi_data_sch_int_fk` FOREIGN KEY (`sch_int_id`) REFERENCES `sch_int` (`sch_int_id`) ON DELETE CASCADE,
  CONSTRAINT `schi_data_schi_fk` FOREIGN KEY (`sch_id`, `schi_nr`) REFERENCES `schi` (`sch_id`, `schi_nr`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Paprastų tvarkaraščių duomenys';

-- Dumping data for table emcor.schi_data: ~31 rows (approximately)
/*!40000 ALTER TABLE `schi_data` DISABLE KEYS */;
INSERT INTO `schi_data` (`sch_id`, `schi_nr`, `sch_int_id`, `per_id`, `sch_int_value`) VALUES
	(22, 1, 1, 2, 15),
	(22, 1, 2, 1, 60),
	(22, 1, 3, 1, 3900),
	(42, 1, 1, 2, 10),
	(42, 1, 2, 1, 300),
	(42, 1, 3, 1, 10),
	(43, 1, 1, 4, 1),
	(43, 1, 2, 1, 120),
	(43, 1, 3, 1, 120),
	(44, 1, 1, 2, 5),
	(44, 1, 2, 1, 60),
	(44, 1, 3, 1, 60),
	(62, 1, 1, 3, 1),
	(62, 1, 2, 1, 1860),
	(62, 1, 3, 1, 1800),
	(103, 1, 1, 2, 20),
	(103, 1, 2, 1, 180),
	(103, 1, 3, 1, 60),
	(167, 1, 1, 2, 30),
	(167, 1, 2, 1, 360),
	(167, 1, 3, 1, 60),
	(238, 1, 1, 3, 4),
	(238, 1, 2, 1, 180),
	(238, 1, 3, 1, 16200),
	(303, 1, 1, 5, 1),
	(303, 1, 2, 1, 360),
	(303, 1, 3, 1, 1),
	(303, 1, 4, 4, 2),
	(310, 1, 1, 3, 6),
	(310, 1, 2, 1, 180),
	(310, 1, 3, 1, 16200);
/*!40000 ALTER TABLE `schi_data` ENABLE KEYS */;

-- Dumping structure for table emcor.sch_int
CREATE TABLE IF NOT EXISTS `sch_int` (
  `sch_int_id` tinyint(3) unsigned NOT NULL COMMENT 'Tvarkaraščių intervalo identifikatorius',
  `sch_int_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Tvarkaraščių intervalo pavadinimas',
  PRIMARY KEY (`sch_int_id`),
  UNIQUE KEY `sch_int_name_u` (`sch_int_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Tvarkaraščių  intervalai';

-- Dumping data for table emcor.sch_int: ~4 rows (approximately)
/*!40000 ALTER TABLE `sch_int` DISABLE KEYS */;
INSERT INTO `sch_int` (`sch_int_id`, `sch_int_name`) VALUES
	(1, 'PERIOD'),
	(3, 'REPEAT'),
	(2, 'START'),
	(4, 'START_DAY');
/*!40000 ALTER TABLE `sch_int` ENABLE KEYS */;

-- Dumping structure for table emcor.se
CREATE TABLE IF NOT EXISTS `se` (
  `se_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Duomenų šaltinio elemento identifikatorius',
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `di_id` int(10) unsigned NOT NULL COMMENT 'Nuskaitomų duomenų elemento identifikatorius',
  `se_ab` tinyint(3) unsigned DEFAULT NULL COMMENT 'Šaltinio elemento duomenų tiesinio transformavimo ryšio modulyje požymis',
  `se_a` double DEFAULT NULL COMMENT 'Duomenų šaltinio elemento daugiklis',
  `se_b` double DEFAULT NULL COMMENT 'Duomenų šaltinio elemento dedamoji',
  `se_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Duomenų šaltinio elemento naudojimo požymis',
  `se_forced` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Duomenų šaltinio elemento priverstinio užpildymo požymis',
  `se_h` tinyint(1) NOT NULL COMMENT 'Istorinių duomenų egzistavimo požymis',
  `se_h_per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Istorinių duomenų gylio laiko vienetų identifikatorius ',
  `se_h_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Laiko periodų kiekis, apibrėžiantis istorinių duomenų gylį',
  `se_h_bound` datetime DEFAULT NULL COMMENT 'Istorinių duomenų apribojimo laikas',
  `se_h_restore_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Laiko periodų kiekis, apibrėžiantis istorinių duomenų, kurie gali būti atnaujinami šaltinyje, gylį',
  `se_h_restore_per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Istorinių duomenų, kurie gali būti atnaujinami šaltinyje, gylio laiko vienetų identifikatorius',
  PRIMARY KEY (`se_id`),
  KEY `se_di_i` (`di_id`),
  KEY `se_h_per_i` (`se_h_per_id`),
  KEY `se_restore_per_i` (`se_h_restore_per_id`),
  KEY `se_src_i` (`src_id`),
  CONSTRAINT `se_di_fk` FOREIGN KEY (`di_id`) REFERENCES `di` (`di_id`) ON DELETE CASCADE,
  CONSTRAINT `se_per_fk` FOREIGN KEY (`se_h_per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `se_restore_per_fk` FOREIGN KEY (`se_h_restore_per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `se_src_fk` FOREIGN KEY (`src_id`) REFERENCES `src` (`src_id`) ON DELETE CASCADE,
  CONSTRAINT `SE_AB_NOT_NULL_CHK` CHECK (`se_ab` is null or `se_ab` is not null and `se_a` is not null and `se_b` is not null),
  CONSTRAINT `SE_RESTORE_PER_NOT_NULL_CHK` CHECK (`se_h_restore_depth` is null or `se_h_restore_depth` is not null and `se_h_restore_per_id` is not null),
  CONSTRAINT `SE_H_PER_ID_NOT_NULL_CHK` CHECK (`se_h_depth` is null or `se_h_per_id` is not null),
  CONSTRAINT `SE_H_SE_H_DEPTH_NOT_NULL_CHK` CHECK (`se_h` <> 1 or `se_h_depth` is not null)
) ENGINE=InnoDB AUTO_INCREMENT=39 DEFAULT CHARSET=utf8 COMMENT='Duomenų šaltinio elementai';

-- Dumping data for table emcor.se: ~34 rows (approximately)
/*!40000 ALTER TABLE `se` DISABLE KEYS */;
INSERT INTO `se` (`se_id`, `src_id`, `di_id`, `se_ab`, `se_a`, `se_b`, `se_enabled`, `se_forced`, `se_h`, `se_h_per_id`, `se_h_depth`, `se_h_bound`, `se_h_restore_depth`, `se_h_restore_per_id`) VALUES
	(1, 1388, 1, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(2, 1388, 2, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(3, 1388, 3, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(4, 1388, 9, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(5, 1388, 10, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(6, 1388, 6, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(7, 1388, 14, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(8, 1388, 4, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(9, 1388, 5, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(10, 1388, 7, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(11, 1388, 13, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(12, 1388, 8, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(13, 1388, 15, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(14, 1389, 11, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(15, 1389, 12, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(16, 1389, 16, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(17, 1389, 17, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(18, 1388, 18, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(19, 1388, 19, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(20, 1388, 20, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(21, 1388, 21, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(26, 1388, 26, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(27, 1388, 27, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(28, 1388, 28, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(29, 1388, 29, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(30, 1388, 30, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(31, 1388, 31, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(32, 1388, 32, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(33, 1388, 33, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(34, 1388, 34, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(35, 1388, 35, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(36, 1388, 36, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(37, 1388, 37, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL),
	(38, 1389, 38, NULL, NULL, NULL, 1, 0, 0, NULL, NULL, NULL, NULL, NULL);
/*!40000 ALTER TABLE `se` ENABLE KEYS */;

-- Dumping structure for table emcor.sep
CREATE TABLE IF NOT EXISTS `sep` (
  `sep_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `se_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento identifikatorius',
  `sp_id` int(10) unsigned NOT NULL COMMENT 'Ryšio kanalo ir duomenų šaltinio sąsajos identifikatorius',
  `sep_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, naudojimo požymis',
  PRIMARY KEY (`sep_id`),
  UNIQUE KEY `sep_ak` (`sp_id`,`se_id`),
  KEY `sep_se_i` (`se_id`),
  CONSTRAINT `sep_se_fk` FOREIGN KEY (`se_id`) REFERENCES `se` (`se_id`) ON DELETE CASCADE,
  CONSTRAINT `sep_sp_fk` FOREIGN KEY (`sp_id`) REFERENCES `sp` (`sp_id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=39 DEFAULT CHARSET=utf8 COMMENT='Duomenų šaltinio elementai, pasiekiami per ryšio kanalą';

-- Dumping data for table emcor.sep: ~34 rows (approximately)
/*!40000 ALTER TABLE `sep` DISABLE KEYS */;
INSERT INTO `sep` (`sep_id`, `se_id`, `sp_id`, `sep_enabled`) VALUES
	(1, 1, 2330, 1),
	(2, 2, 2330, 1),
	(3, 3, 2330, 1),
	(4, 4, 2330, 1),
	(5, 5, 2330, 1),
	(6, 6, 2330, 1),
	(7, 7, 2330, 1),
	(8, 8, 2330, 1),
	(9, 9, 2330, 1),
	(10, 10, 2330, 1),
	(11, 11, 2330, 1),
	(12, 12, 2330, 1),
	(13, 13, 2330, 1),
	(14, 14, 2331, 1),
	(15, 15, 2331, 1),
	(16, 16, 2331, 1),
	(17, 17, 2331, 1),
	(18, 18, 2330, 1),
	(19, 19, 2330, 1),
	(20, 20, 2330, 1),
	(21, 21, 2330, 1),
	(26, 26, 2330, 1),
	(27, 27, 2330, 1),
	(28, 28, 2330, 1),
	(29, 29, 2330, 1),
	(30, 30, 2330, 1),
	(31, 31, 2330, 1),
	(32, 32, 2330, 1),
	(33, 33, 2330, 1),
	(34, 34, 2330, 1),
	(35, 35, 2330, 1),
	(36, 36, 2330, 1),
	(37, 37, 2330, 1),
	(38, 38, 2331, 1);
/*!40000 ALTER TABLE `sep` ENABLE KEYS */;

-- Dumping structure for table emcor.sepac
CREATE TABLE IF NOT EXISTS `sepac` (
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `se_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento identifikatorius',
  `sp_id` int(10) unsigned NOT NULL COMMENT 'Ryšio kanalo ir duomenų šaltinio sąsajos identifikatorius',
  `sep_enabled` tinyint(1) NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, naudojimo požymis',
  `sep_priority` mediumint(8) unsigned NOT NULL,
  `di_id` int(10) unsigned NOT NULL COMMENT 'Nuskaitomų duomenų elemento identifikatorius',
  `di_enabled` tinyint(1) NOT NULL COMMENT 'Nuskaitymo požymis',
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `se_enabled` tinyint(1) NOT NULL COMMENT 'Duomenų šaltinio elemento naudojimo požymis',
  `se_forced` tinyint(1) NOT NULL COMMENT 'Duomenų šaltinio elemento priverstinio užpildymo požymis',
  `se_h` tinyint(1) NOT NULL COMMENT 'Istorinių duomenų egzistavimo požymis',
  `point_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo taško identifikatorius',
  `point_auto_read_enabled` tinyint(1) DEFAULT NULL COMMENT 'Duomenų automatinio nuskaitymo požymis',
  `pl_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
  `das_ml_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Matavimo linijos identifikatorius',
  `se_ab` tinyint(3) unsigned DEFAULT NULL COMMENT 'Šaltinio elemento duomenų tiesinio transformavimo ryšio modulyje požymis',
  `se_a` double DEFAULT NULL COMMENT 'Duomenų šaltinio elemento daugiklis',
  `se_b` double DEFAULT NULL COMMENT 'Duomenų šaltinio elemento dedamoji',
  `stobis` mediumint(8) DEFAULT NULL COMMENT 'Kodas STOBIS',
  `sheaf_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Duomenų pluošto identifikatorius',
  `witheset_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų vytelių rinkinio identifikatorius',
  `ds_id` int(10) unsigned DEFAULT NULL COMMENT 'Apskaitos būsenos signalo identifikatorius',
  `multistep` tinyint(1) DEFAULT NULL,
  `di_bt` datetime DEFAULT NULL,
  `se_h_bound` datetime DEFAULT NULL,
  `ml_id` mediumint(8) unsigned DEFAULT NULL,
  `aggs_id` tinyint(3) unsigned DEFAULT NULL,
  `aggs_type_id` tinyint(3) unsigned DEFAULT NULL,
  `md_per_id` tinyint(3) unsigned DEFAULT NULL,
  `md_int_value` mediumint(8) unsigned DEFAULT NULL,
  `se_h_depth` mediumint(8) unsigned DEFAULT NULL,
  `se_h_per_id` tinyint(3) unsigned DEFAULT NULL,
  `se_h_restore_depth` mediumint(8) unsigned DEFAULT NULL,
  `se_h_restore_per_id` tinyint(3) unsigned DEFAULT NULL,
  PRIMARY KEY (`sep_id`),
  KEY `sepac_di_i` (`di_id`),
  KEY `sepac_dp_i` (`dp_id`,`sp_id`),
  KEY `sepac_src_i` (`src_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Aktualūs surinkimui duomenų šaltinio elementai, pasiekiami per ryšio kanalą';

-- Dumping data for table emcor.sepac: ~0 rows (approximately)
/*!40000 ALTER TABLE `sepac` DISABLE KEYS */;
/*!40000 ALTER TABLE `sepac` ENABLE KEYS */;

-- Dumping structure for table emcor.sep_rc
CREATE TABLE IF NOT EXISTS `sep_rc` (
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `rc_id` tinyint(3) unsigned NOT NULL COMMENT 'Užklausų priežasties identifikatorius',
  `sch_id` mediumint(8) unsigned NOT NULL COMMENT 'Tvarkaraščio identifikatorius',
  `per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Periodo identifikatorius',
  `sep_rc_lag` mediumint(8) unsigned DEFAULT NULL COMMENT 'Periodų kiekis, apibrėžiantis nuskaitymo poslinkį',
  `sep_rc_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Periodų kiekis, apibrėžiantis nuskaitymo gylį',
  PRIMARY KEY (`sep_id`,`rc_id`),
  KEY `sep_rc_per_i` (`per_id`),
  KEY `sep_rc_rc_i` (`rc_id`),
  KEY `sep_rc_sch_i` (`sch_id`),
  CONSTRAINT `sep_rc_per_fk` FOREIGN KEY (`per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `sep_rc_rc_fk` FOREIGN KEY (`rc_id`) REFERENCES `rc` (`rc_id`) ON DELETE CASCADE,
  CONSTRAINT `sep_rc_sch_fk` FOREIGN KEY (`sch_id`) REFERENCES `sch` (`sch_id`),
  CONSTRAINT `sep_rc_sep_fk` FOREIGN KEY (`sep_id`) REFERENCES `sep` (`sep_id`) ON DELETE CASCADE,
  CONSTRAINT `SEP_RC_PER_ID_CHK` CHECK (`per_id` is not null and `sep_rc_lag` >= 0 or `per_id` is not null and `sep_rc_depth` is not null or `per_id` is null and `sep_rc_lag` is null and `sep_rc_depth` is null or `per_id` is null and `sep_rc_lag` = 0 and `sep_rc_depth` is null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Pasiekiamų per ryšio kanalą šaltinio elementų konfigūracija pagal nuskaitymo priežastį';

-- Dumping data for table emcor.sep_rc: ~0 rows (approximately)
/*!40000 ALTER TABLE `sep_rc` DISABLE KEYS */;
/*!40000 ALTER TABLE `sep_rc` ENABLE KEYS */;

-- Dumping structure for table emcor.sep_tmpl
CREATE TABLE IF NOT EXISTS `sep_tmpl` (
  `se_tmpl_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių šablono elemento ID',
  `ph_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius',
  PRIMARY KEY (`se_tmpl_id`,`ph_type_id`),
  KEY `sep_tmpl_ph_type_i` (`ph_type_id`),
  CONSTRAINT `sep_ph_type_fk` FOREIGN KEY (`ph_type_id`) REFERENCES `ph_type` (`ph_type_id`) ON DELETE CASCADE,
  CONSTRAINT `sep_tmpl_se_tmpl_fk` FOREIGN KEY (`se_tmpl_id`) REFERENCES `se_tmpl` (`se_tmpl_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų šaltinių šablono elementai pagal ryšio kanalų tipą';

-- Dumping data for table emcor.sep_tmpl: ~75 rows (approximately)
/*!40000 ALTER TABLE `sep_tmpl` DISABLE KEYS */;
INSERT INTO `sep_tmpl` (`se_tmpl_id`, `ph_type_id`) VALUES
	(341, 1),
	(342, 1),
	(343, 1),
	(344, 1),
	(345, 1),
	(346, 1),
	(347, 1),
	(348, 1),
	(349, 1),
	(350, 1),
	(351, 1),
	(352, 1),
	(353, 1),
	(354, 1),
	(355, 1),
	(356, 1),
	(357, 1),
	(358, 1),
	(359, 1),
	(360, 1),
	(361, 1),
	(362, 1),
	(363, 1),
	(364, 1),
	(365, 1),
	(366, 1),
	(367, 1),
	(368, 1),
	(369, 1),
	(370, 1),
	(371, 1),
	(372, 1),
	(373, 1),
	(374, 1),
	(375, 1),
	(376, 1),
	(377, 1),
	(378, 1),
	(379, 1),
	(380, 1),
	(381, 1),
	(382, 1),
	(383, 1),
	(384, 1),
	(385, 1),
	(386, 1),
	(387, 1),
	(388, 1),
	(388, 2),
	(389, 1),
	(390, 1),
	(391, 1),
	(392, 1),
	(393, 1),
	(394, 1),
	(395, 1),
	(396, 1),
	(397, 1),
	(398, 1),
	(399, 1),
	(400, 1),
	(401, 1),
	(402, 1),
	(403, 1),
	(404, 1),
	(405, 1),
	(406, 1),
	(407, 1),
	(408, 1),
	(409, 1),
	(410, 1),
	(411, 1),
	(412, 1),
	(413, 1),
	(414, 1);
/*!40000 ALTER TABLE `sep_tmpl` ENABLE KEYS */;

-- Dumping structure for table emcor.sep_tmpl_dp_sheaf
CREATE TABLE IF NOT EXISTS `sep_tmpl_dp_sheaf` (
  `se_tmpl_dp_sheaf_id` int(10) unsigned NOT NULL COMMENT 'Nuskaitymo taško duomenų pluošto šaltinių šablono elemento ID',
  `ph_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius',
  PRIMARY KEY (`se_tmpl_dp_sheaf_id`,`ph_type_id`),
  KEY `sep_tmpl_dp_sheaf_ph_type_i` (`ph_type_id`),
  CONSTRAINT `sep_se_tmpl_dp_sheaf_fk` FOREIGN KEY (`se_tmpl_dp_sheaf_id`) REFERENCES `se_tmpl_dp_sheaf` (`se_tmpl_dp_sheaf_id`) ON DELETE CASCADE,
  CONSTRAINT `sep_tmpl_dp_sheaf_ph_type_fk` FOREIGN KEY (`ph_type_id`) REFERENCES `ph_type` (`ph_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitymo taško duomenų pluošto šaltinių šablono elementai pagal ryšio kanalų tipą';

-- Dumping data for table emcor.sep_tmpl_dp_sheaf: ~0 rows (approximately)
/*!40000 ALTER TABLE `sep_tmpl_dp_sheaf` DISABLE KEYS */;
/*!40000 ALTER TABLE `sep_tmpl_dp_sheaf` ENABLE KEYS */;

-- Dumping structure for table emcor.sep_tmpl_dp_sheaf_rc
CREATE TABLE IF NOT EXISTS `sep_tmpl_dp_sheaf_rc` (
  `se_tmpl_dp_sheaf_id` int(10) unsigned NOT NULL COMMENT 'Nuskaitymo taškų duomenų pluošto šaltinių šablono elemento ID',
  `ph_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius',
  `rc_id` tinyint(3) unsigned NOT NULL COMMENT 'Užklausų priežasties identifikatorius',
  `sch_id` mediumint(8) unsigned NOT NULL COMMENT 'Tvarkaraščio identifikatorius',
  `per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Periodo identifikatorius',
  `sep_rc_lag` mediumint(8) unsigned DEFAULT NULL COMMENT 'Periodų kiekis, apibrėžiantis nuskaitymo poslinkį',
  `sep_rc_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Periodų kiekis, apibrėžiantis nuskaitymo gylį',
  PRIMARY KEY (`se_tmpl_dp_sheaf_id`,`ph_type_id`,`rc_id`),
  KEY `sep_tmpl_dp_sheaf_rc_per_i` (`per_id`),
  KEY `sep_tmpl_dp_sheaf_rc_rc_i` (`rc_id`),
  KEY `sep_tmpl_dp_sheaf_rc_sch_i` (`sch_id`),
  CONSTRAINT `sep_rc_sep_dp_tmpl_sheaf_fk` FOREIGN KEY (`se_tmpl_dp_sheaf_id`, `ph_type_id`) REFERENCES `sep_tmpl_dp_sheaf` (`se_tmpl_dp_sheaf_id`, `ph_type_id`) ON DELETE CASCADE,
  CONSTRAINT `sep_tmpl_dp_sheaf_rc_per_fk` FOREIGN KEY (`per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `sep_tmpl_dp_sheaf_rc_rc_fk` FOREIGN KEY (`rc_id`) REFERENCES `rc` (`rc_id`) ON DELETE CASCADE,
  CONSTRAINT `sep_tmpl_dp_sheaf_rc_sch_fk` FOREIGN KEY (`sch_id`) REFERENCES `sch` (`sch_id`),
  CONSTRAINT `SEP_TMPL_DP_SH_RC_PER_ID_CHK` CHECK (`per_id` is not null and `sep_rc_lag` >= 0 or `per_id` is not null and `sep_rc_depth` is not null or `per_id` is null and `sep_rc_lag` is null and `sep_rc_depth` is null or `per_id` is null and `sep_rc_lag` = 0 and `sep_rc_depth` is null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitymo taško Duomenų pluoštų šaltinių šablono elementų pagal ryšio kanalų tipą konfigūracija pagal nuskaitymo priežastį';

-- Dumping data for table emcor.sep_tmpl_dp_sheaf_rc: ~0 rows (approximately)
/*!40000 ALTER TABLE `sep_tmpl_dp_sheaf_rc` DISABLE KEYS */;
/*!40000 ALTER TABLE `sep_tmpl_dp_sheaf_rc` ENABLE KEYS */;

-- Dumping structure for table emcor.sep_tmpl_ds_type
CREATE TABLE IF NOT EXISTS `sep_tmpl_ds_type` (
  `se_tmpl_ds_type_id` int(10) unsigned NOT NULL COMMENT 'Apskaitos būsenų signalų tipų šaltinių šablono elemento ID',
  `ph_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius',
  PRIMARY KEY (`se_tmpl_ds_type_id`,`ph_type_id`),
  KEY `sep_tmpl_ds_type_ph_type_i` (`ph_type_id`),
  CONSTRAINT `sep_se_tmpl_ds_type_fk` FOREIGN KEY (`se_tmpl_ds_type_id`) REFERENCES `se_tmpl_ds_type` (`se_tmpl_ds_type_id`) ON DELETE CASCADE,
  CONSTRAINT `sep_tmpl_ds_type_ph_type_fk` FOREIGN KEY (`ph_type_id`) REFERENCES `ph_type` (`ph_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apskaitos būsenų signalų tipų šaltinių šablono elementai pagal ryšio kanalų tipą';

-- Dumping data for table emcor.sep_tmpl_ds_type: ~0 rows (approximately)
/*!40000 ALTER TABLE `sep_tmpl_ds_type` DISABLE KEYS */;
/*!40000 ALTER TABLE `sep_tmpl_ds_type` ENABLE KEYS */;

-- Dumping structure for table emcor.sep_tmpl_ds_type_rc
CREATE TABLE IF NOT EXISTS `sep_tmpl_ds_type_rc` (
  `se_tmpl_ds_type_id` int(10) unsigned NOT NULL COMMENT 'Apskaitos būsenų signalų tipų šaltinių šablono elemento ID',
  `ph_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius',
  `rc_id` tinyint(3) unsigned NOT NULL COMMENT 'Užklausų priežasties identifikatorius',
  `sch_id` mediumint(8) unsigned NOT NULL COMMENT 'Tvarkaraščio identifikatorius',
  `per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Periodo identifikatorius',
  `sep_rc_lag` mediumint(8) unsigned DEFAULT NULL COMMENT 'Periodų kiekis, apibrežiantis nuskaitymo poslinkį',
  `sep_rc_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Periodų kiekis, apibrežiantis nuskaitymo gylį',
  PRIMARY KEY (`se_tmpl_ds_type_id`,`ph_type_id`,`rc_id`),
  KEY `sep_tmpl_ds_type_rc_per_i` (`per_id`),
  KEY `sep_tmpl_ds_type_rc_rc_i` (`rc_id`),
  KEY `sep_tmpl_ds_type_rc_sch_i` (`sch_id`),
  CONSTRAINT `sep_se_tmpl_ds_type_rc_fk` FOREIGN KEY (`se_tmpl_ds_type_id`) REFERENCES `se_tmpl_ds_type` (`se_tmpl_ds_type_id`) ON DELETE CASCADE,
  CONSTRAINT `sep_tmpl_ds_type_rc_per_fk` FOREIGN KEY (`per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `sep_tmpl_ds_type_rc_rc_fk` FOREIGN KEY (`rc_id`) REFERENCES `rc` (`rc_id`) ON DELETE CASCADE,
  CONSTRAINT `sep_tmpl_ds_type_rc_sch_fk` FOREIGN KEY (`sch_id`) REFERENCES `sch` (`sch_id`),
  CONSTRAINT `SEP_TMPL_DS_TYPE_RC_PER_ID_CHK` CHECK (`per_id` is not null and `sep_rc_lag` >= 0 or `per_id` is not null and `sep_rc_depth` is not null or `per_id` is null and `sep_rc_lag` is null and `sep_rc_depth` is null or `per_id` is null and `sep_rc_lag` = 0 and `sep_rc_depth` is null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apskaitos būsenų signalų tipų šaltinių šablono elementų pagal ryšio kanalų tipą konfiguracija pagal nuskaitymo priežastį';

-- Dumping data for table emcor.sep_tmpl_ds_type_rc: ~0 rows (approximately)
/*!40000 ALTER TABLE `sep_tmpl_ds_type_rc` DISABLE KEYS */;
/*!40000 ALTER TABLE `sep_tmpl_ds_type_rc` ENABLE KEYS */;

-- Dumping structure for table emcor.sep_tmpl_rc
CREATE TABLE IF NOT EXISTS `sep_tmpl_rc` (
  `se_tmpl_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių šablono elemento ID',
  `ph_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius',
  `rc_id` tinyint(3) unsigned NOT NULL COMMENT 'Užklausų priežasties identifikatorius',
  `sch_id` mediumint(8) unsigned NOT NULL COMMENT 'Tvarkaraščio identifikatorius',
  `per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Periodo identifikatorius',
  `sep_rc_lag` mediumint(8) unsigned DEFAULT NULL COMMENT 'Periodų kiekis, apibrėžiantis nuskaitymo poslinkį',
  `sep_rc_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Periodų kiekis, apibrėžiantis nuskaitymo gylį',
  PRIMARY KEY (`se_tmpl_id`,`ph_type_id`,`rc_id`),
  KEY `sep_tmpl_rc_per_i` (`per_id`),
  KEY `sep_tmpl_rc_rc_i` (`rc_id`),
  KEY `sep_tmpl_rc_sch_i` (`sch_id`),
  CONSTRAINT `sep_tmpl_rc_per_fk` FOREIGN KEY (`per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `sep_tmpl_rc_rc_fk` FOREIGN KEY (`rc_id`) REFERENCES `rc` (`rc_id`) ON DELETE CASCADE,
  CONSTRAINT `sep_tmpl_rc_sch_fk` FOREIGN KEY (`sch_id`) REFERENCES `sch` (`sch_id`),
  CONSTRAINT `sep_tmpl_rc_sep_tmpl_fk` FOREIGN KEY (`se_tmpl_id`, `ph_type_id`) REFERENCES `sep_tmpl` (`se_tmpl_id`, `ph_type_id`) ON DELETE CASCADE,
  CONSTRAINT `SEP_TMPL_RC_PER_ID_CHK` CHECK (`per_id` is not null and `sep_rc_lag` >= 0 or `per_id` is not null and `sep_rc_depth` is not null or `per_id` is null and `sep_rc_lag` is null and `sep_rc_depth` is null or `per_id` is null and `sep_rc_lag` = 0 and `sep_rc_depth` is null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų šaltinių šablono elementų pagal ryšio kanalų tipą konfigūracija pagal nuskaitymo priežastį';

-- Dumping data for table emcor.sep_tmpl_rc: ~119 rows (approximately)
/*!40000 ALTER TABLE `sep_tmpl_rc` DISABLE KEYS */;
INSERT INTO `sep_tmpl_rc` (`se_tmpl_id`, `ph_type_id`, `rc_id`, `sch_id`, `per_id`, `sep_rc_lag`, `sep_rc_depth`) VALUES
	(341, 1, 2, 42, NULL, 0, NULL),
	(342, 1, 2, 42, NULL, 0, NULL),
	(343, 1, 2, 42, NULL, 0, NULL),
	(344, 1, 2, 42, NULL, 0, NULL),
	(345, 1, 2, 42, NULL, 0, NULL),
	(346, 1, 2, 42, NULL, 0, NULL),
	(347, 1, 2, 42, NULL, 0, NULL),
	(348, 1, 2, 42, NULL, 0, NULL),
	(349, 1, 2, 42, NULL, 0, NULL),
	(350, 1, 2, 42, NULL, 0, NULL),
	(351, 1, 2, 42, NULL, 0, NULL),
	(352, 1, 2, 42, NULL, 0, NULL),
	(353, 1, 2, 42, NULL, 0, NULL),
	(354, 1, 2, 42, NULL, 0, NULL),
	(355, 1, 2, 43, 5, 0, 1),
	(355, 1, 4, 43, 5, 1, NULL),
	(356, 1, 2, 43, 5, 0, 1),
	(356, 1, 4, 43, 5, 1, NULL),
	(357, 1, 2, 43, 5, 0, 1),
	(357, 1, 4, 43, 5, 1, NULL),
	(358, 1, 2, 43, 5, 0, 1),
	(358, 1, 4, 43, 5, 1, NULL),
	(359, 1, 2, 43, 5, 0, 1),
	(359, 1, 4, 43, 5, 1, NULL),
	(360, 1, 2, 43, 5, 0, 1),
	(360, 1, 4, 43, 5, 1, NULL),
	(361, 1, 2, 43, 5, 0, 1),
	(361, 1, 4, 43, 5, 1, NULL),
	(362, 1, 2, 43, 5, 0, 1),
	(362, 1, 4, 43, 5, 1, NULL),
	(363, 1, 2, 43, 5, 0, 1),
	(363, 1, 4, 43, 5, 1, NULL),
	(364, 1, 2, 43, 5, 0, 1),
	(364, 1, 4, 43, 5, 1, NULL),
	(365, 1, 2, 43, 5, 0, 1),
	(365, 1, 4, 43, 5, 1, NULL),
	(366, 1, 2, 43, 5, 0, 1),
	(366, 1, 4, 43, 5, 1, NULL),
	(367, 1, 2, 43, 5, 0, 1),
	(367, 1, 4, 43, 5, 1, NULL),
	(368, 1, 2, 43, 5, 0, 1),
	(368, 1, 4, 43, 5, 1, NULL),
	(369, 1, 2, 43, 5, 0, 1),
	(369, 1, 4, 43, 5, 1, NULL),
	(370, 1, 2, 43, 5, 0, 1),
	(370, 1, 4, 43, 5, 1, NULL),
	(371, 1, 2, 43, 4, 1, 1),
	(371, 1, 4, 43, 4, 1, NULL),
	(372, 1, 2, 43, 4, 1, 1),
	(372, 1, 4, 43, 4, 1, NULL),
	(373, 1, 2, 43, 4, 1, 1),
	(373, 1, 4, 43, 4, 1, NULL),
	(374, 1, 2, 43, 4, 1, 1),
	(374, 1, 4, 43, 4, 1, NULL),
	(375, 1, 2, 43, 4, 1, 1),
	(375, 1, 4, 43, 4, 1, NULL),
	(376, 1, 2, 43, 4, 1, 1),
	(376, 1, 4, 43, 4, 1, NULL),
	(377, 1, 2, 43, 4, 1, 1),
	(377, 1, 4, 43, 4, 1, NULL),
	(378, 1, 2, 43, 4, 1, 1),
	(378, 1, 4, 43, 4, 1, NULL),
	(379, 1, 2, 43, 4, 1, 1),
	(379, 1, 4, 43, 4, 1, NULL),
	(380, 1, 2, 43, 4, 1, 1),
	(380, 1, 4, 43, 4, 1, NULL),
	(381, 1, 2, 43, 4, 1, 1),
	(381, 1, 4, 43, 4, 1, NULL),
	(382, 1, 2, 43, 4, 1, 1),
	(382, 1, 4, 43, 4, 1, NULL),
	(383, 1, 2, 43, 4, 1, 1),
	(383, 1, 4, 43, 4, 1, NULL),
	(384, 1, 2, 43, 4, 1, 1),
	(384, 1, 4, 43, 4, 1, NULL),
	(385, 1, 2, 43, 4, 1, 1),
	(385, 1, 4, 43, 4, 1, NULL),
	(386, 1, 2, 43, 4, 1, 1),
	(386, 1, 4, 43, 4, 1, NULL),
	(387, 1, 2, 42, 3, 0, 1),
	(387, 1, 4, 43, 3, 1, NULL),
	(388, 1, 2, 42, 3, 0, 1),
	(388, 1, 4, 43, 3, 1, NULL),
	(388, 2, 2, 42, 3, 2, 1),
	(389, 1, 2, 42, 3, 0, 1),
	(389, 1, 4, 43, 3, 1, NULL),
	(390, 1, 2, 42, 3, 0, 1),
	(390, 1, 4, 43, 3, 1, NULL),
	(391, 1, 2, 42, NULL, 0, NULL),
	(392, 1, 2, 42, NULL, 0, NULL),
	(393, 1, 2, 42, NULL, 0, NULL),
	(394, 1, 2, 42, NULL, 0, NULL),
	(395, 1, 2, 42, NULL, 0, NULL),
	(396, 1, 2, 42, NULL, 0, NULL),
	(397, 1, 2, 42, NULL, 0, NULL),
	(398, 1, 2, 42, NULL, 0, NULL),
	(399, 1, 2, 42, NULL, 0, NULL),
	(400, 1, 2, 42, NULL, 0, NULL),
	(401, 1, 2, 42, NULL, 0, NULL),
	(402, 1, 2, 42, NULL, 0, NULL),
	(403, 1, 2, 42, NULL, 0, NULL),
	(404, 1, 2, 42, NULL, 0, NULL),
	(405, 1, 2, 42, NULL, 0, NULL),
	(406, 1, 2, 42, NULL, 0, NULL),
	(407, 1, 2, 42, 3, 0, 1),
	(407, 1, 4, 43, 3, 1, NULL),
	(408, 1, 2, 42, 3, 0, 1),
	(408, 1, 4, 43, 3, 1, NULL),
	(409, 1, 2, 42, 3, 0, 1),
	(409, 1, 4, 43, 3, 1, NULL),
	(410, 1, 2, 42, 3, 0, 1),
	(410, 1, 4, 43, 3, 1, NULL),
	(411, 1, 2, 42, 3, 0, 1),
	(411, 1, 4, 43, 3, 1, NULL),
	(412, 1, 2, 42, 3, 0, 1),
	(412, 1, 4, 43, 3, 1, NULL),
	(413, 1, 2, 42, 3, 0, 1),
	(413, 1, 4, 43, 3, 1, NULL),
	(414, 1, 2, 42, 3, 0, 1),
	(414, 1, 4, 43, 3, 1, NULL);
/*!40000 ALTER TABLE `sep_tmpl_rc` ENABLE KEYS */;

-- Dumping structure for table emcor.sep_tmpl_sheaf
CREATE TABLE IF NOT EXISTS `sep_tmpl_sheaf` (
  `se_tmpl_sheaf_id` int(10) unsigned NOT NULL COMMENT 'Duomenų pluošto šaltinių šablono elemento ID',
  `ph_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius',
  PRIMARY KEY (`se_tmpl_sheaf_id`,`ph_type_id`),
  KEY `sep_tmpl_sheaf_ph_type_i` (`ph_type_id`),
  CONSTRAINT `sep_se_tmpl_sheaf_fk` FOREIGN KEY (`se_tmpl_sheaf_id`) REFERENCES `se_tmpl_sheaf` (`se_tmpl_sheaf_id`) ON DELETE CASCADE,
  CONSTRAINT `sep_tmpl_sheaf_ph_type_fk` FOREIGN KEY (`ph_type_id`) REFERENCES `ph_type` (`ph_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų pluoštų šaltinių šablono elementai pagal ryšio kanalų tipą';

-- Dumping data for table emcor.sep_tmpl_sheaf: ~0 rows (approximately)
/*!40000 ALTER TABLE `sep_tmpl_sheaf` DISABLE KEYS */;
/*!40000 ALTER TABLE `sep_tmpl_sheaf` ENABLE KEYS */;

-- Dumping structure for table emcor.sep_tmpl_sheaf_rc
CREATE TABLE IF NOT EXISTS `sep_tmpl_sheaf_rc` (
  `se_tmpl_sheaf_id` int(10) unsigned NOT NULL COMMENT 'Duomenų pluošto šaltinių šablono elemento ID',
  `ph_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius',
  `rc_id` tinyint(3) unsigned NOT NULL COMMENT 'Užklausų priežasties identifikatorius',
  `sch_id` mediumint(8) unsigned NOT NULL COMMENT 'Tvarkaraščio identifikatorius',
  `per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Periodo identifikatorius',
  `sep_rc_lag` mediumint(8) unsigned DEFAULT NULL COMMENT 'Periodų kiekis, apibrėžiantis nuskaitymo poslinkį',
  `sep_rc_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Periodų kiekis, apibrėžiantis nuskaitymo gylį',
  PRIMARY KEY (`se_tmpl_sheaf_id`,`ph_type_id`,`rc_id`),
  KEY `sep_tmpl_sheaf_rc_per_i` (`per_id`),
  KEY `sep_tmpl_sheaf_rc_rc_i` (`rc_id`),
  KEY `sep_tmpl_sheaf_rc_sch_i` (`sch_id`),
  CONSTRAINT `sep_rc_sep_tmpl_sheaf_fk` FOREIGN KEY (`se_tmpl_sheaf_id`, `ph_type_id`) REFERENCES `sep_tmpl_sheaf` (`se_tmpl_sheaf_id`, `ph_type_id`) ON DELETE CASCADE,
  CONSTRAINT `sep_tmpl_sheaf_rc_per_fk` FOREIGN KEY (`per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `sep_tmpl_sheaf_rc_rc_fk` FOREIGN KEY (`rc_id`) REFERENCES `rc` (`rc_id`) ON DELETE CASCADE,
  CONSTRAINT `sep_tmpl_sheaf_rc_sch_fk` FOREIGN KEY (`sch_id`) REFERENCES `sch` (`sch_id`),
  CONSTRAINT `SEP_TMPL_SHEAF_RC_PER_ID_CHK` CHECK (`per_id` is not null and `sep_rc_lag` >= 0 or `per_id` is not null and `sep_rc_depth` is not null or `per_id` is null and `sep_rc_lag` is null and `sep_rc_depth` is null or `per_id` is null and `sep_rc_lag` = 0 and `sep_rc_depth` is null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų pluoštų šaltinių šablono elementų pagal ryšio kanalų tipą konfigūracija pagal nuskaitymo priežastį';

-- Dumping data for table emcor.sep_tmpl_sheaf_rc: ~0 rows (approximately)
/*!40000 ALTER TABLE `sep_tmpl_sheaf_rc` DISABLE KEYS */;
/*!40000 ALTER TABLE `sep_tmpl_sheaf_rc` ENABLE KEYS */;

-- Dumping structure for table emcor.sep_used
CREATE TABLE IF NOT EXISTS `sep_used` (
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  PRIMARY KEY (`sep_id`),
  CONSTRAINT `sep_used_sep_fk` FOREIGN KEY (`sep_id`) REFERENCES `sep` (`sep_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Panaudotų rodmenų lentelėse duomenų šaltinių elementų, nuskaitomų per ryšio kanalus, sąrašas';

-- Dumping data for table emcor.sep_used: ~26 rows (approximately)
/*!40000 ALTER TABLE `sep_used` DISABLE KEYS */;
INSERT INTO `sep_used` (`sep_id`) VALUES
	(1),
	(2),
	(3),
	(4),
	(5),
	(6),
	(7),
	(8),
	(9),
	(11),
	(13),
	(14),
	(15),
	(16),
	(18),
	(19),
	(20),
	(21),
	(26),
	(28),
	(29),
	(33),
	(35),
	(36),
	(37),
	(38);
/*!40000 ALTER TABLE `sep_used` ENABLE KEYS */;

-- Dumping structure for table emcor.sequence_data
CREATE TABLE IF NOT EXISTS `sequence_data` (
  `sequence_name` varchar(100) COLLATE utf8_bin NOT NULL,
  `sequence_increment` int(11) unsigned NOT NULL DEFAULT 1,
  `sequence_min_value` int(11) unsigned NOT NULL DEFAULT 1,
  `sequence_max_value` bigint(20) unsigned NOT NULL DEFAULT 18446744073709551615,
  `sequence_cur_value` bigint(20) unsigned DEFAULT 1,
  `sequence_cycle` tinyint(1) NOT NULL DEFAULT 1,
  PRIMARY KEY (`sequence_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- Dumping data for table emcor.sequence_data: ~17 rows (approximately)
/*!40000 ALTER TABLE `sequence_data` DISABLE KEYS */;
INSERT INTO `sequence_data` (`sequence_name`, `sequence_increment`, `sequence_min_value`, `sequence_max_value`, `sequence_cur_value`, `sequence_cycle`) VALUES
	('ATOM_LOG_SEQ', 1, 0, 9999999, 1, 1),
	('AU_SEQ', 1, 0, 9999999, 2, 1),
	('BGAO_SEQ', 1, 1, 9999999999, 1, 1),
	('EAPP_SEQ', 1, 1, 9999999999, 1, 1),
	('EDEVPRQ_SEQ', 1, 1, 9999999999, 1, 1),
	('EDEV_SEQ', 1, 1, 9999999999, 1, 1),
	('EE_SEQ', 1, 1, 9999999999, 1, 1),
	('EV_SEQ', 1, 0, 9999999, 1, 1),
	('GRQ_ONR_SEQ', 1, 0, 9999999, 1, 1),
	('RODO_SEQ', 1, 1, 1999999999, 1, 1),
	('RP_LOG_SEQ', 1, 0, 9999999, 1, 1),
	('SRCACL_SEQ', 1, 1, 9999999999, 1, 1),
	('STORE_DS_BUF_SEQ', 1, 1, 999999999, 1, 1),
	('STORE_PL_BUF_SEQ', 1, 1, 999999999, 1, 1),
	('STORE_PW_BUF_SEQ', 1, 1, 999999999, 1, 1),
	('XO_SEQ', 1, 1, 999999999999, 1, 1);
/*!40000 ALTER TABLE `sequence_data` ENABLE KEYS */;

-- Dumping structure for table emcor.server_tz
CREATE TABLE IF NOT EXISTS `server_tz` (
  `tz_id` smallint(5) unsigned NOT NULL COMMENT 'Laiko zonos identifikatorius',
  `server_tz_dst_used` tinyint(1) NOT NULL COMMENT 'Vasaros laiko naudojimo požymis',
  PRIMARY KEY (`tz_id`),
  CONSTRAINT `server_tz_tz_fk` FOREIGN KEY (`tz_id`) REFERENCES `tz` (`tz_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Serverio laiko zona';

-- Dumping data for table emcor.server_tz: ~0 rows (approximately)
/*!40000 ALTER TABLE `server_tz` DISABLE KEYS */;
INSERT INTO `server_tz` (`tz_id`, `server_tz_dst_used`) VALUES
	(1, 1);
/*!40000 ALTER TABLE `server_tz` ENABLE KEYS */;

-- Dumping structure for table emcor.ses
CREATE TABLE IF NOT EXISTS `ses` (
  `ses_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Sesijos identifikatorius',
  `user_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojo identifikatorius',
  `ses_logon` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Sesijos pradžios laikas',
  `ses_logoff` datetime DEFAULT NULL COMMENT 'Sesijos pabaigos laikas',
  `ses_remote_host` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Adresas, iš kurio sukurta sesija',
  PRIMARY KEY (`ses_id`),
  KEY `ses_ses_logon_i` (`ses_logon`),
  KEY `ses_user_i` (`user_id`,`ses_logon`),
  CONSTRAINT `ses_user_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Prisijungimo prie EMCOS sesijos';

-- Dumping data for table emcor.ses: ~0 rows (approximately)
/*!40000 ALTER TABLE `ses` DISABLE KEYS */;
/*!40000 ALTER TABLE `ses` ENABLE KEYS */;

-- Dumping structure for table emcor.ses_nv
CREATE TABLE IF NOT EXISTS `ses_nv` (
  `ses_id` bigint(20) unsigned NOT NULL COMMENT 'Sesijos identifikatorius',
  `dbu` varchar(30) COLLATE utf8_bin NOT NULL COMMENT 'Sistemos vartotojo DB vartotojo vardas',
  `ses_attempt` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Sesijos nesėkmingo prisijungimo laikas',
  `ses_remote_host` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Adresas, iš kurio sukurta sesija',
  PRIMARY KEY (`ses_id`),
  KEY `ses_nv_attempt_i` (`ses_attempt`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Nesėkmingo prisijungimo prie EMCOS sesijos';

-- Dumping data for table emcor.ses_nv: ~0 rows (approximately)
/*!40000 ALTER TABLE `ses_nv` DISABLE KEYS */;
/*!40000 ALTER TABLE `ses_nv` ENABLE KEYS */;

-- Dumping structure for table emcor.se_gs
CREATE TABLE IF NOT EXISTS `se_gs` (
  `se_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento identifikatorius',
  `se_summand` double NOT NULL COMMENT 'Duomenų šaltinio elemento augantis dėmuo',
  PRIMARY KEY (`se_id`),
  CONSTRAINT `se_gs_se_fk` FOREIGN KEY (`se_id`) REFERENCES `se` (`se_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų šaltinio elementų augantys dėmenys';

-- Dumping data for table emcor.se_gs: ~0 rows (approximately)
/*!40000 ALTER TABLE `se_gs` DISABLE KEYS */;
/*!40000 ALTER TABLE `se_gs` ENABLE KEYS */;

-- Dumping structure for table emcor.se_lpty
CREATE TABLE IF NOT EXISTS `se_lpty` (
  `se_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento identifikatorius',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `lpty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ryšio modulių savybės reikšmė',
  PRIMARY KEY (`se_id`,`lpty_id`),
  KEY `se_lpty_lpty_i` (`lpty_id`),
  CONSTRAINT `se_lpty_lpty_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`) ON DELETE CASCADE,
  CONSTRAINT `se_lpty_se_fk` FOREIGN KEY (`se_id`) REFERENCES `se` (`se_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų šaltinio elementų duomenys';

-- Dumping data for table emcor.se_lpty: ~34 rows (approximately)
/*!40000 ALTER TABLE `se_lpty` DISABLE KEYS */;
INSERT INTO `se_lpty` (`se_id`, `lpty_id`, `lpty_value`) VALUES
	(1, 355, '17'),
	(2, 355, '18'),
	(3, 355, '19'),
	(4, 355, '20'),
	(5, 355, '21'),
	(6, 355, '22'),
	(7, 355, '23'),
	(8, 355, '24'),
	(9, 355, '25'),
	(10, 355, '26'),
	(11, 355, '29'),
	(12, 355, '30'),
	(13, 355, '31'),
	(14, 355, '27'),
	(15, 355, '28'),
	(16, 355, '32'),
	(17, 355, '33'),
	(18, 355, '34'),
	(19, 355, '35'),
	(20, 355, '36'),
	(21, 355, '46'),
	(26, 355, '51'),
	(27, 355, '52'),
	(28, 355, '53'),
	(29, 355, '54'),
	(30, 355, '55'),
	(31, 355, '56'),
	(32, 355, '57'),
	(33, 355, '58'),
	(34, 355, '59'),
	(35, 355, '60'),
	(36, 355, '61'),
	(37, 355, '62'),
	(38, 355, '63');
/*!40000 ALTER TABLE `se_lpty` ENABLE KEYS */;

-- Dumping structure for table emcor.se_tmpl
CREATE TABLE IF NOT EXISTS `se_tmpl` (
  `se_tmpl_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Duomenų šaltinių šablono elemento ID',
  `src_tmpl_id` mediumint(8) unsigned NOT NULL COMMENT 'Duomenų šaltinių šablono ID',
  `ml_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo linijos identifikatorius',
  `lp_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio prioritetų profilio identifikatorius',
  `se_ab` tinyint(3) unsigned DEFAULT NULL COMMENT 'Šaltinio elemento duomenų tiesinio transformavimo ryšio modulyje požymis',
  `se_a` double DEFAULT NULL COMMENT 'Duomenų šaltinio elemento daugiklis',
  `se_b` double DEFAULT NULL COMMENT 'Duomenų šaltinio elemento dedamoji',
  `se_h` tinyint(1) NOT NULL COMMENT 'Istorinių duomenų egzistavimo požymis',
  `se_h_per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Istorinių duomenų gylio laiko vienetų identifikatorius ',
  `se_h_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Laiko periodų kiekis, apibrėžiantis istorinių duomenų gylį',
  `se_h_restore_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Laiko periodų kiekis, apibrėžiantis istorinių duomenų, kurie gali būti atnaujinami šaltinyje, gylį',
  `se_h_restore_per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Istorinių duomenų, kurie gali būti atnaujinami šaltinyje, gylio laiko vienetų identifikatorius',
  `se_tmpl_extend_pl` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Požymis, ar šaltinio pagal šabloną sukūrimo metu taško matavimus papildyti šablone numatytu matavimu',
  PRIMARY KEY (`se_tmpl_id`),
  UNIQUE KEY `se_tmpl_ml_u` (`ml_id`,`src_tmpl_id`),
  KEY `se_tmpl_h_per_i` (`se_h_per_id`),
  KEY `se_tmpl_restore_per_i` (`se_h_restore_per_id`),
  KEY `se_tmpl_src_tmpl_i` (`src_tmpl_id`),
  KEY `se_tmpl_lp_fk` (`lp_id`),
  CONSTRAINT `se_tmpl_lp_fk` FOREIGN KEY (`lp_id`) REFERENCES `lp` (`lp_id`),
  CONSTRAINT `se_tmpl_ml_fk` FOREIGN KEY (`ml_id`) REFERENCES `ml` (`ml_id`) ON DELETE CASCADE,
  CONSTRAINT `se_tmpl_per_fk` FOREIGN KEY (`se_h_per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `se_tmpl_restore_per_fk` FOREIGN KEY (`se_h_restore_per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `se_tmpl_src_tmpl_fk` FOREIGN KEY (`src_tmpl_id`) REFERENCES `src_tmpl` (`src_tmpl_id`) ON DELETE CASCADE,
  CONSTRAINT `SE_TMPL_AB_NOT_NULL_CHK` CHECK (`se_ab` is null and `se_a` is null and `se_b` is null or `se_ab` is not null and `se_a` is not null and `se_b` is not null)
) ENGINE=InnoDB AUTO_INCREMENT=415 DEFAULT CHARSET=utf8 COMMENT='Duomenų šaltinių šablono elementai';

-- Dumping data for table emcor.se_tmpl: ~74 rows (approximately)
/*!40000 ALTER TABLE `se_tmpl` DISABLE KEYS */;
INSERT INTO `se_tmpl` (`se_tmpl_id`, `src_tmpl_id`, `ml_id`, `lp_id`, `se_ab`, `se_a`, `se_b`, `se_h`, `se_h_per_id`, `se_h_depth`, `se_h_restore_depth`, `se_h_restore_per_id`, `se_tmpl_extend_pl`) VALUES
	(341, 141, 57, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(342, 141, 56, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(343, 141, 55, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(344, 141, 54, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(345, 141, 53, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(346, 141, 85, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(347, 141, 84, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(348, 141, 67, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(349, 141, 66, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(350, 141, 65, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(351, 141, 64, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(352, 141, 63, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(353, 141, 62, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(354, 141, 58, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(355, 141, 19, 1, 1, 1, 0, 1, 5, 15, NULL, 2, 0),
	(356, 141, 20, 1, 1, 1, 0, 1, 5, 15, NULL, 2, 0),
	(357, 141, 23, 1, 1, 1, 0, 1, 5, 15, NULL, 2, 0),
	(358, 141, 24, 1, 1, 1, 0, 1, 5, 15, NULL, 2, 0),
	(359, 141, 27, 1, 1, 1, 0, 1, 5, 15, NULL, 2, 0),
	(360, 141, 28, 1, 1, 1, 0, 1, 5, 15, NULL, 2, 0),
	(361, 141, 31, 1, 1, 1, 0, 1, 5, 15, NULL, 2, 0),
	(362, 141, 32, 1, 1, 1, 0, 1, 5, 15, NULL, 2, 0),
	(363, 141, 17, 1, 1, 1, 0, 1, 5, 15, NULL, 2, 0),
	(364, 141, 18, 1, 1, 1, 0, 1, 5, 15, NULL, 2, 0),
	(365, 141, 21, 1, 1, 1, 0, 1, 5, 15, NULL, 2, 0),
	(366, 141, 22, 1, 1, 1, 0, 1, 5, 15, NULL, 2, 0),
	(367, 141, 25, 1, 1, 1, 0, 1, 5, 15, NULL, 2, 0),
	(368, 141, 26, 1, 1, 1, 0, 1, 5, 15, NULL, 2, 0),
	(369, 141, 29, 1, 1, 1, 0, 1, 5, 15, NULL, 2, 0),
	(370, 141, 30, 1, 1, 1, 0, 1, 5, 15, NULL, 2, 0),
	(371, 141, 35, 1, 1, 1, 0, 1, 4, 6, NULL, 2, 0),
	(372, 141, 36, 1, 1, 1, 0, 1, 4, 6, NULL, 2, 0),
	(373, 141, 39, 1, 1, 1, 0, 1, 4, 6, NULL, 2, 0),
	(374, 141, 40, 1, 1, 1, 0, 1, 4, 6, NULL, 2, 0),
	(375, 141, 43, 1, 1, 1, 0, 1, 4, 6, NULL, 2, 0),
	(376, 141, 44, 1, 1, 1, 0, 1, 4, 6, NULL, 2, 0),
	(377, 141, 47, 1, 1, 1, 0, 1, 4, 6, NULL, 2, 0),
	(378, 141, 48, 1, 1, 1, 0, 1, 4, 6, NULL, 2, 0),
	(379, 141, 33, 1, 1, 1, 0, 1, 4, 6, NULL, 2, 0),
	(380, 141, 34, 1, 1, 1, 0, 1, 4, 6, NULL, 2, 0),
	(381, 141, 37, 1, 1, 1, 0, 1, 4, 6, NULL, 2, 0),
	(382, 141, 38, 1, 1, 1, 0, 1, 4, 6, NULL, 2, 0),
	(383, 141, 41, 1, 1, 1, 0, 1, 4, 6, NULL, 2, 0),
	(384, 141, 42, 1, 1, 1, 0, 1, 4, 6, NULL, 2, 0),
	(385, 141, 45, 1, 1, 1, 0, 1, 4, 6, NULL, 2, 0),
	(386, 141, 46, 1, 1, 1, 0, 1, 4, 6, NULL, 2, 0),
	(387, 141, 51, 1, 1, 1, 0, 1, 4, 37, NULL, 2, 0),
	(388, 141, 52, 1, 1, 1, 0, 1, 4, 37, NULL, 2, 0),
	(389, 141, 49, 1, 1, 1, 0, 1, 4, 37, NULL, 2, 0),
	(390, 141, 50, 1, 1, 1, 0, 1, 4, 37, NULL, 2, 0),
	(391, 141, 3, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(392, 141, 4, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(393, 141, 7, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(394, 141, 8, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(395, 141, 11, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(396, 141, 12, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(397, 141, 15, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(398, 141, 16, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(399, 141, 1, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(400, 141, 2, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(401, 141, 5, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(402, 141, 6, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(403, 141, 9, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(404, 141, 10, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(405, 141, 13, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(406, 141, 14, 1, 1, 1, 0, 0, NULL, NULL, NULL, NULL, 0),
	(407, 141, 1046, 1, 1, 1, 0, 1, 4, 37, NULL, 2, 0),
	(408, 141, 1047, 1, 1, 1, 0, 1, 4, 37, NULL, 2, 0),
	(409, 141, 1044, 1, 1, 1, 0, 1, 4, 37, NULL, 2, 0),
	(410, 141, 1045, 1, 1, 1, 0, 1, 4, 37, NULL, 2, 0),
	(411, 141, 379, 1, 1, 1, 0, 1, 4, 37, NULL, 2, 0),
	(412, 141, 380, 1, 1, 1, 0, 1, 4, 37, NULL, 2, 0),
	(413, 141, 377, 1, 1, 1, 0, 1, 4, 37, NULL, 2, 0),
	(414, 141, 378, 1, 1, 1, 0, 1, 4, 37, NULL, 2, 0);
/*!40000 ALTER TABLE `se_tmpl` ENABLE KEYS */;

-- Dumping structure for table emcor.se_tmpl_dp_sheaf
CREATE TABLE IF NOT EXISTS `se_tmpl_dp_sheaf` (
  `se_tmpl_dp_sheaf_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Nuskaitymo taškų duomenų pluošto šaltinių šablono elemento ID',
  `src_tmpl_id` mediumint(8) unsigned NOT NULL COMMENT 'Duomenų šaltinių šablono ID',
  `sheaf_id` mediumint(8) unsigned NOT NULL COMMENT 'Duomenų pluošto identifikatorius',
  `lp_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio prioritetų profilio identifikatorius',
  `se_h` tinyint(1) NOT NULL COMMENT 'Istorinių duomenų egzistavimo požymis',
  `se_h_per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Istorinių duomenų gylio laiko vienetų identifikatorius ',
  `se_h_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Laiko periodų kiekis, apibrėžiantis istorinių duomenų gylį',
  `se_h_restore_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Laiko periodų kiekis, apibrėžiantis istorinių duomenų, kurie gali būti atnaujinami šaltinyje, gylį',
  `se_h_restore_per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Istorinių duomenų, kurie gali būti atnaujinami šaltinyje, gylio laiko vienetų identifikatorius',
  `witheset_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų vytelių rinkinio identifikatorius',
  PRIMARY KEY (`se_tmpl_dp_sheaf_id`),
  UNIQUE KEY `se_tmpl_dp_sheaf_u` (`src_tmpl_id`,`sheaf_id`,`witheset_id`),
  KEY `se_tmpl_dp_sheaf_h_per_i` (`se_h_per_id`),
  KEY `se_tmpl_dp_sheaf_res_per_i` (`se_h_restore_per_id`),
  KEY `se_tmpl_dp_sheaf_src_tmpl_i` (`src_tmpl_id`),
  KEY `se_tmpl_dp_sheaf_fk` (`sheaf_id`),
  KEY `se_tmpl_dp_sheaf_lp_fk` (`lp_id`),
  KEY `se_tmpl_dp_sheaf_witheset_fk` (`witheset_id`),
  CONSTRAINT `se_tmpl_dp_sheaf_fk` FOREIGN KEY (`sheaf_id`) REFERENCES `sheaf` (`sheaf_id`) ON DELETE CASCADE,
  CONSTRAINT `se_tmpl_dp_sheaf_lp_fk` FOREIGN KEY (`lp_id`) REFERENCES `lp` (`lp_id`),
  CONSTRAINT `se_tmpl_dp_sheaf_per_fk` FOREIGN KEY (`se_h_per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `se_tmpl_dp_sheaf_res_per_fk` FOREIGN KEY (`se_h_restore_per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `se_tmpl_dp_sheaf_src_tmpl_fk` FOREIGN KEY (`src_tmpl_id`) REFERENCES `src_tmpl` (`src_tmpl_id`) ON DELETE CASCADE,
  CONSTRAINT `se_tmpl_dp_sheaf_witheset_fk` FOREIGN KEY (`witheset_id`) REFERENCES `witheset` (`witheset_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitymo taškų duomenų pluoštų šaltinių šablono elementai';

-- Dumping data for table emcor.se_tmpl_dp_sheaf: ~0 rows (approximately)
/*!40000 ALTER TABLE `se_tmpl_dp_sheaf` DISABLE KEYS */;
/*!40000 ALTER TABLE `se_tmpl_dp_sheaf` ENABLE KEYS */;

-- Dumping structure for table emcor.se_tmpl_dp_sheaf_lpty
CREATE TABLE IF NOT EXISTS `se_tmpl_dp_sheaf_lpty` (
  `se_tmpl_dp_sheaf_id` int(10) unsigned NOT NULL COMMENT 'Nuskaitymo taško duomenų pluošto šaltinių šablono elemento ID',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `lpty_value` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Ryšio modulių savybės reikšmė',
  PRIMARY KEY (`se_tmpl_dp_sheaf_id`,`lpty_id`),
  KEY `se_tmpl_dp_sheaf_lpty_i` (`lpty_id`),
  CONSTRAINT `se_tmpl_dp_sheaf_lpty_lpty_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`) ON DELETE CASCADE,
  CONSTRAINT `se_tmpl_dp_sheaf_lpty_tmpl_fk` FOREIGN KEY (`se_tmpl_dp_sheaf_id`) REFERENCES `se_tmpl_dp_sheaf` (`se_tmpl_dp_sheaf_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Nuskaitymo taško duomenų pluošto šaltinių šablono elementų savybės';

-- Dumping data for table emcor.se_tmpl_dp_sheaf_lpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `se_tmpl_dp_sheaf_lpty` DISABLE KEYS */;
/*!40000 ALTER TABLE `se_tmpl_dp_sheaf_lpty` ENABLE KEYS */;

-- Dumping structure for table emcor.se_tmpl_ds_type
CREATE TABLE IF NOT EXISTS `se_tmpl_ds_type` (
  `se_tmpl_ds_type_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Apskaitos būsenų signalų tipų šaltinių šablono elemento ID',
  `src_tmpl_id` mediumint(8) unsigned NOT NULL COMMENT 'Duomenų šaltinių šablono ID',
  `ds_type_id` int(10) unsigned NOT NULL COMMENT 'Apskaitos būsenų signalų tipo identifikatorius',
  `lp_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio prioritetų profilio identifikatorius',
  `se_h` tinyint(1) NOT NULL COMMENT 'Istorinių duomenų egzistavimo požymis',
  `se_h_per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Istorinių duomenų gylio laiko vienetų identifikatorius ',
  `se_h_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Laiko periodų kiekis, apibrežiantis istorinių duomenų gylį',
  `se_h_restore_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Laiko periodų kiekis, apibrežiantis istorinių duomenų, kurie gali buti atnaujinami šaltinyje, gylį',
  `se_h_restore_per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Istorinių duomenų, kurie gali buti atnaujinami šaltinyje, gylio laiko vienetų identifikatorius',
  `se_tmpl_ds_type_extend_ds` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Požymis, ar šaltinio pagal šabloną sukūrimo metu apskaitos būsenų signalus papildyti šablone numatytu signalų tipu',
  PRIMARY KEY (`se_tmpl_ds_type_id`),
  UNIQUE KEY `se_tmpl_ds_type_u` (`src_tmpl_id`,`ds_type_id`),
  KEY `se_tmpl_ds_type_ds_type_i` (`ds_type_id`),
  KEY `se_tmpl_ds_type_h_per_i` (`se_h_per_id`),
  KEY `se_tmpl_ds_type_restore_per_i` (`se_h_restore_per_id`),
  KEY `se_tmpl_ds_type_src_tmpl_i` (`src_tmpl_id`),
  KEY `se_tmpl_ds_type_lp_fk` (`lp_id`),
  CONSTRAINT `se_tmpl_ds_type_ds_type_fk` FOREIGN KEY (`ds_type_id`) REFERENCES `ds_type` (`ds_type_id`) ON DELETE CASCADE,
  CONSTRAINT `se_tmpl_ds_type_lp_fk` FOREIGN KEY (`lp_id`) REFERENCES `lp` (`lp_id`) ON DELETE CASCADE,
  CONSTRAINT `se_tmpl_ds_type_per_fk` FOREIGN KEY (`se_h_per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `se_tmpl_ds_type_restore_per_fk` FOREIGN KEY (`se_h_restore_per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `se_tmpl_ds_type_src_tmpl_fk` FOREIGN KEY (`src_tmpl_id`) REFERENCES `src_tmpl` (`src_tmpl_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apskaitos būsenų signalų tipų šaltinių šablono elementai';

-- Dumping data for table emcor.se_tmpl_ds_type: ~0 rows (approximately)
/*!40000 ALTER TABLE `se_tmpl_ds_type` DISABLE KEYS */;
/*!40000 ALTER TABLE `se_tmpl_ds_type` ENABLE KEYS */;

-- Dumping structure for table emcor.se_tmpl_ds_type_lpty
CREATE TABLE IF NOT EXISTS `se_tmpl_ds_type_lpty` (
  `se_tmpl_ds_type_id` int(10) unsigned NOT NULL COMMENT 'Apskaitos būsenų signalų tipų šaltinių šablono elemento ID',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `lpty_value` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Ryšio modulių savybės reikšmė',
  PRIMARY KEY (`se_tmpl_ds_type_id`,`lpty_id`),
  KEY `se_tmpl_ds_type_lpty_lpty_i` (`lpty_id`),
  CONSTRAINT `se_tmpl_ds_type_lpty_lpty_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`) ON DELETE CASCADE,
  CONSTRAINT `se_tmpl_ds_type_lpty_tmpl_fk` FOREIGN KEY (`se_tmpl_ds_type_id`) REFERENCES `se_tmpl_ds_type` (`se_tmpl_ds_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apskaitos būsenų signalų tipų šaltinių šablono elementų savybės';

-- Dumping data for table emcor.se_tmpl_ds_type_lpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `se_tmpl_ds_type_lpty` DISABLE KEYS */;
/*!40000 ALTER TABLE `se_tmpl_ds_type_lpty` ENABLE KEYS */;

-- Dumping structure for table emcor.se_tmpl_lpty
CREATE TABLE IF NOT EXISTS `se_tmpl_lpty` (
  `se_tmpl_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių šablono elemento ID',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `lpty_value` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Ryšio modulių savybės reikšmė',
  PRIMARY KEY (`se_tmpl_id`,`lpty_id`),
  KEY `se_tmpl_lpty_i` (`lpty_id`),
  CONSTRAINT `se_tmpl_lpty_lpty_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`) ON DELETE CASCADE,
  CONSTRAINT `se_tmpl_lpty_tmpl_fk` FOREIGN KEY (`se_tmpl_id`) REFERENCES `se_tmpl` (`se_tmpl_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Šaltinių šablono elementų savybės';

-- Dumping data for table emcor.se_tmpl_lpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `se_tmpl_lpty` DISABLE KEYS */;
/*!40000 ALTER TABLE `se_tmpl_lpty` ENABLE KEYS */;

-- Dumping structure for table emcor.se_tmpl_sheaf
CREATE TABLE IF NOT EXISTS `se_tmpl_sheaf` (
  `se_tmpl_sheaf_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Duomenų pluošto šaltinių šablono elemento ID',
  `src_tmpl_id` mediumint(8) unsigned NOT NULL COMMENT 'Duomenų šaltinių šablono ID',
  `sheaf_id` mediumint(8) unsigned NOT NULL COMMENT 'Duomenų pluošto identifikatorius',
  `lp_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio prioritetų profilio identifikatorius',
  `se_h` tinyint(1) NOT NULL COMMENT 'Istorinių duomenų egzistavimo požymis',
  `se_h_per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Istorinių duomenų gylio laiko vienetų identifikatorius ',
  `se_h_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Laiko periodų kiekis, apibrėžiantis istorinių duomenų gylį',
  `se_h_restore_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Laiko periodų kiekis, apibrėžiantis istorinių duomenų, kurie gali būti atnaujinami šaltinyje, gylį',
  `se_h_restore_per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Istorinių duomenų, kurie gali būti atnaujinami šaltinyje, gylio laiko vienetų identifikatorius',
  `witheset_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų vytelių rinkinio identifikatorius',
  PRIMARY KEY (`se_tmpl_sheaf_id`),
  UNIQUE KEY `se_tmpl_sheaf_u` (`src_tmpl_id`,`sheaf_id`,`witheset_id`),
  KEY `se_tmpl_sheaf_h_per_i` (`se_h_per_id`),
  KEY `se_tmpl_sheaf_restore_per_i` (`se_h_restore_per_id`),
  KEY `se_tmpl_sheaf_src_tmpl_i` (`src_tmpl_id`),
  KEY `se_tmpl_sheaf_lp_fk` (`lp_id`),
  KEY `se_tmpl_sheaf_sheaf_fk` (`sheaf_id`),
  KEY `se_tmpl_sheaf_witheset_fk` (`witheset_id`),
  CONSTRAINT `se_tmpl_sheaf_lp_fk` FOREIGN KEY (`lp_id`) REFERENCES `lp` (`lp_id`),
  CONSTRAINT `se_tmpl_sheaf_per_fk` FOREIGN KEY (`se_h_per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `se_tmpl_sheaf_restore_per_fk` FOREIGN KEY (`se_h_restore_per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `se_tmpl_sheaf_sheaf_fk` FOREIGN KEY (`sheaf_id`) REFERENCES `sheaf` (`sheaf_id`) ON DELETE CASCADE,
  CONSTRAINT `se_tmpl_sheaf_src_tmpl_fk` FOREIGN KEY (`src_tmpl_id`) REFERENCES `src_tmpl` (`src_tmpl_id`) ON DELETE CASCADE,
  CONSTRAINT `se_tmpl_sheaf_witheset_fk` FOREIGN KEY (`witheset_id`) REFERENCES `witheset` (`witheset_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų pluoštų šaltinių šablono elementai';

-- Dumping data for table emcor.se_tmpl_sheaf: ~0 rows (approximately)
/*!40000 ALTER TABLE `se_tmpl_sheaf` DISABLE KEYS */;
/*!40000 ALTER TABLE `se_tmpl_sheaf` ENABLE KEYS */;

-- Dumping structure for table emcor.se_tmpl_sheaf_lpty
CREATE TABLE IF NOT EXISTS `se_tmpl_sheaf_lpty` (
  `se_tmpl_sheaf_id` int(10) unsigned NOT NULL COMMENT 'Duomenų pluošto šaltinių šablono elemento ID',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `lpty_value` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Ryšio modulių savybės reikšmė',
  PRIMARY KEY (`se_tmpl_sheaf_id`,`lpty_id`),
  KEY `se_tmpl_sheaf_lpty_i` (`lpty_id`),
  CONSTRAINT `se_tmpl_sheaf_lpty_lpty_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`) ON DELETE CASCADE,
  CONSTRAINT `se_tmpl_sheaf_lpty_tmpl_fk` FOREIGN KEY (`se_tmpl_sheaf_id`) REFERENCES `se_tmpl_sheaf` (`se_tmpl_sheaf_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų pluoštų šaltinių šablono elementų savybės';

-- Dumping data for table emcor.se_tmpl_sheaf_lpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `se_tmpl_sheaf_lpty` DISABLE KEYS */;
/*!40000 ALTER TABLE `se_tmpl_sheaf_lpty` ENABLE KEYS */;

-- Dumping structure for table emcor.sf
CREATE TABLE IF NOT EXISTS `sf` (
  `sf_id` mediumint(8) unsigned NOT NULL COMMENT 'Statuso požymio ID',
  `sf_code` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'Statuso požymio kodas',
  `sf_code2` varchar(2) COLLATE utf8_bin DEFAULT NULL COMMENT 'Statuso požymio kodas2',
  `sf_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Statuso požymio pavadinimas',
  `improvable` tinyint(1) DEFAULT NULL COMMENT 'Požymis, ar galimi geresni duomenys',
  `storable` tinyint(1) DEFAULT NULL COMMENT 'Požymis, ar duomenų reikšmė tinkama saugojimui',
  PRIMARY KEY (`sf_id`),
  UNIQUE KEY `sf_sf_code_u` (`sf_code`),
  UNIQUE KEY `sf_sf_name_u` (`sf_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų statusų galimi požymiai';

-- Dumping data for table emcor.sf: ~156 rows (approximately)
/*!40000 ALTER TABLE `sf` DISABLE KEYS */;
INSERT INTO `sf` (`sf_id`, `sf_code`, `sf_code2`, `sf_name`, `improvable`, `storable`) VALUES
	(1, 'Normal', NULL, 'Duomenys normalūs', 0, 1),
	(2, 'NoData', 'X', 'Duomenų nėra', NULL, 0),
	(3, 'NotFull', 'E', 'Nepilni duomenys', 1, 1),
	(4, 'ND_NotAppear', 'P', 'Duomenys negalimi', 0, 0),
	(5, 'DataPending', 'F', 'Duomenų laukiama', 1, 0),
	(6, 'NotCalc', 'U', 'Duomenys neišskaičiuojami', 0, 0),
	(7, 'Overflow', 'W', 'Perpildymas', 0, 0),
	(8, 'DeviceOff', 'O', 'Prietaisas buvo atjungtas', NULL, NULL),
	(9, 'CRC_Err', 'C', 'CRC klaida', 0, 0),
	(10, 'TimeChange', 'L', 'Laiko keitimas', NULL, NULL),
	(11, 'ConfigChange', 'H', 'Konfigūracijos keitimas', NULL, NULL),
	(12, 'LinkErrors', 'R', 'Ryšio klaidos', NULL, 0),
	(13, 'NotSynchro', 'Z', 'Nesinchronizuoti duomenys', NULL, NULL),
	(14, 'NotReliable', 'I', 'Nepatikimi duomenys', 1, 1),
	(15, 'SwitchedMeter', 'B', 'Apeinamas skaitiklis', NULL, NULL),
	(16, 'NoDataInDevice', '!', 'Prietaise nėra tokios informacijos', NULL, 0),
	(17, 'FormulaError', '*', 'Formulės klaida', 0, 0),
	(18, 'ConstError', 'N', 'Konstantos klaida', 0, 0),
	(19, 'Initialization', 'Q', 'Inicializacija', NULL, NULL),
	(20, 'Channel_NotExist', 'V', 'Nesamas kanalas', 0, 0),
	(21, 'OnRestart', 'Y', 'Persikrovimas', NULL, NULL),
	(22, 'TimeConversion', '^', 'Laiko virtimas', NULL, NULL),
	(23, 'Infinity', '8', 'Begalybė', 0, 0),
	(24, 'NaN', '?', 'Neapibrėžta reikšmė', 0, 0),
	(25, 'Manual', 'M', 'Rankinis įvedimas', NULL, NULL),
	(26, 'St_Sif', '@', 'St_SIF', NULL, NULL),
	(27, 'DataFormatErr', 'K', 'Duomenų formato klaidos', 0, 0),
	(28, 'TooLow', 'J', 'Mažiau nei galima minimali reikšmė', NULL, NULL),
	(29, 'TooHigh', '7', 'Daugiau nei galima maksimali reikšmė', NULL, NULL),
	(30, 'Substitution', 'S', 'Pakaita', NULL, NULL),
	(31, 'Not_Full_Final', 'G', 'Nepilni duomenys. Galutiniai', 0, 1),
	(32, 'Not_Full_NotFinal', 'D', 'Nepilni duomenys. Negalutiniai', 1, 1),
	(33, 'Limit', NULL, 'Limitas', NULL, NULL),
	(34, 'Current', NULL, 'Einamasis', NULL, NULL),
	(35, 'Calc', NULL, 'Paskaičiuota pagal formulę', NULL, NULL),
	(36, 'Reset', NULL, 'Skaitiklio reset', NULL, NULL),
	(37, 'TimeSynchro', NULL, 'Laiko sinchronizacija', NULL, NULL),
	(38, 'DataChange', NULL, 'Duomenų keitimas', NULL, NULL),
	(39, 'ReverseRun', NULL, 'Atbulinė tėkmė', NULL, NULL),
	(40, 'PhaseFailure', NULL, 'Fazės dingimas', NULL, NULL),
	(41, 'IntervalShort', NULL, 'Integravimo intervalas sutrumpintas', NULL, NULL),
	(42, 'IntervalLong', NULL, 'Integravimo intervalas pailgintas', NULL, NULL),
	(43, 'DeviceOn', NULL, 'Prietaisas buvo įjungtas', NULL, NULL),
	(44, 'GeneralError', NULL, 'Bendra sistemos klaida', NULL, NULL),
	(45, 'SensorPowerFailure', NULL, 'Matavimo daviklių maitinimo dingimai', NULL, NULL),
	(46, 'TemperatureSupply_LG_Reverse', NULL, 'Tiekiama temperatūra yra mažesnė nei grįžtama temperatūra', NULL, NULL),
	(47, 'OutOfRange', NULL, 'Reikšmė išėjo už diapazono ribų', 0, 0),
	(48, 'Events', NULL, 'Buvo įvykių', NULL, NULL),
	(49, 'NotReliable_Final', ' ', 'Nepatikimi duomenys. Galutiniai', 0, 1),
	(50, 'StartOfIntegrPeriod', NULL, 'Integravimo periodo pradžia', NULL, NULL),
	(51, 'BillingPeriodReset', NULL, 'Apskaitos periodo užbaigimas', NULL, NULL),
	(52, 'BeforeClockAdjust', NULL, 'Prieš laikrodžio nustatymą', NULL, NULL),
	(53, 'AfterClockAdjust', NULL, 'Po laikrodžio nustatymo', NULL, NULL),
	(54, 'DRV_Calc', NULL, 'Perskaičiuota draiverio', NULL, NULL),
	(55, 'DstChange', NULL, 'Perėjimas prie vasaros/žiemos laiko', NULL, NULL),
	(56, 'ClockError', NULL, 'Laikrodžio sutrikimai', NULL, NULL),
	(57, 'SS_1', NULL, 'Neįprasta situacija 1', NULL, NULL),
	(58, 'SS_2', NULL, 'Neįprasta situacija 2', NULL, NULL),
	(59, 'SS_3', NULL, 'Neįprasta situacija 3', NULL, NULL),
	(60, 'SS_4', NULL, 'Neįprasta situacija 4', NULL, NULL),
	(61, 'SS_5', NULL, 'Neįprasta situacija 5', NULL, NULL),
	(62, 'Flow_SensorPowerFailure_1', NULL, 'Srauto daviklio 1 maitinimo dingimas', NULL, NULL),
	(63, 'Flow_SensorPowerFailure_2', NULL, 'Srauto daviklio 2 maitinimo dingimas', NULL, NULL),
	(64, 'Flow_SensorPowerFailure_3', NULL, 'Srauto daviklio 3 maitinimo dingimas', NULL, NULL),
	(65, 'Flow_SensorExceedFrequency_1', NULL, 'Dažnio viršijimas srauto daviklyje 1', NULL, NULL),
	(66, 'Flow_SensorExceedFrequency_2', NULL, 'Dažnio viršijimas srauto daviklyje 2', NULL, NULL),
	(67, 'Flow_SensorExceedFrequency_3', NULL, 'Dažnio viršijimas srauto daviklyje 3', NULL, NULL),
	(68, 'Temperature_SensorPowerFailure_1', NULL, 'Temperatūros daviklio 1 sutrikimas', NULL, NULL),
	(69, 'Temperature_SensorPowerFailure_2', NULL, 'Temperatūros daviklio 2 sutrikimas', NULL, NULL),
	(70, 'Temperature_SensorPowerFailure_3', NULL, 'Temperatūros daviklio 3 sutrikimas', NULL, NULL),
	(71, 'Temperature_SensorPowerFailure_4', NULL, 'Temperatūros daviklio 4 sutrikimas', NULL, NULL),
	(72, 'HiLimit_Qn_1', NULL, 'Pažeista viršutinė srauto 1 vamzdyje riba', NULL, NULL),
	(73, 'HiLimit_Qn_2', NULL, 'Pažeista viršutinė srauto 2 vamzdyje riba', NULL, NULL),
	(74, 'HiLimit_Qn_3', NULL, 'Pažeista viršutinė srauto 3 vamzdyje riba', NULL, NULL),
	(75, 'HiLimit_Qn_4', NULL, 'Pažeista viršutinė srauto 4 vamzdyje riba', NULL, NULL),
	(76, 'LoLimit_Qn_1', NULL, 'Pažeista apatinė srauto 1 vamzdyje riba', NULL, NULL),
	(77, 'LoLimit_Qn_2', NULL, 'Pažeista apatinė srauto 2 vamzdyje riba', NULL, NULL),
	(78, 'LoLimit_Qn_3', NULL, 'Pažeista apatinė srauto 3 vamzdyje riba', NULL, NULL),
	(79, 'LoLimit_Qn_4', NULL, 'Pažeista apatinė srauto 4 vamzdyje riba', NULL, NULL),
	(80, 'LoCutoff_Qn_1', NULL, 'Srautas 1 vamzdyje mažiau už atkirtą', NULL, NULL),
	(81, 'LoCutoff_Qn_2', NULL, 'Srautas 2 vamzdyje mažiau už atkirtą', NULL, NULL),
	(82, 'LoCutoff_Qn_3', NULL, 'Srautas 3 vamzdyje mažiau už atkirtą', NULL, NULL),
	(83, 'LoCutoff_Qn_4', NULL, 'Srautas 4 vamzdyje mažiau už atkirtą', NULL, NULL),
	(84, 'TransformerConsumptionFailure_1', NULL, 'Tūrio impulsų linijos klaida 1 vamzdyje', NULL, NULL),
	(85, 'TransformerConsumptionFailure_2', NULL, 'Tūrio impulsų linijos klaida 2 vamzdyje', NULL, NULL),
	(86, 'TransformerConsumptionFailure_3', NULL, 'Tūrio impulsų linijos klaida 3 vamzdyje', NULL, NULL),
	(87, 'TransformerConsumptionFailure_4', NULL, 'Tūrio impulsų linijos klaida 4 vamzdyje', NULL, NULL),
	(88, 'Pressure_SensorPowerFailure_1', NULL, 'Slėgio daviklio sutrikimas 1 vamzdyje', NULL, NULL),
	(89, 'Pressure_SensorPowerFailure_2', NULL, 'Slėgio daviklio sutrikimas 2 vamzdyje', NULL, NULL),
	(90, 'Pressure_SensorPowerFailure_3', NULL, 'Slėgio daviklio sutrikimas 3 vamzdyje', NULL, NULL),
	(91, 'Pressure_SensorPowerFailure_4', NULL, 'Slėgio daviklio sutrikimas 4 vamzdyje', NULL, NULL),
	(92, 'SS_G2_gt_KprG1', NULL, 'Neįprasta situacija G2>Kvirš•G1', NULL, NULL),
	(93, 'SS_t1_minus_t2_lt_Delta_trc', NULL, 'Neįprasta situacija t1-t2</	', NULL, NULL),
	(94, 'SS_G1_lt_G2_lt_KprG1', NULL, 'Neįprasta situacija G1<G2<Kvirš•G1', NULL, NULL),
	(95, 'SS_G4_gt_KprG3', NULL, 'Neįprasta situacija G4>Kvirš•G3', NULL, NULL),
	(96, 'SS_t3_minus_t4_lt_Delta_trc', NULL, 'Neįprasta situacija t3-t4</	', NULL, NULL),
	(97, 'SS_G3_lt_G3_lt_KprG3', NULL, 'Neįprasta situacija G3<G4<Kvirš*G3', NULL, NULL),
	(98, 'Flow_SensorPowerFailure', NULL, 'Srauto daviklio sutrikimas', NULL, NULL),
	(99, 'Temperature_SensorPowerFailure', NULL, 'Temperatūros daviklio sutrikimas', NULL, NULL),
	(100, 'Pressure_SensorPowerFailure', NULL, 'Slėgio daviklio sutrikimas', NULL, NULL),
	(101, 'MeasurementZeroVoltageReferenceFailure', NULL, 'Nulinės vardinės įtampos matavimų sutrikimas', NULL, NULL),
	(102, 'MeasurementHighVoltageReferenceFailure ', NULL, 'Aukštos vardinės įtampos matavimų sutrikimas', NULL, NULL),
	(103, 'MeasuringTimerOverflow', NULL, 'Matavimo taimerio perpildymas', NULL, NULL),
	(104, 'MeasuredValueNotValid', NULL, 'Pamatuota reikšmė negalima', NULL, NULL),
	(105, 'SystemFailure', NULL, 'Kanalo šilumos sistemos sutrikimas', NULL, NULL),
	(106, 'Flow_SensorPowerFailure_1_W1', NULL, 'Pirmo srauto daviklio sutrikimas W1', NULL, NULL),
	(107, 'Flow_SensorPowerFailure_2_W1', NULL, 'Antro srauto daviklio sutrikimas W1', NULL, NULL),
	(108, 'Flow_SensorPowerFailure_1_W2', NULL, 'Pirmo srauto daviklio sutrikimas W2', NULL, NULL),
	(109, 'Flow_SensorPowerFailure_2_W2', NULL, 'Antro srauto daviklio sutrikimas W2', NULL, NULL),
	(110, 'Temperature_SensorPowerFailure_Enthalpy_1_W1', NULL, 'Pirmos entalpijos temperatūros daviklio sutrikimas (W1)', NULL, NULL),
	(111, 'Temperature_SensorPowerFailure_Enthalpy_2_W1', NULL, 'Antros entalpijos temperatūros daviklio sutrikimas (W1)', NULL, NULL),
	(112, 'Temperature_SensorPowerFailure_Enthalpy_1_W2', NULL, 'Pirmos entalpijos temperatūros daviklio sutrikimas (W2)', NULL, NULL),
	(113, 'Temperature_SensorPowerFailure_Enthalpy_2_W2', NULL, 'Antros entalpijos temperatūros daviklio sutrikimas (W2)', NULL, NULL),
	(114, 'Pressure_SensorPowerFailure_Enthalpy_1_W1', NULL, 'Pirmos entalpijos slėgio daviklio sutrikimas (W1)', NULL, NULL),
	(115, 'Pressure_SensorPowerFailure_Enthalpy_2_W1', NULL, 'Antros entalpijos slėgio daviklio sutrikimas (W1)', NULL, NULL),
	(116, 'Pressure_SensorPowerFailure_Enthalpy_1_W2', NULL, 'Pirmos entalpijos slėgio daviklio sutrikimas (W2)', NULL, NULL),
	(117, 'Pressure_SensorPowerFailure_Enthalpy_2_W2', NULL, 'Antros entalpijos slėgio daviklio sutrikimas (W2)', NULL, NULL),
	(118, 'EEPROMFailure', NULL, 'EEPROM sutrikimas', NULL, NULL),
	(119, 'Forecast', NULL, 'Prognozė', NULL, NULL),
	(120, 'Not_Commercial', NULL, 'Nekomerciniai duomenys', NULL, NULL),
	(121, 'APhaseFailure', NULL, '1-os fazės dingimas', NULL, NULL),
	(122, 'BPhaseFailure', NULL, '2-os fazės dingimas', NULL, NULL),
	(123, 'CPhaseFailure', NULL, '3-os fazės dingimas', NULL, NULL),
	(124, 'Temperature_TooLow', NULL, 'Temperatūra mažesnė už minimumą', NULL, NULL),
	(125, 'Temperature_TooHigh', NULL, 'Temperatūra didesnė už maksimumą', NULL, NULL),
	(126, 'Pressure_TooLow', NULL, 'Slėgis mažesnis už  minimumą', NULL, NULL),
	(127, 'Pressure_TooHigh', NULL, 'Slėgis didesnis už maksimumą', NULL, NULL),
	(128, 'Flow_TooLow', NULL, 'Tūrio kiekis mažesnis už  minimumą', NULL, NULL),
	(129, 'Flow_TooHigh', NULL, 'Tūrio kiekis didesnis už maksimumą', NULL, NULL),
	(130, 'Pressure_SensorNotPresent', NULL, 'Nėra slėgio daviklio', NULL, NULL),
	(131, 'NoCommunicationWithChannel', NULL, 'Nėra ryšio su kanalu', NULL, NULL),
	(132, 'ThermalEnergyLessThanZero', NULL, 'Šiluminė energija mažesnė už nulį', NULL, NULL),
	(133, 'WatchDog_Reset', NULL, 'WatchDog Reset', NULL, NULL),
	(146, 'TariffSumMismatch', NULL, 'Tarifų T1,T2,T3,T4 suma nesutampa su betarifine suma', 1, 0),
	(147, 'TotalLessThanPrevious', NULL, 'Dabartiniai parodymai mažesni už ankstesnius', 1, 0),
	(148, 'WrongWiring', NULL, 'Klaidingas skaitiklio pajungimas', 0, NULL),
	(149, 'TemperatureSensorFailure', NULL, 'Temperatūros daviklio gedimas', 0, NULL),
	(150, 'ValueReset', NULL, 'Rodmenų numetimas', 0, 0),
	(151, 'MeasuringNeutral', NULL, 'Elektros energijos apskaitos kanalas - neutralė', 0, NULL),
	(152, 'NoValidInputValue', NULL, 'Neleistina įvesties reikšmė', 0, 0),
	(153, 'DivisionByZero', NULL, 'Dalyba iš nulio', 0, 0),
	(154, 'InvalidTerminalTemperature', NULL, 'Negaliojanti ribinė TE temperatūra', 0, 0),
	(155, 'IntegratorOrStatisticsDestroyed', NULL, 'Integratorius arba statistika suardyti', 0, 0),
	(156, 'Exceeding_Maximum_Frequency', NULL, 'Maksimalaus dažnio viršijimas', 0, 0),
	(157, 'Exceeding_Maximum_Flow_Diameter', NULL, 'Maksimalaus kiekio duotajam diametrui viršijimas', 0, 0),
	(158, 'No_Ultrasonic_Signal_Channel', NULL, 'Nėra ultragarsinio signalo kanale', 0, 0),
	(159, 'No_Ultrasonic_Signal_Beam2', NULL, 'Nėra ultragarsinio signalo 2-ame spindulyje', 0, 0),
	(160, 'No_Ultrasonic_Signal_Beam3', NULL, 'Nėra ultragarsinio signalo 3-čiame spindulyje', 0, 0),
	(161, 'No_Ultrasonic_Signal_Beam4', NULL, 'Nėra ultragarsinio signalo 4-tame spindulyje', 0, 0),
	(162, 'Operator_Error_Channel', NULL, 'Operatoriaus klaida kanale', 0, 0),
	(163, 'Operator_Error_Beam2', NULL, 'Operatoriaus klaida 2-ame spindulyje', 0, 0),
	(164, 'Operator_Error_Beam3', NULL, 'Operatoriaus klaida 3-čiame spindulyje', 0, 0),
	(165, 'Operator_Error_Beam4', NULL, 'Operatoriaus klaida 4-tame spindulyje', 0, 0),
	(166, 'Set_Inertia_Time', NULL, 'Inercijos laiko kaupimo būsena', 0, 1),
	(167, 'XDS_SummerTime', NULL, 'Vasaros laikas', NULL, NULL),
	(168, 'XDS_CriticalError', NULL, 'Kritinė klaida', NULL, 0);
/*!40000 ALTER TABLE `sf` ENABLE KEYS */;

-- Dumping structure for table emcor.sheaf
CREATE TABLE IF NOT EXISTS `sheaf` (
  `sheaf_id` mediumint(8) unsigned NOT NULL COMMENT 'Duomenų pluošto identifikatorius',
  `sheaf_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų pluošto kodas',
  `sheaf_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų pluošto pavadinimas',
  `stobis` mediumint(8) DEFAULT NULL COMMENT 'Kodas STOBIS',
  PRIMARY KEY (`sheaf_id`),
  UNIQUE KEY `sheaf_code_u` (`sheaf_code`),
  UNIQUE KEY `sheaf_name_u` (`sheaf_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų pluoštai';

-- Dumping data for table emcor.sheaf: ~11 rows (approximately)
/*!40000 ALTER TABLE `sheaf` DISABLE KEYS */;
INSERT INTO `sheaf` (`sheaf_id`, `sheaf_code`, `sheaf_name`, `stobis`) VALUES
	(1, 'TIME', 'Laikas', -1),
	(2, 'JOURNAL_AND_CURRENT_STATES', 'Įvykių žurnalas ir dabartinės būklės', -2),
	(14, 'TIME_CORRECTION', 'Laiko korekcija', -14),
	(16, 'FULL_CONFIGURATION', 'Visa konfigūracija', -16),
	(19, 'CURRENT_STATES', 'Dabartinės būklės', -19),
	(22, 'JOURNAL', 'Įvykių žurnalas', -22),
	(10010, 'RELAY_1', 'Relė 1', 10010),
	(10011, 'RELAY_2', 'Relė 2', 10011),
	(10951, 'RELAY_3', 'Relė 3', 10951),
	(11293, 'RELAY_4', 'Šåėå ¹4', 11293),
	(11294, 'RELAY_5', 'Šåėå ¹5', 11294);
/*!40000 ALTER TABLE `sheaf` ENABLE KEYS */;

-- Dumping structure for table emcor.sms_log
CREATE TABLE IF NOT EXISTS `sms_log` (
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `rpa_id` int(10) unsigned NOT NULL COMMENT 'Automatizuotos ataskaitos identifikatorius',
  `rpp_id` mediumint(8) unsigned NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo identifikatorius',
  `gsm` varchar(50) COLLATE utf8_bin NOT NULL COMMENT 'Mobilaus telefono numeris',
  KEY `sms_log_db_time_i` (`db_time`),
  KEY `sms_log_gsm_db_time_i` (`gsm`,`db_time`),
  KEY `sms_log_rpp_fk` (`rpp_id`),
  CONSTRAINT `sms_log_rpp_fk` FOREIGN KEY (`rpp_id`) REFERENCES `rpp` (`rpp_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Išsiųstų SMS pranešimų žurnalas';

-- Dumping data for table emcor.sms_log: ~0 rows (approximately)
/*!40000 ALTER TABLE `sms_log` DISABLE KEYS */;
/*!40000 ALTER TABLE `sms_log` ENABLE KEYS */;

-- Dumping structure for table emcor.sp
CREATE TABLE IF NOT EXISTS `sp` (
  `sp_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Ryšio kanalo ir duomenų šaltinio sąsajos identifikatorius',
  `ph_id` int(10) unsigned NOT NULL COMMENT 'Ryšio kanalo identifikatorius',
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  PRIMARY KEY (`sp_id`),
  UNIQUE KEY `sp_ak` (`ph_id`,`src_id`),
  KEY `sp_src_i` (`src_id`),
  CONSTRAINT `sp_ph_fk` FOREIGN KEY (`ph_id`) REFERENCES `ph` (`ph_id`) ON DELETE CASCADE,
  CONSTRAINT `sp_src_fk` FOREIGN KEY (`src_id`) REFERENCES `src` (`src_id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=2357 DEFAULT CHARSET=utf8 COMMENT='Duomenų šaltiniai, pasiekiami per ryšio kanalą';

-- Dumping data for table emcor.sp: ~470 rows (approximately)
/*!40000 ALTER TABLE `sp` DISABLE KEYS */;
INSERT INTO `sp` (`sp_id`, `ph_id`, `src_id`) VALUES
	(714, 457, 467),
	(715, 457, 468),
	(717, 457, 470),
	(718, 457, 471),
	(719, 457, 472),
	(720, 457, 473),
	(721, 457, 474),
	(722, 457, 475),
	(723, 457, 476),
	(724, 457, 477),
	(725, 457, 478),
	(726, 457, 479),
	(727, 457, 480),
	(728, 457, 481),
	(729, 457, 482),
	(730, 457, 483),
	(731, 457, 484),
	(732, 457, 485),
	(733, 457, 486),
	(734, 457, 487),
	(735, 457, 488),
	(736, 457, 489),
	(737, 457, 490),
	(738, 457, 491),
	(739, 457, 492),
	(740, 457, 493),
	(774, 457, 522),
	(775, 457, 523),
	(776, 457, 524),
	(777, 457, 525),
	(778, 457, 526),
	(779, 457, 527),
	(796, 457, 544),
	(797, 457, 545),
	(817, 457, 565),
	(879, 457, 622),
	(880, 457, 623),
	(883, 457, 626),
	(884, 457, 627),
	(885, 457, 628),
	(886, 457, 629),
	(909, 457, 652),
	(910, 457, 653),
	(911, 457, 654),
	(921, 457, 667),
	(922, 457, 668),
	(954, 457, 702),
	(955, 457, 703),
	(956, 457, 704),
	(957, 457, 705),
	(958, 457, 706),
	(962, 457, 712),
	(963, 457, 713),
	(979, 457, 732),
	(980, 457, 733),
	(981, 457, 734),
	(982, 457, 735),
	(983, 457, 736),
	(1000, 457, 758),
	(1001, 457, 759),
	(1002, 457, 760),
	(1003, 457, 761),
	(1004, 457, 762),
	(1005, 457, 763),
	(1006, 457, 764),
	(1008, 457, 766),
	(1009, 457, 767),
	(1010, 457, 768),
	(1011, 457, 769),
	(1012, 457, 770),
	(1013, 457, 771),
	(1014, 457, 772),
	(1024, 457, 777),
	(1025, 457, 778),
	(1026, 457, 779),
	(1029, 457, 782),
	(1030, 457, 783),
	(1031, 457, 784),
	(1070, 457, 833),
	(1071, 457, 834),
	(1072, 457, 835),
	(1080, 457, 842),
	(1854, 457, 912),
	(1879, 457, 937),
	(1884, 457, 942),
	(1904, 457, 962),
	(1905, 457, 963),
	(1906, 457, 964),
	(1936, 457, 994),
	(1944, 457, 1002),
	(1945, 457, 1003),
	(1946, 457, 1004),
	(1947, 457, 1005),
	(1948, 457, 1006),
	(1949, 457, 1007),
	(1950, 457, 1008),
	(1954, 457, 1012),
	(1955, 457, 1013),
	(1956, 457, 1014),
	(1959, 457, 1017),
	(1960, 457, 1018),
	(1961, 457, 1019),
	(1962, 457, 1020),
	(1963, 457, 1021),
	(1964, 457, 1022),
	(1965, 457, 1023),
	(1966, 457, 1024),
	(1967, 457, 1025),
	(1968, 457, 1026),
	(1969, 457, 1027),
	(1970, 457, 1028),
	(1971, 457, 1029),
	(1972, 457, 1030),
	(1973, 457, 1031),
	(1974, 457, 1032),
	(1975, 457, 1033),
	(1976, 457, 1034),
	(1977, 457, 1035),
	(1978, 457, 1036),
	(1979, 457, 1037),
	(1980, 457, 1038),
	(1981, 457, 1039),
	(1982, 457, 1040),
	(1983, 457, 1041),
	(1984, 457, 1042),
	(1985, 457, 1043),
	(1986, 457, 1044),
	(1987, 457, 1045),
	(1988, 457, 1046),
	(1989, 457, 1047),
	(1990, 457, 1048),
	(1991, 457, 1049),
	(1993, 457, 1051),
	(1994, 457, 1052),
	(1995, 457, 1053),
	(1998, 457, 1056),
	(2003, 457, 1061),
	(2004, 457, 1062),
	(2005, 457, 1063),
	(2006, 457, 1064),
	(2007, 457, 1065),
	(2008, 457, 1066),
	(2009, 457, 1067),
	(2010, 457, 1068),
	(2011, 457, 1069),
	(2012, 457, 1070),
	(2013, 457, 1071),
	(2014, 457, 1072),
	(2015, 457, 1073),
	(2016, 457, 1074),
	(2017, 457, 1075),
	(2018, 457, 1076),
	(2019, 457, 1077),
	(2020, 457, 1078),
	(2021, 457, 1079),
	(2022, 457, 1080),
	(2023, 457, 1081),
	(2024, 457, 1082),
	(2025, 457, 1083),
	(2026, 457, 1084),
	(2027, 457, 1085),
	(2028, 457, 1086),
	(2029, 457, 1087),
	(2030, 457, 1088),
	(2033, 457, 1091),
	(2034, 457, 1092),
	(2035, 457, 1093),
	(2036, 457, 1094),
	(2037, 457, 1095),
	(2038, 457, 1096),
	(2039, 457, 1097),
	(2040, 457, 1098),
	(2041, 457, 1099),
	(2042, 457, 1100),
	(2043, 457, 1101),
	(2044, 457, 1102),
	(2045, 457, 1103),
	(2046, 457, 1104),
	(2047, 457, 1105),
	(2048, 457, 1106),
	(2049, 457, 1107),
	(2050, 457, 1108),
	(2051, 457, 1109),
	(2052, 457, 1110),
	(2053, 457, 1111),
	(2054, 457, 1112),
	(2055, 457, 1113),
	(2056, 457, 1114),
	(2057, 457, 1115),
	(2058, 457, 1116),
	(2059, 457, 1117),
	(2060, 457, 1118),
	(2061, 457, 1119),
	(2062, 457, 1120),
	(2063, 457, 1121),
	(2064, 457, 1122),
	(2065, 457, 1123),
	(2066, 457, 1124),
	(2067, 457, 1125),
	(2068, 457, 1126),
	(2073, 457, 1131),
	(2074, 457, 1132),
	(2075, 457, 1133),
	(2076, 457, 1134),
	(2077, 457, 1135),
	(2078, 457, 1136),
	(2079, 457, 1137),
	(2080, 457, 1138),
	(2081, 457, 1139),
	(2082, 457, 1140),
	(2083, 457, 1141),
	(2084, 457, 1142),
	(2085, 457, 1143),
	(2086, 457, 1144),
	(2087, 457, 1145),
	(2088, 457, 1146),
	(2089, 457, 1147),
	(2090, 457, 1148),
	(2091, 457, 1149),
	(2092, 457, 1150),
	(2093, 457, 1151),
	(2094, 457, 1152),
	(2095, 457, 1153),
	(2096, 457, 1154),
	(2097, 457, 1155),
	(2098, 457, 1156),
	(2099, 457, 1157),
	(2100, 457, 1158),
	(2101, 457, 1159),
	(2102, 457, 1160),
	(2103, 457, 1161),
	(2104, 457, 1162),
	(2105, 457, 1163),
	(2106, 457, 1164),
	(2107, 457, 1165),
	(2108, 457, 1166),
	(2109, 457, 1167),
	(2110, 457, 1168),
	(2111, 457, 1169),
	(2112, 457, 1170),
	(2113, 457, 1171),
	(2114, 457, 1172),
	(2115, 457, 1173),
	(2116, 457, 1174),
	(2117, 457, 1175),
	(2118, 457, 1176),
	(2119, 457, 1177),
	(2120, 457, 1178),
	(2121, 457, 1179),
	(2122, 457, 1180),
	(2123, 457, 1181),
	(2125, 457, 1183),
	(2126, 457, 1184),
	(2127, 457, 1185),
	(2128, 457, 1186),
	(2129, 457, 1187),
	(2130, 457, 1188),
	(2131, 457, 1189),
	(2132, 457, 1190),
	(2133, 457, 1191),
	(2134, 457, 1192),
	(2135, 457, 1193),
	(2136, 457, 1194),
	(2137, 457, 1195),
	(2138, 457, 1196),
	(2139, 457, 1197),
	(2140, 457, 1198),
	(2141, 457, 1199),
	(2142, 457, 1200),
	(2143, 457, 1201),
	(2144, 457, 1202),
	(2145, 457, 1203),
	(2146, 457, 1204),
	(2147, 457, 1205),
	(2148, 457, 1206),
	(2149, 457, 1207),
	(2150, 457, 1208),
	(2151, 457, 1209),
	(2152, 457, 1210),
	(2153, 457, 1211),
	(2154, 457, 1212),
	(2155, 457, 1213),
	(2156, 457, 1214),
	(2157, 457, 1215),
	(2158, 457, 1216),
	(2159, 457, 1217),
	(2160, 457, 1218),
	(2161, 457, 1219),
	(2162, 457, 1220),
	(2163, 457, 1221),
	(2164, 457, 1222),
	(2165, 457, 1223),
	(2166, 457, 1224),
	(2167, 457, 1225),
	(2168, 457, 1226),
	(2169, 457, 1227),
	(2170, 457, 1228),
	(2171, 457, 1229),
	(2172, 457, 1230),
	(2173, 457, 1231),
	(2174, 457, 1232),
	(2175, 457, 1233),
	(2176, 457, 1234),
	(2177, 457, 1235),
	(2178, 457, 1236),
	(2179, 457, 1237),
	(2180, 457, 1238),
	(2181, 457, 1239),
	(2182, 457, 1240),
	(2183, 457, 1241),
	(2184, 457, 1242),
	(2185, 457, 1243),
	(2186, 457, 1244),
	(2187, 457, 1245),
	(2188, 457, 1246),
	(2189, 457, 1247),
	(2190, 457, 1248),
	(2191, 457, 1249),
	(2192, 457, 1250),
	(2193, 457, 1251),
	(2194, 457, 1252),
	(2195, 457, 1253),
	(2196, 457, 1254),
	(2197, 457, 1255),
	(2198, 457, 1256),
	(2199, 457, 1257),
	(2200, 457, 1258),
	(2201, 457, 1259),
	(2202, 457, 1260),
	(2203, 457, 1261),
	(2204, 457, 1262),
	(2205, 457, 1263),
	(2206, 457, 1264),
	(2207, 457, 1265),
	(2208, 457, 1266),
	(2209, 457, 1267),
	(2210, 457, 1268),
	(2211, 457, 1269),
	(2212, 457, 1270),
	(2213, 457, 1271),
	(2214, 457, 1272),
	(2215, 457, 1273),
	(2216, 457, 1274),
	(2217, 457, 1275),
	(2218, 457, 1276),
	(2219, 457, 1277),
	(2220, 457, 1278),
	(2221, 457, 1279),
	(2222, 457, 1280),
	(2223, 457, 1281),
	(2224, 457, 1282),
	(2225, 457, 1283),
	(2226, 457, 1284),
	(2227, 457, 1285),
	(2228, 457, 1286),
	(2229, 457, 1287),
	(2230, 457, 1288),
	(2231, 457, 1289),
	(2232, 457, 1290),
	(2233, 457, 1291),
	(2234, 457, 1292),
	(2235, 457, 1293),
	(2236, 457, 1294),
	(2237, 457, 1295),
	(2238, 457, 1296),
	(2239, 457, 1297),
	(2240, 457, 1298),
	(2241, 457, 1299),
	(2242, 457, 1300),
	(2243, 457, 1301),
	(2244, 457, 1302),
	(2245, 457, 1303),
	(2246, 457, 1304),
	(2247, 457, 1305),
	(2248, 457, 1306),
	(2249, 457, 1307),
	(2250, 457, 1308),
	(2251, 457, 1309),
	(2252, 457, 1310),
	(2253, 457, 1311),
	(2254, 457, 1312),
	(2255, 457, 1313),
	(2256, 457, 1314),
	(2257, 457, 1315),
	(2258, 457, 1316),
	(2259, 457, 1317),
	(2260, 457, 1318),
	(2261, 457, 1319),
	(2262, 457, 1320),
	(2263, 457, 1321),
	(2264, 457, 1322),
	(2265, 457, 1323),
	(2266, 457, 1324),
	(2267, 457, 1325),
	(2268, 457, 1326),
	(2269, 457, 1327),
	(2270, 457, 1328),
	(2271, 457, 1329),
	(2272, 457, 1330),
	(2273, 457, 1331),
	(2274, 457, 1332),
	(2275, 457, 1333),
	(2276, 457, 1334),
	(2277, 457, 1335),
	(2278, 457, 1336),
	(2279, 457, 1337),
	(2280, 457, 1338),
	(2281, 457, 1339),
	(2282, 457, 1340),
	(2283, 457, 1341),
	(2284, 457, 1342),
	(2285, 457, 1343),
	(2286, 457, 1344),
	(2287, 457, 1345),
	(2288, 457, 1346),
	(2289, 457, 1347),
	(2290, 457, 1348),
	(2291, 457, 1349),
	(2292, 457, 1350),
	(2293, 457, 1351),
	(2294, 457, 1352),
	(2295, 457, 1353),
	(2296, 457, 1354),
	(2297, 457, 1355),
	(2298, 457, 1356),
	(2299, 457, 1357),
	(2300, 457, 1358),
	(2301, 457, 1359),
	(2302, 457, 1360),
	(2303, 457, 1361),
	(2304, 457, 1362),
	(2305, 457, 1363),
	(2306, 457, 1364),
	(2307, 457, 1365),
	(2308, 457, 1366),
	(2310, 457, 1368),
	(2315, 457, 1373),
	(2316, 457, 1374),
	(2317, 457, 1375),
	(2318, 457, 1376),
	(2319, 457, 1377),
	(2320, 457, 1378),
	(2321, 457, 1379),
	(2322, 457, 1380),
	(2323, 457, 1381),
	(2324, 457, 1382),
	(2325, 457, 1383),
	(2326, 457, 1384),
	(2330, 457, 1388),
	(2331, 457, 1389),
	(2335, 457, 1393),
	(2336, 457, 1394),
	(2337, 457, 1395),
	(2338, 457, 1396),
	(2339, 457, 1397),
	(2340, 457, 1398),
	(2341, 457, 1399),
	(2342, 457, 1400),
	(2343, 457, 1401),
	(2344, 457, 1402),
	(2345, 457, 1403),
	(2346, 457, 1404),
	(2347, 457, 1405),
	(2348, 457, 1406),
	(2349, 457, 1407),
	(2350, 457, 1408),
	(2351, 457, 1409),
	(2352, 457, 1410),
	(2355, 457, 1413),
	(2356, 457, 1414);
/*!40000 ALTER TABLE `sp` ENABLE KEYS */;

-- Dumping structure for table emcor.spac
CREATE TABLE IF NOT EXISTS `spac` (
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `sp_id` int(10) unsigned NOT NULL COMMENT 'Ryšio kanalo ir duomenų šaltinio sąsajos identifikatorius',
  `ph_id` int(10) unsigned NOT NULL COMMENT 'Ryšio kanalo identifikatorius',
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `ph_enabled` tinyint(1) NOT NULL COMMENT 'Ryšio kanalo naudojimo požymis',
  `src_enabled` tinyint(1) NOT NULL COMMENT 'Duomenų šaltinio naudojimo požymis',
  `dp_enabled` tinyint(1) NOT NULL COMMENT 'Nuskaitymo taško naudojimo požymis',
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `devicetype` int(10) NOT NULL COMMENT 'Susijęs duomenų šaltinių tipo identifikatorius',
  `guid` varchar(50) COLLATE utf8_bin DEFAULT NULL COMMENT 'Ryšio draiverio GUID',
  `tz_id` smallint(5) unsigned NOT NULL COMMENT 'Laiko zonos identifikatorius',
  `tz_winter_offset` varchar(30) COLLATE utf8_bin DEFAULT NULL COMMENT 'Atitraukimas iki zonos žiemos laiko',
  `src_tz_dst_used` tinyint(1) NOT NULL COMMENT 'Vasaros laiko naudojimo požymis',
  `src_save_statistics` tinyint(1) NOT NULL COMMENT 'Statistikos rinkimo požymis duomenų šaltiniui',
  `src_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Šaltinio pavadinimas',
  `src_number` varchar(20) COLLATE utf8_bin DEFAULT NULL COMMENT 'Šaltinio numeris',
  `src_type_mod_nr` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  PRIMARY KEY (`dp_id`,`sp_id`),
  KEY `spac_src_i` (`src_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Aktualūs surinkimui duomenų šaltiniai, pasiekiami per ryšio kanalą';

-- Dumping data for table emcor.spac: ~0 rows (approximately)
/*!40000 ALTER TABLE `spac` DISABLE KEYS */;
/*!40000 ALTER TABLE `spac` ENABLE KEYS */;

-- Dumping structure for table emcor.spty
CREATE TABLE IF NOT EXISTS `spty` (
  `spty_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Sistemos savybės identifikatorius',
  `spty_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Sistemos savybių tipo identifikatorius',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  `spty_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Sistemos savybės kodas',
  `spty_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Sistemos savybės pavadinimas',
  `spty_value` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Sistemos savybės reikšmė',
  `spty_default` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Sistemos savybės reikšmė pagal nutylėjimą',
  `spty_numeric` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Požymis, ar sistemos savybės reikšmė turi būti skaitmeninė',
  `spty_nr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Sistemos savybės eilės numeris rušiavimui',
  `visible` tinyint(1) DEFAULT 1 COMMENT 'Rodymo požymis',
  PRIMARY KEY (`spty_id`),
  UNIQUE KEY `spty_code_u` (`spty_code`),
  UNIQUE KEY `spty_name_u` (`spty_name`),
  KEY `spty_enum_fk` (`enum_id`),
  KEY `spty_type_id_fk` (`spty_type_id`),
  CONSTRAINT `spty_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`),
  CONSTRAINT `spty_type_id_fk` FOREIGN KEY (`spty_type_id`) REFERENCES `spty_type` (`spty_type_id`)
) ENGINE=InnoDB AUTO_INCREMENT=63 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Sistemos savybės';

-- Dumping data for table emcor.spty: ~62 rows (approximately)
/*!40000 ALTER TABLE `spty` DISABLE KEYS */;
INSERT INTO `spty` (`spty_id`, `spty_type_id`, `enum_id`, `spty_code`, `spty_name`, `spty_value`, `spty_default`, `spty_numeric`, `spty_nr`, `visible`) VALUES
	(1, 1, 82, 'SHIFT_DTIME_TO_SERVER', 'Saugojant perstumti duomenų laiką į serverio laiką', NULL, '0', 1, NULL, 1),
	(2, 2, 82, 'DELIVER_HOLES_THROUGH_LTL', 'Skylių išdavimas per ryšio užduočių eilę', NULL, '1', 1, NULL, 0),
	(3, 2, NULL, 'HOLES_BLOCK_SIZE_PER_SRC', 'Ištisinis skylių bloko dydis vienam šaltiniui', '1000', '1000', 1, NULL, 1),
	(4, 1, 649, 'REALTIME_DATA_STORAGE_MODE', 'Realaus laiko matavimų saugojimo režimas', NULL, '2', 1, NULL, 1),
	(5, 3, 701, 'LATEST_SUCCESSFUL_READINGS_INFO_USAGE', 'Informacijos apie paskutinius sėkmingus nuskaitymus panaudojimas vykdant įprastinį tiesioginį nuskaitymą', NULL, '1', 1, NULL, 1),
	(6, 4, 82, 'LOG.XO_EXPORT_FORM', 'FORM tipo eksporto formų operacijų registravimas įvykių registre', '0', '0', 1, NULL, 1),
	(7, 4, 82, 'LOG.XO_IMPORT_FORM', 'FORM tipo importo formų operacijų registravimas įvykių registre', '0', '0', 1, NULL, 1),
	(8, 4, 82, 'LOG.XO_EXPORT_ELEMENT', 'ELEMENT tipo eksporto formų operacijų registravimas įvykių registre', '0', '0', 1, NULL, 1),
	(9, 4, 82, 'LOG.XO_IMPORT_ELEMENT', 'ELEMENT tipo importo formų operacijų registravimas įvykių registre', '0', '0', 1, NULL, 1),
	(10, 5, 82, 'LOG.MOU', 'Skaitiklių montavimų/demontavimų registravimas įvykių registre', '1', '0', 1, NULL, 1),
	(11, 1, 82, 'LOG.STORE_PW.SETTING_RECEIVED', 'Skaitiklių parametrų gavimo registravimas įvykių registre', '1', '0', 1, NULL, 1),
	(12, 1, 82, 'LOG.STORE_DW.SETTING_RECEIVED', 'Duomenų koncentratorių parametrų gavimo registravimas įvykių registre', '0', '0', 1, NULL, 1),
	(13, 2, NULL, 'HOLES_ANALYZE_MAX_BUNCH_SIZE', 'Maksimalus elementų, tikrinamų dėl skylių, kiekis apdorojamas vienu metu', '10000', '10000', 1, NULL, 1),
	(14, 4, 82, 'LOG.FULL_METER_CONFIG_SAVE', 'Skaitiklio pilnos parametrų informacijos išsaugojimo registravimas įvykių registre', '1', '0', 1, NULL, 1),
	(15, 4, 82, 'LOG.POINT_READ_CONFIG_FILL', 'Matavimo taško ryšio konfigūracijos užpildymo registravimas įvykių registre', '1', '0', 1, NULL, 1),
	(16, 4, 82, 'LOG.STORE_RP', 'Ataskaitų registravimas įvykių registre', '0', '0', 1, NULL, 1),
	(17, 2, NULL, 'GENERATION_FETCH', 'Generuojamų matavimų imtis', '100', '100', 1, NULL, 1),
	(18, 2, NULL, 'ENABLE_HOLES', 'Skylių išdavimas', NULL, '1', 1, NULL, 0),
	(19, 1, 82, 'SAVE_FULL_STATISTICS', 'Pilnos ryšio statistikos rinkimas', '0', '0', 1, NULL, 1),
	(20, 6, 82, 'PARALLEL_DAS.ENABLED', 'Sistemos užduočių paskirstymas lygiagrečiai veikiantiems duomenų surinkimo serveriams', NULL, '0', 1, NULL, 1),
	(21, 6, NULL, 'PARALLEL_DAS.MAX_DP', 'Maksimalus nuskaitymo taškų kiekis vienam duomenų surinkimo serveriui', NULL, '999999', 1, NULL, 1),
	(22, 6, NULL, 'PARALLEL_DAS.MAX_RP', 'Maksimalus ataskaitų kiekis vienam duomenų surinkimo serveriui', NULL, '999999', 1, NULL, 1),
	(23, 6, NULL, 'PARALLEL_DAS.MAX_XA', 'Maksimalus apsikeitimo duomenimis adresatų kiekis vienam duomenų surinkimo serveriui', NULL, '999999', 1, NULL, 1),
	(24, 6, 82, 'PARALLEL_DAS.NEW_DAS_ENABLED', 'Naujai pajungtas duomenų surinkimo serveris registruojamas galiojantis', NULL, '0', 1, NULL, 1),
	(25, 6, NULL, 'PARALLEL_DAS.INACTIVITY_THRESHOLD', 'Neaktyvumo trukmės (minutėmis) slenkstis duomenų surinkimo serveriui', NULL, '180', 1, NULL, 1),
	(26, 7, 82, 'SHOW_PARTIAL_GROUP_MEASURES', 'Rodyti dalines grupių matavimų reikšmes, kai trūksta grupę sudarančių taškų matavimų duomenų', NULL, '0', 1, NULL, 1),
	(27, 5, 82, 'ALLOW_MULTIPLE_METERS_MOUNTING', 'Leidžiama vienu metu sumontuoti kelis skaitiklius viename apskaitos taške', NULL, '0', 1, NULL, 1),
	(28, 2, 82, 'MERGE_DAY_HOLES_TO_MONTH', 'Apjungti parų duomenų skyles į iki mėnesio trukmės intervalus', NULL, '1', 1, NULL, 0),
	(29, 1, 82, 'REDUCE_STA_GRQ_DATA_STORAGE', 'Sumažinti STA_GRQ_DATA saugojimo apimtis, išmetant atsikartojančius nesėkmingo persiuntimo į STLink įrašus', NULL, '0', 1, NULL, 0),
	(30, 2, 82, 'BLOCK_PL_READING_UNTIL_SETTINGS_CHECK', 'Blokuoti rodmenų nuskaitymą, kol nesutikrinta ryšio konfigūracija pagal konfigūracinių parametrų duomenis', NULL, '0', 1, NULL, 0),
	(31, 5, 82, 'ALLOW_MULTIPLE_POINTS_MOUNTING', 'Leidžiama vienu metu sumontuoti tą patį skaitiklį keliuose apskaitos taškuose', NULL, '0', 1, NULL, 1),
	(32, 1, 82, 'SAVE_CURRENT_PROFILE_READINGS', 'Einamųjų paros profilio rodmenų saugojimas', NULL, '1', 1, NULL, 1),
	(33, 1, 82, 'ENABLE_PW_WRITE_RESTRICTIONS', 'Naudoti skaitiklių parametravimo apribojimus', NULL, '0', 1, NULL, 1),
	(34, 1, 82, 'STORE_NULL_FORCED', 'Perrašyti turimą rodmenį su reikšme perrinktu rodmeniu be reikšmės', NULL, '0', 1, NULL, 1),
	(35, 1, 82, 'WRITE_FIB_FORCED', 'Perrašyti turimą rodmenį nauju rodmeniu, importuotu iš failo', NULL, '0', 1, NULL, 1),
	(36, 1, 82, 'SRC_NAME_FROM_POINT_CODE', 'Pagal šabloną kuriamo vientaškio šaltinio vardo formavimas pagal taško kodą', NULL, '0', 1, NULL, 1),
	(37, 8, 82, 'LOG.WRITE_POINT_RELAY', 'Vartotojo inicijuoto skaitiklio relės valdymo registravimas', '1', '1', 1, NULL, 1),
	(38, 8, 82, 'LOG.WRITE_POINT_TIME', 'Vartotojo inicijuoto skaitiklio laiko nustatymo registravimas', '1', '1', 1, NULL, 1),
	(39, 8, 82, 'LOG.WRITE_POINT_TIME_CORRECTION', 'Vartotojo inicijuoto skaitiklio laiko korekcijos registravimas', '1', '1', 1, NULL, 1),
	(40, 8, 82, 'LOG.WRITE_POINT_CONFIGURATION', 'Vartotojo inicijuoto skaitiklio parametravimo registracija', '1', '1', 1, NULL, 1),
	(41, 8, 82, 'LOG.WRITE_DP_TIME', 'Vartotojo inicijuoto kontrolerio laiko nustatymo registravimas', '1', '1', 1, NULL, 1),
	(42, 8, 82, 'LOG.WRITE_DP_TIME_CORRECTION', 'Vartotojo inicijuoto kontrolerio laiko korekcijos registravimas', '1', '1', 1, NULL, 1),
	(43, 8, 82, 'LOG.WRITE_DP_CONFIGURATION', 'Vartotojo inicijuoto kontrolerio parametravimo registravimas', '1', '1', 1, NULL, 1),
	(44, 2, NULL, 'POINT_TPL_DEPTH', 'Matavimo taškų paskutinių sėkmingų nuskaitymų maršrutų analizės gylis minutėmis', NULL, '2160', 1, NULL, 1),
	(45, 2, NULL, 'DP_TPL_DEPTH', 'Nuskaitymo taškų paskutinių sėkmingų nuskaitymų maršrutų analizės gylis minutėmis', NULL, '2160', 1, NULL, 1),
	(46, 9, NULL, 'RQ_INTERVAL_DEPTH', 'Duomenų nuskaitymo užklausų detalizavimo gylis dienomis', '3', '3', 1, NULL, 1),
	(47, 2, 82, 'ENABLE_HOLES_ECONOMY', 'Skylių ekonomijos rėžimas kritinio apkrovimo metu', '1', '1', 1, NULL, 0),
	(48, 2, NULL, 'HOLES_ECONOMY_DURATION', 'Skylių ekonomijos rėžimo taikymo trukmė minutėmis', '1440', '1440', 1, NULL, 1),
	(49, 2, NULL, 'HOLES_ECONOMY_RODO_DEPTH', 'Skylių ekonomijos rėžimu analizuojamos užsakymų istorijos trukmė minutėmis', '2880', '2880', 1, NULL, 1),
	(50, 2, NULL, 'HOLES_ECONOMY_SUSPEND_DURATION', 'Skylių ekonomijos rėžimo suspendavimo trukmė minutėmis', '1440', '1440', 1, NULL, 1),
	(51, 2, 82, 'MERGE_PROFILE_HOLES_TO_MONTH', 'Apjungti paros profilio duomenų skyles į iki mėnesio trukmės intervalus', NULL, '0', 1, NULL, 0),
	(52, 9, NULL, 'GRQ_MAX_DURATION', 'Maksimali sugrupuotos užklausos įvertinta trukmė minutėmis', NULL, '180', 1, NULL, 0),
	(53, 1, 82, 'STORE_PL_BUF_REJECTION', 'Saugojant į buferį įjungti jau turimų importuojamų rodmenų atmetimo rėžimą', NULL, '0', 1, NULL, 1),
	(54, 9, NULL, 'AUD_DEFAULT_DEPTH', 'Audito nuskaitymo gylis paromis pagal nutylėjimą', NULL, '7', 1, NULL, 0),
	(55, 10, 82, 'CENTRAL_DB', 'Požymis, kad sistema yra centrinė (neleisti pilno importo)', '1', '1', 1, NULL, 0),
	(56, 10, 82, 'DMP_IMP_ENABLED', 'Požymis, kad galimas duomenų perkėlimo importas', '0', '0', 1, NULL, 0),
	(57, 4, 82, 'SAVE_FULL_RP_LOG', 'Pilnos ataskaitų vykdymo statistikos rinkimas', NULL, '0', 1, NULL, 1),
	(58, 11, 82, 'SRC_TMPL.ENABLED', 'Automatinis šaltinių šablonų taikymas', NULL, '1', 1, NULL, 1),
	(59, 11, NULL, 'SRC_TMPL.RUN_MAX_DURATION', 'Automatinio šaltinių šablonų taikymo vieno iškvietimo maksimali vykdymo trukmė sekundėmis', NULL, '120', 1, NULL, 1),
	(60, 11, NULL, 'SRC_TMPL.FLIMIT', 'Duomenų šaltinių kiekis per vieną iteraciją', NULL, '100', 1, NULL, 1),
	(61, 11, NULL, 'SRC_TMPL.ULIMIT', 'Duomenų šaltinių kiekis per vieną atitikimo šablonui tikrinimo iteraciją', NULL, '100', 1, NULL, 1),
	(62, 9, NULL, 'P_AU_EXISTS_METHOD_MAX_DEPTH', 'Maksimalus audito analizės diapazonas paromis, kuriam naudojamas EXISTS metodas', NULL, '20', 1, NULL, 0);
/*!40000 ALTER TABLE `spty` ENABLE KEYS */;

-- Dumping structure for table emcor.spty_type
CREATE TABLE IF NOT EXISTS `spty_type` (
  `spty_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Sistemos savybių tipo identifikatorius',
  `spty_type_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Sistemos savybių tipo kodas',
  `spty_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Sistemos savybių tipo pavadinimas',
  PRIMARY KEY (`spty_type_id`),
  UNIQUE KEY `spty_type_code_u` (`spty_type_code`),
  UNIQUE KEY `spty_type_name_u` (`spty_type_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Sistemos savybių tipai';

-- Dumping data for table emcor.spty_type: ~11 rows (approximately)
/*!40000 ALTER TABLE `spty_type` DISABLE KEYS */;
INSERT INTO `spty_type` (`spty_type_id`, `spty_type_code`, `spty_type_name`) VALUES
	(1, 'STORAGE', 'Duomenų išsaugojimas'),
	(2, 'HOLES', 'Skylių nuskaitymas'),
	(3, 'DIRECT_READING', 'Tiesioginis nuskaitymas'),
	(4, 'IMPORT/EXPORT', 'Duomenų importo/eksporto operacijų apdorojimas'),
	(5, 'MOU', 'Matavimo prietaisų montavimai'),
	(6, 'PARALLEL_DAS', 'Lygiagretus duomenų surinkimo serverių veikimas'),
	(7, 'GROUPS', 'Grupės'),
	(8, 'WRITE2DEVICE', 'Vartotojų inicijuojami prietaisų valdymo/kontrolės/perparametravimo veiksmai'),
	(9, 'RQ_DEPTH', 'Duomenų nuskaitymo užklausų detalizavimas'),
	(10, 'DATA_TRANSFER', 'Duomenų perkelimo sisteminiai nustatymai'),
	(11, 'SRC_TMPL', 'Duomenų šaltinių šablonai');
/*!40000 ALTER TABLE `spty_type` ENABLE KEYS */;

-- Dumping structure for table emcor.sp_lpty
CREATE TABLE IF NOT EXISTS `sp_lpty` (
  `sp_id` int(10) unsigned NOT NULL COMMENT 'Ryšio kanalo ir duomenų šaltinio sąsajos identifikatorius',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `lpty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ryšio modulių savybės reikšmė',
  PRIMARY KEY (`sp_id`,`lpty_id`),
  KEY `sp_lpty_lpty_i` (`lpty_id`),
  CONSTRAINT `sp_lpty_lpty_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`) ON DELETE CASCADE,
  CONSTRAINT `sp_lpty_phsrc_fk` FOREIGN KEY (`sp_id`) REFERENCES `sp` (`sp_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų šaltinių, pasiekiamų per ryšio kanalą, savybės';

-- Dumping data for table emcor.sp_lpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `sp_lpty` DISABLE KEYS */;
/*!40000 ALTER TABLE `sp_lpty` ENABLE KEYS */;

-- Dumping structure for table emcor.sp_state
CREATE TABLE IF NOT EXISTS `sp_state` (
  `sp_id` int(10) unsigned NOT NULL COMMENT 'Ryšio kanalo ir duomenų šaltinio sąsajos identifikatorius',
  `costa_id` tinyint(3) unsigned NOT NULL COMMENT 'Ryšio būsenos ID',
  `costa_from` datetime NOT NULL,
  PRIMARY KEY (`sp_id`),
  CONSTRAINT `sp_state_sp_fk` FOREIGN KEY (`sp_id`) REFERENCES `sp` (`sp_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Šaltinių per ryšio kanalą būsenos';

-- Dumping data for table emcor.sp_state: ~0 rows (approximately)
/*!40000 ALTER TABLE `sp_state` DISABLE KEYS */;
/*!40000 ALTER TABLE `sp_state` ENABLE KEYS */;

-- Dumping structure for table emcor.sp_type_lpty
CREATE TABLE IF NOT EXISTS `sp_type_lpty` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `ph_layer_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio kanalų fizinio sluoksnio identifikatorius',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  `sp_lpty_nr` smallint(5) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio tipo per nurodytą ryšio kanalą galimos savybės eilės numeris rušiavumui',
  `sp_lpty_usage` tinyint(3) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio tipo per nurodytą ryšio kanalą galimos savybės naudojimo požymis',
  `sp_lpty_default_value` varchar(20) COLLATE utf8_bin DEFAULT NULL COMMENT 'Duomenų šaltinio tipo per nurodytą ryšio kanalą galimos savybės reikšmė pagal nutylėjimą',
  `sp_lpty_forced_value` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `lpty_numeric` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Savybės reikšmė yra skaitinė',
  `lpty_regex` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'Savybės reikšmės raktas',
  `lpty_min` double DEFAULT NULL COMMENT 'Savybės reikšmės minimumas',
  `lpty_max` double DEFAULT NULL COMMENT 'Savybės reikšmės maksimumas',
  PRIMARY KEY (`src_type_id`,`ph_layer_id`,`lpty_id`),
  KEY `sp_type_lpty_lpty_i` (`lpty_id`),
  KEY `sp_type_lpty_ph_layer_i` (`ph_layer_id`),
  KEY `sp_type_lpty_enum_fk` (`enum_id`),
  CONSTRAINT `sp_type_lpty_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`),
  CONSTRAINT `sp_type_lpty_lpty_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`) ON DELETE CASCADE,
  CONSTRAINT `sp_type_lpty_ph_layer_fk` FOREIGN KEY (`ph_layer_id`) REFERENCES `ph_layer` (`ph_layer_id`) ON DELETE CASCADE,
  CONSTRAINT `sp_type_lpty_src_type_fk` FOREIGN KEY (`src_type_id`) REFERENCES `src_type` (`src_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Galimų ryšio su nurodyto tipo šaltiniais per nurodyto tipo ryšio kanalus savybių sąrašas';

-- Dumping data for table emcor.sp_type_lpty: ~8 657 rows (approximately)
/*!40000 ALTER TABLE `sp_type_lpty` DISABLE KEYS */;
INSERT INTO `sp_type_lpty` (`src_type_id`, `ph_layer_id`, `lpty_id`, `enum_id`, `sp_lpty_nr`, `sp_lpty_usage`, `sp_lpty_default_value`, `sp_lpty_forced_value`, `lpty_numeric`, `lpty_regex`, `lpty_min`, `lpty_max`) VALUES
	(-4, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(-4, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-4, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-4, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(-4, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-4, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-4, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(-4, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-4, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-4, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(-4, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-4, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-4, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(-4, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-4, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-4, 10, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(-4, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-4, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-4, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(-4, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-4, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-4, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(-4, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-4, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-4, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(-4, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-4, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-4, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(-4, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-4, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-4, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(-4, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-4, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-3, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(-3, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-3, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-3, 1, 449, 888, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(-3, 1, 450, 888, NULL, 3, '15', NULL, 0, NULL, NULL, NULL),
	(-3, 1, 451, 888, NULL, 3, '10', NULL, 0, NULL, NULL, NULL),
	(-3, 1, 452, 888, NULL, 3, '20', NULL, 0, NULL, NULL, NULL),
	(-3, 1, 453, 888, NULL, 3, '12', NULL, 0, NULL, NULL, NULL),
	(-3, 1, 454, 888, NULL, 3, '8', NULL, 0, NULL, NULL, NULL),
	(-1, 1, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(-1, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-1, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-1, 2, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(-1, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-1, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-1, 3, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(-1, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-1, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-1, 4, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(-1, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-1, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-1, 5, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(-1, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-1, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-1, 11, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(-1, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-1, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-1, 12, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(-1, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-1, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-1, 13, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(-1, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-1, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-1, 14, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(-1, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-1, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(-1, 15, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(-1, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(-1, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(0, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(0, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(0, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(0, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(0, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(0, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(0, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(0, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(0, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(0, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(1, 1, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(1, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(1, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(1, 2, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(1, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(1, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(1, 3, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(1, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(1, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(1, 4, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(1, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(1, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(1, 5, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(1, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(1, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(1, 11, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(1, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(1, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(1, 12, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(1, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(1, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(1, 13, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(1, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(1, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(1, 14, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(1, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(1, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(1, 15, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(1, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(1, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(4, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(4, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(4, 1, 17, 121, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(4, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(4, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(4, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(4, 2, 17, 121, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(4, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(4, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(4, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(4, 3, 17, 121, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(4, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(4, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(4, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(4, 4, 17, 121, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(4, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(4, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(4, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(4, 5, 17, 121, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(4, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(4, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(4, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(4, 11, 17, 121, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(4, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(4, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(4, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(4, 12, 17, 121, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(4, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(4, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(4, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(4, 13, 17, 121, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(4, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(4, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(4, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(4, 14, 17, 121, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(4, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(4, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(4, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(4, 15, 17, 121, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(4, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(14, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(14, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(14, 1, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(14, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(14, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(14, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(14, 2, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(14, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(14, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(14, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(14, 3, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(14, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(14, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(14, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(14, 4, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(14, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(14, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(14, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(14, 5, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(14, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(14, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(14, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(14, 11, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(14, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(14, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(14, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(14, 12, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(14, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(14, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(14, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(14, 13, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(14, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(14, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(14, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(14, 14, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(14, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(14, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(14, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(14, 15, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(14, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(24, 1, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(24, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(24, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(24, 2, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(24, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(24, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(24, 3, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(24, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(24, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(24, 4, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(24, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(24, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(24, 5, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(24, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(24, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(24, 11, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(24, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(24, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(24, 12, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(24, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(24, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(24, 13, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(24, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(24, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(24, 14, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(24, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(24, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(24, 15, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(24, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(24, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(25, 1, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(25, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(25, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(25, 2, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(25, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(25, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(25, 3, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(25, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(25, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(25, 4, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(25, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(25, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(25, 5, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(25, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(25, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(25, 11, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(25, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(25, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(25, 12, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(25, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(25, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(25, 13, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(25, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(25, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(25, 14, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(25, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(25, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(25, 15, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(25, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(25, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(26, 1, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(26, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(26, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(26, 2, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(26, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(26, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(26, 3, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(26, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(26, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(26, 4, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(26, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(26, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(26, 5, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(26, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(26, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(26, 11, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(26, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(26, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(26, 12, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(26, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(26, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(26, 13, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(26, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(26, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(26, 14, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(26, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(26, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(26, 15, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(26, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(26, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(30, 1, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(30, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(30, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(30, 2, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(30, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(30, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(30, 3, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(30, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(30, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(30, 4, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(30, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(30, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(30, 5, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(30, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(30, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(30, 11, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(30, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(30, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(30, 12, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(30, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(30, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(30, 13, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(30, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(30, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(30, 14, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(30, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(30, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(30, 15, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(30, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(30, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(32, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(32, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(32, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(32, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(32, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(32, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(32, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(32, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(32, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(32, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(32, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(32, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(32, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(32, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(32, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(32, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(32, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(32, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(32, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(32, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(32, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(32, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(32, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(32, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(32, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(32, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(32, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(32, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(32, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(32, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 1, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(33, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(33, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 2, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(33, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(33, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 3, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(33, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(33, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 4, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(33, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(33, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 5, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(33, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(33, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 11, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(33, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(33, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 12, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(33, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(33, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 13, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(33, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(33, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 14, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(33, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(33, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 15, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(33, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(33, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(35, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(35, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(35, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(35, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(35, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(35, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(35, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(35, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(35, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(35, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(35, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(35, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(35, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(35, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(35, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(35, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(35, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(35, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(35, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(35, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(38, 1, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(38, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(38, 1, 17, 524, NULL, 3, 'Manufacturer', NULL, 0, NULL, NULL, NULL),
	(38, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(38, 2, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(38, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(38, 2, 17, 524, NULL, 3, 'Manufacturer', NULL, 0, NULL, NULL, NULL),
	(38, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(38, 3, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(38, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(38, 3, 17, 524, NULL, 3, 'Manufacturer', NULL, 0, NULL, NULL, NULL),
	(38, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(38, 4, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(38, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(38, 4, 17, 524, NULL, 3, 'Manufacturer', NULL, 0, NULL, NULL, NULL),
	(38, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(38, 5, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(38, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(38, 5, 17, 524, NULL, 3, 'Manufacturer', NULL, 0, NULL, NULL, NULL),
	(38, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(38, 11, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(38, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(38, 11, 17, 524, NULL, 3, 'Manufacturer', NULL, 0, NULL, NULL, NULL),
	(38, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(38, 12, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(38, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(38, 12, 17, 524, NULL, 3, 'Manufacturer', NULL, 0, NULL, NULL, NULL),
	(38, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(38, 13, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(38, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(38, 13, 17, 524, NULL, 3, 'Manufacturer', NULL, 0, NULL, NULL, NULL),
	(38, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(38, 14, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(38, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(38, 14, 17, 524, NULL, 3, 'Manufacturer', NULL, 0, NULL, NULL, NULL),
	(38, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(38, 15, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(38, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(38, 15, 17, 524, NULL, 3, 'Manufacturer', NULL, 0, NULL, NULL, NULL),
	(38, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(39, 1, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(39, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(39, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(39, 1, 156, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(39, 2, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(39, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(39, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(39, 2, 156, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(39, 3, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(39, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(39, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(39, 3, 156, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(39, 4, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(39, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(39, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(39, 4, 156, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(39, 5, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(39, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(39, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(39, 5, 156, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(39, 11, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(39, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(39, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(39, 11, 156, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(39, 12, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(39, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(39, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(39, 12, 156, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(39, 13, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(39, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(39, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(39, 13, 156, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(39, 14, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(39, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(39, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(39, 14, 156, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(39, 15, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(39, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(39, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(39, 15, 156, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(42, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(42, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(42, 1, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(42, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(42, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(42, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(42, 2, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(42, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(42, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(42, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(42, 3, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(42, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(42, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(42, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(42, 4, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(42, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(42, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(42, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(42, 5, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(42, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(42, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(42, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(42, 11, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(42, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(42, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(42, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(42, 12, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(42, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(42, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(42, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(42, 13, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(42, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(42, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(42, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(42, 14, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(42, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(42, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(42, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(42, 15, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(42, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(51, 1, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(51, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(51, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(51, 2, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(51, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(51, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(51, 3, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(51, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(51, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(51, 4, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(51, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(51, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(51, 5, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(51, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(51, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(51, 11, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(51, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(51, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(51, 12, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(51, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(51, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(51, 13, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(51, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(51, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(51, 14, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(51, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(51, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(51, 15, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(51, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(51, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(52, 1, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(52, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(52, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(52, 2, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(52, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(52, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(52, 3, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(52, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(52, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(52, 4, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(52, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(52, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(52, 5, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(52, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(52, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(52, 11, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(52, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(52, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(52, 12, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(52, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(52, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(52, 13, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(52, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(52, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(52, 14, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(52, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(52, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(52, 15, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(52, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(52, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(53, 1, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(53, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(53, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(53, 2, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(53, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(53, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(53, 3, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(53, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(53, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(53, 4, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(53, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(53, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(53, 5, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(53, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(53, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(53, 11, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(53, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(53, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(53, 12, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(53, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(53, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(53, 13, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(53, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(53, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(53, 14, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(53, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(53, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(53, 15, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(53, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(53, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(54, 1, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(54, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(54, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(54, 2, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(54, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(54, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(54, 3, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(54, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(54, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(54, 4, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(54, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(54, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(54, 5, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(54, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(54, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(54, 11, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(54, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(54, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(54, 12, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(54, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(54, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(54, 13, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(54, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(54, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(54, 14, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(54, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(54, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(54, 15, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(54, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(54, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(56, 1, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(56, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(56, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(56, 2, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(56, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(56, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(56, 3, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(56, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(56, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(56, 4, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(56, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(56, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(56, 5, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(56, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(56, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(56, 11, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(56, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(56, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(56, 12, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(56, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(56, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(56, 13, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(56, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(56, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(56, 14, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(56, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(56, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(56, 15, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(56, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(56, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(57, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(57, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(57, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(57, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(57, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(57, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(57, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(57, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(57, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(57, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(57, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(57, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(57, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(57, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(57, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(57, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(57, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(57, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(57, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(57, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(57, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(57, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(57, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(57, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(57, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(57, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(57, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(57, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(57, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(57, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(58, 1, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(58, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(58, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(58, 2, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(58, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(58, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(58, 3, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(58, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(58, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(58, 4, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(58, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(58, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(58, 5, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(58, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(58, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(58, 11, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(58, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(58, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(58, 12, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(58, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(58, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(58, 13, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(58, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(58, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(58, 14, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(58, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(58, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(58, 15, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(58, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(58, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(59, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(59, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(59, 1, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(59, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(59, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(59, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(59, 2, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(59, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(59, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(59, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(59, 3, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(59, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(59, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(59, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(59, 4, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(59, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(59, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(59, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(59, 5, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(59, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(59, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(59, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(59, 11, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(59, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(59, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(59, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(59, 12, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(59, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(59, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(59, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(59, 13, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(59, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(59, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(59, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(59, 14, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(59, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(59, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(59, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(59, 15, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(59, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 1, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 2, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 3, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 4, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 5, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 11, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 12, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 13, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 14, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 15, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(60, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(61, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(61, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(61, 1, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(61, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(61, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(61, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(61, 2, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(61, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(61, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(61, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(61, 3, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(61, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(61, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(61, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(61, 4, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(61, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(61, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(61, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(61, 5, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(61, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(61, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(61, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(61, 11, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(61, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(61, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(61, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(61, 12, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(61, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(61, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(61, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(61, 13, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(61, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(61, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(61, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(61, 14, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(61, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(61, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(61, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(61, 15, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(61, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(62, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(62, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(62, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(62, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(62, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(62, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(62, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(62, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(62, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(62, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(62, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(62, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(62, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(62, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(62, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(62, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(62, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(62, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(62, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(62, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(62, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(62, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(62, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(62, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(62, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(62, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(62, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(62, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(62, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(62, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(63, 1, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(63, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(63, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(63, 2, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(63, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(63, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(63, 3, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(63, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(63, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(63, 4, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(63, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(63, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(63, 5, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(63, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(63, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(63, 11, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(63, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(63, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(63, 12, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(63, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(63, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(63, 13, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(63, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(63, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(63, 14, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(63, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(63, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(63, 15, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(63, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(63, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(64, 1, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(64, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(64, 2, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(64, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(64, 3, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(64, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(64, 4, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(64, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(64, 5, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(64, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(64, 11, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(64, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(64, 12, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(64, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(64, 13, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(64, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(64, 14, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(64, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(64, 15, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(64, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(66, 1, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(66, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(66, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(66, 2, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(66, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(66, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(66, 3, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(66, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(66, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(66, 4, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(66, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(66, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(66, 5, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(66, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(66, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(66, 11, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(66, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(66, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(66, 12, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(66, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(66, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(66, 13, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(66, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(66, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(66, 14, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(66, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(66, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(66, 15, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(66, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(66, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 1, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(67, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 2, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(67, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 3, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(67, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 4, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(67, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 5, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(67, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 11, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(67, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 12, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(67, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 13, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(67, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 14, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(67, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 15, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(67, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(68, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(68, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(68, 1, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(68, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(68, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(68, 2, 12, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(68, 2, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(68, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(68, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(68, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(68, 3, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(68, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(68, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(68, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(68, 4, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(68, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(68, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(68, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(68, 5, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(68, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(68, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(68, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(68, 11, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(68, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(68, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(68, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(68, 12, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(68, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(68, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(68, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(68, 13, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(68, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(68, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(68, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(68, 14, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(68, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(68, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(68, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(68, 15, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(68, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(69, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(69, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(69, 1, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(69, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(69, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(69, 2, 12, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(69, 2, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(69, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(69, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(69, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(69, 3, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(69, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(69, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(69, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(69, 4, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(69, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(69, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(69, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(69, 5, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(69, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(69, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(69, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(69, 11, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(69, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(69, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(69, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(69, 12, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(69, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(69, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(69, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(69, 13, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(69, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(69, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(69, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(69, 14, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(69, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(69, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(69, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(69, 15, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(69, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(70, 1, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(70, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(70, 2, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(70, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(70, 3, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(70, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(70, 4, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(70, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(70, 5, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(70, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(70, 11, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(70, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(70, 12, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(70, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(70, 13, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(70, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(70, 14, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(70, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(70, 15, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(70, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(71, 1, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(71, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(71, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(71, 2, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(71, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(71, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(71, 3, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(71, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(71, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(71, 4, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(71, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(71, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(71, 5, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(71, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(71, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(71, 11, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(71, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(71, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(71, 12, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(71, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(71, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(71, 13, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(71, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(71, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(71, 14, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(71, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(71, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(71, 15, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(71, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(71, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(72, 1, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(72, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(72, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(72, 2, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(72, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(72, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(72, 3, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(72, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(72, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(72, 4, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(72, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(72, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(72, 5, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(72, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(72, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(72, 11, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(72, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(72, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(72, 12, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(72, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(72, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(72, 13, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(72, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(72, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(72, 14, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(72, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(72, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(72, 15, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(72, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(72, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(73, 1, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(73, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(73, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(73, 2, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(73, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(73, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(73, 3, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(73, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(73, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(73, 4, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(73, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(73, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(73, 5, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(73, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(73, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(73, 11, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(73, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(73, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(73, 12, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(73, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(73, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(73, 13, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(73, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(73, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(73, 14, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(73, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(73, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(73, 15, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(73, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(73, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(75, 1, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(75, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(75, 1, 156, NULL, NULL, 1, '50', NULL, 0, NULL, NULL, NULL),
	(75, 1, 157, NULL, NULL, 1, '200', NULL, 0, NULL, NULL, NULL),
	(75, 2, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(75, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(75, 2, 156, NULL, NULL, 1, '50', NULL, 0, NULL, NULL, NULL),
	(75, 2, 157, NULL, NULL, 1, '200', NULL, 0, NULL, NULL, NULL),
	(75, 3, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(75, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(75, 3, 156, NULL, NULL, 1, '50', NULL, 0, NULL, NULL, NULL),
	(75, 3, 157, NULL, NULL, 1, '200', NULL, 0, NULL, NULL, NULL),
	(75, 4, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(75, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(75, 4, 156, NULL, NULL, 1, '50', NULL, 0, NULL, NULL, NULL),
	(75, 4, 157, NULL, NULL, 1, '200', NULL, 0, NULL, NULL, NULL),
	(75, 5, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(75, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(75, 5, 156, NULL, NULL, 1, '50', NULL, 0, NULL, NULL, NULL),
	(75, 5, 157, NULL, NULL, 1, '200', NULL, 0, NULL, NULL, NULL),
	(75, 11, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(75, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(75, 11, 156, NULL, NULL, 1, '50', NULL, 0, NULL, NULL, NULL),
	(75, 11, 157, NULL, NULL, 1, '200', NULL, 0, NULL, NULL, NULL),
	(75, 12, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(75, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(75, 12, 156, NULL, NULL, 1, '50', NULL, 0, NULL, NULL, NULL),
	(75, 12, 157, NULL, NULL, 1, '200', NULL, 0, NULL, NULL, NULL),
	(75, 13, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(75, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(75, 13, 156, NULL, NULL, 1, '50', NULL, 0, NULL, NULL, NULL),
	(75, 13, 157, NULL, NULL, 1, '200', NULL, 0, NULL, NULL, NULL),
	(75, 14, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(75, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(75, 14, 156, NULL, NULL, 1, '50', NULL, 0, NULL, NULL, NULL),
	(75, 14, 157, NULL, NULL, 1, '200', NULL, 0, NULL, NULL, NULL),
	(75, 15, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(75, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(75, 15, 156, NULL, NULL, 1, '50', NULL, 0, NULL, NULL, NULL),
	(75, 15, 157, NULL, NULL, 1, '200', NULL, 0, NULL, NULL, NULL),
	(76, 1, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(76, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(76, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(76, 2, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(76, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(76, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(76, 3, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(76, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(76, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(76, 4, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(76, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(76, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(76, 5, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(76, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(76, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(76, 11, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(76, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(76, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(76, 12, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(76, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(76, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(76, 13, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(76, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(76, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(76, 14, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(76, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(76, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(76, 15, 11, NULL, NULL, 1, '9000', NULL, 0, NULL, NULL, NULL),
	(76, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(76, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(77, 1, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(77, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(77, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(77, 2, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(77, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(77, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(77, 3, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(77, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(77, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(77, 4, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(77, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(77, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(77, 5, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(77, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(77, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(77, 11, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(77, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(77, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(77, 12, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(77, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(77, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(77, 13, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(77, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(77, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(77, 14, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(77, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(77, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(77, 15, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(77, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(77, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(78, 1, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(78, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(78, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(78, 2, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(78, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(78, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(78, 3, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(78, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(78, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(78, 4, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(78, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(78, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(78, 5, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(78, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(78, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(78, 11, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(78, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(78, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(78, 12, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(78, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(78, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(78, 13, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(78, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(78, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(78, 14, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(78, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(78, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(78, 15, 11, NULL, NULL, 1, '1500', NULL, 0, NULL, NULL, NULL),
	(78, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(78, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(79, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(79, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(79, 1, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(79, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(79, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(79, 2, 12, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(79, 2, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(79, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(79, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(79, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(79, 3, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(79, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(79, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(79, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(79, 4, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(79, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(79, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(79, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(79, 5, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(79, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(79, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(79, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(79, 11, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(79, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(79, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(79, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(79, 12, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(79, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(79, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(79, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(79, 13, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(79, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(79, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(79, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(79, 14, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(79, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(79, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(79, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(79, 15, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(79, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(80, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(80, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(80, 1, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(80, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(80, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(80, 2, 12, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(80, 2, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(80, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(80, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(80, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(80, 3, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(80, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(80, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(80, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(80, 4, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(80, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(80, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(80, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(80, 5, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(80, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(80, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(80, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(80, 11, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(80, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(80, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(80, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(80, 12, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(80, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(80, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(80, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(80, 13, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(80, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(80, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(80, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(80, 14, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(80, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(80, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(80, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(80, 15, 17, 406, NULL, 3, 'ModBus', NULL, 0, NULL, NULL, NULL),
	(80, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 1, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 1, 12, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 1, 17, 123, NULL, 3, 'HTTP', NULL, 0, NULL, NULL, NULL),
	(81, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 2, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 2, 12, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 2, 17, 123, NULL, 3, 'HTTP', NULL, 0, NULL, NULL, NULL),
	(81, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 3, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 3, 12, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 3, 17, 123, NULL, 3, 'HTTP', NULL, 0, NULL, NULL, NULL),
	(81, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 4, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 4, 12, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 4, 17, 123, NULL, 3, 'HTTP', NULL, 0, NULL, NULL, NULL),
	(81, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 5, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 5, 12, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 5, 17, 123, NULL, 3, 'HTTP', NULL, 0, NULL, NULL, NULL),
	(81, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 11, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 11, 12, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 11, 17, 123, NULL, 3, 'HTTP', NULL, 0, NULL, NULL, NULL),
	(81, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 12, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 12, 12, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 12, 17, 123, NULL, 3, 'HTTP', NULL, 0, NULL, NULL, NULL),
	(81, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 13, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 13, 12, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 13, 17, 123, NULL, 3, 'HTTP', NULL, 0, NULL, NULL, NULL),
	(81, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 14, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 14, 12, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 14, 17, 123, NULL, 3, 'HTTP', NULL, 0, NULL, NULL, NULL),
	(81, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 15, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 15, 12, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 15, 17, 123, NULL, 3, 'HTTP', NULL, 0, NULL, NULL, NULL),
	(81, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(82, 1, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(82, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(82, 2, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(82, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(82, 3, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(82, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(82, 4, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(82, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(82, 5, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(82, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(82, 11, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(82, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(82, 12, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(82, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(82, 13, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(82, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(82, 14, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(82, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(82, 15, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(82, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(85, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(85, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(85, 1, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(85, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(85, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(85, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(85, 2, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(85, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(85, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(85, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(85, 3, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(85, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(85, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(85, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(85, 4, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(85, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(85, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(85, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(85, 5, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(85, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(85, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(85, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(85, 11, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(85, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(85, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(85, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(85, 12, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(85, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(85, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(85, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(85, 13, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(85, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(85, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(85, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(85, 14, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(85, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(85, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(85, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(85, 15, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(85, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(86, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(86, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(86, 1, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(86, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(86, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(86, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(86, 2, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(86, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(86, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(86, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(86, 3, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(86, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(86, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(86, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(86, 4, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(86, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(86, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(86, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(86, 5, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(86, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(86, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(86, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(86, 11, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(86, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(86, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(86, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(86, 12, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(86, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(86, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(86, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(86, 13, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(86, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(86, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(86, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(86, 14, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(86, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(86, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(86, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(86, 15, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(86, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 1, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(87, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(87, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 2, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(87, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(87, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 3, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(87, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(87, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 4, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(87, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(87, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 5, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(87, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(87, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 11, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(87, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(87, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 12, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(87, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(87, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 13, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(87, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(87, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 14, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(87, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(87, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 15, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(87, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(87, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(88, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(88, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(88, 1, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(88, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(88, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(88, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(88, 2, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(88, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(88, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(88, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(88, 3, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(88, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(88, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(88, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(88, 4, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(88, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(88, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(88, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(88, 5, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(88, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(88, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(88, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(88, 11, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(88, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(88, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(88, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(88, 12, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(88, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(88, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(88, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(88, 13, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(88, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(88, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(88, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(88, 14, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(88, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(88, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(88, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(88, 15, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(88, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(89, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(89, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(89, 1, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(89, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(89, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(89, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(89, 2, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(89, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(89, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(89, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(89, 3, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(89, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(89, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(89, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(89, 4, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(89, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(89, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(89, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(89, 5, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(89, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(89, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(89, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(89, 11, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(89, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(89, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(89, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(89, 12, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(89, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(89, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(89, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(89, 13, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(89, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(89, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(89, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(89, 14, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(89, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(89, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(89, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(89, 15, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(89, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(90, 1, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(90, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(90, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(90, 2, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(90, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(90, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(90, 3, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(90, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(90, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(90, 4, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(90, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(90, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(90, 5, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(90, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(90, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(90, 11, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(90, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(90, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(90, 12, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(90, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(90, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(90, 13, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(90, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(90, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(90, 14, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(90, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(90, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(90, 15, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(90, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(90, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(91, 1, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(91, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(91, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(91, 2, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(91, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(91, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(91, 3, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(91, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(91, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(91, 4, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(91, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(91, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(91, 5, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(91, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(91, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(91, 11, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(91, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(91, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(91, 12, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(91, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(91, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(91, 13, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(91, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(91, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(91, 14, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(91, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(91, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(91, 15, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(91, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(91, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(92, 1, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(92, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(92, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(92, 2, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(92, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(92, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(92, 3, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(92, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(92, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(92, 4, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(92, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(92, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(92, 5, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(92, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(92, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(92, 11, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(92, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(92, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(92, 12, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(92, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(92, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(92, 13, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(92, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(92, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(92, 14, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(92, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(92, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(92, 15, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(92, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(92, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(93, 1, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(93, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(93, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(93, 2, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(93, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(93, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(93, 3, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(93, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(93, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(93, 4, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(93, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(93, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(93, 5, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(93, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(93, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(93, 11, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(93, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(93, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(93, 12, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(93, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(93, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(93, 13, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(93, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(93, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(93, 14, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(93, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(93, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(93, 15, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(93, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(93, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(94, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(94, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(94, 1, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(94, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(94, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(94, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(94, 2, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(94, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(94, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(94, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(94, 3, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(94, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(94, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(94, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(94, 4, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(94, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(94, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(94, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(94, 5, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(94, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(94, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(94, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(94, 11, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(94, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(94, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(94, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(94, 12, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(94, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(94, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(94, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(94, 13, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(94, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(94, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(94, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(94, 14, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(94, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(94, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(94, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(94, 15, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(94, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 1, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(95, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(95, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 1, 113, NULL, NULL, 2, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 2, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(95, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(95, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 2, 113, NULL, NULL, 2, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 3, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(95, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(95, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 3, 113, NULL, NULL, 2, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 4, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(95, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(95, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 4, 113, NULL, NULL, 2, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 5, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(95, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(95, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 5, 113, NULL, NULL, 2, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 11, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(95, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(95, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 11, 113, NULL, NULL, 2, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 12, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(95, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(95, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 12, 113, NULL, NULL, 2, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 13, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(95, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(95, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 13, 113, NULL, NULL, 2, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 14, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(95, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(95, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 14, 113, NULL, NULL, 2, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 15, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(95, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(95, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(95, 15, 113, NULL, NULL, 2, NULL, NULL, 0, NULL, NULL, NULL),
	(96, 1, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(96, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(96, 1, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(96, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(96, 2, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(96, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(96, 2, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(96, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(96, 3, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(96, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(96, 3, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(96, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(96, 4, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(96, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(96, 4, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(96, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(96, 5, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(96, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(96, 5, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(96, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(96, 11, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(96, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(96, 11, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(96, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(96, 12, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(96, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(96, 12, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(96, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(96, 13, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(96, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(96, 13, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(96, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(96, 14, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(96, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(96, 14, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(96, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(96, 15, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(96, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(96, 15, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(96, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(97, 1, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(97, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(97, 1, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(97, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(97, 2, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(97, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(97, 2, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(97, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(97, 3, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(97, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(97, 3, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(97, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(97, 4, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(97, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(97, 4, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(97, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(97, 5, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(97, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(97, 5, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(97, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(97, 11, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(97, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(97, 11, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(97, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(97, 12, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(97, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(97, 12, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(97, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(97, 13, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(97, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(97, 13, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(97, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(97, 14, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(97, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(97, 14, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(97, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(97, 15, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(97, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(97, 15, 17, 122, NULL, 1, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(97, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(98, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(98, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(98, 1, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(98, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(98, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(98, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(98, 2, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(98, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(98, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(98, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(98, 3, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(98, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(98, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(98, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(98, 4, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(98, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(98, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(98, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(98, 5, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(98, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(98, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(98, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(98, 11, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(98, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(98, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(98, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(98, 12, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(98, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(98, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(98, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(98, 13, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(98, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(98, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(98, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(98, 14, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(98, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(98, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(98, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(98, 15, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(98, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(99, 1, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(99, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(99, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(99, 1, 113, NULL, NULL, 1, '9600', NULL, 0, NULL, NULL, NULL),
	(99, 2, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(99, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(99, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(99, 2, 113, NULL, NULL, 1, '9600', NULL, 0, NULL, NULL, NULL),
	(99, 3, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(99, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(99, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(99, 3, 113, NULL, NULL, 1, '9600', NULL, 0, NULL, NULL, NULL),
	(99, 4, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(99, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(99, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(99, 4, 113, NULL, NULL, 1, '9600', NULL, 0, NULL, NULL, NULL),
	(99, 5, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(99, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(99, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(99, 5, 113, NULL, NULL, 1, '9600', NULL, 0, NULL, NULL, NULL),
	(99, 11, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(99, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(99, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(99, 11, 113, NULL, NULL, 1, '9600', NULL, 0, NULL, NULL, NULL),
	(99, 12, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(99, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(99, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(99, 12, 113, NULL, NULL, 1, '9600', NULL, 0, NULL, NULL, NULL),
	(99, 13, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(99, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(99, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(99, 13, 113, NULL, NULL, 1, '9600', NULL, 0, NULL, NULL, NULL),
	(99, 14, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(99, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(99, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(99, 14, 113, NULL, NULL, 1, '9600', NULL, 0, NULL, NULL, NULL),
	(99, 15, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(99, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(99, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(99, 15, 113, NULL, NULL, 1, '9600', NULL, 0, NULL, NULL, NULL),
	(100, 1, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 2, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 3, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 4, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 5, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 11, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 12, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 13, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 14, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 15, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(101, 1, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(101, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(101, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(101, 1, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(101, 2, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(101, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(101, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(101, 2, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(101, 3, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(101, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(101, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(101, 3, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(101, 4, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(101, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(101, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(101, 4, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(101, 5, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(101, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(101, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(101, 5, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(101, 11, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(101, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(101, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(101, 11, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(101, 12, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(101, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(101, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(101, 12, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(101, 13, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(101, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(101, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(101, 13, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(101, 14, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(101, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(101, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(101, 14, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(101, 15, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(101, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(101, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(101, 15, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(102, 1, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(102, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(102, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(102, 1, 121, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(102, 1, 122, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(102, 2, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(102, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(102, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(102, 2, 121, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(102, 2, 122, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(102, 3, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(102, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(102, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(102, 3, 121, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(102, 3, 122, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(102, 4, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(102, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(102, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(102, 4, 121, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(102, 4, 122, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(102, 5, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(102, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(102, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(102, 5, 121, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(102, 5, 122, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(102, 11, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(102, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(102, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(102, 11, 121, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(102, 11, 122, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(102, 12, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(102, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(102, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(102, 12, 121, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(102, 12, 122, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(102, 13, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(102, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(102, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(102, 13, 121, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(102, 13, 122, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(102, 14, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(102, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(102, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(102, 14, 121, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(102, 14, 122, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(102, 15, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(102, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(102, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(102, 15, 121, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(102, 15, 122, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(103, 1, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(103, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(103, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(103, 2, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(103, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(103, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(103, 3, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(103, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(103, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(103, 4, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(103, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(103, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(103, 5, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(103, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(103, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(103, 11, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(103, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(103, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(103, 12, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(103, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(103, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(103, 13, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(103, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(103, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(103, 14, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(103, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(103, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(103, 15, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(103, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(103, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(104, 1, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(104, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(104, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(104, 2, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(104, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(104, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(104, 3, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(104, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(104, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(104, 4, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(104, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(104, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(104, 5, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(104, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(104, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(104, 11, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(104, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(104, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(104, 12, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(104, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(104, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(104, 13, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(104, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(104, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(104, 14, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(104, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(104, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(104, 15, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(104, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(104, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(105, 1, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(105, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(105, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(105, 2, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(105, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(105, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(105, 3, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(105, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(105, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(105, 4, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(105, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(105, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(105, 5, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(105, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(105, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(105, 11, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(105, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(105, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(105, 12, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(105, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(105, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(105, 13, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(105, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(105, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(105, 14, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(105, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(105, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(105, 15, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(105, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(105, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(114, 1, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(114, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(114, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(114, 2, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(114, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(114, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(114, 3, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(114, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(114, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(114, 4, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(114, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(114, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(114, 5, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(114, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(114, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(114, 11, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(114, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(114, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(114, 12, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(114, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(114, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(114, 13, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(114, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(114, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(114, 14, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(114, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(114, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(114, 15, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(114, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(114, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(115, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(115, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(115, 1, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(115, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(115, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(115, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(115, 2, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(115, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(115, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(115, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(115, 3, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(115, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(115, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(115, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(115, 4, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(115, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(115, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(115, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(115, 5, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(115, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(115, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(115, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(115, 11, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(115, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(115, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(115, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(115, 12, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(115, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(115, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(115, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(115, 13, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(115, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(115, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(115, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(115, 14, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(115, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(115, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(115, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(115, 15, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(115, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(116, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(116, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(116, 1, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(116, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(116, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(116, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(116, 2, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(116, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(116, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(116, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(116, 3, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(116, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(116, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(116, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(116, 4, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(116, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(116, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(116, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(116, 5, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(116, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(116, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(116, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(116, 11, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(116, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(116, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(116, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(116, 12, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(116, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(116, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(116, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(116, 13, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(116, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(116, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(116, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(116, 14, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(116, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(116, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(116, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(116, 15, 17, 126, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(116, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(117, 1, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(117, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(117, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(117, 2, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(117, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(117, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(117, 3, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(117, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(117, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(117, 4, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(117, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(117, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(117, 5, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(117, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(117, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(117, 11, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(117, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(117, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(117, 12, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(117, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(117, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(117, 13, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(117, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(117, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(117, 14, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(117, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(117, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(117, 15, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(117, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(117, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 1, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(118, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(118, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 2, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(118, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(118, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 3, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(118, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(118, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 4, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(118, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(118, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 5, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(118, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(118, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 11, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(118, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(118, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 12, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(118, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(118, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 13, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(118, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(118, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 14, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(118, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(118, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 15, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(118, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(118, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(119, 1, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(119, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(119, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(119, 2, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(119, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(119, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(119, 3, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(119, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(119, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(119, 4, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(119, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(119, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(119, 5, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(119, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(119, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(119, 11, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(119, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(119, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(119, 12, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(119, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(119, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(119, 13, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(119, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(119, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(119, 14, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(119, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(119, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(119, 15, 11, NULL, NULL, 1, '1000', NULL, 0, NULL, NULL, NULL),
	(119, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(119, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(120, 1, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(120, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(120, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(120, 2, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(120, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(120, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(120, 3, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(120, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(120, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(120, 4, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(120, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(120, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(120, 5, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(120, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(120, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(120, 11, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(120, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(120, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(120, 12, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(120, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(120, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(120, 13, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(120, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(120, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(120, 14, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(120, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(120, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(120, 15, 11, NULL, NULL, 1, '500', NULL, 0, NULL, NULL, NULL),
	(120, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(120, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(121, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(121, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(121, 1, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(121, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(121, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(121, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(121, 2, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(121, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(121, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(121, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(121, 3, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(121, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(121, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(121, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(121, 4, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(121, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(121, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(121, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(121, 5, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(121, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(121, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(121, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(121, 11, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(121, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(121, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(121, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(121, 12, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(121, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(121, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(121, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(121, 13, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(121, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(121, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(121, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(121, 14, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(121, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(121, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(121, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(121, 15, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(121, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 1, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(122, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(122, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 1, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 2, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(122, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(122, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 2, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 3, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(122, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(122, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 3, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 4, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(122, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(122, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 4, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 5, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(122, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(122, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 5, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 11, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(122, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(122, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 11, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 12, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(122, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(122, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 12, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 13, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(122, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(122, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 13, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 14, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(122, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(122, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 14, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 15, 11, NULL, NULL, 1, '2000', NULL, 0, NULL, NULL, NULL),
	(122, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(122, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(122, 15, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(123, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(123, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(123, 1, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(123, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(123, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(123, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(123, 2, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(123, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(123, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(123, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(123, 3, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(123, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(123, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(123, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(123, 4, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(123, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(123, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(123, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(123, 5, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(123, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(123, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(123, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(123, 11, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(123, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(123, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(123, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(123, 12, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(123, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(123, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(123, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(123, 13, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(123, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(123, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(123, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(123, 14, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(123, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(123, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(123, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(123, 15, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(123, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(124, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(124, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(124, 1, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(124, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(124, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(124, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(124, 2, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(124, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(124, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(124, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(124, 3, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(124, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(124, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(124, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(124, 4, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(124, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(124, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(124, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(124, 5, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(124, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(124, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(124, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(124, 11, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(124, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(124, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(124, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(124, 12, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(124, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(124, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(124, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(124, 13, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(124, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(124, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(124, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(124, 14, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(124, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(124, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(124, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(124, 15, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(124, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 1, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(125, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 2, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(125, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 3, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(125, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 4, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(125, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 5, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(125, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 11, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(125, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 12, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(125, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 13, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(125, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 14, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(125, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 15, 11, NULL, NULL, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(125, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(126, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(126, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(126, 1, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(126, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(126, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(126, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(126, 2, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(126, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(126, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(126, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(126, 3, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(126, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(126, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(126, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(126, 4, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(126, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(126, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(126, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(126, 5, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(126, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(126, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(126, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(126, 11, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(126, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(126, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(126, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(126, 12, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(126, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(126, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(126, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(126, 13, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(126, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(126, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(126, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(126, 14, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(126, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(126, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(126, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(126, 15, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(126, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(127, 1, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(127, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(127, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(127, 2, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(127, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(127, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(127, 3, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(127, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(127, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(127, 4, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(127, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(127, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(127, 5, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(127, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(127, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(127, 11, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(127, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(127, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(127, 12, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(127, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(127, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(127, 13, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(127, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(127, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(127, 14, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(127, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(127, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(127, 15, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(127, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(127, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(128, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(128, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(128, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(128, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(128, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(128, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(128, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(128, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(128, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(128, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(129, 1, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(129, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(129, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(129, 2, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(129, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(129, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(129, 3, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(129, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(129, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(129, 4, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(129, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(129, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(129, 5, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(129, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(129, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(129, 11, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(129, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(129, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(129, 12, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(129, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(129, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(129, 13, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(129, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(129, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(129, 14, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(129, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(129, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(129, 15, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(129, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(129, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(130, 1, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(130, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(130, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(130, 2, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(130, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(130, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(130, 3, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(130, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(130, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(130, 4, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(130, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(130, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(130, 5, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(130, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(130, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(130, 11, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(130, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(130, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(130, 12, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(130, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(130, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(130, 13, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(130, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(130, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(130, 14, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(130, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(130, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(130, 15, 11, NULL, NULL, 3, '800', NULL, 0, NULL, NULL, NULL),
	(130, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(130, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(131, 1, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(131, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(131, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(131, 2, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(131, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(131, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(131, 3, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(131, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(131, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(131, 4, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(131, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(131, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(131, 5, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(131, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(131, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(131, 11, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(131, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(131, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(131, 12, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(131, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(131, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(131, 13, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(131, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(131, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(131, 14, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(131, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(131, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(131, 15, 11, NULL, NULL, 1, '20000', NULL, 0, NULL, NULL, NULL),
	(131, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(131, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(133, 1, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(133, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(133, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(133, 2, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(133, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(133, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(133, 3, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(133, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(133, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(133, 4, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(133, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(133, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(133, 5, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(133, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(133, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(133, 11, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(133, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(133, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(133, 12, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(133, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(133, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(133, 13, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(133, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(133, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(133, 14, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(133, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(133, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(133, 15, 11, NULL, NULL, 1, '3000', NULL, 0, NULL, NULL, NULL),
	(133, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(133, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 1, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(134, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(134, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 1, 196, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 2, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(134, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(134, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 2, 196, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 3, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(134, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(134, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 3, 196, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 4, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(134, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(134, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 4, 196, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 5, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(134, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(134, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 5, 196, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 11, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(134, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(134, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 11, 196, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 12, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(134, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(134, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 12, 196, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 13, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(134, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(134, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 13, 196, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 14, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(134, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(134, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 14, 196, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 15, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(134, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(134, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(134, 15, 196, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 1, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(135, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(135, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 1, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(135, 2, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(135, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(135, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 2, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(135, 3, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(135, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(135, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 3, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(135, 4, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(135, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(135, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 4, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(135, 5, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(135, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(135, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 5, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(135, 11, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(135, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(135, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 11, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(135, 12, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(135, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(135, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 12, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(135, 13, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(135, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(135, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 13, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(135, 14, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(135, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(135, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 14, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(135, 15, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(135, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(135, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 15, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(136, 1, 11, NULL, NULL, 1, '400', NULL, 0, NULL, NULL, NULL),
	(136, 1, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(136, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(136, 2, 11, NULL, NULL, 1, '400', NULL, 0, NULL, NULL, NULL),
	(136, 2, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(136, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(136, 3, 11, NULL, NULL, 1, '400', NULL, 0, NULL, NULL, NULL),
	(136, 3, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(136, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(136, 4, 11, NULL, NULL, 1, '400', NULL, 0, NULL, NULL, NULL),
	(136, 4, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(136, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(136, 5, 11, NULL, NULL, 1, '400', NULL, 0, NULL, NULL, NULL),
	(136, 5, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(136, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(136, 11, 11, NULL, NULL, 1, '400', NULL, 0, NULL, NULL, NULL),
	(136, 11, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(136, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(136, 12, 11, NULL, NULL, 1, '400', NULL, 0, NULL, NULL, NULL),
	(136, 12, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(136, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(136, 13, 11, NULL, NULL, 1, '400', NULL, 0, NULL, NULL, NULL),
	(136, 13, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(136, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(136, 14, 11, NULL, NULL, 1, '400', NULL, 0, NULL, NULL, NULL),
	(136, 14, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(136, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(136, 15, 11, NULL, NULL, 1, '400', NULL, 0, NULL, NULL, NULL),
	(136, 15, 12, NULL, NULL, 1, '2', NULL, 0, NULL, NULL, NULL),
	(136, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(137, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(137, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 1, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(137, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(137, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(137, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 2, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(137, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(137, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(137, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 3, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(137, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(137, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(137, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 4, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(137, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(137, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(137, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 5, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(137, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(137, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(137, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 11, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(137, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(137, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(137, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 12, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(137, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(137, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(137, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 13, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(137, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(137, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(137, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 14, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(137, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(137, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(137, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 15, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(139, 1, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(139, 1, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(139, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 1, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(139, 2, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(139, 2, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(139, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 2, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(139, 3, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(139, 3, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(139, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 3, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(139, 4, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(139, 4, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(139, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 4, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(139, 5, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(139, 5, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(139, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 5, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(139, 10, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(139, 11, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(139, 11, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(139, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 11, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(139, 12, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(139, 12, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(139, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 12, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(139, 13, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(139, 13, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(139, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 13, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(139, 14, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(139, 14, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(139, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 14, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(139, 15, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(139, 15, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(139, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 15, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(140, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(140, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(140, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(140, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(140, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(140, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(140, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(140, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(140, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(140, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(140, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(140, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(140, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(140, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(140, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(140, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(140, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(140, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(140, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(140, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(140, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(141, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(141, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(141, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(141, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(141, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(141, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(141, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(141, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(141, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(141, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(141, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(141, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(141, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(141, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(141, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(141, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(141, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(141, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(141, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(141, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(141, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(141, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(141, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(141, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(141, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(141, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(141, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(141, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(141, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(141, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(142, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(142, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(142, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(142, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(142, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(142, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(142, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(142, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(142, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(142, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(142, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(142, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(142, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(142, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(142, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(142, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(142, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(142, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(142, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(142, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(142, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(142, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(142, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(142, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(142, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(142, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(142, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(142, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(142, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(142, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(143, 1, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(143, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(143, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(143, 2, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(143, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(143, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(143, 3, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(143, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(143, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(143, 4, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(143, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(143, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(143, 5, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(143, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(143, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(143, 11, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(143, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(143, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(143, 12, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(143, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(143, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(143, 13, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(143, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(143, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(143, 14, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(143, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(143, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(143, 15, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(143, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(143, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 1, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(144, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(144, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 1, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(144, 2, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(144, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(144, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 2, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(144, 3, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(144, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(144, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 3, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(144, 4, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(144, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(144, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 4, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(144, 5, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(144, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(144, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 5, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(144, 11, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(144, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(144, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 11, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(144, 12, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(144, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(144, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 12, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(144, 13, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(144, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(144, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 13, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(144, 14, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(144, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(144, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 14, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(144, 15, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(144, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(144, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 15, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(145, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(145, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(145, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(145, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(145, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(145, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(145, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(145, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(145, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(145, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(145, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(145, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(145, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(145, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(145, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(145, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(145, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(145, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(145, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(145, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(145, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(145, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(145, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(145, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(145, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(145, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(145, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(145, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(145, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(145, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(147, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(147, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 1, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 1, 156, NULL, NULL, 3, '200', NULL, 0, NULL, NULL, NULL),
	(147, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(147, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(147, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 2, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 2, 156, NULL, NULL, 3, '200', NULL, 0, NULL, NULL, NULL),
	(147, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(147, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(147, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 3, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 3, 156, NULL, NULL, 3, '200', NULL, 0, NULL, NULL, NULL),
	(147, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(147, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(147, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 4, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 4, 156, NULL, NULL, 3, '200', NULL, 0, NULL, NULL, NULL),
	(147, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(147, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(147, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 5, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 5, 156, NULL, NULL, 3, '200', NULL, 0, NULL, NULL, NULL),
	(147, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(147, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(147, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 11, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 11, 156, NULL, NULL, 3, '200', NULL, 0, NULL, NULL, NULL),
	(147, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(147, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(147, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 12, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 12, 156, NULL, NULL, 3, '200', NULL, 0, NULL, NULL, NULL),
	(147, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(147, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(147, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 13, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 13, 156, NULL, NULL, 3, '200', NULL, 0, NULL, NULL, NULL),
	(147, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(147, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(147, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 14, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 14, 156, NULL, NULL, 3, '200', NULL, 0, NULL, NULL, NULL),
	(147, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(147, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(147, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 15, 113, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 15, 156, NULL, NULL, 3, '200', NULL, 0, NULL, NULL, NULL),
	(148, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(148, 1, 12, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(148, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(148, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(148, 2, 12, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(148, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(148, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(148, 3, 12, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(148, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(148, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(148, 4, 12, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(148, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(148, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(148, 5, 12, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(148, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(148, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(148, 11, 12, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(148, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(148, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(148, 12, 12, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(148, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(148, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(148, 13, 12, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(148, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(148, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(148, 14, 12, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(148, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(148, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(148, 15, 12, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(148, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(151, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(151, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(151, 1, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(151, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(151, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(151, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(151, 2, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(151, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(151, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(151, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(151, 3, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(151, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(151, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(151, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(151, 4, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(151, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(151, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(151, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(151, 5, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(151, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(151, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(151, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(151, 11, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(151, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(151, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(151, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(151, 12, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(151, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(151, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(151, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(151, 13, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(151, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(151, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(151, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(151, 14, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(151, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(151, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(151, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(151, 15, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(151, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 1, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 2, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 3, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 4, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 5, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 11, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 12, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 13, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 14, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 15, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(154, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(154, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 1, 117, NULL, NULL, 3, '64', NULL, 0, NULL, NULL, NULL),
	(154, 1, 197, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 1, 203, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(154, 1, 204, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 1, 205, NULL, NULL, 3, '4', NULL, 0, NULL, NULL, NULL),
	(154, 1, 206, NULL, NULL, 3, '3', NULL, 0, NULL, NULL, NULL),
	(154, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(154, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(154, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 2, 117, NULL, NULL, 3, '64', NULL, 0, NULL, NULL, NULL),
	(154, 2, 197, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 2, 203, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(154, 2, 204, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 2, 205, NULL, NULL, 3, '4', NULL, 0, NULL, NULL, NULL),
	(154, 2, 206, NULL, NULL, 3, '3', NULL, 0, NULL, NULL, NULL),
	(154, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(154, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(154, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 3, 117, NULL, NULL, 3, '64', NULL, 0, NULL, NULL, NULL),
	(154, 3, 197, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 3, 203, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(154, 3, 204, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 3, 205, NULL, NULL, 3, '4', NULL, 0, NULL, NULL, NULL),
	(154, 3, 206, NULL, NULL, 3, '3', NULL, 0, NULL, NULL, NULL),
	(154, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(154, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(154, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 4, 117, NULL, NULL, 3, '64', NULL, 0, NULL, NULL, NULL),
	(154, 4, 197, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 4, 203, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(154, 4, 204, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 4, 205, NULL, NULL, 3, '4', NULL, 0, NULL, NULL, NULL),
	(154, 4, 206, NULL, NULL, 3, '3', NULL, 0, NULL, NULL, NULL),
	(154, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(154, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(154, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 5, 117, NULL, NULL, 3, '64', NULL, 0, NULL, NULL, NULL),
	(154, 5, 197, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 5, 203, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(154, 5, 204, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 5, 205, NULL, NULL, 3, '4', NULL, 0, NULL, NULL, NULL),
	(154, 5, 206, NULL, NULL, 3, '3', NULL, 0, NULL, NULL, NULL),
	(154, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(154, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(154, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 11, 117, NULL, NULL, 3, '64', NULL, 0, NULL, NULL, NULL),
	(154, 11, 197, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 11, 203, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(154, 11, 204, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 11, 205, NULL, NULL, 3, '4', NULL, 0, NULL, NULL, NULL),
	(154, 11, 206, NULL, NULL, 3, '3', NULL, 0, NULL, NULL, NULL),
	(154, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(154, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(154, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 12, 117, NULL, NULL, 3, '64', NULL, 0, NULL, NULL, NULL),
	(154, 12, 197, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 12, 203, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(154, 12, 204, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 12, 205, NULL, NULL, 3, '4', NULL, 0, NULL, NULL, NULL),
	(154, 12, 206, NULL, NULL, 3, '3', NULL, 0, NULL, NULL, NULL),
	(154, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(154, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(154, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 13, 117, NULL, NULL, 3, '64', NULL, 0, NULL, NULL, NULL),
	(154, 13, 197, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 13, 203, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(154, 13, 204, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 13, 205, NULL, NULL, 3, '4', NULL, 0, NULL, NULL, NULL),
	(154, 13, 206, NULL, NULL, 3, '3', NULL, 0, NULL, NULL, NULL),
	(154, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(154, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(154, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 14, 117, NULL, NULL, 3, '64', NULL, 0, NULL, NULL, NULL),
	(154, 14, 197, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 14, 203, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(154, 14, 204, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 14, 205, NULL, NULL, 3, '4', NULL, 0, NULL, NULL, NULL),
	(154, 14, 206, NULL, NULL, 3, '3', NULL, 0, NULL, NULL, NULL),
	(154, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(154, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(154, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 15, 117, NULL, NULL, 3, '64', NULL, 0, NULL, NULL, NULL),
	(154, 15, 197, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 15, 203, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(154, 15, 204, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(154, 15, 205, NULL, NULL, 3, '4', NULL, 0, NULL, NULL, NULL),
	(154, 15, 206, NULL, NULL, 3, '3', NULL, 0, NULL, NULL, NULL),
	(157, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(157, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(157, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(157, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(157, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(157, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(157, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(157, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(157, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(157, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(157, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(157, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(157, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(157, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(157, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(157, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(157, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(157, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(157, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(157, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(157, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(157, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(157, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(157, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(157, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(157, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(157, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(157, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(157, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(157, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(158, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(158, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(158, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(158, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(158, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(158, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(158, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(158, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(158, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(158, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(158, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(158, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(158, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(158, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(158, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(158, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(158, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(158, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(158, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(158, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(158, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(158, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(158, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(158, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(158, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(158, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(158, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(158, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(158, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(158, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(160, 1, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(160, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(160, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(160, 2, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(160, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(160, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(160, 3, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(160, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(160, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(160, 4, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(160, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(160, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(160, 5, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(160, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(160, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(160, 11, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(160, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(160, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(160, 12, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(160, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(160, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(160, 13, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(160, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(160, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(160, 14, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(160, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(160, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(160, 15, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(160, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(160, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(161, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(161, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(161, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(161, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(161, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(161, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(161, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(161, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(161, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(161, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(161, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(161, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(161, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(161, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(161, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(161, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(161, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(161, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(161, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(161, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(161, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(161, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(161, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(161, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(161, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(161, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(161, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(161, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(161, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(161, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(162, 1, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(162, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(162, 1, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 2, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(162, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(162, 2, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 3, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(162, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(162, 3, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 4, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(162, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(162, 4, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 5, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(162, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(162, 5, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 11, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(162, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(162, 11, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 12, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(162, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(162, 12, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 13, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(162, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(162, 13, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 14, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(162, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(162, 14, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 15, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(162, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(162, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(162, 15, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(163, 1, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(163, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(163, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(163, 2, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(163, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(163, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(163, 3, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(163, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(163, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(163, 4, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(163, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(163, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(163, 5, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(163, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(163, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(163, 11, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(163, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(163, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(163, 12, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(163, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(163, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(163, 13, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(163, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(163, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(163, 14, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(163, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(163, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(163, 15, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(163, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(163, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(165, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(165, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(165, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(165, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(165, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(165, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(165, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(165, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(165, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(165, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(165, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(165, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(165, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(165, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(165, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(165, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(165, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(165, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(165, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(165, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(165, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(165, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(165, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(165, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(165, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(165, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(165, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(165, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(165, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(165, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(166, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(166, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(166, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(166, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(166, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(166, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(166, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(166, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(166, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(166, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(166, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(166, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(166, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(166, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(166, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(166, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(166, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(166, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(166, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(166, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(166, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(166, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(166, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(166, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(166, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(166, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(166, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(166, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(166, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(166, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(167, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(167, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(167, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(167, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(167, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(167, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(167, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(167, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(167, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(167, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(167, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(167, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(167, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(167, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(167, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(167, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(167, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(167, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(167, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(167, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(167, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(167, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(167, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(167, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(167, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(167, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(167, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(167, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(167, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(167, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(168, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(168, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(168, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(168, 1, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(168, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(168, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(168, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(168, 2, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(168, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(168, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(168, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(168, 3, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(168, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(168, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(168, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(168, 4, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(168, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(168, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(168, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(168, 5, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(168, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(168, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(168, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(168, 11, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(168, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(168, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(168, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(168, 12, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(168, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(168, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(168, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(168, 13, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(168, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(168, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(168, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(168, 14, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(168, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(168, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(168, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(168, 15, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(174, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(174, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(174, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(174, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(174, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(174, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(174, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(174, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(174, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(174, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(174, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(174, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(174, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(174, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(174, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(174, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(174, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(174, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(174, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(174, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(174, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(174, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(174, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(174, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(174, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(174, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(174, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(174, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(174, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(174, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(179, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(179, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(179, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(179, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(179, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(179, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(179, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(179, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(179, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(179, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(179, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(179, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(179, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(179, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(179, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(179, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(179, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(179, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(179, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(179, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(179, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(179, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(179, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(179, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(179, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(179, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(179, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(179, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(179, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(179, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(180, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(180, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(180, 1, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(180, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(180, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(180, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(180, 2, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(180, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(180, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(180, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(180, 3, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(180, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(180, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(180, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(180, 4, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(180, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(180, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(180, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(180, 5, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(180, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(180, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(180, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(180, 11, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(180, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(180, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(180, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(180, 12, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(180, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(180, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(180, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(180, 13, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(180, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(180, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(180, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(180, 14, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(180, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(180, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(180, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(180, 15, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(180, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(181, 1, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(181, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(181, 1, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 2, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(181, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(181, 2, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 3, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(181, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(181, 3, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 4, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(181, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(181, 4, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 5, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(181, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(181, 5, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 11, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(181, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(181, 11, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 12, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(181, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(181, 12, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 13, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(181, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(181, 13, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 14, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(181, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(181, 14, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 15, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(181, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(181, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(181, 15, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 1, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(182, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(182, 1, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 2, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(182, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(182, 2, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 3, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(182, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(182, 3, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 4, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(182, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(182, 4, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 5, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(182, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(182, 5, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 11, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(182, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(182, 11, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 12, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(182, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(182, 12, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 13, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(182, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(182, 13, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 14, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(182, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(182, 14, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 15, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(182, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(182, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(182, 15, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 1, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(183, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(183, 1, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 2, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(183, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(183, 2, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 3, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(183, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(183, 3, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 4, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(183, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(183, 4, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 5, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(183, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(183, 5, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 11, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(183, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(183, 11, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 12, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(183, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(183, 12, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 13, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(183, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(183, 13, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 14, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(183, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(183, 14, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 15, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(183, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(183, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(183, 15, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 1, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(184, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(184, 1, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 2, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(184, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(184, 2, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 3, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(184, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(184, 3, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 4, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(184, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(184, 4, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 5, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(184, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(184, 5, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 11, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(184, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(184, 11, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 12, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(184, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(184, 12, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 13, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(184, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(184, 13, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 14, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(184, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(184, 14, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 15, 11, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(184, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(184, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(184, 15, 196, NULL, NULL, 3, '2700', NULL, 0, NULL, NULL, NULL),
	(185, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(185, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(185, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(185, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(185, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(185, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(185, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(185, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(185, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(185, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(185, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(185, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(185, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(185, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(185, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(185, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(185, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(185, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(185, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(185, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(185, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(185, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(185, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(185, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(185, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(185, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(185, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(185, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(185, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(185, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(186, 1, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(186, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(186, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(186, 2, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(186, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(186, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(186, 3, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(186, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(186, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(186, 4, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(186, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(186, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(186, 5, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(186, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(186, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(186, 11, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(186, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(186, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(186, 12, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(186, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(186, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(186, 13, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(186, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(186, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(186, 14, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(186, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(186, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(186, 15, 11, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(186, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(186, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(187, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(187, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(187, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(187, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(187, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(187, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(187, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(187, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(187, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(187, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(187, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(187, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(187, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(187, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(187, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(187, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(187, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(187, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(187, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(187, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(187, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(187, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(187, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(187, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(187, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(187, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(187, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(187, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(187, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(187, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(188, 1, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(188, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(188, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(188, 2, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(188, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(188, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(188, 3, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(188, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(188, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(188, 4, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(188, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(188, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(188, 5, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(188, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(188, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(188, 11, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(188, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(188, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(188, 12, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(188, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(188, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(188, 13, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(188, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(188, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(188, 14, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(188, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(188, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(188, 15, 11, NULL, NULL, 3, '400', NULL, 0, NULL, NULL, NULL),
	(188, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(188, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(189, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(189, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(189, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(189, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(189, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(189, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(189, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(189, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(189, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(189, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(189, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(189, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(189, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(189, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(189, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(189, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(189, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(189, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(189, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(189, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(189, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(189, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(189, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(189, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(189, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(189, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(189, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(189, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(189, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(189, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(190, 1, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(190, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(190, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(190, 2, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(190, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(190, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(190, 3, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(190, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(190, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(190, 4, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(190, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(190, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(190, 5, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(190, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(190, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(190, 11, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(190, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(190, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(190, 12, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(190, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(190, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(190, 13, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(190, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(190, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(190, 14, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(190, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(190, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(190, 15, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(190, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(190, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(191, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(191, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(191, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(191, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(191, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(191, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(191, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(191, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(191, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(191, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(191, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(191, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(191, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(191, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(191, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(191, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(191, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(191, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(191, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(191, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(191, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(191, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(191, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(191, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(191, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(191, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(191, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(191, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(191, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(191, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(192, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(192, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(192, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(192, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(192, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(192, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(192, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(192, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(192, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(192, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(192, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(192, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(192, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(192, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(192, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(192, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(192, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(192, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(192, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(192, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(192, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(192, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(192, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(192, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(192, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(192, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(192, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(192, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(192, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(192, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 1, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(195, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 2, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(195, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 3, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(195, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 4, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(195, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 5, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(195, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 10, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(195, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 11, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(195, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 12, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(195, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 13, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(195, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 14, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(195, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 15, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(195, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(197, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(197, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 1, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(197, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(197, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(197, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 2, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(197, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(197, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(197, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 3, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(197, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(197, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(197, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 4, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(197, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(197, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(197, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 5, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(197, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(197, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(197, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 11, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(197, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(197, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(197, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 12, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(197, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(197, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(197, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 13, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(197, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(197, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(197, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 14, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(197, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(197, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(197, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 15, 196, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(200, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(200, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(200, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(200, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(200, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(200, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(200, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(200, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(200, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(200, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(200, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(200, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(200, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(200, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(200, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(200, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(200, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(200, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(200, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(200, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(200, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(200, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(200, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(200, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(200, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(200, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(200, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(200, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(200, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(200, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(202, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(202, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(202, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(202, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(202, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(202, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(202, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(202, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(202, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(202, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(202, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(202, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(202, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(202, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(202, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(202, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(202, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(202, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(202, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(202, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(203, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(203, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 1, 197, NULL, NULL, 3, '10', NULL, 0, NULL, NULL, NULL),
	(203, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(203, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(203, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 2, 197, NULL, NULL, 3, '10', NULL, 0, NULL, NULL, NULL),
	(203, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(203, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(203, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 3, 197, NULL, NULL, 3, '10', NULL, 0, NULL, NULL, NULL),
	(203, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(203, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(203, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 4, 197, NULL, NULL, 3, '10', NULL, 0, NULL, NULL, NULL),
	(203, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(203, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(203, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 5, 197, NULL, NULL, 3, '10', NULL, 0, NULL, NULL, NULL),
	(203, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(203, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(203, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 11, 197, NULL, NULL, 3, '10', NULL, 0, NULL, NULL, NULL),
	(203, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(203, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(203, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 12, 197, NULL, NULL, 3, '10', NULL, 0, NULL, NULL, NULL),
	(203, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(203, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(203, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 13, 197, NULL, NULL, 3, '10', NULL, 0, NULL, NULL, NULL),
	(203, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(203, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(203, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 14, 197, NULL, NULL, 3, '10', NULL, 0, NULL, NULL, NULL),
	(203, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(203, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(203, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 15, 197, NULL, NULL, 3, '10', NULL, 0, NULL, NULL, NULL),
	(205, 1, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(205, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(205, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(205, 2, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(205, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(205, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(205, 3, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(205, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(205, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(205, 4, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(205, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(205, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(205, 5, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(205, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(205, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(205, 11, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(205, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(205, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(205, 12, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(205, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(205, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(205, 13, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(205, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(205, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(205, 14, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(205, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(205, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(205, 15, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(205, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(205, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(206, 1, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(206, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(206, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(206, 2, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(206, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(206, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(206, 3, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(206, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(206, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(206, 4, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(206, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(206, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(206, 5, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(206, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(206, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(206, 11, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(206, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(206, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(206, 12, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(206, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(206, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(206, 13, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(206, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(206, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(206, 14, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(206, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(206, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(206, 15, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(206, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(206, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 1, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(207, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 1, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(207, 1, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(207, 1, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 1, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(207, 2, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(207, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 2, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(207, 2, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(207, 2, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 2, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(207, 3, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(207, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 3, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(207, 3, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(207, 3, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 3, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(207, 4, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(207, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 4, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(207, 4, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(207, 4, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 4, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(207, 5, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(207, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 5, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(207, 5, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(207, 5, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 5, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(207, 11, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(207, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 11, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(207, 11, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(207, 11, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 11, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(207, 12, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(207, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 12, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(207, 12, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(207, 12, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 12, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(207, 13, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(207, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 13, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(207, 13, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(207, 13, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 13, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(207, 14, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(207, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 14, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(207, 14, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(207, 14, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 14, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(207, 15, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(207, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 15, 113, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(207, 15, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(207, 15, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(207, 15, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(208, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 1, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 1, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 1, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(208, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 2, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 2, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 2, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(208, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 3, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 3, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 3, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(208, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 4, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 4, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 4, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(208, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 5, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 5, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 5, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(208, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 11, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 11, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 11, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(208, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 12, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 12, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 12, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(208, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 13, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 13, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 13, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(208, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 14, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 14, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 14, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(208, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 15, 296, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(208, 15, 297, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(208, 15, 305, NULL, NULL, 3, '100', NULL, 0, NULL, NULL, NULL),
	(209, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(209, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(209, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 1, 319, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 1, 320, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(209, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(209, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 2, 319, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 2, 320, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(209, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(209, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 3, 319, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 3, 320, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(209, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(209, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 4, 319, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 4, 320, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(209, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(209, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 5, 319, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 5, 320, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(209, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(209, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 11, 319, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 11, 320, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(209, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(209, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 12, 319, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 12, 320, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(209, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(209, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 13, 319, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 13, 320, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(209, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(209, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 14, 319, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 14, 320, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(209, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(209, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 15, 319, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 15, 320, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(210, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(210, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(210, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(210, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(210, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(210, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(210, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(210, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(210, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(210, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(210, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(210, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(210, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(210, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(210, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(210, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(210, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(210, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(210, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(210, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(210, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(210, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(210, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(210, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(210, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(210, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(210, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(210, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(210, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(210, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 1, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 1, 197, NULL, NULL, 3, '24', NULL, 0, NULL, NULL, NULL),
	(211, 2, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 2, 197, NULL, NULL, 3, '24', NULL, 0, NULL, NULL, NULL),
	(211, 3, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 3, 197, NULL, NULL, 3, '24', NULL, 0, NULL, NULL, NULL),
	(211, 4, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 4, 197, NULL, NULL, 3, '24', NULL, 0, NULL, NULL, NULL),
	(211, 5, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 5, 197, NULL, NULL, 3, '24', NULL, 0, NULL, NULL, NULL),
	(211, 11, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 11, 197, NULL, NULL, 3, '24', NULL, 0, NULL, NULL, NULL),
	(211, 12, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 12, 197, NULL, NULL, 3, '24', NULL, 0, NULL, NULL, NULL),
	(211, 13, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 13, 197, NULL, NULL, 3, '24', NULL, 0, NULL, NULL, NULL),
	(211, 14, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 14, 197, NULL, NULL, 3, '24', NULL, 0, NULL, NULL, NULL),
	(211, 15, 11, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 15, 197, NULL, NULL, 3, '24', NULL, 0, NULL, NULL, NULL),
	(214, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(214, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(214, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(214, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(214, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(214, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(214, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(214, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(214, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(214, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(214, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(214, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(214, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(214, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(214, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(214, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(214, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(214, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(214, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(214, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(214, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(214, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(214, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(214, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(214, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(214, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(214, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(214, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(214, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(214, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(215, 1, 11, NULL, NULL, 3, '35000', NULL, 0, NULL, NULL, NULL),
	(215, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(215, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(215, 1, 333, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(215, 2, 11, NULL, NULL, 3, '35000', NULL, 0, NULL, NULL, NULL),
	(215, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(215, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(215, 2, 333, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(215, 3, 11, NULL, NULL, 3, '35000', NULL, 0, NULL, NULL, NULL),
	(215, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(215, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(215, 3, 333, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(215, 4, 11, NULL, NULL, 3, '35000', NULL, 0, NULL, NULL, NULL),
	(215, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(215, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(215, 4, 333, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(215, 5, 11, NULL, NULL, 3, '35000', NULL, 0, NULL, NULL, NULL),
	(215, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(215, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(215, 5, 333, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(215, 11, 11, NULL, NULL, 3, '35000', NULL, 0, NULL, NULL, NULL),
	(215, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(215, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(215, 11, 333, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(215, 12, 11, NULL, NULL, 3, '35000', NULL, 0, NULL, NULL, NULL),
	(215, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(215, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(215, 12, 333, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(215, 13, 11, NULL, NULL, 3, '35000', NULL, 0, NULL, NULL, NULL),
	(215, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(215, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(215, 13, 333, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(215, 14, 11, NULL, NULL, 3, '35000', NULL, 0, NULL, NULL, NULL),
	(215, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(215, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(215, 14, 333, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(215, 15, 11, NULL, NULL, 3, '35000', NULL, 0, NULL, NULL, NULL),
	(215, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(215, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(215, 15, 333, NULL, NULL, 3, '5000', NULL, 0, NULL, NULL, NULL),
	(216, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(216, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(216, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(216, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(216, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(216, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(216, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(216, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(216, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(216, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(216, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(216, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(216, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(216, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(216, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(216, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(216, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(216, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(216, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(216, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(216, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(216, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(216, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(216, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(216, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(216, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(216, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(216, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(216, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(216, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(217, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(217, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(217, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(217, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(217, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(217, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(217, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(217, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(217, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(217, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(217, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(217, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(217, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(217, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(217, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(217, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(217, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(217, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(217, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(217, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(217, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(217, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(217, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(217, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(217, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(217, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(217, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(217, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(217, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(217, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(218, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(218, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(218, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(218, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(218, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(218, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(218, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(218, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(218, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(218, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(218, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(218, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(218, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(218, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(218, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(218, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(218, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(218, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(218, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(218, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(218, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(218, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(218, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(218, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(218, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(218, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(218, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(218, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(218, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(218, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(220, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(220, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(220, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(220, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(220, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(220, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(220, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(220, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(220, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(220, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(220, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(220, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(220, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(220, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(220, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(220, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(220, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(220, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(220, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(220, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(220, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(220, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(220, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(220, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(220, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(220, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(220, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(220, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(220, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(220, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(221, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(221, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(221, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(221, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(221, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(221, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(221, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(221, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(221, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(221, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(221, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(221, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(221, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(221, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(221, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(221, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(221, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(221, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(221, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(221, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(221, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(221, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(221, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(221, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(221, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(221, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(221, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(221, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(221, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(221, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(223, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(223, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(223, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(223, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(223, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(223, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(223, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(223, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(223, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(223, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(223, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(223, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(223, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(223, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(223, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(223, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(223, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(223, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(223, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(223, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(223, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(223, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(223, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(223, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(223, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(223, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(223, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(223, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(223, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(223, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(224, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(224, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(224, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(224, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(224, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(224, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(224, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(224, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(224, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(224, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(224, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(224, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(224, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(224, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(224, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(224, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(224, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(224, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(224, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(224, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(224, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(224, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(224, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(224, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(224, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(224, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(224, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(224, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(224, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(224, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(225, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(225, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(225, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(225, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(225, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(225, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(225, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(225, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(225, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(225, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(225, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(225, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(225, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(225, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(225, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(225, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(225, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(225, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(225, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(225, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(225, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(225, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(225, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(225, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(225, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(225, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(225, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(225, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(225, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(225, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 1, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(226, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(226, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 1, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(226, 2, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(226, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(226, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 2, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(226, 3, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(226, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(226, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 3, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(226, 4, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(226, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(226, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 4, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(226, 5, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(226, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(226, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 5, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(226, 11, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(226, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(226, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 11, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(226, 12, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(226, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(226, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 12, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(226, 13, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(226, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(226, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 13, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(226, 14, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(226, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(226, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 14, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(226, 15, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(226, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(226, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 15, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(227, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 1, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(228, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(228, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 1, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(228, 2, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(228, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(228, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 2, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(228, 3, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(228, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(228, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 3, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(228, 4, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(228, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(228, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 4, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(228, 5, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(228, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(228, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 5, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(228, 11, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(228, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(228, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 11, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(228, 12, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(228, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(228, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 12, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(228, 13, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(228, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(228, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 13, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(228, 14, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(228, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(228, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 14, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(228, 15, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(228, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(228, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 15, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(229, 1, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(229, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(229, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 1, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(229, 2, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(229, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(229, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 2, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(229, 3, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(229, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(229, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 3, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(229, 4, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(229, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(229, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 4, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(229, 5, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(229, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(229, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 5, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(229, 11, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(229, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(229, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 11, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(229, 12, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(229, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(229, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 12, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(229, 13, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(229, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(229, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 13, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(229, 14, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(229, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(229, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 14, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(229, 15, 11, NULL, NULL, 3, '3000', NULL, 0, NULL, NULL, NULL),
	(229, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(229, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 15, 117, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(232, 1, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(232, 1, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(232, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 1, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(232, 1, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(232, 2, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(232, 2, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(232, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 2, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(232, 2, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(232, 3, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(232, 3, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(232, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 3, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(232, 3, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(232, 4, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(232, 4, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(232, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 4, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(232, 4, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(232, 5, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(232, 5, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(232, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 5, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(232, 5, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(232, 11, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(232, 11, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(232, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 11, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(232, 11, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(232, 12, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(232, 12, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(232, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 12, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(232, 12, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(232, 13, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(232, 13, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(232, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 13, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(232, 13, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(232, 14, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(232, 14, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(232, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 14, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(232, 14, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(232, 15, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(232, 15, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(232, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 15, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(232, 15, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(234, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(234, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(234, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(234, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(234, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(234, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(234, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(234, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(234, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(234, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(234, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(234, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(234, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(234, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(234, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(234, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(234, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(234, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(234, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(234, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(234, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(234, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(234, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(234, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(234, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(234, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(234, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(234, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(234, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(234, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(235, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(235, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(235, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(235, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(235, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(235, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(235, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(235, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(235, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(235, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(235, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(235, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(235, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(235, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(235, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(235, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(235, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(235, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(235, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(235, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(235, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(235, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(235, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(235, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(235, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(235, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(235, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(235, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(235, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(235, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(236, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(236, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(236, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(236, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(236, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(236, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(236, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(236, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(236, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(236, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(236, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(236, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(236, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(236, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(236, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(236, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(236, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(236, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(236, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(236, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(236, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(236, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(236, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(236, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(236, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(236, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(236, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(236, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(236, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(236, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(237, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(237, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(237, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(237, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(237, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(237, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(237, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(237, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(237, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(237, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(237, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(237, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(237, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(237, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(237, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(237, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(237, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(237, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(237, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(237, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(237, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(237, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(237, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(237, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(237, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(237, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(237, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(237, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(237, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(237, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(238, 1, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(238, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(238, 1, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(238, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(238, 2, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(238, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(238, 2, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(238, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(238, 3, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(238, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(238, 3, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(238, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(238, 4, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(238, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(238, 4, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(238, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(238, 5, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(238, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(238, 5, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(238, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(238, 11, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(238, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(238, 11, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(238, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(238, 12, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(238, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(238, 12, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(238, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(238, 13, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(238, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(238, 13, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(238, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(238, 14, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(238, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(238, 14, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(238, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(238, 15, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(238, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(238, 15, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(238, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(239, 1, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(239, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(239, 1, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(239, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(239, 2, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(239, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(239, 2, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(239, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(239, 3, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(239, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(239, 3, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(239, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(239, 4, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(239, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(239, 4, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(239, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(239, 5, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(239, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(239, 5, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(239, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(239, 11, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(239, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(239, 11, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(239, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(239, 12, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(239, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(239, 12, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(239, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(239, 13, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(239, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(239, 13, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(239, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(239, 14, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(239, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(239, 14, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(239, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(239, 15, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(239, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(239, 15, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(239, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(240, 1, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(240, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(240, 1, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(240, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(240, 2, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(240, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(240, 2, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(240, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(240, 3, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(240, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(240, 3, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(240, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(240, 4, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(240, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(240, 4, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(240, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(240, 5, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(240, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(240, 5, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(240, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(240, 11, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(240, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(240, 11, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(240, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(240, 12, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(240, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(240, 12, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(240, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(240, 13, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(240, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(240, 13, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(240, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(240, 14, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(240, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(240, 14, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(240, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(240, 15, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(240, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(240, 15, 17, 122, NULL, 3, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(240, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(241, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(241, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(241, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(241, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(241, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(241, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(241, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(241, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(241, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(241, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(243, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(243, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(243, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(243, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(243, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(243, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(243, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(243, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(243, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(243, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(243, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(243, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(243, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(243, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(243, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(243, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(243, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(243, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(243, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(243, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(244, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(244, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(244, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(244, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(244, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(244, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(244, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(244, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(244, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(244, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(244, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(244, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(244, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(244, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(244, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(244, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(244, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(244, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(244, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(244, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(244, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(244, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(244, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(244, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(244, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(244, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(244, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(244, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(244, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(244, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(246, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(246, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 1, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(246, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(246, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(246, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 2, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(246, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(246, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(246, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 3, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(246, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(246, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(246, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 4, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(246, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(246, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(246, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 5, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(246, 10, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(246, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(246, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 10, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(246, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(246, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(246, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 11, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(246, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(246, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(246, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 12, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(246, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(246, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(246, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 13, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(246, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(246, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(246, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 14, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(246, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(246, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(246, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 15, 113, NULL, NULL, 3, '9600', NULL, 0, NULL, NULL, NULL),
	(248, 1, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(248, 1, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(248, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 1, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(248, 1, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(248, 2, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(248, 2, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(248, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 2, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(248, 2, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(248, 3, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(248, 3, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(248, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 3, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(248, 3, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(248, 4, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(248, 4, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(248, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 4, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(248, 4, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(248, 5, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(248, 5, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(248, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 5, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(248, 5, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(248, 11, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(248, 11, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(248, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 11, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(248, 11, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(248, 12, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(248, 12, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(248, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 12, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(248, 12, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(248, 13, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(248, 13, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(248, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 13, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(248, 13, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(248, 14, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(248, 14, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(248, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 14, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(248, 14, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(248, 15, 11, NULL, NULL, 3, '60000', NULL, 0, NULL, NULL, NULL),
	(248, 15, 12, NULL, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(248, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 15, 254, NULL, NULL, 3, '5', NULL, 0, NULL, NULL, NULL),
	(248, 15, 353, NULL, NULL, 3, '30', NULL, 0, NULL, NULL, NULL),
	(249, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(249, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(249, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(249, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(249, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(249, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(249, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(249, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(249, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(249, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(249, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(249, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(249, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(249, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(249, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(249, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(249, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(249, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(249, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(249, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(249, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(250, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(250, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(250, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(250, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(250, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(250, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(250, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(250, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(250, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(250, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(250, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(250, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(250, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(250, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(250, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(250, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(250, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(250, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(250, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(250, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(250, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(250, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(250, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(250, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(250, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(250, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(250, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(250, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(250, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(250, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(251, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(251, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(251, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(251, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(251, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(251, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(251, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(251, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(251, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(251, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(251, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(251, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(251, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(251, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(251, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(251, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(251, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(251, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(251, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(251, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(252, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(252, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(252, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(252, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(252, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(252, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(252, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(252, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(252, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(252, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(252, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(252, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(252, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(252, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(252, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(252, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(252, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(252, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(252, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(252, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(252, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(252, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(252, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(252, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(252, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(252, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(252, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(252, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(252, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(252, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(253, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(253, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(253, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(253, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(253, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(253, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(253, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(253, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(253, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(253, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(253, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(253, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(253, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(253, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(253, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(253, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(253, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(253, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(253, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(253, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(253, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(253, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(253, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(253, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(253, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(253, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(253, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(253, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(253, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(253, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(255, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(255, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(255, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(255, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(255, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(255, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(255, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(255, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(255, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(255, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(255, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(255, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(255, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(255, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(255, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(255, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(255, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(255, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(255, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(255, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(255, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(255, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(255, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(255, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(255, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(255, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(255, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(255, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(255, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(255, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(256, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(256, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(256, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(256, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(256, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(256, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(256, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(256, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(256, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(256, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(256, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(256, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(256, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(256, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(256, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(256, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(256, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(256, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(256, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(256, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(256, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(256, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(256, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(256, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(256, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(256, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(256, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(256, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(256, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(256, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(257, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(257, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(257, 1, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(257, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(257, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(257, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(257, 2, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(257, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(257, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(257, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(257, 3, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(257, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(257, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(257, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(257, 4, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(257, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(257, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(257, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(257, 5, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(257, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(257, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(257, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(257, 11, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(257, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(257, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(257, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(257, 12, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(257, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(257, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(257, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(257, 13, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(257, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(257, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(257, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(257, 14, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(257, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(257, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(257, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(257, 15, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(257, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(258, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(258, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(258, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(258, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(258, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(258, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(258, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(258, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(258, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(258, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(258, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(258, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(258, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(258, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(258, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(258, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(258, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(258, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(258, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(258, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(259, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(259, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(259, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(259, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(259, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(259, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(259, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(259, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(259, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(259, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(259, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(259, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(259, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(259, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(259, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(259, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(259, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(259, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(259, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(259, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(260, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(260, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(260, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(260, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(260, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(260, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(260, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(260, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(260, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(260, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(260, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(260, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(260, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(260, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(260, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(260, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(260, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(260, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(260, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(260, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(261, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(261, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(261, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(261, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(261, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(261, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(261, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(261, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(261, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(261, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(261, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(261, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(261, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(261, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(261, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(261, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(261, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(261, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(261, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(261, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(262, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(262, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(262, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(262, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(262, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(262, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(262, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(262, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(262, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(262, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(262, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(262, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(262, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(262, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(262, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(262, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(262, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(262, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(262, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(262, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(263, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(263, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(263, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(263, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(263, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(263, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(263, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(263, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(263, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(263, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(263, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(263, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(263, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(263, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(263, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(263, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(263, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(263, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(263, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(263, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(264, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(264, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(264, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(264, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(264, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(264, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(264, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(264, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(264, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(264, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(264, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(264, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(264, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(264, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(264, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(264, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(264, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(264, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(264, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(264, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(265, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(265, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(265, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(265, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(265, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(265, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(265, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(265, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(265, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(265, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(265, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(265, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(265, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(265, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(265, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(265, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(265, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(265, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(265, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(265, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(266, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(266, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(266, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(266, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(266, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(266, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(266, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(266, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(266, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(266, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(266, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(266, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(266, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(266, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(266, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(266, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(266, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(266, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(266, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(266, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(267, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(267, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(267, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(267, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(267, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(267, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(267, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(267, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(267, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(267, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(267, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(267, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(267, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(267, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(267, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(267, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(267, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(267, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(267, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(267, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(268, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(268, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(268, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(268, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(268, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(268, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(268, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(268, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(268, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(268, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(268, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(268, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(268, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(268, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(268, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(268, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(268, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(268, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(268, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(268, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(269, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(269, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(269, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(269, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(269, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(269, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(269, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(269, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(269, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(269, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(269, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(269, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(269, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(269, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(269, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(269, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(269, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(269, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(269, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(269, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(270, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(270, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(270, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(270, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(270, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(270, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(270, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(270, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(270, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(270, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(270, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(270, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(270, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(270, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(270, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(270, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(270, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(270, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(270, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(270, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(271, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(271, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(271, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(271, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(271, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(271, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(271, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(271, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(271, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(271, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(271, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(271, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(271, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(271, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(271, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(271, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(271, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(271, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(271, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(271, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(272, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(272, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(272, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(272, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(272, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(272, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(272, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(272, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(272, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(272, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(272, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(272, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(272, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(272, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(272, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(272, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(272, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(272, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(272, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(272, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(273, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(273, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(273, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(273, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(273, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(273, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(273, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(273, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(273, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(273, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(273, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(273, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(273, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(273, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(273, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(273, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(273, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(273, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(273, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(273, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(274, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(274, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(274, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(274, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(274, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(274, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(274, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(274, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(274, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(274, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(274, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(274, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(274, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(274, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(274, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(274, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(274, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(274, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(274, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(274, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(275, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(275, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(275, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(275, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(275, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(275, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(275, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(275, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(275, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(275, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(275, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(275, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(275, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(275, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(275, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(275, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(275, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(275, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(275, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(275, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(276, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(276, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(276, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(276, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(276, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(276, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(276, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(276, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(276, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(276, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(276, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(276, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(276, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(276, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(276, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(276, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(276, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(276, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(276, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(276, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(277, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(277, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(277, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(277, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(277, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(277, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(277, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(277, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(277, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(277, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(277, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(277, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(277, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(277, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(277, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(277, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(277, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(277, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(277, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(277, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(278, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(278, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(278, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(278, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(278, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(278, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(278, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(278, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(278, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(278, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(278, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(278, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(278, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(278, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(278, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(278, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(278, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(278, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(278, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(278, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(279, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(279, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(279, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(279, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(279, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(279, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(279, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(279, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(279, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(279, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(279, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(279, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(279, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(279, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(279, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(279, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(279, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(279, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(279, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(279, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(280, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(280, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(280, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(280, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(280, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(280, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(280, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(280, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(280, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(280, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(280, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(280, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(280, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(280, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(280, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(280, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(280, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(280, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(280, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(280, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(281, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(281, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(281, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(281, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(281, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(281, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(281, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(281, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(281, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(281, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(281, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(281, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(281, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(281, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(281, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(281, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(281, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(281, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(281, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(281, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(282, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(282, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(282, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(282, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(282, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(282, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(282, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(282, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(282, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(282, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(282, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(282, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(282, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(282, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(282, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(282, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(282, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(282, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(282, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(282, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(282, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(282, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(282, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(282, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(282, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(282, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(282, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(282, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(282, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(282, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 1, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(283, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(283, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 2, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(283, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(283, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 3, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(283, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(283, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 4, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(283, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(283, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 5, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(283, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(283, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 11, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(283, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(283, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 12, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(283, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(283, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 13, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(283, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(283, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 14, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(283, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(283, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 15, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(283, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(283, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(284, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(284, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(284, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(284, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(284, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(284, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(284, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(284, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(284, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(284, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(284, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(284, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(284, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(284, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(284, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(284, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(284, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(284, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(284, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(284, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(284, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(284, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(284, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(284, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(284, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(284, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(284, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(284, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(284, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(284, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(285, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(285, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(285, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(285, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(285, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(285, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(285, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(285, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(285, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(285, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(285, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(285, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(285, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(285, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(285, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(285, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(285, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(285, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(285, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(285, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(285, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(285, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(285, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(285, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(285, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(285, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(285, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(285, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(285, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(285, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(286, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(286, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(286, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(286, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(286, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(286, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(286, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(286, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(286, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(286, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(286, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(286, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(286, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(286, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(286, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(286, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(286, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(286, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(286, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(286, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(286, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(286, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(286, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(286, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(286, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(286, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(286, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(286, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(286, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(286, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(287, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(287, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(287, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(287, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(287, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(287, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(287, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(287, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(287, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(287, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(287, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(287, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(287, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(287, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(287, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(287, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(287, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(287, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(287, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(287, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(287, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(287, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(287, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(287, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(287, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(287, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(287, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(287, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(287, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(287, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 1, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(288, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(288, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 2, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(288, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(288, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 3, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(288, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(288, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 4, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(288, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(288, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 5, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(288, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(288, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 11, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(288, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(288, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 12, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(288, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(288, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 13, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(288, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(288, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 14, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(288, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(288, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 15, 11, NULL, NULL, 3, '20000', NULL, 0, NULL, NULL, NULL),
	(288, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(288, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(290, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(290, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(290, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(290, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(290, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(290, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(290, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(290, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(290, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(290, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(290, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(290, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(290, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(290, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(290, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(290, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(290, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(290, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(290, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(290, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(291, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(291, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(291, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(291, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(291, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(291, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(291, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(291, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(291, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(291, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(291, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(291, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(291, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(291, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(291, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(291, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(291, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(291, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(291, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(291, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(291, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(291, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(291, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(291, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(291, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(291, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(291, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(291, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(291, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(291, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(292, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(292, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(292, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(292, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(292, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(292, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(292, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(292, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(292, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(292, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(292, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(292, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(292, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(292, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(292, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(293, 1, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(293, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(293, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(293, 2, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(293, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(293, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(293, 3, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(293, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(293, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(293, 4, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(293, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(293, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(293, 5, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(293, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(293, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(293, 11, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(293, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(293, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(293, 12, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(293, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(293, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(293, 13, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(293, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(293, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(293, 14, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(293, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(293, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(293, 15, 11, NULL, NULL, 3, '500', NULL, 0, NULL, NULL, NULL),
	(293, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(293, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(294, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(294, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(294, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(294, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(294, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(294, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(294, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(294, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(294, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(294, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(294, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(294, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(294, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(294, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(294, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(294, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(294, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(294, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(294, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(294, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(294, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(294, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(294, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(294, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(294, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(294, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(294, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(294, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(294, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(294, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(295, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(295, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(295, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(295, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(295, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(295, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(295, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(295, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(295, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(295, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(295, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(295, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(295, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(295, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(295, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(295, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(295, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(295, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(295, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(295, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(295, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(295, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(295, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(295, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(295, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(295, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(295, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(295, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(295, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(295, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(296, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(296, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(296, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(296, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(296, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(296, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(296, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(296, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(296, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(296, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(296, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(296, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(296, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(296, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(296, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(296, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(296, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(296, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(296, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(296, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(296, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(296, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(296, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(296, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(296, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(296, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(296, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(296, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(296, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(296, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(299, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(299, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(299, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(299, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(299, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(299, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(299, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(299, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(299, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(299, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(299, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(299, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(299, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(299, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(299, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(299, 10, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(299, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(299, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(299, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(299, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(299, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(299, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(299, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(299, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(299, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(299, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(299, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(299, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(299, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(299, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(299, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(299, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(299, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(300, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(300, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 1, 478, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(300, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(300, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(300, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 2, 478, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(300, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(300, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(300, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 3, 478, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(300, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(300, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(300, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 4, 478, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(300, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(300, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(300, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 5, 478, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(300, 10, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(300, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(300, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 10, 478, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(300, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(300, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(300, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 11, 478, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(300, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(300, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(300, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 12, 478, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(300, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(300, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(300, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 13, 478, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(300, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(300, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(300, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 14, 478, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(300, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(300, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(300, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 15, 478, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(301, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(301, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(301, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(301, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(301, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(301, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(301, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(301, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(301, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(301, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(301, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(301, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(301, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(301, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(301, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(301, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(301, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(301, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(301, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(301, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(301, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(301, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(301, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(301, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(301, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(301, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(301, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(301, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(301, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(301, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(303, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(303, 1, 17, 877, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(303, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(303, 2, 17, 877, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(303, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(303, 3, 17, 877, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(303, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(303, 4, 17, 877, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(303, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(303, 5, 17, 877, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(303, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(303, 11, 17, 877, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(303, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(303, 12, 17, 877, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(303, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(303, 13, 17, 877, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(303, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(303, 14, 17, 877, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(303, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(303, 15, 17, 877, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(306, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(306, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(306, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(306, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(306, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(306, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(306, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(306, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(306, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(306, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(306, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(306, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(306, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(306, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(306, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(306, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(306, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(306, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(306, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(306, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(307, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(307, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(307, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(307, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(307, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(307, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(307, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(307, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(307, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(307, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(307, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(307, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(307, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(307, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(307, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(307, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(307, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(307, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(307, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(307, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(308, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(308, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(308, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(308, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(308, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(308, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(308, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(308, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(308, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(308, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(308, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(308, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(308, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(308, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(308, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(308, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(308, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(308, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(308, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(308, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(337, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(337, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(337, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(337, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(337, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(337, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(337, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(337, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(337, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(337, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(337, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(337, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(337, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(337, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(337, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(337, 10, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(337, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(337, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(337, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(337, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(337, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(337, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(337, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(337, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(337, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(337, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(337, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(337, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(337, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(337, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(337, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(337, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(337, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(338, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(338, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(338, 1, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(338, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(338, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(338, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(338, 2, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(338, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(338, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(338, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(338, 3, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(338, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(338, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(338, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(338, 4, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(338, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(338, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(338, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(338, 5, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(338, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(338, 10, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(338, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(338, 10, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(338, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(338, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(338, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(338, 11, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(338, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(338, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(338, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(338, 12, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(338, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(338, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(338, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(338, 13, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(338, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(338, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(338, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(338, 14, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(338, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(338, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(338, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(338, 15, 17, 124, NULL, 3, 'MBUS', NULL, 0, NULL, NULL, NULL),
	(338, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(339, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(339, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(339, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(339, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(339, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(339, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(339, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(339, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(339, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(339, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(339, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(340, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(340, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(340, 1, 17, 887, NULL, 3, 'MODBUSTCP', NULL, 0, NULL, NULL, NULL),
	(340, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(340, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(340, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(340, 2, 17, 887, NULL, 3, 'MODBUSTCP', NULL, 0, NULL, NULL, NULL),
	(340, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(340, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(340, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(340, 3, 17, 887, NULL, 3, 'MODBUSTCP', NULL, 0, NULL, NULL, NULL),
	(340, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(340, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(340, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(340, 4, 17, 887, NULL, 3, 'MODBUSTCP', NULL, 0, NULL, NULL, NULL),
	(340, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(340, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(340, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(340, 5, 17, 887, NULL, 3, 'MODBUSTCP', NULL, 0, NULL, NULL, NULL),
	(340, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(340, 10, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(340, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(340, 10, 17, 887, NULL, 3, 'MODBUSTCP', NULL, 0, NULL, NULL, NULL),
	(340, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(340, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(340, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(340, 11, 17, 887, NULL, 3, 'MODBUSTCP', NULL, 0, NULL, NULL, NULL),
	(340, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(340, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(340, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(340, 12, 17, 887, NULL, 3, 'MODBUSTCP', NULL, 0, NULL, NULL, NULL),
	(340, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(340, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(340, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(340, 13, 17, 887, NULL, 3, 'MODBUSTCP', NULL, 0, NULL, NULL, NULL),
	(340, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(340, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(340, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(340, 14, 17, 887, NULL, 3, 'MODBUSTCP', NULL, 0, NULL, NULL, NULL),
	(340, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(340, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(340, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(340, 15, 17, 887, NULL, 3, 'MODBUSTCP', NULL, 0, NULL, NULL, NULL),
	(340, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(341, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(341, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(341, 1, 17, 887, NULL, 3, 'MODBUS', 'MODBUSTCP', 0, NULL, NULL, NULL),
	(341, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(341, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(341, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(341, 2, 17, 887, NULL, 3, 'MODBUS', 'MODBUSTCP', 0, NULL, NULL, NULL),
	(341, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(341, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(341, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(341, 3, 17, 887, NULL, 3, 'MODBUS', 'MODBUSTCP', 0, NULL, NULL, NULL),
	(341, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(341, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(341, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(341, 4, 17, 887, NULL, 3, 'MODBUS', 'MODBUSTCP', 0, NULL, NULL, NULL),
	(341, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(341, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(341, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(341, 5, 17, 887, NULL, 3, 'MODBUS', 'MODBUSTCP', 0, NULL, NULL, NULL),
	(341, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(341, 10, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(341, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(341, 10, 17, 887, NULL, 3, 'MODBUS', 'MODBUSTCP', 0, NULL, NULL, NULL),
	(341, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(341, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(341, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(341, 11, 17, 887, NULL, 3, 'MODBUS', 'MODBUSTCP', 0, NULL, NULL, NULL),
	(341, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(341, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(341, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(341, 12, 17, 887, NULL, 3, 'MODBUS', 'MODBUSTCP', 0, NULL, NULL, NULL),
	(341, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(341, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(341, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(341, 13, 17, 887, NULL, 3, 'MODBUS', 'MODBUSTCP', 0, NULL, NULL, NULL),
	(341, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(341, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(341, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(341, 14, 17, 887, NULL, 3, 'MODBUS', 'MODBUSTCP', 0, NULL, NULL, NULL),
	(341, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(341, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(341, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(341, 15, 17, 887, NULL, 3, 'MODBUS', 'MODBUSTCP', 0, NULL, NULL, NULL),
	(341, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(342, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(342, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(342, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(342, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(342, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(342, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(342, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(342, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(342, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(342, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(342, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(342, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(342, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(342, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(342, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(342, 10, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(342, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(342, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(342, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(342, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(342, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(342, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(342, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(342, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(342, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(342, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(342, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(342, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(342, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(342, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(342, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(342, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(342, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(344, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(344, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 1, 503, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(344, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(344, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(344, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 2, 503, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(344, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(344, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(344, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 3, 503, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(344, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(344, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(344, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 4, 503, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(344, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(344, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(344, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 5, 503, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(344, 10, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(344, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(344, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 10, 503, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(344, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(344, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(344, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 11, 503, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(344, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(344, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(344, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 12, 503, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(344, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(344, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(344, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 13, 503, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(344, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(344, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(344, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 14, 503, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(344, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(344, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(344, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 15, 503, NULL, NULL, 3, '0', NULL, 0, NULL, NULL, NULL),
	(346, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(346, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(346, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(346, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(346, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(346, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(346, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(346, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(346, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(346, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(346, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(346, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(346, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(346, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(346, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(346, 10, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(346, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(346, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(346, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(346, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(346, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(346, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(346, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(346, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(346, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(346, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(346, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(346, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(346, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(346, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(346, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(346, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(346, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(348, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(348, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(348, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(348, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(348, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(348, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(348, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(348, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(348, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(348, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(348, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(348, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(348, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(348, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(348, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(349, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(349, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(349, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(349, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(349, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(349, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(349, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(349, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(349, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(349, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(352, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(352, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(352, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(352, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(352, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(352, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(352, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(352, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(352, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(352, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(352, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(352, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(352, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(352, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(352, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(352, 10, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(352, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(352, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(352, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(352, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(352, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(352, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(352, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(352, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(352, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(352, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(352, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(352, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(352, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(352, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(352, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(352, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(352, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(353, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(353, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 1, 505, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 1, 506, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(353, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(353, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 2, 505, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 2, 506, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(353, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(353, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 3, 505, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 3, 506, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(353, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(353, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 4, 505, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 4, 506, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(353, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(353, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 5, 505, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 5, 506, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 10, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(353, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(353, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 10, 505, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 10, 506, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(353, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(353, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 11, 505, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 11, 506, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(353, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(353, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 12, 505, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 12, 506, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(353, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(353, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 13, 505, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 13, 506, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(353, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(353, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 14, 505, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 14, 506, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(353, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(353, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 15, 505, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(353, 15, 506, 82, NULL, 3, '1', NULL, 0, NULL, NULL, NULL),
	(354, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(354, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(354, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(354, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(354, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(354, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(354, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(354, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(354, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(354, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(354, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(354, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(354, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(354, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(354, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(354, 10, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(354, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(354, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(354, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(354, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(354, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(354, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(354, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(354, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(354, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(354, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(354, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(354, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(354, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(354, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(354, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(354, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(354, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(356, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(356, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(356, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(356, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(356, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(356, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(356, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(356, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(356, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(356, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(356, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(356, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(356, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(356, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(356, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(356, 10, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(356, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(356, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(356, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(356, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(356, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(356, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(356, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(356, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(356, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(356, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(356, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(356, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(356, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(356, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(356, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(356, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(356, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(357, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(357, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(357, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(357, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(357, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(357, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(357, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(357, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(357, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(357, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(357, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(357, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(357, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(357, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(357, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(357, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(357, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(357, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(357, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(357, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(358, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(358, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(358, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(358, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(358, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(358, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(358, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(358, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(358, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(358, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(358, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(358, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(358, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(358, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(358, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(358, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(358, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(358, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(358, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(358, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(359, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(359, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(359, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(359, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(359, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(359, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(359, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(359, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(359, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(359, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(359, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(359, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(359, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(359, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(359, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(359, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(359, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(359, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(359, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(359, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(360, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(360, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(360, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(360, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(360, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(360, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(360, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(360, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(360, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(360, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(360, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(360, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(360, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(360, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(360, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(360, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(360, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(360, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(360, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(360, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(361, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(361, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(361, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(361, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(361, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(361, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(361, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(361, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(361, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(361, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(361, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(361, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(361, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(361, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(361, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(361, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(361, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(361, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(361, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(361, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(362, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(362, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(362, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(362, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(362, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(362, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(362, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(362, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(362, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(362, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(362, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(362, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(362, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(362, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(362, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(362, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(362, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(362, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(362, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(362, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(363, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(363, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(363, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(363, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(363, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(363, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(363, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(363, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(363, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(363, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 10, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(363, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(363, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(363, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(363, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(363, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(363, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(363, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(363, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(363, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(363, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(363, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(363, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(364, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(364, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(364, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(364, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(364, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(364, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(364, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(364, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(364, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(364, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(364, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(364, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(364, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(364, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(364, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(364, 10, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(364, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(364, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(364, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(364, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(364, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(364, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(364, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(364, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(364, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(364, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(364, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(364, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(364, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(364, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(364, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(364, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(364, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(365, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(365, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(365, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(365, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(365, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(365, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(365, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(365, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(365, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(365, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(365, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(365, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(365, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(365, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(365, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(365, 10, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(365, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(365, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(365, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(365, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(365, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(365, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(365, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(365, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(365, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(365, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(365, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(365, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(365, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(365, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(365, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(365, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(365, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(366, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(366, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(366, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(366, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(366, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(366, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(366, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(366, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(366, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(366, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(366, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(366, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(366, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(366, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(366, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(366, 10, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(366, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(366, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(366, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(366, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(366, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(366, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(366, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(366, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(366, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(366, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(366, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(366, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(366, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(366, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(366, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(366, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(366, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(367, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(367, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(367, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(367, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(367, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(367, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(367, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(367, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(367, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(367, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 10, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(367, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(367, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(367, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(367, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(367, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(367, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(367, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(367, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(367, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(367, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(367, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(367, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(369, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(369, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(369, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(369, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(369, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(369, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(369, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(369, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(369, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(369, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(369, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(369, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(369, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(369, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(369, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(369, 10, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(369, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(369, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(369, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(369, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(369, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(369, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(369, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(369, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(369, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(369, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(369, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(369, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(369, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(369, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(369, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(369, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(369, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(370, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(370, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(370, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(370, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(370, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(370, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(370, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(370, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(370, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(370, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 10, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(370, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(370, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(370, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(370, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(370, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(370, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(370, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(370, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(370, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(370, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(370, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(370, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(371, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(371, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(371, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(371, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(371, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(371, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(371, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(371, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(371, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(371, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 10, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(371, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(371, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(371, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(371, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(371, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(371, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(371, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(371, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(371, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(371, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(371, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(371, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(372, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(372, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(372, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(372, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(372, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(372, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(372, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(372, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(372, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(372, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 10, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(372, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(372, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(372, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(372, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(372, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(372, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(372, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(372, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(372, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(372, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(372, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(372, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(373, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(373, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(373, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(373, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(373, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(373, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(373, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(373, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(373, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(373, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(373, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(373, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(373, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(373, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(373, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(373, 10, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(373, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(373, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(373, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(373, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(373, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(373, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(373, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(373, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(373, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(373, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(373, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(373, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(373, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(373, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(373, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(373, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(373, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(374, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(374, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(374, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(374, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(374, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(374, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(374, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(374, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(374, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(374, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(374, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(374, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(374, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(374, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(374, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(374, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(374, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(374, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(374, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(374, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(375, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(375, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(375, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(375, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(375, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(375, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(375, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(375, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(375, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(375, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(375, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(375, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(375, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(375, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(375, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(375, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(375, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(375, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(375, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(375, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(376, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(376, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(376, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(376, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(376, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(376, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(376, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(376, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(376, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(376, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(376, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(376, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(376, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(376, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(376, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(376, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(376, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(376, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(376, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(376, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(377, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(377, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(377, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(377, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(377, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(377, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(377, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(377, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(377, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(377, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(377, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(377, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(377, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(377, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(377, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(377, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(377, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(377, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(377, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(377, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(378, 1, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(378, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(378, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(378, 2, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(378, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(378, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(378, 3, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(378, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(378, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(378, 4, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(378, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(378, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(378, 5, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(378, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(378, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(378, 10, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(378, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(378, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(378, 11, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(378, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(378, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(378, 12, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(378, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(378, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(378, 13, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(378, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(378, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(378, 14, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(378, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(378, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(378, 15, 11, NULL, NULL, 3, '1500', NULL, 0, NULL, NULL, NULL),
	(378, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(378, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(379, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(379, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(379, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(379, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(379, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(379, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(379, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(379, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(379, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(379, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(379, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(379, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(379, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(379, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(379, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(379, 10, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(379, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(379, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(379, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(379, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(379, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(379, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(379, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(379, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(379, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(379, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(379, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(379, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(379, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(379, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(379, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(379, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(379, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(381, 1, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(381, 1, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(381, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(381, 2, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(381, 2, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(381, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(381, 3, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(381, 3, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(381, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(381, 4, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(381, 4, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(381, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(381, 5, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(381, 5, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(381, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(381, 10, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(381, 10, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(381, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(381, 11, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(381, 11, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(381, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(381, 12, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(381, 12, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(381, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(381, 13, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(381, 13, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(381, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(381, 14, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(381, 14, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(381, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(381, 15, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(381, 15, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(381, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 1, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(382, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(382, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 2, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(382, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(382, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 3, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(382, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(382, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 4, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(382, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(382, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 5, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(382, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(382, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 10, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(382, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(382, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 11, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(382, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(382, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 12, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(382, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(382, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 13, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(382, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(382, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 14, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(382, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(382, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 15, 11, NULL, NULL, 3, '2000', NULL, 0, NULL, NULL, NULL),
	(382, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(382, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(383, 1, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(383, 1, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(383, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(383, 2, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(383, 2, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(383, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(383, 3, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(383, 3, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(383, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(383, 4, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(383, 4, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(383, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(383, 5, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(383, 5, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(383, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(383, 10, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(383, 10, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(383, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(383, 11, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(383, 11, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(383, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(383, 12, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(383, 12, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(383, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(383, 13, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(383, 13, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(383, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(383, 14, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(383, 14, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(383, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(383, 15, 11, NULL, NULL, 3, '1000', NULL, 0, NULL, NULL, NULL),
	(383, 15, 12, NULL, NULL, 3, '2', NULL, 0, NULL, NULL, NULL),
	(383, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(384, 1, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(384, 1, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(384, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(384, 2, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(384, 2, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(384, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(384, 3, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(384, 3, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(384, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(384, 4, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(384, 4, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(384, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(384, 5, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(384, 5, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(384, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(384, 10, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(384, 10, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(384, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(384, 11, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(384, 11, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(384, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(384, 12, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(384, 12, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(384, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(384, 13, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(384, 13, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(384, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(384, 14, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(384, 14, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(384, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(384, 15, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(384, 15, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(384, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(385, 1, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(385, 1, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(385, 1, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(385, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(385, 2, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(385, 2, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(385, 2, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(385, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(385, 3, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(385, 3, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(385, 3, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(385, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(385, 4, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(385, 4, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(385, 4, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(385, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(385, 5, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(385, 5, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(385, 5, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(385, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(385, 10, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(385, 10, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(385, 10, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(385, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(385, 11, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(385, 11, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(385, 11, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(385, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(385, 12, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(385, 12, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(385, 12, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(385, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(385, 13, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(385, 13, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(385, 13, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(385, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(385, 14, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(385, 14, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(385, 14, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(385, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(385, 15, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(385, 15, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(385, 15, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(385, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(386, 1, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(386, 1, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(386, 1, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(386, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(386, 2, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(386, 2, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(386, 2, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(386, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(386, 3, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(386, 3, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(386, 3, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(386, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(386, 4, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(386, 4, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(386, 4, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(386, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(386, 5, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(386, 5, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(386, 5, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(386, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(386, 10, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(386, 10, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(386, 10, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(386, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(386, 11, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(386, 11, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(386, 11, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(386, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(386, 12, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(386, 12, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(386, 12, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(386, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(386, 13, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(386, 13, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(386, 13, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(386, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(386, 14, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(386, 14, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(386, 14, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(386, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(386, 15, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(386, 15, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(386, 15, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(386, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(387, 1, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(387, 1, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(387, 1, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(387, 1, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(387, 2, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(387, 2, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(387, 2, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(387, 2, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(387, 3, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(387, 3, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(387, 3, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(387, 3, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(387, 4, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(387, 4, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(387, 4, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(387, 4, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(387, 5, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(387, 5, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(387, 5, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(387, 5, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(387, 10, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(387, 10, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(387, 10, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(387, 10, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(387, 11, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(387, 11, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(387, 11, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(387, 11, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(387, 12, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(387, 12, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(387, 12, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(387, 12, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(387, 13, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(387, 13, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(387, 13, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(387, 13, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(387, 14, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(387, 14, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(387, 14, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(387, 14, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL),
	(387, 15, 11, NULL, NULL, 3, '1500', NULL, 1, NULL, NULL, NULL),
	(387, 15, 12, NULL, NULL, 3, '2', NULL, 1, NULL, NULL, NULL),
	(387, 15, 17, 1034, NULL, 3, 'GazModem2', NULL, 0, NULL, NULL, NULL),
	(387, 15, 103, NULL, NULL, 3, NULL, NULL, 0, NULL, NULL, NULL);
/*!40000 ALTER TABLE `sp_type_lpty` ENABLE KEYS */;

-- Dumping structure for table emcor.src
CREATE TABLE IF NOT EXISTS `src` (
  `src_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Duomenų šaltinio identifikatorius',
  `src_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Šaltinio pavadinimas',
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `dl_type_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų išdėstymo tipo identifikatorius',
  `src_bt` datetime DEFAULT NULL COMMENT 'Šaltinio galiojimo pradžia',
  `src_et` datetime DEFAULT NULL COMMENT 'Šaltinio galiojimo pabaiga',
  `src_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Duomenų šaltinio naudojimo požymis',
  `tz_id` smallint(5) unsigned NOT NULL COMMENT 'Laiko zonos identifikatorius',
  `src_tz_dst_used` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Vasaros laiko naudojimo požymis',
  `src_save_statistics` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Statistikos rinkimo požymis duomenų šaltiniui',
  `point_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo taško identifikatorius',
  `src_tmpl_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinių šablono ID',
  `src_number` varchar(20) COLLATE utf8_bin DEFAULT NULL COMMENT 'Šaltinio numeris',
  `src_dir_inv` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Invertuoti per šaltinį nuskaitomų matavimų energijos tėkmės kryptį',
  PRIMARY KEY (`src_id`),
  UNIQUE KEY `src_dp_src_name_u` (`dp_id`,`src_bt`,`src_et`,`src_name`),
  KEY `src_dl_type_i` (`dl_type_id`),
  KEY `src_point_i` (`point_id`),
  KEY `src_src_type_i` (`src_type_id`),
  KEY `src_src_tmpl_i` (`src_tmpl_id`),
  KEY `src_tz_i` (`tz_id`),
  CONSTRAINT `src_dl_type_fk` FOREIGN KEY (`dl_type_id`) REFERENCES `dl_type` (`dl_type_id`),
  CONSTRAINT `src_dp_fk` FOREIGN KEY (`dp_id`) REFERENCES `dp` (`dp_id`) ON DELETE CASCADE,
  CONSTRAINT `src_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `src_src_tmpl_fk` FOREIGN KEY (`src_tmpl_id`) REFERENCES `src_tmpl` (`src_tmpl_id`) ON DELETE SET NULL,
  CONSTRAINT `src_src_type_fk` FOREIGN KEY (`src_type_id`) REFERENCES `src_type` (`src_type_id`),
  CONSTRAINT `src_tz_fk` FOREIGN KEY (`tz_id`) REFERENCES `tz` (`tz_id`)
) ENGINE=InnoDB AUTO_INCREMENT=1415 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų šaltiniai';

-- Dumping data for table emcor.src: ~470 rows (approximately)
/*!40000 ALTER TABLE `src` DISABLE KEYS */;
INSERT INTO `src` (`src_id`, `src_name`, `dp_id`, `src_type_id`, `dl_type_id`, `src_bt`, `src_et`, `src_enabled`, `tz_id`, `src_tz_dst_used`, `src_save_statistics`, `point_id`, `src_tmpl_id`, `src_number`, `src_dir_inv`) VALUES
	(467, 'A+ energijos per mėnesį rodmenų generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(468, 'A+ energijos per parą rodmenų generavimas iš valandinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(470, 'Karšto vandens tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(471, 'Karšto vandens tūrio kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(472, 'Šilumnešio tūrio kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(473, 'Šilumnešio šilumos kiekio per parą rodmenų generavimas iš vidutinės šilumos galios per valandą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(474, 'Vidutinio karšto vandens tūrio debito per valandą rodmenų generavimas iš augančių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(475, 'Vidutinio šilumnešio tūrio debito per valandą rodmenų generavimas iš augančių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(476, 'Vidutinio tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumo per parą rodmenų generavimas iš valandinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(477, 'Vidutinio tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumo per valandą rodmenų generavimas iš momentinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(478, 'Vidutinio šalto vandens tūrio debito per 15 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(479, 'Vidutinio šalto vandens tūrio debito per valandą rodmenų generavimas iš augančių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(480, 'Vidutinio šalto vandens tūrio debito per valandą rodmenų generavimas iš vidutinio debito reikšmių per 15 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(481, 'Vidutinės P+ galios per valandą rodmenų generavimas iš vidutinės galios per 30 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(482, 'Vidutinės grįžtamo šilumnešio temperatūros per parą rodmenų generavimas iš valandinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(483, 'Vidutinės grįžtamo šilumnešio temperatūros per valandą rodmenų generavimas iš momentinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(484, 'Vidutinės oro temperatūros per parą rodmenų generavimas iš vidutinės oro temperatūros per valandą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(485, 'Vidutinės oro temperatūros per valandą rodmenų generavimas iš vidutinės oro temperatūros per 15 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(486, 'Vidutinės šilumnešio šilumos galios per valandą rodmenų generavimas iš augančių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(487, 'Vidutinės tiekiamo šilumnešio temperatūros per parą rodmenų generavimas iš valandinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(488, 'Vidutinės tiekiamo šilumnešio temperatūros per valandą rodmenų generavimas iš momentinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(489, 'Šalto vandens tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(490, 'Šalto vandens tūrio kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(491, 'Šilumnešio temperatūrų grafiko rodmenų generavimas pagal lauko temperatūros duomenis', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(492, 'Šilumos teorinės rodmenų generavimas pagal lauko temperatūros duomenis', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(493, 'Vidutinės P+ galios per valandą rodmenų generavimas iš augančių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(522, 'Vidutinio dujų tūrio debito per valandą rodmenų generavimas iš augančių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(523, 'Dujų tūrio kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(524, 'Dujų tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(525, 'Vidutinio dujų koreguoto tūrio debito per valandą rodmenų generavimas iš augančių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(526, 'Dujų koreguoto tūrio kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(527, 'Dujų koreguoto tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(544, 'Vidutinio karšto vandens tūrio debito per 15 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(545, 'Vidutinio karšto vandens tūrio debito per valandą rodmenų generavimas iš vidutinio debito reikšmių per 15 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(565, 'Suminių rodmenų proporcingas generavimas iš gretimų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(622, 'Vidutinės tiekiamo šilumnešio temperatūros per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(623, 'Vidutinės grįžtamo šilumnešio temperatūros per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(626, 'Vidutinės šilumnešio šilumos galios per 15 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(627, 'Vidutinės šilumnešio šilumos galios per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(628, 'Vidutinio dujų koreguoto tūrio debito per 15 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(629, 'Vidutinio dujų koreguoto tūrio debito per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(652, 'Vidutinės P+ galios per valandą rodmenų generavimas iš vidutinės galios per 5 minutes', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(653, 'Vidutinės Q+ galios per valandą rodmenų generavimas iš vidutinės galios per 5 minutes', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(654, 'Vidutinės Q- galios per valandą rodmenų generavimas iš vidutinės galios per 5 minutes', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(667, 'Vidutinės P+ galios per 15 minučių rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(668, 'Vidutinės P+ galios per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(702, 'Vidutinio dujų koreguoto tūrio debito per valandą rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(703, 'Vidutinės šilumnešio šilumos galios per val. rodmenų generavimas iš aug. reikšmių, užfiksuotų kas 15 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(704, 'Vidutinio šalto vandens tūrio debito per valandą rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(705, 'Vidutinės P+ galios per valandą rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(706, 'Vidutinio karšto vandens tūrio debito per valandą rodmenų generavimas iš augančių reikšmių, užfiksuotų kas 15 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(712, 'Vidutinės Q+ galios per 30 minučių rodmenų generavimas iš reikšmių pagal kvadrantus Q1 ir Q2', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(713, 'Vidutinės Q- galios per 30 minučių rodmenų generavimas iš reikšmių pagal kvadrantus Q3 ir Q4', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(732, 'R- energijos per mėnesį rodmenų generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(733, 'R+ energijos per mėnesį rodmenų generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(734, 'A- energijos per mėnesį rodmenų generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(735, 'Vidutinio tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumo per valandą generavimas iš vidutinių 15 min. reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(736, 'Pusvalandinės vidutinės P+ galios duomenų generavimas iš užfiksuotų kas 30 min. A+ suminių duomenų', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(758, 'A- energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(759, 'R+ energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(760, 'R- energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(761, 'R1 energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(762, 'R2 energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(763, 'R3 energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(764, 'R4 energijos per parą rodmenų generavimas, sumuojant visų tarifų energiją per parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(766, 'A- energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(767, 'R+ energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(768, 'R- energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(769, 'R1 energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(770, 'R2 energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(771, 'R3 energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(772, 'R4 energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(777, 'Vidutinės P+ galios per 30 minučių rodmenų generavimas iš vidutinės galios per 3 minutes', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(778, 'Vidutinės P- galios per 30 minučių rodmenų generavimas iš vidutinės galios per 3 minutes', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(779, 'Vidutinės P+ galios per valandą rodmenų generavimas iš esamų valandinių ir augančių pagal tarifus reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(782, 'R- energijos per parą rodmenų generavimas is valandinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(783, 'R+ energijos per parą rodmenų generavimas is valandinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(784, 'A- energijos per parą rodmenų generavimas is valandinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(833, 'Šilumnešio tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(834, 'Šilumnešio šilumos kiekio per mėnesį rodmenų generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(835, 'Vidutinio šilumnešio tūrio debito per val. rodmenų generavimas iš aug. reikšmių, užfiksuotų kas 15 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(842, 'Dujų koreguoto tūrio kiekio per parą rodmenų generavimas iš valandinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(912, 'Vidutinės P+ galios per valandą rodmenų generavimas iš augančių reikšmių, užfiksuotų kas valandą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(937, 'Elektros pilnosios galios S+ per 30 minučių duomenų generavimas iš P+ ir Q+', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(942, 'Elektros pilnosios galios S+ per valandą duomenų generavimas iš P+ ir Q+', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(962, 'Vidutinės P- galios per valandą rodmenų generavimas iš vidutinės galios per 30 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(963, 'Vidutinės Q+ galios per valandą rodmenų generavimas iš vidutinės galios per 30 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(964, 'Vidutinės Q- galios per valandą rodmenų generavimas iš vidutinės galios per 30 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(994, 'Rodmenų generavimas pagal atnaujintų periodų informaciją', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1002, 'Vidutinės P+ galios per 30 min. rodmenų generavimas iš augančių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1003, 'A+ energijos per parą rodmenų generavimas iš vidutinių reikšmių per 30 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1004, 'A- energijos per parą rodmenų generavimas iš vidutinių reikšmių per 30 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1005, 'R+ energijos per parą rodmenų generavimas iš vidutinių reikšmių per 30 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1006, 'R- energijos per parą rodmenų generavimas iš vidutinių reikšmių per 30 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1007, 'A+ energijos per parą rodmenų generavimas iš augančių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1008, 'A+ energijos per parą rodmenų generavimas iš visų tarifų energijų sumos', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1012, 'A- energijos per parą rodmenų generavimas iš augančių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1013, 'R+ energijos per parą rodmenų generavimas iš augančių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1014, 'R- energijos per parą rodmenų generavimas iš augančių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1017, 'Suminės A+ energijos rodmenų generavimas iš visų tarifų sumų', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1018, 'Suminės A- energijos rodmenų generavimas iš visų tarifų sumų', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1019, 'Suminės R+ energijos rodmenų generavimas iš visų tarifų sumų', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1020, 'Suminės R- energijos rodmenų generavimas iš visų tarifų sumų', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1021, 'Suminės R1 energijos rodmenų generavimas iš visų tarifų sumų', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1022, 'Suminės R2 energijos rodmenų generavimas iš visų tarifų sumų', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1023, 'Suminės R3 energijos rodmenų generavimas iš visų tarifų sumų', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1024, 'Suminės R4  energijos rodmenų generavimas iš visų tarifų sumų', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1025, 'Vidutinio šalto vandens tūrio debito per val. rodmenų generavimas iš tūrio kiekio, fiksuojamo kas valandą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1026, 'Vidutinio karšto vandens tūrio debito per val. rodmenų generavimas iš tūrio kiekio, fiksuojamo kas valandą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1027, 'Suminės A+ energijos rodmenų generavimas iš visų tarifų sumų, fiksuotų kas val.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1028, 'A+ energijos pagal 1 tarifą per mėnesį rodmenų generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1029, 'A+ energijos pagal 2 tarifą per mėnesį rodmenų generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1030, 'A+ energijos pagal 3 tarifą per mėnesį rodmenų generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1031, 'A+ energijos pagal 4 tarifą per mėnesį rodmenų generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1032, 'A+ energijos pagal 1 tarifą per parą rodmenų generavimas iš fiksuotų kas valandą suminių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1033, 'A+ energijos pagal 2 tarifą per parą rodmenų generavimas iš fiksuotų kas valandą suminių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1034, 'A+ energijos pagal 3 tarifą per parą rodmenų generavimas iš fiksuotų kas valandą suminių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1035, 'A+ energijos pagal 4 tarifą per parą rodmenų generavimas iš fiksuotų kas valandą suminių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1036, 'Vidutinės P- galios per valandą rodmenų generavimas tiekimo taškams už 2 įvadų su transformatoriais', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1037, 'Vidutinės P- galios per valandą rodmenų generavimas tiekimo taškams įskaitant linijos nuostolius', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1038, 'Vidutinės P- galios per valandą rodmenų generavimas tiekimo taškams įskaitant transformatoriaus nuostolius', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1039, 'Vidutinės P- galios per 30 min. rodmenų generavimas tiekimo taškams įskaitant transformatoriaus nuostolius', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1040, 'Vidutinės P- galios per val. rodmenų generavimas tiekimo taškams už 2 įvadų su transformatoriais, 2 įvadas nutolęs', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1041, 'Vidutinės P- galios per 30 min. rodmenų generavimas tiekimo taškams įskaitant transformatoriaus ir linijos nuostolius', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1042, 'Vidutinės P+ galios per 30min. generavimas tiekimo taškams už 2 įvadų su transformatoriais, įskaitant linijos nuostolius', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1043, 'Vidutinės P+ galios per 30min. generavimas tiekimo taškams įskaitant linijos nuostolius bei P ir Q kvadratų sumą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1044, 'Vidutinės P+ galios per 30 min. rodmenų generavimas tiekimo taškams įskaitant transformatoriaus nuostolius', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1045, 'Vidutinės P+ galios per 30min. generavimas tiekimo taškams už 2 įvadų ir transformatoriaus', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1046, 'Vidutinės Q+ galios per valandą rodmenų generavimas iš reikšmių pagal kvadrantus Q1 ir Q2', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1047, 'Vidutinės Q- galios per valandą rodmenų generavimas iš reikšmių pagal kvadrantus Q3 ir Q4', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1048, 'Vidutinio tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumo per 15 min. generavimas iš vidutinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1049, 'Vidutinio tiekiamo ir grįžtamo šilumnešio temperatūrų skirtumo per valandą generavimas iš vidutinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1051, 'Šilumnešio masės kiekio per parą rodmenų generavimas iš vidutinio debito per valandą reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1052, 'Vidutinio šilumnešio masės debito per val. rodmenų generavimas iš aug. reikšmių, užfiksuotų kas 15 minučių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1053, 'Šilumnešio masės kiekio per mėnesį rodmenų generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1056, 'A+ energijos per mėnesį rodmenų generavimas, sumuojant visų tarifų energiją per mėnesį ', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1061, 'Vidutinės P- galios per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1062, 'Vidutinės Q+ galios per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1063, 'Vidutinės Q- galios per valandą rodmenų generavimas iš vidutinių 15 minučių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1064, 'A+ energijos per parą rodmenų generavimas iš vidutinių reikšmių per 15 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1065, 'A- energijos per parą rodmenų generavimas iš vidutinių reikšmių per 15 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1066, 'R+ energijos per parą rodmenų generavimas iš vidutinių reikšmių per 15 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1067, 'R- energijos per parą rodmenų generavimas iš vidutinių reikšmių per 15 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1068, 'Šalčio energijos per mėnesį rodmenų generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1069, 'Šalčio tūrio kiekio per mėnesį rodmenų generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1070, 'Šalčio energijos per parą rodmenų generavimas iš augančių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1071, 'Šalčio tūrio kiekio per parą rodmenų generavimas iš augančių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1072, 'Vidutinės šalčio galios per val. rodmenų generavimas iš augančių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1073, 'Vidutinio šalčio tūrio debito per val. rodmenų generavimas iš augančių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1074, 'Pirminių suminių A+ energijos rodmenų generavimas iš pusvalandinių ir augančių rodmenų sumos, fiksuotų kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1075, 'Pirminių suminių A- energijos rodmenų generavimas iš pusvalandinių ir augančių rodmenų sumos, fiksuotų kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1076, 'Pirminių suminių R+ energijos rodmenų generavimas iš pusvalandinių ir augančių rodmenų sumos, fiksuotų kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1077, 'Pirminių suminių R- energijos rodmenų generavimas iš pusvalandinių ir augančių rodmenų sumos, fiksuotų kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1078, 'Parų rodmenų generavimas iš ankstesnių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1079, 'Valandinių P+ duomenų generavimas išdalinant paros sumą pagal šabloną', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1080, 'Valandinių P- duomenų generavimas išdalinant paros sumą pagal šabloną', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1081, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1082, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1083, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1084, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1085, 'Suminės betarifinės A+ energijos duomenų generavimas iš tarifinių suminių matavimų, fiksuojamų kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1086, 'Suminės betarifinės A- energijos duomenų generavimas iš tarifinių suminių matavimų, fiksuojamų kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1087, 'Suminės betarifinės R+ energijos duomenų generavimas iš tarifinių suminių matavimų, fiksuojamų kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1088, 'Suminės betarifinės R- energijos duomenų generavimas iš tarifinių suminių matavimų, fiksuojamų kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1091, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1092, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1093, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1094, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1095, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 4 tarifą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1096, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 4 tarifą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1097, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 4 tarifą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1098, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 4 tarifą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1099, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 3 tarifą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1100, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 3 tarifą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1101, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 3 tarifą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1102, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 3 tarifą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1103, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 1 tarifą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1104, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 1 tarifą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1105, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 1 tarifą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1106, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 1 tarifą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1107, 'A+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 2 tarifą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1108, 'A- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 2 tarifą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1109, 'R+ energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 2 tarifą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1110, 'R- energijos rodmenų per mėnesį generavimas iš augančių rodmenų pagal 2 tarifą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1111, 'A+ energijos rodmenų per mėnesį pagal 1 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1112, 'A- energijos rodmenų per mėnesį pagal 1 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1113, 'R+ energijos rodmenų per mėnesį pagal 1 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1114, 'R- energijos rodmenų per mėnesį pagal 1 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1115, 'A+ energijos rodmenų per mėnesį pagal 2 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1116, 'A- energijos rodmenų per mėnesį pagal 2 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1117, 'R+ energijos rodmenų per mėnesį pagal 2 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1118, 'R- energijos rodmenų per mėnesį pagal 2 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1119, 'A+ energijos rodmenų per mėnesį pagal 3 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1120, 'A- energijos rodmenų per mėnesį pagal 3 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1121, 'R+ energijos rodmenų per mėnesį pagal 3 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1122, 'R- energijos rodmenų per mėnesį pagal 3 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1123, 'A+ energijos rodmenų per mėnesį pagal 4 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1124, 'A- energijos rodmenų per mėnesį pagal 4 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1125, 'R+ energijos rodmenų per mėnesį pagal 4 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1126, 'R- energijos rodmenų per mėnesį pagal 4 tarifą generavimas iš augančių rodmenų, fiksuotų kas mėnesį', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1131, 'Šilumnešio koreguoto šilumos kiekio per parą generavimas iš valandinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1132, 'Šilumnešio koreguoto šilumos kiekio per mėnesį generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1133, 'Paros klaidos kodo rodmenų generavimas iš valandinių rodmenų', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1134, 'Vidutinės įtampos per 30 minučių rodmenų generavimas iš momentinės įtampos', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1135, 'Vidutinės įtampos 1 fazėje per 30 minučių rodmenų generavimas iš momentinės įtampos 1 fazėje', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1136, 'Vidutinės įtampos 2 fazėje per 30 minučių rodmenų generavimas iš momentinės įtampos 2 fazėje', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1137, 'Vidutinės įtampos 3 fazėje per 30 minučių rodmenų generavimas iš momentinės įtampos 3 fazėje', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1138, 'A+ energijos per parą rodmenų generavimas iš suminės A+ energijos, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1139, 'A+ energijos pagal 1 tarifą per parą rodmenų generavimas iš suminės A+ energijos pagal 1 tarifą, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1140, 'A+ energijos pagal 2 tarifą per parą rodmenų generavimas iš suminės A+ energijos pagal 2 tarifą, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1141, 'A+ energijos pagal 3 tarifą per parą rodmenų generavimas iš suminės A+ energijos pagal 3 tarifą, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1142, 'A+ energijos pagal 4 tarifą per parą rodmenų generavimas iš suminės A+ energijos pagal 4 tarifą, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1143, 'A- energijos per parą rodmenų generavimas iš suminės A- energijos, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1144, 'A- energijos pagal 1 tarifą per parą rodmenų generavimas iš suminės A- energijos pagal 1 tarifą, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1145, 'A- energijos pagal 2 tarifą per parą rodmenų generavimas iš suminės A- energijos pagal 2 tarifą, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1146, 'A- energijos pagal 3 tarifą per parą rodmenų generavimas iš suminės A- energijos pagal 3 tarifą, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1147, 'A- energijos pagal 4 tarifą per parą rodmenų generavimas iš suminės A- energijos pagal 4 tarifą, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1148, 'R+ energijos per parą rodmenų generavimas iš suminės R+ energijos, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1149, 'R+ energijos pagal 1 tarifą per parą rodmenų generavimas iš suminės R+ energijos pagal 1 tarifą, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1150, 'R+ energijos pagal 2 tarifą per parą rodmenų generavimas iš suminės R+ energijos pagal 2 tarifą, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1151, 'R+ energijos pagal 3 tarifą per parą rodmenų generavimas iš suminės R+ energijos pagal 3 tarifą, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1152, 'R+ energijos pagal 4 tarifą per parą rodmenų generavimas iš suminės R+ energijos pagal 4 tarifą, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1153, 'R- energijos per parą rodmenų generavimas iš suminės R- energijos, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1154, 'R- energijos pagal 1 tarifą per parą rodmenų generavimas iš suminės R- energijos pagal 1 tarifą, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1155, 'R- energijos pagal 2 tarifą per parą rodmenų generavimas iš suminės R- energijos pagal 2 tarifą, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1156, 'R- energijos pagal 3 tarifą per parą rodmenų generavimas iš suminės R- energijos pagal 3 tarifą, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1157, 'R- energijos pagal 4 tarifą per parą rodmenų generavimas iš suminės R- energijos pagal 4 tarifą, fiksuojamos kas parą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1158, 'Maksimalių momentinių srovės stiprumo rodmenų per valandą generavimas iš momentinių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1159, 'Minimalių momentinių srovės stiprumo rodmenų per valandą  generavimas iš momentinių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1160, 'Maksimalių momentinių srovės stiprumo rodmenų per parą generavimas iš maksimalių rodmenų per valandą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1161, 'Minimalių momentinių srovės stiprumo rodmenų per parą generavimas iš minimalių rodmenų per valandą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1162, 'Maksimalių momentinių įtampos rodmenų per valandą generavimas iš momentinių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1163, 'Minimalių momentinių įtampos rodmenų per valandą generavimas iš momentinių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1164, 'Maksimalių momentinių įtampos rodmenų per parą generavimas iš maksimalių rodmenų per valandą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1165, 'Minimalių momentinių įtampos rodmenų per parą rodmenų generavimas iš minimalių rodmenų per valandą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1166, 'Maksimalių momentinių aktyvinė galia per valandą generavimas iš momentinių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1167, 'Minimalių momentinių aktyvinė galia per valandą generavimas iš momentinių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1168, 'Maksimalių momentinių aktyvinės galios rodmenų per parą generavimas iš maksimalių rodmenų per valandą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1169, 'Minimalių momentinių aktyvinė galios rodmenų per parą generavimas iš minimalių rodmenų per valandą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1170, 'Maksimalių momentinių reaktyvinės galios per valandą rodmenų generavimas iš momentinių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1171, 'Minimalių momentinių reaktyvinės galios per valandą rodmenų generavimas iš momentinių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1172, 'Maksimalių momentinių reaktyvinės galios rodmenų per parą generavimas iš maksimalių rodmenų per valandą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1173, 'Minimalių momentinių reaktyvinės galios rodmenų per parą generavimas iš minimalių rodmenų per valandą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1174, 'Maksimalių momentinių cos(fi) reikšmių per valandą rodmenų generavimas iš momentinių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1175, 'Minimalių momentinių cos(fi) reikšmių per valandą rodmenų generavimas iš momentinių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1176, 'Maksimalių momentinių cos(fi) reikšmių per parą generavimas iš maksimalių reikšmių per valandą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1177, 'Minimalių momentinių cos(fi) reikšmių per parą generavimas iš minimalių reikšmių per valandą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1178, 'Maksimalių momentinių dažnis rodmenų per valandą generavimas iš momentinių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1179, 'Minimalių momentinių dažnis rodmenų per valandą generavimas iš momentinių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1180, 'Maksimalių momentinių dažnio rodmenų per parą generavimas iš maksimalių rodmenų per valandą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1181, 'Minimalių momentinių dažnio rodmenų per parą generavimas iš minimalių rodmenų per valandą', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1183, 'Vidutinės P galios per val. rodmenų generavimas iš vidutinės P galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1184, 'A energijos per 5 min. rodmenų generavimas iš suminės A energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1185, 'Vidutinės P galios per 5 min. rodmenų generavimas iš suminės A energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1186, 'A energijos per val. rodmenų generavimas iš A energijos per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1187, 'Vidutinės P+ galios per val. rodmenų generavimas iš vidutinės P+ galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1188, 'A+ energijos per 5 min. rodmenų generavimas iš suminės A+ energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1189, 'Vidutinės P+ galios per 5 min. rodmenų generavimas iš suminės A+ energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1190, 'A+ energijos per val. rodmenų generavimas iš A+ energijos per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1191, 'Vidutinės P- galios per val. rodmenų generavimas iš vidutinės P- galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1192, 'A- energijos per 5 min. rodmenų generavimas iš suminės A- energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1193, 'Vidutinės P- galios per 5 min. rodmenų generavimas iš suminės A- energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1194, 'A- energijos per val. rodmenų generavimas iš A- energijos per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1195, 'Vidutinės talpuminės galios per val. rodmenų generavimas iš vidutinės talpuminės galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1196, 'Vidutinės talpuminės galios per 5 min. rodmenų generavimas iš suminės talpuminės R energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1197, 'Talpuminės energijos per 5 min. rodmenų generavimas iš suminės talpuminės R energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1198, 'Talpuminės energijos per val. rodmenų generavimas iš talpuminės energijos per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1199, 'Vidutinės Q+ galios per val. rodmenų generavimas iš vidutinės Q+ galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1200, 'Vidutinės Q+ galios per 5 min. rodmenų generavimas iš suminės R+ energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1201, 'R+ energijos per 5 min. rodmenų generavimas iš suminės R+ energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1202, 'R+ energijos per val. rodmenų generavimas iš R+ energijos per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1203, 'Vidutinės Q- galios per val. rodmenų generavimas iš vidutinės Q- galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1204, 'R- energijos per 5 min. rodmenų generavimas iš suminės R- energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1205, 'Vidutinės Q- galios per 5 min. rodmenų generavimas iš suminės R- energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1206, 'R- energijos per val. rodmenų generavimas iš R- energijos per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1207, 'Vidutinės Q1 galios per val. rodmenų generavimas iš vidutinės Q1 galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1208, 'R1 energijos per 5 min. rodmenų generavimas iš suminės R1 energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1209, 'Vidutinės Q1 galios per 5 min. rodmenų generavimas iš suminės R1 energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1210, 'R1 energijos per val. rodmenų generavimas iš R1 energijos per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1211, 'Vidutinės Q2 galios per val. rodmenų generavimas iš vidutinės Q2 galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1212, 'R2 energijos per 5 min. rodmenų generavimas iš suminės R2 energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1213, 'Vidutinės Q2 galios per 5 min. rodmenų generavimas iš suminės R2 energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1214, 'R2 energijos per val. rodmenų generavimas iš R2 energijos per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1215, 'Vidutinės Q3 galios per val. rodmenų generavimas iš vidutinės Q3 galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1216, 'R3 energijos per 5 min. rodmenų generavimas iš suminės R3 energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1217, 'Vidutinės Q3 galios per 5 min. rodmenų generavimas iš suminės R3 energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1218, 'R3 energijos per val. rodmenų generavimas iš R3 energijos per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1219, 'Vidutinės Q4 galios per val. rodmenų generavimas iš vidutinės Q4 galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1220, 'Vidutinės Q4 galios per 5 min. rodmenų generavimas iš suminės R4 energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1221, 'R4 energijos per 5 min. rodmenų generavimas iš suminės R4 energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1222, 'R4 energijos per val. rodmenų generavimas iš R4 energijos per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1223, 'Vidutinės indukcinė galios per val. rodmenų generavimas iš vidutinės indukcinė galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1224, 'Indukcinė energijos per 5 min. rodmenų generavimas iš suminės indukcinė R energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1225, 'Vidutinės indukcinė galios per 5 min. rodmenų generavimas iš suminės indukcinė R energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1226, 'Indukcinė energijos per val. rodmenų generavimas iš Indukcinė energijos per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1227, 'Vidutinės S+ galios per val. rodmenų generavimas iš vidutinės S+ galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1228, 'Vidutinės S+ galios per 5 min. rodmenų generavimas iš suminės W+ energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1229, 'W+ energijos per 5 min. rodmenų generavimas iš suminės W+ energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1230, 'W+ energijos per val. rodmenų generavimas iš W+ energijos per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1231, 'Vidutinės S- galios per val. rodmenų generavimas iš vidutinės S- galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1232, 'Vidutinės S- galios per 5 min. rodmenų generavimas iš suminės W- energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1233, 'W- energijos per 5 min. rodmenų generavimas iš suminės W- energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1234, 'W- energijos per val. rodmenų generavimas iš W- energijos per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1235, 'Vidutinio dujų koreguotos masės debito per val. rodmenų generavimas iš vidutinio dujų koreguotos masės debito per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1236, 'Dujų koreguotos masės kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1237, 'Vidutinio dujų koreguotos masės debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1238, 'Dujų koreguotos masės kiekio per val. rodmenų generavimas iš dujų koreguotos masės kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1239, 'Vidutinio dujų koreguoto tūrio debito per val. rodmenų generavimas iš vidutinio dujų koreguoto tūrio debito per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1240, 'Dujų koreguoto tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1241, 'Vidutinio dujų koreguoto tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1242, 'Dujų koreguoto tūrio kiekio per val. rodmenų generavimas iš dujų koreguoto tūrio kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1243, 'Vidutinio dujų masės debito per val. rodmenų generavimas iš vidutinio dujų masės debito per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1244, 'Dujų masės kiekio per 5 min. rodmenų generavimas iš suminio dujų masės kiekio, fiksuojamo kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1245, 'Vidutinio dujų masės debito per 5 min. rodmenų generavimas iš suminio dujų masės kiekio, fiksuojamo kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1246, 'Dujų masės kiekio per val. rodmenų generavimas iš dujų masės kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1247, 'Vidutinės dujų šilumos galios per val. rodmenų generavimas iš vidutinės dujų šilumos galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1248, 'Dujų šilumos kiekio per 5 min. rodmenų generavimas iš suminio dujų šilumos kiekio, fiksuojamo kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1249, 'Vidutinės dujų šilumos galios per 5 min. rodmenų generavimas iš suminio dujų šilumos kiekio, fiksuojamo kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1250, 'Dujų šilumos kiekio per val. rodmenų generavimas iš dujų šilumos kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1251, 'Vidutinio dujų tūrio debito per val. rodmenų generavimas iš vidutinio dujų tūrio debito per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1252, 'Vidutinio dujų tūrio debito per 5 min. rodmenų generavimas iš suminio dujų tūrio kiekio, fiksuojamo kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1253, 'Dujų tūrio kiekio per 5 min. rodmenų generavimas iš suminio dujų tūrio kiekio, fiksuojamo kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1254, 'Dujų tūrio kiekio per val. rodmenų generavimas iš dujų tūrio kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1255, 'Vidutinės šalčio galios per val. rodmenų generavimas iš vidutinės šalčio galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1256, 'Šalčio energijos per 5 min. rodmenų generavimas iš suminės šalčio energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1257, 'Vidutinės šalčio galios per 5 min. rodmenų generavimas iš suminės šalčio energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1258, 'Šalčio energijos per val. rodmenų generavimas iš šalčio energijos per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1259, 'Vidutinės tiekiamo šalčio galios per val. rodmenų generavimas iš vidutinės tiekiamo šalčio galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1260, 'Tiekiamo šalčio energijos per 5 min. rodmenų generavimas iš suminės tiekiamo šalčio energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1261, 'Vidutinės tiekiamo šalčio galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1262, 'Tiekiamo šalčio energijos per val. rodmenų generavimas iš tiekiamo šalčio energijos per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1263, 'Vidutinės grįžtamo šalčio galios per val. rodmenų generavimas iš vidutinės grįžtamo šalčio galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1264, 'Vidutinės grįžtamo šalčio galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1265, 'Grįžtamo šalčio energijos per 5 min. rodmenų generavimas iš suminės grįžtamo šalčio energijos, fiksuojamos kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1266, 'Grįžtamo šalčio energijos per val. rodmenų generavimas iš grįžtamo šalčio energijos per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1267, 'Vidutinio šalčio tūrio debito per val. rodmenų generavimas iš vidutinio šalčio tūrio debito per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1268, 'Vidutinio šalčio tūrio debito per 5 min. rodmenų generavimas iš suminio šalčio tūrio kiekio, fiksuojamo kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1269, 'Šalčio tūrio kiekio per 5 min. rodmenų generavimas iš suminio šalčio tūrio kiekio, fiksuojamo kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1270, 'Šalčio tūrio kiekio per val. rodmenų generavimas iš šalčio tūrio kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1271, 'Vidutinio tiekiamo šalčio tūrio debito per val. rodmenų generavimas iš vidutinio tiekiamo šalčio tūrio debito per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1272, 'Tiekiamo šalčio tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1273, 'Vidutinio tiekiamo šalčio tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1274, 'Tiekiamo šalčio tūrio kiekio per val. rodmenų generavimas iš tiekiamo šalčio tūrio kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1275, 'Vidutinio grįžtamo šalčio tūrio debito per val. rodmenų generavimas iš vidutinio grįžtamo šalčio tūrio debito per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1276, 'Vidutinio grįžtamo šalčio tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1277, 'Grįžtamo šalčio tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1278, 'Grįžtamo šalčio tūrio kiekio per val. rodmenų generavimas iš grįžtamo šalčio tūrio kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1279, 'Vidutinio šilumnešio masės debito per val. rodmenų generavimas iš vidutinio šilumnešio masės debito per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1280, 'Šilumnešio masės kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1281, 'Vidutinio šilumnešio masės debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1282, 'Šilumnešio masės kiekio per val. rodmenų generavimas iš šilumnešio masės kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1283, 'Vidutinio tiekiamo šilumnešio masės debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1284, 'Vidutinio tiekiamo šilumnešio masės debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1285, 'Tiekiamo šilumnešio masės kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1286, 'Tiekiamo šilumnešio masės kiekio per val. rodmenų generavimas iš tiekiamo šilumnešio masės kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1287, 'Vidutinio grįžtamo šilumnešio masės debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1288, 'Grįžtamo šilumnešio masės kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1289, 'Vidutinio grįžtamo šilumnešio masės debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1290, 'Grįžtamo šilumnešio masės kiekio per val. rodmenų generavimas iš grįžtamo šilumnešio masės kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1291, 'Vidutinės šilumnešio šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1292, 'Šilumnešio šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1293, 'Vidutinės šilumnešio šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1294, 'Šilumnešio šilumos kiekio per val. rodmenų generavimas iš šilumnešio šilumos kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1295, 'Vidutinės tiekiamo šilumnešio šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1296, 'Tiekiamo šilumnešio šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1297, 'Vidutinės tiekiamo šilumnešio šil. galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1298, 'Tiekiamo šilumnešio šilumos kiekio per val. rodmenų generavimas iš tiekiamo šilumnešio šil. kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1299, 'Vidutinės grįžtamo šilumnešio šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1300, 'Grįžtamo šilumnešio šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1301, 'Vidutinės grįžtamo šilumnešio šil. galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1302, 'Grįžtamo šilumnešio šilumos kiekio per val. rodmenų generavimas iš grįžtamo šilumnešio šil. kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1303, 'Vidutinio šilumnešio tūrio debito per val. rodmenų generavimas iš vidutinio šilumnešio tūrio debito per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1304, 'Šilumnešio tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1305, 'Vidutinio šilumnešio tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1306, 'Šilumnešio tūrio kiekio per val. rodmenų generavimas iš šilumnešio tūrio kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1307, 'Vidutinio tiekiamo šilumnešio tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1308, 'Vidutinio tiekiamo šilumnešio tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1309, 'Tiekiamo šilumnešio tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1310, 'Tiekiamo šilumnešio tūrio kiekio per val. rodmenų generavimas iš tiekiamo šilumnešio tūrio kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1311, 'Vidutinio grįžtamo šilumnešio tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1312, 'Grįžtamo šilumnešio tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1313, 'Vidutinio grįžtamo šilumnešio tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1314, 'Grįžtamo šilumnešio tūrio kiekio per val. rodmenų generavimas iš grįžtamo šilumnešio tūrio kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1315, 'Vidutinės šalto vandens šilumos galios per val. rodmenų generavimas iš vidutinės šalto vandens šilumos galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1316, 'Vidutinės šalto vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1317, 'Šalto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1318, 'Šalto vandens šilumos kiekio per val. rodmenų generavimas iš šalto vandens šilumos kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1319, 'Vidutinės tiekiamo šalto vandens šil. galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1320, 'Tiekiamo šalto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1321, 'Vidutinės tiekiamo šalto vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1322, 'Tiekiamo šalto vandens šilumos kiekio per val. rodmenų generavimas iš tiekiamo šalto vandens šilumos kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1323, 'Vidutinės grįžtamo šalto vandens šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1324, 'Grįžtamo šalto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1325, 'Vidutinės grįžtamo šalto vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1326, 'Grįžtamo šalto vandens šilumos kiekio per val. rodmenų generavimas iš grįžtamo šalto vandens šilumos kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1327, 'Vidutinio šalto vandens tūrio debito per val. rodmenų generavimas iš vidutinio šalto vandens tūrio debito per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1328, 'Vidutinio šalto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamųkas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1329, 'Šalto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1330, 'Šalto vandens tūrio kiekio per val. rodmenų generavimas iš Šalto vandens tūrio kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1331, 'Vidutinio tiekiamo šalto vandens tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1332, 'Tiekiamo šalto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamųkas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1333, 'Vidutinio tiekiamo šalto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1334, 'Tiekiamo šalto vandens tūrio kiekio per val. rodmenų generavimas iš tiekiamo šalto vandens tūrio kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1335, 'Vidutinio grįžtamo šalto vandens tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1336, 'Vidutinio grįžtamo šalto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1337, 'Grįžtamo šalto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1338, 'Grįžtamo šalto vandens tūrio kiekio per val. rodmenų generavimas iš grįžtamo šalto vandens tūrio kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1339, 'Vidutinės karšto vandens šilumos galios per val. rodmenų generavimas iš vidutinės karšto vandens šil. galios per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1340, 'Karšto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1341, 'Vidutinės karšto vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1342, 'Karšto vandens šilumos kiekio per val. rodmenų generavimas iš karšto vandens šilumos kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1343, 'Vidutinės tiekiamo karšto vandens šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1344, 'Vidutinės tiekiamo karš. vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1345, 'Tiekiamo karšto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1346, 'Tiekiamo karšto vandens šilumos kiekio per val. rodmenų generavimas iš tiekiamo karšto vandens šilumos kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1347, 'Vidutinės grįžtamo karšto vandens šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1348, 'Vidutinės grįžtamo karš. vandens šilumos galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1349, 'Grįžtamo karšto vandens šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1350, 'Grįžtamo karšto vandens šilumos kiekio per val. rodmenų generavimas iš grįžtamo karšto vandens šilumos kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1351, 'Vidutinio karšto vandens tūrio debito per val. rodmenų generavimas iš vidutinio karšto vandens tūrio debito per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1352, 'Karšto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminio karšto vandens tūrio kiekio, fiksuojamo kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1353, 'Vidutinio karšto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1354, 'Karšto vandens tūrio kiekio per val. rodmenų generavimas iš Karšto vandens tūrio kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1355, 'Vidutinio tiekiamo karšto vandens tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1356, 'Vidutinio tiekiamo karšto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1357, 'Tiekiamo karšto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1358, 'Tiekiamo karšto vandens tūrio kiekio per val. rodmenų generavimas iš tiekiamo karšto vandens tūrio kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1359, 'Vidutinio grįžtamo karšto vandens tūrio debito per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1360, 'Grįžtamo karšto vandens tūrio kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1361, 'Vidutinio grįžtamo karšto vandens tūrio debito per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1362, 'Grįžtamo karšto vandens tūrio kiekio per val. rodmenų generavimas iš grįžtamo karšto vandens tūrio kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1363, 'Vidutinės šilumnešio koreguota šilumos galios per val. rodmenų generavimas iš vidutinių duomenų per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1364, 'Šilumnešio koreguoto šilumos kiekio per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1365, 'Vidutinės šilumnešio koreguota šil. galios per 5 min. rodmenų generavimas iš suminių duomenų, fiksuojamų kas 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1366, 'Šilumnešio koreguoto šil. kiekio per val. rodmenų generavimas iš šilumnešio koreguoto šil. kiekio per 5 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1368, 'Momentinio rodiklio generavimas iš suminio dujų koreguoto tūrio kiekio, fiksuojamo kas minutę', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1373, 'Sunaudotos šilumnešio šilumos kiekio per mėnesį generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1374, 'Sunaudotos šilumnešio šilumos kiekio per parą generavimas iš valandinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1375, 'Tiekiamo šilumnešio šilumos kiekio per mėnesį generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1376, 'Tiekiamo šilumnešio šilumos kiekio per parą generavimas iš valandinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1377, 'Šilumnešio šilumos kiekio per parą generavimas iš valandinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1378, 'Karšto vandens šilumos kiekio per parą generavimas iš valandinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1379, 'Karšto vandens šilumos kiekio per mėnesį generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1380, 'Tiekiamo karšto vandens šilumos kiekio per mėnesį generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1381, 'Tiekiamo karšto vandens šilumos kiekio per parą generavimas iš valandinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1382, 'Sunaudotos karšto vandens šilumos kiekio per mėnesį generavimas iš parų reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1383, 'Sunaudotos karšto vandens šilumos kiekio per parą generavimas iš valandinių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1384, 'Fiksuotų kas parą suminių duomenų generavimas iš fiksuotų kas mėnesį ir parų energijos duomenų', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1388, 'Sistemos monitoringo duomenų, fiksuojamų kas parą generavimas', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1389, 'Sistemos monitoringo duomenų, fiksuojamų kas valandą generavimas', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1393, 'Vidutinio šalto vandens debito per 2 min. generavimas iš augančių reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1394, 'Suminės A+ energijos proporcingas generavimas iš gretimų reikšmių, fiksuotų kas valandą ', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1395, 'Suminės A+ energijos pagal 1 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1396, 'Suminės A+ energijos pagal 2 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1397, 'Suminės A+ energijos pagal 3 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1398, 'Suminės A+ energijos pagal 4 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1399, 'Suminės A- energijos pagal 1 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1400, 'Suminės A- energijos pagal 2 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1401, 'Suminės A- energijos pagal 3 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1402, 'Suminės A- energijos pagal 4 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1403, 'Suminės R+ energijos pagal 1 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1404, 'Suminės R+ energijos pagal 2 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1405, 'Suminės R+ energijos pagal 3 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1406, 'Suminės R+ energijos pagal 4 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1407, 'Suminės R- energijos pagal 1 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1408, 'Suminės R- energijos pagal 2 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1409, 'Suminės R- energijos pagal 3 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1410, 'Suminės R- energijos pagal 4 tarifą, fiksuotos kas parą, generavimas iš suminių ir einamų paros reikšmių', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1413, 'Suminės A+ energijos proporcingas generavimas iš gretimų reikšmių, fiksuotų kas 15 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0),
	(1414, 'Suminės A+ energijos proporcingas generavimas iš gretimų reikšmių, fiksuotų kas 30 min.', 454, 0, 1, NULL, NULL, 1, 1, 1, 0, NULL, NULL, NULL, 0);
/*!40000 ALTER TABLE `src` ENABLE KEYS */;

-- Dumping structure for table emcor.srcacl
CREATE TABLE IF NOT EXISTS `srcacl` (
  `srcacl_id` int(10) unsigned NOT NULL COMMENT 'Signalo apie su šaltiniais susijusios aktualios surinkimui konfigūracijos pasikeitimus identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `s_src` tinyint(1) NOT NULL DEFAULT 0,
  `s_src_lpty` tinyint(1) NOT NULL DEFAULT 0,
  `s_sp` tinyint(1) NOT NULL DEFAULT 0,
  `s_sp_lpty` tinyint(1) NOT NULL DEFAULT 0,
  `s_se_lpty` tinyint(1) NOT NULL DEFAULT 0,
  `s_sep` tinyint(1) NOT NULL DEFAULT 0,
  `s_sep_rc` tinyint(1) NOT NULL DEFAULT 0,
  `das_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  PRIMARY KEY (`srcacl_id`),
  KEY `srcacl_db_time_i` (`db_time`),
  KEY `srcacl_src_i` (`src_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Signalai apie su šaltiniais susijusios aktualios surinkimui konfigūracijos pasikeitimus';

-- Dumping data for table emcor.srcacl: ~0 rows (approximately)
/*!40000 ALTER TABLE `srcacl` DISABLE KEYS */;
/*!40000 ALTER TABLE `srcacl` ENABLE KEYS */;

-- Dumping structure for table emcor.srcacl_das
CREATE TABLE IF NOT EXISTS `srcacl_das` (
  `srcacl_id` int(10) unsigned NOT NULL COMMENT 'Signalo apie su šaltiniais susijusios aktualios surinkimui konfigūracijos pasikeitimus identifikatorius',
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  `db_time` datetime DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  PRIMARY KEY (`srcacl_id`,`das_id`),
  KEY `srcacl_das_das_fk` (`das_id`),
  CONSTRAINT `srcacl_das_das_fk` FOREIGN KEY (`das_id`) REFERENCES `das` (`das_id`) ON DELETE CASCADE,
  CONSTRAINT `srcacl_das_srcacl_fk` FOREIGN KEY (`srcacl_id`) REFERENCES `srcacl` (`srcacl_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų surinkimo serverių nuskaityti signalai apie su šaltiniais susijusios aktualios surinkimui konfigūracijos pasikeitimus';

-- Dumping data for table emcor.srcacl_das: ~0 rows (approximately)
/*!40000 ALTER TABLE `srcacl_das` DISABLE KEYS */;
/*!40000 ALTER TABLE `srcacl_das` ENABLE KEYS */;

-- Dumping structure for table emcor.srcu
CREATE TABLE IF NOT EXISTS `srcu` (
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `db_time` datetime DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  PRIMARY KEY (`src_id`),
  CONSTRAINT `srcu_src_fk` FOREIGN KEY (`src_id`) REFERENCES `src` (`src_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų šaltinių konfigūracijos keitimo požymiai';

-- Dumping data for table emcor.srcu: ~0 rows (approximately)
/*!40000 ALTER TABLE `srcu` DISABLE KEYS */;
/*!40000 ALTER TABLE `srcu` ENABLE KEYS */;

-- Dumping structure for table emcor.src_dw#opty
CREATE TABLE IF NOT EXISTS `src_dw#opty` (
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`src_id`,`withe_id`,`ind1`,`ind2`,`ind3`,`opty_id`),
  KEY `src_dw#opty_opty_fk` (`opty_id`),
  CONSTRAINT `src_dw#opty_opty_fk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_dw#opty_src_fk` FOREIGN KEY (`src_id`) REFERENCES `src` (`src_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Nuskaitymo taškų prietaisų konfigūracinių masyvinių parametrų nuskaitymui reikalingų parametrų reikšmės';

-- Dumping data for table emcor.src_dw#opty: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_dw#opty` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_dw#opty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_dw_opty
CREATE TABLE IF NOT EXISTS `src_dw_opty` (
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`src_id`,`withe_id`,`opty_id`),
  KEY `src_dw_opty_opty_fk` (`opty_id`),
  CONSTRAINT `src_dw_opty_opty_fk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_dw_opty_src_fk` FOREIGN KEY (`src_id`) REFERENCES `src` (`src_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Nuskaitymo taškų prietaisų konfigūracinių parametrų nuskaitymui reikalingų parametrų reikšmės';

-- Dumping data for table emcor.src_dw_opty: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_dw_opty` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_dw_opty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_dw_rc#opty
CREATE TABLE IF NOT EXISTS `src_dw_rc#opty` (
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `rc_in` tinyint(1) NOT NULL COMMENT 'Nuskaitymo užklausų požymis',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`src_id`,`withe_id`,`ind1`,`ind2`,`ind3`,`rc_in`,`opty_id`),
  KEY `src_dw_rc#opty_opty_fk` (`opty_id`),
  CONSTRAINT `src_dw_rc#opty_opty_fk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_dw_rc#opty_src_fk` FOREIGN KEY (`src_id`) REFERENCES `src` (`src_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Nuskaitymo taškų prietaisų konfigūracinių masyvinių parametrų nuskaitymui/įrašymui reikalingų parametrų reikšmės';

-- Dumping data for table emcor.src_dw_rc#opty: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_dw_rc#opty` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_dw_rc#opty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_dw_rc_opty
CREATE TABLE IF NOT EXISTS `src_dw_rc_opty` (
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `rc_in` tinyint(1) NOT NULL COMMENT 'Nuskaitymo užklausų požymis',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`src_id`,`withe_id`,`rc_in`,`opty_id`),
  KEY `src_dw_rc_opty_opty_fk` (`opty_id`),
  CONSTRAINT `src_dw_rc_opty_opty_fk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_dw_rc_opty_src_fk` FOREIGN KEY (`src_id`) REFERENCES `src` (`src_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Nuskaitymo taškų prietaisų konfigūracinių parametrų nuskaitymui/įrašymui reikalingų parametrų reikšmės';

-- Dumping data for table emcor.src_dw_rc_opty: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_dw_rc_opty` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_dw_rc_opty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_dw_tmst
CREATE TABLE IF NOT EXISTS `src_dw_tmst` (
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `id` smallint(5) unsigned NOT NULL,
  `dw_rt` datetime NOT NULL COMMENT 'Nuskaitymo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime NOT NULL COMMENT 'Duomenų paketo laiko žymė',
  PRIMARY KEY (`src_id`,`id`),
  CONSTRAINT `src_dw_tmst_src_fk` FOREIGN KEY (`src_id`) REFERENCES `src` (`src_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitomų per šaltinį nuskaitymo taško duomenų pluoštų laiko žymės';

-- Dumping data for table emcor.src_dw_tmst: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_dw_tmst` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_dw_tmst` ENABLE KEYS */;

-- Dumping structure for table emcor.src_lpty
CREATE TABLE IF NOT EXISTS `src_lpty` (
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `lpty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Ryšio modulių savybės reikšmė',
  PRIMARY KEY (`src_id`,`lpty_id`),
  KEY `src_lpty_lpty_i` (`lpty_id`),
  CONSTRAINT `src_lpty_lpty_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_lpty_src_fk` FOREIGN KEY (`src_id`) REFERENCES `src` (`src_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų šaltinių savybės';

-- Dumping data for table emcor.src_lpty: ~53 rows (approximately)
/*!40000 ALTER TABLE `src_lpty` DISABLE KEYS */;
INSERT INTO `src_lpty` (`src_id`, `lpty_id`, `lpty_value`) VALUES
	(467, 151, '0'),
	(468, 151, '0'),
	(470, 151, '0'),
	(471, 151, '0'),
	(472, 151, '0'),
	(473, 151, '0'),
	(476, 151, '0'),
	(478, 151, '0'),
	(480, 151, '0'),
	(481, 151, '0'),
	(482, 151, '0'),
	(484, 151, '0'),
	(485, 151, '0'),
	(487, 151, '0'),
	(489, 151, '0'),
	(490, 151, '0'),
	(523, 151, '0'),
	(524, 151, '0'),
	(526, 151, '0'),
	(527, 151, '0'),
	(544, 151, '0'),
	(545, 151, '0'),
	(622, 151, '0'),
	(623, 151, '0'),
	(626, 151, '0'),
	(627, 151, '0'),
	(628, 151, '0'),
	(629, 151, '0'),
	(667, 151, '0'),
	(668, 151, '0'),
	(702, 151, '0'),
	(703, 151, '0'),
	(704, 151, '0'),
	(705, 151, '0'),
	(706, 151, '0'),
	(712, 151, '0'),
	(713, 151, '0'),
	(732, 151, '0'),
	(733, 151, '0'),
	(734, 151, '0'),
	(735, 151, '0'),
	(736, 151, '0'),
	(782, 151, '0'),
	(783, 151, '0'),
	(784, 151, '0'),
	(833, 151, '0'),
	(834, 151, '0'),
	(835, 151, '0'),
	(842, 151, '0'),
	(912, 151, '0'),
	(1008, 151, '0'),
	(1028, 151, '1'),
	(1056, 151, '0');
/*!40000 ALTER TABLE `src_lpty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_mod
CREATE TABLE IF NOT EXISTS `src_mod` (
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `src_type_mod_impl_code` varchar(80) COLLATE utf8_bin DEFAULT NULL COMMENT 'Šaltinių tipo modifikacijos implementacijos kodas',
  PRIMARY KEY (`src_id`),
  CONSTRAINT `src_mod_src_fk` FOREIGN KEY (`src_id`) REFERENCES `src` (`src_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų šaltinių nustatytos modifikacijos';

-- Dumping data for table emcor.src_mod: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_mod` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_mod` ENABLE KEYS */;

-- Dumping structure for table emcor.src_pw#opty
CREATE TABLE IF NOT EXISTS `src_pw#opty` (
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`src_id`,`point_id`,`withe_id`,`ind1`,`ind2`,`ind3`,`opty_id`),
  KEY `src_pw#opty_opty_fk` (`opty_id`),
  KEY `src_pw#opty_point_fk` (`point_id`),
  CONSTRAINT `src_pw#opty_opty_fk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_pw#opty_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `src_pw#opty_src_fk` FOREIGN KEY (`src_id`) REFERENCES `src` (`src_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimo taškų prietaisų konfigūracinių masyvinių parametrų nuskaitymui reikalingų parametrų reikšmės';

-- Dumping data for table emcor.src_pw#opty: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_pw#opty` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_pw#opty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_pw_opty
CREATE TABLE IF NOT EXISTS `src_pw_opty` (
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`src_id`,`point_id`,`withe_id`,`opty_id`),
  KEY `src_pw_opty_opty_fk` (`opty_id`),
  KEY `src_pw_opty_point_fk` (`point_id`),
  CONSTRAINT `src_pw_opty_opty_fk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_pw_opty_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `src_pw_opty_src_fk` FOREIGN KEY (`src_id`) REFERENCES `src` (`src_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimo taškų prietaisų konfigūracinių parametrų nuskaitymui reikalingų parametrų reikšmės';

-- Dumping data for table emcor.src_pw_opty: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_pw_opty` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_pw_opty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_pw_rc#opty
CREATE TABLE IF NOT EXISTS `src_pw_rc#opty` (
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `rc_in` tinyint(1) NOT NULL COMMENT 'Nuskaitymo užklausų požymis',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`src_id`,`point_id`,`withe_id`,`ind1`,`ind2`,`ind3`,`rc_in`,`opty_id`),
  KEY `src_pw_rc#opty_point_fk` (`point_id`),
  KEY `src_ww_rc#opty_opty_fk` (`opty_id`),
  CONSTRAINT `src_pw_rc#opty_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `src_pw_rc#opty_src_fk` FOREIGN KEY (`src_id`) REFERENCES `src` (`src_id`) ON DELETE CASCADE,
  CONSTRAINT `src_ww_rc#opty_opty_fk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimo taškų prietaisų konfigūracinių masyvinių parametrų nuskaitymui/įrašymui reikalingų parametrų reikšmės';

-- Dumping data for table emcor.src_pw_rc#opty: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_pw_rc#opty` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_pw_rc#opty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_pw_rc_opty
CREATE TABLE IF NOT EXISTS `src_pw_rc_opty` (
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `rc_in` tinyint(1) NOT NULL COMMENT 'Nuskaitymo užklausų požymis',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`src_id`,`point_id`,`withe_id`,`rc_in`,`opty_id`),
  KEY `src_pw_rc_opty_opty_fk` (`opty_id`),
  KEY `src_pw_rc_opty_point_fk` (`point_id`),
  CONSTRAINT `src_pw_rc_opty_opty_fk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_pw_rc_opty_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `src_pw_rc_opty_src_fk` FOREIGN KEY (`src_id`) REFERENCES `src` (`src_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Matavimo taškų prietaisų konfigūracinių parametrų nuskaitymui/įrašymui reikalingų parametrų reikšmės';

-- Dumping data for table emcor.src_pw_rc_opty: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_pw_rc_opty` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_pw_rc_opty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_pw_tmst
CREATE TABLE IF NOT EXISTS `src_pw_tmst` (
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `point_id` int(10) unsigned NOT NULL COMMENT 'Matavimo taško identifikatorius',
  `id` smallint(5) unsigned NOT NULL,
  `pw_rt` datetime NOT NULL COMMENT 'Matavimo taško vytelės duomenų nuskaitymo laikas',
  `pck_t` datetime NOT NULL COMMENT 'Duomenų paketo laiko žymė',
  PRIMARY KEY (`src_id`,`point_id`,`id`),
  KEY `src_pw_tmst_point_fk` (`point_id`),
  CONSTRAINT `src_pw_tmst_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `src_pw_tmst_src_fk` FOREIGN KEY (`src_id`) REFERENCES `src` (`src_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitomų per šaltinį matavimo taško duomenų pluoštų laiko žymės';

-- Dumping data for table emcor.src_pw_tmst: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_pw_tmst` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_pw_tmst` ENABLE KEYS */;

-- Dumping structure for table emcor.src_rule
CREATE TABLE IF NOT EXISTS `src_rule` (
  `src_rule_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Duomenų šaltinių kūrimo taikant atitinkamus šablonus taisyklės identifikatorius',
  `rule_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Taisyklės galiojimo požymis',
  `src_tmpl_id` mediumint(8) unsigned NOT NULL COMMENT 'Duomenų šaltinių šablono ID',
  `meter_type_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Matavimo priemonių tipo identifikatorius',
  `ecp_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Taško ekonominio profilio identifikatorius',
  `point_type_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Matavimo taškų tipo identifikatorius',
  `dev_type_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Duomenų koncentratoriaus tipo identifikatorius',
  `dp_type_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Duomenų nuskaitymo taškų tipo identifikatorius',
  `mou_type_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Pajungimo schemos identifikatorius',
  `ppty_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Matavimo taškų savybės identifikatorius',
  `ppty_value` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Matavimo taško savybės reikšmė',
  PRIMARY KEY (`src_rule_id`),
  KEY `src_rule_dev_type_i` (`dev_type_id`),
  KEY `src_rule_dp_type_i` (`dp_type_id`),
  KEY `src_rule_ecp_i` (`ecp_id`),
  KEY `src_rule_meter_type_i` (`meter_type_id`),
  KEY `src_rule_mou_type_i` (`mou_type_id`),
  KEY `src_rule_point_type_i` (`point_type_id`),
  KEY `src_rule_ppty_i` (`ppty_id`),
  KEY `src_rule_src_tmpl_i` (`src_tmpl_id`),
  CONSTRAINT `src_rule_dev_type_fk` FOREIGN KEY (`dev_type_id`) REFERENCES `dev_type` (`dev_type_id`),
  CONSTRAINT `src_rule_dp_type_fk` FOREIGN KEY (`dp_type_id`) REFERENCES `dp_type` (`dp_type_id`),
  CONSTRAINT `src_rule_ecp_fk` FOREIGN KEY (`ecp_id`) REFERENCES `ecp` (`ecp_id`),
  CONSTRAINT `src_rule_meter_type_fk` FOREIGN KEY (`meter_type_id`) REFERENCES `meter_type` (`meter_type_id`),
  CONSTRAINT `src_rule_mou_type_fk` FOREIGN KEY (`mou_type_id`) REFERENCES `mou_type` (`mou_type_id`),
  CONSTRAINT `src_rule_point_type_fk` FOREIGN KEY (`point_type_id`) REFERENCES `point_type` (`point_type_id`),
  CONSTRAINT `src_rule_ppty_fk` FOREIGN KEY (`ppty_id`) REFERENCES `ppty` (`ppty_id`),
  CONSTRAINT `src_rule_src_tmpl_fk` FOREIGN KEY (`src_tmpl_id`) REFERENCES `src_tmpl` (`src_tmpl_id`),
  CONSTRAINT `SRC_RULE_PPTY_INCOMPLETE_CHK` CHECK (`ppty_id` is null and `ppty_value` is null or `ppty_id` is not null and `ppty_value` is not null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų šaltinių kūrimo taikant atitinkamus šablonus taisyklės';

-- Dumping data for table emcor.src_rule: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_rule` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_rule` ENABLE KEYS */;

-- Dumping structure for table emcor.src_state
CREATE TABLE IF NOT EXISTS `src_state` (
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `src_crs` double NOT NULL COMMENT 'Duomenų šaltinio kontrolinė suma, suformuota iš susijusių su šaltiniu apskaitos taškų identifikatorių',
  PRIMARY KEY (`src_id`),
  CONSTRAINT `src_state_src_fk` FOREIGN KEY (`src_id`) REFERENCES `src` (`src_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų šaltinių konfigūracijos kontrolinės sumos';

-- Dumping data for table emcor.src_state: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_state` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_state` ENABLE KEYS */;

-- Dumping structure for table emcor.src_tmpl
CREATE TABLE IF NOT EXISTS `src_tmpl` (
  `src_tmpl_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Duomenų šaltinių šablono ID',
  `src_tmpl_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų šaltinių šablono kodas',
  `src_tmpl_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų šaltinių šablono pavadinimas',
  `src_tmpl_multipoint` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Duomenų šaltinių šablono keletui taškų požymis',
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `dl_type_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų išdėstymo tipo identifikatorius',
  `tz_id` smallint(5) unsigned NOT NULL COMMENT 'Laiko zonos identifikatorius',
  `src_tz_dst_used` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Vasaros laiko naudojimo požymis',
  `src_save_statistics` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Statistikos rinkimo požymis duomenų šaltiniui',
  `ignore_se_ab` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Šaltinio elemento koeficientų ignoravimo požymis',
  `src_dir_inv` tinyint(1) NOT NULL DEFAULT 0,
  `inherit_src_number` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Automatiškai modifikuoti šaltinio numerį pagal sumontuoto prietaiso numerį',
  PRIMARY KEY (`src_tmpl_id`),
  UNIQUE KEY `src_tmpl_code_u` (`src_tmpl_code`),
  UNIQUE KEY `src_tmpl_name_u` (`src_tmpl_name`),
  KEY `src_tmpl_dl_type_i` (`dl_type_id`),
  KEY `src_tmpl_src_type_i` (`src_type_id`),
  KEY `src_tmpl_tz_i` (`tz_id`),
  CONSTRAINT `src_tmpl_dl_type_fk` FOREIGN KEY (`dl_type_id`) REFERENCES `dl_type` (`dl_type_id`),
  CONSTRAINT `src_tmpl_src_type_fk` FOREIGN KEY (`src_type_id`) REFERENCES `src_type` (`src_type_id`),
  CONSTRAINT `src_tmpl_tz_fk` FOREIGN KEY (`tz_id`) REFERENCES `tz` (`tz_id`)
) ENGINE=InnoDB AUTO_INCREMENT=162 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų šaltinių šablonai';

-- Dumping data for table emcor.src_tmpl: ~2 rows (approximately)
/*!40000 ALTER TABLE `src_tmpl` DISABLE KEYS */;
INSERT INTO `src_tmpl` (`src_tmpl_id`, `src_tmpl_code`, `src_tmpl_name`, `src_tmpl_multipoint`, `src_type_id`, `dl_type_id`, `tz_id`, `src_tz_dst_used`, `src_save_statistics`, `ignore_se_ab`, `src_dir_inv`, `inherit_src_number`) VALUES
	(141, 'LZQM', 'Standartinis LZQM', 0, 1, 2, 1, 0, 0, 0, 0, 1),
	(161, 'EPQM', 'EPQM', 0, 30, 2, 1, 1, 1, 0, 0, 1);
/*!40000 ALTER TABLE `src_tmpl` ENABLE KEYS */;

-- Dumping structure for table emcor.src_tmpl_lpty
CREATE TABLE IF NOT EXISTS `src_tmpl_lpty` (
  `src_tmpl_id` mediumint(8) unsigned NOT NULL COMMENT 'Duomenų šaltinių šablono ID',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `lpty_value` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Ryšio modulių savybės reikšmė',
  PRIMARY KEY (`src_tmpl_id`,`lpty_id`),
  KEY `src_tmpl_lpty_i` (`lpty_id`),
  CONSTRAINT `src_tmpl_lpty_lpty_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_tmpl_lpty_tmpl_fk` FOREIGN KEY (`src_tmpl_id`) REFERENCES `src_tmpl` (`src_tmpl_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Šaltinių šablono elementų savybės';

-- Dumping data for table emcor.src_tmpl_lpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_tmpl_lpty` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_tmpl_lpty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_tmpl_ph_type_lpty
CREATE TABLE IF NOT EXISTS `src_tmpl_ph_type_lpty` (
  `src_tmpl_id` mediumint(8) unsigned NOT NULL COMMENT 'Duomenų šaltinių šablono ID',
  `ph_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `lpty_value` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Ryšio modulių savybės reikšmė',
  PRIMARY KEY (`src_tmpl_id`,`ph_type_id`,`lpty_id`),
  KEY `src_tmpl_ph_type_i` (`ph_type_id`),
  KEY `src_tmpl_ph_type_lpty_i` (`lpty_id`),
  CONSTRAINT `src_tmpl_ph_type_lpty_lpty_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_tmpl_ph_type_lpty_tmpl_fk` FOREIGN KEY (`src_tmpl_id`) REFERENCES `src_tmpl` (`src_tmpl_id`) ON DELETE CASCADE,
  CONSTRAINT `src_tmpl_ph_type_type_fk` FOREIGN KEY (`ph_type_id`) REFERENCES `ph_type` (`ph_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Šaltinių šablono elementų savybės pagal ryšio kanalų tipą ';

-- Dumping data for table emcor.src_tmpl_ph_type_lpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_tmpl_ph_type_lpty` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_tmpl_ph_type_lpty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type
CREATE TABLE IF NOT EXISTS `src_type` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų šaltinių tipo kodas',
  `src_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų šaltinių tipo pavadinimas',
  `guid` varchar(50) COLLATE utf8_bin DEFAULT NULL COMMENT 'Ryšio draiverio GUID',
  `src_type_internal` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Sistemos apklausiamų duomenų arba importuojamų išorinių duomenų požymis',
  `tm_guid` varchar(50) COLLATE utf8_bin DEFAULT NULL COMMENT 'Transporto menedžerio GUID',
  `devicetype` int(10) NOT NULL COMMENT 'Susijęs duomenų šaltinių tipo identifikatorius',
  `horizontal_read_mode` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Horizontalaus archyvų nuskaitymo požymis',
  `shred_journal_read_enabled` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Žurnalų skylių išskaidymo pagal kodus naudojimo požymis',
  `ticket_guid` varchar(50) COLLATE utf8_bin DEFAULT NULL COMMENT 'Ticket draiverio GUID',
  `src_type_withcurrentvalue_mode` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Duomenų šaltinių tipo WithCurrentValue rėžimo taikymo požymis',
  PRIMARY KEY (`src_type_id`),
  KEY `src_type_code_u` (`src_type_code`),
  KEY `src_type_name_u` (`src_type_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų šaltinių  tipai';

-- Dumping data for table emcor.src_type: ~282 rows (approximately)
/*!40000 ALTER TABLE `src_type` DISABLE KEYS */;
INSERT INTO `src_type` (`src_type_id`, `src_type_code`, `src_type_name`, `guid`, `src_type_internal`, `tm_guid`, `devicetype`, `horizontal_read_mode`, `shred_journal_read_enabled`, `ticket_guid`, `src_type_withcurrentvalue_mode`) VALUES
	(-4, 'MIR_OMi', 'MIR_OMi', '{65279236-B7F0-4B5F-928E-AA774C04F058}', 1, NULL, -4, 0, 0, NULL, 0),
	(-3, 'IEC_60870-5-104', 'IEC 60870-5-104', '{B2CBE835-64F8-4E29-B18B-2BCBF91D66F3}', 1, NULL, -3, 0, 0, NULL, 0),
	(-2, 'OPC_SERVER', 'OPC Server', NULL, 1, NULL, -2, 0, 0, NULL, 0),
	(-1, 'LZMF', 'LZMF', '{F0DA88FD-4FC1-435E-8B0F-DA874E4B11C9}', 1, NULL, -1, 0, 0, NULL, 1),
	(0, 'Generated_by_SQL_Server', 'Generated_by_SQL_Server', NULL, 1, NULL, 0, 0, 0, NULL, 0),
	(1, 'LZQM', 'LZQM', '{F0DA88FD-4FC1-435E-8B0F-DA874E4B11C9}', 1, NULL, 1, 0, 1, NULL, 1),
	(4, 'MultiCal', 'MultiCal', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 4, 0, 0, NULL, 0),
	(14, 'Combimeter_Q', 'Combimeter Q', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 14, 0, 0, NULL, 0),
	(24, 'GEM', 'Gama 100 (G1A)', '{F0DA88FD-4FC1-435E-8B0F-DA874E4B11C9}', 1, NULL, 24, 0, 1, NULL, 1),
	(25, 'EMS', 'EMS', '{F0DA88FD-4FC1-435E-8B0F-DA874E4B11C9}', 1, NULL, 25, 0, 1, NULL, 1),
	(26, 'Katra_SKU_01M', 'Katra SKU-01M', '{914A8508-9A4D-4C0E-9AC8-02BD7F43950C}', 1, NULL, 26, 0, 0, NULL, 0),
	(30, 'EPQM', 'EPQM', '{F0DA88FD-4FC1-435E-8B0F-DA874E4B11C9}', 1, NULL, 30, 0, 1, NULL, 1),
	(32, 'Siemens_ZxD', 'Siemens ZxD', '{DC99BDE2-6E2E-4859-9AA6-B6E91AC7670A}', 1, NULL, 32, 0, 0, NULL, 0),
	(33, 'EPQS', 'EPQS', '{F0DA88FD-4FC1-435E-8B0F-DA874E4B11C9}', 1, NULL, 33, 0, 1, NULL, 1),
	(35, 'Mercury_230', 'Mercury 230', '{2CC5AFAD-43BF-426C-9A26-6D9C70299B58}', 1, NULL, 35, 0, 0, NULL, 0),
	(38, 'ABB_EuroAlpha', 'ABB EuroAlpha', '{EDE11555-614D-472D-BD72-826B47F0BA1A}', 1, NULL, 38, 0, 0, NULL, 0),
	(39, 'SL7000', 'SL7000', '{042377EB-900B-4409-B460-66AB9AB4388C}', 1, NULL, 39, 0, 0, NULL, 0),
	(42, 'Infocal5', 'Infocal 5', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 42, 0, 0, NULL, 0),
	(51, 'LZKM', 'LZKM', '{F0DA88FD-4FC1-435E-8B0F-DA874E4B11C9}', 1, NULL, 51, 0, 1, NULL, 1),
	(52, 'ION_8X00', 'ION-8X00', '{A2C2D3BF-4D9C-4DAB-A086-2E57BAB86FD5}', 1, NULL, 52, 0, 0, NULL, 0),
	(53, 'RTU-325', 'RTU-325', '{5F9A48D3-7E95-4356-A237-F6A44C0FD270}', 1, NULL, 53, 0, 0, NULL, 0),
	(54, 'IM-2300', 'IM-2300', '{1BD7DBA1-1A7B-46D3-8346-A3A71873B32E}', 1, NULL, 54, 0, 0, NULL, 0),
	(56, 'Hydro_Meter', 'Hydro Meter', '{19B4B405-A1DB-4C08-8A34-6C9D31AC7FFA}', 1, NULL, 56, 0, 0, NULL, 0),
	(57, 'Katra_SKM_01M', 'Katra SKM-01M', '{AAE2E04B-57DC-4B3B-9B0C-602AE1A899B7}', 1, NULL, 57, 0, 0, NULL, 0),
	(58, 'Izar_Prt', 'Izar Prt', '{19B4B405-A1DB-4C08-8A34-6C9D31AC7FFA}', 1, NULL, 58, 0, 0, NULL, 0),
	(59, 'Hydro_Port', 'Hydro Port', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 59, 0, 0, NULL, 0),
	(60, 'Manual_Input', 'Manual Input', NULL, 1, NULL, 60, 0, 0, NULL, 0),
	(61, 'SiemensPulse_adapter', 'Siemens Pulse-adapter', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 61, 0, 0, NULL, 0),
	(62, 'Katra_SKS_3', 'Katra SKS-3', '{2249A9B1-241F-4AF4-91D2-297616EFC41C}', 1, NULL, 62, 0, 0, NULL, 0),
	(63, 'Sicon_C10', 'Sicon-C10', '{25233118-9C42-41C3-955E-AD7DF2726135}', 1, NULL, 63, 0, 0, NULL, 0),
	(64, 'ENKS_2', 'ENKS-2', '{B041658C-A85B-48C2-B8F3-4633A055A251}', 1, NULL, 64, 0, 0, NULL, 0),
	(66, 'VEP', 'VEP', '{A304F58C-5C41-4723-A306-48A3D3FD89A9}', 1, NULL, 66, 0, 0, NULL, 0),
	(67, 'SET_4TA', 'SET-4TA', '{2B7DF93D-7396-4A0B-99C5-23E6D2F7B17D}', 1, NULL, 67, 0, 0, NULL, 0),
	(68, 'SET_4TM', 'SET-4TM', '{2B7DF93D-7396-4A0B-99C5-23E6D2F7B17D}', 1, NULL, 68, 0, 0, NULL, 0),
	(69, 'PSC_4TM', 'PSC', '{2B7DF93D-7396-4A0B-99C5-23E6D2F7B17D}', 1, NULL, 69, 0, 0, NULL, 0),
	(70, 'Vzljot_TSRV_022', 'Vzljot TSRV-022', '{DC749C8D-1BC6-49A7-BE04-F35371FC47FF}', 1, NULL, 70, 0, 0, NULL, 0),
	(71, 'TMK_H1', 'TMK-H1', NULL, 1, '{5679E7EB-F33C-4632-9454-41A3BE7620A8}', 71, 0, 0, NULL, 0),
	(72, 'TMK_H2', 'TMK-H2', NULL, 1, '{5679E7EB-F33C-4632-9454-41A3BE7620A8}', 72, 0, 0, NULL, 0),
	(73, 'TMK_H3', 'TMK-H3', NULL, 1, '{5679E7EB-F33C-4632-9454-41A3BE7620A8}', 73, 0, 0, NULL, 0),
	(75, 'Irga_2G', 'Irga 2G', '{342CDB1E-C977-4F69-B5B8-EF92A73D8CCE}', 1, NULL, 75, 0, 0, NULL, 0),
	(76, 'MK_H1', 'MK-H1', NULL, 1, '{5679E7EB-F33C-4632-9454-41A3BE7620A8}', 76, 0, 0, NULL, 0),
	(77, 'Sicon_C50', 'Sicon-C50', '{296271E7-EA9F-446E-BD68-3FFCF8B00DE6}', 1, NULL, 77, 0, 0, NULL, 0),
	(78, 'Sicon_C70', 'Sicon-C70', '{25233118-9C42-41C3-955E-AD7DF2726135}', 1, NULL, 78, 0, 0, NULL, 0),
	(79, 'SET_4TM_01', 'SET-4TM-01', '{2B7DF93D-7396-4A0B-99C5-23E6D2F7B17D}', 1, NULL, 79, 0, 0, NULL, 0),
	(80, 'SET_1M_01', 'SET-1M-01', '{2B7DF93D-7396-4A0B-99C5-23E6D2F7B17D}', 1, NULL, 80, 0, 0, NULL, 0),
	(81, 'EKOM_3000', 'EKOM-3000', '{2398E8AC-D29E-4493-9E9C-94111C6F233D}', 1, NULL, 81, 0, 0, NULL, 0),
	(82, 'TSP_200', 'TSP-200', '{8592E2C5-5837-4940-8251-333D54DA66A0}', 1, NULL, 82, 0, 0, NULL, 0),
	(85, 'Siemens_WTT16', 'Siemens_WTT16', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 85, 0, 0, NULL, 0),
	(86, 'Siemens_WFC21', 'Siemens_WFC21', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 86, 0, 0, NULL, 0),
	(87, 'Valsena_DKEG10', 'Valsena_DKEG10', '{2AABF372-0348-4408-9F20-7451A8AE1700}', 1, NULL, 87, 0, 0, NULL, 0),
	(88, 'Siemens_WFM21', 'Siemens-WFM21', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 88, 0, 0, NULL, 0),
	(89, 'Sensus_HRI ', 'Sensus-HRI ', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 89, 0, 0, NULL, 0),
	(90, 'EX5x1', 'EX541/EX531', '{E5367E0D-12B1-4695-9781-693428AC905B}', 1, NULL, 90, 0, 0, NULL, 0),
	(91, 'Vzljot_Em', 'Vzljot Em', '{02E3456B-54A8-4128-A59A-492945FD507C}', 1, NULL, 91, 0, 0, NULL, 0),
	(92, 'Vzljot_Er', 'Vzljot Er', '{02E3456B-54A8-4128-A59A-492945FD507C}', 1, NULL, 92, 0, 0, NULL, 0),
	(93, 'Dimetic_Metran333', 'Dimetic Metran-333', '{1270849B-9FEA-4025-8C6A-50DCBEDD282D}', 1, NULL, 93, 0, 0, NULL, 0),
	(94, 'Siemens_AEW310', 'Siemens AEW310', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 94, 0, 0, NULL, 0),
	(95, 'Energomera_Ce6850m', 'Energomera Ce6850m', '{4E8EC099-85BD-4529-9FD4-F55C30D66F1D}', 1, NULL, 95, 0, 0, NULL, 0),
	(96, 'DK_3', 'DK-3', '{69190850-CFCE-4BE0-9DDE-8173934D63BE}', 1, NULL, 96, 0, 0, NULL, 0),
	(97, 'DK_6', 'DK-6', '{69190850-CFCE-4BE0-9DDE-8173934D63BE}', 1, NULL, 97, 0, 0, NULL, 0),
	(98, 'ABB_Delta', 'ABB Delta', '{8CB15282-1FA8-431A-AFEC-59496908549C}', 1, NULL, 98, 0, 0, NULL, 0),
	(99, 'EK_260', 'EK-260', '{263D0365-3D25-4327-93F6-B032D3FAAB59}', 1, NULL, 99, 0, 0, NULL, 0),
	(100, 'WEB_Service', 'KE WEB service', '{22E3E60A-A854-4CE7-843B-B216AABF6C1F}', 0, NULL, 100, 0, 0, NULL, 0),
	(101, 'Grodno_Energo', 'Grodno-Energo', '{E0D242E6-A466-45A2-97A0-14E1F05C5341}', 1, NULL, 101, 0, 0, NULL, 0),
	(102, 'EST_Tools4', 'EST-Tools4', '{5E7ECC75-5296-426C-A3B1-68E78897E2A1}', 1, NULL, 102, 0, 0, NULL, 0),
	(103, 'CC_301', 'CC-301', '{A68EAEB8-71AD-45A3-9439-57DADFBC9AF6}', 1, NULL, 103, 0, 0, NULL, 0),
	(104, 'UK_1', 'UK-1', '{39D94E0B-ED44-4667-878A-3E128696F7DF}', 1, NULL, 104, 0, 0, NULL, 0),
	(105, 'Mercury_225', 'Mercury-225', '{021DDDF0-980C-4D50-BD74-13D046BB660F}', 1, NULL, 105, 0, 0, NULL, 0),
	(106, 'MsSQL_ISKREN', 'DB ISKREN', '{B688AC8D-5EC5-4A2A-85B0-512C863C2018}', 1, NULL, 106, 0, 0, NULL, 0),
	(107, 'XML_80020', 'XML-80020', NULL, 0, NULL, 100107, 0, 0, NULL, 0),
	(108, 'XML_51070', 'XML-51070', NULL, 0, NULL, 108, 0, 0, NULL, 0),
	(109, 'XML_80030', 'XML-80030', NULL, 0, NULL, 100109, 0, 0, NULL, 0),
	(110, 'ASKP', 'ASKP', NULL, 0, NULL, 100110, 0, 0, NULL, 0),
	(111, 'EMCOS_EEML', 'EMCOS-EEML', NULL, 0, NULL, 100111, 0, 0, NULL, 0),
	(112, 'XML_80040', 'XML-80040', NULL, 0, NULL, 100112, 0, 0, NULL, 0),
	(113, 'XML_80050', 'XML-80050', NULL, 0, NULL, 113, 0, 0, NULL, 0),
	(114, 'Uniflo_1000', 'Uniflo 1000', '{E7B63F60-F6BD-445C-B1E4-D46224E79053}', 1, NULL, 114, 0, 0, NULL, 0),
	(115, 'PadPuls_M2C ', 'PadPuls M2C ', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 115, 0, 0, NULL, 0),
	(116, 'Siemens_UH50', 'Siemens UH50', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 116, 0, 0, NULL, 0),
	(117, 'DKEG_48', 'Valsena DKEG-48', '{2AABF372-0348-4408-9F20-7451A8AE1700}', 1, NULL, 117, 0, 0, NULL, 0),
	(118, 'DIN_32', 'Valsena DIN-32', '{2AABF372-0348-4408-9F20-7451A8AE1700}', 1, NULL, 118, 0, 0, NULL, 0),
	(119, 'Elkora_B_34', 'ELKORA B-34', '{137B1F7C-FC9F-40A2-842F-AA682076C106}', 1, NULL, 119, 0, 0, NULL, 0),
	(120, 'CONTO_d4', 'Conto D4-Pd', '{D4595487-3893-40F9-BF1B-7FC7939A7D5E}', 1, NULL, 120, 0, 0, NULL, 0),
	(121, 'Sonometer_1000', 'Danfoss Sonometer 1000', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 121, 0, 0, NULL, 0),
	(122, 'EM4T', 'EM4T', '{4D5AB58C-DCB0-404C-85CC-66EC54AC6B9A}', 1, NULL, 122, 0, 0, NULL, 0),
	(123, 'Danfoss_Sharky', 'Danfoss Sharky', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 123, 0, 0, NULL, 0),
	(124, 'ABB_SVM_F2', 'ABB_SVM F2', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 124, 0, 0, NULL, 0),
	(125, 'Saiman_OTAN', 'Saiman Otan', '{7590BF39-6B4C-4B3B-A36B-426C15DD592B}', 1, NULL, 125, 0, 0, NULL, 0),
	(126, 'Actaris_CF_55', 'Actaris CF 55', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 126, 0, 0, NULL, 0),
	(127, 'GAMA', 'GAMA 300 (G3A)', '{F0DA88FD-4FC1-435E-8B0F-DA874E4B11C9}', 1, NULL, 127, 0, 1, NULL, 1),
	(128, 'EMCOS_DataSet', 'EMCOS DataSet', '{2CBA9076-F0F5-4D18-A85F-001B03205135}', 0, NULL, 128, 0, 0, NULL, 0),
	(129, 'Gran_Elektro_C12_CC_301', 'CC-301[Gran-Elektro C-12]', '{52CAB0FB-E6CC-4383-A702-1E75D26F7457}', 1, NULL, 130, 0, 0, NULL, 0),
	(130, 'Gran_Elektro_C12', 'Gran-Elektro_C12', '{52CAB0FB-E6CC-4383-A702-1E75D26F7457}', 1, NULL, 130, 0, 0, NULL, 0),
	(131, 'MCL_4_OPT', 'MCL 4 Optical', '{428454D5-3D20-4E39-A87B-83832200E207}', 1, NULL, 131, 0, 0, NULL, 0),
	(133, 'SEL_2401', 'SEL-2401', '{AB8CF948-9122-4DBB-87BE-B83C6F3C283D}', 1, NULL, 133, 0, 0, NULL, 0),
	(134, 'GAMA_DLC', 'GAMA 300 (GD2)', '{EB75EC08-0272-4B44-82F0-B05F91E66B28}', 1, NULL, 134, 0, 0, NULL, 0),
	(135, 'CE303', 'CE303', '{3B7EDA8E-1525-4A94-8B11-B71F39A98348}', 1, NULL, 135, 0, 0, NULL, 0),
	(136, 'DxxD536', 'DTSD536/ DSSD536', '{4AB0B694-8506-4DFA-8D6D-07A5C48A3DC7}', 1, NULL, 136, 0, 0, NULL, 0),
	(137, 'Energomera_USPD_164_01I', 'Energomera_164_01I', '{75C0239A-8682-40E4-AD3A-BC331E3E6ECB}', 1, NULL, 137, 0, 0, NULL, 0),
	(139, 'ADD_ADDAX', 'ADD ADDAX', '{DA529BFD-EABD-454C-B80E-DCAD555D1D62}', 1, NULL, 139, 1, 0, '{205C4E46-3442-43B4-8423-6A0582944B25}', 0),
	(140, 'Elgama_G3B', 'GAMA 300 (G3B)', '{CE3CFB4C-25B2-47BF-ADE6-162873B09A06}', 1, NULL, 140, 0, 0, NULL, 0),
	(141, 'EkoMera CEEO', 'EkoMera CEEO', '{BFED89B9-4C6D-4B26-A748-86B3F719FA96}', 1, NULL, 141, 0, 0, NULL, 0),
	(142, 'EMH_DMZ', 'EMH DMZ', '{BFED89B9-4C6D-4B26-A748-86B3F719FA96}', 1, NULL, 141, 0, 0, NULL, 0),
	(143, 'ACE6000', 'ACE-6000', '{042377EB-900B-4409-B460-66AB9AB4388C}', 1, NULL, 39, 0, 0, NULL, 0),
	(144, 'STDBService', 'STDBService', '{0F493C59-2902-4E49-81DB-5145FF78E4EA}', 1, NULL, 142, 0, 0, NULL, 0),
	(145, 'Energomera_CE102', 'CE102', '{08B50EAD-20F3-4AE4-9A68-42BC75E97AAA}', 1, NULL, 143, 0, 0, NULL, 0),
	(147, 'Elster_A1700', 'Elster A1700', '{65A61582-0ACA-4FF2-B942-A2467205EF10}', 1, NULL, 145, 0, 0, NULL, 0),
	(148, 'Elster_A1140_1120', 'Elster A1140', '{50A75B8F-4FD2-4FD0-B34E-BE34F96EF9EA}', 1, NULL, 185, 0, 0, NULL, 0),
	(151, 'Integral_V_MaXX', 'Actaris Integral-V MaXX', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 147, 0, 0, NULL, 0),
	(153, 'EMCOS_WEB_service', 'EMCOS WEB service', '{4C5530B2-CA7C-4974-BAC6-2D1D1AD6E65D}', 0, NULL, 149, 1, 0, NULL, 0),
	(154, 'Elster_A1800', 'Elster A1800', '{4752E8E7-FFC2-49D1-8968-11DB114B0D42}', 1, NULL, 145, 0, 0, NULL, 0),
	(157, 'Ekomera_EA52grn/1', 'Pafal EA52grn/1', '{BE3E5026-86F0-4505-96E9-861A61CC860D}', 1, NULL, 152, 0, 0, NULL, 0),
	(158, 'CARLO GAVAZZI_WM22_EM4', 'CARLO GAVAZZI WM22/EM4', '{958BB4D1-10B7-464F-9060-B7D8B88A8760}', 1, NULL, 153, 0, 0, NULL, 0),
	(160, 'VZEP_EE800x_2', 'VZEP EE800x/2', '{851A4358-3A30-4C20-B5BA-98CEB21A4527}', 1, NULL, 155, 0, 0, NULL, 0),
	(161, 'Circutor_CVM_96', 'Circutor CVM-96', '{26A6F7A4-7A70-44F6-9D46-894984842420}', 1, NULL, 156, 0, 0, NULL, 0),
	(162, 'ElgSist_MDC', 'MDC 1.01', '{16EF3887-860D-4695-9E8B-7386300C2C74}', 1, NULL, 157, 0, 0, NULL, 0),
	(163, 'SAYANY_APC_GPRS', 'SAYANY APC-GPRS', '{9B215E7E-C527-46F3-9943-FC0C76FA35F6}', 1, NULL, 158, 0, 0, NULL, 0),
	(165, 'ARGO', 'ARGO', '{9171BEB6-E81E-4B6E-A6C3-AD3F1C64CCD7}', 1, NULL, 161, 0, 0, NULL, 0),
	(166, 'Telecart_Energija_9', 'Telecart Energija-9', '{CAF6F2C4-1B24-4B0E-894E-74F63C642992}', 1, NULL, 162, 0, 0, NULL, 0),
	(167, 'Oblik_LO_3T', 'Oblik LO-3T', '{6603DFC3-E16C-47B5-9FA0-4D98909D1C10}', 1, NULL, 163, 0, 0, NULL, 0),
	(168, 'Elvin_ET', 'Elvin_ET', '{C4653AF1-75E8-4266-B80C-D8926EBDBD05}', 1, NULL, 164, 0, 0, NULL, 0),
	(169, 'UkrEnergo_30818', 'UkrEnergo (30818)', NULL, 0, NULL, 100169, 0, 0, NULL, 0),
	(170, 'UkrEnergo_30917', 'UkrEnergo (30917)', NULL, 0, NULL, 100170, 0, 0, NULL, 0),
	(171, 'UkrEnergo_30817', 'UkrEnergo (30817)', NULL, 0, NULL, 100171, 0, 0, NULL, 0),
	(174, 'Karat_Elf', 'Karat Elf', '{09F73418-4C93-4219-A1F2-6C05FCCF27D9}', 1, NULL, 166, 0, 0, NULL, 0),
	(179, 'Spirax_Sarco_M800', 'Spirax-Sarco M800', '{7AA32C98-A8B5-428C-B19B-A61D674AE2A0}', 1, NULL, 168, 0, 0, NULL, 0),
	(180, 'Wehrle_ETK_EAX', 'Wehrle ETK-EAX', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 169, 0, 0, NULL, 0),
	(181, 'ElgSist_MDC_EPQS', 'EPQS per MDC', '{16EF3887-860D-4695-9E8B-7386300C2C74}', 1, NULL, 157, 0, 0, NULL, 0),
	(182, 'ElgSist_MDC_EPQM', 'EPQM/LZQM/LZKM per MDC', '{16EF3887-860D-4695-9E8B-7386300C2C74}', 1, NULL, 157, 0, 0, NULL, 0),
	(183, 'ElgSist_MDC_EMS', 'EMS per MDC', '{16EF3887-860D-4695-9E8B-7386300C2C74}', 1, NULL, 157, 0, 0, NULL, 0),
	(184, 'ElgSist_MDC_GAMA', 'GAMA G3A per MDC', '{16EF3887-860D-4695-9E8B-7386300C2C74}', 1, NULL, 157, 0, 0, NULL, 0),
	(185, 'Teplokom_VKT_x', 'VKT-x', '{7418EDD1-97F0-4D30-80B8-69DA685DF254}', 1, NULL, 170, 0, 0, NULL, 0),
	(186, 'RTU-327', 'RTU-327', '{34A961F8-3F29-4294-A5B2-500548FF5B62}', 1, NULL, 171, 0, 0, NULL, 0),
	(187, 'Rail350', 'Rail350', '{530A7E9E-F2A8-4902-99AD-DA1B7D7C5528}', 1, NULL, 172, 0, 0, NULL, 0),
	(188, 'CC_101', 'CC-101', '{A68EAEB8-71AD-45A3-9439-57DADFBC9AF6}', 1, NULL, 103, 0, 0, NULL, 0),
	(189, 'ZE_311_DR', 'ZE 311.DR', '{D1442AEB-28EB-4285-8245-7D15FFA0FD30}', 1, NULL, 173, 0, 0, NULL, 0),
	(190, 'VALSENA_DKEG_2', 'VALSENA DKEG-2', '{2AABF372-0348-4408-9F20-7451A8AE1700}', 1, NULL, 174, 0, 0, NULL, 0),
	(191, 'HXE12_34', 'HXE12/34', '{9E934B8B-383D-4BD2-934E-7B313C6A32C7}', 1, NULL, 175, 0, 0, NULL, 0),
	(192, 'Kamstrup_382', 'Kamstrup 382', '{D2CF5662-D3DD-452B-9146-D912A4235CF4}', 1, NULL, 176, 0, 0, NULL, 0),
	(193, 'PCCI', 'PCCI', NULL, 0, NULL, 100193, 0, 0, NULL, 0),
	(195, 'Rubisafe_WS', 'Rubisafe WS', '{947BDD80-A0A5-4A0E-A954-39583E9FD65B}', 0, NULL, 178, 0, 0, NULL, 0),
	(197, 'Energomera_USPD_164_01M', 'Energomera 164-01M', '{75C0239A-8682-40E4-AD3A-BC331E3E6ECB}', 1, NULL, 137, 0, 0, NULL, 0),
	(200, 'Vzljot_TSRV_024M', 'Vzljot TSRV-024M', '{88783D79-5FF5-4DE1-B884-58F5060F3C9B}', 1, NULL, 182, 0, 0, NULL, 0),
	(202, 'SEM_3_CRC_RB', 'SEM-3 (CRC-RB)', '{BA994329-33F9-4244-A053-A4D4B58B04A8}', 1, NULL, 184, 0, 0, NULL, 0),
	(203, 'RiM_099', 'RiM099.02', '{F7DCB9BF-2A9F-48DF-857F-AC8B1492F2C0}', 1, NULL, 186, 0, 0, NULL, 0),
	(205, 'BIK_2_CONTROLLER', 'BIK-2 controller', '{132D3B4A-0707-46D6-BF71-682E81B2787F}', 1, NULL, 188, 0, 0, NULL, 0),
	(206, 'BIK_2_METER', 'BIK-2 meter', '{132D3B4A-0707-46D6-BF71-682E81B2787F}', 1, NULL, 188, 0, 0, NULL, 0),
	(207, 'USPD_164_CE303', 'CE303 per Energomera 164-01M', '{3B7EDA8E-1525-4A94-8B11-B71F39A98348}', 1, NULL, 135, 0, 0, NULL, 0),
	(208, 'USPD_164_CE102', 'CE102 per Energomera 164-01M', '{08B50EAD-20F3-4AE4-9A68-42BC75E97AAA}', 1, NULL, 143, 0, 0, NULL, 0),
	(209, 'Elgama_G1B', 'GAMA 100 (G1B)', '{CE3CFB4C-25B2-47BF-ADE6-162873B09A06}', 1, NULL, 140, 0, 0, NULL, 0),
	(210, 'Logika_SPT_961', 'SPT961', '{EC933664-DFF8-48C5-ADFA-EFB78E97F46A}', 1, NULL, 189, 0, 0, NULL, 0),
	(211, 'IVK_EnergijaWS', 'IVK Energija per Web Servisa', '{74D1ADFA-3808-43F5-BBE7-F528A8BEA6A9}', 0, NULL, 190, 1, 0, NULL, 0),
	(213, 'Eesti_Energia_CSV', 'Eesti Energia (CSV)', NULL, 0, NULL, 100213, 0, 0, NULL, 0),
	(214, 'Vzljot_TSRV_034', 'Vzljot TSRV-034', '{D51F4B52-9B03-4D58-B97F-4F47D36CCF3A}', 1, NULL, 192, 0, 0, NULL, 0),
	(215, 'ADD_SNMP_V3', 'ADD SNMPV3', '{0BC4130D-D758-43D1-A342-95E8FBEDB747}', 1, NULL, 193, 0, 0, NULL, 0),
	(216, 'IM2300_ModBus', 'IM2300-ImServer', '{041BF9FB-FFCA-4E3B-B85D-33E5EA0B626D}', 1, NULL, 54, 0, 0, NULL, 0),
	(217, 'Tekon_1x', 'Tekon-19', '{B479FC4B-24D4-4659-89E3-FD272530659A}', 1, NULL, 194, 0, 0, NULL, 0),
	(218, 'KM_x', 'KM-5', '{7CC61163-8528-43C7-AC7D-CFEC99C0BD95}', 1, NULL, 195, 0, 0, NULL, 0),
	(219, 'MsSQL_SADKO', 'DB SADKO', '{0355E69C-56DD-4DED-A5C3-A3703909119F}', 1, NULL, 106, 0, 0, NULL, 0),
	(220, 'Vzljot_TSRV_020_023', 'Vzljet TSRV-020(021, 022, 023)', '{967569BF-F430-4C81-B940-474D88DC3083}', 1, NULL, 196, 0, 0, NULL, 0),
	(221, 'Vzljet_TSRV_010', 'Vzljet TSRV-010', '{9A268927-F8F7-440A-900D-1F5FD434577B}', 1, NULL, 197, 0, 0, NULL, 0),
	(223, 'IM2300_ModBus_Vzljot', 'IM2300-Vzljet', '{041BF9FB-FFCA-4E3B-B85D-33E5EA0B626D}', 1, NULL, 54, 0, 0, NULL, 0),
	(224, 'IM2300_ModBus_AutomatedSolutions', 'IM2300-Automated Solutions', '{041BF9FB-FFCA-4E3B-B85D-33E5EA0B626D}', 1, NULL, 54, 0, 0, NULL, 0),
	(225, 'IM2300_ModBus_Other', 'IM2300-Other', '{041BF9FB-FFCA-4E3B-B85D-33E5EA0B626D}', 1, NULL, 54, 0, 0, NULL, 0),
	(226, 'STDBService_Composite', 'STDBService Composite', '{0F493C59-2902-4E49-81DB-5145FF78E4EA}', 1, NULL, 142, 0, 0, NULL, 0),
	(227, 'MsSQL_GISMETEO', 'GISMETEO DB', '{39B14CD9-BF29-4BDB-9D36-8D4ADB8095D2}', 1, NULL, 199, 0, 0, NULL, 0),
	(228, 'STDBService_H', 'STDBService H', '{0F493C59-2902-4E49-81DB-5145FF78E4EA}', 1, NULL, 142, 1, 0, NULL, 0),
	(229, 'STDBService_Composite_H', 'STDBService Composite H', '{0F493C59-2902-4E49-81DB-5145FF78E4EA}', 1, NULL, 142, 1, 0, NULL, 0),
	(231, 'ENERGOKRUG_DB', 'DB EnergoKrug', NULL, 0, NULL, 100231, 0, 0, NULL, 0),
	(232, 'ElgAMI_Ws', 'DMDC', '{E3A6B323-06DB-491D-A90E-E5F99A919494}', 1, NULL, 201, 0, 0, NULL, 0),
	(233, 'Globos_CSV', 'Globos (CSV)', NULL, 0, NULL, 100233, 0, 0, NULL, 0),
	(234, 'ESMOM_1', 'ESMON-1.x', '{A953EA64-A8B2-4ECD-920B-6B116DB4ACB5}', 1, NULL, 202, 0, 0, NULL, 0),
	(235, 'Indigo_Plus', 'Indigo+', '{14FA346B-8870-41E0-9FB6-2C647B43154E}', 1, NULL, 203, 0, 0, NULL, 0),
	(236, 'VTD_U', 'VTD-U', '{43224CE3-FD44-4999-A64F-B3A2823D0C56}', 1, NULL, 204, 0, 0, NULL, 0),
	(237, 'VRS_T', 'VRS-T', '{0DB9112C-B41B-44FF-BCE5-50E4458B0416}', 1, NULL, 205, 0, 0, NULL, 0),
	(238, 'Valsena_DK-x_gas', 'Valsena DK-x dujos', '{69190850-CFCE-4BE0-9DDE-8173934D63BE}', 1, NULL, 97, 0, 0, NULL, 0),
	(239, 'Valsena_DK-x_heat', 'Valsena DK-x šiluma', '{69190850-CFCE-4BE0-9DDE-8173934D63BE}', 1, NULL, 97, 0, 0, NULL, 0),
	(240, 'Valsena_DK-x_steam', 'Valsena DK-x garas', '{69190850-CFCE-4BE0-9DDE-8173934D63BE}', 1, NULL, 97, 0, 0, NULL, 0),
	(241, 'IEC-61968', 'IEC-61968', '{8D728F8C-E9BF-4B0E-963D-31975CBF1E03}', 1, NULL, 206, 0, 0, NULL, 0),
	(243, 'Energomera_USPD_164B', 'USPD 164-01B [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(244, 'Saiman_1000', 'Saiman-1000', '{E8A81FDF-7FEC-4D1E-9A9B-56AFC15B7860}', 1, NULL, 208, 0, 0, NULL, 0),
	(245, 'IEC_61968', 'IEC-61968', NULL, 0, NULL, 100245, 0, 0, NULL, 0),
	(246, 'Iskra_MT830', 'Iskra MT830', '{5AEBCCB5-69AA-400F-BEC0-65FFD045ED66}', 1, NULL, 209, 0, 0, NULL, 0),
	(248, 'ElgAMI_Ws_OnLine', 'DMDC OnLine', '{E3A6B323-06DB-491D-A90E-E5F99A919494}', 1, NULL, 201, 0, 0, NULL, 0),
	(249, 'NIK_2303', 'NIK 2303', '{3D7F313C-778C-495F-9C60-6AFCEDE9EF56}', 1, NULL, 211, 0, 0, NULL, 0),
	(250, 'Circutor_EDMK', 'Circutor EDMK', '{BBC067DE-48E2-44BB-B144-69C86552518F}', 1, NULL, 212, 0, 0, NULL, 0),
	(251, 'Mir_S03', 'MIR S-03', '{670DF1A7-E9C0-4979-846B-D75C1A9DD237}', 1, NULL, 213, 0, 1, NULL, 0),
	(252, 'CLOU_CL7331', 'CL7331', '{ADF58B58-92EF-48C6-B17F-6A58DAAABCD9}', 1, NULL, 214, 0, 0, NULL, 0),
	(253, 'MCL_5.8', 'MCL 5.8', '{B99BC113-9042-461F-804A-17CF0247E071}', 1, NULL, 215, 0, 0, NULL, 0),
	(255, 'MCL_5.5', 'MCL 5.5', '{B99BC113-9042-461F-804A-17CF0247E071}', 1, NULL, 215, 0, 0, NULL, 0),
	(256, 'MCL_5.0', 'MCL 5.0', '{B99BC113-9042-461F-804A-17CF0247E071}', 1, NULL, 215, 0, 0, NULL, 0),
	(257, 'Cyble', 'CYBLE', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 217, 0, 0, NULL, 0),
	(258, 'CE_Net', 'CE NetConnections [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(259, 'CE_102', 'CE102 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(260, 'CE_102M', 'CE102M [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(261, 'CE_201', 'CE201 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(262, 'CE_207', 'CE207 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(263, 'CE_208', 'CE208 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(264, 'CE_300', 'CE300 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(265, 'CE_301', 'CE301 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(266, 'CE_301m', 'CE301M [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(267, 'CE_302', 'CE302 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(268, 'CE_303', 'CE303 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(269, 'CE_304', 'CE304 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(270, 'CE_306', 'CE306 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(271, 'CE_805', 'CE805 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(272, 'CE_824', 'CE824 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(273, 'USPD164_01M_3_8', 'USPD 164-01M 3.8 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(274, 'USPD164_01M', 'USPD 164-01M [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(275, 'USPD164_01', 'USPD 164-01 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(276, 'USPD164_01I', 'USPD 164-01I [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(277, 'CE_6822', 'CE6822 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(278, 'CE_6822_v6', 'CE6822 v6 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(279, 'CE_6823M', 'CE6823M [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(280, 'CE_6850', 'CE6850 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(281, 'CE_6850M', 'CE6850M [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(282, 'Mir_USPD_01', 'MIR USPD-01[101]', '{D1B3E50E-D053-4909-952F-91CD7AE7788B}', 1, NULL, 218, 0, 0, NULL, 0),
	(283, 'Saiman_ORMAN_PLC', 'Saiman ORMAN [PLC]', '{C80317BB-B36A-42B4-AFF3-2A8B62CB892A}', 1, NULL, 219, 0, 0, NULL, 0),
	(284, 'Saiman_ORMAN_DALA_ModBus', 'Saiman ORMAN, DALA [ModBus]', '{39AE0BF4-DBCB-450F-B785-316DB9991180}', 1, NULL, 220, 0, 0, NULL, 0),
	(285, 'MCL_5.8.5', 'MCL 5.8.5', '{B99BC113-9042-461F-804A-17CF0247E071}', 1, NULL, 215, 0, 0, NULL, 0),
	(286, 'CVMk_L_C2', 'CVMk-L C2', '{26A6F7A4-7A70-44F6-9D46-894984842420}', 1, NULL, 156, 0, 0, NULL, 0),
	(287, 'TS_11', 'TS-11', '{0244CF4C-C278-48F8-9033-10136880D05F}', 1, NULL, 221, 0, 0, NULL, 0),
	(288, 'Saiman_DALA_PLC', 'Saiman DALA [PLC]', '{C80317BB-B36A-42B4-AFF3-2A8B62CB892A}', 1, NULL, 219, 0, 0, NULL, 0),
	(289, 'DneprOblEnergo_DB', 'DneprOblEnergo(DB)', NULL, 0, NULL, 100289, 0, 0, NULL, 0),
	(290, 'SEM_2_ESC', 'SEM-2 (ESC)', '{6F9C15CA-B1D6-4F56-BCF0-8DBAA9A4A077}', 1, NULL, 222, 0, 0, NULL, 0),
	(291, 'KSPD_x', 'KSPD-5', '{95CAAC02-E4F8-44A7-B905-80F5E7182E78}', 1, NULL, 223, 0, 0, NULL, 0),
	(292, 'Mirtek_x_RU', 'Mirtek_x_RU', '{C539A249-ABE7-4DB9-9133-7FD5A32B1DB5}', 1, NULL, 224, 0, 0, NULL, 0),
	(293, 'Valsena_DKEG_210', 'DKEG-210', '{2AABF372-0348-4408-9F20-7451A8AE1700}', 1, NULL, 225, 0, 0, NULL, 0),
	(294, 'Irvis_RI_x', 'Irvis RI-3|4|5', '{0033984B-05B0-4EBE-8F22-AEC8C5DAB038}', 1, NULL, 226, 0, 0, NULL, 0),
	(295, 'CVMk2', 'CVMk2-ITF', '{1CA5CF12-F82F-4E9F-88D3-5C0991461984}', 1, NULL, 225, 0, 0, NULL, 0),
	(296, 'EK_270', 'EK-270', '{B0543F85-750E-4190-8F29-30B16A952D21}', 1, NULL, 227, 0, 0, NULL, 0),
	(299, 'Corax', 'Corax', '{2C99C189-2A71-4A52-9DA9-886B4C17DC8A}', 1, NULL, 230, 0, 0, NULL, 0),
	(300, 'DJZ22', 'DJZ22', '{18568AC6-CC3B-47E2-9DA6-3AF31BF84268}', 1, NULL, 231, 0, 0, NULL, 0),
	(301, 'RMC621', 'Endress+Hauser RMC621', '{EFBA677F-C0E6-48BD-BADF-6B9409C8C184}', 1, NULL, 232, 0, 0, NULL, 0),
	(303, 'Valsena_Temperature', 'Valsena, Temperature sensor', '{07C76F4C-A4C0-49CB-A09B-99006218C01C}', 1, NULL, 234, 0, 0, NULL, 0),
	(305, 'SNG_1517', 'SNG-1517', NULL, 0, NULL, 100305, 0, 0, NULL, 0),
	(306, 'CE_208S7', 'CE208S7 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(307, 'CE_826', 'CE826 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(308, 'CE_901', 'CE901 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(337, 'Wasion_aMeter_x', 'Wasion aMeter', '{E7FE9073-77E6-4332-B6C8-E7A6DEB1D59A}', 1, NULL, 236, 0, 0, NULL, 0),
	(338, 'Katra_SKU_03', 'SKU-03', '{FC6D3DBB-6BCF-4CE4-BBDB-16402A0099A7}', 1, NULL, 237, 0, 0, NULL, 0),
	(339, 'Mir_USPD_01_ST104', 'MIR USPD-01[ST104]', '{FCC4B6C3-903C-404B-A1CA-87E918974653}', 1, NULL, 238, 0, 0, NULL, 0),
	(340, 'Universal_ModBus', 'Universal ModBus', '{CF602026-C77A-49E6-A0C5-4B8D85B10B01}', 1, NULL, 239, 0, 0, NULL, 0),
	(341, 'Universal_ModBus_Ovation', 'Ovation', '{CF602026-C77A-49E6-A0C5-4B8D85B10B01}', 1, NULL, 239, 0, 0, NULL, 0),
	(342, 'Mir_USPD_01_OM', 'MIR USPD-01[OM]', '{F97AF665-D43A-4974-A22C-3A7F759DEDC5}', 1, NULL, 240, 0, 0, NULL, 0),
	(344, 'Namjun_UCD_Q10', 'UCD-Q10', '{B495BEAE-68BB-430B-83B2-42CA5EF7E437}', 1, NULL, 242, 0, 0, NULL, 0),
	(346, 'CLOU_DLT645', 'DLT645(TE71,TE73)', '{693667E8-70DA-4729-B03C-A30B0C83C91D}', 1, NULL, 244, 0, 0, NULL, 0),
	(348, 'Comander_Multiport', 'Comander Multiport', '{98536177-9AA4-42EF-92E3-D669FE3C7E11}', 1, NULL, 246, 0, 0, NULL, 0),
	(349, 'ZE_114_DR', 'ZE 114.DR', '{614EA945-709C-48C1-9D98-B6E33BF0D3CD}', 1, NULL, 247, 0, 0, NULL, 0),
	(352, 'Pulsar_M', 'Pulsar-M', '{4F391CBE-5CA8-4070-9BFD-ABBB9A235880}', 1, NULL, 250, 0, 0, NULL, 0),
	(353, 'Mercury_250', 'Mercury-250', '{24A4B709-B8EA-4F92-BE9F-67E3ADD7BC81}', 1, NULL, 251, 0, 0, NULL, 0),
	(354, 'Ovation_KCB', 'Ovation-KCB', '{01BA8C37-5F3C-4876-9B2D-5725CAF71C28}', 1, NULL, 252, 0, 0, NULL, 0),
	(356, 'Saiman_P41xxx_PLC', 'Saiman P41xxx PLC', '{A1A9F08F-1AD1-40CD-BB1D-74851121A2EA}', 1, NULL, 254, 0, 0, NULL, 0),
	(357, 'Mercury_230_AR', 'Mercury 230 AR', '{2CC5AFAD-43BF-426C-9A26-6D9C70299B58}', 1, NULL, 35, 0, 0, NULL, 0),
	(358, 'Mercury_231', 'Mercury 231', '{2CC5AFAD-43BF-426C-9A26-6D9C70299B58}', 1, NULL, 35, 0, 0, NULL, 0),
	(359, 'Mercury_232', 'Mercury 232', '{2CC5AFAD-43BF-426C-9A26-6D9C70299B58}', 1, NULL, 35, 0, 0, NULL, 0),
	(360, 'Mercury_233', 'Mercury 233', '{2CC5AFAD-43BF-426C-9A26-6D9C70299B58}', 1, NULL, 35, 0, 0, NULL, 0),
	(361, 'Mercury_234', 'Mercury 234', '{2CC5AFAD-43BF-426C-9A26-6D9C70299B58}', 1, NULL, 35, 0, 0, NULL, 0),
	(362, 'Mercury_236', 'Mercury 236', '{2CC5AFAD-43BF-426C-9A26-6D9C70299B58}', 1, NULL, 35, 0, 0, NULL, 0),
	(363, 'MIT_5000_MG', 'MIT 5000 MG', '{686A8054-B34A-483B-9F67-5562243339C9}', 1, NULL, 255, 0, 0, NULL, 0),
	(364, 'ESO_EDP', 'ESO EDP (elektros duomenų portalas)', '{3A128090-EF50-4132-93B4-1CD4E3EAA8C7}', 1, NULL, 256, 0, 0, NULL, 0),
	(365, 'Termotronic_TV7', 'Termotronic TV7', '{8375E5CC-F740-4515-A3AB-38AC26A428D7}', 1, NULL, 257, 0, 0, NULL, 0),
	(366, 'Vzljot_TSRV_031', 'Vzljot TSRV-031 (032, 033)', '{D51F4B52-9B03-4D58-B97F-4F47D36CCF3A}', 1, NULL, 192, 0, 0, NULL, 0),
	(367, 'MIT_5000_MG_CLOU_DLT645', 'DLT645 per MIT 5000 MG', '{693667E8-70DA-4729-B03C-A30B0C83C91D}', 1, NULL, 244, 0, 0, NULL, 0),
	(369, 'Logika_SPT_941', 'SPT941', '{C7B2491C-3F79-4849-9E02-05F93B04CD24}', 1, NULL, 258, 0, 0, NULL, 0),
	(370, 'Mir_S04_Dlms', 'Mir S-04', '{EC892C16-4264-4693-9A1B-E448C4BBBC97}', 1, NULL, 259, 0, 0, NULL, 0),
	(371, 'Mir_S05_Dlms', 'Mir S-05', '{EC892C16-4264-4693-9A1B-E448C4BBBC97}', 1, NULL, 259, 0, 0, NULL, 0),
	(372, 'Mir_S07_Dlms', 'Mir S-07', '{EC892C16-4264-4693-9A1B-E448C4BBBC97}', 1, NULL, 259, 0, 0, NULL, 0),
	(373, 'Vzljot_URSV_5xx', 'Vzljot URSV 5xx', '{55F2E264-83D7-48FF-8D97-ED02D2659803}', 1, NULL, 260, 0, 0, NULL, 0),
	(374, 'CE_205', 'CE 205 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(375, 'CE_305', 'CE 305 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(376, 'CE_308', 'CE 308 [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(377, 'USPD_CE805M', 'CE805M [DLL]', '{9EDC9490-8DDF-4D4F-B7FE-60B6B5417898}', 1, NULL, 207, 0, 0, NULL, 0),
	(378, 'LogoScreen_NT', 'LogoScreen NT', '{508E2DE6-FD82-498A-91A6-D12B1311146C}', 1, NULL, 261, 0, 0, NULL, 0),
	(379, 'Elgama_DC12', 'Elgama DC12', '{DE243087-30FB-4FD9-A5C5-8733596E691F}', 1, NULL, 262, 0, 0, NULL, 0),
	(381, 'Unigas_300', 'Unigas-300', '{2ED30347-C2D0-4B69-9726-593FDB56E1E8}', 1, NULL, 264, 1, 0, NULL, 0),
	(382, 'NIK_2303E', 'NIK 2303E', '{3D7F313C-778C-495F-9C60-6AFCEDE9EF56}', 1, NULL, 211, 0, 0, NULL, 0),
	(383, 'MCL_5.10', 'MCL 5.10', '{B99BC113-9042-461F-804A-17CF0247E071}', 1, NULL, 215, 0, 0, NULL, 0),
	(384, 'Valsena_DKK_64', 'DKK-64', '{DB84004E-DBCF-4F90-8DE5-C9A30C1F3DD0}', 1, NULL, 265, 1, 0, NULL, 0),
	(385, 'PLUM_MacBAT_III', 'MacBAT III', '{B8E18CAA-AC5D-437E-AAA8-5AC90B203F24}', 1, NULL, 266, 1, 0, NULL, 0),
	(386, 'PLUM_MacBATe', 'MacBATe', '{B8E18CAA-AC5D-437E-AAA8-5AC90B203F24}', 1, NULL, 266, 1, 0, NULL, 0),
	(387, 'PLUM_MacMAT_IIA', 'MacMAT IIA', '{B8E18CAA-AC5D-437E-AAA8-5AC90B203F24}', 1, NULL, 266, 1, 0, NULL, 0);
/*!40000 ALTER TABLE `src_type` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_growth
CREATE TABLE IF NOT EXISTS `src_type_growth` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `growth_limit` double NOT NULL COMMENT 'Augimo riba',
  PRIMARY KEY (`src_type_id`),
  CONSTRAINT `src_type_growth_src_type_fk` FOREIGN KEY (`src_type_id`) REFERENCES `src_type` (`src_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų šaltinių tipų suminių matavimų augimo ribos';

-- Dumping data for table emcor.src_type_growth: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_type_growth` DISABLE KEYS */;
INSERT INTO `src_type_growth` (`src_type_id`, `growth_limit`) VALUES
	(105, 10000);
/*!40000 ALTER TABLE `src_type_growth` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_important_withe
CREATE TABLE IF NOT EXISTS `src_type_important_withe` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `is_point` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  `withe_id` mediumint(8) DEFAULT NULL COMMENT 'Duomenų vytelės identifikatorius',
  UNIQUE KEY `src_type_important_withe_u` (`src_type_id`,`is_point`,`withe_id`),
  KEY `src_type_important_withe_w_fk` (`withe_id`),
  CONSTRAINT `src_type_important_withe_t_fk` FOREIGN KEY (`src_type_id`) REFERENCES `src_type` (`src_type_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_important_withe_w_fk` FOREIGN KEY (`withe_id`) REFERENCES `withe` (`withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Šaltinių tipų prietaisų svarbūs konfigūraciniai parametrai';

-- Dumping data for table emcor.src_type_important_withe: ~136 rows (approximately)
/*!40000 ALTER TABLE `src_type_important_withe` DISABLE KEYS */;
INSERT INTO `src_type_important_withe` (`src_type_id`, `is_point`, `withe_id`) VALUES
	(1, 1, -50055),
	(1, 1, -50054),
	(1, 1, -50044),
	(1, 1, -50038),
	(1, 1, -50037),
	(1, 1, -50036),
	(1, 1, -50035),
	(1, 1, -50034),
	(1, 1, -50033),
	(1, 1, -50020),
	(1, 1, -50019),
	(1, 1, -50018),
	(1, 1, -50017),
	(1, 1, -50016),
	(1, 1, -50015),
	(1, 1, -50014),
	(1, 1, -50013),
	(1, 1, -50012),
	(1, 1, -50011),
	(1, 1, -50008),
	(1, 1, -50005),
	(1, 1, -8),
	(25, 1, -50055),
	(25, 1, -50054),
	(25, 1, -50026),
	(25, 1, -50025),
	(25, 1, -50020),
	(25, 1, -50019),
	(25, 1, -50018),
	(25, 1, -50017),
	(25, 1, -50016),
	(25, 1, -50015),
	(25, 1, -50014),
	(25, 1, -50013),
	(25, 1, -50012),
	(25, 1, -50011),
	(25, 1, -50010),
	(25, 1, -50008),
	(25, 1, -50006),
	(25, 1, -50005),
	(25, 1, -13),
	(25, 1, -10),
	(25, 1, -9),
	(25, 1, -8),
	(30, 1, -50055),
	(30, 1, -50054),
	(30, 1, -50044),
	(30, 1, -50038),
	(30, 1, -50037),
	(30, 1, -50036),
	(30, 1, -50035),
	(30, 1, -50034),
	(30, 1, -50033),
	(30, 1, -50020),
	(30, 1, -50019),
	(30, 1, -50018),
	(30, 1, -50017),
	(30, 1, -50016),
	(30, 1, -50015),
	(30, 1, -50014),
	(30, 1, -50013),
	(30, 1, -50012),
	(30, 1, -50011),
	(30, 1, -50008),
	(30, 1, -50005),
	(30, 1, -8),
	(33, 1, -50117),
	(33, 1, -50077),
	(33, 1, -50062),
	(33, 1, -50061),
	(33, 1, -50060),
	(33, 1, -50059),
	(33, 1, -12),
	(33, 1, -11),
	(33, 1, -10),
	(33, 1, -9),
	(33, 1, -8),
	(33, 1, -3),
	(51, 1, -50055),
	(51, 1, -50054),
	(51, 1, -50044),
	(51, 1, -50038),
	(51, 1, -50037),
	(51, 1, -50036),
	(51, 1, -50035),
	(51, 1, -50034),
	(51, 1, -50033),
	(51, 1, -50020),
	(51, 1, -50019),
	(51, 1, -50018),
	(51, 1, -50017),
	(51, 1, -50016),
	(51, 1, -50015),
	(51, 1, -50014),
	(51, 1, -50013),
	(51, 1, -50012),
	(51, 1, -50011),
	(51, 1, -50008),
	(51, 1, -50005),
	(51, 1, -8),
	(103, 1, NULL),
	(127, 1, -50026),
	(127, 1, -50025),
	(127, 1, -50024),
	(127, 1, -50020),
	(127, 1, -50019),
	(127, 1, -50018),
	(127, 1, -50017),
	(127, 1, -50016),
	(127, 1, -50015),
	(127, 1, -50014),
	(127, 1, -50013),
	(127, 1, -50012),
	(127, 1, -50011),
	(127, 1, -50010),
	(127, 1, -50008),
	(127, 1, -50006),
	(127, 1, -50005),
	(127, 1, -13),
	(127, 1, -10),
	(127, 1, -9),
	(127, 1, -8),
	(135, 1, NULL),
	(139, 1, NULL),
	(140, 1, NULL),
	(145, 1, NULL),
	(157, 1, NULL),
	(185, 1, NULL),
	(188, 1, NULL),
	(189, 1, NULL),
	(200, 1, NULL),
	(207, 1, NULL),
	(208, 1, NULL),
	(209, 1, NULL),
	(232, 1, NULL),
	(248, 1, NULL);
/*!40000 ALTER TABLE `src_type_important_withe` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_lpty
CREATE TABLE IF NOT EXISTS `src_type_lpty` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  `src_lpty_nr` smallint(5) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio tipo galimos savybės eilės numeris rušiavimui',
  `src_lpty_usage` tinyint(3) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio tipo galimos savybės naudojimo požymis',
  `src_lpty_filter` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Duomenų šaltinio tipo galimos savybės filtravimo požymis',
  `src_lpty_default_value` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Nurodyto tipo duomenų šaltinio galimos savybės reikšmė pagal nutylėjimą',
  `src_lpty_forced_value` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Nurodyto tipo duomenų šaltinių savybės fiksuota reikšmė',
  `lpty_numeric` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Savybės reikšmė yra skaitinė',
  `lpty_regex` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'Savybės reikšmės raktas',
  `lpty_min` double DEFAULT NULL COMMENT 'Savybės reikšmės minimumas',
  `lpty_max` double DEFAULT NULL COMMENT 'Savybės reikšmės maksimumas',
  PRIMARY KEY (`src_type_id`,`lpty_id`),
  KEY `src_type_lpty_enum_i` (`enum_id`),
  KEY `src_type_lpty_lpty_i` (`lpty_id`),
  CONSTRAINT `src_type_lpty_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`),
  CONSTRAINT `src_type_lpty_lpty_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_lpty_src_type_fk` FOREIGN KEY (`src_type_id`) REFERENCES `src_type` (`src_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Nurodyto tipo duomenų šaltinių galimos savybės';

-- Dumping data for table emcor.src_type_lpty: ~2 414 rows (approximately)
/*!40000 ALTER TABLE `src_type_lpty` DISABLE KEYS */;
INSERT INTO `src_type_lpty` (`src_type_id`, `lpty_id`, `enum_id`, `src_lpty_nr`, `src_lpty_usage`, `src_lpty_filter`, `src_lpty_default_value`, `src_lpty_forced_value`, `lpty_numeric`, `lpty_regex`, `lpty_min`, `lpty_max`) VALUES
	(-4, 37, 903, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(-4, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(-4, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(-4, 108, NULL, NULL, 3, 0, '2000', NULL, 0, NULL, NULL, NULL),
	(-4, 164, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(-4, 165, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(-4, 195, 82, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(-4, 386, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(-4, 466, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(-4, 499, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(-4, 500, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(-3, 107, 882, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(-3, 195, 82, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(-3, 455, 889, NULL, 3, 0, '2', NULL, 0, NULL, NULL, NULL),
	(-3, 456, 889, NULL, 3, 0, '2', NULL, 0, NULL, NULL, NULL),
	(-3, 457, 890, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(-3, 458, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(-3, 459, 882, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(-3, 460, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(-3, 464, 882, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(-3, 465, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(-3, 466, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(-2, 189, NULL, 10, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(-2, 190, NULL, 20, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(-2, 191, NULL, 30, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(-2, 192, NULL, 50, 3, 0, '500', NULL, 0, NULL, NULL, NULL),
	(-2, 193, NULL, 40, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(-2, 194, NULL, 10, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(-2, 195, 82, 20, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(-1, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(-1, 108, NULL, NULL, 3, 0, '1000', NULL, 0, NULL, NULL, NULL),
	(-1, 199, NULL, NULL, 3, 0, '7000', NULL, 0, NULL, NULL, NULL),
	(-1, 200, NULL, NULL, 3, 0, '10000', NULL, 0, NULL, NULL, NULL),
	(-1, 201, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(-1, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(0, 151, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(0, 355, 781, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(1, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(1, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(1, 108, NULL, NULL, 3, 0, '30', NULL, 0, NULL, NULL, NULL),
	(1, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(1, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(1, 199, NULL, NULL, 3, 0, '7000', NULL, 0, NULL, NULL, NULL),
	(1, 200, NULL, NULL, 3, 0, '10000', NULL, 0, NULL, NULL, NULL),
	(1, 201, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(1, 230, 539, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(1, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(4, 18, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(4, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(4, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(4, 101, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(4, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(4, 123, 395, NULL, 2, 0, '11309', NULL, 0, NULL, NULL, NULL),
	(4, 222, 82, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(4, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(14, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(14, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(14, 101, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(14, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(14, 123, 396, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(14, 222, 82, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(14, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(24, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(24, 104, 83, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(24, 108, NULL, NULL, 3, 0, '30', NULL, 0, NULL, NULL, NULL),
	(24, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(24, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(24, 170, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(24, 199, NULL, NULL, 3, 0, '7000', NULL, 0, NULL, NULL, NULL),
	(24, 200, NULL, NULL, 3, 0, '10000', NULL, 0, NULL, NULL, NULL),
	(24, 201, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(24, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(25, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(25, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(25, 105, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(25, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(25, 108, NULL, NULL, 3, 0, '30', NULL, 0, NULL, NULL, NULL),
	(25, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(25, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(25, 199, NULL, NULL, 3, 0, '7000', NULL, 0, NULL, NULL, NULL),
	(25, 200, NULL, NULL, 3, 0, '10000', NULL, 0, NULL, NULL, NULL),
	(25, 201, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(25, 202, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(25, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(26, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(26, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(30, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(30, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(30, 108, NULL, NULL, 3, 0, '30', NULL, 0, NULL, NULL, NULL),
	(30, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(30, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(30, 199, NULL, NULL, 3, 0, '7000', NULL, 0, NULL, NULL, NULL),
	(30, 200, NULL, NULL, 3, 0, '10000', NULL, 0, NULL, NULL, NULL),
	(30, 201, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(30, 230, 539, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(30, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(32, 24, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(32, 26, NULL, NULL, 3, 0, '16', NULL, 0, NULL, NULL, NULL),
	(32, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 18, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 108, NULL, NULL, 3, 0, '30', NULL, 0, NULL, NULL, NULL),
	(33, 109, NULL, NULL, 2, 0, NULL, NULL, 0, '^[0-9]d*(.d+)?$', NULL, NULL),
	(33, 110, NULL, NULL, 2, 0, NULL, NULL, 0, '^[0-9]d*(.d+)?$', NULL, NULL),
	(33, 111, NULL, NULL, 2, 0, NULL, NULL, 0, '^[0-9]d*(.d+)?$', NULL, NULL),
	(33, 112, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(33, 199, NULL, NULL, 3, 0, '7000', NULL, 0, NULL, NULL, NULL),
	(33, 200, NULL, NULL, 3, 0, '10000', NULL, 0, NULL, NULL, NULL),
	(33, 201, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(33, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(33, 498, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(35, 13, 441, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(35, 14, NULL, NULL, 3, 0, '111111', NULL, 0, NULL, NULL, NULL),
	(35, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 105, NULL, NULL, 3, 0, NULL, '2', 0, NULL, NULL, NULL),
	(35, 124, 535, NULL, 3, 0, '-1', NULL, 0, NULL, NULL, NULL),
	(35, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 228, NULL, NULL, 3, 0, '222222', NULL, 0, NULL, NULL, NULL),
	(35, 229, 525, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 242, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 245, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 246, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 247, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 248, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 249, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(35, 476, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(38, 14, NULL, NULL, 3, 0, '00000000', NULL, 0, NULL, NULL, NULL),
	(38, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(38, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(38, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(38, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(38, 221, NULL, NULL, 3, 0, '6', NULL, 0, NULL, NULL, NULL),
	(38, 227, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(38, 243, NULL, NULL, 3, 0, '500', NULL, 0, NULL, NULL, NULL),
	(39, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(39, 24, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(39, 25, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(39, 26, NULL, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(39, 28, NULL, NULL, 0, 0, '0', NULL, 0, NULL, NULL, NULL),
	(39, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(39, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(39, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(39, 259, NULL, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(39, 491, NULL, NULL, 3, 1, '0000630100FF', NULL, 0, NULL, NULL, NULL),
	(42, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(42, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(42, 101, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(42, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(42, 123, 397, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(42, 222, 82, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(42, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(51, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(51, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(51, 108, NULL, NULL, 3, 0, '30', NULL, 0, NULL, NULL, NULL),
	(51, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(51, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(51, 199, NULL, NULL, 3, 0, '7000', NULL, 0, NULL, NULL, NULL),
	(51, 200, NULL, NULL, 3, 0, '10000', NULL, 0, NULL, NULL, NULL),
	(51, 201, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(51, 230, 539, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(51, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(52, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(52, 37, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(52, 61, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(53, 13, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(53, 14, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(53, 37, NULL, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(53, 61, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(53, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(53, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(53, 232, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(53, 379, NULL, NULL, 3, 0, '480', NULL, 0, NULL, NULL, NULL),
	(54, 61, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(56, 14, NULL, NULL, 1, 0, '517289', NULL, 0, NULL, NULL, NULL),
	(56, 18, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(56, 29, NULL, NULL, 1, 0, '30', NULL, 0, NULL, NULL, NULL),
	(56, 61, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(56, 102, NULL, NULL, 1, 0, '30', NULL, 0, NULL, NULL, NULL),
	(56, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(57, 61, NULL, NULL, 1, 0, '$FE', NULL, 0, NULL, NULL, NULL),
	(57, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(58, 14, NULL, NULL, 1, 0, '517289', NULL, 0, NULL, NULL, NULL),
	(58, 18, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(58, 29, NULL, NULL, 1, 0, '30', NULL, 0, NULL, NULL, NULL),
	(58, 61, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(58, 102, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(58, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(59, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(59, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(59, 101, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(59, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(59, 123, 398, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(59, 222, 82, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(59, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(61, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(61, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(61, 101, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(61, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(61, 123, 399, NULL, 2, 0, '19875', NULL, 0, NULL, NULL, NULL),
	(61, 222, 82, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(61, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(62, 18, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(62, 61, NULL, NULL, 1, 0, '$FE', NULL, 0, NULL, NULL, NULL),
	(62, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(63, 13, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(63, 14, NULL, NULL, 1, 0, '1234', NULL, 0, NULL, NULL, NULL),
	(63, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(63, 61, NULL, NULL, 1, 0, '0', NULL, 0, NULL, NULL, NULL),
	(63, 125, NULL, NULL, 1, 0, '0', NULL, 0, NULL, NULL, NULL),
	(63, 126, NULL, NULL, 1, 0, '0', NULL, 0, NULL, NULL, NULL),
	(63, 158, 377, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(63, 164, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(63, 165, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(64, 30, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(64, 31, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(64, 61, NULL, NULL, 1, 0, '0', NULL, 0, NULL, NULL, NULL),
	(66, 13, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(66, 14, NULL, NULL, 1, 0, '321654', NULL, 0, NULL, NULL, NULL),
	(66, 15, NULL, NULL, 1, 0, '608', NULL, 0, NULL, NULL, NULL),
	(66, 16, NULL, NULL, 1, 0, '100', NULL, 0, NULL, NULL, NULL),
	(66, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 61, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(67, 473, NULL, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(68, 14, NULL, NULL, 3, 0, '000000', NULL, 0, NULL, NULL, NULL),
	(68, 37, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(68, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(68, 105, 381, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(68, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(68, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(68, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(68, 473, NULL, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(69, 14, NULL, NULL, 3, 0, '000000', NULL, 0, NULL, NULL, NULL),
	(69, 37, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(69, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(69, 105, 382, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(69, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(69, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(69, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(69, 473, NULL, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(70, 18, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(70, 61, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(71, 18, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(71, 20, 744, NULL, 3, 0, '240', NULL, 0, NULL, NULL, NULL),
	(71, 32, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(71, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(71, 171, NULL, NULL, 3, 0, '4800', NULL, 0, NULL, NULL, NULL),
	(71, 332, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(72, 18, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(72, 20, 744, NULL, 3, 0, '240', NULL, 0, NULL, NULL, NULL),
	(72, 32, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(72, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(72, 171, NULL, NULL, 3, 0, '4800', NULL, 0, NULL, NULL, NULL),
	(72, 332, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(73, 18, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(73, 20, 744, NULL, 3, 0, '240', NULL, 0, NULL, NULL, NULL),
	(73, 32, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(73, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(73, 171, NULL, NULL, 3, 0, '4800', NULL, 0, NULL, NULL, NULL),
	(73, 332, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(75, 18, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(75, 35, NULL, NULL, 1, 0, '0', NULL, 0, NULL, NULL, NULL),
	(75, 61, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(76, 18, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(76, 20, 744, NULL, 3, 0, '240', NULL, 0, NULL, NULL, NULL),
	(76, 32, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(76, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(76, 171, NULL, NULL, 3, 0, '4800', NULL, 0, NULL, NULL, NULL),
	(76, 332, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(77, 13, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(77, 14, NULL, NULL, 1, 0, '1234', NULL, 0, NULL, NULL, NULL),
	(77, 18, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(77, 126, NULL, NULL, 1, 0, '0', NULL, 0, NULL, NULL, NULL),
	(77, 129, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(77, 164, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(77, 165, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(77, 522, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(78, 13, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(78, 14, NULL, NULL, 1, 0, '1234', NULL, 0, NULL, NULL, NULL),
	(78, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(78, 61, NULL, NULL, 1, 0, '0', NULL, 0, NULL, NULL, NULL),
	(78, 125, NULL, NULL, 1, 0, '0', NULL, 0, NULL, NULL, NULL),
	(78, 126, NULL, NULL, 1, 0, '0', NULL, 0, NULL, NULL, NULL),
	(78, 158, 377, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(78, 164, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(78, 165, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(79, 14, NULL, NULL, 3, 0, '000000', NULL, 0, NULL, NULL, NULL),
	(79, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(79, 105, 383, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(79, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(79, 473, NULL, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(80, 14, NULL, NULL, 3, 0, '000000', NULL, 0, NULL, NULL, NULL),
	(80, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(80, 105, 384, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(80, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(80, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(80, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(80, 473, NULL, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(81, 13, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 15, NULL, NULL, 3, 0, '512', NULL, 0, NULL, NULL, NULL),
	(81, 16, NULL, NULL, 3, 0, '100', NULL, 0, NULL, NULL, NULL),
	(81, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 20, NULL, NULL, 3, 0, '7.0', NULL, 0, NULL, NULL, NULL),
	(81, 27, NULL, NULL, 3, 0, '60', NULL, 0, NULL, NULL, NULL),
	(81, 28, NULL, NULL, 3, 0, '1800', NULL, 0, NULL, NULL, NULL),
	(81, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(81, 164, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(81, 165, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(81, 188, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(81, 406, 82, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(81, 409, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(81, 473, NULL, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(82, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(82, 30, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(82, 31, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(82, 36, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(82, 102, NULL, NULL, 1, 0, '5000', NULL, 0, NULL, NULL, NULL),
	(85, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(85, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(85, 101, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(85, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(85, 123, 400, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(85, 222, 82, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(85, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(86, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(86, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(86, 101, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(86, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(86, 123, 401, NULL, 2, 0, '12901', NULL, 0, NULL, NULL, NULL),
	(86, 222, 82, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(86, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(87, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 21, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 61, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(87, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 107, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 158, 542, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(87, 223, 522, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(88, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(88, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(88, 101, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(88, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(88, 123, 402, NULL, 2, 0, '12901', NULL, 0, NULL, NULL, NULL),
	(88, 222, 82, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(88, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(89, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(89, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(89, 101, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(89, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(89, 123, 403, NULL, 2, 0, '19630', NULL, 0, NULL, NULL, NULL),
	(89, 222, 82, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(89, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(90, 61, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(91, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(91, 20, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(91, 21, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(91, 61, NULL, NULL, 1, 0, '0', NULL, 0, NULL, NULL, NULL),
	(92, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(92, 20, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(92, 21, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(92, 61, NULL, NULL, 1, 0, '0', NULL, 0, NULL, NULL, NULL),
	(93, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(93, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(94, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(94, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(94, 101, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(94, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(94, 123, 404, NULL, 2, 0, '12901', NULL, 0, NULL, NULL, NULL),
	(94, 222, 82, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(94, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(95, 61, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(96, 18, NULL, NULL, 1, 1, '1', NULL, 0, NULL, NULL, NULL),
	(96, 20, NULL, NULL, 1, 0, NULL, '1', 0, NULL, NULL, NULL),
	(96, 21, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(96, 61, NULL, NULL, 1, 0, '0', NULL, 0, NULL, NULL, NULL),
	(96, 357, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(97, 18, NULL, NULL, 1, 1, '1', NULL, 0, NULL, NULL, NULL),
	(97, 20, NULL, NULL, 1, 0, NULL, '2', 0, NULL, NULL, NULL),
	(97, 21, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(97, 61, NULL, NULL, 1, 0, '0', NULL, 0, NULL, NULL, NULL),
	(97, 107, NULL, NULL, 1, 1, '1', NULL, 0, NULL, NULL, NULL),
	(97, 357, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(98, 20, NULL, NULL, 3, 0, '$FF', NULL, 0, NULL, NULL, NULL),
	(98, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(98, 101, NULL, NULL, 3, 0, '$FF', NULL, 0, NULL, NULL, NULL),
	(98, 105, 84, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(98, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(99, 13, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(99, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(99, 61, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(100, 18, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(101, 14, NULL, NULL, 3, 0, 'stuspd', NULL, 0, NULL, NULL, NULL),
	(101, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(101, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(101, 105, 431, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(101, 117, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(101, 119, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(101, 149, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(101, 150, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(101, 152, 251, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(101, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(101, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(101, 250, NULL, NULL, 3, 0, '4', NULL, 0, NULL, NULL, NULL),
	(102, 14, NULL, NULL, 3, 0, '1234', NULL, 0, NULL, NULL, NULL),
	(102, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(102, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(102, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(102, 120, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(102, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(102, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(102, 473, NULL, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(103, 14, NULL, NULL, 3, 0, '00000000', NULL, 0, NULL, NULL, NULL),
	(103, 20, NULL, NULL, 3, 0, '1.43', NULL, 0, NULL, NULL, NULL),
	(103, 28, NULL, NULL, 3, 1, '1800', NULL, 0, NULL, NULL, NULL),
	(103, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(103, 105, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(103, 153, NULL, NULL, 3, 0, '1', NULL, 0, '^[0-9]d*(.d+)?$', NULL, NULL),
	(103, 154, NULL, NULL, 3, 0, '1', NULL, 0, '^[0-9]d*(.d+)?$', NULL, NULL),
	(103, 155, NULL, NULL, 3, 0, '1', NULL, 0, '^[0-9]d*(.d+)?$', NULL, NULL),
	(103, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(103, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(104, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(104, 159, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(104, 160, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(104, 161, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(104, 162, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(105, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(105, 21, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(105, 61, NULL, NULL, 3, 0, '2FFF', NULL, 0, NULL, NULL, NULL),
	(105, 124, NULL, NULL, 3, 0, '-1', NULL, 0, NULL, NULL, NULL),
	(105, 242, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(105, 244, 538, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(105, 245, NULL, NULL, 3, 0, '3000', NULL, 0, NULL, NULL, NULL),
	(105, 246, 543, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(105, 247, 544, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(105, 248, 545, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(105, 249, 546, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 18, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 132, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 134, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 136, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 138, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 140, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 142, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 144, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 146, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 147, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 148, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(106, 158, NULL, NULL, 1, 1, '1', NULL, 0, NULL, NULL, NULL),
	(115, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(115, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(115, 101, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(115, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(115, 123, 393, NULL, 2, 0, '18604', NULL, 0, NULL, NULL, NULL),
	(115, 222, 82, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(115, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(116, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(116, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(116, 101, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(116, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(116, 123, 405, NULL, 2, 0, '12967', NULL, 0, NULL, NULL, NULL),
	(116, 222, 82, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(116, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(117, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(117, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(117, 21, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(117, 61, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(117, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(117, 107, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(117, 158, 542, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(117, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(117, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 21, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 61, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(118, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 107, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 158, 542, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(118, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(119, 34, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(119, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(119, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(120, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(121, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(121, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(121, 101, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(121, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(121, 123, 394, NULL, 2, 0, '4307', NULL, 0, NULL, NULL, NULL),
	(121, 222, 82, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(121, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(122, 61, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(123, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(123, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(123, 101, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(123, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(123, 123, 391, NULL, 2, 0, '4307', NULL, 0, NULL, NULL, NULL),
	(123, 222, 82, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(123, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(124, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(124, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(124, 101, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(124, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(124, 123, 392, NULL, 2, 0, '20173', NULL, 0, NULL, NULL, NULL),
	(124, 222, 82, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(124, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(125, 14, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(125, 61, NULL, NULL, NULL, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(126, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(126, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(126, 101, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(126, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(126, 123, 411, NULL, 2, 0, '1143', NULL, 0, NULL, NULL, NULL),
	(126, 222, 82, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(126, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(127, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(127, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(127, 105, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(127, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(127, 108, NULL, NULL, 3, 0, '30', NULL, 0, NULL, NULL, NULL),
	(127, 164, NULL, NULL, 3, 1, '5', NULL, 0, NULL, NULL, NULL),
	(127, 165, NULL, NULL, 3, 1, '1800', NULL, 0, NULL, NULL, NULL),
	(127, 199, NULL, NULL, 3, 0, '7000', NULL, 0, NULL, NULL, NULL),
	(127, 200, NULL, NULL, 3, 0, '10000', NULL, 0, NULL, NULL, NULL),
	(127, 201, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(127, 202, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(127, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(128, 166, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(128, 167, NULL, NULL, 3, 0, '*$$DeviceNumber$$*$$FileDateMask$$*', NULL, 0, NULL, NULL, NULL),
	(128, 168, NULL, NULL, 3, 0, 'YYYY_MM_DD', NULL, 0, NULL, NULL, NULL),
	(128, 169, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(128, 183, 466, NULL, 3, 0, '2', NULL, 0, NULL, NULL, NULL),
	(128, 184, 466, NULL, 3, 0, '2', NULL, 0, NULL, NULL, NULL),
	(128, 185, NULL, NULL, 3, 0, '*$$DeviceNumber$$*$$FileDateMask$$*', NULL, 0, NULL, NULL, NULL),
	(128, 186, NULL, NULL, 3, 0, 'YYYY_MM_DD', NULL, 0, NULL, NULL, NULL),
	(129, 14, NULL, NULL, 3, 0, '1111', NULL, 0, NULL, NULL, NULL),
	(129, 61, NULL, NULL, 1, 0, '0', NULL, 0, NULL, NULL, NULL),
	(129, 172, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(129, 173, NULL, NULL, 1, 0, '0', NULL, 0, NULL, NULL, NULL),
	(129, 174, NULL, NULL, 3, 0, '1.43', NULL, 0, NULL, NULL, NULL),
	(129, 175, NULL, NULL, 3, 0, '1800', NULL, 0, NULL, NULL, NULL),
	(129, 176, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(129, 177, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(129, 178, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(130, 14, NULL, NULL, 3, 0, '1111', NULL, 0, NULL, NULL, NULL),
	(130, 18, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(130, 61, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(130, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(130, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(130, 180, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(131, 105, 442, NULL, 1, 0, '36', NULL, 0, NULL, NULL, NULL),
	(131, 119, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(131, 158, NULL, NULL, 1, 0, '131', NULL, 0, NULL, NULL, NULL),
	(131, 171, NULL, NULL, 1, 0, '4800', NULL, 0, NULL, NULL, NULL),
	(134, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 20, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 61, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 228, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(135, 354, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(135, 379, NULL, NULL, 3, 0, '24', NULL, 0, NULL, NULL, NULL),
	(136, 14, NULL, NULL, 1, 0, '111111', NULL, 0, NULL, NULL, NULL),
	(136, 164, NULL, NULL, 1, 1, '0', NULL, 0, NULL, NULL, NULL),
	(136, 165, NULL, NULL, 1, 1, '0', NULL, 0, NULL, NULL, NULL),
	(137, 13, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 18, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 20, NULL, NULL, 3, 0, '3.8', NULL, 0, NULL, NULL, NULL),
	(137, 37, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 105, NULL, NULL, 1, 0, '0', '0', 0, NULL, NULL, NULL),
	(137, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 119, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(137, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 224, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(137, 232, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(137, 294, 689, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(139, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 20, NULL, NULL, 3, 0, '7', NULL, 0, NULL, NULL, NULL),
	(139, 102, NULL, NULL, 4, 0, '30', NULL, 0, NULL, NULL, NULL),
	(139, 188, 525, NULL, 3, 0, 'FALSE', NULL, 0, NULL, NULL, NULL),
	(139, 254, NULL, NULL, 3, 0, '5', NULL, 0, NULL, NULL, NULL),
	(139, 255, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 256, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 257, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 258, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 259, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 263, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 264, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 265, 581, NULL, 3, 0, 'P3.2', NULL, 0, NULL, NULL, NULL),
	(139, 286, NULL, NULL, 3, 1, '3', NULL, 0, NULL, NULL, NULL),
	(139, 287, NULL, NULL, 3, 1, '2', NULL, 0, NULL, NULL, NULL),
	(139, 288, NULL, NULL, 3, 1, '0000636200FF', NULL, 0, NULL, NULL, NULL),
	(139, 289, NULL, NULL, 3, 1, '0000636201FF', NULL, 0, NULL, NULL, NULL),
	(139, 290, NULL, NULL, 3, 1, '0000636202FF', NULL, 0, NULL, NULL, NULL),
	(139, 291, NULL, NULL, 3, 1, '0000636204FF', NULL, 0, NULL, NULL, NULL),
	(139, 293, NULL, NULL, 3, 0, '10', NULL, 0, NULL, NULL, NULL),
	(139, 387, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 404, NULL, NULL, 3, 0, '900', NULL, 0, NULL, NULL, NULL),
	(139, 405, NULL, NULL, 3, 0, '360', NULL, 0, NULL, NULL, NULL),
	(139, 480, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 481, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 482, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 483, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 484, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 485, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(139, 496, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 24, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(140, 26, NULL, NULL, 3, 0, '32', NULL, 0, NULL, NULL, NULL),
	(140, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 257, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 259, NULL, NULL, 1, 1, '0', NULL, 0, NULL, NULL, NULL),
	(140, 260, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 269, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 270, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 271, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 272, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 273, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 274, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 275, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 276, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 277, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 278, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 279, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 280, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 281, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 292, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 332, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 336, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 339, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 360, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 361, 82, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(140, 430, 874, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(140, 474, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(140, 475, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(141, 61, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(141, 105, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(142, 61, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(142, 105, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(143, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(143, 24, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(143, 25, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(143, 26, NULL, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(143, 28, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(143, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(143, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(143, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(143, 229, 82, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(143, 259, NULL, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(143, 491, NULL, NULL, 3, 1, '0000630100FF', NULL, 0, NULL, NULL, NULL),
	(144, 14, NULL, NULL, 3, 0, 'stuspd', NULL, 0, NULL, NULL, NULL),
	(144, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 105, 431, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(144, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 117, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 119, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(144, 149, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(144, 150, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(144, 152, 251, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(144, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(144, 250, NULL, NULL, 3, 0, '4', NULL, 0, NULL, NULL, NULL),
	(145, 14, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(145, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(145, 105, 686, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(145, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(145, 119, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(145, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(145, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(145, 317, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(145, 318, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(147, 14, NULL, NULL, 3, 0, '00000000', NULL, 0, NULL, NULL, NULL),
	(147, 18, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(147, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(148, 14, NULL, NULL, 3, 0, '0000000', NULL, 0, NULL, NULL, NULL),
	(148, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(148, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(148, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(148, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(148, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(148, 171, NULL, NULL, 3, 0, '9600', NULL, 0, NULL, NULL, NULL),
	(151, 20, NULL, NULL, 3, 0, '$FF', NULL, 0, NULL, NULL, NULL),
	(151, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(151, 101, NULL, NULL, 3, 0, '$FF', NULL, 0, NULL, NULL, NULL),
	(151, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(151, 123, 786, NULL, 2, 0, '19842', NULL, 0, NULL, NULL, NULL),
	(151, 222, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(151, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(153, 13, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 187, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(153, 188, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(153, 251, 570, NULL, 3, 0, 'Binary', NULL, 0, NULL, NULL, NULL),
	(154, 13, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 14, NULL, NULL, 3, 0, '00000000000000000000', NULL, 0, NULL, NULL, NULL),
	(154, 37, 807, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 171, NULL, NULL, 3, 0, '9600', NULL, 0, NULL, NULL, NULL),
	(154, 198, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(154, 230, 539, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(154, 265, 580, NULL, 3, 0, 'ANSIVALSENA', NULL, 0, NULL, NULL, NULL),
	(154, 342, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 343, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 406, 82, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(154, 432, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(154, 473, NULL, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(157, 61, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(157, 282, 633, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(157, 283, 645, NULL, 3, 0, '174', NULL, 0, NULL, NULL, NULL),
	(157, 381, NULL, NULL, 2, 0, '6000', NULL, 0, NULL, NULL, NULL),
	(158, 13, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(158, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(158, 105, 523, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(160, 14, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(160, 220, NULL, NULL, 3, 0, '50', NULL, 0, NULL, NULL, NULL),
	(161, 13, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(161, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(161, 105, 526, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(162, 20, 537, NULL, 3, 0, NULL, '2', 0, NULL, NULL, NULL),
	(162, 158, 529, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(162, 232, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(162, 238, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(162, 239, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(162, 240, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(162, 241, 536, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(163, 18, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(163, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(163, 126, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(163, 207, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(163, 209, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(163, 210, 515, NULL, 3, 0, '7', NULL, 0, NULL, NULL, NULL),
	(163, 211, 516, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(163, 213, NULL, NULL, 3, 0, '2', NULL, 0, NULL, NULL, NULL),
	(163, 215, NULL, NULL, 3, 0, '896', NULL, 0, NULL, NULL, NULL),
	(163, 217, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(163, 219, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(165, 14, NULL, NULL, 3, 0, '11111111', NULL, 0, NULL, NULL, NULL),
	(165, 18, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(165, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(165, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(165, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(166, 268, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(167, 13, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(167, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(167, 20, 551, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(167, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(168, 14, NULL, NULL, 3, 0, '00000000', NULL, 0, NULL, NULL, NULL),
	(168, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(168, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(168, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(168, 225, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(174, 14, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(174, 34, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(174, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(174, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(174, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(174, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(179, 13, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(179, 61, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(180, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(180, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(180, 101, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(180, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(180, 123, 534, NULL, 2, 0, '24391', NULL, 0, NULL, NULL, NULL),
	(180, 222, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(180, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(181, 20, 537, NULL, 3, 0, NULL, '2', 0, NULL, NULL, NULL),
	(181, 158, 530, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(181, 232, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(181, 233, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(181, 234, NULL, NULL, 1, 0, NULL, NULL, 0, '^[0-9]d*(.d+)?$', NULL, NULL),
	(181, 235, NULL, NULL, 1, 0, NULL, NULL, 0, '^[0-9]d*(.d+)?$', NULL, NULL),
	(181, 236, NULL, NULL, 1, 0, NULL, NULL, 0, '^[0-9]d*(.d+)?$', NULL, NULL),
	(181, 237, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(181, 238, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(181, 239, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(181, 240, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(181, 241, 536, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(182, 20, 537, NULL, 3, 0, NULL, '2', 0, NULL, NULL, NULL),
	(182, 158, 531, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(182, 232, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(182, 238, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(182, 239, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(182, 240, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(182, 241, 536, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(183, 20, 537, NULL, 3, 0, NULL, '2', 0, NULL, NULL, NULL),
	(183, 158, 532, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(183, 202, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(183, 232, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(183, 233, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(183, 238, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(183, 239, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(183, 240, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(183, 241, 536, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(184, 20, 537, NULL, 3, 0, NULL, '2', 0, NULL, NULL, NULL),
	(184, 158, 533, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(184, 232, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(184, 238, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(184, 239, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(184, 240, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(184, 241, 536, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(185, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(185, 106, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(185, 261, 579, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(185, 262, 578, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(185, 341, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(185, 532, 82, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(186, 14, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(186, 232, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(187, 13, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(187, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(188, 14, NULL, NULL, 3, 0, '00000000', NULL, 0, NULL, NULL, NULL),
	(188, 20, NULL, NULL, 3, 0, '1.43', NULL, 0, NULL, NULL, NULL),
	(188, 28, NULL, NULL, 3, 0, '1800', NULL, 0, NULL, NULL, NULL),
	(188, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(188, 105, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(188, 153, NULL, NULL, 3, 0, '1', NULL, 0, '^[0-9]d*(.d+)?$', NULL, NULL),
	(188, 154, NULL, NULL, 3, 0, '1', NULL, 0, '^[0-9]d*(.d+)?$', NULL, NULL),
	(188, 155, NULL, NULL, 3, 0, '1', NULL, 0, '^[0-9]d*(.d+)?$', NULL, NULL),
	(188, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(188, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(189, 61, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(189, 265, 632, NULL, 3, 0, 'IEC62056_21_Mode_C', NULL, 0, NULL, NULL, NULL),
	(189, 282, 633, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(189, 283, 634, NULL, 3, 0, '174', NULL, 0, NULL, NULL, NULL),
	(189, 380, 82, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(189, 381, NULL, NULL, 2, 0, '6000', NULL, 0, NULL, NULL, NULL),
	(190, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(190, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(190, 61, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(190, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(190, 107, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(190, 158, 542, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(190, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(190, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(191, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(191, 105, 637, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(192, 13, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(192, 61, NULL, NULL, 1, 0, '254', NULL, 0, NULL, NULL, NULL),
	(192, 123, NULL, NULL, 3, 0, '11309', NULL, 0, NULL, NULL, NULL),
	(192, 222, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(195, 13, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 14, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 106, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 438, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(195, 439, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 13, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 18, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 20, NULL, NULL, 3, 0, '3.8', NULL, 0, NULL, NULL, NULL),
	(197, 37, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 105, NULL, NULL, 1, 0, '1', '1', 0, NULL, NULL, NULL),
	(197, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 119, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(197, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 224, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(197, 232, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(197, 294, 689, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(200, 18, 717, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(200, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(200, 106, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(200, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(200, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(200, 323, 716, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(200, 533, 1032, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 408, 801, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 421, 805, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(202, 424, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(203, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 105, 635, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 106, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 284, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 285, 635, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(203, 295, 690, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(205, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(205, 105, NULL, NULL, 3, 0, NULL, '0', 0, NULL, NULL, NULL),
	(205, 106, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(205, 119, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(205, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(205, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(205, 232, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(206, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(206, 105, NULL, NULL, 3, 0, NULL, '1', 0, NULL, NULL, NULL),
	(206, 106, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(206, 119, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(206, 232, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 20, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 61, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 228, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 283, NULL, NULL, 1, 0, NULL, '137', 0, NULL, NULL, NULL),
	(207, 298, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 299, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(207, 300, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 301, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 302, NULL, NULL, 1, 0, NULL, '1', 0, NULL, NULL, NULL),
	(207, 303, NULL, NULL, 3, 0, '3.8', NULL, 0, NULL, NULL, NULL),
	(207, 304, 655, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(207, 316, NULL, NULL, 1, 0, NULL, '<FN>EnergomeraDirectAccess.dll</FN><Ver>1.0</Ver>', 0, NULL, NULL, NULL),
	(207, 354, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(207, 379, NULL, NULL, 3, 0, '24', NULL, 0, NULL, NULL, NULL),
	(208, 14, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(208, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 105, 686, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 119, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(208, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 283, NULL, NULL, 1, 0, NULL, '137', 0, NULL, NULL, NULL),
	(208, 298, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 299, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(208, 300, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 301, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 302, NULL, NULL, 1, 0, NULL, '1', 0, NULL, NULL, NULL),
	(208, 303, NULL, NULL, 3, 0, '3.8', NULL, 0, NULL, NULL, NULL),
	(208, 304, 655, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(208, 316, NULL, NULL, 1, 0, NULL, '<FN>EnergomeraDirectAccess.dll</FN><Ver>1.0</Ver>', 0, NULL, NULL, NULL),
	(208, 317, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(208, 318, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(209, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 24, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(209, 26, NULL, NULL, 3, 0, '32', NULL, 0, NULL, NULL, NULL),
	(209, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 257, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 259, NULL, NULL, 1, 1, '0', NULL, 0, NULL, NULL, NULL),
	(209, 260, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 269, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 270, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 271, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 272, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 273, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 274, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 275, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 276, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 277, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 278, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 279, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 280, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 281, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 292, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 332, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 336, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 339, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 360, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 361, 82, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(209, 430, 874, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(209, 474, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(209, 475, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(210, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(210, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(210, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(210, 119, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(210, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(210, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 13, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 14, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 321, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 322, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 324, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 325, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 326, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 327, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 328, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(211, 329, 718, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(214, 18, 724, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(214, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(214, 105, 976, NULL, 1, 0, NULL, '4', 0, NULL, NULL, NULL),
	(214, 106, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(215, 13, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(215, 14, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(215, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(215, 293, NULL, NULL, 3, 0, '7', NULL, 0, NULL, NULL, NULL),
	(215, 332, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(216, 18, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(216, 20, NULL, NULL, 3, 0, '1.4', NULL, 0, NULL, NULL, NULL),
	(216, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(216, 105, NULL, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(216, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(216, 107, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(217, 14, NULL, NULL, 3, 0, 'FFFFFFFF', NULL, 0, NULL, NULL, NULL),
	(217, 18, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(217, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(217, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(217, 120, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(217, 265, 769, NULL, 3, 0, 'FT.1.2', NULL, 0, NULL, NULL, NULL),
	(217, 345, NULL, NULL, 3, 0, '-1', NULL, 0, NULL, NULL, NULL),
	(217, 346, 82, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(217, 347, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(217, 348, NULL, NULL, 3, 1, '365', NULL, 0, NULL, NULL, NULL),
	(217, 349, NULL, NULL, 3, 1, '12', NULL, 0, NULL, NULL, NULL),
	(217, 350, NULL, NULL, 3, 1, '16', NULL, 0, NULL, NULL, NULL),
	(217, 351, NULL, NULL, 3, 1, '16', NULL, 0, NULL, NULL, NULL),
	(217, 352, NULL, NULL, 3, 1, '1440', NULL, 0, NULL, NULL, NULL),
	(218, 18, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(218, 20, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(218, 105, 766, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(218, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(218, 283, 789, NULL, 3, 0, '195', NULL, 0, NULL, NULL, NULL),
	(218, 388, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(218, 389, 790, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(218, 390, 791, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 18, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 132, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 134, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 136, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 138, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 140, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 142, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 144, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 146, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(219, 147, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(220, 18, 740, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(220, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(220, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(220, 323, 739, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(221, 18, 742, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(221, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(221, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(221, 323, 741, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(223, 18, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(223, 20, NULL, NULL, 3, 0, '1.4', NULL, 0, NULL, NULL, NULL),
	(223, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(223, 105, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(223, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(223, 107, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(224, 18, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(224, 20, NULL, NULL, 3, 0, '1.4', NULL, 0, NULL, NULL, NULL),
	(224, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(224, 105, NULL, NULL, 3, 0, '2', NULL, 0, NULL, NULL, NULL),
	(224, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(224, 107, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(225, 18, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(225, 20, NULL, NULL, 3, 0, '1.4', NULL, 0, NULL, NULL, NULL),
	(225, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(225, 105, NULL, NULL, 3, 0, '4', NULL, 0, NULL, NULL, NULL),
	(225, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(225, 107, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 14, NULL, NULL, 3, 0, 'stuspd', NULL, 0, NULL, NULL, NULL),
	(226, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 105, NULL, NULL, 3, 0, NULL, '5', 0, NULL, NULL, NULL),
	(226, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 117, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 119, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(226, 149, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(226, 150, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(226, 152, 251, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(226, 250, NULL, NULL, 3, 0, '4', NULL, 0, NULL, NULL, NULL),
	(226, 334, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(226, 335, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 132, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 134, NULL, NULL, 3, 0, 'SQLOLEDB.1', NULL, 0, NULL, NULL, NULL),
	(227, 136, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 138, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 140, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 142, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 144, 525, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 146, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 147, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(227, 338, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(228, 14, NULL, NULL, 3, 0, 'stuspd', NULL, 0, NULL, NULL, NULL),
	(228, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 105, 431, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(228, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 117, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 119, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(228, 149, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(228, 150, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(228, 152, 251, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(228, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(228, 250, NULL, NULL, 3, 0, '4', NULL, 0, NULL, NULL, NULL),
	(228, 337, NULL, NULL, 3, 0, NULL, '1', 0, NULL, NULL, NULL),
	(229, 14, NULL, NULL, 3, 0, 'stuspd', NULL, 0, NULL, NULL, NULL),
	(229, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 105, NULL, NULL, 3, 0, NULL, '5', 0, NULL, NULL, NULL),
	(229, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 117, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 119, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(229, 149, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(229, 150, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(229, 152, 251, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(229, 250, NULL, NULL, 3, 0, '4', NULL, 0, NULL, NULL, NULL),
	(229, 334, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 335, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(229, 337, NULL, NULL, 3, 0, NULL, '1', 0, NULL, NULL, NULL),
	(232, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 255, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 256, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 257, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 258, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 259, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 263, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 264, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 293, NULL, NULL, 3, 0, '10', NULL, 0, NULL, NULL, NULL),
	(232, 356, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 363, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 364, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 365, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 366, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 367, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 368, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 369, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 370, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 371, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 372, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 373, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 374, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 375, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 376, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 377, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 378, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(232, 383, NULL, NULL, 3, 0, NULL, '0', 0, NULL, NULL, NULL),
	(232, 431, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(234, 18, 770, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(234, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(235, 14, NULL, NULL, 3, 0, '123456', NULL, 0, NULL, NULL, NULL),
	(235, 164, NULL, NULL, 3, 1, '5', NULL, 0, NULL, NULL, NULL),
	(235, 165, NULL, NULL, 3, 1, '1800', NULL, 0, NULL, NULL, NULL),
	(235, 282, NULL, NULL, 3, 0, '300', NULL, 0, NULL, NULL, NULL),
	(235, 318, NULL, NULL, 3, 0, '13579B', NULL, 0, NULL, NULL, NULL),
	(235, 344, NULL, NULL, 3, 0, 'ABCDEF', NULL, 0, NULL, NULL, NULL),
	(236, 18, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(236, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(236, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(236, 323, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(237, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(237, 382, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(238, 20, NULL, NULL, 1, 0, NULL, '3', 0, NULL, NULL, NULL),
	(238, 21, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(238, 32, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(238, 61, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(238, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(238, 357, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(239, 20, NULL, NULL, 1, 0, NULL, '4', 0, NULL, NULL, NULL),
	(239, 21, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(239, 32, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(239, 61, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(239, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(239, 357, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(240, 20, NULL, NULL, 1, 0, NULL, '5', 0, NULL, NULL, NULL),
	(240, 21, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(240, 32, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(240, 61, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(240, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(240, 357, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(241, 384, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 13, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 105, NULL, NULL, 1, 0, NULL, '19', 0, NULL, NULL, NULL),
	(243, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 119, NULL, NULL, 3, 0, '253', NULL, 0, NULL, NULL, NULL),
	(243, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(243, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(243, 398, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 399, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 400, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 401, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 402, NULL, NULL, 3, 0, '10000', NULL, 0, NULL, NULL, NULL),
	(243, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(243, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(243, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(244, 14, NULL, NULL, 3, 0, '000000000', NULL, 0, NULL, NULL, NULL),
	(244, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(244, 232, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(244, 386, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(244, 495, 82, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(246, 37, NULL, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(246, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 341, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 490, 82, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(246, 492, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 493, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(246, 494, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 255, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 256, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 257, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 258, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 259, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 263, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 264, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 293, NULL, NULL, 3, 0, '10', NULL, 0, NULL, NULL, NULL),
	(248, 356, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 363, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 364, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 365, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 366, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 367, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 368, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 369, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 370, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 371, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 372, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 373, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 374, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 375, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 376, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 377, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 378, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 383, NULL, NULL, 3, 0, NULL, '1', 0, NULL, NULL, NULL),
	(248, 391, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 392, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 393, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(248, 431, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 13, 788, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 14, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 18, NULL, NULL, 1, 1, NULL, NULL, 1, NULL, NULL, NULL),
	(249, 24, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 25, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 26, NULL, NULL, 3, 0, '16', NULL, 0, NULL, NULL, NULL),
	(249, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 229, 82, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 256, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 257, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(249, 531, NULL, NULL, 3, 0, NULL, NULL, 1, NULL, NULL, NULL),
	(250, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(250, 385, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(251, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 37, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 105, NULL, NULL, 1, 0, NULL, '3', 0, NULL, NULL, NULL),
	(251, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 265, 1, NULL, 3, 0, 'SLIP', NULL, 0, NULL, NULL, NULL),
	(251, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(251, 407, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(252, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(252, 230, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(252, 410, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(253, 105, NULL, NULL, 1, 0, NULL, '3', 0, NULL, NULL, NULL),
	(253, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(255, 105, NULL, NULL, 1, 0, NULL, '2', 0, NULL, NULL, NULL),
	(255, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(256, 105, NULL, NULL, 1, 0, NULL, '1', 0, NULL, NULL, NULL),
	(256, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(257, 20, NULL, NULL, 3, 0, '$FF', NULL, 0, NULL, NULL, NULL),
	(257, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(257, 101, NULL, NULL, 3, 0, '$FF', NULL, 0, NULL, NULL, NULL),
	(257, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(257, 123, 797, NULL, 2, 0, '1143', NULL, 0, NULL, NULL, NULL),
	(257, 222, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(257, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(258, 13, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 105, NULL, NULL, 1, 0, NULL, '1', 0, NULL, NULL, NULL),
	(258, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(258, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(258, 400, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 401, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 402, NULL, NULL, 3, 0, '100', NULL, 0, NULL, NULL, NULL),
	(258, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(258, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(258, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(259, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 105, NULL, NULL, 1, 0, NULL, '2', 0, NULL, NULL, NULL),
	(259, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 119, NULL, NULL, 3, 0, '253', NULL, 0, NULL, NULL, NULL),
	(259, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(259, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(259, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(259, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(259, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(260, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 105, NULL, NULL, 1, 0, NULL, '3', 0, NULL, NULL, NULL),
	(260, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(260, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(260, 399, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(260, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(260, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(261, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 105, NULL, NULL, 1, 0, NULL, '4', 0, NULL, NULL, NULL),
	(261, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(261, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(261, 399, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(261, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(261, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(262, 13, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 105, NULL, NULL, 1, 0, NULL, '5', 0, NULL, NULL, NULL),
	(262, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 119, NULL, NULL, 3, 0, '253', NULL, 0, NULL, NULL, NULL),
	(262, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(262, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(262, 398, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 399, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 400, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 401, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 402, NULL, NULL, 3, 0, '1000000', NULL, 0, NULL, NULL, NULL),
	(262, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(262, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(262, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(263, 13, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 105, NULL, NULL, 1, 0, NULL, '6', 0, NULL, NULL, NULL),
	(263, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(263, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(263, 399, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 400, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 401, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(263, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(263, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(264, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 105, NULL, NULL, 1, 0, NULL, '7', 0, NULL, NULL, NULL),
	(264, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(264, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(264, 399, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(264, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(264, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(265, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 105, NULL, NULL, 1, 0, NULL, '8', 0, NULL, NULL, NULL),
	(265, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(265, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(265, 399, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(265, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(265, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(266, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 105, NULL, NULL, 1, 0, NULL, '9', 0, NULL, NULL, NULL),
	(266, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 119, NULL, NULL, 3, 0, '253', NULL, 0, NULL, NULL, NULL),
	(266, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(266, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(266, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(266, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(266, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(267, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 105, NULL, NULL, 1, 0, NULL, '10', 0, NULL, NULL, NULL),
	(267, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(267, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(267, 399, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(267, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(267, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(268, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 105, NULL, NULL, 1, 0, NULL, '11', 0, NULL, NULL, NULL),
	(268, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(268, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(268, 399, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(268, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(268, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(269, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 105, NULL, NULL, 1, 0, NULL, '12', 0, NULL, NULL, NULL),
	(269, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(269, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(269, 399, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(269, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(269, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(270, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 105, NULL, NULL, 1, 0, NULL, '13', 0, NULL, NULL, NULL),
	(270, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 119, NULL, NULL, 3, 0, '253', NULL, 0, NULL, NULL, NULL),
	(270, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(270, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(270, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(270, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(270, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(271, 13, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 105, NULL, NULL, 1, 0, NULL, '14', 0, NULL, NULL, NULL),
	(271, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 119, NULL, NULL, 3, 0, '253', NULL, 0, NULL, NULL, NULL),
	(271, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(271, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(271, 400, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 401, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 402, NULL, NULL, 3, 0, '100', NULL, 0, NULL, NULL, NULL),
	(271, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(271, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(271, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(272, 13, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 105, NULL, NULL, 1, 0, NULL, '15', 0, NULL, NULL, NULL),
	(272, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 119, NULL, NULL, 3, 0, '253', NULL, 0, NULL, NULL, NULL),
	(272, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(272, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(272, 400, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 401, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 402, NULL, NULL, 3, 0, '100', NULL, 0, NULL, NULL, NULL),
	(272, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(272, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(272, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(273, 13, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 105, NULL, NULL, 1, 0, NULL, '16', 0, NULL, NULL, NULL),
	(273, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 119, NULL, NULL, 3, 0, '253', NULL, 0, NULL, NULL, NULL),
	(273, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(273, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(273, 400, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 401, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 402, NULL, NULL, 3, 0, '100', NULL, 0, NULL, NULL, NULL),
	(273, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(273, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(273, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(274, 13, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 105, NULL, NULL, 1, 0, NULL, '17', 0, NULL, NULL, NULL),
	(274, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 119, NULL, NULL, 3, 0, '253', NULL, 0, NULL, NULL, NULL),
	(274, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(274, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(274, 400, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 401, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 402, NULL, NULL, 3, 0, '100', NULL, 0, NULL, NULL, NULL),
	(274, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(274, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(274, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(275, 13, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 105, NULL, NULL, 1, 0, NULL, '18', 0, NULL, NULL, NULL),
	(275, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 119, NULL, NULL, 3, 0, '253', NULL, 0, NULL, NULL, NULL),
	(275, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(275, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(275, 400, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 401, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(275, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(275, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(276, 13, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 105, NULL, NULL, 1, 0, NULL, '20', 0, NULL, NULL, NULL),
	(276, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 119, NULL, NULL, 3, 0, '253', NULL, 0, NULL, NULL, NULL),
	(276, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(276, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(276, 400, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 401, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 402, NULL, NULL, 3, 0, '100', NULL, 0, NULL, NULL, NULL),
	(276, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(276, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(276, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(277, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 105, NULL, NULL, 1, 0, NULL, '21', 0, NULL, NULL, NULL),
	(277, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 119, NULL, NULL, 3, 0, '253', NULL, 0, NULL, NULL, NULL),
	(277, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(277, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(277, 398, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(277, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(277, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(278, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 105, NULL, NULL, 1, 0, NULL, '22', 0, NULL, NULL, NULL),
	(278, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 119, NULL, NULL, 3, 0, '253', NULL, 0, NULL, NULL, NULL),
	(278, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(278, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(278, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(278, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(278, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(279, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 105, NULL, NULL, 1, 0, NULL, '23', 0, NULL, NULL, NULL),
	(279, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(279, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(279, 399, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(279, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(279, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(280, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 105, NULL, NULL, 1, 0, NULL, '24', 0, NULL, NULL, NULL),
	(280, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(280, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(280, 399, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(280, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(280, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(281, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 105, NULL, NULL, 1, 0, NULL, '25', 0, NULL, NULL, NULL),
	(281, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(281, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(281, 399, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(281, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(281, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(282, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(282, 386, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 14, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 105, NULL, NULL, 1, 0, NULL, '1', 0, NULL, NULL, NULL),
	(283, 411, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 412, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(283, 413, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 414, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 415, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 416, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(283, 424, 876, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(283, 429, 820, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(284, 14, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(284, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(284, 105, 816, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(284, 120, 815, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(285, 105, NULL, NULL, 1, 0, NULL, '4', 0, NULL, NULL, NULL),
	(285, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(286, 13, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(286, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(286, 105, NULL, NULL, 1, 0, NULL, '4', 0, NULL, NULL, NULL),
	(287, 18, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(287, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(287, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(287, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(287, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(287, 323, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 14, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 105, NULL, NULL, 1, 0, NULL, '2', 0, NULL, NULL, NULL),
	(288, 411, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 412, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(288, 413, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 414, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 415, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 416, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(288, 424, 876, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(288, 429, 820, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 18, 801, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 61, 800, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 106, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 419, 82, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(290, 420, 802, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 421, 801, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 422, 802, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(290, 423, 82, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(291, 14, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(291, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(291, 389, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(292, 14, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(292, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(292, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(292, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(292, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(292, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(292, 499, 934, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(293, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(293, 20, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(293, 61, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(293, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(293, 107, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(293, 158, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(293, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(293, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(294, 14, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(294, 18, NULL, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(294, 21, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(294, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(294, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(294, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(294, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(295, 21, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(295, 61, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(295, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(295, 265, 808, NULL, 3, 0, 'MODBUS', NULL, 0, NULL, NULL, NULL),
	(295, 426, 809, NULL, 3, 0, 'Word', NULL, 0, NULL, NULL, NULL),
	(296, 61, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(296, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(296, 120, NULL, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(296, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(296, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(296, 427, NULL, NULL, 3, 0, '00000000', NULL, 0, NULL, NULL, NULL),
	(296, 428, NULL, NULL, 3, 0, '00000000', NULL, 0, NULL, NULL, NULL),
	(299, 105, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(299, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(299, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(299, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(299, 227, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(299, 282, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(299, 283, 899, NULL, 3, 0, '230', NULL, 0, NULL, NULL, NULL),
	(299, 381, NULL, NULL, 3, 0, '500', NULL, 0, NULL, NULL, NULL),
	(299, 441, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 284, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 341, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 468, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(300, 469, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(300, 470, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(300, 471, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 472, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(300, 479, NULL, NULL, 3, 0, '5000', NULL, 0, NULL, NULL, NULL),
	(300, 507, 82, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(301, 21, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(301, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(303, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 18, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 61, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 105, NULL, NULL, 3, 0, NULL, '26', 0, NULL, NULL, NULL),
	(306, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 107, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 322, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(306, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(306, 400, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 401, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 402, NULL, NULL, 3, 0, '100', NULL, 0, NULL, NULL, NULL),
	(306, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(306, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(306, 437, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 438, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 439, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(306, 440, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 18, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 61, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 105, NULL, NULL, 3, 0, NULL, '27', 0, NULL, NULL, NULL),
	(307, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 107, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(307, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(307, 400, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 401, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 402, NULL, NULL, 3, 0, '100', NULL, 0, NULL, NULL, NULL),
	(307, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(307, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(307, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(308, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 18, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 105, NULL, NULL, 3, 0, NULL, '28', 0, NULL, NULL, NULL),
	(308, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 107, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(308, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(308, 399, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 400, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 401, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(308, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(308, 425, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(337, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(337, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(337, 24, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(337, 25, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(337, 26, NULL, NULL, 3, 0, '32', NULL, 0, NULL, NULL, NULL),
	(337, 257, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(337, 258, NULL, NULL, 3, 1, '2', NULL, 0, NULL, NULL, NULL),
	(337, 259, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(337, 477, 894, NULL, 3, 0, '2', NULL, 0, NULL, NULL, NULL),
	(337, 491, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(338, 18, NULL, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(338, 20, NULL, NULL, 3, 0, '$FF', NULL, 0, NULL, NULL, NULL),
	(338, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(338, 101, NULL, NULL, 3, 0, '$FF', NULL, 0, NULL, NULL, NULL),
	(338, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(338, 123, 886, NULL, 2, 0, '1801', NULL, 0, NULL, NULL, NULL),
	(338, 222, 82, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(338, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(339, 107, 882, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(339, 464, 888, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(339, 465, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(340, 21, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(340, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(340, 130, NULL, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(340, 424, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(340, 442, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(340, 443, NULL, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(340, 444, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(340, 445, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(340, 446, NULL, NULL, 1, 0, '1', NULL, 0, NULL, NULL, NULL),
	(340, 447, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(340, 448, NULL, NULL, 1, 0, '0', NULL, 0, NULL, NULL, NULL),
	(340, 467, 892, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(340, 497, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(341, 21, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(341, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(341, 130, NULL, NULL, 3, 0, '3', '4', 0, NULL, NULL, NULL),
	(341, 442, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(341, 443, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(341, 444, NULL, NULL, 1, 0, NULL, '4', 0, NULL, NULL, NULL),
	(341, 445, NULL, NULL, 1, 0, NULL, '1', 0, NULL, NULL, NULL),
	(341, 446, NULL, NULL, 1, 0, NULL, '1', 0, NULL, NULL, NULL),
	(341, 447, NULL, NULL, 1, 0, NULL, '0', 0, NULL, NULL, NULL),
	(341, 448, NULL, NULL, 1, 0, NULL, '0', 0, NULL, NULL, NULL),
	(341, 467, 892, NULL, 1, 0, NULL, '0', 0, NULL, NULL, NULL),
	(341, 497, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(342, 37, 903, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(342, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(342, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(342, 108, NULL, NULL, 3, 0, '2000', NULL, 0, NULL, NULL, NULL),
	(342, 164, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(342, 165, NULL, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(342, 386, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 486, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 487, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 488, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 489, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(344, 504, NULL, NULL, 3, 0, '10', NULL, 0, NULL, NULL, NULL),
	(346, 13, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(346, 14, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(346, 20, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(346, 37, NULL, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(346, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(346, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(346, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(346, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(346, 490, 82, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(348, 14, NULL, NULL, 3, 0, 'andra', NULL, 0, NULL, NULL, NULL),
	(349, 14, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(349, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(349, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(349, 282, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(349, 283, 933, NULL, 3, 0, '247', NULL, 0, NULL, NULL, NULL),
	(349, 381, NULL, NULL, 3, 0, '1000', NULL, 0, NULL, NULL, NULL),
	(352, 18, 982, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(352, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(352, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(352, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(352, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 61, NULL, NULL, 3, 0, '255', NULL, 0, NULL, NULL, NULL),
	(353, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 317, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(353, 386, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(354, 21, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(354, 61, 882, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(354, 130, 949, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(354, 231, 82, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(354, 357, 946, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(354, 467, 892, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(354, 501, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(354, 502, 949, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(356, 14, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(356, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(356, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(356, 490, NULL, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(357, 13, 441, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(357, 14, NULL, NULL, 3, 0, '111111', NULL, 0, NULL, NULL, NULL),
	(357, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 105, NULL, NULL, 3, 0, NULL, '1', 0, NULL, NULL, NULL),
	(357, 124, 535, NULL, 3, 0, '-1', NULL, 0, NULL, NULL, NULL),
	(357, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 228, NULL, NULL, 3, 0, '222222', NULL, 0, NULL, NULL, NULL),
	(357, 229, 525, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 242, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 245, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 246, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 247, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 248, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 249, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(357, 476, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 13, 441, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(358, 14, NULL, NULL, 3, 0, '111111', NULL, 0, NULL, NULL, NULL),
	(358, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 105, NULL, NULL, 3, 0, NULL, '2', 0, NULL, NULL, NULL),
	(358, 124, 535, NULL, 3, 0, '-1', NULL, 0, NULL, NULL, NULL),
	(358, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 228, NULL, NULL, 3, 0, '222222', NULL, 0, NULL, NULL, NULL),
	(358, 229, 525, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 242, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 245, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 246, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 247, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 248, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 249, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(358, 476, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 13, 441, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(359, 14, NULL, NULL, 3, 0, '111111', NULL, 0, NULL, NULL, NULL),
	(359, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 105, NULL, NULL, 3, 0, NULL, '2', 0, NULL, NULL, NULL),
	(359, 124, 535, NULL, 3, 0, '-1', NULL, 0, NULL, NULL, NULL),
	(359, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 228, NULL, NULL, 3, 0, '222222', NULL, 0, NULL, NULL, NULL),
	(359, 229, 525, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 242, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 245, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 246, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 247, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 248, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 249, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(359, 476, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 13, 441, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(360, 14, NULL, NULL, 3, 0, '111111', NULL, 0, NULL, NULL, NULL),
	(360, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 105, NULL, NULL, 3, 0, NULL, '3', 0, NULL, NULL, NULL),
	(360, 124, 535, NULL, 3, 0, '-1', NULL, 0, NULL, NULL, NULL),
	(360, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 228, NULL, NULL, 3, 0, '222222', NULL, 0, NULL, NULL, NULL),
	(360, 229, 525, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 242, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 245, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 246, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 247, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 248, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 249, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(360, 476, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 13, 441, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(361, 14, NULL, NULL, 3, 0, '111111', NULL, 0, NULL, NULL, NULL),
	(361, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 105, NULL, NULL, 3, 0, NULL, '3', 0, NULL, NULL, NULL),
	(361, 124, 535, NULL, 3, 0, '-1', NULL, 0, NULL, NULL, NULL),
	(361, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 228, NULL, NULL, 3, 0, '222222', NULL, 0, NULL, NULL, NULL),
	(361, 229, 525, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 242, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 245, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 246, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 247, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 248, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 249, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(361, 476, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 13, 441, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(362, 14, NULL, NULL, 3, 0, '111111', NULL, 0, NULL, NULL, NULL),
	(362, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 105, NULL, NULL, 3, 0, NULL, '3', 0, NULL, NULL, NULL),
	(362, 124, 535, NULL, 3, 0, '-1', NULL, 0, NULL, NULL, NULL),
	(362, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 228, NULL, NULL, 3, 0, '222222', NULL, 0, NULL, NULL, NULL),
	(362, 229, 525, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 242, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 245, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 246, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 247, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 248, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 249, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(362, 476, NULL, NULL, 2, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 37, NULL, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(363, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 526, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 527, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 528, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(363, 529, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(363, 530, 987, NULL, 3, 1, '0', NULL, 0, NULL, NULL, NULL),
	(364, 13, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(364, 14, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(364, 61, NULL, NULL, 1, 0, 'https://public.etic.lt/EDPWS/', NULL, 0, NULL, NULL, NULL),
	(364, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(364, 489, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(364, 508, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(365, 18, 983, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(365, 61, 882, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(365, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(365, 323, 889, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(366, 18, 724, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(366, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(366, 105, 976, NULL, 1, 0, NULL, '1', 0, NULL, NULL, NULL),
	(366, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 13, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(367, 14, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(367, 20, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 37, 975, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(367, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 283, 974, NULL, 3, 0, NULL, '255', 0, NULL, NULL, NULL),
	(367, 490, 82, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(367, 509, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 510, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 511, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(367, 512, 967, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(367, 513, 968, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(367, 514, 969, NULL, 3, 0, '2400', NULL, 0, NULL, NULL, NULL),
	(367, 515, 970, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(367, 516, 971, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(367, 517, 972, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(367, 518, 973, NULL, 3, 0, '8', NULL, 0, NULL, NULL, NULL),
	(367, 519, NULL, NULL, 3, 0, '60000', NULL, 0, NULL, NULL, NULL),
	(367, 520, NULL, NULL, 3, 0, '100', NULL, 0, NULL, NULL, NULL),
	(369, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(369, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(369, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(369, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(369, 417, NULL, NULL, 3, 0, NULL, 'TRUE', 0, NULL, NULL, NULL),
	(370, 13, 979, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(370, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 24, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 25, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 26, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 229, 82, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 257, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 258, NULL, NULL, 3, 1, '2', NULL, 0, NULL, NULL, NULL),
	(370, 259, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(370, 491, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 13, 979, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(371, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 24, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 25, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 26, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 229, 82, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 257, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 258, NULL, NULL, 3, 1, '2', NULL, 0, NULL, NULL, NULL),
	(371, 259, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(371, 491, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 13, 979, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(372, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 24, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 25, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 26, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 229, 82, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 257, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 258, NULL, NULL, 3, 1, '2', NULL, 0, NULL, NULL, NULL),
	(372, 259, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(372, 491, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(373, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(373, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(373, 106, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 105, NULL, NULL, 1, 0, NULL, '29', 0, NULL, NULL, NULL),
	(374, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(374, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(374, 399, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(374, 425, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 105, NULL, NULL, 1, 0, NULL, '30', 0, NULL, NULL, NULL),
	(375, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(375, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(375, 399, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(375, 425, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 105, NULL, NULL, 1, 0, NULL, '31', 0, NULL, NULL, NULL),
	(376, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(376, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(376, 399, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(376, 425, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 13, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 105, NULL, NULL, 1, 0, NULL, '32', 0, NULL, NULL, NULL),
	(377, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 107, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 119, NULL, NULL, 3, 0, '253', NULL, 0, NULL, NULL, NULL),
	(377, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 318, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 322, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 337, 873, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(377, 344, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 394, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 395, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 396, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 397, NULL, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(377, 400, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 401, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 402, NULL, NULL, 3, 0, '100', NULL, 0, NULL, NULL, NULL),
	(377, 403, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(377, 425, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(378, 21, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(378, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(378, 130, 949, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(378, 426, 978, NULL, 3, 0, 'Float', NULL, 0, NULL, NULL, NULL),
	(378, 446, 946, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(378, 467, 977, NULL, 3, 0, '0', NULL, 0, NULL, NULL, NULL),
	(378, 502, 949, NULL, 3, 0, '3', NULL, 0, NULL, NULL, NULL),
	(378, 521, 946, NULL, 3, 0, '1', NULL, 0, NULL, NULL, NULL),
	(379, 14, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(379, 18, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(379, 26, NULL, NULL, 3, 0, '16', NULL, 0, NULL, NULL, NULL),
	(379, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(379, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(379, 259, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(379, 491, NULL, NULL, 1, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(381, 14, NULL, NULL, 3, 0, 'Kamstrup', NULL, 0, NULL, NULL, NULL),
	(381, 18, 1033, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(381, 61, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(381, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(381, 164, NULL, NULL, 3, 1, '0', NULL, 1, NULL, NULL, NULL),
	(381, 165, NULL, NULL, 3, 1, '0', NULL, 1, NULL, NULL, NULL),
	(381, 332, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(381, 354, 82, NULL, 3, 0, '0', NULL, 1, NULL, 0, 1),
	(381, 535, NULL, NULL, 3, 1, NULL, NULL, 1, NULL, 0, 15),
	(382, 13, 788, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 14, NULL, NULL, 1, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 24, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 25, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 26, NULL, NULL, 3, 0, '16', NULL, 0, NULL, NULL, NULL),
	(382, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 164, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 165, NULL, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 229, 82, NULL, 3, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 256, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 257, NULL, NULL, 2, 1, NULL, NULL, 0, NULL, NULL, NULL),
	(382, 531, NULL, NULL, 3, 0, NULL, NULL, 1, NULL, NULL, NULL),
	(383, 105, NULL, NULL, 1, 0, NULL, '5', 0, NULL, NULL, NULL),
	(383, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(384, 18, 1036, NULL, 3, 1, NULL, NULL, 1, NULL, 1, 8),
	(384, 61, 882, NULL, 1, 0, NULL, NULL, 1, NULL, 0, 255),
	(384, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(384, 164, NULL, NULL, 3, 1, '0', NULL, 1, NULL, NULL, NULL),
	(384, 165, NULL, NULL, 3, 1, '0', NULL, 1, NULL, NULL, NULL),
	(384, 332, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(384, 534, 889, NULL, 3, 1, NULL, NULL, 1, NULL, 1, 2),
	(384, 535, NULL, NULL, 3, 1, NULL, NULL, 1, NULL, 0, 15),
	(385, 14, NULL, NULL, 3, 0, '4096', NULL, 0, NULL, NULL, NULL),
	(385, 18, 1035, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(385, 61, NULL, NULL, 1, 0, NULL, NULL, 1, NULL, 0, 65535),
	(385, 105, NULL, NULL, 3, 0, NULL, '2', 0, NULL, NULL, NULL),
	(385, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(385, 119, NULL, NULL, 3, 0, '0', NULL, 1, NULL, 0, 65535),
	(385, 164, NULL, NULL, 3, 1, '0', NULL, 1, NULL, NULL, NULL),
	(385, 165, NULL, NULL, 3, 1, '0', NULL, 1, NULL, NULL, NULL),
	(385, 198, NULL, NULL, 3, 0, '000', NULL, 0, NULL, NULL, NULL),
	(385, 332, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(385, 535, NULL, NULL, 3, 1, NULL, NULL, 1, NULL, 0, 15),
	(386, 14, NULL, NULL, 3, 0, '4096', NULL, 0, NULL, NULL, NULL),
	(386, 18, 1035, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(386, 61, NULL, NULL, 1, 0, NULL, NULL, 1, NULL, 0, 65535),
	(386, 105, NULL, NULL, 3, 0, NULL, '1', 0, NULL, NULL, NULL),
	(386, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(386, 119, NULL, NULL, 3, 0, '0', NULL, 1, NULL, 0, 65535),
	(386, 164, NULL, NULL, 3, 1, '0', NULL, 1, NULL, NULL, NULL),
	(386, 165, NULL, NULL, 3, 1, '0', NULL, 1, NULL, NULL, NULL),
	(386, 198, NULL, NULL, 3, 0, '000', NULL, 0, NULL, NULL, NULL),
	(386, 332, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(386, 535, NULL, NULL, 3, 1, NULL, NULL, 1, NULL, 0, 15),
	(387, 14, NULL, NULL, 3, 0, '4096', NULL, 0, NULL, NULL, NULL),
	(387, 18, 1035, NULL, 3, 1, '1', NULL, 0, NULL, NULL, NULL),
	(387, 61, NULL, NULL, 1, 0, NULL, NULL, 1, NULL, 0, 65535),
	(387, 105, NULL, NULL, 3, 0, NULL, '3', 0, NULL, NULL, NULL),
	(387, 106, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(387, 119, NULL, NULL, 3, 0, '0', NULL, 1, NULL, 0, 65535),
	(387, 164, NULL, NULL, 3, 1, '0', NULL, 1, NULL, NULL, NULL),
	(387, 165, NULL, NULL, 3, 1, '0', NULL, 1, NULL, NULL, NULL),
	(387, 198, NULL, NULL, 3, 0, '000', NULL, 0, NULL, NULL, NULL),
	(387, 332, NULL, NULL, 3, 0, NULL, NULL, 0, NULL, NULL, NULL),
	(387, 535, NULL, NULL, 3, 1, NULL, NULL, 1, NULL, 0, 15);
/*!40000 ALTER TABLE `src_type_lpty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_lpty_filter
CREATE TABLE IF NOT EXISTS `src_type_lpty_filter` (
  `src_type_lpty_filter_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Nurodyto tipo duomenų šaltinių galimų savybių filtravimo ID',
  `src_type_lpty_filter_code` varchar(50) COLLATE utf8_bin NOT NULL DEFAULT 'VISI' COMMENT 'Nurodyto tipo duomenų šaltinių galimų savybių filtravimo kodas',
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `sheaf_id` mediumint(8) NOT NULL DEFAULT 0 COMMENT 'Duomenų pluošto identifikatorius',
  `ds_id` smallint(5) NOT NULL DEFAULT 0 COMMENT 'Apskaitos būsenos signalo identifikatorius',
  `md_id` smallint(5) NOT NULL DEFAULT 0 COMMENT 'Matavimo diskretiškumo identifikatorius',
  `aggs_id` smallint(5) NOT NULL DEFAULT 0 COMMENT 'Agregavimo segmento identifikatorius',
  `lpty_filter_default_value` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Nurodyto tipo duomenų šaltinių galimos filtruojamos savybės reikšmė pagal nutylėjimą',
  `is_point` tinyint(1) DEFAULT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  `lpty_filter_forced_value` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Nurodyto tipo duomenų šaltinių savybės fiksuota reikšmė filtrą atitinkantiems elementams',
  PRIMARY KEY (`src_type_lpty_filter_id`),
  UNIQUE KEY `src_type_lpty_filter_uk` (`src_type_id`,`lpty_id`,`sheaf_id`,`ds_id`,`md_id`,`aggs_id`,`is_point`),
  KEY `lpty_filter_fk` (`lpty_id`),
  CONSTRAINT `lpty_filter_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_filter_fk` FOREIGN KEY (`src_type_id`) REFERENCES `src_type` (`src_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=2584 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Nurodyto tipo duomenų šaltinių galimų savybių filtravimas';

-- Dumping data for table emcor.src_type_lpty_filter: ~2 448 rows (approximately)
/*!40000 ALTER TABLE `src_type_lpty_filter` DISABLE KEYS */;
INSERT INTO `src_type_lpty_filter` (`src_type_lpty_filter_id`, `src_type_lpty_filter_code`, `src_type_id`, `lpty_id`, `sheaf_id`, `ds_id`, `md_id`, `aggs_id`, `lpty_filter_default_value`, `is_point`, `lpty_filter_forced_value`) VALUES
	(1, 'TIME', 81, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(2, 'TIME', 81, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(3, 'TIME', 101, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(4, 'TIME', 101, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(5, 'TIME_CORRECTION', 101, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(6, 'TIME_CORRECTION', 101, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(11, 'P30 Q30', 82, 18, 0, 0, 3, 3, NULL, NULL, NULL),
	(12, 'P30 Q30', 82, 36, 0, 0, 3, 3, NULL, NULL, NULL),
	(13, 'DISCRETE', 26, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(15, 'PROFILE', 39, 18, 0, 0, 3, 3, NULL, NULL, NULL),
	(16, 'PROFILE', 39, 18, 0, 0, 4, 4, NULL, NULL, NULL),
	(17, 'PROFILE', 39, 18, 0, 0, 12, 13, NULL, NULL, NULL),
	(18, 'PROFILE', 52, 18, 0, 0, 3, 3, '1', NULL, NULL),
	(19, 'PROFILE', 52, 18, 0, 0, 4, 4, '1', NULL, NULL),
	(20, 'PROFILE', 52, 18, 0, 0, 12, 13, '1', NULL, NULL),
	(21, 'PROFILE', 52, 37, 0, 0, 3, 3, '$F80', NULL, NULL),
	(22, 'PROFILE', 52, 37, 0, 0, 4, 4, '$F80', NULL, NULL),
	(23, 'PROFILE', 52, 37, 0, 0, 12, 13, '$F80', NULL, NULL),
	(24, 'DISCRETE', 53, 232, 0, -1, 0, 0, NULL, NULL, NULL),
	(25, 'DISCRETE', 63, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(26, 'DISCRETE', 66, 18, 0, -1, 0, 0, '0', NULL, NULL),
	(27, 'PROFILE', 68, 37, 0, 0, 3, 3, '1', NULL, NULL),
	(28, 'PROFILE', 68, 37, 0, 0, 4, 4, '1', NULL, NULL),
	(29, 'PROFILE', 68, 37, 0, 0, 12, 13, '1', NULL, NULL),
	(30, 'PROFILE', 69, 37, 0, 0, 3, 3, '1', NULL, NULL),
	(31, 'PROFILE', 69, 37, 0, 0, 4, 4, '1', NULL, NULL),
	(32, 'PROFILE', 69, 37, 0, 0, 12, 13, '1', NULL, NULL),
	(33, 'INSTANT', 77, 130, 0, 0, 7, 7, '1100', NULL, NULL),
	(34, 'DISCRETE', 78, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(35, 'INSTANT', 78, 158, 0, 0, 7, 7, NULL, NULL, NULL),
	(36, 'METER JOURNAL', 78, 158, 2, 0, 0, 0, NULL, NULL, NULL),
	(37, 'DISCRETE', 87, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(38, 'ALL SHEAF', 87, 21, -1, 0, 0, 0, '0', NULL, NULL),
	(40, 'ALL SHEAF', 91, 21, -1, 0, 0, 0, NULL, NULL, NULL),
	(41, 'DISCRETE', 91, 18, 0, -1, 0, 0, '1', NULL, NULL),
	(42, 'ALL SHEAF', 92, 21, -1, 0, 0, 0, NULL, NULL, NULL),
	(43, 'VISI BE SHEAF', 92, 18, 0, 0, -1, -1, '1', NULL, NULL),
	(44, 'ALL SHEAF', 96, 21, -1, 0, 0, 0, NULL, NULL, NULL),
	(45, 'ALL SHEAF', 97, 21, -1, 0, 0, 0, NULL, NULL, NULL),
	(46, 'CONTROLLER JOURNAL', 101, 152, 2, 0, 0, 0, '4', NULL, NULL),
	(48, 'METER JOURNAL', 101, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(50, 'DATE/TIME', 101, 150, 1, 0, 0, 0, '0', NULL, NULL),
	(51, 'DATE/TIME CORRECTION', 101, 150, 14, 0, 0, 0, '0', NULL, NULL),
	(53, 'DATE/TIME', 101, 149, 1, 0, 0, 0, '0', NULL, NULL),
	(54, 'DATE/TIME CORRECTION', 101, 149, 14, 0, 0, 0, '0', NULL, NULL),
	(55, 'DISCRETE', 104, 160, 0, -1, 0, 0, '0', NULL, NULL),
	(56, 'DISCRETE', 104, 162, 0, -1, 0, 0, '0', NULL, NULL),
	(57, 'DISCRETE', 104, 159, 0, -1, 0, 0, '0', NULL, NULL),
	(58, 'DISCRETE', 104, 161, 0, -1, 0, 0, '0', NULL, NULL),
	(59, 'SUM', 105, 21, 0, 0, -1, 8, '1', NULL, NULL),
	(60, 'ALL SHEAF', 106, 18, -1, 0, 0, 0, NULL, NULL, NULL),
	(61, 'DISCRETE', 106, 147, 0, -1, 0, 0, NULL, NULL, NULL),
	(62, 'DISCRETE', 106, 148, 0, -1, 0, 0, NULL, NULL, NULL),
	(63, 'DISCRETE', 117, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(64, 'ALL SHEAF', 117, 21, -1, 0, 0, 0, '0', NULL, NULL),
	(66, 'DISCRETE', 118, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(67, 'ALL SHEAF', 118, 21, -1, 0, 0, 0, '0', NULL, NULL),
	(69, 'WITHOUT SHEAF', 26, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(70, 'WITHOUT SHEAF', 38, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(71, 'WITHOUT SHEAF', 53, 232, 0, 0, -1, -1, NULL, NULL, NULL),
	(72, 'WITHOUT SHEAF', 63, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(73, 'WITHOUT SHEAF', 66, 18, 0, 0, -1, -1, '0', NULL, NULL),
	(74, 'WITHOUT SHEAF', 78, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(75, 'WITHOUT SHEAF', 87, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(76, 'WITHOUT SHEAF', 91, 18, 0, 0, -1, -1, '1', NULL, NULL),
	(77, 'WITHOUT SHEAF', 101, 18, 0, 0, -1, -1, '0', NULL, NULL),
	(78, 'WITHOUT SHEAF', 101, 150, 0, 0, -1, -1, '0', NULL, NULL),
	(79, 'WITHOUT SHEAF', 101, 149, 0, 0, -1, -1, '0', NULL, NULL),
	(80, 'WITHOUT SHEAF', 104, 160, 0, 0, -1, -1, '0', NULL, NULL),
	(81, 'WITHOUT SHEAF', 104, 162, 0, 0, -1, -1, '0', NULL, NULL),
	(82, 'WITHOUT SHEAF', 104, 159, 0, 0, -1, -1, '0', NULL, NULL),
	(83, 'WITHOUT SHEAF', 104, 161, 0, 0, -1, -1, '0', NULL, NULL),
	(84, 'WITHOUT SHEAF', 106, 147, 0, 0, -1, -1, NULL, NULL, NULL),
	(85, 'WITHOUT SHEAF', 106, 148, 0, 0, -1, -1, NULL, NULL, NULL),
	(86, 'WITHOUT SHEAF', 117, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(87, 'WITHOUT SHEAF', 118, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(88, 'PROFILE', 103, 28, 0, 0, 3, 3, '1800', NULL, NULL),
	(89, 'PROFILE', 103, 28, 0, 0, 4, 4, '1800', NULL, NULL),
	(90, 'PROFILE', 103, 28, 0, 0, 12, 13, '1800', NULL, NULL),
	(91, 'PROFILE', 24, 170, 0, 0, 3, 3, '1', NULL, NULL),
	(92, 'PROFILE', 24, 170, 0, 0, 4, 4, '1', NULL, NULL),
	(93, 'PROFILE', 24, 170, 0, 0, 12, 13, '1', NULL, NULL),
	(96, 'WITHOUT SHEAF', 102, 18, 0, 0, -1, -1, '0', NULL, NULL),
	(97, 'TIME_CORRECTION', 136, 164, 14, 0, 0, 0, '0', NULL, NULL),
	(98, 'TIME_CORRECTION', 136, 165, 14, 0, 0, 0, '0', NULL, NULL),
	(106, 'TIME_CORRECTION', 63, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(107, 'TIME_CORRECTION', 63, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(108, 'TIME', 63, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(109, 'TIME', 63, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(110, 'TIME_CORRECTION', 78, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(111, 'TIME_CORRECTION', 78, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(112, 'TIME', 78, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(113, 'TIME', 78, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(114, 'TIME_CORRECTION', 77, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(115, 'TIME_CORRECTION', 77, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(116, 'DISCRETE', 87, 21, 0, -1, 0, 0, NULL, NULL, NULL),
	(121, 'ALL SHEAF', 106, 158, -1, 0, 0, 0, '1', NULL, NULL),
	(122, 'TIME_CORRECTION', 103, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(123, 'TIME_CORRECTION', 103, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(124, 'TIME', 103, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(125, 'TIME', 103, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(126, 'WITHOUT SHEAF', 130, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(127, 'DAY', 130, 180, 0, 0, 5, 5, '0', NULL, NULL),
	(128, 'MONTH', 130, 180, 0, 0, 6, 6, '0', NULL, NULL),
	(131, 'PROFILE', 143, 18, 0, 0, 3, 3, NULL, NULL, NULL),
	(132, 'PROFILE', 143, 18, 0, 0, 4, 4, NULL, NULL, NULL),
	(133, 'PROFILE', 143, 18, 0, 0, 12, 13, NULL, NULL, NULL),
	(134, 'TIME_CORRECTION', 87, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(135, 'TIME_CORRECTION', 87, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(136, 'TIME', 87, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(137, 'TIME', 87, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(138, 'TIME_CORRECTION', 117, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(139, 'TIME_CORRECTION', 117, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(140, 'TIME', 117, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(141, 'TIME', 117, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(142, 'TIME_CORRECTION', 118, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(143, 'TIME_CORRECTION', 118, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(144, 'TIME', 118, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(145, 'TIME', 118, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(146, 'TIME_CORRECTION', 102, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(147, 'TIME_CORRECTION', 102, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(148, 'TIME', 102, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(149, 'TIME', 102, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(151, 'TIME_CORRECTION', 127, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(152, 'TIME_CORRECTION', 127, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(153, 'DATE/TIME CORRECTION', 144, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(154, 'DATE/TIME CORRECTION', 144, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(155, 'TIME', 144, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(156, 'TIME', 144, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(157, 'TIME', 144, 149, 1, 0, 0, 0, '0', NULL, NULL),
	(158, 'TIME', 144, 150, 1, 0, 0, 0, '0', NULL, NULL),
	(159, 'WITHOUT SHEAF', 144, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(160, 'METER JOURNAL', 144, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(161, 'METER JOURNAL', 144, 152, 2, 0, 0, 0, '4', NULL, NULL),
	(164, 'WITHOUT SHEAF', 144, 149, 0, 0, -1, -1, '0', NULL, NULL),
	(165, 'WITHOUT SHEAF', 144, 150, 0, 0, -1, -1, '0', NULL, NULL),
	(166, 'WITHOUT SHEAF', 81, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(167, 'DISCRETE', 81, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(168, 'METER JOURNAL', 81, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(171, 'WITHOUT DISCRETE', -2, 193, -1, 0, -1, -1, '0', NULL, NULL),
	(176, 'SUM', 147, 18, 0, 0, -1, 8, NULL, NULL, NULL),
	(177, 'TIME', 154, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(178, 'TIME', 154, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(179, 'PROFILE', 25, 202, 0, 0, 3, 3, '21', NULL, NULL),
	(180, 'PROFILE', 25, 202, 0, 0, 4, 4, '21', NULL, NULL),
	(181, 'PROFILE', 25, 202, 0, 0, 12, 13, '21', NULL, NULL),
	(182, 'PROFILE', 127, 202, 0, 0, 3, 3, '21', NULL, NULL),
	(183, 'PROFILE', 127, 202, 0, 0, 4, 4, '21', NULL, NULL),
	(184, 'PROFILE', 127, 202, 0, 0, 12, 13, '21', NULL, NULL),
	(185, 'INSTANT', 24, 104, 0, 0, 7, 7, '230', NULL, NULL),
	(187, 'TIME_CORRECTION', 1, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(188, 'TIME_CORRECTION', 1, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(189, 'TIME', 1, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(190, 'TIME', 1, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(191, 'TIME_CORRECTION', 30, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(192, 'TIME_CORRECTION', 30, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(193, 'TIME', 30, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(194, 'TIME', 30, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(195, 'TIME_CORRECTION', 51, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(196, 'TIME_CORRECTION', 51, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(197, 'TIME', 51, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(198, 'TIME', 51, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(199, 'TIME_CORRECTION', 25, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(200, 'TIME_CORRECTION', 25, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(201, 'TIME_CORRECTION', 33, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(202, 'TIME_CORRECTION', 33, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(203, 'TIME', 33, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(204, 'TIME', 33, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(211, 'DISCRETE', 87, 223, 0, -1, 0, 0, NULL, NULL, NULL),
	(212, 'WITHOUT SHEAF', 96, 18, 0, 0, -1, -1, '1', NULL, NULL),
	(213, 'WITHOUT SHEAF', 97, 18, 0, 0, -1, -1, '1', NULL, NULL),
	(214, 'WITHOUT SHEAF', 97, 107, 0, 0, -1, -1, '1', NULL, NULL),
	(216, 'DISCRETE', 137, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(217, 'DISCRETE', 137, 224, 0, -1, 0, 0, NULL, NULL, NULL),
	(220, 'WITHOUT SHEAF', 137, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(221, 'WITHOUT SHEAF', 137, 37, 0, 0, -1, -1, NULL, NULL, NULL),
	(222, 'TIME', 137, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(223, 'TIME', 137, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(224, 'TIME_CORRECTION', 137, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(225, 'TIME_CORRECTION', 137, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(226, 'TIME', 147, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(227, 'TIME', 147, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(228, 'TIME_CORRECTION', 147, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(229, 'TIME_CORRECTION', 147, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(230, 'TIME', 168, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(231, 'TIME', 168, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(232, 'TIME_CORRECTION', 168, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(233, 'TIME_CORRECTION', 168, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(234, 'TIME', 38, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(235, 'TIME', 38, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(236, 'TIME_CORRECTION', 38, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(237, 'TIME_CORRECTION', 38, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(238, 'TIME_CORRECTION', 38, 227, 14, 0, 0, 0, '5', NULL, NULL),
	(239, 'TIME', 130, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(240, 'TIME', 130, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(241, 'TIME', 35, 229, 1, 0, 0, 0, NULL, NULL, NULL),
	(242, 'TIME', 35, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(243, 'TIME', 35, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(244, 'TIME_CORRECTION', 35, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(245, 'TIME_CORRECTION', 35, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(246, 'JOURNAL', 87, 18, 2, 0, 0, 0, '0', NULL, NULL),
	(247, 'JOURNAL', 117, 18, 2, 0, 0, 0, '0', NULL, NULL),
	(248, 'JOURNAL', 118, 18, 2, 0, 0, 0, '0', NULL, NULL),
	(249, 'JOURNAL', 186, 232, 2, 0, 0, 0, NULL, NULL, NULL),
	(250, 'WITHOUT SHEAF', 186, 232, 0, 0, -1, -1, NULL, NULL, NULL),
	(251, 'PROFILE', 165, 18, 0, 0, 12, 13, '1', NULL, NULL),
	(252, 'PROFILE', 165, 18, 0, 0, 3, 3, '1', NULL, NULL),
	(253, 'PROFILE', 165, 18, 0, 0, 4, 4, '1', NULL, NULL),
	(254, 'SUM', 165, 18, 0, 0, -1, 8, NULL, NULL, NULL),
	(255, 'TIME', 165, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(256, 'TIME', 165, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(257, 'TIME', 190, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(258, 'TIME', 190, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(259, 'TIME_CORRECTION', 190, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(260, 'TIME_CORRECTION', 190, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(261, 'DISCRETE', 190, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(262, 'WITHOUT SHEAF', 190, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(263, 'JOURNAL', 190, 18, 2, 0, 0, 0, '0', NULL, NULL),
	(265, 'TIME', 188, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(266, 'TIME', 188, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(267, 'TIME_CORRECTION', 188, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(268, 'TIME_CORRECTION', 188, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(277, 'TIME_CORRECTION', 174, 164, 14, 0, 0, 0, '0', NULL, NULL),
	(278, 'TIME_CORRECTION', 174, 165, 14, 0, 0, 0, '3540', NULL, NULL),
	(285, 'DISCRETE', 197, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(287, 'WITHOUT SHEAF', 197, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(288, 'DISCRETE', 197, 224, 0, -1, 0, 0, NULL, NULL, NULL),
	(290, 'WITHOUT SHEAF', 197, 37, 0, 0, -1, -1, NULL, NULL, NULL),
	(291, 'TIME', 197, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(292, 'TIME', 197, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(293, 'TIME_CORRECTION', 197, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(294, 'TIME_CORRECTION', 197, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(297, 'ALL SHEAF', 137, 18, -1, 0, 0, 0, NULL, NULL, NULL),
	(298, 'ALL SHEAF', 197, 18, -1, 0, 0, 0, NULL, NULL, NULL),
	(299, 'TIME_CORRECTION', 68, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(300, 'TIME_CORRECTION', 68, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(301, 'TIME_CORRECTION', 69, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(302, 'TIME_CORRECTION', 69, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(303, 'TIME_CORRECTION', 80, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(304, 'TIME_CORRECTION', 80, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(305, 'Full Journal', 140, 269, 2, 0, 0, 0, NULL, NULL, NULL),
	(306, 'Full Journal', 140, 270, 2, 0, 0, 0, NULL, NULL, NULL),
	(307, 'Full Journal', 140, 271, 2, 0, 0, 0, NULL, NULL, NULL),
	(308, 'Full Journal', 140, 272, 2, 0, 0, 0, NULL, NULL, NULL),
	(309, 'Full Journal', 140, 273, 2, 0, 0, 0, NULL, NULL, NULL),
	(310, 'Full Journal', 140, 274, 2, 0, 0, 0, NULL, NULL, NULL),
	(311, 'Full Journal', 140, 275, 2, 0, 0, 0, NULL, NULL, NULL),
	(312, 'Full Journal', 140, 276, 2, 0, 0, 0, NULL, NULL, NULL),
	(313, 'Full Journal', 140, 277, 2, 0, 0, 0, NULL, NULL, NULL),
	(314, 'Full Journal', 140, 278, 2, 0, 0, 0, NULL, NULL, NULL),
	(315, 'Full Journal', 140, 279, 2, 0, 0, 0, NULL, NULL, NULL),
	(316, 'Full Journal', 140, 280, 2, 0, 0, 0, NULL, NULL, NULL),
	(317, 'Full Journal', 140, 281, 2, 0, 0, 0, NULL, NULL, NULL),
	(318, 'JOURNAL', 203, 285, 2, 0, 0, 0, NULL, 1, NULL),
	(320, 'JOURNAL', 203, 284, 2, 0, 0, 0, NULL, 1, NULL),
	(322, 'TIME', 203, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(323, 'TIME', 203, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(324, 'JOURNAL', 139, 288, 2, 0, 0, 0, NULL, NULL, NULL),
	(325, 'JOURNAL', 139, 289, 2, 0, 0, 0, NULL, NULL, NULL),
	(326, 'JOURNAL', 139, 290, 2, 0, 0, 0, NULL, NULL, NULL),
	(327, 'JOURNAL', 139, 291, 2, 0, 0, 0, NULL, NULL, NULL),
	(334, 'WITHOUT SHEAF', 139, 256, 0, 0, -1, -1, NULL, NULL, NULL),
	(338, 'WITHOUT SHEAF', 139, 257, 0, 0, -1, -1, NULL, NULL, NULL),
	(342, 'WITHOUT SHEAF', 139, 258, 0, 0, -1, -1, NULL, NULL, NULL),
	(346, 'WITHOUT SHEAF', 139, 259, 0, 0, -1, -1, NULL, NULL, NULL),
	(350, 'WITHOUT SHEAF', 139, 18, 0, 0, 1, -1, NULL, NULL, NULL),
	(351, 'WITHOUT SHEAF', 139, 18, 0, 0, 2, -1, NULL, NULL, NULL),
	(352, 'WITHOUT SHEAF', 139, 18, 0, 0, 3, -1, NULL, NULL, NULL),
	(353, 'WITHOUT SHEAF', 139, 18, 0, 0, 4, -1, NULL, NULL, NULL),
	(354, 'WITHOUT SHEAF', 139, 18, 0, 0, 5, -1, NULL, NULL, NULL),
	(355, 'WITHOUT SHEAF', 139, 18, 0, 0, 6, -1, NULL, NULL, NULL),
	(356, 'WITHOUT SHEAF', 139, 18, 0, 0, 8, -1, NULL, NULL, NULL),
	(357, 'WITHOUT SHEAF', 139, 18, 0, 0, 9, -1, NULL, NULL, NULL),
	(358, 'WITHOUT SHEAF', 139, 18, 0, 0, 10, -1, NULL, NULL, NULL),
	(359, 'WITHOUT SHEAF', 139, 18, 0, 0, 11, -1, NULL, NULL, NULL),
	(360, 'WITHOUT SHEAF', 139, 18, 0, 0, 12, -1, NULL, NULL, NULL),
	(361, 'WITHOUT SHEAF', 139, 18, 0, 0, 13, -1, NULL, NULL, NULL),
	(362, 'WITHOUT SHEAF', 139, 18, 0, 0, 14, -1, NULL, NULL, NULL),
	(363, 'WITHOUT SHEAF', 139, 18, 0, 0, 15, -1, NULL, NULL, NULL),
	(364, 'WITHOUT SHEAF', 139, 18, 0, 0, 16, -1, NULL, NULL, NULL),
	(365, 'WITHOUT SHEAF', 139, 18, 0, 0, 17, -1, NULL, NULL, NULL),
	(366, 'WITHOUT SHEAF', 139, 18, 0, 0, 18, -1, NULL, NULL, NULL),
	(367, 'WITHOUT SHEAF', 139, 18, 0, 0, 19, -1, NULL, NULL, NULL),
	(368, 'WITHOUT SHEAF', 139, 286, 0, 0, 1, -1, NULL, NULL, NULL),
	(369, 'WITHOUT SHEAF', 139, 286, 0, 0, 2, -1, NULL, NULL, NULL),
	(370, 'WITHOUT SHEAF', 139, 286, 0, 0, 3, -1, NULL, NULL, NULL),
	(371, 'WITHOUT SHEAF', 139, 286, 0, 0, 4, -1, NULL, NULL, NULL),
	(372, 'WITHOUT SHEAF', 139, 286, 0, 0, 5, -1, NULL, NULL, NULL),
	(373, 'WITHOUT SHEAF', 139, 286, 0, 0, 6, -1, NULL, NULL, NULL),
	(374, 'WITHOUT SHEAF', 139, 286, 0, 0, 8, -1, NULL, NULL, NULL),
	(375, 'WITHOUT SHEAF', 139, 286, 0, 0, 9, -1, NULL, NULL, NULL),
	(376, 'WITHOUT SHEAF', 139, 286, 0, 0, 10, -1, NULL, NULL, NULL),
	(377, 'WITHOUT SHEAF', 139, 286, 0, 0, 11, -1, NULL, NULL, NULL),
	(378, 'WITHOUT SHEAF', 139, 286, 0, 0, 12, -1, NULL, NULL, NULL),
	(379, 'WITHOUT SHEAF', 139, 286, 0, 0, 13, -1, NULL, NULL, NULL),
	(380, 'WITHOUT SHEAF', 139, 286, 0, 0, 14, -1, NULL, NULL, NULL),
	(381, 'WITHOUT SHEAF', 139, 286, 0, 0, 15, -1, NULL, NULL, NULL),
	(382, 'WITHOUT SHEAF', 139, 286, 0, 0, 16, -1, NULL, NULL, NULL),
	(383, 'WITHOUT SHEAF', 139, 286, 0, 0, 17, -1, NULL, NULL, NULL),
	(384, 'WITHOUT SHEAF', 139, 286, 0, 0, 18, -1, NULL, NULL, NULL),
	(385, 'WITHOUT SHEAF', 139, 286, 0, 0, 19, -1, NULL, NULL, NULL),
	(386, 'WITHOUT SHEAF', 139, 287, 0, 0, 1, -1, NULL, NULL, NULL),
	(387, 'WITHOUT SHEAF', 139, 287, 0, 0, 2, -1, NULL, NULL, NULL),
	(388, 'WITHOUT SHEAF', 139, 287, 0, 0, 3, -1, NULL, NULL, NULL),
	(389, 'WITHOUT SHEAF', 139, 287, 0, 0, 4, -1, NULL, NULL, NULL),
	(390, 'WITHOUT SHEAF', 139, 287, 0, 0, 5, -1, NULL, NULL, NULL),
	(391, 'WITHOUT SHEAF', 139, 287, 0, 0, 6, -1, NULL, NULL, NULL),
	(392, 'WITHOUT SHEAF', 139, 287, 0, 0, 8, -1, NULL, NULL, NULL),
	(393, 'WITHOUT SHEAF', 139, 287, 0, 0, 9, -1, NULL, NULL, NULL),
	(394, 'WITHOUT SHEAF', 139, 287, 0, 0, 10, -1, NULL, NULL, NULL),
	(395, 'WITHOUT SHEAF', 139, 287, 0, 0, 11, -1, NULL, NULL, NULL),
	(396, 'WITHOUT SHEAF', 139, 287, 0, 0, 12, -1, NULL, NULL, NULL),
	(397, 'WITHOUT SHEAF', 139, 287, 0, 0, 13, -1, NULL, NULL, NULL),
	(398, 'WITHOUT SHEAF', 139, 287, 0, 0, 14, -1, NULL, NULL, NULL),
	(399, 'WITHOUT SHEAF', 139, 287, 0, 0, 15, -1, NULL, NULL, NULL),
	(400, 'WITHOUT SHEAF', 139, 287, 0, 0, 16, -1, NULL, NULL, NULL),
	(401, 'WITHOUT SHEAF', 139, 287, 0, 0, 17, -1, NULL, NULL, NULL),
	(402, 'WITHOUT SHEAF', 139, 287, 0, 0, 18, -1, NULL, NULL, NULL),
	(403, 'WITHOUT SHEAF', 139, 287, 0, 0, 19, -1, NULL, NULL, NULL),
	(404, 'SUM', 148, 18, 0, 0, -1, 8, NULL, NULL, NULL),
	(405, 'TIME', 148, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(406, 'TIME', 148, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(407, 'TIME_CORRECTION', 148, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(408, 'TIME_CORRECTION', 148, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(409, 'TIME', 140, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(410, 'TIME', 140, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(411, 'TIME_CORRECTION', 140, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(412, 'TIME_CORRECTION', 140, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(413, 'TIME_CORRECTION', 140, 260, 14, 0, 0, 0, NULL, NULL, NULL),
	(414, 'SUMFIX', 140, 260, 0, 0, 5, 8, NULL, NULL, NULL),
	(415, 'SUMFIX', 140, 260, 0, 0, 6, 8, NULL, NULL, NULL),
	(416, 'INSTANT', 140, 260, 0, 0, 7, -1, NULL, NULL, NULL),
	(417, 'SUMFIX', 140, 18, 0, 0, 5, 8, NULL, NULL, NULL),
	(418, 'SUMFIX', 140, 18, 0, 0, 6, 8, NULL, NULL, NULL),
	(419, 'SUMFIX', 140, 259, 0, 0, 5, 8, NULL, NULL, NULL),
	(420, 'SUMFIX', 140, 259, 0, 0, 6, 8, NULL, NULL, NULL),
	(421, 'SUMFIX', 140, 257, 0, 0, 5, 8, NULL, NULL, NULL),
	(422, 'SUMFIX', 140, 257, 0, 0, 6, 8, NULL, NULL, NULL),
	(423, 'INSTANT', 140, 257, 0, 0, 7, -1, NULL, NULL, NULL),
	(424, 'WITHOUT SHEAF', 137, 232, 0, 0, -1, -1, NULL, NULL, NULL),
	(425, 'WITHOUT SHEAF', 197, 232, 0, 0, -1, -1, NULL, NULL, NULL),
	(426, 'WITHOUT SHEAF', 203, 295, 0, 0, -1, -1, '0', NULL, NULL),
	(427, 'WITHOUT SHEAF', 203, 285, 0, 0, -1, -1, NULL, NULL, NULL),
	(428, 'JOURNAL ALL', 203, 285, 22, 0, 0, 0, NULL, 1, NULL),
	(429, 'WITHOUT SHEAF', 203, 284, 0, 0, -1, -1, NULL, NULL, NULL),
	(430, 'JOURNAL ALL', 203, 284, 22, 0, 0, 0, NULL, 1, NULL),
	(431, 'WITHOUT SHEAF', 203, 106, 0, 0, -1, -1, NULL, NULL, NULL),
	(432, 'JOURNAL ALL', 203, 106, 2, 0, 0, 0, NULL, NULL, NULL),
	(433, 'JOURNAL ALL', 203, 106, 22, 0, 0, 0, NULL, NULL, NULL),
	(434, 'PROFILE', 140, 18, 0, 0, 12, 13, NULL, NULL, NULL),
	(435, 'PROFILE', 140, 18, 0, 0, 3, 3, NULL, NULL, NULL),
	(436, 'PROFILE', 140, 18, 0, 0, 4, 4, NULL, NULL, NULL),
	(437, 'PROFILE', 140, 260, 0, 0, 12, 13, NULL, NULL, NULL),
	(438, 'PROFILE', 140, 260, 0, 0, 3, 3, NULL, NULL, NULL),
	(439, 'PROFILE', 140, 260, 0, 0, 4, 4, NULL, NULL, NULL),
	(440, 'PROFILE', 140, 257, 0, 0, 12, 13, NULL, NULL, NULL),
	(441, 'PROFILE', 140, 257, 0, 0, 3, 3, NULL, NULL, NULL),
	(442, 'PROFILE', 140, 257, 0, 0, 4, 4, NULL, NULL, NULL),
	(443, 'PROFILE', 140, 259, 0, 0, 12, 13, NULL, NULL, NULL),
	(444, 'PROFILE', 140, 259, 0, 0, 3, 3, NULL, NULL, NULL),
	(445, 'PROFILE', 140, 259, 0, 0, 4, 4, NULL, NULL, NULL),
	(446, 'JOURNAL ALL', 203, 285, 19, 0, 0, 0, NULL, NULL, NULL),
	(447, 'JOURNAL ALL', 203, 284, 19, 0, 0, 0, NULL, NULL, NULL),
	(448, 'JOURNAL ALL', 203, 106, 19, 0, 0, 0, NULL, NULL, NULL),
	(449, 'JOURNAL ALL', 205, 106, 2, 0, 0, 0, NULL, NULL, NULL),
	(450, 'JOURNAL ALL', 205, 106, 22, 0, 0, 0, NULL, NULL, NULL),
	(451, 'SUM', 205, 106, 0, 0, -1, 8, NULL, NULL, NULL),
	(452, 'TIME', 205, 106, 1, 0, 0, 0, NULL, NULL, NULL),
	(453, 'RELAY', 205, 106, 10010, 0, 0, 0, NULL, NULL, NULL),
	(454, 'TIME', 205, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(455, 'TIME', 205, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(456, 'JOURNAL ALL', 205, 232, 2, 0, 0, 0, NULL, NULL, NULL),
	(457, 'JOURNAL ALL', 205, 232, 22, 0, 0, 0, NULL, NULL, NULL),
	(458, 'SUM', 205, 232, 0, 0, -1, 8, NULL, NULL, NULL),
	(459, 'RELAY', 205, 232, 10010, 0, 0, 0, NULL, NULL, NULL),
	(460, 'JOURNAL ALL', 206, 106, 2, 0, 0, 0, NULL, NULL, NULL),
	(461, 'JOURNAL ALL', 206, 106, 22, 0, 0, 0, NULL, NULL, NULL),
	(462, 'SUM', 206, 106, 0, 0, -1, 8, NULL, NULL, NULL),
	(463, 'TIME', 206, 106, 1, 0, 0, 0, NULL, NULL, NULL),
	(464, 'RELAY', 206, 106, 10010, 0, 0, 0, NULL, NULL, NULL),
	(465, 'JOURNAL ALL', 206, 232, 2, 0, 0, 0, NULL, NULL, NULL),
	(466, 'JOURNAL ALL', 206, 232, 22, 0, 0, 0, NULL, NULL, NULL),
	(467, 'SUM', 206, 232, 0, 0, -1, 8, NULL, NULL, NULL),
	(468, 'TIME', 206, 232, 1, 0, 0, 0, NULL, NULL, NULL),
	(469, 'RELAY', 206, 232, 10010, 0, 0, 0, NULL, NULL, NULL),
	(470, 'TIME', 135, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(471, 'TIME', 135, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(472, 'TIME_CORRECTION', 135, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(473, 'TIME_CORRECTION', 135, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(474, 'TIME', 207, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(475, 'TIME', 207, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(476, 'TIME_CORRECTION', 207, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(477, 'TIME_CORRECTION', 207, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(478, 'TIME', 145, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(479, 'TIME', 145, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(482, 'TIME', 208, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(483, 'TIME', 208, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(486, 'PROFILE', 209, 18, 0, 0, 12, 13, NULL, NULL, NULL),
	(487, 'PROFILE', 209, 18, 0, 0, 4, 4, NULL, NULL, NULL),
	(488, 'PROFILE', 209, 18, 0, 0, 3, 3, NULL, NULL, NULL),
	(489, 'SUMFIX', 209, 18, 0, 0, 6, 8, NULL, NULL, NULL),
	(490, 'SUMFIX', 209, 18, 0, 0, 5, 8, NULL, NULL, NULL),
	(491, 'TIME_CORRECTION', 209, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(492, 'TIME', 209, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(493, 'TIME_CORRECTION', 209, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(494, 'TIME', 209, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(495, 'PROFILE', 209, 257, 0, 0, 4, 4, NULL, NULL, NULL),
	(496, 'PROFILE', 209, 257, 0, 0, 3, 3, NULL, NULL, NULL),
	(497, 'PROFILE', 209, 257, 0, 0, 12, 13, NULL, NULL, NULL),
	(498, 'INSTANT', 209, 257, 0, 0, 7, -1, NULL, NULL, NULL),
	(499, 'SUMFIX', 209, 257, 0, 0, 6, 8, NULL, NULL, NULL),
	(500, 'SUMFIX', 209, 257, 0, 0, 5, 8, NULL, NULL, NULL),
	(501, 'PROFILE', 209, 259, 0, 0, 4, 4, NULL, NULL, NULL),
	(502, 'PROFILE', 209, 259, 0, 0, 3, 3, NULL, NULL, NULL),
	(503, 'PROFILE', 209, 259, 0, 0, 12, 13, NULL, NULL, NULL),
	(504, 'SUMFIX', 209, 259, 0, 0, 6, 8, NULL, NULL, NULL),
	(505, 'SUMFIX', 209, 259, 0, 0, 5, 8, NULL, NULL, NULL),
	(506, 'PROFILE', 209, 260, 0, 0, 4, 4, NULL, NULL, NULL),
	(507, 'PROFILE', 209, 260, 0, 0, 3, 3, NULL, NULL, NULL),
	(508, 'PROFILE', 209, 260, 0, 0, 12, 13, NULL, NULL, NULL),
	(509, 'INSTANT', 209, 260, 0, 0, 7, -1, NULL, NULL, NULL),
	(510, 'SUMFIX', 209, 260, 0, 0, 6, 8, NULL, NULL, NULL),
	(511, 'SUMFIX', 209, 260, 0, 0, 5, 8, NULL, NULL, NULL),
	(512, 'TIME_CORRECTION', 209, 260, 14, 0, 0, 0, NULL, NULL, NULL),
	(513, 'Full Journal', 209, 269, 2, 0, 0, 0, NULL, NULL, NULL),
	(514, 'Full Journal', 209, 270, 2, 0, 0, 0, NULL, NULL, NULL),
	(515, 'Full Journal', 209, 271, 2, 0, 0, 0, NULL, NULL, NULL),
	(516, 'Full Journal', 209, 272, 2, 0, 0, 0, NULL, NULL, NULL),
	(517, 'Full Journal', 209, 273, 2, 0, 0, 0, NULL, NULL, NULL),
	(518, 'Full Journal', 209, 274, 2, 0, 0, 0, NULL, NULL, NULL),
	(519, 'Full Journal', 209, 275, 2, 0, 0, 0, NULL, NULL, NULL),
	(520, 'Full Journal', 209, 276, 2, 0, 0, 0, NULL, NULL, NULL),
	(521, 'Full Journal', 209, 277, 2, 0, 0, 0, NULL, NULL, NULL),
	(522, 'Full Journal', 209, 278, 2, 0, 0, 0, NULL, NULL, NULL),
	(523, 'Full Journal', 209, 279, 2, 0, 0, 0, NULL, NULL, NULL),
	(524, 'Full Journal', 209, 280, 2, 0, 0, 0, NULL, NULL, NULL),
	(525, 'Full Journal', 209, 281, 2, 0, 0, 0, NULL, NULL, NULL),
	(526, 'SUMFIX', 140, 18, 0, 0, 6, 6, NULL, NULL, NULL),
	(527, 'SUMFIX', 140, 257, 0, 0, 6, 6, NULL, NULL, NULL),
	(528, 'SUMFIX', 140, 259, 0, 0, 6, 6, NULL, NULL, NULL),
	(529, 'SUMFIX', 140, 260, 0, 0, 6, 6, NULL, NULL, NULL),
	(530, 'SUMFIX', 209, 18, 0, 0, 6, 6, NULL, NULL, NULL),
	(531, 'SUMFIX', 209, 257, 0, 0, 6, 6, NULL, NULL, NULL),
	(532, 'SUMFIX', 209, 259, 0, 0, 6, 6, NULL, NULL, NULL),
	(533, 'SUMFIX', 209, 260, 0, 0, 6, 6, NULL, NULL, NULL),
	(534, 'SRC_TYPE_LPTY_FILTER', 210, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(535, 'TIME', 210, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(536, 'TIME', 210, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(537, 'TIME_CORRECTION', 210, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(538, 'TIME_CORRECTION', 210, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(541, 'RELAY', 140, 260, 10010, 0, 0, 0, NULL, NULL, NULL),
	(542, 'RELAY', 209, 260, 10010, 0, 0, 0, NULL, NULL, NULL),
	(543, 'INSTANT', 200, 323, 0, 0, 7, -1, NULL, NULL, NULL),
	(544, 'PROFILE', 200, 323, 0, 0, 4, 4, NULL, NULL, NULL),
	(545, 'PROFILE', 200, 323, 0, 0, 5, 5, NULL, NULL, NULL),
	(546, 'PROFILE', 200, 323, 0, 0, 6, 6, NULL, NULL, NULL),
	(547, 'SUMFIX', 200, 323, 0, 0, 4, 8, NULL, NULL, NULL),
	(548, 'SUMFIX', 200, 323, 0, 0, 5, 8, NULL, NULL, NULL),
	(549, 'SUMFIX', 200, 323, 0, 0, 6, 8, NULL, NULL, NULL),
	(550, 'INSTANT', 200, 18, 0, 0, 7, -1, NULL, NULL, NULL),
	(551, 'PROFILE', 200, 18, 0, 0, 4, 4, NULL, NULL, NULL),
	(552, 'PROFILE', 200, 18, 0, 0, 5, 5, NULL, NULL, NULL),
	(553, 'PROFILE', 200, 18, 0, 0, 6, 6, NULL, NULL, NULL),
	(554, 'SUMFIX', 200, 18, 0, 0, 4, 8, NULL, NULL, NULL),
	(555, 'SUMFIX', 200, 18, 0, 0, 5, 8, NULL, NULL, NULL),
	(556, 'SUMFIX', 200, 18, 0, 0, 6, 8, NULL, NULL, NULL),
	(557, 'INSTANT', 200, 106, 0, 0, 7, -1, NULL, NULL, NULL),
	(558, 'PROFILE', 200, 106, 0, 0, 4, 4, NULL, NULL, NULL),
	(559, 'PROFILE', 200, 106, 0, 0, 5, 5, NULL, NULL, NULL),
	(560, 'PROFILE', 200, 106, 0, 0, 6, 6, NULL, NULL, NULL),
	(561, 'SUMFIX', 200, 106, 0, 0, 4, 8, NULL, NULL, NULL),
	(562, 'SUMFIX', 200, 106, 0, 0, 5, 8, NULL, NULL, NULL),
	(563, 'SUMFIX', 200, 106, 0, 0, 6, 8, NULL, NULL, NULL),
	(564, 'WITHOUT SHEAF', 185, 106, 0, 0, -1, -1, NULL, NULL, NULL),
	(571, 'WITHOUT SHEAF', 214, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(572, 'WITHOUT SHEAF', 214, 106, 0, 0, -1, -1, NULL, NULL, NULL),
	(573, 'Full Journal', 200, 106, 2, 0, 0, 0, NULL, NULL, NULL),
	(575, 'SUMFIX', 140, 18, 0, 0, 4, 8, NULL, NULL, NULL),
	(576, 'SUMFIX', 140, 257, 0, 0, 4, 8, NULL, NULL, NULL),
	(577, 'SUMFIX', 140, 259, 0, 0, 4, 8, NULL, NULL, NULL),
	(578, 'SUMFIX', 140, 260, 0, 0, 4, 8, NULL, NULL, NULL),
	(579, 'SUMFIX', 209, 18, 0, 0, 4, 8, NULL, NULL, NULL),
	(580, 'SUMFIX', 209, 257, 0, 0, 4, 8, NULL, NULL, NULL),
	(581, 'SUMFIX', 209, 259, 0, 0, 4, 8, NULL, NULL, NULL),
	(582, 'SUMFIX', 209, 260, 0, 0, 4, 8, NULL, NULL, NULL),
	(583, 'DATE/TIME CORRECTION', 226, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(584, 'DATE/TIME CORRECTION', 226, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(585, 'TIME', 226, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(586, 'TIME', 226, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(587, 'TIME', 226, 149, 1, 0, 0, 0, '0', NULL, NULL),
	(588, 'TIME', 226, 150, 1, 0, 0, 0, '0', NULL, NULL),
	(589, 'WITHOUT SHEAF', 226, 334, 0, 0, -1, -1, NULL, NULL, NULL),
	(590, 'METER JOURNAL', 226, 334, 2, 0, 0, 0, NULL, NULL, NULL),
	(591, 'WITHOUT SHEAF', 226, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(592, 'METER JOURNAL', 226, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(593, 'METER JOURNAL', 226, 152, 2, 0, 0, 0, '4', NULL, NULL),
	(594, 'WITHOUT SHEAF', 226, 149, 0, 0, -1, -1, '0', NULL, NULL),
	(595, 'WITHOUT SHEAF', 226, 150, 0, 0, -1, -1, '0', NULL, NULL),
	(596, 'WITHOUT SHEAF', 226, 335, 0, 0, -1, -1, NULL, NULL, NULL),
	(597, 'METER JOURNAL', 226, 335, 2, 0, 0, 0, NULL, NULL, NULL),
	(601, 'Full Journal', 209, 336, 2, 0, 0, 0, NULL, NULL, NULL),
	(602, 'Full Journal', 140, 336, 2, 0, 0, 0, NULL, NULL, NULL),
	(603, 'Full Journal', 209, 336, 22, 0, 0, 0, NULL, NULL, NULL),
	(604, 'Full Journal', 140, 336, 22, 0, 0, 0, NULL, NULL, NULL),
	(605, 'JOURNAL ALL', 140, 269, 22, 0, 0, 0, NULL, NULL, NULL),
	(606, 'JOURNAL ALL', 140, 270, 22, 0, 0, 0, NULL, NULL, NULL),
	(607, 'JOURNAL ALL', 140, 271, 22, 0, 0, 0, NULL, NULL, NULL),
	(608, 'JOURNAL ALL', 140, 272, 22, 0, 0, 0, NULL, NULL, NULL),
	(609, 'JOURNAL ALL', 140, 273, 22, 0, 0, 0, NULL, NULL, NULL),
	(610, 'JOURNAL ALL', 140, 274, 22, 0, 0, 0, NULL, NULL, NULL),
	(611, 'JOURNAL ALL', 140, 275, 22, 0, 0, 0, NULL, NULL, NULL),
	(612, 'JOURNAL ALL', 140, 276, 22, 0, 0, 0, NULL, NULL, NULL),
	(613, 'JOURNAL ALL', 140, 277, 22, 0, 0, 0, NULL, NULL, NULL),
	(614, 'JOURNAL ALL', 140, 278, 22, 0, 0, 0, NULL, NULL, NULL),
	(615, 'JOURNAL ALL', 140, 279, 22, 0, 0, 0, NULL, NULL, NULL),
	(616, 'JOURNAL ALL', 140, 280, 22, 0, 0, 0, NULL, NULL, NULL),
	(617, 'JOURNAL ALL', 140, 281, 22, 0, 0, 0, NULL, NULL, NULL),
	(618, 'JOURNAL ALL', 209, 269, 22, 0, 0, 0, NULL, NULL, NULL),
	(619, 'JOURNAL ALL', 209, 270, 22, 0, 0, 0, NULL, NULL, NULL),
	(620, 'JOURNAL ALL', 209, 271, 22, 0, 0, 0, NULL, NULL, NULL),
	(621, 'JOURNAL ALL', 209, 272, 22, 0, 0, 0, NULL, NULL, NULL),
	(622, 'JOURNAL ALL', 209, 273, 22, 0, 0, 0, NULL, NULL, NULL),
	(623, 'JOURNAL ALL', 209, 274, 22, 0, 0, 0, NULL, NULL, NULL),
	(624, 'JOURNAL ALL', 209, 275, 22, 0, 0, 0, NULL, NULL, NULL),
	(625, 'JOURNAL ALL', 209, 276, 22, 0, 0, 0, NULL, NULL, NULL),
	(626, 'JOURNAL ALL', 209, 277, 22, 0, 0, 0, NULL, NULL, NULL),
	(627, 'JOURNAL ALL', 209, 278, 22, 0, 0, 0, NULL, NULL, NULL),
	(628, 'JOURNAL ALL', 209, 279, 22, 0, 0, 0, NULL, NULL, NULL),
	(629, 'JOURNAL ALL', 209, 280, 22, 0, 0, 0, NULL, NULL, NULL),
	(630, 'JOURNAL ALL', 209, 281, 22, 0, 0, 0, NULL, NULL, NULL),
	(631, 'DATE/TIME CORRECTION', 229, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(632, 'DATE/TIME CORRECTION', 229, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(633, 'TIME', 229, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(634, 'TIME', 229, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(635, 'TIME', 229, 149, 1, 0, 0, 0, '0', NULL, NULL),
	(636, 'TIME', 229, 150, 1, 0, 0, 0, '0', NULL, NULL),
	(637, 'WITHOUT SHEAF', 229, 334, 0, 0, -1, -1, NULL, NULL, NULL),
	(638, 'METER JOURNAL', 229, 334, 2, 0, 0, 0, NULL, NULL, NULL),
	(639, 'WITHOUT SHEAF', 229, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(640, 'METER JOURNAL', 229, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(641, 'METER JOURNAL', 229, 152, 2, 0, 0, 0, '4', NULL, NULL),
	(642, 'WITHOUT SHEAF', 229, 149, 0, 0, -1, -1, '0', NULL, NULL),
	(643, 'WITHOUT SHEAF', 229, 150, 0, 0, -1, -1, '0', NULL, NULL),
	(644, 'JOURNAL ALL', 229, 334, 22, 0, 0, 0, NULL, NULL, NULL),
	(645, 'JOURNAL ALL', 229, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(646, 'JOURNAL ALL', 229, 152, 22, 0, 0, 0, '4', NULL, NULL),
	(647, 'JOURNAL ALL', 229, 335, 22, 0, 0, 0, NULL, NULL, NULL),
	(648, 'WITHOUT SHEAF', 229, 335, 0, 0, -1, -1, NULL, NULL, NULL),
	(649, 'METER JOURNAL', 229, 335, 2, 0, 0, 0, NULL, NULL, NULL),
	(650, 'DATE/TIME CORRECTION', 228, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(651, 'DATE/TIME CORRECTION', 228, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(652, 'TIME', 228, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(653, 'TIME', 228, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(654, 'TIME', 228, 149, 1, 0, 0, 0, '0', NULL, NULL),
	(655, 'TIME', 228, 150, 1, 0, 0, 0, '0', NULL, NULL),
	(656, 'WITHOUT SHEAF', 228, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(657, 'METER JOURNAL', 228, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(658, 'METER JOURNAL', 228, 152, 2, 0, 0, 0, '4', NULL, NULL),
	(659, 'WITHOUT SHEAF', 228, 149, 0, 0, -1, -1, '0', NULL, NULL),
	(660, 'WITHOUT SHEAF', 228, 150, 0, 0, -1, -1, '0', NULL, NULL),
	(661, 'JOURNAL ALL', 228, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(662, 'JOURNAL ALL', 228, 152, 22, 0, 0, 0, '4', NULL, NULL),
	(663, 'JOURNAL ALL', 144, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(664, 'JOURNAL ALL', 144, 152, 22, 0, 0, 0, '4', NULL, NULL),
	(665, 'JOURNAL ALL', 226, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(666, 'JOURNAL ALL', 226, 152, 22, 0, 0, 0, '4', NULL, NULL),
	(667, 'JOURNAL ALL', 226, 334, 22, 0, 0, 0, NULL, NULL, NULL),
	(668, 'JOURNAL ALL', 226, 335, 22, 0, 0, 0, NULL, NULL, NULL),
	(669, 'RELAY', 140, 339, 10010, 0, 0, 0, NULL, NULL, NULL),
	(670, 'RELAY', 209, 339, 10010, 0, 0, 0, NULL, NULL, NULL),
	(671, 'JOURNAL ALL', 53, 232, 22, 0, 0, 0, NULL, NULL, NULL),
	(672, 'METER JOURNAL', 53, 232, 2, 0, 0, 0, NULL, NULL, NULL),
	(673, 'TIME', 235, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(674, 'TIME', 235, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(675, 'TIME_CORRECTION', 235, 164, 14, 0, 0, 0, '0', NULL, NULL),
	(676, 'TIME_CORRECTION', 235, 165, 14, 0, 0, 0, '0', NULL, NULL),
	(677, 'PROFILE', 209, 18, 0, 0, 1, 1, NULL, NULL, NULL),
	(678, 'PROFILE', 209, 18, 0, 0, 2, 2, NULL, NULL, NULL),
	(679, 'PROFILE', 209, 18, 0, 0, 8, 9, NULL, NULL, NULL),
	(680, 'PROFILE', 209, 18, 0, 0, 10, 11, NULL, NULL, NULL),
	(681, 'PROFILE', 209, 257, 0, 0, 1, 1, NULL, NULL, NULL),
	(682, 'PROFILE', 209, 257, 0, 0, 2, 2, NULL, NULL, NULL),
	(683, 'PROFILE', 209, 257, 0, 0, 8, 9, NULL, NULL, NULL),
	(684, 'PROFILE', 209, 257, 0, 0, 10, 11, NULL, NULL, NULL),
	(685, 'PROFILE', 209, 259, 0, 0, 1, 1, NULL, NULL, NULL),
	(686, 'PROFILE', 209, 259, 0, 0, 2, 2, NULL, NULL, NULL),
	(687, 'PROFILE', 209, 259, 0, 0, 8, 9, NULL, NULL, NULL),
	(688, 'PROFILE', 209, 259, 0, 0, 10, 11, NULL, NULL, NULL),
	(689, 'PROFILE', 209, 260, 0, 0, 1, 1, NULL, NULL, NULL),
	(690, 'PROFILE', 209, 260, 0, 0, 2, 2, NULL, NULL, NULL),
	(691, 'PROFILE', 209, 260, 0, 0, 8, 9, NULL, NULL, NULL),
	(692, 'PROFILE', 209, 260, 0, 0, 10, 11, NULL, NULL, NULL),
	(693, 'PROFILE', 140, 18, 0, 0, 1, 1, NULL, NULL, NULL),
	(694, 'PROFILE', 140, 18, 0, 0, 2, 2, NULL, NULL, NULL),
	(695, 'PROFILE', 140, 18, 0, 0, 8, 9, NULL, NULL, NULL),
	(696, 'PROFILE', 140, 18, 0, 0, 10, 11, NULL, NULL, NULL),
	(697, 'PROFILE', 140, 257, 0, 0, 1, 1, NULL, NULL, NULL),
	(698, 'PROFILE', 140, 257, 0, 0, 2, 2, NULL, NULL, NULL),
	(699, 'PROFILE', 140, 257, 0, 0, 8, 9, NULL, NULL, NULL),
	(700, 'PROFILE', 140, 257, 0, 0, 10, 11, NULL, NULL, NULL),
	(701, 'PROFILE', 140, 259, 0, 0, 1, 1, NULL, NULL, NULL),
	(702, 'PROFILE', 140, 259, 0, 0, 2, 2, NULL, NULL, NULL),
	(703, 'PROFILE', 140, 259, 0, 0, 8, 9, NULL, NULL, NULL),
	(704, 'PROFILE', 140, 259, 0, 0, 10, 11, NULL, NULL, NULL),
	(705, 'PROFILE', 140, 260, 0, 0, 1, 1, NULL, NULL, NULL),
	(706, 'PROFILE', 140, 260, 0, 0, 2, 2, NULL, NULL, NULL),
	(707, 'PROFILE', 140, 260, 0, 0, 8, 9, NULL, NULL, NULL),
	(708, 'PROFILE', 140, 260, 0, 0, 10, 11, NULL, NULL, NULL),
	(709, 'PROFILE_DAY', 217, 348, 0, 0, 5, -1, NULL, NULL, NULL),
	(710, 'PROFILE_MONTH', 217, 349, 0, 0, 6, -1, NULL, NULL, NULL),
	(711, 'PROFILE_HOUR', 217, 350, 0, 0, 4, -1, NULL, NULL, NULL),
	(712, 'PROFILE_HALFHOUR', 217, 351, 0, 0, 3, -1, NULL, NULL, NULL),
	(713, 'PROFILE_MINUTES', 217, 352, 0, 0, 1, -1, NULL, NULL, NULL),
	(714, 'PROFILE_MINUTES', 217, 352, 0, 0, 2, -1, NULL, NULL, NULL),
	(715, 'PROFILE_MINUTES', 217, 352, 0, 0, 8, -1, NULL, NULL, NULL),
	(716, 'PROFILE_MINUTES', 217, 352, 0, 0, 9, -1, NULL, NULL, NULL),
	(717, 'PROFILE_MINUTES', 217, 352, 0, 0, 10, -1, NULL, NULL, NULL),
	(718, 'PROFILE_MINUTES', 217, 352, 0, 0, 11, -1, NULL, NULL, NULL),
	(719, 'PROFILE_MINUTES', 217, 352, 0, 0, 12, -1, NULL, NULL, NULL),
	(720, 'PROFILE_MINUTES', 217, 352, 0, 0, 13, -1, NULL, NULL, NULL),
	(721, 'DISCRETE', 234, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(722, 'INSTANT', 33, 18, 0, 0, 1, 1, NULL, NULL, NULL),
	(723, 'INSTANT', 33, 18, 0, 0, 2, 1, NULL, NULL, NULL),
	(724, 'INSTANT', 33, 18, 0, 0, 3, 1, NULL, NULL, NULL),
	(725, 'INSTANT', 33, 18, 0, 0, 4, 1, NULL, NULL, NULL),
	(726, 'INSTANT', 33, 18, 0, 0, 7, 1, NULL, NULL, NULL),
	(727, 'INSTANT', 33, 18, 0, 0, 8, 1, NULL, NULL, NULL),
	(728, 'INSTANT', 33, 18, 0, 0, 9, 1, NULL, NULL, NULL),
	(729, 'INSTANT', 33, 18, 0, 0, 10, 1, NULL, NULL, NULL),
	(730, 'INSTANT', 33, 18, 0, 0, 11, 1, NULL, NULL, NULL),
	(731, 'INSTANT', 33, 18, 0, 0, 12, 1, NULL, NULL, NULL),
	(732, 'INSTANT', 33, 18, 0, 0, 13, 1, NULL, NULL, NULL),
	(733, 'INSTANT', 33, 18, 0, 0, 14, 1, NULL, NULL, NULL),
	(734, 'INSTANT', 33, 18, 0, 0, 15, 1, NULL, NULL, NULL),
	(735, 'INSTANT', 33, 18, 0, 0, 16, 1, NULL, NULL, NULL),
	(736, 'INSTANT', 33, 18, 0, 0, 17, 1, NULL, NULL, NULL),
	(737, 'INSTANT', 33, 18, 0, 0, 18, 1, NULL, NULL, NULL),
	(738, 'INSTANT', 33, 18, 0, 0, 19, 1, NULL, NULL, NULL),
	(739, 'INSTANT', 33, 18, 0, 0, 1, 2, NULL, NULL, NULL),
	(740, 'INSTANT', 33, 18, 0, 0, 2, 2, NULL, NULL, NULL),
	(741, 'INSTANT', 33, 18, 0, 0, 3, 2, NULL, NULL, NULL),
	(742, 'INSTANT', 33, 18, 0, 0, 4, 2, NULL, NULL, NULL),
	(743, 'INSTANT', 33, 18, 0, 0, 7, 2, NULL, NULL, NULL),
	(744, 'INSTANT', 33, 18, 0, 0, 8, 2, NULL, NULL, NULL),
	(745, 'INSTANT', 33, 18, 0, 0, 9, 2, NULL, NULL, NULL),
	(746, 'INSTANT', 33, 18, 0, 0, 10, 2, NULL, NULL, NULL),
	(747, 'INSTANT', 33, 18, 0, 0, 11, 2, NULL, NULL, NULL),
	(748, 'INSTANT', 33, 18, 0, 0, 12, 2, NULL, NULL, NULL),
	(749, 'INSTANT', 33, 18, 0, 0, 13, 2, NULL, NULL, NULL),
	(750, 'INSTANT', 33, 18, 0, 0, 14, 2, NULL, NULL, NULL),
	(751, 'INSTANT', 33, 18, 0, 0, 15, 2, NULL, NULL, NULL),
	(752, 'INSTANT', 33, 18, 0, 0, 16, 2, NULL, NULL, NULL),
	(753, 'INSTANT', 33, 18, 0, 0, 17, 2, NULL, NULL, NULL),
	(754, 'INSTANT', 33, 18, 0, 0, 18, 2, NULL, NULL, NULL),
	(755, 'INSTANT', 33, 18, 0, 0, 19, 2, NULL, NULL, NULL),
	(756, 'INSTANT', 33, 18, 0, 0, 1, 3, NULL, NULL, NULL),
	(757, 'INSTANT', 33, 18, 0, 0, 2, 3, NULL, NULL, NULL),
	(758, 'INSTANT', 33, 18, 0, 0, 3, 3, NULL, NULL, NULL),
	(759, 'INSTANT', 33, 18, 0, 0, 4, 3, NULL, NULL, NULL),
	(760, 'INSTANT', 33, 18, 0, 0, 7, 3, NULL, NULL, NULL),
	(761, 'INSTANT', 33, 18, 0, 0, 8, 3, NULL, NULL, NULL),
	(762, 'INSTANT', 33, 18, 0, 0, 9, 3, NULL, NULL, NULL),
	(763, 'INSTANT', 33, 18, 0, 0, 10, 3, NULL, NULL, NULL),
	(764, 'INSTANT', 33, 18, 0, 0, 11, 3, NULL, NULL, NULL),
	(765, 'INSTANT', 33, 18, 0, 0, 12, 3, NULL, NULL, NULL),
	(766, 'INSTANT', 33, 18, 0, 0, 13, 3, NULL, NULL, NULL),
	(767, 'INSTANT', 33, 18, 0, 0, 14, 3, NULL, NULL, NULL),
	(768, 'INSTANT', 33, 18, 0, 0, 15, 3, NULL, NULL, NULL),
	(769, 'INSTANT', 33, 18, 0, 0, 16, 3, NULL, NULL, NULL),
	(770, 'INSTANT', 33, 18, 0, 0, 17, 3, NULL, NULL, NULL),
	(771, 'INSTANT', 33, 18, 0, 0, 18, 3, NULL, NULL, NULL),
	(772, 'INSTANT', 33, 18, 0, 0, 19, 3, NULL, NULL, NULL),
	(773, 'INSTANT', 33, 18, 0, 0, 1, 4, NULL, NULL, NULL),
	(774, 'INSTANT', 33, 18, 0, 0, 2, 4, NULL, NULL, NULL),
	(775, 'INSTANT', 33, 18, 0, 0, 3, 4, NULL, NULL, NULL),
	(776, 'INSTANT', 33, 18, 0, 0, 4, 4, NULL, NULL, NULL),
	(777, 'INSTANT', 33, 18, 0, 0, 7, 4, NULL, NULL, NULL),
	(778, 'INSTANT', 33, 18, 0, 0, 8, 4, NULL, NULL, NULL),
	(779, 'INSTANT', 33, 18, 0, 0, 9, 4, NULL, NULL, NULL),
	(780, 'INSTANT', 33, 18, 0, 0, 10, 4, NULL, NULL, NULL),
	(781, 'INSTANT', 33, 18, 0, 0, 11, 4, NULL, NULL, NULL),
	(782, 'INSTANT', 33, 18, 0, 0, 12, 4, NULL, NULL, NULL),
	(783, 'INSTANT', 33, 18, 0, 0, 13, 4, NULL, NULL, NULL),
	(784, 'INSTANT', 33, 18, 0, 0, 14, 4, NULL, NULL, NULL),
	(785, 'INSTANT', 33, 18, 0, 0, 15, 4, NULL, NULL, NULL),
	(786, 'INSTANT', 33, 18, 0, 0, 16, 4, NULL, NULL, NULL),
	(787, 'INSTANT', 33, 18, 0, 0, 17, 4, NULL, NULL, NULL),
	(788, 'INSTANT', 33, 18, 0, 0, 18, 4, NULL, NULL, NULL),
	(789, 'INSTANT', 33, 18, 0, 0, 19, 4, NULL, NULL, NULL),
	(790, 'INSTANT', 33, 18, 0, 0, 1, 5, NULL, NULL, NULL),
	(791, 'INSTANT', 33, 18, 0, 0, 2, 5, NULL, NULL, NULL),
	(792, 'INSTANT', 33, 18, 0, 0, 3, 5, NULL, NULL, NULL),
	(793, 'INSTANT', 33, 18, 0, 0, 4, 5, NULL, NULL, NULL),
	(794, 'INSTANT', 33, 18, 0, 0, 7, 5, NULL, NULL, NULL),
	(795, 'INSTANT', 33, 18, 0, 0, 8, 5, NULL, NULL, NULL),
	(796, 'INSTANT', 33, 18, 0, 0, 9, 5, NULL, NULL, NULL),
	(797, 'INSTANT', 33, 18, 0, 0, 10, 5, NULL, NULL, NULL),
	(798, 'INSTANT', 33, 18, 0, 0, 11, 5, NULL, NULL, NULL),
	(799, 'INSTANT', 33, 18, 0, 0, 12, 5, NULL, NULL, NULL),
	(800, 'INSTANT', 33, 18, 0, 0, 13, 5, NULL, NULL, NULL),
	(801, 'INSTANT', 33, 18, 0, 0, 14, 5, NULL, NULL, NULL),
	(802, 'INSTANT', 33, 18, 0, 0, 15, 5, NULL, NULL, NULL),
	(803, 'INSTANT', 33, 18, 0, 0, 16, 5, NULL, NULL, NULL),
	(804, 'INSTANT', 33, 18, 0, 0, 17, 5, NULL, NULL, NULL),
	(805, 'INSTANT', 33, 18, 0, 0, 18, 5, NULL, NULL, NULL),
	(806, 'INSTANT', 33, 18, 0, 0, 19, 5, NULL, NULL, NULL),
	(807, 'INSTANT', 33, 18, 0, 0, 1, 6, NULL, NULL, NULL),
	(808, 'INSTANT', 33, 18, 0, 0, 2, 6, NULL, NULL, NULL),
	(809, 'INSTANT', 33, 18, 0, 0, 3, 6, NULL, NULL, NULL),
	(810, 'INSTANT', 33, 18, 0, 0, 4, 6, NULL, NULL, NULL),
	(811, 'INSTANT', 33, 18, 0, 0, 7, 6, NULL, NULL, NULL),
	(812, 'INSTANT', 33, 18, 0, 0, 8, 6, NULL, NULL, NULL),
	(813, 'INSTANT', 33, 18, 0, 0, 9, 6, NULL, NULL, NULL),
	(814, 'INSTANT', 33, 18, 0, 0, 10, 6, NULL, NULL, NULL),
	(815, 'INSTANT', 33, 18, 0, 0, 11, 6, NULL, NULL, NULL),
	(816, 'INSTANT', 33, 18, 0, 0, 12, 6, NULL, NULL, NULL),
	(817, 'INSTANT', 33, 18, 0, 0, 13, 6, NULL, NULL, NULL),
	(818, 'INSTANT', 33, 18, 0, 0, 14, 6, NULL, NULL, NULL),
	(819, 'INSTANT', 33, 18, 0, 0, 15, 6, NULL, NULL, NULL),
	(820, 'INSTANT', 33, 18, 0, 0, 16, 6, NULL, NULL, NULL),
	(821, 'INSTANT', 33, 18, 0, 0, 17, 6, NULL, NULL, NULL),
	(822, 'INSTANT', 33, 18, 0, 0, 18, 6, NULL, NULL, NULL),
	(823, 'INSTANT', 33, 18, 0, 0, 19, 6, NULL, NULL, NULL),
	(824, 'INSTANT', 33, 18, 0, 0, 1, 7, NULL, NULL, NULL),
	(825, 'INSTANT', 33, 18, 0, 0, 2, 7, NULL, NULL, NULL),
	(826, 'INSTANT', 33, 18, 0, 0, 3, 7, NULL, NULL, NULL),
	(827, 'INSTANT', 33, 18, 0, 0, 4, 7, NULL, NULL, NULL),
	(828, 'INSTANT', 33, 18, 0, 0, 7, 7, NULL, NULL, NULL),
	(829, 'INSTANT', 33, 18, 0, 0, 8, 7, NULL, NULL, NULL),
	(830, 'INSTANT', 33, 18, 0, 0, 9, 7, NULL, NULL, NULL),
	(831, 'INSTANT', 33, 18, 0, 0, 10, 7, NULL, NULL, NULL),
	(832, 'INSTANT', 33, 18, 0, 0, 11, 7, NULL, NULL, NULL),
	(833, 'INSTANT', 33, 18, 0, 0, 12, 7, NULL, NULL, NULL),
	(834, 'INSTANT', 33, 18, 0, 0, 13, 7, NULL, NULL, NULL),
	(835, 'INSTANT', 33, 18, 0, 0, 14, 7, NULL, NULL, NULL),
	(836, 'INSTANT', 33, 18, 0, 0, 15, 7, NULL, NULL, NULL),
	(837, 'INSTANT', 33, 18, 0, 0, 16, 7, NULL, NULL, NULL),
	(838, 'INSTANT', 33, 18, 0, 0, 17, 7, NULL, NULL, NULL),
	(839, 'INSTANT', 33, 18, 0, 0, 18, 7, NULL, NULL, NULL),
	(840, 'INSTANT', 33, 18, 0, 0, 19, 7, NULL, NULL, NULL),
	(841, 'INSTANT', 33, 18, 0, 0, 1, 9, NULL, NULL, NULL),
	(842, 'INSTANT', 33, 18, 0, 0, 2, 9, NULL, NULL, NULL),
	(843, 'INSTANT', 33, 18, 0, 0, 3, 9, NULL, NULL, NULL),
	(844, 'INSTANT', 33, 18, 0, 0, 4, 9, NULL, NULL, NULL),
	(845, 'INSTANT', 33, 18, 0, 0, 7, 9, NULL, NULL, NULL),
	(846, 'INSTANT', 33, 18, 0, 0, 8, 9, NULL, NULL, NULL),
	(847, 'INSTANT', 33, 18, 0, 0, 9, 9, NULL, NULL, NULL),
	(848, 'INSTANT', 33, 18, 0, 0, 10, 9, NULL, NULL, NULL),
	(849, 'INSTANT', 33, 18, 0, 0, 11, 9, NULL, NULL, NULL),
	(850, 'INSTANT', 33, 18, 0, 0, 12, 9, NULL, NULL, NULL),
	(851, 'INSTANT', 33, 18, 0, 0, 13, 9, NULL, NULL, NULL),
	(852, 'INSTANT', 33, 18, 0, 0, 14, 9, NULL, NULL, NULL),
	(853, 'INSTANT', 33, 18, 0, 0, 15, 9, NULL, NULL, NULL),
	(854, 'INSTANT', 33, 18, 0, 0, 16, 9, NULL, NULL, NULL),
	(855, 'INSTANT', 33, 18, 0, 0, 17, 9, NULL, NULL, NULL),
	(856, 'INSTANT', 33, 18, 0, 0, 18, 9, NULL, NULL, NULL),
	(857, 'INSTANT', 33, 18, 0, 0, 19, 9, NULL, NULL, NULL),
	(858, 'INSTANT', 33, 18, 0, 0, 1, 10, NULL, NULL, NULL),
	(859, 'INSTANT', 33, 18, 0, 0, 2, 10, NULL, NULL, NULL),
	(860, 'INSTANT', 33, 18, 0, 0, 3, 10, NULL, NULL, NULL),
	(861, 'INSTANT', 33, 18, 0, 0, 4, 10, NULL, NULL, NULL),
	(862, 'INSTANT', 33, 18, 0, 0, 7, 10, NULL, NULL, NULL),
	(863, 'INSTANT', 33, 18, 0, 0, 8, 10, NULL, NULL, NULL),
	(864, 'INSTANT', 33, 18, 0, 0, 9, 10, NULL, NULL, NULL),
	(865, 'INSTANT', 33, 18, 0, 0, 10, 10, NULL, NULL, NULL),
	(866, 'INSTANT', 33, 18, 0, 0, 11, 10, NULL, NULL, NULL),
	(867, 'INSTANT', 33, 18, 0, 0, 12, 10, NULL, NULL, NULL),
	(868, 'INSTANT', 33, 18, 0, 0, 13, 10, NULL, NULL, NULL),
	(869, 'INSTANT', 33, 18, 0, 0, 14, 10, NULL, NULL, NULL),
	(870, 'INSTANT', 33, 18, 0, 0, 15, 10, NULL, NULL, NULL),
	(871, 'INSTANT', 33, 18, 0, 0, 16, 10, NULL, NULL, NULL),
	(872, 'INSTANT', 33, 18, 0, 0, 17, 10, NULL, NULL, NULL),
	(873, 'INSTANT', 33, 18, 0, 0, 18, 10, NULL, NULL, NULL),
	(874, 'INSTANT', 33, 18, 0, 0, 19, 10, NULL, NULL, NULL),
	(875, 'INSTANT', 33, 18, 0, 0, 1, 11, NULL, NULL, NULL),
	(876, 'INSTANT', 33, 18, 0, 0, 2, 11, NULL, NULL, NULL),
	(877, 'INSTANT', 33, 18, 0, 0, 3, 11, NULL, NULL, NULL),
	(878, 'INSTANT', 33, 18, 0, 0, 4, 11, NULL, NULL, NULL),
	(879, 'INSTANT', 33, 18, 0, 0, 7, 11, NULL, NULL, NULL),
	(880, 'INSTANT', 33, 18, 0, 0, 8, 11, NULL, NULL, NULL),
	(881, 'INSTANT', 33, 18, 0, 0, 9, 11, NULL, NULL, NULL),
	(882, 'INSTANT', 33, 18, 0, 0, 10, 11, NULL, NULL, NULL),
	(883, 'INSTANT', 33, 18, 0, 0, 11, 11, NULL, NULL, NULL),
	(884, 'INSTANT', 33, 18, 0, 0, 12, 11, NULL, NULL, NULL),
	(885, 'INSTANT', 33, 18, 0, 0, 13, 11, NULL, NULL, NULL),
	(886, 'INSTANT', 33, 18, 0, 0, 14, 11, NULL, NULL, NULL),
	(887, 'INSTANT', 33, 18, 0, 0, 15, 11, NULL, NULL, NULL),
	(888, 'INSTANT', 33, 18, 0, 0, 16, 11, NULL, NULL, NULL),
	(889, 'INSTANT', 33, 18, 0, 0, 17, 11, NULL, NULL, NULL),
	(890, 'INSTANT', 33, 18, 0, 0, 18, 11, NULL, NULL, NULL),
	(891, 'INSTANT', 33, 18, 0, 0, 19, 11, NULL, NULL, NULL),
	(892, 'INSTANT', 33, 18, 0, 0, 1, 12, NULL, NULL, NULL),
	(893, 'INSTANT', 33, 18, 0, 0, 2, 12, NULL, NULL, NULL),
	(894, 'INSTANT', 33, 18, 0, 0, 3, 12, NULL, NULL, NULL),
	(895, 'INSTANT', 33, 18, 0, 0, 4, 12, NULL, NULL, NULL),
	(896, 'INSTANT', 33, 18, 0, 0, 7, 12, NULL, NULL, NULL),
	(897, 'INSTANT', 33, 18, 0, 0, 8, 12, NULL, NULL, NULL),
	(898, 'INSTANT', 33, 18, 0, 0, 9, 12, NULL, NULL, NULL),
	(899, 'INSTANT', 33, 18, 0, 0, 10, 12, NULL, NULL, NULL),
	(900, 'INSTANT', 33, 18, 0, 0, 11, 12, NULL, NULL, NULL),
	(901, 'INSTANT', 33, 18, 0, 0, 12, 12, NULL, NULL, NULL),
	(902, 'INSTANT', 33, 18, 0, 0, 13, 12, NULL, NULL, NULL),
	(903, 'INSTANT', 33, 18, 0, 0, 14, 12, NULL, NULL, NULL),
	(904, 'INSTANT', 33, 18, 0, 0, 15, 12, NULL, NULL, NULL),
	(905, 'INSTANT', 33, 18, 0, 0, 16, 12, NULL, NULL, NULL),
	(906, 'INSTANT', 33, 18, 0, 0, 17, 12, NULL, NULL, NULL),
	(907, 'INSTANT', 33, 18, 0, 0, 18, 12, NULL, NULL, NULL),
	(908, 'INSTANT', 33, 18, 0, 0, 19, 12, NULL, NULL, NULL),
	(909, 'INSTANT', 33, 18, 0, 0, 1, 13, NULL, NULL, NULL),
	(910, 'INSTANT', 33, 18, 0, 0, 2, 13, NULL, NULL, NULL),
	(911, 'INSTANT', 33, 18, 0, 0, 3, 13, NULL, NULL, NULL),
	(912, 'INSTANT', 33, 18, 0, 0, 4, 13, NULL, NULL, NULL),
	(913, 'INSTANT', 33, 18, 0, 0, 7, 13, NULL, NULL, NULL),
	(914, 'INSTANT', 33, 18, 0, 0, 8, 13, NULL, NULL, NULL),
	(915, 'INSTANT', 33, 18, 0, 0, 9, 13, NULL, NULL, NULL),
	(916, 'INSTANT', 33, 18, 0, 0, 10, 13, NULL, NULL, NULL),
	(917, 'INSTANT', 33, 18, 0, 0, 11, 13, NULL, NULL, NULL),
	(918, 'INSTANT', 33, 18, 0, 0, 12, 13, NULL, NULL, NULL),
	(919, 'INSTANT', 33, 18, 0, 0, 13, 13, NULL, NULL, NULL),
	(920, 'INSTANT', 33, 18, 0, 0, 14, 13, NULL, NULL, NULL),
	(921, 'INSTANT', 33, 18, 0, 0, 15, 13, NULL, NULL, NULL),
	(922, 'INSTANT', 33, 18, 0, 0, 16, 13, NULL, NULL, NULL),
	(923, 'INSTANT', 33, 18, 0, 0, 17, 13, NULL, NULL, NULL),
	(924, 'INSTANT', 33, 18, 0, 0, 18, 13, NULL, NULL, NULL),
	(925, 'INSTANT', 33, 18, 0, 0, 19, 13, NULL, NULL, NULL),
	(926, 'INSTANT', 33, 18, 0, 0, 1, 14, NULL, NULL, NULL),
	(927, 'INSTANT', 33, 18, 0, 0, 2, 14, NULL, NULL, NULL),
	(928, 'INSTANT', 33, 18, 0, 0, 3, 14, NULL, NULL, NULL),
	(929, 'INSTANT', 33, 18, 0, 0, 4, 14, NULL, NULL, NULL),
	(930, 'INSTANT', 33, 18, 0, 0, 7, 14, NULL, NULL, NULL),
	(931, 'INSTANT', 33, 18, 0, 0, 8, 14, NULL, NULL, NULL),
	(932, 'INSTANT', 33, 18, 0, 0, 9, 14, NULL, NULL, NULL),
	(933, 'INSTANT', 33, 18, 0, 0, 10, 14, NULL, NULL, NULL),
	(934, 'INSTANT', 33, 18, 0, 0, 11, 14, NULL, NULL, NULL),
	(935, 'INSTANT', 33, 18, 0, 0, 12, 14, NULL, NULL, NULL),
	(936, 'INSTANT', 33, 18, 0, 0, 13, 14, NULL, NULL, NULL),
	(937, 'INSTANT', 33, 18, 0, 0, 14, 14, NULL, NULL, NULL),
	(938, 'INSTANT', 33, 18, 0, 0, 15, 14, NULL, NULL, NULL),
	(939, 'INSTANT', 33, 18, 0, 0, 16, 14, NULL, NULL, NULL),
	(940, 'INSTANT', 33, 18, 0, 0, 17, 14, NULL, NULL, NULL),
	(941, 'INSTANT', 33, 18, 0, 0, 18, 14, NULL, NULL, NULL),
	(942, 'INSTANT', 33, 18, 0, 0, 19, 14, NULL, NULL, NULL),
	(943, 'INSTANT', 33, 18, 0, 0, 1, 15, NULL, NULL, NULL),
	(944, 'INSTANT', 33, 18, 0, 0, 2, 15, NULL, NULL, NULL),
	(945, 'INSTANT', 33, 18, 0, 0, 3, 15, NULL, NULL, NULL),
	(946, 'INSTANT', 33, 18, 0, 0, 4, 15, NULL, NULL, NULL),
	(947, 'INSTANT', 33, 18, 0, 0, 7, 15, NULL, NULL, NULL),
	(948, 'INSTANT', 33, 18, 0, 0, 8, 15, NULL, NULL, NULL),
	(949, 'INSTANT', 33, 18, 0, 0, 9, 15, NULL, NULL, NULL),
	(950, 'INSTANT', 33, 18, 0, 0, 10, 15, NULL, NULL, NULL),
	(951, 'INSTANT', 33, 18, 0, 0, 11, 15, NULL, NULL, NULL),
	(952, 'INSTANT', 33, 18, 0, 0, 12, 15, NULL, NULL, NULL),
	(953, 'INSTANT', 33, 18, 0, 0, 13, 15, NULL, NULL, NULL),
	(954, 'INSTANT', 33, 18, 0, 0, 14, 15, NULL, NULL, NULL),
	(955, 'INSTANT', 33, 18, 0, 0, 15, 15, NULL, NULL, NULL),
	(956, 'INSTANT', 33, 18, 0, 0, 16, 15, NULL, NULL, NULL),
	(957, 'INSTANT', 33, 18, 0, 0, 17, 15, NULL, NULL, NULL),
	(958, 'INSTANT', 33, 18, 0, 0, 18, 15, NULL, NULL, NULL),
	(959, 'INSTANT', 33, 18, 0, 0, 19, 15, NULL, NULL, NULL),
	(961, 'DISCRETE', 144, 224, 0, -1, 0, 0, NULL, NULL, NULL),
	(962, 'DISCRETE', 226, 224, 0, -1, 0, 0, NULL, NULL, NULL),
	(963, 'DISCRETE', 228, 224, 0, -1, 0, 0, NULL, NULL, NULL),
	(964, 'DISCRETE', 229, 224, 0, -1, 0, 0, NULL, NULL, NULL),
	(965, 'DISCRETE', 144, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(966, 'DISCRETE', 226, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(967, 'DISCRETE', 228, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(968, 'DISCRETE', 229, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(969, 'DISCRETE', 144, 149, 0, -1, 0, 0, NULL, NULL, NULL),
	(970, 'DISCRETE', 226, 149, 0, -1, 0, 0, NULL, NULL, NULL),
	(971, 'DISCRETE', 228, 149, 0, -1, 0, 0, NULL, NULL, NULL),
	(972, 'DISCRETE', 229, 149, 0, -1, 0, 0, NULL, NULL, NULL),
	(973, 'DISCRETE', 144, 150, 0, -1, 0, 0, NULL, NULL, NULL),
	(974, 'DISCRETE', 226, 150, 0, -1, 0, 0, NULL, NULL, NULL),
	(975, 'DISCRETE', 228, 150, 0, -1, 0, 0, NULL, NULL, NULL),
	(976, 'DISCRETE', 229, 150, 0, -1, 0, 0, NULL, NULL, NULL),
	(977, 'DISCRETE', 229, 334, 0, -1, 0, 0, NULL, NULL, NULL),
	(978, 'DISCRETE', 226, 334, 0, -1, 0, 0, NULL, NULL, NULL),
	(979, 'DISCRETE', 229, 335, 0, -1, 0, 0, NULL, NULL, NULL),
	(980, 'DISCRETE', 226, 335, 0, -1, 0, 0, NULL, NULL, NULL),
	(981, 'WITHOUT SHEAF', 232, 255, 0, 0, -1, -1, NULL, NULL, NULL),
	(982, 'WITHOUT SHEAF', 232, 256, 0, 0, -1, -1, NULL, NULL, NULL),
	(983, 'WITHOUT SHEAF', 232, 257, 0, 0, -1, -1, NULL, NULL, NULL),
	(984, 'WITHOUT SHEAF', 232, 258, 0, 0, -1, -1, NULL, NULL, NULL),
	(985, 'WITHOUT SHEAF', 232, 259, 0, 0, -1, -1, NULL, NULL, NULL),
	(986, 'WITHOUT SHEAF', 232, 18, 0, 0, 1, -1, NULL, NULL, NULL),
	(987, 'WITHOUT SHEAF', 232, 18, 0, 0, 2, -1, NULL, NULL, NULL),
	(988, 'WITHOUT SHEAF', 232, 18, 0, 0, 3, -1, NULL, NULL, NULL),
	(989, 'WITHOUT SHEAF', 232, 18, 0, 0, 4, -1, NULL, NULL, NULL),
	(990, 'WITHOUT SHEAF', 232, 18, 0, 0, 5, -1, NULL, NULL, NULL),
	(991, 'WITHOUT SHEAF', 232, 18, 0, 0, 6, -1, NULL, NULL, NULL),
	(992, 'WITHOUT SHEAF', 232, 18, 0, 0, 8, -1, NULL, NULL, NULL),
	(993, 'WITHOUT SHEAF', 232, 18, 0, 0, 9, -1, NULL, NULL, NULL),
	(994, 'WITHOUT SHEAF', 232, 18, 0, 0, 10, -1, NULL, NULL, NULL),
	(995, 'WITHOUT SHEAF', 232, 18, 0, 0, 11, -1, NULL, NULL, NULL),
	(996, 'WITHOUT SHEAF', 232, 18, 0, 0, 12, -1, NULL, NULL, NULL),
	(997, 'WITHOUT SHEAF', 232, 18, 0, 0, 13, -1, NULL, NULL, NULL),
	(998, 'WITHOUT SHEAF', 232, 18, 0, 0, 14, -1, NULL, NULL, NULL),
	(999, 'WITHOUT SHEAF', 232, 18, 0, 0, 15, -1, NULL, NULL, NULL),
	(1000, 'WITHOUT SHEAF', 232, 18, 0, 0, 16, -1, NULL, NULL, NULL),
	(1001, 'WITHOUT SHEAF', 232, 18, 0, 0, 17, -1, NULL, NULL, NULL),
	(1002, 'WITHOUT SHEAF', 232, 18, 0, 0, 18, -1, NULL, NULL, NULL),
	(1003, 'WITHOUT SHEAF', 232, 18, 0, 0, 19, -1, NULL, NULL, NULL),
	(1006, 'Full Journal', 232, 365, 2, 0, 0, 0, NULL, 1, NULL),
	(1007, 'Full Journal', 232, 366, 2, 0, 0, 0, NULL, 1, NULL),
	(1008, 'Full Journal', 232, 367, 2, 0, 0, 0, NULL, 1, NULL),
	(1009, 'Full Journal', 232, 368, 2, 0, 0, 0, NULL, 1, NULL),
	(1010, 'Full Journal', 232, 369, 2, 0, 0, 0, NULL, 1, NULL),
	(1011, 'Full Journal', 232, 370, 2, 0, 0, 0, NULL, 1, NULL),
	(1012, 'Full Journal', 232, 371, 2, 0, 0, 0, NULL, 1, NULL),
	(1013, 'Full Journal', 232, 372, 2, 0, 0, 0, NULL, 1, NULL),
	(1014, 'Full Journal', 232, 373, 2, 0, 0, 0, NULL, 1, NULL),
	(1015, 'Full Journal', 232, 374, 2, 0, 0, 0, NULL, 1, NULL),
	(1016, 'Full Journal', 232, 375, 2, 0, 0, 0, NULL, 1, NULL),
	(1017, 'Full Journal', 232, 376, 2, 0, 0, 0, NULL, 1, NULL),
	(1018, 'Full Journal', 232, 377, 2, 0, 0, 0, NULL, 1, NULL),
	(1019, 'Full Journal', 232, 378, 2, 0, 0, 0, NULL, 1, NULL),
	(1020, 'Full Journal', 232, 365, 22, 0, 0, 0, NULL, 1, NULL),
	(1021, 'Full Journal', 232, 366, 22, 0, 0, 0, NULL, 1, NULL),
	(1022, 'Full Journal', 232, 367, 22, 0, 0, 0, NULL, 1, NULL),
	(1023, 'Full Journal', 232, 368, 22, 0, 0, 0, NULL, 1, NULL),
	(1024, 'Full Journal', 232, 369, 22, 0, 0, 0, NULL, 1, NULL),
	(1025, 'Full Journal', 232, 370, 22, 0, 0, 0, NULL, 1, NULL),
	(1026, 'Full Journal', 232, 371, 22, 0, 0, 0, NULL, 1, NULL),
	(1027, 'Full Journal', 232, 372, 22, 0, 0, 0, NULL, 1, NULL),
	(1028, 'Full Journal', 232, 373, 22, 0, 0, 0, NULL, 1, NULL),
	(1029, 'Full Journal', 232, 374, 22, 0, 0, 0, NULL, 1, NULL),
	(1030, 'Full Journal', 232, 375, 22, 0, 0, 0, NULL, 1, NULL),
	(1031, 'Full Journal', 232, 376, 22, 0, 0, 0, NULL, 1, NULL),
	(1032, 'Full Journal', 232, 377, 22, 0, 0, 0, NULL, 1, NULL),
	(1033, 'Full Journal', 232, 378, 22, 0, 0, 0, NULL, 1, NULL),
	(1034, 'Full Journal', 232, 255, 2, 0, 0, 0, NULL, 1, NULL),
	(1035, 'Full Journal', 232, 255, 22, 0, 0, 0, NULL, 1, NULL),
	(1036, 'MEASURES', 244, 386, 0, 0, -1, -1, NULL, NULL, NULL),
	(1037, 'TIME', 249, 229, 1, 0, 0, 0, NULL, NULL, NULL),
	(1038, 'TIME', 249, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(1039, 'TIME', 249, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(1040, 'TIME_CORRECTION', 249, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1041, 'TIME_CORRECTION', 249, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1042, 'TIME_CORRECTION', 202, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1043, 'TIME_CORRECTION', 202, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1045, 'WITHOUT SHEAF', 248, 391, 0, 0, -1, -1, NULL, NULL, NULL),
	(1046, 'WITHOUT SHEAF', 248, 392, 0, 0, -1, -1, NULL, NULL, NULL),
	(1047, 'WITHOUT SHEAF', 248, 393, 0, 0, -1, -1, NULL, NULL, NULL),
	(1048, 'WITHOUT SHEAF', 248, 18, 0, 0, 1, -1, NULL, NULL, NULL),
	(1049, 'WITHOUT SHEAF', 248, 18, 0, 0, 2, -1, NULL, NULL, NULL),
	(1050, 'WITHOUT SHEAF', 248, 18, 0, 0, 3, -1, NULL, NULL, NULL),
	(1051, 'WITHOUT SHEAF', 248, 18, 0, 0, 4, -1, NULL, NULL, NULL),
	(1052, 'WITHOUT SHEAF', 248, 18, 0, 0, 5, -1, NULL, NULL, NULL),
	(1053, 'WITHOUT SHEAF', 248, 18, 0, 0, 6, -1, NULL, NULL, NULL),
	(1054, 'WITHOUT SHEAF', 248, 18, 0, 0, 8, -1, NULL, NULL, NULL),
	(1055, 'WITHOUT SHEAF', 248, 18, 0, 0, 9, -1, NULL, NULL, NULL),
	(1056, 'WITHOUT SHEAF', 248, 18, 0, 0, 10, -1, NULL, NULL, NULL),
	(1057, 'WITHOUT SHEAF', 248, 18, 0, 0, 11, -1, NULL, NULL, NULL),
	(1058, 'WITHOUT SHEAF', 248, 18, 0, 0, 12, -1, NULL, NULL, NULL),
	(1059, 'WITHOUT SHEAF', 248, 18, 0, 0, 13, -1, NULL, NULL, NULL),
	(1060, 'WITHOUT SHEAF', 248, 18, 0, 0, 14, -1, NULL, NULL, NULL),
	(1061, 'WITHOUT SHEAF', 248, 18, 0, 0, 15, -1, NULL, NULL, NULL),
	(1062, 'WITHOUT SHEAF', 248, 18, 0, 0, 16, -1, NULL, NULL, NULL),
	(1063, 'WITHOUT SHEAF', 248, 18, 0, 0, 17, -1, NULL, NULL, NULL),
	(1064, 'WITHOUT SHEAF', 248, 18, 0, 0, 18, -1, NULL, NULL, NULL),
	(1065, 'WITHOUT SHEAF', 248, 18, 0, 0, 19, -1, NULL, NULL, NULL),
	(1066, 'WITHOUT SHEAF', 248, 255, 0, 0, -1, -1, NULL, NULL, NULL),
	(1067, 'Full Journal', 248, 255, 2, 0, 0, 0, NULL, 1, NULL),
	(1068, 'Full Journal', 248, 255, 22, 0, 0, 0, NULL, 1, NULL),
	(1069, 'WITHOUT SHEAF', 248, 256, 0, 0, -1, -1, NULL, NULL, NULL),
	(1070, 'WITHOUT SHEAF', 248, 257, 0, 0, -1, -1, NULL, NULL, NULL),
	(1071, 'WITHOUT SHEAF', 248, 258, 0, 0, -1, -1, NULL, NULL, NULL),
	(1072, 'WITHOUT SHEAF', 248, 259, 0, 0, -1, -1, NULL, NULL, NULL),
	(1073, 'Full Journal', 248, 365, 2, 0, 0, 0, NULL, 1, NULL),
	(1074, 'Full Journal', 248, 365, 22, 0, 0, 0, NULL, 1, NULL),
	(1075, 'Full Journal', 248, 366, 2, 0, 0, 0, NULL, 1, NULL),
	(1076, 'Full Journal', 248, 366, 22, 0, 0, 0, NULL, 1, NULL),
	(1077, 'Full Journal', 248, 367, 2, 0, 0, 0, NULL, 1, NULL),
	(1078, 'Full Journal', 248, 367, 22, 0, 0, 0, NULL, 1, NULL),
	(1079, 'Full Journal', 248, 368, 2, 0, 0, 0, NULL, 1, NULL),
	(1080, 'Full Journal', 248, 368, 22, 0, 0, 0, NULL, 1, NULL),
	(1081, 'Full Journal', 248, 369, 2, 0, 0, 0, NULL, 1, NULL),
	(1082, 'Full Journal', 248, 369, 22, 0, 0, 0, NULL, 1, NULL),
	(1083, 'Full Journal', 248, 370, 2, 0, 0, 0, NULL, 1, NULL),
	(1084, 'Full Journal', 248, 370, 22, 0, 0, 0, NULL, 1, NULL),
	(1085, 'Full Journal', 248, 371, 2, 0, 0, 0, NULL, 1, NULL),
	(1086, 'Full Journal', 248, 371, 22, 0, 0, 0, NULL, 1, NULL),
	(1087, 'Full Journal', 248, 372, 2, 0, 0, 0, NULL, 1, NULL),
	(1088, 'Full Journal', 248, 372, 22, 0, 0, 0, NULL, 1, NULL),
	(1089, 'Full Journal', 248, 373, 2, 0, 0, 0, NULL, 1, NULL),
	(1090, 'Full Journal', 248, 373, 22, 0, 0, 0, NULL, 1, NULL),
	(1091, 'Full Journal', 248, 374, 2, 0, 0, 0, NULL, 1, NULL),
	(1092, 'Full Journal', 248, 374, 22, 0, 0, 0, NULL, 1, NULL),
	(1093, 'Full Journal', 248, 375, 2, 0, 0, 0, NULL, 1, NULL),
	(1094, 'Full Journal', 248, 375, 22, 0, 0, 0, NULL, 1, NULL),
	(1095, 'Full Journal', 248, 376, 2, 0, 0, 0, NULL, 1, NULL),
	(1096, 'Full Journal', 248, 376, 22, 0, 0, 0, NULL, 1, NULL),
	(1097, 'Full Journal', 248, 377, 2, 0, 0, 0, NULL, 1, NULL),
	(1098, 'Full Journal', 248, 377, 22, 0, 0, 0, NULL, 1, NULL),
	(1099, 'Full Journal', 248, 378, 2, 0, 0, 0, NULL, 1, NULL),
	(1100, 'Full Journal', 248, 378, 22, 0, 0, 0, NULL, 1, NULL),
	(1101, 'WITHOUT SHEAF', 262, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1102, 'Full Journal', 262, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1103, 'Full Journal', 262, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1104, 'Full Journal', 262, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1105, 'WITHOUT SHEAF', 262, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1106, 'WITHOUT SHEAF', 262, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1107, 'Full Journal', 262, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1108, 'Full Journal', 262, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1109, 'Full Journal', 262, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1110, 'TIME_CORRECTION', 262, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1111, 'TIME_CORRECTION', 262, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1112, 'WITHOUT SHEAF', 259, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1113, 'Full Journal', 259, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1114, 'Full Journal', 259, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1115, 'Full Journal', 259, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1116, 'WITHOUT SHEAF', 259, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1117, 'WITHOUT SHEAF', 259, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1118, 'Full Journal', 259, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1119, 'Full Journal', 259, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1120, 'Full Journal', 259, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1121, 'TIME_CORRECTION', 259, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1122, 'TIME_CORRECTION', 259, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1123, 'WITHOUT SHEAF', 258, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1124, 'Full Journal', 258, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1125, 'Full Journal', 258, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1126, 'Full Journal', 258, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1127, 'WITHOUT SHEAF', 258, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1128, 'WITHOUT SHEAF', 258, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1129, 'Full Journal', 258, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1130, 'Full Journal', 258, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1131, 'Full Journal', 258, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1132, 'TIME_CORRECTION', 258, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1133, 'TIME_CORRECTION', 258, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1134, 'WITHOUT SHEAF', 260, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1135, 'Full Journal', 260, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1136, 'Full Journal', 260, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1137, 'Full Journal', 260, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1138, 'WITHOUT SHEAF', 260, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1139, 'WITHOUT SHEAF', 260, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1140, 'Full Journal', 260, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1141, 'Full Journal', 260, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1142, 'Full Journal', 260, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1143, 'TIME_CORRECTION', 260, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1144, 'TIME_CORRECTION', 260, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1145, 'WITHOUT SHEAF', 261, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1146, 'Full Journal', 261, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1147, 'Full Journal', 261, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1148, 'Full Journal', 261, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1149, 'WITHOUT SHEAF', 261, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1150, 'WITHOUT SHEAF', 261, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1151, 'Full Journal', 261, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1152, 'Full Journal', 261, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1153, 'Full Journal', 261, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1154, 'TIME_CORRECTION', 261, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1155, 'TIME_CORRECTION', 261, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1156, 'WITHOUT SHEAF', 263, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1157, 'Full Journal', 263, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1158, 'Full Journal', 263, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1159, 'Full Journal', 263, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1160, 'WITHOUT SHEAF', 263, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1161, 'WITHOUT SHEAF', 263, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1162, 'Full Journal', 263, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1163, 'Full Journal', 263, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1164, 'Full Journal', 263, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1165, 'TIME_CORRECTION', 263, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1166, 'TIME_CORRECTION', 263, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1167, 'WITHOUT SHEAF', 264, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1168, 'Full Journal', 264, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1169, 'Full Journal', 264, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1170, 'Full Journal', 264, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1171, 'WITHOUT SHEAF', 264, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1172, 'WITHOUT SHEAF', 264, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1173, 'Full Journal', 264, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1174, 'Full Journal', 264, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1175, 'Full Journal', 264, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1176, 'TIME_CORRECTION', 264, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1177, 'TIME_CORRECTION', 264, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1178, 'WITHOUT SHEAF', 265, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1179, 'Full Journal', 265, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1180, 'Full Journal', 265, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1181, 'Full Journal', 265, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1182, 'WITHOUT SHEAF', 265, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1183, 'WITHOUT SHEAF', 265, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1184, 'Full Journal', 265, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1185, 'Full Journal', 265, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1186, 'Full Journal', 265, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1187, 'TIME_CORRECTION', 265, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1188, 'TIME_CORRECTION', 265, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1189, 'WITHOUT SHEAF', 266, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1190, 'Full Journal', 266, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1191, 'Full Journal', 266, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1192, 'Full Journal', 266, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1193, 'WITHOUT SHEAF', 266, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1194, 'WITHOUT SHEAF', 266, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1195, 'Full Journal', 266, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1196, 'Full Journal', 266, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1197, 'Full Journal', 266, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1198, 'TIME_CORRECTION', 266, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1199, 'TIME_CORRECTION', 266, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1200, 'WITHOUT SHEAF', 267, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1201, 'Full Journal', 267, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1202, 'Full Journal', 267, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1203, 'Full Journal', 267, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1204, 'WITHOUT SHEAF', 267, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1205, 'WITHOUT SHEAF', 267, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1206, 'Full Journal', 267, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1207, 'Full Journal', 267, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1208, 'Full Journal', 267, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1209, 'TIME_CORRECTION', 267, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1210, 'TIME_CORRECTION', 267, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1211, 'WITHOUT SHEAF', 268, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1212, 'Full Journal', 268, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1213, 'Full Journal', 268, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1214, 'Full Journal', 268, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1215, 'WITHOUT SHEAF', 268, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1216, 'WITHOUT SHEAF', 268, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1217, 'Full Journal', 268, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1218, 'Full Journal', 268, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1219, 'Full Journal', 268, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1220, 'TIME_CORRECTION', 268, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1221, 'TIME_CORRECTION', 268, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1222, 'WITHOUT SHEAF', 269, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1223, 'Full Journal', 269, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1224, 'Full Journal', 269, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1225, 'Full Journal', 269, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1226, 'WITHOUT SHEAF', 269, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1227, 'WITHOUT SHEAF', 269, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1228, 'Full Journal', 269, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1229, 'Full Journal', 269, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1230, 'Full Journal', 269, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1231, 'TIME_CORRECTION', 269, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1232, 'TIME_CORRECTION', 269, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1233, 'WITHOUT SHEAF', 270, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1234, 'Full Journal', 270, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1235, 'Full Journal', 270, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1236, 'Full Journal', 270, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1237, 'WITHOUT SHEAF', 270, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1238, 'WITHOUT SHEAF', 270, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1239, 'Full Journal', 270, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1240, 'Full Journal', 270, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1241, 'Full Journal', 270, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1242, 'TIME_CORRECTION', 270, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1243, 'TIME_CORRECTION', 270, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1244, 'WITHOUT SHEAF', 271, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1245, 'Full Journal', 271, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1246, 'Full Journal', 271, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1247, 'Full Journal', 271, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1248, 'WITHOUT SHEAF', 271, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1249, 'WITHOUT SHEAF', 271, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1250, 'Full Journal', 271, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1251, 'Full Journal', 271, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1252, 'Full Journal', 271, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1253, 'TIME_CORRECTION', 271, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1254, 'TIME_CORRECTION', 271, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1255, 'WITHOUT SHEAF', 272, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1256, 'Full Journal', 272, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1257, 'Full Journal', 272, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1258, 'Full Journal', 272, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1259, 'WITHOUT SHEAF', 272, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1260, 'WITHOUT SHEAF', 272, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1261, 'Full Journal', 272, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1262, 'Full Journal', 272, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1263, 'Full Journal', 272, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1264, 'TIME_CORRECTION', 272, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1265, 'TIME_CORRECTION', 272, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1266, 'WITHOUT SHEAF', 273, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1267, 'Full Journal', 273, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1268, 'Full Journal', 273, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1269, 'Full Journal', 273, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1270, 'WITHOUT SHEAF', 273, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1271, 'WITHOUT SHEAF', 273, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1272, 'Full Journal', 273, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1273, 'Full Journal', 273, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1274, 'Full Journal', 273, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1275, 'TIME_CORRECTION', 273, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1276, 'TIME_CORRECTION', 273, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1277, 'WITHOUT SHEAF', 274, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1278, 'Full Journal', 274, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1279, 'Full Journal', 274, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1280, 'Full Journal', 274, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1281, 'WITHOUT SHEAF', 274, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1282, 'WITHOUT SHEAF', 274, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1283, 'Full Journal', 274, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1284, 'Full Journal', 274, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1285, 'Full Journal', 274, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1286, 'TIME_CORRECTION', 274, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1287, 'TIME_CORRECTION', 274, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1288, 'WITHOUT SHEAF', 275, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1289, 'Full Journal', 275, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1290, 'Full Journal', 275, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1291, 'Full Journal', 275, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1292, 'WITHOUT SHEAF', 275, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1293, 'WITHOUT SHEAF', 275, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1294, 'Full Journal', 275, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1295, 'Full Journal', 275, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1296, 'Full Journal', 275, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1297, 'TIME_CORRECTION', 275, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1298, 'TIME_CORRECTION', 275, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1299, 'WITHOUT SHEAF', 276, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1300, 'Full Journal', 276, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1301, 'Full Journal', 276, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1302, 'Full Journal', 276, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1303, 'WITHOUT SHEAF', 276, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1304, 'WITHOUT SHEAF', 276, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1305, 'Full Journal', 276, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1306, 'Full Journal', 276, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1307, 'Full Journal', 276, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1308, 'TIME_CORRECTION', 276, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1309, 'TIME_CORRECTION', 276, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1310, 'WITHOUT SHEAF', 277, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1311, 'Full Journal', 277, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1312, 'Full Journal', 277, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1313, 'Full Journal', 277, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1314, 'WITHOUT SHEAF', 277, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1315, 'WITHOUT SHEAF', 277, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1316, 'Full Journal', 277, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1317, 'Full Journal', 277, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1318, 'Full Journal', 277, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1319, 'TIME_CORRECTION', 277, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1320, 'TIME_CORRECTION', 277, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1321, 'WITHOUT SHEAF', 278, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1322, 'Full Journal', 278, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1323, 'Full Journal', 278, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1324, 'Full Journal', 278, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1325, 'WITHOUT SHEAF', 278, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1326, 'WITHOUT SHEAF', 278, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1327, 'Full Journal', 278, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1328, 'Full Journal', 278, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1329, 'Full Journal', 278, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1330, 'TIME_CORRECTION', 278, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1331, 'TIME_CORRECTION', 278, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1332, 'WITHOUT SHEAF', 279, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1333, 'Full Journal', 279, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1334, 'Full Journal', 279, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1335, 'Full Journal', 279, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1336, 'WITHOUT SHEAF', 279, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1337, 'WITHOUT SHEAF', 279, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1338, 'Full Journal', 279, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1339, 'Full Journal', 279, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1340, 'Full Journal', 279, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1341, 'TIME_CORRECTION', 279, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1342, 'TIME_CORRECTION', 279, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1343, 'WITHOUT SHEAF', 280, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1344, 'Full Journal', 280, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1345, 'Full Journal', 280, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1346, 'Full Journal', 280, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1347, 'WITHOUT SHEAF', 280, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1348, 'WITHOUT SHEAF', 280, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1349, 'Full Journal', 280, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1350, 'Full Journal', 280, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1351, 'Full Journal', 280, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1352, 'TIME_CORRECTION', 280, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1353, 'TIME_CORRECTION', 280, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1354, 'WITHOUT SHEAF', 281, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1355, 'Full Journal', 281, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1356, 'Full Journal', 281, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1357, 'Full Journal', 281, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1358, 'WITHOUT SHEAF', 281, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1359, 'WITHOUT SHEAF', 281, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1360, 'Full Journal', 281, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1361, 'Full Journal', 281, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1362, 'Full Journal', 281, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1363, 'TIME_CORRECTION', 281, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1364, 'TIME_CORRECTION', 281, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1365, 'WITHOUT SHEAF', 243, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1366, 'Full Journal', 243, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1367, 'Full Journal', 243, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1368, 'Full Journal', 243, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1369, 'WITHOUT SHEAF', 243, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1370, 'WITHOUT SHEAF', 243, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1371, 'Full Journal', 243, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1372, 'Full Journal', 243, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1373, 'Full Journal', 243, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1374, 'TIME_CORRECTION', 243, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1375, 'TIME_CORRECTION', 243, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1376, 'METER JOURNAL', 63, 18, 2, 0, 0, 0, NULL, 1, NULL),
	(1377, 'METER JOURNAL', 78, 18, 2, 0, 0, 0, NULL, 1, NULL),
	(1378, 'METER JOURNAL', 63, 158, 2, 0, 0, 0, NULL, 1, NULL),
	(1379, 'TIME_CORRECTION', 24, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1380, 'TIME_CORRECTION', 24, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1381, 'WITHOUT SHEAF', 251, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1382, 'DISCRETE', 251, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(1383, 'Full Journal', 251, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1384, 'Full Journal', 251, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1385, 'Full Journal', 251, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1386, 'WITHOUT SHEAF', 251, 37, 0, 0, -1, -1, NULL, 1, NULL),
	(1387, 'TIME', 251, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(1388, 'TIME_CORRECTION', 251, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1389, 'TIME', 251, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(1390, 'TIME_CORRECTION', 251, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1391, 'CONFIGURATION', 232, 255, 16, 0, 0, 0, NULL, 1, NULL),
	(1392, 'RELAY', 232, 255, 10010, 0, 0, 0, NULL, 1, NULL),
	(1393, 'CONFIGURATION', 248, 255, 16, 0, 0, 0, NULL, 1, NULL),
	(1394, 'RELAY', 248, 255, 10010, 0, 0, 0, NULL, 1, NULL),
	(1396, 'PROFILE', 209, 360, 0, 0, 1, 1, NULL, NULL, NULL),
	(1397, 'PROFILE', 209, 360, 0, 0, 2, 2, NULL, NULL, NULL),
	(1398, 'PROFILE', 209, 360, 0, 0, 3, 3, NULL, NULL, NULL),
	(1399, 'PROFILE', 209, 360, 0, 0, 4, 4, NULL, NULL, NULL),
	(1400, 'PROFILE', 209, 360, 0, 0, 8, 9, NULL, NULL, NULL),
	(1401, 'PROFILE', 209, 360, 0, 0, 10, 11, NULL, NULL, NULL),
	(1402, 'PROFILE', 209, 360, 0, 0, 12, 13, NULL, NULL, NULL),
	(1403, 'PROFILE', 209, 361, 0, 0, 1, 1, NULL, NULL, NULL),
	(1404, 'PROFILE', 209, 361, 0, 0, 2, 2, NULL, NULL, NULL),
	(1405, 'PROFILE', 209, 361, 0, 0, 3, 3, NULL, NULL, NULL),
	(1406, 'PROFILE', 209, 361, 0, 0, 4, 4, NULL, NULL, NULL),
	(1407, 'PROFILE', 209, 361, 0, 0, 8, 9, NULL, NULL, NULL),
	(1408, 'PROFILE', 209, 361, 0, 0, 10, 11, NULL, NULL, NULL),
	(1409, 'PROFILE', 209, 361, 0, 0, 12, 13, NULL, NULL, NULL),
	(1410, 'PROFILE', 140, 361, 0, 0, 1, 1, NULL, NULL, NULL),
	(1411, 'PROFILE', 140, 361, 0, 0, 2, 2, NULL, NULL, NULL),
	(1412, 'PROFILE', 140, 361, 0, 0, 3, 3, NULL, NULL, NULL),
	(1413, 'PROFILE', 140, 361, 0, 0, 4, 4, NULL, NULL, NULL),
	(1414, 'PROFILE', 140, 361, 0, 0, 8, 9, NULL, NULL, NULL),
	(1415, 'PROFILE', 140, 361, 0, 0, 10, 11, NULL, NULL, NULL),
	(1416, 'PROFILE', 140, 361, 0, 0, 12, 13, NULL, NULL, NULL),
	(1417, 'PROFILE', 140, 360, 0, 0, 1, 1, NULL, NULL, NULL),
	(1418, 'PROFILE', 140, 360, 0, 0, 2, 2, NULL, NULL, NULL),
	(1419, 'PROFILE', 140, 360, 0, 0, 3, 3, NULL, NULL, NULL),
	(1420, 'PROFILE', 140, 360, 0, 0, 4, 4, NULL, NULL, NULL),
	(1421, 'PROFILE', 140, 360, 0, 0, 8, 9, NULL, NULL, NULL),
	(1422, 'PROFILE', 140, 360, 0, 0, 10, 11, NULL, NULL, NULL),
	(1423, 'PROFILE', 140, 360, 0, 0, 12, 13, NULL, NULL, NULL),
	(1424, 'PROFILE_MAX_MON', 209, 361, 0, 0, 6, 11, NULL, NULL, NULL),
	(1425, 'PROFILE_MAX_MON', 209, 259, 0, 0, 6, 11, NULL, NULL, NULL),
	(1426, 'PROFILE_MAX_MON', 209, 257, 0, 0, 6, 11, NULL, NULL, NULL),
	(1427, 'PROFILE_MAX_MON', 140, 361, 0, 0, 6, 11, NULL, NULL, NULL),
	(1428, 'PROFILE_MAX_MON', 140, 257, 0, 0, 6, 11, NULL, NULL, NULL),
	(1429, 'PROFILE_MAX_MON', 209, 18, 0, 0, 6, 11, NULL, NULL, NULL),
	(1430, 'PROFILE_MAX_MON', 209, 360, 0, 0, 6, 11, NULL, NULL, NULL),
	(1431, 'PROFILE_MAX_MON', 140, 260, 0, 0, 6, 11, NULL, NULL, NULL),
	(1432, 'PROFILE_MAX_MON', 140, 259, 0, 0, 6, 11, NULL, NULL, NULL),
	(1433, 'PROFILE_MAX_MON', 209, 260, 0, 0, 6, 11, NULL, NULL, NULL),
	(1434, 'PROFILE_MAX_MON', 140, 18, 0, 0, 6, 11, NULL, NULL, NULL),
	(1435, 'PROFILE_MAX_MON', 140, 360, 0, 0, 6, 11, NULL, NULL, NULL),
	(1436, 'PROFILE_MAX_MON', 209, 18, 0, 0, 6, 3, NULL, NULL, NULL),
	(1437, 'PROFILE_MAX_MON', 140, 260, 0, 0, 6, 4, NULL, NULL, NULL),
	(1438, 'PROFILE_MAX_MON', 140, 18, 0, 0, 6, 3, NULL, NULL, NULL),
	(1439, 'PROFILE_MAX_MON', 140, 259, 0, 0, 6, 3, NULL, NULL, NULL),
	(1440, 'PROFILE_MAX_MON', 209, 360, 0, 0, 6, 3, NULL, NULL, NULL),
	(1441, 'PROFILE_MAX_MON', 140, 361, 0, 0, 6, 3, NULL, NULL, NULL),
	(1442, 'PROFILE_MAX_MON', 140, 18, 0, 0, 6, 4, NULL, NULL, NULL),
	(1443, 'PROFILE_MAX_MON', 140, 360, 0, 0, 6, 3, NULL, NULL, NULL),
	(1444, 'PROFILE_MAX_MON', 209, 361, 0, 0, 6, 3, NULL, NULL, NULL),
	(1445, 'PROFILE_MAX_MON', 209, 257, 0, 0, 6, 3, NULL, NULL, NULL),
	(1446, 'PROFILE_MAX_MON', 209, 257, 0, 0, 6, 4, NULL, NULL, NULL),
	(1447, 'PROFILE_MAX_MON', 140, 257, 0, 0, 6, 3, NULL, NULL, NULL),
	(1448, 'PROFILE_MAX_MON', 140, 361, 0, 0, 6, 4, NULL, NULL, NULL),
	(1449, 'PROFILE_MAX_MON', 209, 259, 0, 0, 6, 3, NULL, NULL, NULL),
	(1450, 'PROFILE_MAX_MON', 209, 260, 0, 0, 6, 3, NULL, NULL, NULL),
	(1451, 'PROFILE_MAX_MON', 209, 360, 0, 0, 6, 4, NULL, NULL, NULL),
	(1452, 'PROFILE_MAX_MON', 209, 260, 0, 0, 6, 4, NULL, NULL, NULL),
	(1453, 'PROFILE_MAX_MON', 140, 259, 0, 0, 6, 4, NULL, NULL, NULL),
	(1454, 'PROFILE_MAX_MON', 140, 257, 0, 0, 6, 4, NULL, NULL, NULL),
	(1455, 'PROFILE_MAX_MON', 209, 259, 0, 0, 6, 4, NULL, NULL, NULL),
	(1456, 'PROFILE_MAX_MON', 209, 361, 0, 0, 6, 4, NULL, NULL, NULL),
	(1457, 'PROFILE_MAX_MON', 209, 18, 0, 0, 6, 4, NULL, NULL, NULL),
	(1458, 'PROFILE_MAX_MON', 140, 260, 0, 0, 6, 3, NULL, NULL, NULL),
	(1459, 'PROFILE_MAX_MON', 140, 360, 0, 0, 6, 4, NULL, NULL, NULL),
	(1460, 'TIME_CORRECTION', 290, 164, 14, 0, 0, 0, '5', 0, NULL),
	(1461, 'TIME_CORRECTION', 290, 165, 14, 0, 0, 0, '1800', 0, NULL),
	(1462, 'INSTANT', 290, 18, 0, 0, 7, 7, NULL, NULL, NULL),
	(1463, 'SUM', 290, 18, 0, 0, 7, 8, NULL, NULL, NULL),
	(1464, '3_MIN', 290, 421, 0, 0, 8, -1, NULL, NULL, NULL),
	(1465, '30_MIN', 290, 421, 0, 0, 3, -1, NULL, NULL, NULL),
	(1466, 'DAY', 290, 421, 0, 0, 5, 5, NULL, NULL, NULL),
	(1467, 'MONTH', 290, 421, 0, 0, 6, 6, NULL, NULL, NULL),
	(1468, 'DAYMAX', 290, 420, 0, 0, 5, 9, NULL, NULL, NULL),
	(1469, 'DAYMAX', 290, 420, 0, 0, 5, 3, NULL, NULL, NULL),
	(1470, 'MONTHMAX', 290, 420, 0, 0, 6, 9, NULL, NULL, NULL),
	(1471, 'MONTHMAX', 290, 420, 0, 0, 6, 3, NULL, NULL, NULL),
	(1472, '3_MIN', 290, 422, 0, 0, 8, -1, NULL, NULL, NULL),
	(1473, '30_MIN', 290, 422, 0, 0, 3, -1, NULL, NULL, NULL),
	(1474, 'DAY', 290, 422, 0, 0, 5, 5, NULL, NULL, NULL),
	(1475, 'MONTH', 290, 422, 0, 0, 6, 6, NULL, NULL, NULL),
	(1476, '3_MIN', 290, 423, 0, 0, 8, -1, NULL, NULL, NULL),
	(1477, '30_MIN', 290, 423, 0, 0, 3, -1, NULL, NULL, NULL),
	(1478, 'DAY', 290, 423, 0, 0, 5, 5, NULL, NULL, NULL),
	(1479, 'MONTH', 290, 423, 0, 0, 6, 6, NULL, NULL, NULL),
	(1480, 'TIME', 287, 164, 1, 0, 0, 0, '0', 1, NULL),
	(1481, 'TIME', 287, 165, 1, 0, 0, 0, '0', 1, NULL),
	(1482, 'WITHOUT INSTANT', 287, 323, 0, 0, 3, 3, NULL, NULL, NULL),
	(1483, 'WITHOUT INSTANT', 287, 323, 0, 0, 5, 3, NULL, NULL, NULL),
	(1484, 'WITHOUT INSTANT', 287, 323, 0, 0, 6, 3, NULL, NULL, NULL),
	(1485, 'WITHOUT INSTANT', 287, 323, 0, 0, 4, 4, NULL, NULL, NULL),
	(1486, 'WITHOUT INSTANT', 287, 323, 0, 0, 5, 4, NULL, NULL, NULL),
	(1487, 'WITHOUT INSTANT', 287, 323, 0, 0, 6, 4, NULL, NULL, NULL),
	(1488, 'WITHOUT INSTANT', 287, 323, 0, 0, 5, 5, NULL, NULL, NULL),
	(1489, 'WITHOUT INSTANT', 287, 323, 0, 0, 6, 5, NULL, NULL, NULL),
	(1490, 'WITHOUT INSTANT', 287, 323, 0, 0, 6, 6, NULL, NULL, NULL),
	(1491, 'WITHOUT INSTANT', 287, 323, 0, 0, 3, 8, NULL, NULL, NULL),
	(1492, 'WITHOUT INSTANT', 287, 323, 0, 0, 4, 8, NULL, NULL, NULL),
	(1493, 'WITHOUT INSTANT', 287, 323, 0, 0, 5, 8, NULL, NULL, NULL),
	(1494, 'WITHOUT INSTANT', 287, 323, 0, 0, 6, 8, NULL, NULL, NULL),
	(1495, 'WITHOUT INSTANT', 287, 323, 0, 0, 7, 8, NULL, NULL, NULL),
	(1496, 'WITHOUT INSTANT', 287, 323, 0, 0, 12, 8, NULL, NULL, NULL),
	(1497, 'WITHOUT INSTANT', 287, 323, 0, 0, 5, 13, NULL, NULL, NULL),
	(1498, 'WITHOUT INSTANT', 287, 323, 0, 0, 6, 13, NULL, NULL, NULL),
	(1499, 'WITHOUT INSTANT', 287, 323, 0, 0, 12, 13, NULL, NULL, NULL),
	(1500, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 3, 3, NULL, NULL, NULL),
	(1501, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 5, 3, NULL, NULL, NULL),
	(1502, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 6, 3, NULL, NULL, NULL),
	(1503, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 4, 4, NULL, NULL, NULL),
	(1504, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 5, 4, NULL, NULL, NULL),
	(1505, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 6, 4, NULL, NULL, NULL),
	(1506, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 5, 5, NULL, NULL, NULL),
	(1507, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 6, 5, NULL, NULL, NULL),
	(1508, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 6, 6, NULL, NULL, NULL),
	(1509, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 3, 8, NULL, NULL, NULL),
	(1510, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 4, 8, NULL, NULL, NULL),
	(1511, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 5, 8, NULL, NULL, NULL),
	(1512, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 6, 8, NULL, NULL, NULL),
	(1513, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 7, 8, NULL, NULL, NULL),
	(1514, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 12, 8, NULL, NULL, NULL),
	(1515, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 5, 13, NULL, NULL, NULL),
	(1516, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 6, 13, NULL, NULL, NULL),
	(1517, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 12, 13, NULL, NULL, NULL),
	(1518, 'INSTANT', 202, 18, 0, 0, -1, 7, NULL, NULL, NULL),
	(1519, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 3, 3, NULL, NULL, NULL),
	(1520, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 5, 3, NULL, NULL, NULL),
	(1521, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 6, 3, NULL, NULL, NULL),
	(1522, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 4, 4, NULL, NULL, NULL),
	(1523, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 5, 4, NULL, NULL, NULL),
	(1524, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 6, 4, NULL, NULL, NULL),
	(1525, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 5, 5, NULL, NULL, NULL),
	(1526, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 6, 5, NULL, NULL, NULL),
	(1527, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 6, 6, NULL, NULL, NULL),
	(1528, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 3, 8, NULL, NULL, NULL),
	(1529, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 4, 8, NULL, NULL, NULL),
	(1530, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 5, 8, NULL, NULL, NULL),
	(1531, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 6, 8, NULL, NULL, NULL),
	(1532, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 7, 8, NULL, NULL, NULL),
	(1533, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 12, 8, NULL, NULL, NULL),
	(1534, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 5, 13, NULL, NULL, NULL),
	(1535, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 6, 13, NULL, NULL, NULL),
	(1536, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 12, 13, NULL, NULL, NULL),
	(1537, 'TIME_CORRECTION', 53, 164, 14, 0, 0, 0, '5', 0, NULL),
	(1538, 'TIME_CORRECTION', 53, 165, 14, 0, 0, 0, '1800', 0, NULL),
	(1539, 'PROFILE', 53, 37, 0, 0, 1, 1, '1', NULL, NULL),
	(1540, 'PROFILE', 53, 37, 0, 0, 2, 2, '1', NULL, NULL),
	(1541, 'PROFILE', 53, 37, 0, 0, 8, 9, '1', NULL, NULL),
	(1542, 'PROFILE', 53, 37, 0, 0, 10, 11, '1', NULL, NULL),
	(1543, 'PROFILE', 53, 37, 0, 0, 4, 4, '1', NULL, NULL),
	(1544, 'PROFILE', 53, 37, 0, 0, 3, 3, '1', NULL, NULL),
	(1545, 'PROFILE', 53, 37, 0, 0, 12, 13, '1', NULL, NULL),
	(1546, 'WITHOUT SHEAF', 262, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1547, 'WITHOUT SHEAF', 259, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1548, 'WITHOUT SHEAF', 258, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1549, 'WITHOUT SHEAF', 260, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1550, 'WITHOUT SHEAF', 261, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1551, 'WITHOUT SHEAF', 263, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1552, 'WITHOUT SHEAF', 264, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1553, 'WITHOUT SHEAF', 265, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1554, 'WITHOUT SHEAF', 266, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1555, 'WITHOUT SHEAF', 267, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1556, 'WITHOUT SHEAF', 268, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1557, 'WITHOUT SHEAF', 269, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1558, 'WITHOUT SHEAF', 270, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1559, 'WITHOUT SHEAF', 271, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1560, 'WITHOUT SHEAF', 272, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1561, 'WITHOUT SHEAF', 273, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1562, 'WITHOUT SHEAF', 274, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1563, 'WITHOUT SHEAF', 275, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1564, 'WITHOUT SHEAF', 276, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1565, 'WITHOUT SHEAF', 277, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1566, 'WITHOUT SHEAF', 278, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1567, 'WITHOUT SHEAF', 279, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1568, 'WITHOUT SHEAF', 280, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1569, 'WITHOUT SHEAF', 281, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1570, 'WITHOUT SHEAF', 243, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1571, 'WITHOUT SHEAF', 282, 386, 0, 0, -1, -1, NULL, 1, NULL),
	(1572, 'METER JOURNAL', 282, 386, 2, 0, 0, 0, NULL, 1, NULL),
	(1573, 'WITHOUT SHEAF', 118, 107, 0, 0, -1, -1, '0', NULL, NULL),
	(1574, 'WITHOUT SHEAF', 190, 107, 0, 0, -1, -1, '0', NULL, NULL),
	(1575, 'WITHOUT SHEAF', 117, 107, 0, 0, -1, -1, '0', NULL, NULL),
	(1576, 'WITHOUT SHEAF', 87, 107, 0, 0, -1, -1, '0', NULL, NULL),
	(1577, 'WITHOUT SHEAF', 118, 158, 0, 0, -1, -1, NULL, NULL, NULL),
	(1578, 'WITHOUT SHEAF', 190, 158, 0, 0, -1, -1, NULL, NULL, NULL),
	(1579, 'WITHOUT SHEAF', 117, 158, 0, 0, -1, -1, NULL, NULL, NULL),
	(1580, 'WITHOUT SHEAF', 87, 158, 0, 0, -1, -1, NULL, NULL, NULL),
	(1581, 'TIME', 293, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(1582, 'TIME', 293, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(1583, 'DISCRETE', 293, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(1584, 'WITHOUT SHEAF', 293, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1585, 'JOURNAL', 293, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1586, 'WITHOUT SHEAF', 293, 107, 0, 0, -1, -1, '0', NULL, NULL),
	(1587, 'WITHOUT SHEAF', 293, 158, 0, 0, -1, -1, NULL, NULL, NULL),
	(1588, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 1, 1, NULL, NULL, NULL),
	(1591, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 8, 9, NULL, NULL, NULL),
	(1593, 'WITHOUT SHEAF/INSTANT', 202, 408, 0, 0, 10, 11, NULL, NULL, NULL),
	(1595, 'PROFILE', 154, 37, 0, 0, 1, 1, '1', NULL, NULL),
	(1596, 'PROFILE', 154, 37, 0, 0, 1, 7, '1', NULL, NULL),
	(1597, 'PROFILE', 154, 37, 0, 0, 2, 2, '1', NULL, NULL),
	(1598, 'PROFILE', 154, 37, 0, 0, 2, 7, '1', NULL, NULL),
	(1599, 'PROFILE', 154, 37, 0, 0, 3, 3, '1', NULL, NULL),
	(1600, 'PROFILE', 154, 37, 0, 0, 3, 7, '1', NULL, NULL),
	(1601, 'PROFILE', 154, 37, 0, 0, 4, 4, '1', NULL, NULL),
	(1602, 'PROFILE', 154, 37, 0, 0, 4, 7, '1', NULL, NULL),
	(1603, 'PROFILE', 154, 37, 0, 0, 10, 7, '1', NULL, NULL),
	(1604, 'PROFILE', 154, 37, 0, 0, 10, 11, '1', NULL, NULL),
	(1605, 'PROFILE', 154, 37, 0, 0, 11, 12, '1', NULL, NULL),
	(1606, 'PROFILE', 154, 37, 0, 0, 12, 7, '1', NULL, NULL),
	(1607, 'PROFILE', 154, 37, 0, 0, 12, 13, '1', NULL, NULL),
	(1608, 'PROFILE', 154, 37, 0, 0, 13, 14, '1', NULL, NULL),
	(1609, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 1, 1, NULL, NULL, NULL),
	(1610, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 8, 9, NULL, NULL, NULL),
	(1611, 'WITHOUT SHEAF/INSTANT', 202, 421, 0, 0, 10, 11, NULL, NULL, NULL),
	(1612, 'MEASURES', 290, 106, 0, 0, -1, -1, NULL, NULL, NULL),
	(1613, 'TOTALFIXMON', 290, 18, 0, 0, 6, 8, NULL, NULL, NULL),
	(1614, 'MEASURES', 244, 232, 0, 0, -1, -1, NULL, NULL, NULL),
	(1615, 'WITHOUT SHEAF', 294, 21, 0, 0, -1, -1, NULL, NULL, NULL),
	(1616, 'WITHOUT SHEAF', 294, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1617, 'TIME', 294, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(1618, 'TIME', 294, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(1619, 'TIME', 296, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(1620, 'TIME', 296, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(1621, 'RELAY', 232, 431, 10010, 0, 0, 0, NULL, 1, NULL),
	(1622, 'RELAY', 248, 431, 10010, 0, 0, 0, NULL, 1, NULL),
	(1623, 'RELAY', 232, 256, 10010, 0, 0, 0, NULL, 1, NULL),
	(1624, 'RELAY', 248, 256, 10010, 0, 0, 0, NULL, 1, NULL),
	(1625, 'PROFILE', 154, 37, 0, 0, 8, 7, '1', NULL, NULL),
	(1626, 'PROFILE', 154, 37, 0, 0, 4, 11, '1', NULL, NULL),
	(1627, 'PROFILE', 154, 37, 0, 0, 9, 10, '1', NULL, NULL),
	(1628, 'PROFILE', 154, 37, 0, 0, 4, 12, '1', NULL, NULL),
	(1629, 'PROFILE', 154, 37, 0, 0, 8, 9, '1', NULL, NULL),
	(1630, 'PROFILE', 154, 37, 0, 0, 4, 2, '1', NULL, NULL),
	(1631, 'PROFILE', 154, 37, 0, 0, 4, 9, '1', NULL, NULL),
	(1632, 'PROFILE', 154, 37, 0, 0, 4, 1, '1', NULL, NULL),
	(1633, 'PROFILE', 154, 37, 0, 0, 4, 10, '1', NULL, NULL),
	(1636, 'WITHOUT SHEAF', 308, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1637, 'WITHOUT SHEAF', 307, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1638, 'WITHOUT SHEAF', 306, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1639, 'WITHOUT SHEAF', 307, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1640, 'WITHOUT SHEAF', 308, 403, 0, 0, -1, -1, '-1', NULL, NULL),
	(1641, 'WITHOUT SHEAF', 306, 425, 0, 0, -1, -1, '0', NULL, NULL),
	(1642, 'TIME_CORRECTION', 307, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1643, 'TIME_CORRECTION', 306, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1644, 'TIME_CORRECTION', 308, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1645, 'TIME_CORRECTION', 308, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1646, 'TIME_CORRECTION', 307, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1647, 'TIME_CORRECTION', 306, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1648, 'WITHOUT SHEAF', 306, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1649, 'Full Journal', 308, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1650, 'Full Journal', 306, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1651, 'Full Journal', 308, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1652, 'WITHOUT SHEAF', 306, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1653, 'Full Journal', 307, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1654, 'Full Journal', 307, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1655, 'Full Journal', 306, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1656, 'Full Journal', 308, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1657, 'Full Journal', 307, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1658, 'Full Journal', 307, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1659, 'WITHOUT SHEAF', 308, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1660, 'Full Journal', 306, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1661, 'WITHOUT SHEAF', 307, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1662, 'Full Journal', 306, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1663, 'Full Journal', 308, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(1664, 'Full Journal', 307, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1665, 'WITHOUT SHEAF', 308, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(1666, 'Full Journal', 307, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(1667, 'WITHOUT SHEAF', 307, 107, 0, 0, -1, -1, NULL, NULL, NULL),
	(1668, 'Full Journal', 308, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(1669, 'Full Journal', 308, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(1670, 'Full Journal', 306, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(1671, 'Full Journal', 306, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(1672, 'RELAY1', 306, 107, 10010, 0, 0, 0, NULL, 1, '1001'),
	(1673, 'RELAY2', 306, 107, 10011, 0, 0, 0, NULL, 1, '1001'),
	(1674, 'RELAY1', 306, 322, 10010, 0, 0, 0, NULL, 1, '0'),
	(1675, 'RELAY2', 306, 322, 10011, 0, 0, 0, NULL, 1, '0'),
	(1676, 'RELAY1', 306, 437, 10010, 0, 0, 0, NULL, 1, '4'),
	(1677, 'RELAY2', 306, 437, 10011, 0, 0, 0, NULL, 1, '5'),
	(1678, 'RELAY1', 306, 438, 10010, 0, 0, 0, NULL, 1, '0'),
	(1679, 'RELAY2', 306, 438, 10011, 0, 0, 0, NULL, 1, '0'),
	(1680, 'RELAY1', 306, 439, 10010, 0, 0, 0, NULL, 1, '0'),
	(1681, 'RELAY2', 306, 439, 10011, 0, 0, 0, NULL, 1, '1'),
	(1682, 'RELAY1', 306, 440, 10010, 0, 0, 0, NULL, 1, '0'),
	(1683, 'RELAY2', 306, 440, 10011, 0, 0, 0, NULL, 1, '0'),
	(1684, 'TIME_CORRECTION', 299, 441, 14, 0, 0, 0, NULL, 1, NULL),
	(1685, 'TIME_CORRECTION', 299, 164, 14, 0, 0, 0, '5', 1, NULL),
	(1686, 'TIME_CORRECTION', 299, 165, 14, 0, 0, 0, '300', 1, NULL),
	(1687, 'TIME_CORRECTION', 299, 227, 14, 0, 0, 0, '30', 1, NULL),
	(1688, 'Ht_HeatQntt', 338, 18, 0, 0, -1, -1, '1', 1, NULL),
	(1691, 'CURRENT_MON', 140, 475, 0, 0, 6, 6, NULL, 1, NULL),
	(1692, 'CURRENT_MON', 209, 474, 0, 0, 6, 6, NULL, 1, NULL),
	(1693, 'CURRENT_MON', 140, 474, 0, 0, 6, 6, NULL, 1, NULL),
	(1694, 'CURRENT_MON', 209, 475, 0, 0, 6, 6, NULL, 1, NULL),
	(1695, 'CURRENT_PROFILE', 140, 474, 0, 0, 1, 1, NULL, 1, NULL),
	(1696, 'CURRENT_PROFILE', 140, 474, 0, 0, 2, 2, NULL, 1, NULL),
	(1697, 'CURRENT_PROFILE', 140, 474, 0, 0, 3, 3, NULL, 1, NULL),
	(1698, 'CURRENT_PROFILE', 140, 474, 0, 0, 4, 1, NULL, 1, NULL),
	(1699, 'CURRENT_PROFILE', 140, 474, 0, 0, 4, 2, NULL, 1, NULL),
	(1700, 'CURRENT_PROFILE', 140, 474, 0, 0, 4, 4, NULL, 1, NULL),
	(1701, 'CURRENT_PROFILE', 140, 474, 0, 0, 4, 7, NULL, 1, NULL),
	(1702, 'CURRENT_PROFILE', 140, 474, 0, 0, 4, 9, NULL, 1, NULL),
	(1703, 'CURRENT_PROFILE', 140, 474, 0, 0, 4, 10, NULL, 1, NULL),
	(1704, 'CURRENT_PROFILE', 140, 474, 0, 0, 4, 11, NULL, 1, NULL),
	(1705, 'CURRENT_PROFILE', 140, 474, 0, 0, 4, 12, NULL, 1, NULL),
	(1706, 'CURRENT_PROFILE', 140, 474, 0, 0, 8, 9, NULL, 1, NULL),
	(1707, 'CURRENT_PROFILE', 140, 474, 0, 0, 9, 10, NULL, 1, NULL),
	(1708, 'CURRENT_PROFILE', 140, 474, 0, 0, 10, 11, NULL, 1, NULL),
	(1709, 'CURRENT_PROFILE', 140, 474, 0, 0, 11, 12, NULL, 1, NULL),
	(1710, 'CURRENT_PROFILE', 140, 474, 0, 0, 12, 13, NULL, 1, NULL),
	(1711, 'CURRENT_PROFILE', 140, 474, 0, 0, 13, 14, NULL, 1, NULL),
	(1712, 'CURRENT_PROFILE', 140, 475, 0, 0, 1, 1, NULL, 1, NULL),
	(1713, 'CURRENT_PROFILE', 140, 475, 0, 0, 2, 2, NULL, 1, NULL),
	(1714, 'CURRENT_PROFILE', 140, 475, 0, 0, 3, 3, NULL, 1, NULL),
	(1715, 'CURRENT_PROFILE', 140, 475, 0, 0, 4, 1, NULL, 1, NULL),
	(1716, 'CURRENT_PROFILE', 140, 475, 0, 0, 4, 2, NULL, 1, NULL),
	(1717, 'CURRENT_PROFILE', 140, 475, 0, 0, 4, 4, NULL, 1, NULL),
	(1718, 'CURRENT_PROFILE', 140, 475, 0, 0, 4, 7, NULL, 1, NULL),
	(1719, 'CURRENT_PROFILE', 140, 475, 0, 0, 4, 9, NULL, 1, NULL),
	(1720, 'CURRENT_PROFILE', 140, 475, 0, 0, 4, 10, NULL, 1, NULL),
	(1721, 'CURRENT_PROFILE', 140, 475, 0, 0, 4, 11, NULL, 1, NULL),
	(1722, 'CURRENT_PROFILE', 140, 475, 0, 0, 4, 12, NULL, 1, NULL),
	(1723, 'CURRENT_PROFILE', 140, 475, 0, 0, 8, 9, NULL, 1, NULL),
	(1724, 'CURRENT_PROFILE', 140, 475, 0, 0, 9, 10, NULL, 1, NULL),
	(1725, 'CURRENT_PROFILE', 140, 475, 0, 0, 10, 11, NULL, 1, NULL),
	(1726, 'CURRENT_PROFILE', 140, 475, 0, 0, 11, 12, NULL, 1, NULL),
	(1727, 'CURRENT_PROFILE', 140, 475, 0, 0, 12, 13, NULL, 1, NULL),
	(1728, 'CURRENT_PROFILE', 140, 475, 0, 0, 13, 14, NULL, 1, NULL),
	(1729, 'CURRENT_PROFILE', 209, 474, 0, 0, 1, 1, NULL, 1, NULL),
	(1730, 'CURRENT_PROFILE', 209, 474, 0, 0, 2, 2, NULL, 1, NULL),
	(1731, 'CURRENT_PROFILE', 209, 474, 0, 0, 3, 3, NULL, 1, NULL),
	(1732, 'CURRENT_PROFILE', 209, 474, 0, 0, 4, 1, NULL, 1, NULL),
	(1733, 'CURRENT_PROFILE', 209, 474, 0, 0, 4, 2, NULL, 1, NULL),
	(1734, 'CURRENT_PROFILE', 209, 474, 0, 0, 4, 4, NULL, 1, NULL),
	(1735, 'CURRENT_PROFILE', 209, 474, 0, 0, 4, 7, NULL, 1, NULL),
	(1736, 'CURRENT_PROFILE', 209, 474, 0, 0, 4, 9, NULL, 1, NULL),
	(1737, 'CURRENT_PROFILE', 209, 474, 0, 0, 4, 10, NULL, 1, NULL),
	(1738, 'CURRENT_PROFILE', 209, 474, 0, 0, 4, 11, NULL, 1, NULL),
	(1739, 'CURRENT_PROFILE', 209, 474, 0, 0, 4, 12, NULL, 1, NULL),
	(1740, 'CURRENT_PROFILE', 209, 474, 0, 0, 8, 9, NULL, 1, NULL),
	(1741, 'CURRENT_PROFILE', 209, 474, 0, 0, 9, 10, NULL, 1, NULL),
	(1742, 'CURRENT_PROFILE', 209, 474, 0, 0, 10, 11, NULL, 1, NULL),
	(1743, 'CURRENT_PROFILE', 209, 474, 0, 0, 11, 12, NULL, 1, NULL),
	(1744, 'CURRENT_PROFILE', 209, 474, 0, 0, 12, 13, NULL, 1, NULL),
	(1745, 'CURRENT_PROFILE', 209, 474, 0, 0, 13, 14, NULL, 1, NULL),
	(1746, 'CURRENT_PROFILE', 209, 475, 0, 0, 1, 1, NULL, 1, NULL),
	(1747, 'CURRENT_PROFILE', 209, 475, 0, 0, 2, 2, NULL, 1, NULL),
	(1748, 'CURRENT_PROFILE', 209, 475, 0, 0, 3, 3, NULL, 1, NULL),
	(1749, 'CURRENT_PROFILE', 209, 475, 0, 0, 4, 1, NULL, 1, NULL),
	(1750, 'CURRENT_PROFILE', 209, 475, 0, 0, 4, 2, NULL, 1, NULL),
	(1751, 'CURRENT_PROFILE', 209, 475, 0, 0, 4, 4, NULL, 1, NULL),
	(1752, 'CURRENT_PROFILE', 209, 475, 0, 0, 4, 7, NULL, 1, NULL),
	(1753, 'CURRENT_PROFILE', 209, 475, 0, 0, 4, 9, NULL, 1, NULL),
	(1754, 'CURRENT_PROFILE', 209, 475, 0, 0, 4, 10, NULL, 1, NULL),
	(1755, 'CURRENT_PROFILE', 209, 475, 0, 0, 4, 11, NULL, 1, NULL),
	(1756, 'CURRENT_PROFILE', 209, 475, 0, 0, 4, 12, NULL, 1, NULL),
	(1757, 'CURRENT_PROFILE', 209, 475, 0, 0, 8, 9, NULL, 1, NULL),
	(1758, 'CURRENT_PROFILE', 209, 475, 0, 0, 9, 10, NULL, 1, NULL),
	(1759, 'CURRENT_PROFILE', 209, 475, 0, 0, 10, 11, NULL, 1, NULL),
	(1760, 'CURRENT_PROFILE', 209, 475, 0, 0, 11, 12, NULL, 1, NULL),
	(1761, 'CURRENT_PROFILE', 209, 475, 0, 0, 12, 13, NULL, 1, NULL),
	(1762, 'CURRENT_PROFILE', 209, 475, 0, 0, 13, 14, NULL, 1, NULL),
	(1766, 'JOURNAL', 139, 483, 2, 0, 0, 0, NULL, NULL, NULL),
	(1767, 'JOURNAL', 139, 482, 2, 0, 0, 0, NULL, NULL, NULL),
	(1768, 'JOURNAL', 139, 480, 2, 0, 0, 0, NULL, NULL, NULL),
	(1769, 'JOURNAL', 139, 484, 2, 0, 0, 0, NULL, NULL, NULL),
	(1770, 'JOURNAL', 139, 485, 2, 0, 0, 0, NULL, NULL, NULL),
	(1771, 'JOURNAL', 139, 481, 2, 0, 0, 0, NULL, NULL, NULL),
	(1772, 'JOURNALW', 139, 483, 22, 0, 0, 0, NULL, NULL, NULL),
	(1773, 'JOURNALW', 139, 482, 22, 0, 0, 0, NULL, NULL, NULL),
	(1774, 'JOURNALW', 139, 480, 22, 0, 0, 0, NULL, NULL, NULL),
	(1775, 'JOURNALW', 139, 484, 22, 0, 0, 0, NULL, NULL, NULL),
	(1776, 'JOURNALW', 139, 288, 22, 0, 0, 0, NULL, NULL, NULL),
	(1777, 'JOURNALW', 139, 485, 22, 0, 0, 0, NULL, NULL, NULL),
	(1778, 'JOURNALW', 139, 481, 22, 0, 0, 0, NULL, NULL, NULL),
	(1779, 'JOURNALW', 139, 291, 22, 0, 0, 0, NULL, NULL, NULL),
	(1780, 'JOURNALW', 139, 290, 22, 0, 0, 0, NULL, NULL, NULL),
	(1781, 'JOURNALW', 139, 289, 22, 0, 0, 0, NULL, NULL, NULL),
	(1782, 'PROFILE', 342, 37, 0, 0, 13, -1, NULL, 1, NULL),
	(1783, 'PROFILE', 342, 37, 0, 0, 8, -1, NULL, 1, NULL),
	(1784, 'PROFILE', 342, 37, 0, 0, 3, -1, NULL, 1, NULL),
	(1785, 'PROFILE', 342, 37, 0, 0, 12, -1, NULL, 1, NULL),
	(1786, 'PROFILE', 342, 37, 0, 0, 1, -1, NULL, 1, NULL),
	(1787, 'PROFILE', 342, 37, 0, 0, 2, -1, NULL, 1, NULL),
	(1788, 'PROFILE', 342, 37, 0, 0, 10, -1, NULL, 1, NULL),
	(1789, 'PROFILE', 342, 37, 0, 0, 11, -1, NULL, 1, NULL),
	(1790, 'PROFILE', 342, 37, 0, 0, 4, -1, NULL, 1, NULL),
	(1791, 'PROFILE', 342, 37, 0, 0, 9, -1, NULL, 1, NULL),
	(1792, 'DEVICE_TIME', 342, 165, 1, 0, 0, 0, '0', 0, NULL),
	(1793, 'DEVICE_TIME', 342, 164, 1, 0, 0, 0, '0', 0, NULL),
	(1794, 'PROFILE', -4, 37, 0, 0, 13, -1, NULL, 1, NULL),
	(1795, 'PROFILE', -4, 37, 0, 0, 8, -1, NULL, 1, NULL),
	(1796, 'PROFILE', -4, 37, 0, 0, 3, -1, NULL, 1, NULL),
	(1797, 'PROFILE', -4, 37, 0, 0, 12, -1, NULL, 1, NULL),
	(1798, 'PROFILE', -4, 37, 0, 0, 1, -1, NULL, 1, NULL),
	(1799, 'PROFILE', -4, 37, 0, 0, 2, -1, NULL, 1, NULL),
	(1800, 'PROFILE', -4, 37, 0, 0, 10, -1, NULL, 1, NULL),
	(1801, 'PROFILE', -4, 37, 0, 0, 11, -1, NULL, 1, NULL),
	(1802, 'PROFILE', -4, 37, 0, 0, 4, -1, NULL, 1, NULL),
	(1803, 'PROFILE', -4, 37, 0, 0, 9, -1, NULL, 1, NULL),
	(1804, 'MAXMON', 346, 490, 0, 0, 6, -1, '1', NULL, NULL),
	(1805, 'TIME', 346, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(1806, 'TIME', 346, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(1807, 'TIME', 246, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(1808, 'TIME', 246, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(1809, 'MAXMON', 246, 490, 0, 0, 6, -1, '1', NULL, NULL),
	(1810, 'PROFILE', 246, 37, 0, 0, 1, 8, '1', NULL, NULL),
	(1811, 'PROFILE', 246, 37, 0, 0, 2, 8, '1', NULL, NULL),
	(1812, 'PROFILE', 246, 37, 0, 0, 3, 8, '1', NULL, NULL),
	(1813, 'PROFILE', 246, 37, 0, 0, 4, 8, '1', NULL, NULL),
	(1814, 'PROFILE', 246, 37, 0, 0, 8, 8, '1', NULL, NULL),
	(1815, 'PROFILE', 246, 37, 0, 0, 9, 8, '1', NULL, NULL),
	(1816, 'PROFILE', 246, 37, 0, 0, 10, 8, '1', NULL, NULL),
	(1817, 'PROFILE', 246, 37, 0, 0, 11, 8, '1', NULL, NULL),
	(1818, 'PROFILE', 246, 37, 0, 0, 12, 8, '1', NULL, NULL),
	(1819, 'PROFILE', 246, 37, 0, 0, 13, 8, '1', NULL, NULL),
	(1820, 'PROFILE', 39, 18, 0, 0, 1, 1, '1', NULL, NULL),
	(1821, 'PROFILE', 39, 18, 0, 0, 2, 2, '1', NULL, NULL),
	(1822, 'PROFILE', 39, 18, 0, 0, 4, 1, '1', NULL, NULL),
	(1823, 'PROFILE', 39, 18, 0, 0, 4, 2, '1', NULL, NULL),
	(1824, 'PROFILE', 39, 18, 0, 0, 4, 9, '1', NULL, NULL),
	(1825, 'PROFILE', 39, 18, 0, 0, 4, 10, '1', NULL, NULL),
	(1826, 'PROFILE', 39, 18, 0, 0, 4, 11, '1', NULL, NULL),
	(1827, 'PROFILE', 39, 18, 0, 0, 4, 12, '1', NULL, NULL),
	(1828, 'PROFILE', 39, 18, 0, 0, 8, 9, '1', NULL, NULL),
	(1829, 'PROFILE', 39, 18, 0, 0, 9, 10, '1', NULL, NULL),
	(1830, 'PROFILE', 39, 18, 0, 0, 10, 11, '1', NULL, NULL),
	(1831, 'PROFILE', 39, 18, 0, 0, 11, 12, '1', NULL, NULL),
	(1832, 'PROFILE', 39, 18, 0, 0, 13, 14, '1', NULL, NULL),
	(1833, 'PROFILE', 39, 18, 0, 0, 14, 15, '1', NULL, NULL),
	(1834, 'PROFILE', 143, 18, 0, 0, 1, 1, '1', NULL, NULL),
	(1835, 'PROFILE', 143, 18, 0, 0, 2, 2, '1', NULL, NULL),
	(1836, 'PROFILE', 143, 18, 0, 0, 4, 1, '1', NULL, NULL),
	(1837, 'PROFILE', 143, 18, 0, 0, 4, 2, '1', NULL, NULL),
	(1838, 'PROFILE', 143, 18, 0, 0, 4, 9, '1', NULL, NULL),
	(1839, 'PROFILE', 143, 18, 0, 0, 4, 10, '1', NULL, NULL),
	(1840, 'PROFILE', 143, 18, 0, 0, 4, 11, '1', NULL, NULL),
	(1841, 'PROFILE', 143, 18, 0, 0, 4, 12, '1', NULL, NULL),
	(1842, 'PROFILE', 143, 18, 0, 0, 8, 9, '1', NULL, NULL),
	(1843, 'PROFILE', 143, 18, 0, 0, 9, 10, '1', NULL, NULL),
	(1844, 'PROFILE', 143, 18, 0, 0, 10, 11, '1', NULL, NULL),
	(1845, 'PROFILE', 143, 18, 0, 0, 11, 12, '1', NULL, NULL),
	(1846, 'PROFILE', 143, 18, 0, 0, 13, 14, '1', NULL, NULL),
	(1847, 'PROFILE', 143, 18, 0, 0, 14, 15, '1', NULL, NULL),
	(1848, 'PROFILE', 39, 259, 0, 0, 1, 1, '1', NULL, NULL),
	(1849, 'PROFILE', 39, 259, 0, 0, 2, 2, '1', NULL, NULL),
	(1850, 'PROFILE', 39, 259, 0, 0, 3, 3, '1', NULL, NULL),
	(1851, 'PROFILE', 39, 259, 0, 0, 4, 1, '1', NULL, NULL),
	(1852, 'PROFILE', 39, 259, 0, 0, 4, 2, '1', NULL, NULL),
	(1853, 'PROFILE', 39, 259, 0, 0, 4, 4, '1', NULL, NULL),
	(1854, 'PROFILE', 39, 259, 0, 0, 4, 9, '1', NULL, NULL),
	(1855, 'PROFILE', 39, 259, 0, 0, 4, 10, '1', NULL, NULL),
	(1856, 'PROFILE', 39, 259, 0, 0, 4, 11, '1', NULL, NULL),
	(1857, 'PROFILE', 39, 259, 0, 0, 4, 12, '1', NULL, NULL),
	(1858, 'PROFILE', 39, 259, 0, 0, 8, 9, '1', NULL, NULL),
	(1859, 'PROFILE', 39, 259, 0, 0, 9, 10, '1', NULL, NULL),
	(1860, 'PROFILE', 39, 259, 0, 0, 10, 11, '1', NULL, NULL),
	(1861, 'PROFILE', 39, 259, 0, 0, 11, 12, '1', NULL, NULL),
	(1862, 'PROFILE', 39, 259, 0, 0, 12, 13, '1', NULL, NULL),
	(1863, 'PROFILE', 39, 259, 0, 0, 13, 14, '1', NULL, NULL),
	(1864, 'PROFILE', 39, 259, 0, 0, 14, 15, '1', NULL, NULL),
	(1865, 'PROFILE', 143, 259, 0, 0, 1, 1, '1', NULL, NULL),
	(1866, 'PROFILE', 143, 259, 0, 0, 2, 2, '1', NULL, NULL),
	(1867, 'PROFILE', 143, 259, 0, 0, 3, 3, '1', NULL, NULL),
	(1868, 'PROFILE', 143, 259, 0, 0, 4, 1, '1', NULL, NULL),
	(1869, 'PROFILE', 143, 259, 0, 0, 4, 2, '1', NULL, NULL),
	(1870, 'PROFILE', 143, 259, 0, 0, 4, 4, '1', NULL, NULL),
	(1871, 'PROFILE', 143, 259, 0, 0, 4, 9, '1', NULL, NULL),
	(1872, 'PROFILE', 143, 259, 0, 0, 4, 10, '1', NULL, NULL),
	(1873, 'PROFILE', 143, 259, 0, 0, 4, 11, '1', NULL, NULL),
	(1874, 'PROFILE', 143, 259, 0, 0, 4, 12, '1', NULL, NULL),
	(1875, 'PROFILE', 143, 259, 0, 0, 8, 9, '1', NULL, NULL),
	(1876, 'PROFILE', 143, 259, 0, 0, 9, 10, '1', NULL, NULL),
	(1877, 'PROFILE', 143, 259, 0, 0, 10, 11, '1', NULL, NULL),
	(1878, 'PROFILE', 143, 259, 0, 0, 11, 12, '1', NULL, NULL),
	(1879, 'PROFILE', 143, 259, 0, 0, 12, 13, '1', NULL, NULL),
	(1880, 'PROFILE', 143, 259, 0, 0, 13, 14, '1', NULL, NULL),
	(1881, 'PROFILE', 143, 259, 0, 0, 14, 15, '1', NULL, NULL),
	(1886, 'Relay_1', 244, 232, 10010, 0, 0, 0, NULL, NULL, NULL),
	(1887, 'Relay_1', 244, 386, 10010, 0, 0, 0, NULL, NULL, NULL),
	(1888, 'PROFILE', 39, 491, 0, 0, 3, 3, '0000630100FF', NULL, NULL),
	(1889, 'PROFILE', 39, 491, 0, 0, 4, 4, '0000630100FF', NULL, NULL),
	(1890, 'PROFILE', 39, 491, 0, 0, 12, 13, '0000630100FF', NULL, NULL),
	(1891, 'PROFILE', 143, 491, 0, 0, 3, 3, '0000630100FF', NULL, NULL),
	(1892, 'PROFILE', 143, 491, 0, 0, 4, 4, '0000630100FF', NULL, NULL),
	(1893, 'PROFILE', 143, 491, 0, 0, 12, 13, '0000630100FF', NULL, NULL),
	(1894, 'PROFILE', 39, 491, 0, 0, 1, 1, '0000630100FF', NULL, NULL),
	(1895, 'PROFILE', 39, 491, 0, 0, 2, 2, '0000630100FF', NULL, NULL),
	(1896, 'PROFILE', 39, 491, 0, 0, 4, 1, '0000630100FF', NULL, NULL),
	(1897, 'PROFILE', 39, 491, 0, 0, 4, 2, '0000630100FF', NULL, NULL),
	(1898, 'PROFILE', 39, 491, 0, 0, 4, 9, '0000630100FF', NULL, NULL),
	(1899, 'PROFILE', 39, 491, 0, 0, 4, 10, '0000630100FF', NULL, NULL),
	(1900, 'PROFILE', 39, 491, 0, 0, 4, 11, '0000630100FF', NULL, NULL),
	(1901, 'PROFILE', 39, 491, 0, 0, 4, 12, '0000630100FF', NULL, NULL),
	(1902, 'PROFILE', 39, 491, 0, 0, 8, 9, '0000630100FF', NULL, NULL),
	(1903, 'PROFILE', 39, 491, 0, 0, 9, 10, '0000630100FF', NULL, NULL),
	(1904, 'PROFILE', 39, 491, 0, 0, 10, 11, '0000630100FF', NULL, NULL),
	(1905, 'PROFILE', 39, 491, 0, 0, 11, 12, '0000630100FF', NULL, NULL),
	(1906, 'PROFILE', 39, 491, 0, 0, 13, 14, '0000630100FF', NULL, NULL),
	(1907, 'PROFILE', 39, 491, 0, 0, 14, 15, '0000630100FF', NULL, NULL),
	(1908, 'PROFILE', 143, 491, 0, 0, 1, 1, '0000630100FF', NULL, NULL),
	(1909, 'PROFILE', 143, 491, 0, 0, 2, 2, '0000630100FF', NULL, NULL),
	(1910, 'PROFILE', 143, 491, 0, 0, 4, 1, '0000630100FF', NULL, NULL),
	(1911, 'PROFILE', 143, 491, 0, 0, 4, 2, '0000630100FF', NULL, NULL),
	(1912, 'PROFILE', 143, 491, 0, 0, 4, 9, '0000630100FF', NULL, NULL),
	(1913, 'PROFILE', 143, 491, 0, 0, 4, 10, '0000630100FF', NULL, NULL),
	(1914, 'PROFILE', 143, 491, 0, 0, 4, 11, '0000630100FF', NULL, NULL),
	(1915, 'PROFILE', 143, 491, 0, 0, 4, 12, '0000630100FF', NULL, NULL),
	(1916, 'PROFILE', 143, 491, 0, 0, 8, 9, '0000630100FF', NULL, NULL),
	(1917, 'PROFILE', 143, 491, 0, 0, 9, 10, '0000630100FF', NULL, NULL),
	(1918, 'PROFILE', 143, 491, 0, 0, 10, 11, '0000630100FF', NULL, NULL),
	(1919, 'PROFILE', 143, 491, 0, 0, 11, 12, '0000630100FF', NULL, NULL),
	(1920, 'PROFILE', 143, 491, 0, 0, 13, 14, '0000630100FF', NULL, NULL),
	(1921, 'PROFILE', 143, 491, 0, 0, 14, 15, '0000630100FF', NULL, NULL),
	(1922, 'SUM', -4, 37, 0, 0, 7, 8, NULL, 1, NULL),
	(1923, 'TIME', -4, 164, 1, 0, 0, 0, '0', 0, NULL),
	(1924, 'TIME', -4, 165, 1, 0, 0, 0, '0', 0, NULL),
	(1925, 'TIME', 39, 164, 1, 0, 0, 0, NULL, 1, NULL),
	(1926, 'TIME', 143, 164, 1, 0, 0, 0, NULL, 1, NULL),
	(1927, 'TIME', 39, 165, 1, 0, 0, 0, NULL, 1, NULL),
	(1928, 'TIME', 143, 165, 1, 0, 0, 0, NULL, 1, NULL),
	(1929, 'TIME', 39, 229, 1, 0, 0, 0, NULL, 1, NULL),
	(1930, 'TIME', 143, 229, 1, 0, 0, 0, NULL, 1, NULL),
	(1931, 'TIME', 292, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(1932, 'TIME', 292, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(1934, 'CONFIGURATION', 143, 491, 16, 0, 0, 0, '0000630100FF', 1, NULL),
	(1935, 'SUMFIX', 140, 18, 0, 0, 3, 8, NULL, NULL, NULL),
	(1936, 'SUMFIX', 140, 18, 0, 0, 10, 8, NULL, NULL, NULL),
	(1937, 'SUMFIX', 140, 18, 0, 0, 12, 8, NULL, NULL, NULL),
	(1938, 'SUMFIX', 140, 257, 0, 0, 3, 8, NULL, NULL, NULL),
	(1939, 'SUMFIX', 140, 257, 0, 0, 10, 8, NULL, NULL, NULL),
	(1940, 'SUMFIX', 140, 257, 0, 0, 12, 8, NULL, NULL, NULL),
	(1941, 'SUMFIX', 140, 259, 0, 0, 3, 8, NULL, NULL, NULL),
	(1942, 'SUMFIX', 140, 259, 0, 0, 10, 8, NULL, NULL, NULL),
	(1943, 'SUMFIX', 140, 259, 0, 0, 12, 8, NULL, NULL, NULL),
	(1944, 'SUMFIX', 140, 260, 0, 0, 3, 8, NULL, NULL, NULL),
	(1945, 'SUMFIX', 140, 260, 0, 0, 10, 8, NULL, NULL, NULL),
	(1946, 'SUMFIX', 140, 260, 0, 0, 12, 8, NULL, NULL, NULL),
	(1947, 'SUMFIX', 209, 18, 0, 0, 3, 8, NULL, NULL, NULL),
	(1948, 'SUMFIX', 209, 18, 0, 0, 10, 8, NULL, NULL, NULL),
	(1949, 'SUMFIX', 209, 18, 0, 0, 12, 8, NULL, NULL, NULL),
	(1950, 'SUMFIX', 209, 257, 0, 0, 3, 8, NULL, NULL, NULL),
	(1951, 'SUMFIX', 209, 257, 0, 0, 10, 8, NULL, NULL, NULL),
	(1952, 'SUMFIX', 209, 257, 0, 0, 12, 8, NULL, NULL, NULL),
	(1953, 'SUMFIX', 209, 259, 0, 0, 3, 8, NULL, NULL, NULL),
	(1954, 'SUMFIX', 209, 259, 0, 0, 10, 8, NULL, NULL, NULL),
	(1955, 'SUMFIX', 209, 259, 0, 0, 12, 8, NULL, NULL, NULL),
	(1956, 'SUMFIX', 209, 260, 0, 0, 3, 8, NULL, NULL, NULL),
	(1957, 'SUMFIX', 209, 260, 0, 0, 10, 8, NULL, NULL, NULL),
	(1958, 'SUMFIX', 209, 260, 0, 0, 12, 8, NULL, NULL, NULL),
	(1959, 'PROFILE', 346, 37, 0, 0, 1, -1, '1', NULL, NULL),
	(1960, 'PROFILE', 346, 37, 0, 0, 2, -1, '1', NULL, NULL),
	(1961, 'PROFILE', 346, 37, 0, 0, 3, -1, '1', NULL, NULL),
	(1962, 'PROFILE', 346, 37, 0, 0, 4, -1, '1', NULL, NULL),
	(1963, 'PROFILE', 346, 37, 0, 0, 8, -1, '1', NULL, NULL),
	(1964, 'PROFILE', 346, 37, 0, 0, 9, -1, '1', NULL, NULL),
	(1965, 'PROFILE', 346, 37, 0, 0, 10, -1, '1', NULL, NULL),
	(1966, 'PROFILE', 346, 37, 0, 0, 11, -1, '1', NULL, NULL),
	(1967, 'PROFILE', 346, 37, 0, 0, 12, -1, '1', NULL, NULL),
	(1968, 'PROFILE', 346, 37, 0, 0, 13, -1, '1', NULL, NULL),
	(1969, 'MAXMON', 356, 490, 0, 0, 6, -1, '1', NULL, NULL),
	(1970, 'TIME', 353, 164, 1, 0, 0, 0, NULL, 0, NULL),
	(1971, 'TIME', 353, 165, 1, 0, 0, 0, NULL, 0, NULL),
	(1972, 'JOURNAL ALL', 353, 386, 2, 0, 0, 0, NULL, 1, NULL),
	(1973, 'JOURNALW', 353, 386, 22, 0, 0, 0, NULL, 1, NULL),
	(1974, 'MEASURES', 353, 386, 0, 0, -1, -1, NULL, 1, NULL),
	(1975, 'RELAY', 353, 386, 10010, 0, 0, 0, NULL, 1, NULL),
	(1976, 'TIME', 360, 229, 1, 0, 0, 0, NULL, NULL, NULL),
	(1977, 'TIME_CORRECTION', 359, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1978, 'TIME', 358, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(1979, 'TIME_CORRECTION', 360, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1980, 'TIME', 360, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(1981, 'TIME', 359, 229, 1, 0, 0, 0, NULL, NULL, NULL),
	(1982, 'TIME', 359, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(1983, 'TIME_CORRECTION', 362, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1984, 'TIME', 359, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(1985, 'TIME', 361, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(1986, 'TIME_CORRECTION', 360, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1987, 'TIME', 362, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(1988, 'TIME_CORRECTION', 362, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1989, 'TIME', 357, 229, 1, 0, 0, 0, NULL, NULL, NULL),
	(1990, 'TIME_CORRECTION', 361, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1991, 'TIME', 358, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(1992, 'TIME', 358, 229, 1, 0, 0, 0, NULL, NULL, NULL),
	(1993, 'TIME_CORRECTION', 357, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(1994, 'TIME_CORRECTION', 359, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(1995, 'TIME', 362, 229, 1, 0, 0, 0, NULL, NULL, NULL),
	(1996, 'TIME', 357, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(1997, 'TIME', 362, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(1998, 'TIME', 357, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(1999, 'TIME_CORRECTION', 357, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(2000, 'TIME', 361, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(2001, 'TIME_CORRECTION', 361, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(2002, 'TIME_CORRECTION', 358, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(2003, 'TIME_CORRECTION', 358, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(2004, 'TIME', 360, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(2005, 'TIME', 361, 229, 1, 0, 0, 0, NULL, NULL, NULL),
	(2006, 'TIME', 369, 164, 1, 0, 0, 0, '0', 1, NULL),
	(2007, 'TIME', 369, 165, 1, 0, 0, 0, '0', 1, NULL),
	(2008, 'METER_NUMBER_HOUR', 364, 489, 0, 0, 4, -1, NULL, NULL, NULL),
	(2009, 'MAXMON', 367, 490, 0, 0, 6, -1, '1', NULL, NULL),
	(2010, 'PROFILE', 367, 37, 0, 0, 3, -1, '1', NULL, NULL),
	(2011, 'PROFILE', 367, 37, 0, 0, 4, -1, '1', NULL, NULL),
	(2012, 'PROFILE', 367, 37, 0, 0, 12, -1, '1', NULL, NULL),
	(2013, 'TIME', 367, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(2014, 'TIME', 367, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(2015, 'WITHOUT SHEAF', 366, 106, 0, 0, -1, -1, NULL, NULL, NULL),
	(2016, 'WITHOUT SHEAF', 366, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(2017, 'TIME_CORRECTION', 374, 164, 14, 0, 0, 0, '5', 1, NULL),
	(2018, 'TIME_CORRECTION', 375, 164, 14, 0, 0, 0, '5', 1, NULL),
	(2019, 'TIME_CORRECTION', 376, 164, 14, 0, 0, 0, '5', 1, NULL),
	(2020, 'TIME_CORRECTION', 377, 164, 14, 0, 0, 0, '5', 0, NULL),
	(2021, 'TIME_CORRECTION', 374, 165, 14, 0, 0, 0, '1800', 1, NULL),
	(2022, 'TIME_CORRECTION', 375, 165, 14, 0, 0, 0, '1800', 1, NULL),
	(2023, 'TIME_CORRECTION', 376, 165, 14, 0, 0, 0, '1800', 1, NULL),
	(2024, 'TIME_CORRECTION', 377, 165, 14, 0, 0, 0, '1800', 0, NULL),
	(2025, 'TIME', 374, 164, 1, 0, 0, 0, '0', 1, NULL),
	(2026, 'TIME', 375, 164, 1, 0, 0, 0, '0', 1, NULL),
	(2027, 'TIME', 376, 164, 1, 0, 0, 0, '0', 1, NULL),
	(2028, 'TIME', 377, 164, 1, 0, 0, 0, '0', 0, NULL),
	(2029, 'TIME', 374, 165, 1, 0, 0, 0, '0', 1, NULL),
	(2030, 'TIME', 375, 165, 1, 0, 0, 0, '0', 1, NULL),
	(2031, 'TIME', 376, 165, 1, 0, 0, 0, '0', 1, NULL),
	(2032, 'TIME', 377, 165, 1, 0, 0, 0, '0', 0, NULL),
	(2033, 'WITHOUT SHEAF', 374, 18, 0, 0, -1, -1, NULL, 1, NULL),
	(2034, 'WITHOUT SHEAF', 375, 18, 0, 0, -1, -1, NULL, 1, NULL),
	(2035, 'WITHOUT SHEAF', 376, 18, 0, 0, -1, -1, NULL, 1, NULL),
	(2036, 'WITHOUT SHEAF', 377, 18, 0, 0, -1, -1, NULL, 1, NULL),
	(2037, 'Full Journal', 374, 18, 2, 0, 0, 0, NULL, 1, NULL),
	(2038, 'Full Journal', 375, 18, 2, 0, 0, 0, NULL, 1, NULL),
	(2039, 'Full Journal', 376, 18, 2, 0, 0, 0, NULL, 1, NULL),
	(2040, 'Full Journal', 377, 18, 2, 0, 0, 0, NULL, NULL, NULL),
	(2041, 'Full Journal', 374, 18, 19, 0, 0, 0, NULL, 1, NULL),
	(2042, 'Full Journal', 375, 18, 19, 0, 0, 0, NULL, 1, NULL),
	(2043, 'Full Journal', 376, 18, 19, 0, 0, 0, NULL, 1, NULL),
	(2044, 'Full Journal', 377, 18, 19, 0, 0, 0, NULL, NULL, NULL),
	(2045, 'Full Journal', 374, 18, 22, 0, 0, 0, NULL, 1, NULL),
	(2046, 'Full Journal', 375, 18, 22, 0, 0, 0, NULL, 1, NULL),
	(2047, 'Full Journal', 376, 18, 22, 0, 0, 0, NULL, 1, NULL),
	(2048, 'Full Journal', 377, 18, 22, 0, 0, 0, NULL, NULL, NULL),
	(2049, 'WITHOUT SHEAF', 374, 107, 0, 0, -1, -1, NULL, 1, NULL),
	(2050, 'WITHOUT SHEAF', 375, 107, 0, 0, -1, -1, NULL, 1, NULL),
	(2051, 'WITHOUT SHEAF', 376, 107, 0, 0, -1, -1, NULL, 1, NULL),
	(2052, 'WITHOUT SHEAF', 377, 107, 0, 0, -1, -1, NULL, 1, NULL),
	(2053, 'Full Journal', 374, 107, 2, 0, 0, 0, NULL, 1, NULL),
	(2054, 'Full Journal', 375, 107, 2, 0, 0, 0, NULL, 1, NULL),
	(2055, 'Full Journal', 376, 107, 2, 0, 0, 0, NULL, 1, NULL),
	(2056, 'Full Journal', 377, 107, 2, 0, 0, 0, NULL, NULL, NULL),
	(2057, 'Full Journal', 374, 107, 19, 0, 0, 0, NULL, 1, NULL),
	(2058, 'Full Journal', 375, 107, 19, 0, 0, 0, NULL, 1, NULL),
	(2059, 'Full Journal', 376, 107, 19, 0, 0, 0, NULL, 1, NULL),
	(2060, 'Full Journal', 377, 107, 19, 0, 0, 0, NULL, NULL, NULL),
	(2061, 'Full Journal', 374, 107, 22, 0, 0, 0, NULL, 1, NULL),
	(2062, 'Full Journal', 375, 107, 22, 0, 0, 0, NULL, 1, NULL),
	(2063, 'Full Journal', 376, 107, 22, 0, 0, 0, NULL, 1, NULL),
	(2064, 'Full Journal', 377, 107, 22, 0, 0, 0, NULL, NULL, NULL),
	(2065, 'WITHOUT SHEAF', 374, 403, 0, 0, -1, -1, '-1', 1, NULL),
	(2066, 'WITHOUT SHEAF', 375, 403, 0, 0, -1, -1, '-1', 1, NULL),
	(2067, 'WITHOUT SHEAF', 376, 403, 0, 0, -1, -1, '-1', 1, NULL),
	(2068, 'WITHOUT SHEAF', 377, 403, 0, 0, -1, -1, '-1', 1, NULL),
	(2069, 'WITHOUT SHEAF', 374, 425, 0, 0, -1, -1, '0', 1, NULL),
	(2070, 'WITHOUT SHEAF', 375, 425, 0, 0, -1, -1, '0', 1, NULL),
	(2071, 'WITHOUT SHEAF', 376, 425, 0, 0, -1, -1, '0', 1, NULL),
	(2072, 'WITHOUT SHEAF', 377, 425, 0, 0, -1, -1, '0', 1, NULL),
	(2073, 'Relay_1', 377, 322, 10010, 0, 0, 0, NULL, 1, NULL),
	(2074, 'Relay_2', 377, 322, 10011, 0, 0, 0, NULL, 1, NULL),
	(2075, 'WITHOUT SHEAF', 373, 18, 0, 0, -1, -1, NULL, 1, NULL),
	(2076, 'WITHOUT SHEAF', 373, 106, 0, 0, -1, -1, NULL, 1, NULL),
	(2077, 'TIME', 371, 229, 1, 0, 0, 0, NULL, 1, NULL),
	(2078, 'TIME', 372, 229, 1, 0, 0, 0, NULL, 1, NULL),
	(2079, 'TIME', 372, 164, 1, 0, 0, 0, NULL, 1, NULL),
	(2080, 'TIME', 370, 165, 1, 0, 0, 0, NULL, 1, NULL),
	(2081, 'TIME', 370, 164, 1, 0, 0, 0, NULL, 1, NULL),
	(2082, 'TIME', 371, 164, 1, 0, 0, 0, NULL, 1, NULL),
	(2083, 'TIME', 370, 229, 1, 0, 0, 0, NULL, 1, NULL),
	(2084, 'TIME', 372, 165, 1, 0, 0, 0, NULL, 1, NULL),
	(2085, 'TIME', 371, 165, 1, 0, 0, 0, NULL, 1, NULL),
	(2086, 'WITHOUT SHEAF', 370, 491, 0, 0, -1, -1, NULL, 1, NULL),
	(2087, 'WITHOUT SHEAF', 371, 491, 0, 0, -1, -1, NULL, 1, NULL),
	(2088, 'WITHOUT SHEAF', 372, 491, 0, 0, -1, -1, NULL, 1, NULL),
	(2089, 'METER JOURNAL', 370, 491, 2, 0, 0, 0, NULL, 1, NULL),
	(2090, 'METER JOURNAL', 371, 491, 2, 0, 0, 0, NULL, 1, NULL),
	(2091, 'METER JOURNAL', 372, 491, 2, 0, 0, 0, NULL, 1, NULL),
	(2092, 'JOURNAL', 370, 491, 22, 0, 0, 0, NULL, 1, NULL),
	(2093, 'JOURNAL', 371, 491, 22, 0, 0, 0, NULL, 1, NULL),
	(2094, 'JOURNAL', 372, 491, 22, 0, 0, 0, NULL, 1, NULL),
	(2095, 'WITHOUT SHEAF', 370, 257, 0, 0, -1, -1, NULL, 1, NULL),
	(2096, 'WITHOUT SHEAF', 371, 257, 0, 0, -1, -1, NULL, 1, NULL),
	(2097, 'WITHOUT SHEAF', 372, 257, 0, 0, -1, -1, NULL, 1, NULL),
	(2098, 'INSTANT', 370, 258, 0, 0, 7, 7, '2', 1, NULL),
	(2099, 'INSTANT', 371, 258, 0, 0, 7, 7, '2', 1, NULL),
	(2100, 'INSTANT', 372, 258, 0, 0, 7, 7, '2', 1, NULL),
	(2101, 'INSTANT_SUM', 370, 258, 0, 0, 7, 8, '2', 1, NULL),
	(2102, 'INSTANT_SUM', 371, 258, 0, 0, 7, 8, '2', 1, NULL),
	(2103, 'INSTANT_SUM', 372, 258, 0, 0, 7, 8, '2', 1, NULL),
	(2104, 'PROFILE', 370, 18, 0, 0, 1, 1, NULL, 1, NULL),
	(2105, 'PROFILE', 370, 18, 0, 0, 1, 7, NULL, 1, NULL),
	(2106, 'PROFILE', 370, 18, 0, 0, 1, 8, NULL, 1, NULL),
	(2107, 'PROFILE', 370, 18, 0, 0, 2, 2, NULL, 1, NULL),
	(2108, 'PROFILE', 370, 18, 0, 0, 2, 7, NULL, 1, NULL),
	(2109, 'PROFILE', 370, 18, 0, 0, 2, 8, NULL, 1, NULL),
	(2110, 'PROFILE', 370, 18, 0, 0, 3, 3, NULL, 1, NULL),
	(2111, 'PROFILE', 370, 18, 0, 0, 3, 7, NULL, 1, NULL),
	(2112, 'PROFILE', 370, 18, 0, 0, 3, 8, NULL, 1, NULL),
	(2113, 'PROFILE', 370, 18, 0, 0, 4, 1, NULL, 1, NULL),
	(2114, 'PROFILE', 370, 18, 0, 0, 4, 2, NULL, 1, NULL),
	(2115, 'PROFILE', 370, 18, 0, 0, 4, 4, NULL, 1, NULL),
	(2116, 'PROFILE', 370, 18, 0, 0, 4, 7, NULL, 1, NULL),
	(2117, 'PROFILE', 370, 18, 0, 0, 4, 8, NULL, 1, NULL),
	(2118, 'PROFILE', 370, 18, 0, 0, 4, 9, NULL, 1, NULL),
	(2119, 'PROFILE', 370, 18, 0, 0, 4, 10, NULL, 1, NULL),
	(2120, 'PROFILE', 370, 18, 0, 0, 4, 11, NULL, 1, NULL),
	(2121, 'PROFILE', 370, 18, 0, 0, 4, 12, NULL, 1, NULL),
	(2122, 'PROFILE', 370, 18, 0, 0, 5, 1, NULL, 1, NULL),
	(2123, 'PROFILE', 370, 18, 0, 0, 5, 2, NULL, 1, NULL),
	(2124, 'PROFILE', 370, 18, 0, 0, 5, 3, NULL, 1, NULL),
	(2125, 'PROFILE', 370, 18, 0, 0, 5, 4, NULL, 1, NULL),
	(2126, 'PROFILE', 370, 18, 0, 0, 5, 5, NULL, 1, NULL),
	(2127, 'PROFILE', 370, 18, 0, 0, 5, 7, NULL, 1, NULL),
	(2128, 'PROFILE', 370, 18, 0, 0, 5, 8, NULL, 1, NULL),
	(2129, 'PROFILE', 370, 18, 0, 0, 5, 9, NULL, 1, NULL),
	(2130, 'PROFILE', 370, 18, 0, 0, 5, 10, NULL, 1, NULL),
	(2131, 'PROFILE', 370, 18, 0, 0, 5, 11, NULL, 1, NULL),
	(2132, 'PROFILE', 370, 18, 0, 0, 5, 12, NULL, 1, NULL),
	(2133, 'PROFILE', 370, 18, 0, 0, 5, 13, NULL, 1, NULL),
	(2134, 'PROFILE', 370, 18, 0, 0, 5, 14, NULL, 1, NULL),
	(2135, 'PROFILE', 370, 18, 0, 0, 6, 1, NULL, 1, NULL),
	(2136, 'PROFILE', 370, 18, 0, 0, 6, 2, NULL, 1, NULL),
	(2137, 'PROFILE', 370, 18, 0, 0, 6, 3, NULL, 1, NULL),
	(2138, 'PROFILE', 370, 18, 0, 0, 6, 4, NULL, 1, NULL),
	(2139, 'PROFILE', 370, 18, 0, 0, 6, 5, NULL, 1, NULL),
	(2140, 'PROFILE', 370, 18, 0, 0, 6, 6, NULL, 1, NULL),
	(2141, 'PROFILE', 370, 18, 0, 0, 6, 7, NULL, 1, NULL),
	(2142, 'PROFILE', 370, 18, 0, 0, 6, 8, NULL, 1, NULL),
	(2143, 'PROFILE', 370, 18, 0, 0, 6, 9, NULL, 1, NULL),
	(2144, 'PROFILE', 370, 18, 0, 0, 6, 10, NULL, 1, NULL),
	(2145, 'PROFILE', 370, 18, 0, 0, 6, 11, NULL, 1, NULL),
	(2146, 'PROFILE', 370, 18, 0, 0, 6, 12, NULL, 1, NULL),
	(2147, 'PROFILE', 370, 18, 0, 0, 6, 13, NULL, 1, NULL),
	(2148, 'PROFILE', 370, 18, 0, 0, 6, 14, NULL, 1, NULL),
	(2149, 'PROFILE', 370, 18, 0, 0, 8, 7, NULL, 1, NULL),
	(2150, 'PROFILE', 370, 18, 0, 0, 8, 9, NULL, 1, NULL),
	(2151, 'PROFILE', 370, 18, 0, 0, 9, 10, NULL, 1, NULL),
	(2152, 'PROFILE', 370, 18, 0, 0, 10, 7, NULL, 1, NULL),
	(2153, 'PROFILE', 370, 18, 0, 0, 10, 8, NULL, 1, NULL),
	(2154, 'PROFILE', 370, 18, 0, 0, 10, 11, NULL, 1, NULL),
	(2155, 'PROFILE', 370, 18, 0, 0, 11, 12, NULL, 1, NULL),
	(2156, 'PROFILE', 370, 18, 0, 0, 12, 7, NULL, 1, NULL),
	(2157, 'PROFILE', 370, 18, 0, 0, 12, 8, NULL, 1, NULL),
	(2158, 'PROFILE', 370, 18, 0, 0, 12, 13, NULL, 1, NULL),
	(2159, 'PROFILE', 370, 18, 0, 0, 13, 8, NULL, 1, NULL),
	(2160, 'PROFILE', 370, 18, 0, 0, 13, 14, NULL, 1, NULL),
	(2161, 'PROFILE', 370, 18, 0, 0, 14, 15, NULL, 1, NULL),
	(2162, 'PROFILE', 370, 18, 0, 0, 15, 7, NULL, 1, NULL),
	(2163, 'PROFILE', 370, 18, 0, 0, 19, 7, NULL, 1, NULL),
	(2164, 'PROFILE', 370, 259, 0, 0, 1, 1, NULL, 1, NULL),
	(2165, 'PROFILE', 370, 259, 0, 0, 1, 7, NULL, 1, NULL),
	(2166, 'PROFILE', 370, 259, 0, 0, 1, 8, NULL, 1, NULL),
	(2167, 'PROFILE', 370, 259, 0, 0, 2, 2, NULL, 1, NULL),
	(2168, 'PROFILE', 370, 259, 0, 0, 2, 7, NULL, 1, NULL),
	(2169, 'PROFILE', 370, 259, 0, 0, 2, 8, NULL, 1, NULL),
	(2170, 'PROFILE', 370, 259, 0, 0, 3, 3, NULL, 1, NULL),
	(2171, 'PROFILE', 370, 259, 0, 0, 3, 7, NULL, 1, NULL),
	(2172, 'PROFILE', 370, 259, 0, 0, 3, 8, NULL, 1, NULL),
	(2173, 'PROFILE', 370, 259, 0, 0, 4, 1, NULL, 1, NULL),
	(2174, 'PROFILE', 370, 259, 0, 0, 4, 2, NULL, 1, NULL),
	(2175, 'PROFILE', 370, 259, 0, 0, 4, 4, NULL, 1, NULL),
	(2176, 'PROFILE', 370, 259, 0, 0, 4, 7, NULL, 1, NULL),
	(2177, 'PROFILE', 370, 259, 0, 0, 4, 8, NULL, 1, NULL),
	(2178, 'PROFILE', 370, 259, 0, 0, 4, 9, NULL, 1, NULL),
	(2179, 'PROFILE', 370, 259, 0, 0, 4, 10, NULL, 1, NULL),
	(2180, 'PROFILE', 370, 259, 0, 0, 4, 11, NULL, 1, NULL),
	(2181, 'PROFILE', 370, 259, 0, 0, 4, 12, NULL, 1, NULL),
	(2182, 'PROFILE', 370, 259, 0, 0, 5, 1, NULL, 1, NULL),
	(2183, 'PROFILE', 370, 259, 0, 0, 5, 2, NULL, 1, NULL),
	(2184, 'PROFILE', 370, 259, 0, 0, 5, 3, NULL, 1, NULL),
	(2185, 'PROFILE', 370, 259, 0, 0, 5, 4, NULL, 1, NULL),
	(2186, 'PROFILE', 370, 259, 0, 0, 5, 5, NULL, 1, NULL),
	(2187, 'PROFILE', 370, 259, 0, 0, 5, 7, NULL, 1, NULL),
	(2188, 'PROFILE', 370, 259, 0, 0, 5, 8, NULL, 1, NULL),
	(2189, 'PROFILE', 370, 259, 0, 0, 5, 9, NULL, 1, NULL),
	(2190, 'PROFILE', 370, 259, 0, 0, 5, 10, NULL, 1, NULL),
	(2191, 'PROFILE', 370, 259, 0, 0, 5, 11, NULL, 1, NULL),
	(2192, 'PROFILE', 370, 259, 0, 0, 5, 12, NULL, 1, NULL),
	(2193, 'PROFILE', 370, 259, 0, 0, 5, 13, NULL, 1, NULL),
	(2194, 'PROFILE', 370, 259, 0, 0, 5, 14, NULL, 1, NULL),
	(2195, 'PROFILE', 370, 259, 0, 0, 6, 1, NULL, 1, NULL),
	(2196, 'PROFILE', 370, 259, 0, 0, 6, 2, NULL, 1, NULL),
	(2197, 'PROFILE', 370, 259, 0, 0, 6, 3, NULL, 1, NULL),
	(2198, 'PROFILE', 370, 259, 0, 0, 6, 4, NULL, 1, NULL),
	(2199, 'PROFILE', 370, 259, 0, 0, 6, 5, NULL, 1, NULL),
	(2200, 'PROFILE', 370, 259, 0, 0, 6, 6, NULL, 1, NULL),
	(2201, 'PROFILE', 370, 259, 0, 0, 6, 7, NULL, 1, NULL),
	(2202, 'PROFILE', 370, 259, 0, 0, 6, 8, NULL, 1, NULL),
	(2203, 'PROFILE', 370, 259, 0, 0, 6, 9, NULL, 1, NULL),
	(2204, 'PROFILE', 370, 259, 0, 0, 6, 10, NULL, 1, NULL),
	(2205, 'PROFILE', 370, 259, 0, 0, 6, 11, NULL, 1, NULL),
	(2206, 'PROFILE', 370, 259, 0, 0, 6, 12, NULL, 1, NULL),
	(2207, 'PROFILE', 370, 259, 0, 0, 6, 13, NULL, 1, NULL),
	(2208, 'PROFILE', 370, 259, 0, 0, 6, 14, NULL, 1, NULL),
	(2209, 'PROFILE', 370, 259, 0, 0, 8, 7, NULL, 1, NULL),
	(2210, 'PROFILE', 370, 259, 0, 0, 8, 9, NULL, 1, NULL),
	(2211, 'PROFILE', 370, 259, 0, 0, 9, 10, NULL, 1, NULL),
	(2212, 'PROFILE', 370, 259, 0, 0, 10, 7, NULL, 1, NULL),
	(2213, 'PROFILE', 370, 259, 0, 0, 10, 8, NULL, 1, NULL),
	(2214, 'PROFILE', 370, 259, 0, 0, 10, 11, NULL, 1, NULL),
	(2215, 'PROFILE', 370, 259, 0, 0, 11, 12, NULL, 1, NULL),
	(2216, 'PROFILE', 370, 259, 0, 0, 12, 7, NULL, 1, NULL),
	(2217, 'PROFILE', 370, 259, 0, 0, 12, 8, NULL, 1, NULL),
	(2218, 'PROFILE', 370, 259, 0, 0, 12, 13, NULL, 1, NULL),
	(2219, 'PROFILE', 370, 259, 0, 0, 13, 8, NULL, 1, NULL),
	(2220, 'PROFILE', 370, 259, 0, 0, 13, 14, NULL, 1, NULL),
	(2221, 'PROFILE', 370, 259, 0, 0, 14, 15, NULL, 1, NULL),
	(2222, 'PROFILE', 370, 259, 0, 0, 15, 7, NULL, 1, NULL),
	(2223, 'PROFILE', 370, 259, 0, 0, 19, 7, NULL, 1, NULL),
	(2224, 'PROFILE', 371, 18, 0, 0, 1, 1, NULL, 1, NULL),
	(2225, 'PROFILE', 371, 18, 0, 0, 1, 7, NULL, 1, NULL),
	(2226, 'PROFILE', 371, 18, 0, 0, 1, 8, NULL, 1, NULL),
	(2227, 'PROFILE', 371, 18, 0, 0, 2, 2, NULL, 1, NULL),
	(2228, 'PROFILE', 371, 18, 0, 0, 2, 7, NULL, 1, NULL),
	(2229, 'PROFILE', 371, 18, 0, 0, 2, 8, NULL, 1, NULL),
	(2230, 'PROFILE', 371, 18, 0, 0, 3, 3, NULL, 1, NULL),
	(2231, 'PROFILE', 371, 18, 0, 0, 3, 7, NULL, 1, NULL),
	(2232, 'PROFILE', 371, 18, 0, 0, 3, 8, NULL, 1, NULL),
	(2233, 'PROFILE', 371, 18, 0, 0, 4, 1, NULL, 1, NULL),
	(2234, 'PROFILE', 371, 18, 0, 0, 4, 2, NULL, 1, NULL),
	(2235, 'PROFILE', 371, 18, 0, 0, 4, 4, NULL, 1, NULL),
	(2236, 'PROFILE', 371, 18, 0, 0, 4, 7, NULL, 1, NULL),
	(2237, 'PROFILE', 371, 18, 0, 0, 4, 8, NULL, 1, NULL),
	(2238, 'PROFILE', 371, 18, 0, 0, 4, 9, NULL, 1, NULL),
	(2239, 'PROFILE', 371, 18, 0, 0, 4, 10, NULL, 1, NULL),
	(2240, 'PROFILE', 371, 18, 0, 0, 4, 11, NULL, 1, NULL),
	(2241, 'PROFILE', 371, 18, 0, 0, 4, 12, NULL, 1, NULL),
	(2242, 'PROFILE', 371, 18, 0, 0, 5, 1, NULL, 1, NULL),
	(2243, 'PROFILE', 371, 18, 0, 0, 5, 2, NULL, 1, NULL),
	(2244, 'PROFILE', 371, 18, 0, 0, 5, 3, NULL, 1, NULL),
	(2245, 'PROFILE', 371, 18, 0, 0, 5, 4, NULL, 1, NULL),
	(2246, 'PROFILE', 371, 18, 0, 0, 5, 5, NULL, 1, NULL),
	(2247, 'PROFILE', 371, 18, 0, 0, 5, 7, NULL, 1, NULL),
	(2248, 'PROFILE', 371, 18, 0, 0, 5, 8, NULL, 1, NULL),
	(2249, 'PROFILE', 371, 18, 0, 0, 5, 9, NULL, 1, NULL),
	(2250, 'PROFILE', 371, 18, 0, 0, 5, 10, NULL, 1, NULL),
	(2251, 'PROFILE', 371, 18, 0, 0, 5, 11, NULL, 1, NULL),
	(2252, 'PROFILE', 371, 18, 0, 0, 5, 12, NULL, 1, NULL),
	(2253, 'PROFILE', 371, 18, 0, 0, 5, 13, NULL, 1, NULL),
	(2254, 'PROFILE', 371, 18, 0, 0, 5, 14, NULL, 1, NULL),
	(2255, 'PROFILE', 371, 18, 0, 0, 6, 1, NULL, 1, NULL),
	(2256, 'PROFILE', 371, 18, 0, 0, 6, 2, NULL, 1, NULL),
	(2257, 'PROFILE', 371, 18, 0, 0, 6, 3, NULL, 1, NULL),
	(2258, 'PROFILE', 371, 18, 0, 0, 6, 4, NULL, 1, NULL),
	(2259, 'PROFILE', 371, 18, 0, 0, 6, 5, NULL, 1, NULL),
	(2260, 'PROFILE', 371, 18, 0, 0, 6, 6, NULL, 1, NULL),
	(2261, 'PROFILE', 371, 18, 0, 0, 6, 7, NULL, 1, NULL),
	(2262, 'PROFILE', 371, 18, 0, 0, 6, 8, NULL, 1, NULL),
	(2263, 'PROFILE', 371, 18, 0, 0, 6, 9, NULL, 1, NULL),
	(2264, 'PROFILE', 371, 18, 0, 0, 6, 10, NULL, 1, NULL),
	(2265, 'PROFILE', 371, 18, 0, 0, 6, 11, NULL, 1, NULL),
	(2266, 'PROFILE', 371, 18, 0, 0, 6, 12, NULL, 1, NULL),
	(2267, 'PROFILE', 371, 18, 0, 0, 6, 13, NULL, 1, NULL),
	(2268, 'PROFILE', 371, 18, 0, 0, 6, 14, NULL, 1, NULL),
	(2269, 'PROFILE', 371, 18, 0, 0, 8, 7, NULL, 1, NULL),
	(2270, 'PROFILE', 371, 18, 0, 0, 8, 9, NULL, 1, NULL),
	(2271, 'PROFILE', 371, 18, 0, 0, 9, 10, NULL, 1, NULL),
	(2272, 'PROFILE', 371, 18, 0, 0, 10, 7, NULL, 1, NULL),
	(2273, 'PROFILE', 371, 18, 0, 0, 10, 8, NULL, 1, NULL),
	(2274, 'PROFILE', 371, 18, 0, 0, 10, 11, NULL, 1, NULL),
	(2275, 'PROFILE', 371, 18, 0, 0, 11, 12, NULL, 1, NULL),
	(2276, 'PROFILE', 371, 18, 0, 0, 12, 7, NULL, 1, NULL),
	(2277, 'PROFILE', 371, 18, 0, 0, 12, 8, NULL, 1, NULL),
	(2278, 'PROFILE', 371, 18, 0, 0, 12, 13, NULL, 1, NULL),
	(2279, 'PROFILE', 371, 18, 0, 0, 13, 8, NULL, 1, NULL),
	(2280, 'PROFILE', 371, 18, 0, 0, 13, 14, NULL, 1, NULL),
	(2281, 'PROFILE', 371, 18, 0, 0, 14, 15, NULL, 1, NULL),
	(2282, 'PROFILE', 371, 18, 0, 0, 15, 7, NULL, 1, NULL),
	(2283, 'PROFILE', 371, 18, 0, 0, 19, 7, NULL, 1, NULL),
	(2284, 'PROFILE', 371, 259, 0, 0, 1, 1, NULL, 1, NULL),
	(2285, 'PROFILE', 371, 259, 0, 0, 1, 7, NULL, 1, NULL),
	(2286, 'PROFILE', 371, 259, 0, 0, 1, 8, NULL, 1, NULL),
	(2287, 'PROFILE', 371, 259, 0, 0, 2, 2, NULL, 1, NULL),
	(2288, 'PROFILE', 371, 259, 0, 0, 2, 7, NULL, 1, NULL),
	(2289, 'PROFILE', 371, 259, 0, 0, 2, 8, NULL, 1, NULL),
	(2290, 'PROFILE', 371, 259, 0, 0, 3, 3, NULL, 1, NULL),
	(2291, 'PROFILE', 371, 259, 0, 0, 3, 7, NULL, 1, NULL),
	(2292, 'PROFILE', 371, 259, 0, 0, 3, 8, NULL, 1, NULL),
	(2293, 'PROFILE', 371, 259, 0, 0, 4, 1, NULL, 1, NULL),
	(2294, 'PROFILE', 371, 259, 0, 0, 4, 2, NULL, 1, NULL),
	(2295, 'PROFILE', 371, 259, 0, 0, 4, 4, NULL, 1, NULL),
	(2296, 'PROFILE', 371, 259, 0, 0, 4, 7, NULL, 1, NULL),
	(2297, 'PROFILE', 371, 259, 0, 0, 4, 8, NULL, 1, NULL),
	(2298, 'PROFILE', 371, 259, 0, 0, 4, 9, NULL, 1, NULL),
	(2299, 'PROFILE', 371, 259, 0, 0, 4, 10, NULL, 1, NULL),
	(2300, 'PROFILE', 371, 259, 0, 0, 4, 11, NULL, 1, NULL),
	(2301, 'PROFILE', 371, 259, 0, 0, 4, 12, NULL, 1, NULL),
	(2302, 'PROFILE', 371, 259, 0, 0, 5, 1, NULL, 1, NULL),
	(2303, 'PROFILE', 371, 259, 0, 0, 5, 2, NULL, 1, NULL),
	(2304, 'PROFILE', 371, 259, 0, 0, 5, 3, NULL, 1, NULL),
	(2305, 'PROFILE', 371, 259, 0, 0, 5, 4, NULL, 1, NULL),
	(2306, 'PROFILE', 371, 259, 0, 0, 5, 5, NULL, 1, NULL),
	(2307, 'PROFILE', 371, 259, 0, 0, 5, 7, NULL, 1, NULL),
	(2308, 'PROFILE', 371, 259, 0, 0, 5, 8, NULL, 1, NULL),
	(2309, 'PROFILE', 371, 259, 0, 0, 5, 9, NULL, 1, NULL),
	(2310, 'PROFILE', 371, 259, 0, 0, 5, 10, NULL, 1, NULL),
	(2311, 'PROFILE', 371, 259, 0, 0, 5, 11, NULL, 1, NULL),
	(2312, 'PROFILE', 371, 259, 0, 0, 5, 12, NULL, 1, NULL),
	(2313, 'PROFILE', 371, 259, 0, 0, 5, 13, NULL, 1, NULL),
	(2314, 'PROFILE', 371, 259, 0, 0, 5, 14, NULL, 1, NULL),
	(2315, 'PROFILE', 371, 259, 0, 0, 6, 1, NULL, 1, NULL),
	(2316, 'PROFILE', 371, 259, 0, 0, 6, 2, NULL, 1, NULL),
	(2317, 'PROFILE', 371, 259, 0, 0, 6, 3, NULL, 1, NULL),
	(2318, 'PROFILE', 371, 259, 0, 0, 6, 4, NULL, 1, NULL),
	(2319, 'PROFILE', 371, 259, 0, 0, 6, 5, NULL, 1, NULL),
	(2320, 'PROFILE', 371, 259, 0, 0, 6, 6, NULL, 1, NULL),
	(2321, 'PROFILE', 371, 259, 0, 0, 6, 7, NULL, 1, NULL),
	(2322, 'PROFILE', 371, 259, 0, 0, 6, 8, NULL, 1, NULL),
	(2323, 'PROFILE', 371, 259, 0, 0, 6, 9, NULL, 1, NULL),
	(2324, 'PROFILE', 371, 259, 0, 0, 6, 10, NULL, 1, NULL),
	(2325, 'PROFILE', 371, 259, 0, 0, 6, 11, NULL, 1, NULL),
	(2326, 'PROFILE', 371, 259, 0, 0, 6, 12, NULL, 1, NULL),
	(2327, 'PROFILE', 371, 259, 0, 0, 6, 13, NULL, 1, NULL),
	(2328, 'PROFILE', 371, 259, 0, 0, 6, 14, NULL, 1, NULL),
	(2329, 'PROFILE', 371, 259, 0, 0, 8, 7, NULL, 1, NULL),
	(2330, 'PROFILE', 371, 259, 0, 0, 8, 9, NULL, 1, NULL),
	(2331, 'PROFILE', 371, 259, 0, 0, 9, 10, NULL, 1, NULL),
	(2332, 'PROFILE', 371, 259, 0, 0, 10, 7, NULL, 1, NULL),
	(2333, 'PROFILE', 371, 259, 0, 0, 10, 8, NULL, 1, NULL),
	(2334, 'PROFILE', 371, 259, 0, 0, 10, 11, NULL, 1, NULL),
	(2335, 'PROFILE', 371, 259, 0, 0, 11, 12, NULL, 1, NULL),
	(2336, 'PROFILE', 371, 259, 0, 0, 12, 7, NULL, 1, NULL),
	(2337, 'PROFILE', 371, 259, 0, 0, 12, 8, NULL, 1, NULL),
	(2338, 'PROFILE', 371, 259, 0, 0, 12, 13, NULL, 1, NULL),
	(2339, 'PROFILE', 371, 259, 0, 0, 13, 8, NULL, 1, NULL),
	(2340, 'PROFILE', 371, 259, 0, 0, 13, 14, NULL, 1, NULL),
	(2341, 'PROFILE', 371, 259, 0, 0, 14, 15, NULL, 1, NULL),
	(2342, 'PROFILE', 371, 259, 0, 0, 15, 7, NULL, 1, NULL),
	(2343, 'PROFILE', 371, 259, 0, 0, 19, 7, NULL, 1, NULL),
	(2344, 'PROFILE', 372, 18, 0, 0, 1, 1, NULL, 1, NULL),
	(2345, 'PROFILE', 372, 18, 0, 0, 1, 7, NULL, 1, NULL),
	(2346, 'PROFILE', 372, 18, 0, 0, 1, 8, NULL, 1, NULL),
	(2347, 'PROFILE', 372, 18, 0, 0, 2, 2, NULL, 1, NULL),
	(2348, 'PROFILE', 372, 18, 0, 0, 2, 7, NULL, 1, NULL),
	(2349, 'PROFILE', 372, 18, 0, 0, 2, 8, NULL, 1, NULL),
	(2350, 'PROFILE', 372, 18, 0, 0, 3, 3, NULL, 1, NULL),
	(2351, 'PROFILE', 372, 18, 0, 0, 3, 7, NULL, 1, NULL),
	(2352, 'PROFILE', 372, 18, 0, 0, 3, 8, NULL, 1, NULL),
	(2353, 'PROFILE', 372, 18, 0, 0, 4, 1, NULL, 1, NULL),
	(2354, 'PROFILE', 372, 18, 0, 0, 4, 2, NULL, 1, NULL),
	(2355, 'PROFILE', 372, 18, 0, 0, 4, 4, NULL, 1, NULL),
	(2356, 'PROFILE', 372, 18, 0, 0, 4, 7, NULL, 1, NULL),
	(2357, 'PROFILE', 372, 18, 0, 0, 4, 8, NULL, 1, NULL),
	(2358, 'PROFILE', 372, 18, 0, 0, 4, 9, NULL, 1, NULL),
	(2359, 'PROFILE', 372, 18, 0, 0, 4, 10, NULL, 1, NULL),
	(2360, 'PROFILE', 372, 18, 0, 0, 4, 11, NULL, 1, NULL),
	(2361, 'PROFILE', 372, 18, 0, 0, 4, 12, NULL, 1, NULL),
	(2362, 'PROFILE', 372, 18, 0, 0, 5, 1, NULL, 1, NULL),
	(2363, 'PROFILE', 372, 18, 0, 0, 5, 2, NULL, 1, NULL),
	(2364, 'PROFILE', 372, 18, 0, 0, 5, 3, NULL, 1, NULL),
	(2365, 'PROFILE', 372, 18, 0, 0, 5, 4, NULL, 1, NULL),
	(2366, 'PROFILE', 372, 18, 0, 0, 5, 5, NULL, 1, NULL),
	(2367, 'PROFILE', 372, 18, 0, 0, 5, 7, NULL, 1, NULL),
	(2368, 'PROFILE', 372, 18, 0, 0, 5, 8, NULL, 1, NULL),
	(2369, 'PROFILE', 372, 18, 0, 0, 5, 9, NULL, 1, NULL),
	(2370, 'PROFILE', 372, 18, 0, 0, 5, 10, NULL, 1, NULL),
	(2371, 'PROFILE', 372, 18, 0, 0, 5, 11, NULL, 1, NULL),
	(2372, 'PROFILE', 372, 18, 0, 0, 5, 12, NULL, 1, NULL),
	(2373, 'PROFILE', 372, 18, 0, 0, 5, 13, NULL, 1, NULL),
	(2374, 'PROFILE', 372, 18, 0, 0, 5, 14, NULL, 1, NULL),
	(2375, 'PROFILE', 372, 18, 0, 0, 6, 1, NULL, 1, NULL),
	(2376, 'PROFILE', 372, 18, 0, 0, 6, 2, NULL, 1, NULL),
	(2377, 'PROFILE', 372, 18, 0, 0, 6, 3, NULL, 1, NULL),
	(2378, 'PROFILE', 372, 18, 0, 0, 6, 4, NULL, 1, NULL),
	(2379, 'PROFILE', 372, 18, 0, 0, 6, 5, NULL, 1, NULL),
	(2380, 'PROFILE', 372, 18, 0, 0, 6, 6, NULL, 1, NULL),
	(2381, 'PROFILE', 372, 18, 0, 0, 6, 7, NULL, 1, NULL),
	(2382, 'PROFILE', 372, 18, 0, 0, 6, 8, NULL, 1, NULL),
	(2383, 'PROFILE', 372, 18, 0, 0, 6, 9, NULL, 1, NULL),
	(2384, 'PROFILE', 372, 18, 0, 0, 6, 10, NULL, 1, NULL),
	(2385, 'PROFILE', 372, 18, 0, 0, 6, 11, NULL, 1, NULL),
	(2386, 'PROFILE', 372, 18, 0, 0, 6, 12, NULL, 1, NULL),
	(2387, 'PROFILE', 372, 18, 0, 0, 6, 13, NULL, 1, NULL),
	(2388, 'PROFILE', 372, 18, 0, 0, 6, 14, NULL, 1, NULL),
	(2389, 'PROFILE', 372, 18, 0, 0, 8, 7, NULL, 1, NULL),
	(2390, 'PROFILE', 372, 18, 0, 0, 8, 9, NULL, 1, NULL),
	(2391, 'PROFILE', 372, 18, 0, 0, 9, 10, NULL, 1, NULL),
	(2392, 'PROFILE', 372, 18, 0, 0, 10, 7, NULL, 1, NULL),
	(2393, 'PROFILE', 372, 18, 0, 0, 10, 8, NULL, 1, NULL),
	(2394, 'PROFILE', 372, 18, 0, 0, 10, 11, NULL, 1, NULL),
	(2395, 'PROFILE', 372, 18, 0, 0, 11, 12, NULL, 1, NULL),
	(2396, 'PROFILE', 372, 18, 0, 0, 12, 7, NULL, 1, NULL),
	(2397, 'PROFILE', 372, 18, 0, 0, 12, 8, NULL, 1, NULL),
	(2398, 'PROFILE', 372, 18, 0, 0, 12, 13, NULL, 1, NULL),
	(2399, 'PROFILE', 372, 18, 0, 0, 13, 8, NULL, 1, NULL),
	(2400, 'PROFILE', 372, 18, 0, 0, 13, 14, NULL, 1, NULL),
	(2401, 'PROFILE', 372, 18, 0, 0, 14, 15, NULL, 1, NULL),
	(2402, 'PROFILE', 372, 18, 0, 0, 15, 7, NULL, 1, NULL),
	(2403, 'PROFILE', 372, 18, 0, 0, 19, 7, NULL, 1, NULL),
	(2404, 'PROFILE', 372, 259, 0, 0, 1, 1, NULL, 1, NULL),
	(2405, 'PROFILE', 372, 259, 0, 0, 1, 7, NULL, 1, NULL),
	(2406, 'PROFILE', 372, 259, 0, 0, 1, 8, NULL, 1, NULL),
	(2407, 'PROFILE', 372, 259, 0, 0, 2, 2, NULL, 1, NULL),
	(2408, 'PROFILE', 372, 259, 0, 0, 2, 7, NULL, 1, NULL),
	(2409, 'PROFILE', 372, 259, 0, 0, 2, 8, NULL, 1, NULL),
	(2410, 'PROFILE', 372, 259, 0, 0, 3, 3, NULL, 1, NULL),
	(2411, 'PROFILE', 372, 259, 0, 0, 3, 7, NULL, 1, NULL),
	(2412, 'PROFILE', 372, 259, 0, 0, 3, 8, NULL, 1, NULL),
	(2413, 'PROFILE', 372, 259, 0, 0, 4, 1, NULL, 1, NULL),
	(2414, 'PROFILE', 372, 259, 0, 0, 4, 2, NULL, 1, NULL),
	(2415, 'PROFILE', 372, 259, 0, 0, 4, 4, NULL, 1, NULL),
	(2416, 'PROFILE', 372, 259, 0, 0, 4, 7, NULL, 1, NULL),
	(2417, 'PROFILE', 372, 259, 0, 0, 4, 8, NULL, 1, NULL),
	(2418, 'PROFILE', 372, 259, 0, 0, 4, 9, NULL, 1, NULL),
	(2419, 'PROFILE', 372, 259, 0, 0, 4, 10, NULL, 1, NULL),
	(2420, 'PROFILE', 372, 259, 0, 0, 4, 11, NULL, 1, NULL),
	(2421, 'PROFILE', 372, 259, 0, 0, 4, 12, NULL, 1, NULL),
	(2422, 'PROFILE', 372, 259, 0, 0, 5, 1, NULL, 1, NULL),
	(2423, 'PROFILE', 372, 259, 0, 0, 5, 2, NULL, 1, NULL),
	(2424, 'PROFILE', 372, 259, 0, 0, 5, 3, NULL, 1, NULL),
	(2425, 'PROFILE', 372, 259, 0, 0, 5, 4, NULL, 1, NULL),
	(2426, 'PROFILE', 372, 259, 0, 0, 5, 5, NULL, 1, NULL),
	(2427, 'PROFILE', 372, 259, 0, 0, 5, 7, NULL, 1, NULL),
	(2428, 'PROFILE', 372, 259, 0, 0, 5, 8, NULL, 1, NULL),
	(2429, 'PROFILE', 372, 259, 0, 0, 5, 9, NULL, 1, NULL),
	(2430, 'PROFILE', 372, 259, 0, 0, 5, 10, NULL, 1, NULL),
	(2431, 'PROFILE', 372, 259, 0, 0, 5, 11, NULL, 1, NULL),
	(2432, 'PROFILE', 372, 259, 0, 0, 5, 12, NULL, 1, NULL),
	(2433, 'PROFILE', 372, 259, 0, 0, 5, 13, NULL, 1, NULL),
	(2434, 'PROFILE', 372, 259, 0, 0, 5, 14, NULL, 1, NULL),
	(2435, 'PROFILE', 372, 259, 0, 0, 6, 1, NULL, 1, NULL),
	(2436, 'PROFILE', 372, 259, 0, 0, 6, 2, NULL, 1, NULL),
	(2437, 'PROFILE', 372, 259, 0, 0, 6, 3, NULL, 1, NULL),
	(2438, 'PROFILE', 372, 259, 0, 0, 6, 4, NULL, 1, NULL),
	(2439, 'PROFILE', 372, 259, 0, 0, 6, 5, NULL, 1, NULL),
	(2440, 'PROFILE', 372, 259, 0, 0, 6, 6, NULL, 1, NULL),
	(2441, 'PROFILE', 372, 259, 0, 0, 6, 7, NULL, 1, NULL),
	(2442, 'PROFILE', 372, 259, 0, 0, 6, 8, NULL, 1, NULL),
	(2443, 'PROFILE', 372, 259, 0, 0, 6, 9, NULL, 1, NULL),
	(2444, 'PROFILE', 372, 259, 0, 0, 6, 10, NULL, 1, NULL),
	(2445, 'PROFILE', 372, 259, 0, 0, 6, 11, NULL, 1, NULL),
	(2446, 'PROFILE', 372, 259, 0, 0, 6, 12, NULL, 1, NULL),
	(2447, 'PROFILE', 372, 259, 0, 0, 6, 13, NULL, 1, NULL),
	(2448, 'PROFILE', 372, 259, 0, 0, 6, 14, NULL, 1, NULL),
	(2449, 'PROFILE', 372, 259, 0, 0, 8, 7, NULL, 1, NULL),
	(2450, 'PROFILE', 372, 259, 0, 0, 8, 9, NULL, 1, NULL),
	(2451, 'PROFILE', 372, 259, 0, 0, 9, 10, NULL, 1, NULL),
	(2452, 'PROFILE', 372, 259, 0, 0, 10, 7, NULL, 1, NULL),
	(2453, 'PROFILE', 372, 259, 0, 0, 10, 8, NULL, 1, NULL),
	(2454, 'PROFILE', 372, 259, 0, 0, 10, 11, NULL, 1, NULL),
	(2455, 'PROFILE', 372, 259, 0, 0, 11, 12, NULL, 1, NULL),
	(2456, 'PROFILE', 372, 259, 0, 0, 12, 7, NULL, 1, NULL),
	(2457, 'PROFILE', 372, 259, 0, 0, 12, 8, NULL, 1, NULL),
	(2458, 'PROFILE', 372, 259, 0, 0, 12, 13, NULL, 1, NULL),
	(2459, 'PROFILE', 372, 259, 0, 0, 13, 8, NULL, 1, NULL),
	(2460, 'PROFILE', 372, 259, 0, 0, 13, 14, NULL, 1, NULL),
	(2461, 'PROFILE', 372, 259, 0, 0, 14, 15, NULL, 1, NULL),
	(2462, 'PROFILE', 372, 259, 0, 0, 15, 7, NULL, 1, NULL),
	(2463, 'PROFILE', 372, 259, 0, 0, 19, 7, NULL, 1, NULL),
	(2467, 'TIME', 352, 164, 1, 0, 0, 0, '0', NULL, NULL),
	(2468, 'TIME', 352, 165, 1, 0, 0, 0, '0', NULL, NULL),
	(2469, 'WITHOUT SHEAF', 352, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(2470, 'WITHOUT SHEAF', 379, 491, 0, 0, -1, -1, NULL, 1, NULL),
	(2471, 'WITHOUT SHEAF', 379, 18, 0, 0, -1, -1, NULL, 1, NULL),
	(2472, 'WITHOUT SHEAF', 379, 259, 0, 0, -1, -1, NULL, 1, NULL),
	(2473, 'WITHOUT SHEAF', 365, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(2474, 'WITHOUT SHEAF', 365, 323, 0, 0, -1, -1, NULL, NULL, NULL),
	(2477, 'TIME_CORRECTION', 200, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(2478, 'TIME_CORRECTION', 200, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(2479, 'WITHOUT SHEAF', 363, 18, 0, 0, -1, -1, NULL, 1, NULL),
	(2480, 'PROFILE', 363, 37, 0, 0, 1, 1, '1', 1, NULL),
	(2481, 'PROFILE', 363, 37, 0, 0, 3, 3, '1', 1, NULL),
	(2482, 'PROFILE', 363, 37, 0, 0, 4, 4, '1', 1, NULL),
	(2483, 'PROFILE', 363, 37, 0, 0, 10, 11, '1', 1, NULL),
	(2484, 'PROFILE', 363, 37, 0, 0, 12, 13, '1', 1, NULL),
	(2485, 'SUM', 363, 530, 0, 0, 5, 8, '0', 1, NULL),
	(2486, 'SUM', 363, 530, 0, 0, 6, 8, '0', 1, NULL),
	(2487, 'SUM', 363, 530, 0, 0, 7, 8, '0', 1, NULL),
	(2488, 'TIME', 363, 164, 1, 0, 0, 0, '0', 0, NULL),
	(2489, 'TIME', 363, 165, 1, 0, 0, 0, '0', 0, NULL),
	(2490, 'SHEAFS', 139, 255, 1, 0, 0, 0, NULL, NULL, NULL),
	(2491, 'SHEAFS', 139, 255, 2, 0, 0, 0, NULL, NULL, NULL),
	(2492, 'SHEAFS', 139, 255, 16, 0, 0, 0, NULL, 1, NULL),
	(2493, 'SHEAFS', 139, 255, 22, 0, 0, 0, NULL, NULL, NULL),
	(2494, 'SHEAFS', 139, 255, 10010, 0, 0, 0, NULL, NULL, NULL),
	(2495, 'SHEAFS', 139, 255, 10011, 0, 0, 0, NULL, NULL, NULL),
	(2496, 'SHEAFS', 139, 255, 10951, 0, 0, 0, NULL, NULL, NULL),
	(2503, 'ALL', 139, 255, 0, 0, -1, -1, NULL, NULL, NULL),
	(2507, 'PROFILE', 337, 18, 0, 0, 1, 1, NULL, 1, NULL),
	(2508, 'PROFILE', 337, 18, 0, 0, 1, 7, NULL, 1, NULL),
	(2509, 'PROFILE', 337, 18, 0, 0, 1, 8, NULL, 1, NULL),
	(2510, 'PROFILE', 337, 18, 0, 0, 2, 2, NULL, 1, NULL),
	(2511, 'PROFILE', 337, 18, 0, 0, 2, 7, NULL, 1, NULL),
	(2512, 'PROFILE', 337, 18, 0, 0, 2, 8, NULL, 1, NULL),
	(2513, 'PROFILE', 337, 18, 0, 0, 3, 3, NULL, 1, NULL),
	(2514, 'PROFILE', 337, 18, 0, 0, 3, 7, NULL, 1, NULL),
	(2515, 'PROFILE', 337, 18, 0, 0, 3, 8, NULL, 1, NULL),
	(2516, 'PROFILE', 337, 18, 0, 0, 4, 1, NULL, 1, NULL),
	(2517, 'PROFILE', 337, 18, 0, 0, 4, 2, NULL, 1, NULL),
	(2518, 'PROFILE', 337, 18, 0, 0, 4, 4, NULL, 1, NULL),
	(2519, 'PROFILE', 337, 18, 0, 0, 4, 7, NULL, 1, NULL),
	(2520, 'PROFILE', 337, 18, 0, 0, 4, 8, NULL, 1, NULL),
	(2521, 'PROFILE', 337, 18, 0, 0, 4, 9, NULL, 1, NULL),
	(2522, 'PROFILE', 337, 18, 0, 0, 4, 10, NULL, 1, NULL),
	(2523, 'PROFILE', 337, 18, 0, 0, 4, 11, NULL, 1, NULL),
	(2524, 'PROFILE', 337, 18, 0, 0, 4, 12, NULL, 1, NULL),
	(2525, 'PROFILE', 337, 18, 0, 0, 8, 7, NULL, 1, NULL),
	(2526, 'PROFILE', 337, 18, 0, 0, 8, 9, NULL, 1, NULL),
	(2527, 'PROFILE', 337, 18, 0, 0, 9, 10, NULL, 1, NULL),
	(2528, 'PROFILE', 337, 18, 0, 0, 10, 7, NULL, 1, NULL),
	(2529, 'PROFILE', 337, 18, 0, 0, 10, 8, NULL, 1, NULL),
	(2530, 'PROFILE', 337, 18, 0, 0, 10, 11, NULL, 1, NULL),
	(2531, 'PROFILE', 337, 18, 0, 0, 11, 12, NULL, 1, NULL),
	(2532, 'PROFILE', 337, 18, 0, 0, 12, 7, NULL, 1, NULL),
	(2533, 'PROFILE', 337, 18, 0, 0, 12, 8, NULL, 1, NULL),
	(2534, 'PROFILE', 337, 18, 0, 0, 12, 13, NULL, 1, NULL),
	(2535, 'PROFILE', 337, 18, 0, 0, 13, 8, NULL, 1, NULL),
	(2536, 'PROFILE', 337, 18, 0, 0, 13, 14, NULL, 1, NULL),
	(2537, 'PROFILE', 337, 18, 0, 0, 14, 15, NULL, 1, NULL),
	(2538, 'PROFILE', 337, 18, 0, 0, 15, 7, NULL, 1, NULL),
	(2539, 'PROFILE', 337, 18, 0, 0, 19, 7, NULL, 1, NULL),
	(2540, 'PROFILE', 337, 257, 0, 0, -1, -1, NULL, 1, NULL),
	(2541, 'PROFILE', 337, 258, 0, 0, -1, -1, NULL, 1, NULL),
	(2542, 'PROFILE', 337, 259, 0, 0, -1, -1, NULL, 1, NULL),
	(2543, 'PROFILE', 337, 491, 0, 0, -1, -1, NULL, 1, NULL),
	(2544, 'EN_FIX', 249, 18, 0, 0, 10, 8, NULL, 1, NULL),
	(2545, 'EN_FIX', 249, 18, 0, 0, 3, 8, NULL, 1, NULL),
	(2546, 'EN_FIX', 249, 18, 0, 0, 2, 8, NULL, 1, NULL),
	(2547, 'EN_FIX', 249, 18, 0, 0, 12, 8, NULL, 1, NULL),
	(2548, 'EN_FIX', 249, 18, 0, 0, 4, 8, NULL, 1, NULL),
	(2549, 'EN_FIX', 249, 18, 0, 0, 13, 8, NULL, 1, NULL),
	(2550, 'EN_FIX', 249, 18, 0, 0, 11, 8, NULL, 1, NULL),
	(2551, 'EN_FIX', 249, 18, 0, 0, 1, 8, NULL, 1, NULL),
	(2552, 'ALL', 249, 256, 0, 0, -1, -1, NULL, 1, NULL),
	(2553, 'ALL', 249, 257, 0, 0, -1, -1, NULL, 1, NULL),
	(2554, 'TIME', 382, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(2555, 'TIME_CORRECTION', 382, 164, 14, 0, 0, 0, '5', NULL, NULL),
	(2556, 'TIME', 382, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(2557, 'TIME_CORRECTION', 382, 165, 14, 0, 0, 0, '1800', NULL, NULL),
	(2558, 'TIME', 382, 229, 1, 0, 0, 0, NULL, NULL, NULL),
	(2559, 'ALL', 382, 256, 0, 0, -1, -1, NULL, 1, NULL),
	(2560, 'ALL', 382, 257, 0, 0, -1, -1, NULL, 1, NULL),
	(2561, 'WITHOUT SHEAF', 200, 533, 0, 0, -1, -1, NULL, NULL, NULL),
	(2562, 'WITHOUT SHEAF', 381, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(2563, 'TIME', 381, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(2564, 'TIME', 381, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(2565, 'WITHOUT SHEAF', 385, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(2566, 'WITHOUT SHEAF', 386, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(2567, 'WITHOUT SHEAF', 387, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(2568, 'TIME', 385, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(2569, 'TIME', 385, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(2570, 'TIME', 386, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(2571, 'TIME', 386, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(2572, 'TIME', 387, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(2573, 'TIME', 387, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(2574, 'MEASURES', 384, 18, 0, 0, -1, -1, NULL, NULL, NULL),
	(2575, 'DISCRETE', 384, 18, 0, -1, 0, 0, NULL, NULL, NULL),
	(2576, 'WITHOUT SHEAF', 384, 534, 0, 0, -1, -1, NULL, NULL, NULL),
	(2577, 'TIME', 384, 164, 1, 0, 0, 0, NULL, NULL, NULL),
	(2578, 'TIME', 384, 165, 1, 0, 0, 0, NULL, NULL, NULL),
	(2579, 'MEASURES', 384, 535, 0, 0, -1, -1, NULL, NULL, NULL),
	(2580, 'MEASURES', 381, 535, 0, 0, -1, -1, NULL, NULL, NULL),
	(2581, 'MEASURES', 385, 535, 0, 0, -1, -1, NULL, NULL, NULL),
	(2582, 'MEASURES', 386, 535, 0, 0, -1, -1, NULL, NULL, NULL),
	(2583, 'MEASURES', 387, 535, 0, 0, -1, -1, NULL, NULL, NULL);
/*!40000 ALTER TABLE `src_type_lpty_filter` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_lpty_opty
CREATE TABLE IF NOT EXISTS `src_type_lpty_opty` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `lpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Ryšio modulių savybės identifikatorius',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  PRIMARY KEY (`src_type_id`,`lpty_id`,`opty_id`),
  KEY `src_type_lpty_opty_lpty_fk` (`lpty_id`),
  KEY `src_type_lpty_opty_opty_fk` (`opty_id`),
  CONSTRAINT `src_type_lpty_opty_lpty_fk` FOREIGN KEY (`lpty_id`) REFERENCES `lpty` (`lpty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_lpty_opty_opty_fk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_lpty_opty_src_type_fk` FOREIGN KEY (`src_type_id`) REFERENCES `src_type` (`src_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Automatinio ryšio modulių savybių panaudojimo duomenų įrašymo į prietaisą užsakymuose konfigūracija';

-- Dumping data for table emcor.src_type_lpty_opty: ~5 rows (approximately)
/*!40000 ALTER TABLE `src_type_lpty_opty` DISABLE KEYS */;
INSERT INTO `src_type_lpty_opty` (`src_type_id`, `lpty_id`, `opty_id`) VALUES
	(140, 339, 16),
	(209, 339, 16),
	(232, 431, 12),
	(248, 431, 12),
	(306, 437, 37);
/*!40000 ALTER TABLE `src_type_lpty_opty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mlf
CREATE TABLE IF NOT EXISTS `src_type_mlf` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `mlf_id` tinyint(3) unsigned NOT NULL COMMENT 'Matavimų klasifikatoriaus lauko, naudojamo duomenų surinkime, identifikatorius',
  PRIMARY KEY (`src_type_id`,`mlf_id`),
  KEY `src_type_mlf_mlf_fk` (`mlf_id`),
  CONSTRAINT `src_type_mlf_mlf_fk` FOREIGN KEY (`mlf_id`) REFERENCES `mlf` (`mlf_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_mlf_type_fk` FOREIGN KEY (`src_type_id`) REFERENCES `src_type` (`src_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Matavimų klasifikatoriaus laukai, naudojami nuskaitant duomenis per atitinkamus šaltinių tipus';

-- Dumping data for table emcor.src_type_mlf: ~6 rows (approximately)
/*!40000 ALTER TABLE `src_type_mlf` DISABLE KEYS */;
INSERT INTO `src_type_mlf` (`src_type_id`, `mlf_id`) VALUES
	(202, 4),
	(202, 5),
	(202, 6),
	(290, 4),
	(290, 5),
	(290, 6);
/*!40000 ALTER TABLE `src_type_mlf` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod
CREATE TABLE IF NOT EXISTS `src_type_mod` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `version_dependent` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Priklausomybė nuo versijos',
  `typecode_dependent` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Priklausomybė nuo tipo kodo',
  `src_type_mod_desc` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  PRIMARY KEY (`src_type_id`,`src_type_mod_nr`),
  CONSTRAINT `src_type_mod_src_type_fk` FOREIGN KEY (`src_type_id`) REFERENCES `src_type` (`src_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų šaltinių tipų modifikacijos';

-- Dumping data for table emcor.src_type_mod: ~123 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod` DISABLE KEYS */;
INSERT INTO `src_type_mod` (`src_type_id`, `src_type_mod_nr`, `version_dependent`, `typecode_dependent`, `src_type_mod_desc`) VALUES
	(1, 1, 0, 0, 'LZQM'),
	(24, 1, 0, 0, 'GEM'),
	(25, 1, 1, 0, 'EMS, version < $30'),
	(25, 2, 1, 0, 'EMS, $30<=version<=$50'),
	(25, 3, 1, 0, 'EMS, $50<version<=$F0'),
	(30, 1, 0, 0, 'EPQM'),
	(33, 1, 0, 0, 'EPQS'),
	(35, 1, 0, 0, 'Mercury_230'),
	(39, 1, 0, 0, NULL),
	(51, 1, 0, 0, 'LZKM'),
	(68, 1, 0, 0, 'SET_4TM'),
	(69, 1, 0, 0, 'PSC_4TM'),
	(79, 1, 0, 0, 'SET_4TM_01'),
	(81, 1, 0, 0, NULL),
	(103, 1, 0, 0, NULL),
	(127, 1, 0, 0, 'GAMA'),
	(135, 1, 1, 0, 'Version<7'),
	(135, 2, 1, 0, 'Version>=7'),
	(137, 1, 1, 0, 'Version<=3.6'),
	(137, 2, 1, 0, 'Version>=3.8'),
	(139, 1, 1, 0, 'ADD_ADDAX, Version <7.5'),
	(139, 2, 1, 0, 'ADD_ADDAX, Version >=7.5'),
	(140, 1, 0, 0, NULL),
	(143, 1, 0, 0, NULL),
	(145, 1, 1, 1, 'CE102 R8Q, Version 1-2'),
	(145, 2, 1, 1, 'CE102 S7, Version 1-5'),
	(145, 3, 1, 1, 'CE102 R8, Version 1-5'),
	(145, 4, 1, 1, 'CE102 S7J, Version 5'),
	(145, 5, 1, 1, 'CE301M S31, Version=1'),
	(145, 6, 1, 1, 'CE301M_R33, Version=1'),
	(145, 7, 1, 1, 'CE102 S6, Version 1-4'),
	(145, 8, 1, 1, 'CE102 R5, Version 1-4'),
	(145, 9, 1, 1, 'CE102 S7, Version 6'),
	(145, 10, 1, 1, 'CE102 R8, Version 6'),
	(145, 11, 1, 1, 'CE102 S7J, Version 6'),
	(154, 1, 0, 0, NULL),
	(157, 1, 0, 0, 'Pafal EA52'),
	(162, 1, 0, 0, 'MDC, Version 1'),
	(181, 1, 0, 0, 'MDC_EPQS, Version 1'),
	(182, 1, 0, 0, 'MDC_EPQM, Version 1'),
	(183, 1, 0, 0, 'MDC_EMS, Version 1'),
	(184, 1, 0, 0, 'MDC_GAMA, Version 1'),
	(185, 1, 0, 0, NULL),
	(188, 1, 0, 0, NULL),
	(189, 1, 0, 0, NULL),
	(197, 1, 1, 0, 'Version<=3.6'),
	(197, 2, 1, 0, 'Version>=3.8'),
	(200, 1, 0, 0, NULL),
	(203, 1, 0, 0, 'RiM_099'),
	(205, 1, 0, 0, NULL),
	(206, 1, 0, 0, NULL),
	(207, 1, 1, 0, 'Version<7'),
	(207, 2, 1, 0, 'Version>=7'),
	(208, 1, 1, 1, 'CE102 R8Q, Version 1-2'),
	(208, 2, 1, 1, 'CE102 S7, Version 1-5'),
	(208, 3, 1, 1, 'CE102 R8, Version 1-5'),
	(208, 4, 1, 1, 'CE102 S7J, Version 5'),
	(208, 5, 1, 1, 'CE301M S31, Version=1'),
	(208, 6, 1, 1, 'CE301M_R33, Version=1'),
	(208, 7, 1, 1, 'CE102 S6, Version 1-4'),
	(208, 8, 1, 1, 'CE102 R5, Version 1-4'),
	(208, 9, 1, 1, 'CE102 S7, Version 6'),
	(208, 10, 1, 1, 'CE102 R8, Version 6'),
	(208, 11, 1, 1, 'CE102 S7J, Version 6'),
	(209, 1, 0, 0, NULL),
	(210, 1, 0, 0, 'SPT961'),
	(215, 1, 0, 0, NULL),
	(232, 1, 0, 0, NULL),
	(234, 1, 0, 0, 'ESMON'),
	(243, 1, 0, 0, 'USPD 164-01B [DLL]'),
	(244, 1, 1, 0, 'Saiman-1000, Version <7.11'),
	(244, 2, 1, 0, 'Saiman-1000, Version >=7.11'),
	(248, 1, 0, 0, NULL),
	(249, 1, 0, 0, 'NIK 2303'),
	(251, 1, 0, 0, 'MIR S-03'),
	(252, 1, 0, 0, 'CLOU_CL7331'),
	(253, 1, 0, 0, 'MCL 5.8'),
	(255, 1, 0, 0, 'MCL 5.5'),
	(256, 1, 0, 0, 'MCL 5.0'),
	(257, 1, 0, 0, 'CYBLE'),
	(283, 1, 0, 0, 'Saiman_ORMAN_PLC'),
	(284, 1, 0, 0, 'Saiman ORMAN, DALA [ModBus]'),
	(285, 1, 0, 0, 'MCL 5.8.5'),
	(287, 1, 0, 0, 'TS_11'),
	(288, 1, 0, 0, 'Saiman_ORMAN_PLC'),
	(290, 1, 0, 0, 'SEM_2_ESC'),
	(291, 1, 0, 0, 'KSPD_x'),
	(292, 1, 1, 1, 'Version <=$32, generation 0'),
	(292, 2, 1, 1, 'Version >$32, generation 1'),
	(292, 3, 1, 1, 'Version >$32, generation 2'),
	(296, 1, 0, 0, 'EK_270'),
	(299, 1, 0, 0, NULL),
	(303, 1, 0, 0, NULL),
	(306, 1, 0, 0, NULL),
	(337, 1, 0, 0, 'Wasion_aMeter_x'),
	(338, 1, 0, 0, 'Katra_SKU_03'),
	(346, 1, 0, 0, 'CLOU_DLT645'),
	(348, 1, 0, 0, NULL),
	(349, 1, 0, 0, NULL),
	(352, 1, 0, 0, NULL),
	(353, 1, 0, 0, NULL),
	(356, 1, 0, 0, NULL),
	(357, 1, 0, 0, 'Mercury_230_AR'),
	(358, 1, 0, 0, 'Mercury_231'),
	(359, 1, 0, 0, 'Mercury_232'),
	(360, 1, 0, 0, 'Mercury_233'),
	(361, 1, 0, 0, 'Mercury_234'),
	(362, 1, 0, 0, 'Mercury_236'),
	(363, 1, 0, 0, NULL),
	(367, 1, 0, 0, 'MIT_5000_MG_CLOU_DLT645'),
	(369, 1, 0, 0, NULL),
	(370, 1, 0, 0, NULL),
	(371, 1, 0, 0, NULL),
	(372, 1, 0, 0, NULL),
	(373, 1, 0, 0, NULL),
	(377, 1, 0, 0, 'USPD_CE805M'),
	(379, 1, 0, 0, NULL),
	(382, 1, 0, 0, 'NIK_2303E'),
	(383, 1, 0, 0, 'MCL 5.10'),
	(384, 1, 0, 0, NULL),
	(385, 1, 0, 0, NULL),
	(386, 1, 0, 0, NULL),
	(387, 1, 0, 0, NULL);
/*!40000 ALTER TABLE `src_type_mod` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod_dw_impl#cfg
CREATE TABLE IF NOT EXISTS `src_type_mod_dw_impl#cfg` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `enr` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus elemento numeris',
  `src_type_mod_impl_code` varchar(80) COLLATE utf8_bin NOT NULL COMMENT 'Šaltinių tipo modifikacijos implementacijos kodas',
  `sep_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `dw_v` varbinary(1024) DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų reikšmė',
  PRIMARY KEY (`src_type_id`,`src_type_mod_nr`,`withe_id`,`ind1`,`ind2`,`ind3`,`src_type_mod_impl_code`,`enr`),
  KEY `src_type_mod_dw_impl#cfg_sep_i` (`sep_id`),
  CONSTRAINT `src_type_mod_dw_impl#cfg_sfk` FOREIGN KEY (`sep_id`) REFERENCES `sep` (`sep_id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Nuskaitymo taškų konfigūracinių masyvinių parametrų elementų reikšmės pagal implementaciją';

-- Dumping data for table emcor.src_type_mod_dw_impl#cfg: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod_dw_impl#cfg` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_type_mod_dw_impl#cfg` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod_dw_impl_cfg
CREATE TABLE IF NOT EXISTS `src_type_mod_dw_impl_cfg` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `src_type_mod_impl_code` varchar(80) COLLATE utf8_bin NOT NULL COMMENT 'Šaltinių tipo modifikacijos implementacijos kodas',
  `sep_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `dw_v` varbinary(1024) DEFAULT NULL COMMENT 'Nuskaitymo taško vytelės duomenų reikšmė',
  PRIMARY KEY (`src_type_id`,`src_type_mod_nr`,`withe_id`,`src_type_mod_impl_code`),
  KEY `src_type_mod_dw_impl_cfg_sep_i` (`sep_id`),
  CONSTRAINT `src_type_mod_dw_impl_cfg_sfk` FOREIGN KEY (`sep_id`) REFERENCES `sep` (`sep_id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Nuskaitymo taškų konfigūracinių parametrų reikšmės pagal implementaciją';

-- Dumping data for table emcor.src_type_mod_dw_impl_cfg: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod_dw_impl_cfg` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_type_mod_dw_impl_cfg` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod_keys
CREATE TABLE IF NOT EXISTS `src_type_mod_keys` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `version_text` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'Versijos raktas',
  `typecode_text` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Tipo kodo raktas',
  KEY `src_type_mod_keys_src_type_i` (`src_type_id`,`src_type_mod_nr`),
  CONSTRAINT `src_type_mod_keys_src_type_fk` FOREIGN KEY (`src_type_id`, `src_type_mod_nr`) REFERENCES `src_type_mod` (`src_type_id`, `src_type_mod_nr`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų šaltinių tipų modifikacijų raktų reikšmės';

-- Dumping data for table emcor.src_type_mod_keys: ~40 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod_keys` DISABLE KEYS */;
INSERT INTO `src_type_mod_keys` (`src_type_id`, `src_type_mod_nr`, `version_text`, `typecode_text`) VALUES
	(292, 3, '^(5[0-9]|[6-9][0-9]|[1-9][0-9][0-9])$', '^(5[0-9]|[6-9][0-9]|[1-9][0-9][0-9]).(9|1[4-6]|3[2-4])$'),
	(244, 1, '^([7].[0][0-9]|[7].[1][0]|[1-6].[0-9][0-9])$', NULL),
	(244, 2, '^([7].[1][1-9]|[7].[2-9][0-9]|[8-9].[0-9][0-9])$', NULL),
	(139, 1, '^([7].[0-4][0-9]*|[1-6].[0-9]*|[1-7])$', NULL),
	(139, 2, '^([7].[5-9][0-9]*)$', NULL),
	(145, 9, '^[6]|[6].[0-9]$', '2'),
	(145, 10, '^[6]|[6].[0-9]$', '5'),
	(145, 11, '^[6]|[6].[0-9]$', '3'),
	(208, 9, '^[6]|[6].[0-9]$', '2'),
	(208, 10, '^[6]|[6].[0-9]$', '5'),
	(208, 11, '^[6]|[6].[0-9]$', '3'),
	(25, 1, '^([0-9]|[1-3][0-9]|4[0-7])$', NULL),
	(25, 2, '^(4[89]|[5-7][0-9]|80)$', NULL),
	(25, 3, '^(8[1-9]|9[0-9]|1[0-9]{2}|2[0-3][0-9]|240)$', NULL),
	(145, 2, '^[1-5]|[1-5].[0-9]$', '2'),
	(145, 3, '^[1-5]|[1-5].[0-9]$', '5'),
	(145, 4, '^[5]|[5].[0-9]$', '3'),
	(145, 5, '^[1]|[1].[0-9]$', '7'),
	(145, 6, '^[1]|[1].[0-9]$', '8'),
	(145, 7, '^[1-4]|[1-4].[0-9]$', '1'),
	(145, 8, '^[1-4]|[1-4].[0-9]$', '4'),
	(135, 1, '^[1-6]|[1-6].[0-9]$', NULL),
	(208, 2, '^[1-5]|[1-5].[0-9]$', '2'),
	(208, 3, '^[1-5]|[1-5].[0-9]$', '5'),
	(208, 4, '^[5]|[5].[0-9]$', '3'),
	(208, 5, '^[1]|[1].[0-9]$', '7'),
	(208, 6, '^[1]|[1].[0-9]$', '8'),
	(208, 7, '^[1-4]|[1-4].[0-9]$', '1'),
	(208, 8, '^[1-4]|[1-4].[0-9]$', '4'),
	(135, 2, '^[7]|[7].[0-9]$', NULL),
	(145, 1, '^[1-2]|[1-2].[0-9]$', '6'),
	(208, 1, '^[1-2]|[1-2].[0-9]$', '6'),
	(207, 1, '^[1-6]|[1-6].[0-9]$', NULL),
	(207, 2, '^[7]|[7].[0-9]$', NULL),
	(137, 1, '^([0-2].[0-9]{1,2}|3.[0-6])[ab].*$', NULL),
	(197, 1, '^([0-2].[0-9]{1,2}|3.[0-6])[ab].*$', NULL),
	(137, 2, '^([4-9].[0-9]{1,2}|3.([89]|[1-9][0-9]))[ab].*$', NULL),
	(197, 2, '^([4-9].[0-9]{1,2}|3.([89]|[1-9][0-9]))[ab].*$', NULL),
	(292, 1, '^([0-9]|[1-4][0-9])$', '^([0-9]|[1-4][0-9]).([1-4]|12|13|17|18)$'),
	(292, 2, '^(5[0-9]|[6-9][0-9]|[1-9][0-9][0-9])$', '^(5[0-9]|[6-9][0-9]|[1-9][0-9][0-9]).(7|8)$');
/*!40000 ALTER TABLE `src_type_mod_keys` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod_pw_impl#cfg
CREATE TABLE IF NOT EXISTS `src_type_mod_pw_impl#cfg` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `enr` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus elemento numeris',
  `src_type_mod_impl_code` varchar(80) COLLATE utf8_bin NOT NULL COMMENT 'Šaltinių tipo modifikacijos implementacijos kodas',
  `sep_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `pw_v` varbinary(1024) DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų reikšmė',
  PRIMARY KEY (`src_type_id`,`src_type_mod_nr`,`withe_id`,`ind1`,`ind2`,`ind3`,`src_type_mod_impl_code`,`enr`),
  KEY `src_type_mod_pw_impl#cfg_sep_i` (`sep_id`),
  CONSTRAINT `src_type_mod_pw_impl#cfg_sfk` FOREIGN KEY (`sep_id`) REFERENCES `sep` (`sep_id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Taškų konfigūracinių masyvinių parametrų elementų reikšmės pagal implementaciją';

-- Dumping data for table emcor.src_type_mod_pw_impl#cfg: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod_pw_impl#cfg` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_type_mod_pw_impl#cfg` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod_pw_impl_cfg
CREATE TABLE IF NOT EXISTS `src_type_mod_pw_impl_cfg` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `src_type_mod_impl_code` varchar(80) COLLATE utf8_bin NOT NULL COMMENT 'Šaltinių tipo modifikacijos implementacijos kodas',
  `sep_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `pw_v` varbinary(1024) DEFAULT NULL COMMENT 'Matavimo taško vytelės duomenų reikšmė',
  PRIMARY KEY (`src_type_id`,`src_type_mod_nr`,`withe_id`,`src_type_mod_impl_code`),
  KEY `src_type_mod_pw_impl_cfg_sep_i` (`sep_id`),
  CONSTRAINT `src_type_mod_pw_impl_cfg_sfk` FOREIGN KEY (`sep_id`) REFERENCES `sep` (`sep_id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Taškų konfigūracinių parametrų reikšmės pagal implementaciją';

-- Dumping data for table emcor.src_type_mod_pw_impl_cfg: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod_pw_impl_cfg` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_type_mod_pw_impl_cfg` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod_withe
CREATE TABLE IF NOT EXISTS `src_type_mod_withe` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `is_point` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `dt_id` tinyint(3) unsigned NOT NULL COMMENT 'Duomenų tipo identifikatorius',
  `ind1_cnt` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmo indekso dimensija',
  `ind1_code` varchar(40) COLLATE utf8_bin DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmo indekso kodas',
  `ind2_cnt` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antro indekso dimensija',
  `ind2_code` varchar(40) COLLATE utf8_bin DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antro indekso kodas',
  `ind3_cnt` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečio indekso dimensija',
  `ind3_code` varchar(40) COLLATE utf8_bin DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečio indekso kodas',
  `enr_cnt` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus dimensija',
  `readable` tinyint(1) DEFAULT NULL COMMENT 'Požymis, ar galimas nuskaitymas',
  `writable` tinyint(1) DEFAULT NULL COMMENT 'Požymis, ar galimas įrašymas',
  `omit_value` tinyint(1) DEFAULT NULL COMMENT 'Požymis, ar neįtraukti <Value>',
  `cidl` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Požymis, ar parametro pakeitimas sukelia rodmenų numetimą',
  PRIMARY KEY (`src_type_id`,`src_type_mod_nr`,`is_point`,`withe_id`),
  KEY `src_type_mod_withe_dt_fk` (`dt_id`),
  KEY `src_type_mod_withe_withe_fk` (`withe_id`),
  CONSTRAINT `src_type_mod_withe_dt_fk` FOREIGN KEY (`dt_id`) REFERENCES `dt` (`dt_id`),
  CONSTRAINT `src_type_mod_withe_mod_fk` FOREIGN KEY (`src_type_id`, `src_type_mod_nr`) REFERENCES `src_type_mod` (`src_type_id`, `src_type_mod_nr`) ON DELETE CASCADE,
  CONSTRAINT `src_type_mod_withe_withe_fk` FOREIGN KEY (`withe_id`) REFERENCES `withe` (`withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Informacija apie prietaisų modifikacijų konfigūracinius parametrus';

-- Dumping data for table emcor.src_type_mod_withe: ~3 806 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod_withe` DISABLE KEYS */;
INSERT INTO `src_type_mod_withe` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`, `dt_id`, `ind1_cnt`, `ind1_code`, `ind2_cnt`, `ind2_code`, `ind3_cnt`, `ind3_code`, `enr_cnt`, `readable`, `writable`, `omit_value`, `cidl`) VALUES
	(1, 1, 1, -50181, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(1, 1, 1, -50058, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(1, 1, 1, -50057, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(1, 1, 1, -50055, 3, 5, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 1),
	(1, 1, 1, -50054, 3, NULL, NULL, NULL, NULL, NULL, NULL, 5, NULL, NULL, NULL, 1),
	(1, 1, 1, -50053, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(1, 1, 1, -50052, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(1, 1, 1, -50051, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(1, 1, 1, -50050, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(1, 1, 1, -50049, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(1, 1, 1, -50048, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(1, 1, 1, -50047, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(1, 1, 1, -50046, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(1, 1, 1, -50045, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(1, 1, 1, -50044, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(1, 1, 1, -50043, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(1, 1, 1, -50042, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(1, 1, 1, -50041, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(1, 1, 1, -50040, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(1, 1, 1, -50038, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(1, 1, 1, -50037, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(1, 1, 1, -50036, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(1, 1, 1, -50035, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(1, 1, 1, -50034, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(1, 1, 1, -50033, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(1, 1, 1, -50020, 2, 5, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 1),
	(1, 1, 1, -50019, 3, 5, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 1),
	(1, 1, 1, -50018, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(1, 1, 1, -50017, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(1, 1, 1, -50016, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(1, 1, 1, -50015, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(1, 1, 1, -50014, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(1, 1, 1, -50013, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(1, 1, 1, -50012, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(1, 1, 1, -50011, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(1, 1, 1, -50008, 3, NULL, NULL, NULL, NULL, NULL, NULL, 5, NULL, NULL, NULL, 1),
	(1, 1, 1, -50005, 5, NULL, NULL, NULL, NULL, NULL, NULL, 372, NULL, NULL, NULL, 1),
	(1, 1, 1, -50004, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(1, 1, 1, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(1, 1, 1, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(1, 1, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(1, 1, 1, -3, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(1, 1, 1, 10690, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(1, 1, 1, 10691, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(1, 1, 1, 10692, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(1, 1, 1, 10693, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(1, 1, 1, 10695, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(1, 1, 1, 10696, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(1, 1, 1, 10697, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(1, 1, 1, 10698, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(24, 1, 1, -50032, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(24, 1, 1, -50031, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(24, 1, 1, -50030, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(24, 1, 1, -50029, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(24, 1, 1, -50028, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(24, 1, 1, -50027, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(24, 1, 1, -50020, 2, 15, 'Index', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(24, 1, 1, -50019, 3, 15, 'Index', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(24, 1, 1, -50018, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(24, 1, 1, -50017, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(24, 1, 1, -50016, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(24, 1, 1, -50015, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(24, 1, 1, -50014, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(24, 1, 1, -50013, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(24, 1, 1, -50012, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(24, 1, 1, -50011, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(24, 1, 1, -50010, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(24, 1, 1, -50008, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(24, 1, 1, -50006, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(24, 1, 1, -50005, 5, NULL, NULL, NULL, NULL, NULL, NULL, 372, NULL, NULL, NULL, 0),
	(24, 1, 1, -50004, 3, 2, 'Index', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(24, 1, 1, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(24, 1, 1, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(24, 1, 1, -50001, 4, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(24, 1, 1, -50000, 4, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(24, 1, 1, -15, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(24, 1, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(24, 1, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(24, 1, 1, -3, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 1, 1, -50055, 3, 5, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 1),
	(25, 1, 1, -50054, 3, NULL, NULL, NULL, NULL, NULL, NULL, 5, NULL, NULL, NULL, 1),
	(25, 1, 1, -50028, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 1, 1, -50027, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 1, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(25, 1, 1, -50025, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(25, 1, 1, -50024, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, 0, NULL, 0),
	(25, 1, 1, -50023, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 1, 1, -50022, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 1, 1, -50020, 2, 5, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 1),
	(25, 1, 1, -50019, 3, 5, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 1),
	(25, 1, 1, -50018, 2, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(25, 1, 1, -50017, 2, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(25, 1, 1, -50016, 2, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(25, 1, 1, -50015, 2, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(25, 1, 1, -50014, 2, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(25, 1, 1, -50013, 2, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(25, 1, 1, -50012, 2, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(25, 1, 1, -50011, 2, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(25, 1, 1, -50008, 3, NULL, NULL, NULL, NULL, NULL, NULL, 5, NULL, NULL, NULL, 1),
	(25, 1, 1, -50005, 5, NULL, NULL, NULL, NULL, NULL, NULL, 372, NULL, NULL, NULL, 1),
	(25, 1, 1, -50004, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(25, 1, 1, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(25, 1, 1, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(25, 1, 1, -50001, 4, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(25, 1, 1, -50000, 4, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(25, 1, 1, -15, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 1, 1, -13, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, 0, NULL, 1),
	(25, 1, 1, -10, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(25, 1, 1, -9, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(25, 1, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(25, 1, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 1, 1, -3, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 2, 1, -50028, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 2, 1, -50027, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 2, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(25, 2, 1, -50025, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(25, 2, 1, -50024, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, 0, NULL, 0),
	(25, 2, 1, -50023, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 2, 1, -50022, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 2, 1, -50020, 2, 16, 'Index', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 1),
	(25, 2, 1, -50019, 3, 16, 'Index', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 1),
	(25, 2, 1, -50018, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(25, 2, 1, -50017, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(25, 2, 1, -50016, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(25, 2, 1, -50015, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(25, 2, 1, -50014, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(25, 2, 1, -50013, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(25, 2, 1, -50012, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(25, 2, 1, -50011, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(25, 2, 1, -50010, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 1),
	(25, 2, 1, -50008, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 1),
	(25, 2, 1, -50006, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 1),
	(25, 2, 1, -50005, 5, NULL, NULL, NULL, NULL, NULL, NULL, 372, NULL, NULL, NULL, 1),
	(25, 2, 1, -50004, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(25, 2, 1, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(25, 2, 1, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(25, 2, 1, -50001, 4, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(25, 2, 1, -50000, 4, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(25, 2, 1, -15, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 2, 1, -13, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, 0, NULL, 1),
	(25, 2, 1, -10, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(25, 2, 1, -9, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(25, 2, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(25, 2, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 2, 1, -3, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 3, 1, -50032, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 3, 1, -50031, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 3, 1, -50030, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 3, 1, -50029, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 3, 1, -50028, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 3, 1, -50027, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 3, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(25, 3, 1, -50025, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(25, 3, 1, -50024, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, 0, NULL, 0),
	(25, 3, 1, -50023, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 3, 1, -50022, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 3, 1, -50020, 2, 16, 'Index', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 1),
	(25, 3, 1, -50019, 3, 16, 'Index', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 1),
	(25, 3, 1, -50018, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(25, 3, 1, -50017, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(25, 3, 1, -50016, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(25, 3, 1, -50015, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(25, 3, 1, -50014, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(25, 3, 1, -50013, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(25, 3, 1, -50012, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(25, 3, 1, -50011, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(25, 3, 1, -50010, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 1),
	(25, 3, 1, -50008, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 1),
	(25, 3, 1, -50006, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 1),
	(25, 3, 1, -50005, 5, NULL, NULL, NULL, NULL, NULL, NULL, 372, NULL, NULL, NULL, 1),
	(25, 3, 1, -50004, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(25, 3, 1, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(25, 3, 1, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(25, 3, 1, -50001, 4, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(25, 3, 1, -50000, 4, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(25, 3, 1, -15, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 3, 1, -13, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, 0, NULL, 1),
	(25, 3, 1, -10, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(25, 3, 1, -9, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(25, 3, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(25, 3, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(25, 3, 1, -3, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(30, 1, 1, -50181, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(30, 1, 1, -50058, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(30, 1, 1, -50057, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(30, 1, 1, -50055, 3, 5, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 1),
	(30, 1, 1, -50054, 3, NULL, NULL, NULL, NULL, NULL, NULL, 5, NULL, NULL, NULL, 1),
	(30, 1, 1, -50053, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(30, 1, 1, -50052, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(30, 1, 1, -50051, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(30, 1, 1, -50050, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(30, 1, 1, -50049, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(30, 1, 1, -50048, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(30, 1, 1, -50047, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(30, 1, 1, -50046, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(30, 1, 1, -50045, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(30, 1, 1, -50044, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(30, 1, 1, -50043, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(30, 1, 1, -50042, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(30, 1, 1, -50041, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(30, 1, 1, -50040, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(30, 1, 1, -50038, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(30, 1, 1, -50037, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(30, 1, 1, -50036, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(30, 1, 1, -50035, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(30, 1, 1, -50034, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(30, 1, 1, -50033, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(30, 1, 1, -50020, 2, 5, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 1),
	(30, 1, 1, -50019, 3, 5, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 1),
	(30, 1, 1, -50018, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(30, 1, 1, -50017, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(30, 1, 1, -50016, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(30, 1, 1, -50015, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(30, 1, 1, -50014, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(30, 1, 1, -50013, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(30, 1, 1, -50012, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(30, 1, 1, -50011, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(30, 1, 1, -50008, 3, NULL, NULL, NULL, NULL, NULL, NULL, 5, NULL, NULL, NULL, 1),
	(30, 1, 1, -50005, 5, NULL, NULL, NULL, NULL, NULL, NULL, 372, NULL, NULL, NULL, 1),
	(30, 1, 1, -50004, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(30, 1, 1, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(30, 1, 1, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(30, 1, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(30, 1, 1, -3, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(30, 1, 1, 10690, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(30, 1, 1, 10691, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(30, 1, 1, 10692, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(30, 1, 1, 10693, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(30, 1, 1, 10695, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(30, 1, 1, 10696, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(30, 1, 1, 10697, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(30, 1, 1, 10698, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(33, 1, 1, -50917, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(33, 1, 1, -50916, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(33, 1, 1, -50915, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50914, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50197, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(33, 1, 1, -50196, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(33, 1, 1, -50195, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50194, 2, 2, 'Index', NULL, NULL, NULL, NULL, 15, NULL, NULL, NULL, 0),
	(33, 1, 1, -50193, 2, 2, 'Index', NULL, NULL, NULL, NULL, 15, NULL, NULL, NULL, 0),
	(33, 1, 1, -50192, 2, 2, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(33, 1, 1, -50191, 2, 2, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(33, 1, 1, -50190, 2, 2, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(33, 1, 1, -50189, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50188, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50187, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50186, 5, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50185, 5, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50184, 5, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50183, 5, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50181, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(33, 1, 1, -50162, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(33, 1, 1, -50161, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50160, 3, 32, 'Index', NULL, NULL, NULL, NULL, 32, NULL, NULL, NULL, 0),
	(33, 1, 1, -50159, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50158, 3, 32, 'Index', NULL, NULL, NULL, NULL, 32, NULL, NULL, NULL, 0),
	(33, 1, 1, -50157, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(33, 1, 1, -50156, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50155, 5, NULL, NULL, NULL, NULL, NULL, NULL, 432, NULL, NULL, NULL, 0),
	(33, 1, 1, -50154, 5, NULL, NULL, NULL, NULL, NULL, NULL, 432, NULL, NULL, NULL, 0),
	(33, 1, 1, -50153, 5, NULL, NULL, NULL, NULL, NULL, NULL, 432, NULL, NULL, NULL, 0),
	(33, 1, 1, -50152, 5, NULL, NULL, NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(33, 1, 1, -50151, 5, NULL, NULL, NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(33, 1, 1, -50150, 5, NULL, NULL, NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(33, 1, 1, -50149, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50148, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50147, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50146, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50145, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50144, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50143, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50142, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50141, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50140, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50139, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50138, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50137, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50136, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50135, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50134, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50133, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50132, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50131, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50130, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50129, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50128, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50127, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50126, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50125, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50124, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50123, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50122, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50121, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50120, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50119, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50118, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50117, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(33, 1, 1, -50116, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50115, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50114, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50113, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50112, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50111, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50110, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50109, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50108, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50107, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50106, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50105, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50104, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50103, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50102, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50101, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50100, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50098, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50097, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50096, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50095, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50094, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50093, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50092, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50091, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50090, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50089, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50088, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50087, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(33, 1, 1, -50086, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50085, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50084, 5, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(33, 1, 1, -50083, 5, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(33, 1, 1, -50082, 5, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(33, 1, 1, -50081, 5, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(33, 1, 1, -50080, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50078, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(33, 1, 1, -50076, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50075, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50074, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50073, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50072, 2, NULL, NULL, NULL, NULL, NULL, NULL, 3, NULL, NULL, NULL, 0),
	(33, 1, 1, -50071, 2, NULL, NULL, NULL, NULL, NULL, NULL, 3, NULL, NULL, NULL, 0),
	(33, 1, 1, -50070, 2, NULL, NULL, NULL, NULL, NULL, NULL, 3, NULL, NULL, NULL, 0),
	(33, 1, 1, -50069, 2, NULL, NULL, NULL, NULL, NULL, NULL, 3, NULL, NULL, NULL, 0),
	(33, 1, 1, -50068, 2, NULL, NULL, NULL, NULL, NULL, NULL, 3, NULL, NULL, NULL, 0),
	(33, 1, 1, -50067, 2, NULL, NULL, NULL, NULL, NULL, NULL, 3, NULL, NULL, NULL, 0),
	(33, 1, 1, -50066, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50065, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50064, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50063, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50062, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(33, 1, 1, -50061, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(33, 1, 1, -50060, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(33, 1, 1, -50059, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(33, 1, 1, -50056, 2, 127, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(33, 1, 1, -50053, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50052, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50048, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50025, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50021, 2, 127, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(33, 1, 1, -50019, 2, 127, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(33, 1, 1, -50017, 2, NULL, NULL, NULL, NULL, NULL, NULL, 32, NULL, NULL, NULL, 0),
	(33, 1, 1, -50016, 2, NULL, NULL, NULL, NULL, NULL, NULL, 32, NULL, NULL, NULL, 0),
	(33, 1, 1, -50015, 2, NULL, NULL, NULL, NULL, NULL, NULL, 32, NULL, NULL, NULL, 0),
	(33, 1, 1, -50014, 2, NULL, NULL, NULL, NULL, NULL, NULL, 32, NULL, NULL, NULL, 0),
	(33, 1, 1, -50013, 2, NULL, NULL, NULL, NULL, NULL, NULL, 32, NULL, NULL, NULL, 0),
	(33, 1, 1, -50012, 2, NULL, NULL, NULL, NULL, NULL, NULL, 32, NULL, NULL, NULL, 0),
	(33, 1, 1, -50011, 2, NULL, NULL, NULL, NULL, NULL, NULL, 32, NULL, NULL, NULL, 0),
	(33, 1, 1, -50010, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(33, 1, 1, -50009, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(33, 1, 1, -50008, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(33, 1, 1, -50007, 2, NULL, NULL, NULL, NULL, NULL, NULL, 256, NULL, NULL, NULL, 0),
	(33, 1, 1, -50006, 3, NULL, NULL, NULL, NULL, NULL, NULL, 256, NULL, NULL, NULL, 0),
	(33, 1, 1, -50004, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -50001, 3, 2, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(33, 1, 1, -50000, 3, 2, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(33, 1, 1, -12, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(33, 1, 1, -11, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(33, 1, 1, -10, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(33, 1, 1, -9, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(33, 1, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(33, 1, 1, -5, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(33, 1, 1, -3, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(35, 1, 1, -50073, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(35, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(39, 1, 1, -50496, 2, 2, 'Profile', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(39, 1, 1, -50495, 2, 2, 'Profile', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(39, 1, 1, -50494, 2, 2, 'Profile', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(39, 1, 1, -50493, 3, 2, 'Profile', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(39, 1, 1, -50491, 2, 2, 'Profile', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(39, 1, 1, -50304, 3, 2, 'Profile', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(51, 1, 1, -50181, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(51, 1, 1, -50058, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(51, 1, 1, -50057, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(51, 1, 1, -50055, 3, 5, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 1),
	(51, 1, 1, -50054, 3, NULL, NULL, NULL, NULL, NULL, NULL, 5, NULL, NULL, NULL, 1),
	(51, 1, 1, -50053, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(51, 1, 1, -50052, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(51, 1, 1, -50051, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(51, 1, 1, -50050, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(51, 1, 1, -50049, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(51, 1, 1, -50048, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(51, 1, 1, -50047, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(51, 1, 1, -50046, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(51, 1, 1, -50045, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(51, 1, 1, -50044, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(51, 1, 1, -50043, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(51, 1, 1, -50042, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(51, 1, 1, -50041, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(51, 1, 1, -50040, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(51, 1, 1, -50038, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(51, 1, 1, -50037, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(51, 1, 1, -50036, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(51, 1, 1, -50035, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(51, 1, 1, -50034, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(51, 1, 1, -50033, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(51, 1, 1, -50020, 2, 5, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 1),
	(51, 1, 1, -50019, 3, 5, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 1),
	(51, 1, 1, -50018, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(51, 1, 1, -50017, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(51, 1, 1, -50016, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(51, 1, 1, -50015, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(51, 1, 1, -50014, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(51, 1, 1, -50013, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(51, 1, 1, -50012, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(51, 1, 1, -50011, 5, 5, 'Index', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 1),
	(51, 1, 1, -50008, 3, NULL, NULL, NULL, NULL, NULL, NULL, 5, NULL, NULL, NULL, 1),
	(51, 1, 1, -50005, 5, NULL, NULL, NULL, NULL, NULL, NULL, 372, NULL, NULL, NULL, 1),
	(51, 1, 1, -50004, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(51, 1, 1, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(51, 1, 1, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(51, 1, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1),
	(51, 1, 1, -3, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(51, 1, 1, 10690, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(51, 1, 1, 10691, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(51, 1, 1, 10692, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(51, 1, 1, 10693, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(51, 1, 1, 10695, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(51, 1, 1, 10696, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(51, 1, 1, 10697, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(51, 1, 1, 10698, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(68, 1, 1, -50693, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(68, 1, 1, -50692, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(68, 1, 1, -50668, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(68, 1, 1, -50654, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(68, 1, 1, -50557, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(68, 1, 1, -50382, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(68, 1, 1, -50233, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(68, 1, 1, -50090, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(68, 1, 1, -50089, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(68, 1, 1, -50079, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(68, 1, 1, -50078, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(68, 1, 1, -10, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(68, 1, 1, -9, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(68, 1, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(68, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(68, 1, 1, -1, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(69, 1, 1, -50693, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(69, 1, 1, -50692, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(69, 1, 1, -50668, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(69, 1, 1, -50654, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(69, 1, 1, -50557, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(69, 1, 1, -50382, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(69, 1, 1, -50233, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(69, 1, 1, -50090, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(69, 1, 1, -50089, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(69, 1, 1, -50079, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(69, 1, 1, -50078, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(69, 1, 1, -10, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(69, 1, 1, -9, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(69, 1, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(69, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(69, 1, 1, -1, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(79, 1, 1, -50693, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(79, 1, 1, -50692, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(79, 1, 1, -50668, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(79, 1, 1, -50654, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(79, 1, 1, -50557, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(79, 1, 1, -50382, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(79, 1, 1, -50233, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(79, 1, 1, -50090, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(79, 1, 1, -50089, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(79, 1, 1, -50079, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(79, 1, 1, -50078, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(79, 1, 1, -10, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(79, 1, 1, -9, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(79, 1, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(79, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(79, 1, 1, -1, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(81, 1, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(103, 1, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(103, 1, 1, -50320, 1, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(103, 1, 1, 10841, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(127, 1, 1, -50032, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(127, 1, 1, -50031, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(127, 1, 1, -50030, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(127, 1, 1, -50029, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(127, 1, 1, -50028, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(127, 1, 1, -50027, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(127, 1, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(127, 1, 1, -50025, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(127, 1, 1, -50024, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, 0, NULL, 1),
	(127, 1, 1, -50023, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(127, 1, 1, -50022, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(127, 1, 1, -50020, 2, 16, 'Index', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 1),
	(127, 1, 1, -50019, 4, 16, 'Index', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 1),
	(127, 1, 1, -50018, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(127, 1, 1, -50017, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(127, 1, 1, -50016, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(127, 1, 1, -50015, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(127, 1, 1, -50014, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(127, 1, 1, -50013, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(127, 1, 1, -50012, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(127, 1, 1, -50011, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 1),
	(127, 1, 1, -50010, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 1),
	(127, 1, 1, -50008, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 1),
	(127, 1, 1, -50006, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 1),
	(127, 1, 1, -50005, 5, NULL, NULL, NULL, NULL, NULL, NULL, 372, NULL, NULL, NULL, 1),
	(127, 1, 1, -50004, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(127, 1, 1, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(127, 1, 1, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(127, 1, 1, -50001, 4, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(127, 1, 1, -50000, 4, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(127, 1, 1, -15, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(127, 1, 1, -13, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, 0, NULL, 1),
	(127, 1, 1, -10, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(127, 1, 1, -9, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(127, 1, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(127, 1, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(127, 1, 1, -3, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(135, 1, 1, -50461, 5, NULL, NULL, NULL, NULL, NULL, NULL, 40, NULL, NULL, NULL, 0),
	(135, 1, 1, -50460, 5, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 1, 1, -50459, 5, NULL, NULL, NULL, NULL, NULL, NULL, 48, NULL, NULL, NULL, 0),
	(135, 1, 1, -50458, 5, NULL, NULL, NULL, NULL, NULL, NULL, 5, NULL, NULL, NULL, 0),
	(135, 1, 1, -50457, 5, NULL, NULL, NULL, NULL, NULL, NULL, 34, NULL, NULL, NULL, 0),
	(135, 1, 1, -50456, 5, NULL, NULL, NULL, NULL, NULL, NULL, 28, NULL, NULL, NULL, 0),
	(135, 1, 1, -50455, 5, NULL, NULL, NULL, NULL, NULL, NULL, 27, NULL, NULL, NULL, 0),
	(135, 1, 1, -50454, 5, NULL, NULL, NULL, NULL, NULL, NULL, 63, NULL, NULL, NULL, 0),
	(135, 1, 1, -50453, 5, NULL, NULL, NULL, NULL, NULL, NULL, 104, NULL, NULL, NULL, 0),
	(135, 1, 1, -50452, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50451, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50450, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50449, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50448, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50447, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50446, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50445, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50444, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50443, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50442, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50441, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50440, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50439, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50438, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50437, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50436, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50435, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50434, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50433, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50432, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50431, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50430, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50429, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50428, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50427, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50426, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50423, 5, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(135, 1, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(135, 1, 1, -50373, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50372, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50371, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50370, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50369, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50320, 1, 4, 'Channel', NULL, NULL, NULL, NULL, 5, NULL, NULL, NULL, 0),
	(135, 1, 1, -50319, 1, 4, 'Channel', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(135, 1, 1, -50222, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(135, 1, 1, -50196, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(135, 1, 1, -50182, 2, 3, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50181, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(135, 1, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(135, 1, 1, -50066, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50063, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -50020, 2, 36, 'GraphNr', NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 1, 1, -50019, 3, 36, 'GraphNr', NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 1, 1, -50018, 2, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(135, 1, 1, -50017, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 1, 1, -50016, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 1, 1, -50015, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 1, 1, -50014, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 1, 1, -50013, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 1, 1, -50012, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 1, 1, -50011, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 1, 1, -50008, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 1, 1, -50006, 3, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(135, 1, 1, -10, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -9, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(135, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(135, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 1, 1, 10854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50462, 1, 2, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(135, 2, 1, -50461, 5, NULL, NULL, NULL, NULL, NULL, NULL, 40, NULL, NULL, NULL, 0),
	(135, 2, 1, -50460, 5, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 2, 1, -50459, 5, NULL, NULL, NULL, NULL, NULL, NULL, 48, NULL, NULL, NULL, 0),
	(135, 2, 1, -50458, 5, NULL, NULL, NULL, NULL, NULL, NULL, 5, NULL, NULL, NULL, 0),
	(135, 2, 1, -50457, 5, NULL, NULL, NULL, NULL, NULL, NULL, 34, NULL, NULL, NULL, 0),
	(135, 2, 1, -50456, 5, NULL, NULL, NULL, NULL, NULL, NULL, 28, NULL, NULL, NULL, 0),
	(135, 2, 1, -50455, 5, NULL, NULL, NULL, NULL, NULL, NULL, 27, NULL, NULL, NULL, 0),
	(135, 2, 1, -50454, 5, NULL, NULL, NULL, NULL, NULL, NULL, 63, NULL, NULL, NULL, 0),
	(135, 2, 1, -50453, 5, NULL, NULL, NULL, NULL, NULL, NULL, 104, NULL, NULL, NULL, 0),
	(135, 2, 1, -50452, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50451, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50450, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50449, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50448, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50447, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50446, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50445, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50444, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50443, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50442, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50441, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50440, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50439, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50438, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50437, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50436, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50435, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50434, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50433, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50432, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50431, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50430, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50429, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50428, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50427, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50426, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50423, 5, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(135, 2, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(135, 2, 1, -50373, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50372, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50371, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50370, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50369, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50320, 1, 2, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50319, 1, 2, 'Channel', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(135, 2, 1, -50222, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(135, 2, 1, -50196, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(135, 2, 1, -50182, 2, 3, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50181, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(135, 2, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(135, 2, 1, -50066, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50063, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -50020, 2, 36, 'GraphNr', NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 2, 1, -50019, 3, 36, 'GraphNr', NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 2, 1, -50018, 2, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(135, 2, 1, -50017, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 2, 1, -50016, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 2, 1, -50015, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 2, 1, -50014, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 2, 1, -50013, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 2, 1, -50012, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 2, 1, -50011, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 2, 1, -50008, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(135, 2, 1, -50006, 3, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(135, 2, 1, -10, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -9, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(135, 2, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(135, 2, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(135, 2, 1, 10854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50322, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 1, 0, -50321, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 12, 0, NULL, NULL, 0),
	(137, 1, 0, -50320, 1, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 1, 0, -50319, 1, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 1, 0, -50318, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(137, 1, 0, -50317, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(137, 1, 0, -50316, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50315, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50314, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50313, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50312, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50311, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50310, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50309, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50308, 2, 10, 'ProfileNr', 512, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50307, 2, 10, 'ProfileNr', 512, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50306, 2, 10, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50305, 2, 10, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50304, 2, 10, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50303, 1, 10, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50302, 2, 10, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50301, 2, 10, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50300, 3, 10, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50298, 2, 512, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50297, 2, 512, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50296, 2, 512, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50295, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(137, 1, 0, -50276, 3, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50275, 5, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50274, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50273, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50272, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50271, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50270, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50269, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50268, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50267, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50265, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50257, 2, 240, 'Channel', NULL, NULL, NULL, NULL, 7, NULL, NULL, NULL, 0),
	(137, 1, 0, -50256, 2, 240, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50253, 2, 240, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50252, 2, 240, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50251, 5, 240, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(137, 1, 0, -50250, 2, 240, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50249, 3, 240, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 1, 0, -50247, 2, 240, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50246, 3, 240, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50241, 1, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 1, 0, -50237, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50236, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50235, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50234, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50233, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50232, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50231, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50224, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50223, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50222, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50221, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(137, 1, 0, -50220, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(137, 1, 0, -50219, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(137, 1, 0, -50218, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(137, 1, 0, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(137, 1, 0, -50216, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(137, 1, 0, -50215, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(137, 1, 0, -50214, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50213, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50212, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50211, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50210, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50209, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50208, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50207, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50206, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(137, 1, 0, -50205, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50203, 2, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(137, 1, 0, -50199, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(137, 1, 0, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50181, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, 0, NULL, NULL, 0),
	(137, 1, 0, -50163, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(137, 1, 0, -50022, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(137, 1, 0, -50020, 2, NULL, NULL, 16, 'GraphNr', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(137, 1, 0, -50018, 2, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50017, 2, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50016, 2, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50015, 2, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50014, 2, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50013, 2, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50012, 2, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50011, 2, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50008, 3, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50006, 3, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(137, 1, 0, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, -7, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(137, 1, 0, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(137, 1, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(137, 1, 0, 10010, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, 10011, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 0, 10292, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 0),
	(137, 1, 0, 10842, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 1, 0, 10843, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 1, 0, 10854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 1, 0, 10875, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(137, 1, 0, 10876, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 1, 0, 10887, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(137, 1, 0, 10888, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(137, 1, 1, 10010, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 1, 10011, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 1, 1, 10854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 1, 1, 10875, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(137, 1, 1, 10876, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 1, 1, 10887, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(137, 1, 1, 10888, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(137, 2, 0, -50322, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 2, 0, -50321, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 12, 0, NULL, NULL, 0),
	(137, 2, 0, -50320, 1, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 2, 0, -50319, 1, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 2, 0, -50318, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(137, 2, 0, -50317, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(137, 2, 0, -50316, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50315, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50314, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50313, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50312, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50311, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50310, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50309, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50308, 2, 10, 'ProfileNr', 512, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50307, 2, 10, 'ProfileNr', 512, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50306, 2, 10, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50305, 2, 10, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50304, 2, 10, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50303, 1, 10, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50302, 2, 10, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50301, 2, 10, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50300, 3, 10, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50298, 2, 512, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50297, 2, 512, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50296, 2, 512, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50295, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(137, 2, 0, -50276, 3, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50275, 5, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50274, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50273, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50272, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50271, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50270, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50269, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50268, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50267, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50265, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50257, 2, 240, 'Channel', NULL, NULL, NULL, NULL, 7, NULL, NULL, NULL, 0),
	(137, 2, 0, -50256, 2, 240, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50253, 2, 240, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50252, 2, 240, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50251, 5, 240, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(137, 2, 0, -50250, 2, 240, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50249, 3, 240, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 2, 0, -50247, 2, 240, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50246, 3, 240, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50241, 1, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 2, 0, -50237, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50236, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50235, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50234, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50233, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50232, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50231, 2, 16, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50224, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50223, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50222, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50221, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(137, 2, 0, -50220, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(137, 2, 0, -50219, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(137, 2, 0, -50218, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(137, 2, 0, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(137, 2, 0, -50216, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(137, 2, 0, -50215, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(137, 2, 0, -50214, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50213, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50212, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50211, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50210, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50209, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50208, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50207, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50206, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(137, 2, 0, -50205, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50203, 2, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(137, 2, 0, -50199, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(137, 2, 0, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50181, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, 0, NULL, NULL, 0),
	(137, 2, 0, -50163, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(137, 2, 0, -50022, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(137, 2, 0, -50020, 2, 4, 'GroupNr', 16, 'GraphNr', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(137, 2, 0, -50018, 2, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50017, 2, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50016, 2, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50015, 2, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50014, 2, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50013, 2, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50012, 2, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50011, 2, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50008, 3, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50006, 3, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(137, 2, 0, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, -7, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(137, 2, 0, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(137, 2, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(137, 2, 0, 10010, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, 10011, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 0, 10292, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 0),
	(137, 2, 0, 10842, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 2, 0, 10843, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 2, 0, 10854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 2, 0, 10875, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(137, 2, 0, 10876, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 2, 0, 10887, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(137, 2, 0, 10888, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(137, 2, 1, 10010, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 1, 10011, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(137, 2, 1, 10854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 2, 1, 10875, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(137, 2, 1, 10876, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(137, 2, 1, 10887, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(137, 2, 1, 10888, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(139, 1, 0, -50163, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(139, 1, 1, -50654, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(139, 1, 1, -50483, 2, 8, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50482, 2, 8, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50481, 2, 8, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50480, 2, 8, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50479, 3, 8, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50478, 2, 8, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50466, 2, 4, 'Index', NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(139, 1, 1, -50465, 2, 4, 'Index', NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(139, 1, 1, -50464, 3, 4, 'Index', NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(139, 1, 1, -50463, 2, 4, 'Index', NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(139, 1, 1, -50425, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50424, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50422, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(139, 1, 1, -50421, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50420, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(139, 1, 1, -50419, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(139, 1, 1, -50418, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50417, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50391, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50390, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50359, 2, NULL, NULL, NULL, NULL, NULL, NULL, 30, NULL, NULL, NULL, 0),
	(139, 1, 1, -50358, 3, NULL, NULL, NULL, NULL, NULL, NULL, 30, NULL, NULL, NULL, 0),
	(139, 1, 1, -50357, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50356, 2, NULL, NULL, NULL, NULL, NULL, NULL, 168, NULL, NULL, NULL, 0),
	(139, 1, 1, -50355, 2, NULL, NULL, NULL, NULL, NULL, NULL, 168, NULL, NULL, NULL, 0),
	(139, 1, 1, -50354, 3, NULL, NULL, NULL, NULL, NULL, NULL, 168, NULL, NULL, NULL, 0),
	(139, 1, 1, -50353, 3, NULL, NULL, NULL, NULL, NULL, NULL, 168, NULL, NULL, NULL, 0),
	(139, 1, 1, -50352, 3, NULL, NULL, NULL, NULL, NULL, NULL, 168, NULL, NULL, NULL, 0),
	(139, 1, 1, -50351, 3, NULL, NULL, NULL, NULL, NULL, NULL, 168, NULL, NULL, NULL, 0),
	(139, 1, 1, -50350, 2, NULL, NULL, NULL, NULL, NULL, NULL, 7, NULL, NULL, NULL, 0),
	(139, 1, 1, -50349, 2, NULL, NULL, NULL, NULL, NULL, NULL, 7, NULL, NULL, NULL, 0),
	(139, 1, 1, -50348, 2, NULL, NULL, NULL, NULL, NULL, NULL, 84, NULL, NULL, NULL, 0),
	(139, 1, 1, -50347, 2, NULL, NULL, NULL, NULL, NULL, NULL, 84, NULL, NULL, NULL, 0),
	(139, 1, 1, -50346, 3, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(139, 1, 1, -50345, 3, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(139, 1, 1, -50344, 3, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(139, 1, 1, -50343, 3, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(139, 1, 1, -50342, 3, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(139, 1, 1, -50341, 3, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(139, 1, 1, -50340, 3, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(139, 1, 1, -50339, 3, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(139, 1, 1, -50338, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50337, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50319, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50098, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50097, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50078, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50022, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -8, 2, 4, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -7, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, -1, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 1, 1, 10854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(139, 2, 0, -50163, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(139, 2, 1, -50853, 2, NULL, NULL, NULL, NULL, NULL, NULL, 30, NULL, NULL, NULL, 0),
	(139, 2, 1, -50852, 3, NULL, NULL, NULL, NULL, NULL, NULL, 30, NULL, NULL, NULL, 0),
	(139, 2, 1, -50654, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(139, 2, 1, -50483, 2, 8, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50482, 2, 8, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50481, 2, 8, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50480, 2, 8, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50479, 3, 8, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50478, 2, 8, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50466, 2, 4, 'Index', NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(139, 2, 1, -50465, 2, 4, 'Index', NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(139, 2, 1, -50464, 3, 4, 'Index', NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(139, 2, 1, -50463, 2, 4, 'Index', NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(139, 2, 1, -50425, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50424, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50422, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(139, 2, 1, -50421, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50420, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(139, 2, 1, -50419, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(139, 2, 1, -50418, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50417, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50391, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50390, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50359, 2, NULL, NULL, NULL, NULL, NULL, NULL, 30, NULL, NULL, NULL, 0),
	(139, 2, 1, -50358, 3, NULL, NULL, NULL, NULL, NULL, NULL, 30, NULL, NULL, NULL, 0),
	(139, 2, 1, -50357, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50356, 2, NULL, NULL, NULL, NULL, NULL, NULL, 168, NULL, NULL, NULL, 0),
	(139, 2, 1, -50355, 2, NULL, NULL, NULL, NULL, NULL, NULL, 168, NULL, NULL, NULL, 0),
	(139, 2, 1, -50354, 3, NULL, NULL, NULL, NULL, NULL, NULL, 168, NULL, NULL, NULL, 0),
	(139, 2, 1, -50353, 3, NULL, NULL, NULL, NULL, NULL, NULL, 168, NULL, NULL, NULL, 0),
	(139, 2, 1, -50352, 3, NULL, NULL, NULL, NULL, NULL, NULL, 168, NULL, NULL, NULL, 0),
	(139, 2, 1, -50351, 3, NULL, NULL, NULL, NULL, NULL, NULL, 168, NULL, NULL, NULL, 0),
	(139, 2, 1, -50350, 2, NULL, NULL, NULL, NULL, NULL, NULL, 7, NULL, NULL, NULL, 0),
	(139, 2, 1, -50349, 2, NULL, NULL, NULL, NULL, NULL, NULL, 7, NULL, NULL, NULL, 0),
	(139, 2, 1, -50348, 2, NULL, NULL, NULL, NULL, NULL, NULL, 84, NULL, NULL, NULL, 0),
	(139, 2, 1, -50347, 2, NULL, NULL, NULL, NULL, NULL, NULL, 84, NULL, NULL, NULL, 0),
	(139, 2, 1, -50346, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(139, 2, 1, -50345, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(139, 2, 1, -50344, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(139, 2, 1, -50343, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(139, 2, 1, -50342, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(139, 2, 1, -50341, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(139, 2, 1, -50340, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(139, 2, 1, -50339, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(139, 2, 1, -50338, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50337, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50319, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50098, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50097, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50078, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50022, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -8, 2, 4, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -7, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, -1, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(139, 2, 1, 10854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(140, 1, 1, -50511, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50500, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(140, 1, 1, -50499, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(140, 1, 1, -50498, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(140, 1, 1, -50497, 3, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(140, 1, 1, -50496, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(140, 1, 1, -50495, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(140, 1, 1, -50494, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(140, 1, 1, -50493, 3, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(140, 1, 1, -50491, 2, 500, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(140, 1, 1, -50490, 3, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(140, 1, 1, -50489, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(140, 1, 1, -50488, 3, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(140, 1, 1, -50416, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50415, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50414, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50413, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50412, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50411, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50410, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50409, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50408, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50407, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50406, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50405, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50404, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50403, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50402, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50359, 2, NULL, NULL, NULL, NULL, NULL, NULL, 80, NULL, 0, NULL, 0),
	(140, 1, 1, -50358, 3, NULL, NULL, NULL, NULL, NULL, NULL, 80, NULL, 0, NULL, 0),
	(140, 1, 1, -50357, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50356, 2, NULL, NULL, NULL, NULL, NULL, NULL, 128, NULL, NULL, NULL, 0),
	(140, 1, 1, -50355, 2, NULL, NULL, NULL, NULL, NULL, NULL, 128, NULL, NULL, NULL, 0),
	(140, 1, 1, -50352, 3, NULL, NULL, NULL, NULL, NULL, NULL, 128, NULL, NULL, NULL, 0),
	(140, 1, 1, -50351, 3, NULL, NULL, NULL, NULL, NULL, NULL, 128, NULL, NULL, NULL, 0),
	(140, 1, 1, -50348, 2, NULL, NULL, NULL, NULL, NULL, NULL, 105, NULL, NULL, NULL, 0),
	(140, 1, 1, -50347, 2, NULL, NULL, NULL, NULL, NULL, NULL, 105, NULL, NULL, NULL, 0),
	(140, 1, 1, -50344, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(140, 1, 1, -50343, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(140, 1, 1, -50342, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(140, 1, 1, -50341, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(140, 1, 1, -50338, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50337, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50336, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50319, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50304, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50222, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 3, NULL, NULL, NULL, 0),
	(140, 1, 1, -50163, 2, 4, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50078, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(140, 1, 1, -50073, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(140, 1, 1, -50022, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -31, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(140, 1, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(140, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(140, 1, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(140, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(140, 1, 1, 10881, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(143, 1, 1, -50496, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(143, 1, 1, -50495, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(143, 1, 1, -50494, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(143, 1, 1, -50493, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(143, 1, 1, -50491, 2, 8, 'Channel', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(145, 1, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 1, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 1, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 1, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 1, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 1, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 1, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 1, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 1, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 1, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 1, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 1, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 1, 1, -50380, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50379, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50320, 1, 8, 'TariffNr', 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50319, 1, 8, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 1, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 1, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 1, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 1, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 1, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 1, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 1, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 1, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 1, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 1, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 1, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 2, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 2, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 2, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 2, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 2, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 2, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 2, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 2, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 2, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 2, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 2, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 2, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50376, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 2, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50320, 1, 8, 'TariffNr', 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50319, 1, 8, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 2, 1, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 2, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 2, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 2, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 2, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 2, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 2, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 2, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 2, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 2, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 2, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 3, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 3, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 3, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 3, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 3, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 3, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 3, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 3, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 3, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 3, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 3, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 3, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50376, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 3, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50320, 1, 8, 'TariffNr', 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50319, 1, 8, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 3, 1, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 3, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 3, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 3, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 3, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 3, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 3, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 3, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 3, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 3, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 3, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 4, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 4, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 4, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 4, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 4, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 4, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 4, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 4, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 4, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 4, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 4, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 4, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50320, 1, 8, 'TariffNr', 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50319, 1, 8, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(145, 4, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 4, 1, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 4, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 4, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 4, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 4, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 4, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 4, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 4, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 4, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 4, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 4, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 5, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 5, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 5, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 5, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 5, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 5, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 5, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 5, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 5, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 5, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 5, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 5, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50320, 1, 8, 'TariffNr', 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50319, 1, 8, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(145, 5, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 5, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 5, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 5, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 5, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 5, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 5, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 5, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 5, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 5, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 5, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 5, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 6, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 6, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 6, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 6, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 6, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 6, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 6, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 6, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 6, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 6, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 6, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 6, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50320, 1, 8, 'TariffNr', 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50319, 1, 8, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(145, 6, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 6, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 6, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 6, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 6, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 6, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 6, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 6, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 6, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 6, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 6, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 6, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 7, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 7, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 7, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 7, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 7, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 7, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 7, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 7, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 7, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 7, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 7, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 7, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 7, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 7, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 7, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 7, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 7, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 7, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 7, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 7, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 7, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 7, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 7, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 7, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 7, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 7, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 7, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 7, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 7, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 7, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 7, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 7, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 7, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 7, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 7, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 8, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 8, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 8, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 8, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 8, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 8, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 8, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 8, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 8, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 8, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 8, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 8, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 8, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 8, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 8, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 8, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 8, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 8, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 8, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 8, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 8, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 8, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 8, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 8, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 8, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 8, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 8, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 8, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 8, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 8, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 8, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 8, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 8, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 8, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 8, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 9, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 9, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 9, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 9, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 9, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 9, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 9, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 9, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 9, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 9, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 9, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 9, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 9, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50376, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 9, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50319, 1, 1, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 9, 1, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 9, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 9, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 9, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 9, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 9, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 9, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 9, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 9, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 9, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 9, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 10, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 10, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 10, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 10, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 10, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 10, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 10, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 10, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 10, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 10, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 10, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 10, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50376, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 10, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50319, 1, 1, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 10, 1, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 10, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 10, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 10, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 10, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 10, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 10, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 10, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 10, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 10, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 10, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 11, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 11, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 11, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 11, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 11, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 11, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 11, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 11, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(145, 11, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 11, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 11, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 11, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50319, 1, 1, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(145, 11, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 11, 1, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 11, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 11, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(145, 11, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 11, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 11, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 11, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 11, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 11, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(145, 11, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(145, 11, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50811, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50810, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50809, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50808, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50807, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50806, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50805, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50804, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50803, 2, NULL, NULL, NULL, NULL, NULL, NULL, 132, NULL, NULL, NULL, 0),
	(154, 1, 1, -50802, 2, NULL, NULL, NULL, NULL, NULL, NULL, 132, NULL, NULL, NULL, 0),
	(154, 1, 1, -50801, 2, NULL, NULL, NULL, NULL, NULL, NULL, 132, NULL, NULL, NULL, 0),
	(154, 1, 1, -50800, 5, NULL, NULL, NULL, NULL, NULL, NULL, 132, NULL, NULL, NULL, 0),
	(154, 1, 1, -50799, 5, NULL, NULL, NULL, NULL, NULL, NULL, 132, NULL, NULL, NULL, 0),
	(154, 1, 1, -50798, 2, NULL, NULL, NULL, NULL, NULL, NULL, 132, NULL, NULL, NULL, 0),
	(154, 1, 1, -50797, 5, NULL, NULL, NULL, NULL, NULL, NULL, 35, NULL, NULL, NULL, 0),
	(154, 1, 1, -50796, 5, NULL, NULL, NULL, NULL, NULL, NULL, 35, NULL, NULL, NULL, 0),
	(154, 1, 1, -50795, 2, NULL, NULL, NULL, NULL, NULL, NULL, 35, NULL, NULL, NULL, 0),
	(154, 1, 1, -50794, 2, NULL, NULL, NULL, NULL, NULL, NULL, 35, NULL, NULL, NULL, 0),
	(154, 1, 1, -50793, 5, NULL, NULL, NULL, NULL, NULL, NULL, 255, NULL, NULL, NULL, 0),
	(154, 1, 1, -50792, 5, NULL, NULL, NULL, NULL, NULL, NULL, 255, NULL, NULL, NULL, 0),
	(154, 1, 1, -50791, 2, NULL, NULL, NULL, NULL, NULL, NULL, 255, NULL, NULL, NULL, 0),
	(154, 1, 1, -50790, 4, NULL, NULL, NULL, NULL, NULL, NULL, 255, NULL, NULL, NULL, 0),
	(154, 1, 1, -50789, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50788, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50787, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50786, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50785, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50784, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50783, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50782, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50781, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50780, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50779, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50778, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50777, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50776, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50775, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50774, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50773, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50772, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50771, 2, NULL, NULL, NULL, NULL, NULL, NULL, 32, NULL, NULL, NULL, 0),
	(154, 1, 1, -50770, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(154, 1, 1, -50769, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(154, 1, 1, -50768, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(154, 1, 1, -50767, 5, NULL, NULL, NULL, NULL, NULL, NULL, 6, NULL, NULL, NULL, 0),
	(154, 1, 1, -50766, 2, NULL, NULL, NULL, NULL, NULL, NULL, 6, NULL, NULL, NULL, 0),
	(154, 1, 1, -50765, 2, NULL, NULL, NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(154, 1, 1, -50764, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50763, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50762, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50761, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50760, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50759, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50758, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50757, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50756, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50755, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50754, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50753, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50752, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50751, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50750, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50749, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50748, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50747, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50746, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50745, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50744, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50743, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50742, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50741, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50740, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50739, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50738, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50737, 1, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(154, 1, 1, -50736, 3, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(154, 1, 1, -50735, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50734, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(154, 1, 1, -50733, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(154, 1, 1, -50732, 2, NULL, NULL, NULL, NULL, NULL, NULL, 10, NULL, NULL, NULL, 0),
	(154, 1, 1, -50731, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50730, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50729, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50728, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50727, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50726, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50725, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50724, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50723, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50722, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50721, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50720, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50719, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50718, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50717, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50716, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50715, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50714, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50713, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50712, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50711, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50710, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50709, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50708, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50707, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50706, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50705, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50704, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50703, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50702, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50701, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50700, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50699, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50698, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50654, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50382, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50288, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50098, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50097, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50091, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50076, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -50018, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(154, 1, 1, -50017, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(154, 1, 1, -50016, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(154, 1, 1, -50015, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(154, 1, 1, -50014, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(154, 1, 1, -50013, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(154, 1, 1, -50012, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(154, 1, 1, -50011, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(154, 1, 1, -10, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -9, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(154, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(154, 1, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50509, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50508, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50507, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50506, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50505, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50504, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50503, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50502, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50501, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50457, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, 0, NULL, 0),
	(157, 1, 1, -50456, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, 0, NULL, 0),
	(157, 1, 1, -50447, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50418, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50417, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50347, 2, 10, 'WeekNr', NULL, NULL, NULL, NULL, 8, NULL, 0, NULL, 0),
	(157, 1, 1, -50337, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50319, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50304, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50133, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50127, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50114, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50076, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50073, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50022, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -50020, 2, 16, 'DayNr', NULL, NULL, NULL, NULL, 8, NULL, 0, NULL, 0),
	(157, 1, 1, -50019, 3, 16, 'DayNr', NULL, NULL, NULL, NULL, 8, NULL, 0, NULL, 0),
	(157, 1, 1, -50010, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, 0, NULL, 0),
	(157, 1, 1, -50008, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, 0, NULL, 0),
	(157, 1, 1, -50006, 3, NULL, NULL, NULL, NULL, NULL, NULL, 40, NULL, 0, NULL, 0),
	(157, 1, 1, -50005, 5, NULL, NULL, NULL, NULL, NULL, NULL, 372, NULL, 0, NULL, 0),
	(157, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(157, 1, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(162, 1, 0, -50331, 3, NULL, NULL, NULL, NULL, NULL, NULL, 30, NULL, 0, NULL, 0),
	(162, 1, 0, -50180, 3, NULL, NULL, NULL, NULL, NULL, NULL, 30, NULL, 0, NULL, 0),
	(162, 1, 0, -50179, 2, 8, 'GroupNr', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(162, 1, 0, -50178, 2, 8, 'GroupNr', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(162, 1, 0, -50177, 2, 8, 'GroupNr', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(162, 1, 0, -50176, 2, 8, 'GroupNr', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(162, 1, 0, -50175, 2, NULL, NULL, NULL, NULL, NULL, NULL, 6, NULL, NULL, NULL, 0),
	(162, 1, 0, -50174, 2, NULL, NULL, NULL, NULL, NULL, NULL, 6, NULL, NULL, NULL, 0),
	(162, 1, 0, -50173, 2, NULL, NULL, NULL, NULL, NULL, NULL, 6, NULL, NULL, NULL, 0),
	(162, 1, 0, -50172, 2, NULL, NULL, NULL, NULL, NULL, NULL, 6, NULL, NULL, NULL, 0),
	(162, 1, 0, -50171, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(162, 1, 0, -50170, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(162, 1, 0, -50169, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(162, 1, 0, -50168, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(162, 1, 0, -50167, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(162, 1, 0, -50166, 2, NULL, NULL, NULL, NULL, NULL, NULL, 30, NULL, NULL, NULL, 0),
	(162, 1, 0, -50165, 2, NULL, NULL, NULL, NULL, NULL, NULL, 30, NULL, NULL, NULL, 0),
	(162, 1, 0, -50164, 2, NULL, NULL, NULL, NULL, NULL, NULL, 30, NULL, NULL, NULL, 0),
	(162, 1, 0, -50163, 2, NULL, NULL, NULL, NULL, NULL, NULL, 30, NULL, NULL, NULL, 0),
	(162, 1, 0, -50087, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(185, 1, 1, -50484, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(185, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(188, 1, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(188, 1, 1, -50320, 1, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(188, 1, 1, 10841, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(189, 1, 1, -50517, 2, 6, 'CalendarID', NULL, NULL, NULL, NULL, 8, NULL, 0, NULL, 0),
	(189, 1, 1, -50516, 3, 6, 'CalendarID', NULL, NULL, NULL, NULL, 8, NULL, 0, NULL, 0),
	(189, 1, 1, -50515, 2, 6, 'CalendarID', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(189, 1, 1, -50514, 2, 6, 'CalendarID', NULL, NULL, NULL, NULL, 16, NULL, 0, NULL, 0),
	(189, 1, 1, -50513, 3, 6, 'CalendarID', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(189, 1, 1, -50512, 2, 3, 'CalendarID', NULL, NULL, NULL, NULL, 10, NULL, 0, NULL, 0),
	(189, 1, 1, -50511, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(189, 1, 1, -50456, 2, 3, 'CalendarID', NULL, NULL, NULL, NULL, 16, NULL, 0, NULL, 0),
	(189, 1, 1, -50417, 2, 3, 'CalendarID', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(189, 1, 1, -50347, 2, 3, 'CalendarID', 4, 'WeekNr', NULL, NULL, 7, NULL, 0, NULL, 0),
	(189, 1, 1, -50337, 3, 3, 'CalendarID', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(189, 1, 1, -50319, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(189, 1, 1, -50127, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(189, 1, 1, -50102, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(189, 1, 1, -50097, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(189, 1, 1, -50020, 2, 3, 'CalendarID', 6, 'DayNr', NULL, NULL, 8, NULL, 0, NULL, 0),
	(189, 1, 1, -50019, 3, 3, 'CalendarID', 6, 'DayNr', NULL, NULL, 8, NULL, 0, NULL, 0),
	(189, 1, 1, -50010, 2, 3, 'CalendarID', NULL, NULL, NULL, NULL, 4, NULL, 0, NULL, 0),
	(189, 1, 1, -50008, 3, 3, 'CalendarID', NULL, NULL, NULL, NULL, 4, NULL, 0, NULL, 0),
	(189, 1, 1, -50007, 2, 3, 'CalendarID', NULL, NULL, NULL, NULL, 40, NULL, 0, NULL, 0),
	(189, 1, 1, -50006, 3, 3, 'CalendarID', NULL, NULL, NULL, NULL, 40, NULL, 0, NULL, 0),
	(189, 1, 1, -50005, 3, 3, 'CalendarID', NULL, NULL, NULL, NULL, 10, NULL, 0, NULL, 0),
	(189, 1, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(189, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(189, 1, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(197, 1, 0, -50322, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 1, 0, -50321, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 12, 0, NULL, NULL, 0),
	(197, 1, 0, -50320, 1, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 1, 0, -50319, 1, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 1, 0, -50318, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(197, 1, 0, -50317, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(197, 1, 0, -50316, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50315, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50314, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50313, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50312, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50311, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50310, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50309, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50308, 2, 7, 'ProfileNr', 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50307, 2, 7, 'ProfileNr', 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50306, 2, 7, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50305, 2, 7, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50304, 2, 7, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50303, 1, 7, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50302, 2, 7, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50301, 2, 7, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50300, 3, 7, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50298, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50297, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50296, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50295, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(197, 1, 0, -50294, 5, NULL, NULL, NULL, NULL, NULL, NULL, 7, NULL, NULL, NULL, 0),
	(197, 1, 0, -50293, 5, NULL, NULL, NULL, NULL, NULL, NULL, 45, NULL, NULL, NULL, 0),
	(197, 1, 0, -50292, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50291, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50290, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50289, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50287, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50286, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50285, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50284, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(197, 1, 0, -50283, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(197, 1, 0, -50282, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(197, 1, 0, -50281, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50280, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50279, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50278, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50277, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50276, 3, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50275, 5, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50274, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50273, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50272, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50271, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50270, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50269, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50268, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50267, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50266, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50265, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50264, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(197, 1, 0, -50263, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50262, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50261, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50260, 2, 256, 'Channel', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(197, 1, 0, -50259, 2, 256, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50258, 2, 256, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50257, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 7, NULL, NULL, NULL, 0),
	(197, 1, 0, -50256, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50255, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50254, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50253, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50252, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50251, 5, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(197, 1, 0, -50250, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50249, 3, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 1, 0, -50248, 3, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50247, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50246, 3, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50245, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50244, 5, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50243, 5, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50242, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50241, 1, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 1, 0, -50240, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50239, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50238, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50237, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50236, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50235, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50234, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50233, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50232, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50231, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50230, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50229, 5, NULL, NULL, NULL, NULL, NULL, NULL, 7, NULL, NULL, NULL, 0),
	(197, 1, 0, -50228, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50227, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50226, 3, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(197, 1, 0, -50225, 3, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(197, 1, 0, -50224, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50223, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50222, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50221, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(197, 1, 0, -50220, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(197, 1, 0, -50219, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(197, 1, 0, -50218, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(197, 1, 0, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(197, 1, 0, -50216, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(197, 1, 0, -50215, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(197, 1, 0, -50214, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50213, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50212, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50211, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50210, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50209, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50208, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50207, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50206, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(197, 1, 0, -50205, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50203, 2, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(197, 1, 0, -50202, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50201, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50200, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50199, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(197, 1, 0, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50181, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, 0, NULL, NULL, 0),
	(197, 1, 0, -50163, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(197, 1, 0, -50022, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(197, 1, 0, -50020, 2, NULL, NULL, 16, 'GraphNr', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(197, 1, 0, -50018, 2, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50017, 2, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50016, 2, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50015, 2, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50014, 2, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50013, 2, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50012, 2, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50011, 2, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50008, 3, NULL, NULL, 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50006, 3, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(197, 1, 0, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, -7, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(197, 1, 0, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(197, 1, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(197, 1, 0, 10010, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, 10011, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 0, 10292, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 0),
	(197, 1, 0, 10842, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 1, 0, 10843, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 1, 0, 10854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 1, 0, 10875, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(197, 1, 0, 10876, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 1, 0, 10887, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(197, 1, 0, 10888, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(197, 1, 1, 10010, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 1, 10011, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 1, 1, 10854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 1, 1, 10875, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(197, 1, 1, 10876, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 1, 1, 10887, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(197, 1, 1, 10888, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(197, 2, 0, -50332, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50331, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50330, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50329, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50328, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50327, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50326, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50325, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50324, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50323, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50322, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 2, 0, -50321, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 12, 0, NULL, NULL, 0),
	(197, 2, 0, -50320, 1, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 2, 0, -50319, 1, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 2, 0, -50318, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(197, 2, 0, -50317, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(197, 2, 0, -50316, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50315, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50314, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50313, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50312, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50311, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50310, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50309, 2, 16, 'TaskNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50308, 2, 7, 'ProfileNr', 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50307, 2, 7, 'ProfileNr', 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50306, 2, 7, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50305, 2, 7, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50304, 2, 7, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50303, 1, 7, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50302, 2, 7, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50301, 2, 7, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50300, 3, 7, 'ProfileNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50298, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50297, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50296, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50295, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(197, 2, 0, -50294, 5, NULL, NULL, NULL, NULL, NULL, NULL, 7, NULL, NULL, NULL, 0),
	(197, 2, 0, -50293, 5, NULL, NULL, NULL, NULL, NULL, NULL, 45, NULL, NULL, NULL, 0),
	(197, 2, 0, -50292, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50291, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50290, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50289, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50287, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50286, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50285, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50284, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(197, 2, 0, -50283, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(197, 2, 0, -50282, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(197, 2, 0, -50281, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50280, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50279, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50278, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50277, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50276, 3, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50275, 5, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50274, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50273, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50272, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50271, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50270, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50269, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50268, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50267, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50266, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50265, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50264, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(197, 2, 0, -50263, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50262, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50261, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50260, 2, 256, 'Channel', NULL, NULL, NULL, NULL, 8, NULL, NULL, NULL, 0),
	(197, 2, 0, -50259, 2, 256, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50258, 2, 256, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50257, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 7, NULL, NULL, NULL, 0),
	(197, 2, 0, -50256, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50255, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50254, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50253, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50252, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50251, 5, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(197, 2, 0, -50250, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50249, 3, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 2, 0, -50248, 3, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50247, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50246, 3, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50245, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50244, 5, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50243, 5, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50242, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50241, 1, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 2, 0, -50240, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50239, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50238, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50237, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50236, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50235, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50234, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50233, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50232, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50231, 2, 8, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50230, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50229, 5, NULL, NULL, NULL, NULL, NULL, NULL, 7, NULL, NULL, NULL, 0),
	(197, 2, 0, -50228, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50227, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50226, 3, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(197, 2, 0, -50225, 3, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(197, 2, 0, -50224, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50223, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50222, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50221, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(197, 2, 0, -50220, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(197, 2, 0, -50219, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(197, 2, 0, -50218, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(197, 2, 0, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(197, 2, 0, -50216, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(197, 2, 0, -50215, 2, NULL, NULL, NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(197, 2, 0, -50214, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50213, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50212, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50211, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50210, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50209, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50208, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50207, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50206, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(197, 2, 0, -50205, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50203, 2, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(197, 2, 0, -50199, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(197, 2, 0, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50181, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, 0, NULL, NULL, 0),
	(197, 2, 0, -50163, 2, 1000, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(197, 2, 0, -50022, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(197, 2, 0, -50020, 2, 4, 'GroupNr', 16, 'GraphNr', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(197, 2, 0, -50018, 2, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50017, 2, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50016, 2, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50015, 2, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50014, 2, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50013, 2, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50012, 2, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50011, 2, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50008, 3, 4, 'GroupNr', 12, 'ProgNr', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50006, 3, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(197, 2, 0, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, -7, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(197, 2, 0, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(197, 2, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(197, 2, 0, 10010, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, 10011, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 0, 10292, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 1, 0),
	(197, 2, 0, 10842, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 2, 0, 10843, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 2, 0, 10854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 2, 0, 10875, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(197, 2, 0, 10876, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 2, 0, 10887, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(197, 2, 0, 10888, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(197, 2, 1, 10010, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 1, 10011, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(197, 2, 1, 10854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 2, 1, 10875, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(197, 2, 1, 10876, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(197, 2, 1, 10887, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(197, 2, 1, 10888, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(200, 1, 0, -50485, 2, 3, 'System', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(200, 1, 0, -50484, 2, 3, 'System', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(200, 1, 1, -50485, 2, 3, 'System', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(200, 1, 1, -50484, 2, 3, 'System', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(200, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(200, 1, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(203, 1, 1, -50360, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(203, 1, 1, 10946, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(205, 1, 0, 10010, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(205, 1, 0, 10854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(206, 1, 1, 10010, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(206, 1, 1, 10854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50461, 5, NULL, NULL, NULL, NULL, NULL, NULL, 40, NULL, NULL, NULL, 0),
	(207, 1, 1, -50460, 5, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 1, 1, -50459, 5, NULL, NULL, NULL, NULL, NULL, NULL, 48, NULL, NULL, NULL, 0),
	(207, 1, 1, -50458, 5, NULL, NULL, NULL, NULL, NULL, NULL, 5, NULL, NULL, NULL, 0),
	(207, 1, 1, -50457, 5, NULL, NULL, NULL, NULL, NULL, NULL, 34, NULL, NULL, NULL, 0),
	(207, 1, 1, -50456, 5, NULL, NULL, NULL, NULL, NULL, NULL, 28, NULL, NULL, NULL, 0),
	(207, 1, 1, -50455, 5, NULL, NULL, NULL, NULL, NULL, NULL, 27, NULL, NULL, NULL, 0),
	(207, 1, 1, -50454, 5, NULL, NULL, NULL, NULL, NULL, NULL, 63, NULL, NULL, NULL, 0),
	(207, 1, 1, -50453, 5, NULL, NULL, NULL, NULL, NULL, NULL, 104, NULL, NULL, NULL, 0),
	(207, 1, 1, -50452, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50451, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50450, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50449, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50448, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50447, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50446, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50445, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50444, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50443, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50442, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50441, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50440, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50439, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50438, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50437, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50436, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50435, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50434, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50433, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50432, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50431, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50430, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50429, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50428, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50427, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50426, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50423, 5, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(207, 1, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(207, 1, 1, -50373, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50372, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50371, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50370, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50369, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50320, 1, 4, 'Channel', NULL, NULL, NULL, NULL, 5, NULL, NULL, NULL, 0),
	(207, 1, 1, -50319, 1, 4, 'Channel', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(207, 1, 1, -50222, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(207, 1, 1, -50196, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(207, 1, 1, -50182, 2, 3, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50181, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(207, 1, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(207, 1, 1, -50066, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50063, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -50020, 2, 36, 'GraphNr', NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 1, 1, -50019, 3, 36, 'GraphNr', NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 1, 1, -50018, 2, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(207, 1, 1, -50017, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 1, 1, -50016, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 1, 1, -50015, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 1, 1, -50014, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 1, 1, -50013, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 1, 1, -50012, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 1, 1, -50011, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 1, 1, -50008, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 1, 1, -50006, 3, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(207, 1, 1, -10, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -9, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(207, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(207, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 1, 1, 10854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50462, 1, 2, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(207, 2, 1, -50461, 5, NULL, NULL, NULL, NULL, NULL, NULL, 40, NULL, NULL, NULL, 0),
	(207, 2, 1, -50460, 5, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 2, 1, -50459, 5, NULL, NULL, NULL, NULL, NULL, NULL, 48, NULL, NULL, NULL, 0),
	(207, 2, 1, -50458, 5, NULL, NULL, NULL, NULL, NULL, NULL, 5, NULL, NULL, NULL, 0),
	(207, 2, 1, -50457, 5, NULL, NULL, NULL, NULL, NULL, NULL, 34, NULL, NULL, NULL, 0),
	(207, 2, 1, -50456, 5, NULL, NULL, NULL, NULL, NULL, NULL, 28, NULL, NULL, NULL, 0),
	(207, 2, 1, -50455, 5, NULL, NULL, NULL, NULL, NULL, NULL, 27, NULL, NULL, NULL, 0),
	(207, 2, 1, -50454, 5, NULL, NULL, NULL, NULL, NULL, NULL, 63, NULL, NULL, NULL, 0),
	(207, 2, 1, -50453, 5, NULL, NULL, NULL, NULL, NULL, NULL, 104, NULL, NULL, NULL, 0),
	(207, 2, 1, -50452, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50451, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50450, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50449, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50448, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50447, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50446, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50445, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50444, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50443, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50442, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50441, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50440, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50439, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50438, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50437, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50436, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50435, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50434, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50433, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50432, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50431, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50430, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50429, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50428, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50427, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50426, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50423, 5, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(207, 2, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(207, 2, 1, -50373, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50372, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50371, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50370, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50369, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50320, 1, 2, 'Channel', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50319, 1, 2, 'Channel', NULL, NULL, NULL, NULL, 4, NULL, NULL, NULL, 0),
	(207, 2, 1, -50222, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(207, 2, 1, -50196, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(207, 2, 1, -50182, 2, 3, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50181, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(207, 2, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(207, 2, 1, -50066, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50063, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -50020, 2, 36, 'GraphNr', NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 2, 1, -50019, 3, 36, 'GraphNr', NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 2, 1, -50018, 2, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(207, 2, 1, -50017, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 2, 1, -50016, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 2, 1, -50015, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 2, 1, -50014, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 2, 1, -50013, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 2, 1, -50012, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 2, 1, -50011, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 2, 1, -50008, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(207, 2, 1, -50006, 3, NULL, NULL, NULL, NULL, NULL, NULL, 64, NULL, NULL, NULL, 0),
	(207, 2, 1, -10, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -9, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(207, 2, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(207, 2, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(207, 2, 1, 10854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 1, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 1, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 1, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 1, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 1, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 1, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 1, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 1, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 1, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 1, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 1, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 1, 1, -50380, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50379, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50320, 1, 8, 'TariffNr', 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50319, 1, 8, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 1, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 1, 1, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 1, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 1, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 1, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 1, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 1, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 1, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 1, 1, -50025, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 1, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 1, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 1, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 2, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 2, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 2, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 2, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 2, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 2, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 2, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 2, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 2, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 2, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 2, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 2, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50376, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 2, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50320, 1, 8, 'TariffNr', 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50319, 1, 8, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 2, 1, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 2, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 2, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 2, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 2, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 2, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 2, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 2, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 2, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 2, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 2, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 3, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 3, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 3, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 3, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 3, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 3, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 3, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 3, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 3, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 3, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 3, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 3, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50376, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 3, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50320, 1, 8, 'TariffNr', 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50319, 1, 8, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 3, 1, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 3, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 3, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 3, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 3, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 3, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 3, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 3, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 3, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 3, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 3, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 4, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 4, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 4, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 4, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 4, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 4, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 4, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 4, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 4, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 4, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 4, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 4, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50320, 1, 8, 'TariffNr', 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50319, 1, 8, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(208, 4, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 4, 1, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 4, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 4, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 4, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 4, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 4, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 4, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 4, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 4, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 4, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 4, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 5, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 5, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 5, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 5, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 5, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 5, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 5, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 5, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 5, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 5, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 5, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 5, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50320, 1, 8, 'TariffNr', 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50319, 1, 8, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(208, 5, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 5, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 5, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 5, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 5, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 5, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 5, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 5, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 5, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 5, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 5, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 5, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 6, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 6, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 6, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 6, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 6, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 6, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 6, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 6, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 6, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 6, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 6, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 6, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50320, 1, 8, 'TariffNr', 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50319, 1, 8, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(208, 6, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 6, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 6, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 6, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 6, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 6, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 6, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 6, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 6, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 6, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 6, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 6, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 7, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 7, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 7, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 7, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 7, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 7, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 7, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 7, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 7, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 7, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 7, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 7, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 7, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 7, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 7, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 7, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 7, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 7, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 7, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 7, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 7, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 7, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 7, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 7, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 7, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 7, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 7, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 7, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 7, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 7, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 7, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 7, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 7, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 7, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 7, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 8, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 8, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 8, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 8, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 8, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 8, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 8, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 8, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 8, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 8, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 8, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 8, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 8, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 8, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 8, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 8, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 8, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 8, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 8, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 8, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 8, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 8, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 8, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 8, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 8, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 8, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 8, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 8, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 8, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 8, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 8, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 8, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 8, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 8, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 8, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 9, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 9, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 9, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 9, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 9, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 9, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 9, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 9, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 9, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 9, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 9, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 9, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 9, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50376, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 9, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50319, 1, 1, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 9, 1, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 9, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 9, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 9, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 9, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 9, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 9, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 9, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 9, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 9, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 9, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 10, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 10, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 10, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 10, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 10, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 10, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 10, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 10, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 10, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 10, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 10, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 10, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50376, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 10, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50319, 1, 1, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 10, 1, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 10, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 10, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 10, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 10, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 10, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 10, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 10, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 10, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 10, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 10, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50401, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 11, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 11, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 11, 1, -50398, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 11, 1, -50397, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 11, 1, -50396, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 11, 1, -50395, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 11, 1, -50394, 2, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 11, 1, -50393, 3, 12, 'Index', NULL, NULL, NULL, NULL, 16, NULL, NULL, NULL, 0),
	(208, 11, 1, -50392, 1, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50389, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50387, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50385, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 11, 1, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50383, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50382, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 11, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 11, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50377, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50375, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50374, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50359, 2, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50319, 1, 1, 'TariffNr', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 2, NULL, NULL, NULL, 0),
	(208, 11, 1, -50199, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 11, 1, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 11, 1, -50196, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 11, 1, -50182, 2, 2, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50181, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(208, 11, 1, -50099, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50092, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 11, 1, -50089, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 11, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 11, 1, -50026, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 11, 1, -50006, 3, 32, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 11, 1, -3, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(208, 11, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(208, 11, 1, 10109, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50511, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50500, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(209, 1, 1, -50499, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(209, 1, 1, -50498, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(209, 1, 1, -50497, 3, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(209, 1, 1, -50496, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(209, 1, 1, -50495, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(209, 1, 1, -50494, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(209, 1, 1, -50493, 3, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(209, 1, 1, -50491, 2, 500, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(209, 1, 1, -50490, 3, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(209, 1, 1, -50489, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(209, 1, 1, -50488, 3, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(209, 1, 1, -50416, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50415, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50414, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50413, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50412, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50411, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50410, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50409, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50408, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50407, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50406, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50405, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50404, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50403, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50402, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50359, 2, NULL, NULL, NULL, NULL, NULL, NULL, 80, NULL, 0, NULL, 0),
	(209, 1, 1, -50358, 3, NULL, NULL, NULL, NULL, NULL, NULL, 80, NULL, 0, NULL, 0),
	(209, 1, 1, -50357, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50356, 2, NULL, NULL, NULL, NULL, NULL, NULL, 128, NULL, NULL, NULL, 0),
	(209, 1, 1, -50355, 2, NULL, NULL, NULL, NULL, NULL, NULL, 128, NULL, NULL, NULL, 0),
	(209, 1, 1, -50352, 3, NULL, NULL, NULL, NULL, NULL, NULL, 128, NULL, NULL, NULL, 0),
	(209, 1, 1, -50351, 3, NULL, NULL, NULL, NULL, NULL, NULL, 128, NULL, NULL, NULL, 0),
	(209, 1, 1, -50348, 2, NULL, NULL, NULL, NULL, NULL, NULL, 105, NULL, NULL, NULL, 0),
	(209, 1, 1, -50347, 2, NULL, NULL, NULL, NULL, NULL, NULL, 105, NULL, NULL, NULL, 0),
	(209, 1, 1, -50344, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(209, 1, 1, -50343, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(209, 1, 1, -50342, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(209, 1, 1, -50341, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(209, 1, 1, -50338, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50337, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50336, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50319, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50304, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50222, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, 3, NULL, NULL, NULL, 0),
	(209, 1, 1, -50163, 2, 4, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50078, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(209, 1, 1, -50073, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(209, 1, 1, -50022, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -31, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(209, 1, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(209, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(209, 1, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(209, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(209, 1, 1, 10881, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(210, 1, 1, -50847, 3, NULL, NULL, NULL, NULL, NULL, NULL, 6, NULL, 0, NULL, 0),
	(210, 1, 1, -50846, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, 0, NULL, 0),
	(210, 1, 1, -50845, 3, 6, 'Channel', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(210, 1, 1, -50844, 3, 6, 'Channel', NULL, NULL, NULL, NULL, 12, NULL, 0, NULL, 0),
	(210, 1, 1, -50843, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(210, 1, 1, -50842, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(210, 1, 1, -50697, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(210, 1, 1, -50696, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(210, 1, 1, -50695, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(210, 1, 1, -50672, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(210, 1, 1, -50564, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(210, 1, 1, -50554, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(210, 1, 1, -50288, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(210, 1, 1, -50079, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(210, 1, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(210, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(210, 1, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(215, 1, 0, -50477, 2, 1000, 'MeterNr', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(215, 1, 0, -50476, 4, 1000, 'MeterNr', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(215, 1, 0, -50475, 3, 1000, 'MeterNr', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(215, 1, 0, -50474, 3, 1000, 'MeterNr', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(215, 1, 0, -50473, 3, 1000, 'MeterNr', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(215, 1, 0, -50472, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(215, 1, 0, -50471, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(215, 1, 0, -50470, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(215, 1, 0, -50469, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(215, 1, 0, -50468, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(215, 1, 0, -50467, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(215, 1, 0, -5, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(215, 1, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(215, 1, 0, 10843, 2, 1000, 'MeterNr', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(232, 1, 0, -50510, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(232, 1, 0, -50416, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50415, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50414, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50413, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50412, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50411, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50410, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50409, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50408, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50407, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50406, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50405, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50404, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50403, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50402, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50357, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50356, 2, NULL, NULL, NULL, NULL, NULL, NULL, 128, NULL, NULL, NULL, 0),
	(232, 1, 0, -50355, 2, NULL, NULL, NULL, NULL, NULL, NULL, 128, NULL, NULL, NULL, 0),
	(232, 1, 0, -50352, 3, NULL, NULL, NULL, NULL, NULL, NULL, 128, NULL, NULL, NULL, 0),
	(232, 1, 0, -50351, 3, NULL, NULL, NULL, NULL, NULL, NULL, 128, NULL, NULL, NULL, 0),
	(232, 1, 0, -50348, 2, NULL, NULL, NULL, NULL, NULL, NULL, 105, NULL, NULL, NULL, 0),
	(232, 1, 0, -50347, 2, NULL, NULL, NULL, NULL, NULL, NULL, 105, NULL, NULL, NULL, 0),
	(232, 1, 0, -50344, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(232, 1, 0, -50343, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(232, 1, 0, -50342, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(232, 1, 0, -50341, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(232, 1, 0, -50338, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50337, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50336, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50319, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50222, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50163, 3, NULL, NULL, NULL, NULL, NULL, NULL, 100, NULL, 0, NULL, 0),
	(232, 1, 0, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50078, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(232, 1, 0, -1, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(232, 1, 1, -50511, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(232, 1, 1, -50500, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(232, 1, 1, -50499, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(232, 1, 1, -50498, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(232, 1, 1, -50497, 3, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(232, 1, 1, -50496, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(232, 1, 1, -50495, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(232, 1, 1, -50494, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(232, 1, 1, -50493, 3, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(232, 1, 1, -50491, 2, 500, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(232, 1, 1, -50490, 3, NULL, NULL, NULL, NULL, NULL, NULL, 100, NULL, 0, NULL, 0),
	(232, 1, 1, -50489, 2, NULL, NULL, NULL, NULL, NULL, NULL, 100, NULL, 0, NULL, 0),
	(232, 1, 1, -50488, 3, NULL, NULL, NULL, NULL, NULL, NULL, 100, NULL, 0, NULL, 0),
	(232, 1, 1, -50304, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(232, 1, 1, -50022, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 1, -31, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(232, 1, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(232, 1, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(232, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(234, 1, 0, -50487, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(234, 1, 0, -50486, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(234, 1, 0, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(234, 1, 0, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(234, 1, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(234, 1, 1, -50487, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(234, 1, 1, -50486, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(234, 1, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(234, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(234, 1, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(243, 1, 0, -50945, 3, 2048, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(243, 1, 0, -50944, 3, 2048, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(243, 1, 0, -50943, 3, 2048, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(243, 1, 0, -50942, 3, 2048, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(243, 1, 0, -50941, 5, 2048, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50940, 5, 2048, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50939, 2, 2048, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50938, 2, 2048, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50937, 5, 2048, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50934, 5, 4, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50933, 5, 4, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50932, 5, 4, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50931, 5, 4, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50930, 5, 4, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50929, 5, 4, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50928, 2, 4, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50927, 4, 4, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50926, 5, 4, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50924, 3, 2048, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(243, 1, 0, -50553, 3, 2048, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(243, 1, 0, -50512, 2, 92, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50378, 3, 2048, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(243, 1, 0, -50242, 3, 2048, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(243, 1, 0, -50020, 2, 32, 'Axis1', 4, 'Axis2', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(243, 1, 0, -50017, 2, 12, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50016, 2, 12, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50015, 2, 12, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50014, 2, 12, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50013, 2, 12, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50012, 2, 12, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50011, 2, 12, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50008, 4, 12, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50007, 2, 16, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50006, 4, 16, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -50005, 4, 92, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(243, 1, 0, -10, 3, 2048, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(243, 1, 0, -9, 3, 2048, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(244, 1, 0, -50610, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50598, 3, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50597, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50596, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50595, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50594, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50593, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50592, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50590, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50589, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50588, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50587, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50586, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50585, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50584, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50583, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50582, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50581, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50580, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50579, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50578, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50576, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50575, 2, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50574, 2, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50573, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50572, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50571, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50570, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50569, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50568, 2, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50567, 2, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50566, 5, NULL, NULL, NULL, NULL, NULL, NULL, 31, NULL, NULL, NULL, 0),
	(244, 1, 0, -50565, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50564, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50553, 3, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50540, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50519, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(244, 1, 0, -50503, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50486, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50470, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50288, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50225, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50213, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(244, 1, 0, -50166, 2, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, -50101, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -50044, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(244, 1, 0, -1, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(244, 1, 0, 10283, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 1, 0, 10930, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 1, 0, 11197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(244, 1, 1, 10010, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50841, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50840, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50839, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50838, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50837, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50836, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50835, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50834, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50833, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50832, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50831, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50830, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50829, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50828, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50827, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50826, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50825, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50824, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50823, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50822, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50821, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50820, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50819, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50818, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50817, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50816, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50815, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50814, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50813, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50812, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50610, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50598, 3, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50597, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50596, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50595, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50594, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50593, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50592, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50590, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50589, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50588, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50587, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50586, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50585, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50584, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50583, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50582, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50581, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50580, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50579, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50578, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50576, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50575, 2, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50574, 2, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50573, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50572, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50571, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50570, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50569, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50568, 2, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50567, 2, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50566, 5, NULL, NULL, NULL, NULL, NULL, NULL, 31, NULL, NULL, NULL, 0),
	(244, 2, 0, -50565, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50564, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50553, 3, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50540, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50519, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(244, 2, 0, -50503, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50486, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50470, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50288, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50225, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50213, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(244, 2, 0, -50166, 2, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, -50101, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -50044, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(244, 2, 0, -1, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, 0),
	(244, 2, 0, 10283, 5, 1024, 'MeterID', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(244, 2, 0, 10930, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(244, 2, 0, 11197, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(244, 2, 1, 10010, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50510, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(248, 1, 0, -50416, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50415, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50414, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50413, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50412, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50411, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50410, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50409, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50408, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50407, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50406, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50405, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50404, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50403, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50402, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50357, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50356, 2, NULL, NULL, NULL, NULL, NULL, NULL, 128, NULL, NULL, NULL, 0),
	(248, 1, 0, -50355, 2, NULL, NULL, NULL, NULL, NULL, NULL, 128, NULL, NULL, NULL, 0),
	(248, 1, 0, -50352, 3, NULL, NULL, NULL, NULL, NULL, NULL, 128, NULL, NULL, NULL, 0),
	(248, 1, 0, -50351, 3, NULL, NULL, NULL, NULL, NULL, NULL, 128, NULL, NULL, NULL, 0),
	(248, 1, 0, -50348, 2, NULL, NULL, NULL, NULL, NULL, NULL, 105, NULL, NULL, NULL, 0),
	(248, 1, 0, -50347, 2, NULL, NULL, NULL, NULL, NULL, NULL, 105, NULL, NULL, NULL, 0),
	(248, 1, 0, -50344, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(248, 1, 0, -50343, 2, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(248, 1, 0, -50342, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(248, 1, 0, -50341, 3, NULL, NULL, NULL, NULL, NULL, NULL, 12, NULL, NULL, NULL, 0),
	(248, 1, 0, -50338, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50337, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50336, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50319, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50222, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50163, 3, NULL, NULL, NULL, NULL, NULL, NULL, 100, NULL, 0, NULL, 0),
	(248, 1, 0, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50078, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(248, 1, 0, -1, 4, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(248, 1, 1, -50511, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(248, 1, 1, -50500, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(248, 1, 1, -50499, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(248, 1, 1, -50498, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(248, 1, 1, -50497, 3, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(248, 1, 1, -50496, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(248, 1, 1, -50495, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(248, 1, 1, -50494, 2, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(248, 1, 1, -50493, 3, NULL, NULL, NULL, NULL, NULL, NULL, 500, NULL, 0, NULL, 0),
	(248, 1, 1, -50491, 2, 500, 'Index', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(248, 1, 1, -50490, 3, NULL, NULL, NULL, NULL, NULL, NULL, 100, NULL, 0, NULL, 0),
	(248, 1, 1, -50489, 2, NULL, NULL, NULL, NULL, NULL, NULL, 100, NULL, 0, NULL, 0),
	(248, 1, 1, -50488, 3, NULL, NULL, NULL, NULL, NULL, NULL, 100, NULL, 0, NULL, 0),
	(248, 1, 1, -50304, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(248, 1, 1, -50022, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 1, -31, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(248, 1, 1, -8, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(248, 1, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(248, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(249, 1, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(249, 1, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(249, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(249, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(249, 1, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(251, 1, 1, -50400, 2, 30, 'Index', NULL, NULL, NULL, NULL, 48, NULL, NULL, NULL, 0),
	(251, 1, 1, -50098, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(251, 1, 1, -50097, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(251, 1, 1, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(251, 1, 1, -50020, 2, 12, 'MonthNr', 7, 'WeekDayNr', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(251, 1, 1, -50006, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(251, 1, 1, -50003, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(251, 1, 1, -50002, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(251, 1, 1, -10, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(251, 1, 1, -9, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(251, 1, 1, -8, 2, 2, 'Index', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(251, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(251, 1, 1, -3, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(252, 1, 1, -50381, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(252, 1, 1, -1, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(252, 1, 1, 10010, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(252, 1, 1, 10011, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(252, 1, 1, 10854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(252, 1, 1, 10951, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50946, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50547, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(253, 1, 0, -50546, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50545, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50543, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50542, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50541, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50540, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50539, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50538, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50537, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50536, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50535, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50534, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50533, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50532, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(253, 1, 0, -50531, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50530, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50529, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50528, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50527, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50526, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50525, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50524, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50523, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50522, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50521, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50520, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50486, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(253, 1, 0, -50277, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(253, 1, 0, -50087, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(253, 1, 0, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(253, 1, 0, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(253, 1, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(255, 1, 0, -50600, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(255, 1, 0, -50599, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(255, 1, 0, -50563, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(255, 1, 0, -50562, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(255, 1, 0, -50550, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(255, 1, 0, -50549, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(255, 1, 0, -50548, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(255, 1, 0, -50547, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(255, 1, 0, -50541, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(255, 1, 0, -50540, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(255, 1, 0, -50539, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(255, 1, 0, -50538, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(255, 1, 0, -50537, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(255, 1, 0, -50535, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(255, 1, 0, -50532, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(255, 1, 0, -50521, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(255, 1, 0, -50277, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(255, 1, 0, -50087, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(255, 1, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(256, 1, 0, -50600, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(256, 1, 0, -50599, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(256, 1, 0, -50563, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(256, 1, 0, -50562, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(256, 1, 0, -50550, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(256, 1, 0, -50549, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(256, 1, 0, -50548, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(256, 1, 0, -50547, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(256, 1, 0, -50541, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(256, 1, 0, -50540, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(256, 1, 0, -50539, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(256, 1, 0, -50538, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(256, 1, 0, -50537, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(256, 1, 0, -50535, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(256, 1, 0, -50532, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(256, 1, 0, -50521, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(256, 1, 0, -50277, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(256, 1, 0, -50087, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(256, 1, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(257, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(257, 1, 1, -1, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(283, 1, 1, -50936, 2, NULL, NULL, NULL, NULL, NULL, NULL, 14, NULL, NULL, NULL, 0),
	(283, 1, 1, -50935, 2, NULL, NULL, NULL, NULL, NULL, NULL, 14, NULL, 0, NULL, 0),
	(283, 1, 1, -50691, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(283, 1, 1, -50636, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(283, 1, 1, -50635, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(283, 1, 1, -50553, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(283, 1, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(283, 1, 1, -50357, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(283, 1, 1, -50352, 3, NULL, NULL, NULL, NULL, NULL, NULL, 14, NULL, NULL, NULL, 0),
	(283, 1, 1, -50351, 3, NULL, NULL, NULL, NULL, NULL, NULL, 14, NULL, 0, NULL, 0),
	(283, 1, 1, -50073, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(283, 1, 1, -18, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(283, 1, 1, -1, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(283, 1, 1, 10010, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50690, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50689, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50688, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50687, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50686, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50685, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50684, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50683, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50682, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50681, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50680, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50679, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50678, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50677, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50676, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50675, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50674, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50673, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50672, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50670, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50669, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50668, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50629, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50628, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50627, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50626, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50625, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50624, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50623, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50622, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50620, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50619, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50618, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50574, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50560, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50557, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50552, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50417, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50400, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50399, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50398, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50397, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50396, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50395, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50382, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -50166, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50073, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(284, 1, 1, -50006, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -18, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -10, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -9, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(284, 1, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(285, 1, 0, -50946, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50547, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(285, 1, 0, -50546, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50545, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50543, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50542, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50541, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50540, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50539, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50538, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50537, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50536, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50535, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50534, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50533, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50532, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(285, 1, 0, -50531, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50530, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50529, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50528, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50527, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50526, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50525, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50524, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50523, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50522, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50521, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50520, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50486, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(285, 1, 0, -50277, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(285, 1, 0, -50087, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(285, 1, 0, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(285, 1, 0, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(285, 1, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(287, 1, 1, -50608, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(287, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(287, 1, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(288, 1, 1, -50936, 2, NULL, NULL, NULL, NULL, NULL, NULL, 14, NULL, NULL, NULL, 0),
	(288, 1, 1, -50935, 2, NULL, NULL, NULL, NULL, NULL, NULL, 14, NULL, 0, NULL, 0),
	(288, 1, 1, -50691, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(288, 1, 1, -50636, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(288, 1, 1, -50635, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(288, 1, 1, -50553, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(288, 1, 1, -50378, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(288, 1, 1, -50357, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(288, 1, 1, -50352, 3, NULL, NULL, NULL, NULL, NULL, NULL, 14, NULL, NULL, NULL, 0),
	(288, 1, 1, -50351, 3, NULL, NULL, NULL, NULL, NULL, NULL, 14, NULL, 0, NULL, 0),
	(288, 1, 1, -50073, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(288, 1, 1, -18, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(288, 1, 1, -1, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(288, 1, 1, 10010, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(290, 1, 0, -50651, 3, 64, 'MeterID', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(290, 1, 0, -50650, 3, 64, 'MeterID', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(290, 1, 0, -50649, 3, 64, 'MeterID', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(290, 1, 0, -50648, 3, 64, 'MeterID', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(290, 1, 0, -50647, 3, 64, 'MeterID', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(290, 1, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(291, 1, 1, -50652, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(291, 1, 1, -50288, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(291, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(291, 1, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(291, 1, 1, -1, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(292, 1, 1, -50912, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 1, 1, -50911, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 1, 1, -50891, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 1, 1, -50881, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 1, 1, -50880, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 1, 1, -50879, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 1, 1, -50655, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 1, 1, -50654, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 1, 1, -50653, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 1, 1, -50574, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 1, 1, -50567, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 1, 1, -50560, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 1, 1, -50520, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 1, 1, -50440, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 1, 1, -50417, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 1, 1, -50400, 2, 2, 'Index', 12, 'MonthNr', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(292, 1, 1, -50398, 2, 2, 'Index', 12, 'MonthNr', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(292, 1, 1, -50396, 2, 2, 'Index', 12, 'MonthNr', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(292, 1, 1, -50394, 2, 2, 'Index', 12, 'MonthNr', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(292, 1, 1, -50377, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 1, 1, -50373, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 1, 1, -50359, 2, 2, 'Index', NULL, NULL, NULL, NULL, 45, NULL, NULL, NULL, 0),
	(292, 1, 1, -50358, 3, 2, 'Index', NULL, NULL, NULL, NULL, 45, NULL, NULL, NULL, 0),
	(292, 1, 1, -50288, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 1, 1, -50165, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 1, 1, -50079, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 1, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 1, 1, -50073, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 1, 1, -50040, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 1, 1, -50027, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 1, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(292, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 1, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(292, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(292, 2, 1, -50890, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -50889, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -50888, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -50887, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -50886, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -50885, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -50884, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -50881, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 2, 1, -50880, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 2, 1, -50879, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 2, 1, -50655, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 2, 1, -50654, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 2, 1, -50653, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 2, 1, -50574, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 2, 1, -50567, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -50560, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 2, 1, -50557, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 2, 1, -50440, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -50417, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -50400, 2, 2, 'Index', 12, 'MonthNr', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(292, 2, 1, -50398, 2, 2, 'Index', 12, 'MonthNr', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(292, 2, 1, -50396, 2, 2, 'Index', 12, 'MonthNr', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(292, 2, 1, -50394, 2, 2, 'Index', 12, 'MonthNr', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(292, 2, 1, -50377, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -50373, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -50359, 2, 2, 'Index', NULL, NULL, NULL, NULL, 45, NULL, NULL, NULL, 0),
	(292, 2, 1, -50358, 3, 2, 'Index', NULL, NULL, NULL, NULL, 45, NULL, NULL, NULL, 0),
	(292, 2, 1, -50288, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 2, 1, -50165, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 2, 1, -50102, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -50079, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -50078, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 2, 1, -50076, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 2, 1, -50040, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 2, 1, -50027, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -10, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -9, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 2, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(292, 2, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 2, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(292, 2, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(292, 2, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(292, 2, 1, 10951, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(292, 2, 1, 11293, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(292, 2, 1, 11294, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(292, 3, 1, -50913, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50910, 2, 5, 'Index', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50909, 2, 5, 'Index', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50908, 2, 5, 'Index', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50907, 2, 5, 'Index', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50906, 2, 5, 'Index', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50905, 2, 5, 'Index', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50904, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50903, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50902, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50901, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50900, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50899, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50898, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50897, 2, 2, 'Index', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50896, 2, 2, 'Index', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50895, 2, 2, 'Index', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50894, 5, 5, 'Index', NULL, NULL, NULL, NULL, 24, NULL, NULL, NULL, 0),
	(292, 3, 1, -50893, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50892, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50891, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50890, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50889, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50888, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50887, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50886, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50885, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50884, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50883, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50882, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50881, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50880, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50879, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50655, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50654, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50653, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50574, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50567, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50566, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50565, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50564, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50563, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50560, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50557, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50520, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50440, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50417, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50400, 2, 2, 'Index', 12, 'MonthNr', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(292, 3, 1, -50398, 2, 2, 'Index', 12, 'MonthNr', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(292, 3, 1, -50396, 2, 2, 'Index', 12, 'MonthNr', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(292, 3, 1, -50394, 2, 2, 'Index', 12, 'MonthNr', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(292, 3, 1, -50380, 2, 5, 'Index', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50377, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50373, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50370, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50369, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50367, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50359, 2, 2, 'Index', NULL, NULL, NULL, NULL, 45, NULL, NULL, NULL, 0),
	(292, 3, 1, -50358, 3, 2, 'Index', NULL, NULL, NULL, NULL, 45, NULL, NULL, NULL, 0),
	(292, 3, 1, -50319, 1, 5, 'Index', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50288, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50182, 2, 5, 'Index', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50165, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50102, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50079, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50078, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50076, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50040, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -50027, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -10, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -9, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -8, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(292, 3, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(292, 3, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(292, 3, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(292, 3, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(292, 3, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(292, 3, 1, 10951, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(292, 3, 1, 11293, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(292, 3, 1, 11294, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(296, 1, 1, -50851, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(296, 1, 1, -50850, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(296, 1, 1, -50849, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(296, 1, 1, -50848, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(296, 1, 1, -50564, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(296, 1, 1, -50079, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(296, 1, 1, -50078, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(296, 1, 1, -50077, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(296, 1, 1, -50076, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(296, 1, 1, -8, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(296, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(296, 1, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(299, 1, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(299, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(299, 1, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(303, 1, 1, -50694, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(303, 1, 1, -50373, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(306, 1, 1, 10010, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(306, 1, 1, 10011, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(337, 1, 1, -50496, 3, 2, 'Profile', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(337, 1, 1, -50495, 3, 2, 'Profile', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(337, 1, 1, -50494, 3, 2, 'Profile', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(337, 1, 1, -50493, 3, 2, 'Profile', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(337, 1, 1, -50491, 2, 2, 'Profile', NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(337, 1, 1, -50489, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(337, 1, 1, -50488, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(337, 1, 1, -50304, 3, 2, 'Profile', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(338, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(338, 1, 1, -1, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(346, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50878, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50877, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50876, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50875, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50874, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(348, 1, 0, -50873, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 0),
	(348, 1, 0, -50872, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50871, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(348, 1, 0, -50870, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(348, 1, 0, -50869, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(348, 1, 0, -50868, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(348, 1, 0, -50867, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50866, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50865, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50864, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50863, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50862, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50861, 3, 3, 'RESETPHONE', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(348, 1, 0, -50860, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50859, 3, 2, 'RESETTIME', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(348, 1, 0, -50858, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50857, 3, 5, 'PHONE', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(348, 1, 0, -50856, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50855, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50854, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50550, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50549, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50548, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50545, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50542, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50540, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50539, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50524, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50277, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -50217, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(348, 1, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(349, 1, 1, -50511, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(349, 1, 1, -50102, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(349, 1, 1, -50079, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(349, 1, 1, -50004, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(349, 1, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(352, 1, 1, -50079, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(352, 1, 1, -50075, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(352, 1, 1, -50074, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(352, 1, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(353, 1, 1, -50388, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(353, 1, 1, -50386, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(353, 1, 1, -50320, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(353, 1, 1, -50319, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(353, 1, 1, -50182, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(353, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(356, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(357, 1, 1, -50073, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(357, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(358, 1, 1, -50073, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(358, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(359, 1, 1, -50073, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(359, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(360, 1, 1, -50073, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(360, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(361, 1, 1, -50073, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(361, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(362, 1, 1, -50073, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(362, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(363, 1, 0, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(367, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(369, 1, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(370, 1, 1, -50921, 2, 12, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(370, 1, 1, -50920, 2, 12, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(370, 1, 1, -50919, 2, 12, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(370, 1, 1, -50918, 3, 12, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(370, 1, 1, -50489, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(370, 1, 1, -50488, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(370, 1, 1, -50304, 2, 12, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(371, 1, 1, -50921, 2, 3, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(371, 1, 1, -50920, 2, 3, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(371, 1, 1, -50919, 2, 3, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(371, 1, 1, -50918, 3, 3, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(371, 1, 1, -50489, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(371, 1, 1, -50488, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(371, 1, 1, -50304, 2, 3, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(372, 1, 1, -50921, 2, 12, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(372, 1, 1, -50920, 2, 12, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(372, 1, 1, -50919, 2, 12, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(372, 1, 1, -50918, 3, 12, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(372, 1, 1, -50489, 2, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(372, 1, 1, -50488, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(372, 1, 1, -50304, 2, 12, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(373, 1, 1, -50923, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(373, 1, 1, -50922, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(373, 1, 1, -3, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50925, 2, 4000, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50924, 1, 4000, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50594, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50593, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50592, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50583, 3, 2, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50553, 3, 4000, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50486, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50384, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50378, 2, 4000, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50331, 2, 4000, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50295, 2, 16, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50282, 2, 4000, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50267, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50246, 3, 4000, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50244, 5, 4000, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50242, 2, 4000, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50223, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50222, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50221, 2, 3, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50220, 2, 3, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50219, 2, 3, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50218, 2, 3, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50217, 2, 3, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50216, 2, 3, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50213, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50212, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50210, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50209, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50208, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50207, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50203, 2, 64, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50201, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50198, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50181, 3, 16, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50165, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50079, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50022, 3, 16, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50020, 2, 16, 'Axis1', 4, 'Axis2', NULL, NULL, 48, NULL, NULL, NULL, 0),
	(377, 1, 0, -50018, 2, 12, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50017, 2, 12, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50016, 2, 12, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50015, 2, 12, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50014, 2, 12, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50013, 2, 12, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50012, 2, 12, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50011, 2, 12, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50008, 4, 12, 'Axis1', 4, 'Axis2', NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50006, 4, 64, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL, 0),
	(377, 1, 0, -50003, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, -50002, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 0, 10842, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 1, -50310, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 1, -50163, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 1, 10010, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(377, 1, 1, 10011, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(379, 1, 0, -50373, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(379, 1, 0, -50163, 3, NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(379, 1, 1, -50921, 2, 2, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(379, 1, 1, -50920, 2, 2, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(379, 1, 1, -50919, 2, 2, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(379, 1, 1, -50918, 3, 2, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(379, 1, 1, -50491, 2, 300, 'Index', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(379, 1, 1, -50304, 2, 2, 'Axis1', NULL, NULL, NULL, NULL, 1, NULL, 0, NULL, 0),
	(382, 1, 1, -7, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(382, 1, 1, -5, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(382, 1, 1, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(382, 1, 1, 10010, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(382, 1, 1, 10011, 5, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(383, 1, 0, -50950, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(383, 1, 0, -50949, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(383, 1, 0, -50948, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(383, 1, 0, -50946, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(383, 1, 0, -50542, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(383, 1, 0, -50540, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(383, 1, 0, -50534, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(383, 1, 0, -50530, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(383, 1, 0, -50528, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(383, 1, 0, -50526, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(383, 1, 0, -50524, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(383, 1, 0, -50523, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(383, 1, 0, -3, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0),
	(384, 1, 1, -8, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(385, 1, 1, -8, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(385, 1, 1, 1115, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(385, 1, 1, 1116, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(385, 1, 1, 1156, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(385, 1, 1, 1170, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(385, 1, 1, 1172, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(386, 1, 1, -8, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(386, 1, 1, 1115, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(386, 1, 1, 1116, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(386, 1, 1, 1156, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(386, 1, 1, 1170, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(387, 1, 1, -8, 3, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1),
	(387, 1, 1, 1115, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(387, 1, 1, 1116, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0),
	(387, 1, 1, 1156, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0);
/*!40000 ALTER TABLE `src_type_mod_withe` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod_withe#const
CREATE TABLE IF NOT EXISTS `src_type_mod_withe#const` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `is_point` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  PRIMARY KEY (`src_type_id`,`src_type_mod_nr`,`is_point`,`withe_id`,`ind1`,`ind2`,`ind3`),
  CONSTRAINT `src_type_mod_withe#const_wfk` FOREIGN KEY (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) REFERENCES `src_type_mod_withe` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Prietaisų modifikacijų konfigūracinių masyvinių parametrų elementai, kurių reikšmės pastovios tai pačiai implementacijai';

-- Dumping data for table emcor.src_type_mod_withe#const: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod_withe#const` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_type_mod_withe#const` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod_withe#iopty
CREATE TABLE IF NOT EXISTS `src_type_mod_withe#iopty` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `is_point` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `src_type_mod_impl_code` varchar(80) COLLATE utf8_bin NOT NULL COMMENT 'Šaltinių tipo modifikacijos implementacijos kodas',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`src_type_id`,`src_type_mod_nr`,`is_point`,`withe_id`,`ind1`,`ind2`,`ind3`,`src_type_mod_impl_code`,`opty_id`),
  KEY `src_type_mod_withe#iopty_o_fk` (`opty_id`),
  CONSTRAINT `src_type_mod_withe#iopty_o_fk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_mod_withe#iopty_w_fk` FOREIGN KEY (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) REFERENCES `src_type_mod_withe` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Prietaisų modifikacijų implementacijų masyvinių konfigūracinių parametrų nuskaitymui reikalingų parametrų reikšmės';

-- Dumping data for table emcor.src_type_mod_withe#iopty: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod_withe#iopty` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_type_mod_withe#iopty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod_withe#opty
CREATE TABLE IF NOT EXISTS `src_type_mod_withe#opty` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `is_point` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`src_type_id`,`src_type_mod_nr`,`is_point`,`withe_id`,`ind1`,`ind2`,`ind3`,`opty_id`),
  KEY `src_type_mod_withe#opty_opt_fk` (`opty_id`),
  CONSTRAINT `src_type_mod_withe#opty_opt_fk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_mod_withe#opty_wth_fk` FOREIGN KEY (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) REFERENCES `src_type_mod_withe` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Prietaisų modifikacijų konfigūracinių masyvinių parametrų nuskaitymui reikalingų parametrų reikšmės';

-- Dumping data for table emcor.src_type_mod_withe#opty: ~68 210 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod_withe#opty` DISABLE KEYS */;
INSERT INTO `src_type_mod_withe#opty` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`, `ind1`, `ind2`, `ind3`, `opty_id`, `opty_value`) VALUES
	(39, 1, 1, -50496, 1, 0, 0, 12, '0.0.99.1.0.255'),
	(39, 1, 1, -50496, 2, 0, 0, 12, '0.0.99.2.0.255'),
	(39, 1, 1, -50495, 1, 0, 0, 12, '0.0.99.1.0.255'),
	(39, 1, 1, -50495, 2, 0, 0, 12, '0.0.99.2.0.255'),
	(39, 1, 1, -50494, 1, 0, 0, 12, '0.0.99.1.0.255'),
	(39, 1, 1, -50494, 2, 0, 0, 12, '0.0.99.2.0.255'),
	(39, 1, 1, -50493, 1, 0, 0, 12, '0.0.99.1.0.255'),
	(39, 1, 1, -50493, 2, 0, 0, 12, '0.0.99.2.0.255'),
	(39, 1, 1, -50491, 1, 0, 0, 12, '0.0.99.1.0.255'),
	(39, 1, 1, -50491, 2, 0, 0, 12, '0.0.99.2.0.255'),
	(39, 1, 1, -50304, 1, 0, 0, 12, '0.0.99.1.0.255'),
	(39, 1, 1, -50304, 2, 0, 0, 12, '0.0.99.2.0.255'),
	(243, 1, 0, -50945, 1, 0, 0, 39, '0'),
	(243, 1, 0, -50945, 2, 0, 0, 39, '1'),
	(243, 1, 0, -50945, 3, 0, 0, 39, '2'),
	(243, 1, 0, -50945, 4, 0, 0, 39, '3'),
	(243, 1, 0, -50945, 5, 0, 0, 39, '4'),
	(243, 1, 0, -50945, 6, 0, 0, 39, '5'),
	(243, 1, 0, -50945, 7, 0, 0, 39, '6'),
	(243, 1, 0, -50945, 8, 0, 0, 39, '7'),
	(243, 1, 0, -50945, 9, 0, 0, 39, '8'),
	(243, 1, 0, -50945, 10, 0, 0, 39, '9'),
	(243, 1, 0, -50945, 11, 0, 0, 39, '10'),
	(243, 1, 0, -50945, 12, 0, 0, 39, '11'),
	(243, 1, 0, -50945, 13, 0, 0, 39, '12'),
	(243, 1, 0, -50945, 14, 0, 0, 39, '13'),
	(243, 1, 0, -50945, 15, 0, 0, 39, '14'),
	(243, 1, 0, -50945, 16, 0, 0, 39, '15'),
	(243, 1, 0, -50945, 17, 0, 0, 39, '16'),
	(243, 1, 0, -50945, 18, 0, 0, 39, '17'),
	(243, 1, 0, -50945, 19, 0, 0, 39, '18'),
	(243, 1, 0, -50945, 20, 0, 0, 39, '19'),
	(243, 1, 0, -50945, 21, 0, 0, 39, '20'),
	(243, 1, 0, -50945, 22, 0, 0, 39, '21'),
	(243, 1, 0, -50945, 23, 0, 0, 39, '22'),
	(243, 1, 0, -50945, 24, 0, 0, 39, '23'),
	(243, 1, 0, -50945, 25, 0, 0, 39, '24'),
	(243, 1, 0, -50945, 26, 0, 0, 39, '25'),
	(243, 1, 0, -50945, 27, 0, 0, 39, '26'),
	(243, 1, 0, -50945, 28, 0, 0, 39, '27'),
	(243, 1, 0, -50945, 29, 0, 0, 39, '28'),
	(243, 1, 0, -50945, 30, 0, 0, 39, '29'),
	(243, 1, 0, -50945, 31, 0, 0, 39, '30'),
	(243, 1, 0, -50945, 32, 0, 0, 39, '31'),
	(243, 1, 0, -50945, 33, 0, 0, 39, '32'),
	(243, 1, 0, -50945, 34, 0, 0, 39, '33'),
	(243, 1, 0, -50945, 35, 0, 0, 39, '34'),
	(243, 1, 0, -50945, 36, 0, 0, 39, '35'),
	(243, 1, 0, -50945, 37, 0, 0, 39, '36'),
	(243, 1, 0, -50945, 38, 0, 0, 39, '37'),
	(243, 1, 0, -50945, 39, 0, 0, 39, '38'),
	(243, 1, 0, -50945, 40, 0, 0, 39, '39'),
	(243, 1, 0, -50945, 41, 0, 0, 39, '40'),
	(243, 1, 0, -50945, 42, 0, 0, 39, '41'),
	(243, 1, 0, -50945, 43, 0, 0, 39, '42'),
	(243, 1, 0, -50945, 44, 0, 0, 39, '43'),
	(243, 1, 0, -50945, 45, 0, 0, 39, '44'),
	(243, 1, 0, -50945, 46, 0, 0, 39, '45'),
	(243, 1, 0, -50945, 47, 0, 0, 39, '46'),
	(243, 1, 0, -50945, 48, 0, 0, 39, '47'),
	(243, 1, 0, -50945, 49, 0, 0, 39, '48'),
	(243, 1, 0, -50945, 50, 0, 0, 39, '49'),
	(243, 1, 0, -50945, 51, 0, 0, 39, '50'),
	(243, 1, 0, -50945, 52, 0, 0, 39, '51'),
	(243, 1, 0, -50945, 53, 0, 0, 39, '52'),
	(243, 1, 0, -50945, 54, 0, 0, 39, '53'),
	(243, 1, 0, -50945, 55, 0, 0, 39, '54'),
	(243, 1, 0, -50945, 56, 0, 0, 39, '55'),
	(243, 1, 0, -50945, 57, 0, 0, 39, '56'),
	(243, 1, 0, -50945, 58, 0, 0, 39, '57'),
	(243, 1, 0, -50945, 59, 0, 0, 39, '58'),
	(243, 1, 0, -50945, 60, 0, 0, 39, '59'),
	(243, 1, 0, -50945, 61, 0, 0, 39, '60'),
	(243, 1, 0, -50945, 62, 0, 0, 39, '61'),
	(243, 1, 0, -50945, 63, 0, 0, 39, '62'),
	(243, 1, 0, -50945, 64, 0, 0, 39, '63'),
	(243, 1, 0, -50945, 65, 0, 0, 39, '64'),
	(243, 1, 0, -50945, 66, 0, 0, 39, '65'),
	(243, 1, 0, -50945, 67, 0, 0, 39, '66'),
	(243, 1, 0, -50945, 68, 0, 0, 39, '67'),
	(243, 1, 0, -50945, 69, 0, 0, 39, '68'),
	(243, 1, 0, -50945, 70, 0, 0, 39, '69'),
	(243, 1, 0, -50945, 71, 0, 0, 39, '70'),
	(243, 1, 0, -50945, 72, 0, 0, 39, '71'),
	(243, 1, 0, -50945, 73, 0, 0, 39, '72'),
	(243, 1, 0, -50945, 74, 0, 0, 39, '73'),
	(243, 1, 0, -50945, 75, 0, 0, 39, '74'),
	(243, 1, 0, -50945, 76, 0, 0, 39, '75'),
	(243, 1, 0, -50945, 77, 0, 0, 39, '76'),
	(243, 1, 0, -50945, 78, 0, 0, 39, '77'),
	(243, 1, 0, -50945, 79, 0, 0, 39, '78'),
	(243, 1, 0, -50945, 80, 0, 0, 39, '79'),
	(243, 1, 0, -50945, 81, 0, 0, 39, '80'),
	(243, 1, 0, -50945, 82, 0, 0, 39, '81'),
	(243, 1, 0, -50945, 83, 0, 0, 39, '82'),
	(243, 1, 0, -50945, 84, 0, 0, 39, '83'),
	(243, 1, 0, -50945, 85, 0, 0, 39, '84'),
	(243, 1, 0, -50945, 86, 0, 0, 39, '85'),
	(243, 1, 0, -50945, 87, 0, 0, 39, '86'),
	(243, 1, 0, -50945, 88, 0, 0, 39, '87'),
	(243, 1, 0, -50945, 89, 0, 0, 39, '88'),
	(243, 1, 0, -50945, 90, 0, 0, 39, '89'),
	(243, 1, 0, -50945, 91, 0, 0, 39, '90'),
	(243, 1, 0, -50945, 92, 0, 0, 39, '91'),
	(243, 1, 0, -50945, 93, 0, 0, 39, '92'),
	(243, 1, 0, -50945, 94, 0, 0, 39, '93'),
	(243, 1, 0, -50945, 95, 0, 0, 39, '94'),
	(243, 1, 0, -50945, 96, 0, 0, 39, '95'),
	(243, 1, 0, -50945, 97, 0, 0, 39, '96'),
	(243, 1, 0, -50945, 98, 0, 0, 39, '97'),
	(243, 1, 0, -50945, 99, 0, 0, 39, '98'),
	(243, 1, 0, -50945, 100, 0, 0, 39, '99'),
	(243, 1, 0, -50945, 101, 0, 0, 39, '100'),
	(243, 1, 0, -50945, 102, 0, 0, 39, '101'),
	(243, 1, 0, -50945, 103, 0, 0, 39, '102'),
	(243, 1, 0, -50945, 104, 0, 0, 39, '103'),
	(243, 1, 0, -50945, 105, 0, 0, 39, '104'),
	(243, 1, 0, -50945, 106, 0, 0, 39, '105'),
	(243, 1, 0, -50945, 107, 0, 0, 39, '106'),
	(243, 1, 0, -50945, 108, 0, 0, 39, '107'),
	(243, 1, 0, -50945, 109, 0, 0, 39, '108'),
	(243, 1, 0, -50945, 110, 0, 0, 39, '109'),
	(243, 1, 0, -50945, 111, 0, 0, 39, '110'),
	(243, 1, 0, -50945, 112, 0, 0, 39, '111'),
	(243, 1, 0, -50945, 113, 0, 0, 39, '112'),
	(243, 1, 0, -50945, 114, 0, 0, 39, '113'),
	(243, 1, 0, -50945, 115, 0, 0, 39, '114'),
	(243, 1, 0, -50945, 116, 0, 0, 39, '115'),
	(243, 1, 0, -50945, 117, 0, 0, 39, '116'),
	(243, 1, 0, -50945, 118, 0, 0, 39, '117'),
	(243, 1, 0, -50945, 119, 0, 0, 39, '118'),
	(243, 1, 0, -50945, 120, 0, 0, 39, '119'),
	(243, 1, 0, -50945, 121, 0, 0, 39, '120'),
	(243, 1, 0, -50945, 122, 0, 0, 39, '121'),
	(243, 1, 0, -50945, 123, 0, 0, 39, '122'),
	(243, 1, 0, -50945, 124, 0, 0, 39, '123'),
	(243, 1, 0, -50945, 125, 0, 0, 39, '124'),
	(243, 1, 0, -50945, 126, 0, 0, 39, '125'),
	(243, 1, 0, -50945, 127, 0, 0, 39, '126'),
	(243, 1, 0, -50945, 128, 0, 0, 39, '127'),
	(243, 1, 0, -50945, 129, 0, 0, 39, '128'),
	(243, 1, 0, -50945, 130, 0, 0, 39, '129'),
	(243, 1, 0, -50945, 131, 0, 0, 39, '130'),
	(243, 1, 0, -50945, 132, 0, 0, 39, '131'),
	(243, 1, 0, -50945, 133, 0, 0, 39, '132'),
	(243, 1, 0, -50945, 134, 0, 0, 39, '133'),
	(243, 1, 0, -50945, 135, 0, 0, 39, '134'),
	(243, 1, 0, -50945, 136, 0, 0, 39, '135'),
	(243, 1, 0, -50945, 137, 0, 0, 39, '136'),
	(243, 1, 0, -50945, 138, 0, 0, 39, '137'),
	(243, 1, 0, -50945, 139, 0, 0, 39, '138'),
	(243, 1, 0, -50945, 140, 0, 0, 39, '139'),
	(243, 1, 0, -50945, 141, 0, 0, 39, '140'),
	(243, 1, 0, -50945, 142, 0, 0, 39, '141'),
	(243, 1, 0, -50945, 143, 0, 0, 39, '142'),
	(243, 1, 0, -50945, 144, 0, 0, 39, '143'),
	(243, 1, 0, -50945, 145, 0, 0, 39, '144'),
	(243, 1, 0, -50945, 146, 0, 0, 39, '145'),
	(243, 1, 0, -50945, 147, 0, 0, 39, '146'),
	(243, 1, 0, -50945, 148, 0, 0, 39, '147'),
	(243, 1, 0, -50945, 149, 0, 0, 39, '148'),
	(243, 1, 0, -50945, 150, 0, 0, 39, '149'),
	(243, 1, 0, -50945, 151, 0, 0, 39, '150'),
	(243, 1, 0, -50945, 152, 0, 0, 39, '151'),
	(243, 1, 0, -50945, 153, 0, 0, 39, '152'),
	(243, 1, 0, -50945, 154, 0, 0, 39, '153'),
	(243, 1, 0, -50945, 155, 0, 0, 39, '154'),
	(243, 1, 0, -50945, 156, 0, 0, 39, '155'),
	(243, 1, 0, -50945, 157, 0, 0, 39, '156'),
	(243, 1, 0, -50945, 158, 0, 0, 39, '157'),
	(243, 1, 0, -50945, 159, 0, 0, 39, '158'),
	(243, 1, 0, -50945, 160, 0, 0, 39, '159'),
	(243, 1, 0, -50945, 161, 0, 0, 39, '160'),
	(243, 1, 0, -50945, 162, 0, 0, 39, '161'),
	(243, 1, 0, -50945, 163, 0, 0, 39, '162'),
	(243, 1, 0, -50945, 164, 0, 0, 39, '163'),
	(243, 1, 0, -50945, 165, 0, 0, 39, '164'),
	(243, 1, 0, -50945, 166, 0, 0, 39, '165'),
	(243, 1, 0, -50945, 167, 0, 0, 39, '166'),
	(243, 1, 0, -50945, 168, 0, 0, 39, '167'),
	(243, 1, 0, -50945, 169, 0, 0, 39, '168'),
	(243, 1, 0, -50945, 170, 0, 0, 39, '169'),
	(243, 1, 0, -50945, 171, 0, 0, 39, '170'),
	(243, 1, 0, -50945, 172, 0, 0, 39, '171'),
	(243, 1, 0, -50945, 173, 0, 0, 39, '172'),
	(243, 1, 0, -50945, 174, 0, 0, 39, '173'),
	(243, 1, 0, -50945, 175, 0, 0, 39, '174'),
	(243, 1, 0, -50945, 176, 0, 0, 39, '175'),
	(243, 1, 0, -50945, 177, 0, 0, 39, '176'),
	(243, 1, 0, -50945, 178, 0, 0, 39, '177'),
	(243, 1, 0, -50945, 179, 0, 0, 39, '178'),
	(243, 1, 0, -50945, 180, 0, 0, 39, '179'),
	(243, 1, 0, -50945, 181, 0, 0, 39, '180'),
	(243, 1, 0, -50945, 182, 0, 0, 39, '181'),
	(243, 1, 0, -50945, 183, 0, 0, 39, '182'),
	(243, 1, 0, -50945, 184, 0, 0, 39, '183'),
	(243, 1, 0, -50945, 185, 0, 0, 39, '184'),
	(243, 1, 0, -50945, 186, 0, 0, 39, '185'),
	(243, 1, 0, -50945, 187, 0, 0, 39, '186'),
	(243, 1, 0, -50945, 188, 0, 0, 39, '187'),
	(243, 1, 0, -50945, 189, 0, 0, 39, '188'),
	(243, 1, 0, -50945, 190, 0, 0, 39, '189'),
	(243, 1, 0, -50945, 191, 0, 0, 39, '190'),
	(243, 1, 0, -50945, 192, 0, 0, 39, '191'),
	(243, 1, 0, -50945, 193, 0, 0, 39, '192'),
	(243, 1, 0, -50945, 194, 0, 0, 39, '193'),
	(243, 1, 0, -50945, 195, 0, 0, 39, '194'),
	(243, 1, 0, -50945, 196, 0, 0, 39, '195'),
	(243, 1, 0, -50945, 197, 0, 0, 39, '196'),
	(243, 1, 0, -50945, 198, 0, 0, 39, '197'),
	(243, 1, 0, -50945, 199, 0, 0, 39, '198'),
	(243, 1, 0, -50945, 200, 0, 0, 39, '199'),
	(243, 1, 0, -50945, 201, 0, 0, 39, '200'),
	(243, 1, 0, -50945, 202, 0, 0, 39, '201'),
	(243, 1, 0, -50945, 203, 0, 0, 39, '202'),
	(243, 1, 0, -50945, 204, 0, 0, 39, '203'),
	(243, 1, 0, -50945, 205, 0, 0, 39, '204'),
	(243, 1, 0, -50945, 206, 0, 0, 39, '205'),
	(243, 1, 0, -50945, 207, 0, 0, 39, '206'),
	(243, 1, 0, -50945, 208, 0, 0, 39, '207'),
	(243, 1, 0, -50945, 209, 0, 0, 39, '208'),
	(243, 1, 0, -50945, 210, 0, 0, 39, '209'),
	(243, 1, 0, -50945, 211, 0, 0, 39, '210'),
	(243, 1, 0, -50945, 212, 0, 0, 39, '211'),
	(243, 1, 0, -50945, 213, 0, 0, 39, '212'),
	(243, 1, 0, -50945, 214, 0, 0, 39, '213'),
	(243, 1, 0, -50945, 215, 0, 0, 39, '214'),
	(243, 1, 0, -50945, 216, 0, 0, 39, '215'),
	(243, 1, 0, -50945, 217, 0, 0, 39, '216'),
	(243, 1, 0, -50945, 218, 0, 0, 39, '217'),
	(243, 1, 0, -50945, 219, 0, 0, 39, '218'),
	(243, 1, 0, -50945, 220, 0, 0, 39, '219'),
	(243, 1, 0, -50945, 221, 0, 0, 39, '220'),
	(243, 1, 0, -50945, 222, 0, 0, 39, '221'),
	(243, 1, 0, -50945, 223, 0, 0, 39, '222'),
	(243, 1, 0, -50945, 224, 0, 0, 39, '223'),
	(243, 1, 0, -50945, 225, 0, 0, 39, '224'),
	(243, 1, 0, -50945, 226, 0, 0, 39, '225'),
	(243, 1, 0, -50945, 227, 0, 0, 39, '226'),
	(243, 1, 0, -50945, 228, 0, 0, 39, '227'),
	(243, 1, 0, -50945, 229, 0, 0, 39, '228'),
	(243, 1, 0, -50945, 230, 0, 0, 39, '229'),
	(243, 1, 0, -50945, 231, 0, 0, 39, '230'),
	(243, 1, 0, -50945, 232, 0, 0, 39, '231'),
	(243, 1, 0, -50945, 233, 0, 0, 39, '232'),
	(243, 1, 0, -50945, 234, 0, 0, 39, '233'),
	(243, 1, 0, -50945, 235, 0, 0, 39, '234'),
	(243, 1, 0, -50945, 236, 0, 0, 39, '235'),
	(243, 1, 0, -50945, 237, 0, 0, 39, '236'),
	(243, 1, 0, -50945, 238, 0, 0, 39, '237'),
	(243, 1, 0, -50945, 239, 0, 0, 39, '238'),
	(243, 1, 0, -50945, 240, 0, 0, 39, '239'),
	(243, 1, 0, -50945, 241, 0, 0, 39, '240'),
	(243, 1, 0, -50945, 242, 0, 0, 39, '241'),
	(243, 1, 0, -50945, 243, 0, 0, 39, '242'),
	(243, 1, 0, -50945, 244, 0, 0, 39, '243'),
	(243, 1, 0, -50945, 245, 0, 0, 39, '244'),
	(243, 1, 0, -50945, 246, 0, 0, 39, '245'),
	(243, 1, 0, -50945, 247, 0, 0, 39, '246'),
	(243, 1, 0, -50945, 248, 0, 0, 39, '247'),
	(243, 1, 0, -50945, 249, 0, 0, 39, '248'),
	(243, 1, 0, -50945, 250, 0, 0, 39, '249'),
	(243, 1, 0, -50945, 251, 0, 0, 39, '250'),
	(243, 1, 0, -50945, 252, 0, 0, 39, '251'),
	(243, 1, 0, -50945, 253, 0, 0, 39, '252'),
	(243, 1, 0, -50945, 254, 0, 0, 39, '253'),
	(243, 1, 0, -50945, 255, 0, 0, 39, '254'),
	(243, 1, 0, -50945, 256, 0, 0, 39, '255'),
	(243, 1, 0, -50945, 257, 0, 0, 39, '256'),
	(243, 1, 0, -50945, 258, 0, 0, 39, '257'),
	(243, 1, 0, -50945, 259, 0, 0, 39, '258'),
	(243, 1, 0, -50945, 260, 0, 0, 39, '259'),
	(243, 1, 0, -50945, 261, 0, 0, 39, '260'),
	(243, 1, 0, -50945, 262, 0, 0, 39, '261'),
	(243, 1, 0, -50945, 263, 0, 0, 39, '262'),
	(243, 1, 0, -50945, 264, 0, 0, 39, '263'),
	(243, 1, 0, -50945, 265, 0, 0, 39, '264'),
	(243, 1, 0, -50945, 266, 0, 0, 39, '265'),
	(243, 1, 0, -50945, 267, 0, 0, 39, '266'),
	(243, 1, 0, -50945, 268, 0, 0, 39, '267'),
	(243, 1, 0, -50945, 269, 0, 0, 39, '268'),
	(243, 1, 0, -50945, 270, 0, 0, 39, '269'),
	(243, 1, 0, -50945, 271, 0, 0, 39, '270'),
	(243, 1, 0, -50945, 272, 0, 0, 39, '271'),
	(243, 1, 0, -50945, 273, 0, 0, 39, '272'),
	(243, 1, 0, -50945, 274, 0, 0, 39, '273'),
	(243, 1, 0, -50945, 275, 0, 0, 39, '274'),
	(243, 1, 0, -50945, 276, 0, 0, 39, '275'),
	(243, 1, 0, -50945, 277, 0, 0, 39, '276'),
	(243, 1, 0, -50945, 278, 0, 0, 39, '277'),
	(243, 1, 0, -50945, 279, 0, 0, 39, '278'),
	(243, 1, 0, -50945, 280, 0, 0, 39, '279'),
	(243, 1, 0, -50945, 281, 0, 0, 39, '280'),
	(243, 1, 0, -50945, 282, 0, 0, 39, '281'),
	(243, 1, 0, -50945, 283, 0, 0, 39, '282'),
	(243, 1, 0, -50945, 284, 0, 0, 39, '283'),
	(243, 1, 0, -50945, 285, 0, 0, 39, '284'),
	(243, 1, 0, -50945, 286, 0, 0, 39, '285'),
	(243, 1, 0, -50945, 287, 0, 0, 39, '286'),
	(243, 1, 0, -50945, 288, 0, 0, 39, '287'),
	(243, 1, 0, -50945, 289, 0, 0, 39, '288'),
	(243, 1, 0, -50945, 290, 0, 0, 39, '289'),
	(243, 1, 0, -50945, 291, 0, 0, 39, '290'),
	(243, 1, 0, -50945, 292, 0, 0, 39, '291'),
	(243, 1, 0, -50945, 293, 0, 0, 39, '292'),
	(243, 1, 0, -50945, 294, 0, 0, 39, '293'),
	(243, 1, 0, -50945, 295, 0, 0, 39, '294'),
	(243, 1, 0, -50945, 296, 0, 0, 39, '295'),
	(243, 1, 0, -50945, 297, 0, 0, 39, '296'),
	(243, 1, 0, -50945, 298, 0, 0, 39, '297'),
	(243, 1, 0, -50945, 299, 0, 0, 39, '298'),
	(243, 1, 0, -50945, 300, 0, 0, 39, '299'),
	(243, 1, 0, -50945, 301, 0, 0, 39, '300'),
	(243, 1, 0, -50945, 302, 0, 0, 39, '301'),
	(243, 1, 0, -50945, 303, 0, 0, 39, '302'),
	(243, 1, 0, -50945, 304, 0, 0, 39, '303'),
	(243, 1, 0, -50945, 305, 0, 0, 39, '304'),
	(243, 1, 0, -50945, 306, 0, 0, 39, '305'),
	(243, 1, 0, -50945, 307, 0, 0, 39, '306'),
	(243, 1, 0, -50945, 308, 0, 0, 39, '307'),
	(243, 1, 0, -50945, 309, 0, 0, 39, '308'),
	(243, 1, 0, -50945, 310, 0, 0, 39, '309'),
	(243, 1, 0, -50945, 311, 0, 0, 39, '310'),
	(243, 1, 0, -50945, 312, 0, 0, 39, '311'),
	(243, 1, 0, -50945, 313, 0, 0, 39, '312'),
	(243, 1, 0, -50945, 314, 0, 0, 39, '313'),
	(243, 1, 0, -50945, 315, 0, 0, 39, '314'),
	(243, 1, 0, -50945, 316, 0, 0, 39, '315'),
	(243, 1, 0, -50945, 317, 0, 0, 39, '316'),
	(243, 1, 0, -50945, 318, 0, 0, 39, '317'),
	(243, 1, 0, -50945, 319, 0, 0, 39, '318'),
	(243, 1, 0, -50945, 320, 0, 0, 39, '319'),
	(243, 1, 0, -50945, 321, 0, 0, 39, '320'),
	(243, 1, 0, -50945, 322, 0, 0, 39, '321'),
	(243, 1, 0, -50945, 323, 0, 0, 39, '322'),
	(243, 1, 0, -50945, 324, 0, 0, 39, '323'),
	(243, 1, 0, -50945, 325, 0, 0, 39, '324'),
	(243, 1, 0, -50945, 326, 0, 0, 39, '325'),
	(243, 1, 0, -50945, 327, 0, 0, 39, '326'),
	(243, 1, 0, -50945, 328, 0, 0, 39, '327'),
	(243, 1, 0, -50945, 329, 0, 0, 39, '328'),
	(243, 1, 0, -50945, 330, 0, 0, 39, '329'),
	(243, 1, 0, -50945, 331, 0, 0, 39, '330'),
	(243, 1, 0, -50945, 332, 0, 0, 39, '331'),
	(243, 1, 0, -50945, 333, 0, 0, 39, '332'),
	(243, 1, 0, -50945, 334, 0, 0, 39, '333'),
	(243, 1, 0, -50945, 335, 0, 0, 39, '334'),
	(243, 1, 0, -50945, 336, 0, 0, 39, '335'),
	(243, 1, 0, -50945, 337, 0, 0, 39, '336'),
	(243, 1, 0, -50945, 338, 0, 0, 39, '337'),
	(243, 1, 0, -50945, 339, 0, 0, 39, '338'),
	(243, 1, 0, -50945, 340, 0, 0, 39, '339'),
	(243, 1, 0, -50945, 341, 0, 0, 39, '340'),
	(243, 1, 0, -50945, 342, 0, 0, 39, '341'),
	(243, 1, 0, -50945, 343, 0, 0, 39, '342'),
	(243, 1, 0, -50945, 344, 0, 0, 39, '343'),
	(243, 1, 0, -50945, 345, 0, 0, 39, '344'),
	(243, 1, 0, -50945, 346, 0, 0, 39, '345'),
	(243, 1, 0, -50945, 347, 0, 0, 39, '346'),
	(243, 1, 0, -50945, 348, 0, 0, 39, '347'),
	(243, 1, 0, -50945, 349, 0, 0, 39, '348'),
	(243, 1, 0, -50945, 350, 0, 0, 39, '349'),
	(243, 1, 0, -50945, 351, 0, 0, 39, '350'),
	(243, 1, 0, -50945, 352, 0, 0, 39, '351'),
	(243, 1, 0, -50945, 353, 0, 0, 39, '352'),
	(243, 1, 0, -50945, 354, 0, 0, 39, '353'),
	(243, 1, 0, -50945, 355, 0, 0, 39, '354'),
	(243, 1, 0, -50945, 356, 0, 0, 39, '355'),
	(243, 1, 0, -50945, 357, 0, 0, 39, '356'),
	(243, 1, 0, -50945, 358, 0, 0, 39, '357'),
	(243, 1, 0, -50945, 359, 0, 0, 39, '358'),
	(243, 1, 0, -50945, 360, 0, 0, 39, '359'),
	(243, 1, 0, -50945, 361, 0, 0, 39, '360'),
	(243, 1, 0, -50945, 362, 0, 0, 39, '361'),
	(243, 1, 0, -50945, 363, 0, 0, 39, '362'),
	(243, 1, 0, -50945, 364, 0, 0, 39, '363'),
	(243, 1, 0, -50945, 365, 0, 0, 39, '364'),
	(243, 1, 0, -50945, 366, 0, 0, 39, '365'),
	(243, 1, 0, -50945, 367, 0, 0, 39, '366'),
	(243, 1, 0, -50945, 368, 0, 0, 39, '367'),
	(243, 1, 0, -50945, 369, 0, 0, 39, '368'),
	(243, 1, 0, -50945, 370, 0, 0, 39, '369'),
	(243, 1, 0, -50945, 371, 0, 0, 39, '370'),
	(243, 1, 0, -50945, 372, 0, 0, 39, '371'),
	(243, 1, 0, -50945, 373, 0, 0, 39, '372'),
	(243, 1, 0, -50945, 374, 0, 0, 39, '373'),
	(243, 1, 0, -50945, 375, 0, 0, 39, '374'),
	(243, 1, 0, -50945, 376, 0, 0, 39, '375'),
	(243, 1, 0, -50945, 377, 0, 0, 39, '376'),
	(243, 1, 0, -50945, 378, 0, 0, 39, '377'),
	(243, 1, 0, -50945, 379, 0, 0, 39, '378'),
	(243, 1, 0, -50945, 380, 0, 0, 39, '379'),
	(243, 1, 0, -50945, 381, 0, 0, 39, '380'),
	(243, 1, 0, -50945, 382, 0, 0, 39, '381'),
	(243, 1, 0, -50945, 383, 0, 0, 39, '382'),
	(243, 1, 0, -50945, 384, 0, 0, 39, '383'),
	(243, 1, 0, -50945, 385, 0, 0, 39, '384'),
	(243, 1, 0, -50945, 386, 0, 0, 39, '385'),
	(243, 1, 0, -50945, 387, 0, 0, 39, '386'),
	(243, 1, 0, -50945, 388, 0, 0, 39, '387'),
	(243, 1, 0, -50945, 389, 0, 0, 39, '388'),
	(243, 1, 0, -50945, 390, 0, 0, 39, '389'),
	(243, 1, 0, -50945, 391, 0, 0, 39, '390'),
	(243, 1, 0, -50945, 392, 0, 0, 39, '391'),
	(243, 1, 0, -50945, 393, 0, 0, 39, '392'),
	(243, 1, 0, -50945, 394, 0, 0, 39, '393'),
	(243, 1, 0, -50945, 395, 0, 0, 39, '394'),
	(243, 1, 0, -50945, 396, 0, 0, 39, '395'),
	(243, 1, 0, -50945, 397, 0, 0, 39, '396'),
	(243, 1, 0, -50945, 398, 0, 0, 39, '397'),
	(243, 1, 0, -50945, 399, 0, 0, 39, '398'),
	(243, 1, 0, -50945, 400, 0, 0, 39, '399'),
	(243, 1, 0, -50945, 401, 0, 0, 39, '400'),
	(243, 1, 0, -50945, 402, 0, 0, 39, '401'),
	(243, 1, 0, -50945, 403, 0, 0, 39, '402'),
	(243, 1, 0, -50945, 404, 0, 0, 39, '403'),
	(243, 1, 0, -50945, 405, 0, 0, 39, '404'),
	(243, 1, 0, -50945, 406, 0, 0, 39, '405'),
	(243, 1, 0, -50945, 407, 0, 0, 39, '406'),
	(243, 1, 0, -50945, 408, 0, 0, 39, '407'),
	(243, 1, 0, -50945, 409, 0, 0, 39, '408'),
	(243, 1, 0, -50945, 410, 0, 0, 39, '409'),
	(243, 1, 0, -50945, 411, 0, 0, 39, '410'),
	(243, 1, 0, -50945, 412, 0, 0, 39, '411'),
	(243, 1, 0, -50945, 413, 0, 0, 39, '412'),
	(243, 1, 0, -50945, 414, 0, 0, 39, '413'),
	(243, 1, 0, -50945, 415, 0, 0, 39, '414'),
	(243, 1, 0, -50945, 416, 0, 0, 39, '415'),
	(243, 1, 0, -50945, 417, 0, 0, 39, '416'),
	(243, 1, 0, -50945, 418, 0, 0, 39, '417'),
	(243, 1, 0, -50945, 419, 0, 0, 39, '418'),
	(243, 1, 0, -50945, 420, 0, 0, 39, '419'),
	(243, 1, 0, -50945, 421, 0, 0, 39, '420'),
	(243, 1, 0, -50945, 422, 0, 0, 39, '421'),
	(243, 1, 0, -50945, 423, 0, 0, 39, '422'),
	(243, 1, 0, -50945, 424, 0, 0, 39, '423'),
	(243, 1, 0, -50945, 425, 0, 0, 39, '424'),
	(243, 1, 0, -50945, 426, 0, 0, 39, '425'),
	(243, 1, 0, -50945, 427, 0, 0, 39, '426'),
	(243, 1, 0, -50945, 428, 0, 0, 39, '427'),
	(243, 1, 0, -50945, 429, 0, 0, 39, '428'),
	(243, 1, 0, -50945, 430, 0, 0, 39, '429'),
	(243, 1, 0, -50945, 431, 0, 0, 39, '430'),
	(243, 1, 0, -50945, 432, 0, 0, 39, '431'),
	(243, 1, 0, -50945, 433, 0, 0, 39, '432'),
	(243, 1, 0, -50945, 434, 0, 0, 39, '433'),
	(243, 1, 0, -50945, 435, 0, 0, 39, '434'),
	(243, 1, 0, -50945, 436, 0, 0, 39, '435'),
	(243, 1, 0, -50945, 437, 0, 0, 39, '436'),
	(243, 1, 0, -50945, 438, 0, 0, 39, '437'),
	(243, 1, 0, -50945, 439, 0, 0, 39, '438'),
	(243, 1, 0, -50945, 440, 0, 0, 39, '439'),
	(243, 1, 0, -50945, 441, 0, 0, 39, '440'),
	(243, 1, 0, -50945, 442, 0, 0, 39, '441'),
	(243, 1, 0, -50945, 443, 0, 0, 39, '442'),
	(243, 1, 0, -50945, 444, 0, 0, 39, '443'),
	(243, 1, 0, -50945, 445, 0, 0, 39, '444'),
	(243, 1, 0, -50945, 446, 0, 0, 39, '445'),
	(243, 1, 0, -50945, 447, 0, 0, 39, '446'),
	(243, 1, 0, -50945, 448, 0, 0, 39, '447'),
	(243, 1, 0, -50945, 449, 0, 0, 39, '448'),
	(243, 1, 0, -50945, 450, 0, 0, 39, '449'),
	(243, 1, 0, -50945, 451, 0, 0, 39, '450'),
	(243, 1, 0, -50945, 452, 0, 0, 39, '451'),
	(243, 1, 0, -50945, 453, 0, 0, 39, '452'),
	(243, 1, 0, -50945, 454, 0, 0, 39, '453'),
	(243, 1, 0, -50945, 455, 0, 0, 39, '454'),
	(243, 1, 0, -50945, 456, 0, 0, 39, '455'),
	(243, 1, 0, -50945, 457, 0, 0, 39, '456'),
	(243, 1, 0, -50945, 458, 0, 0, 39, '457'),
	(243, 1, 0, -50945, 459, 0, 0, 39, '458'),
	(243, 1, 0, -50945, 460, 0, 0, 39, '459'),
	(243, 1, 0, -50945, 461, 0, 0, 39, '460'),
	(243, 1, 0, -50945, 462, 0, 0, 39, '461'),
	(243, 1, 0, -50945, 463, 0, 0, 39, '462'),
	(243, 1, 0, -50945, 464, 0, 0, 39, '463'),
	(243, 1, 0, -50945, 465, 0, 0, 39, '464'),
	(243, 1, 0, -50945, 466, 0, 0, 39, '465'),
	(243, 1, 0, -50945, 467, 0, 0, 39, '466'),
	(243, 1, 0, -50945, 468, 0, 0, 39, '467'),
	(243, 1, 0, -50945, 469, 0, 0, 39, '468'),
	(243, 1, 0, -50945, 470, 0, 0, 39, '469'),
	(243, 1, 0, -50945, 471, 0, 0, 39, '470'),
	(243, 1, 0, -50945, 472, 0, 0, 39, '471'),
	(243, 1, 0, -50945, 473, 0, 0, 39, '472'),
	(243, 1, 0, -50945, 474, 0, 0, 39, '473'),
	(243, 1, 0, -50945, 475, 0, 0, 39, '474'),
	(243, 1, 0, -50945, 476, 0, 0, 39, '475'),
	(243, 1, 0, -50945, 477, 0, 0, 39, '476'),
	(243, 1, 0, -50945, 478, 0, 0, 39, '477'),
	(243, 1, 0, -50945, 479, 0, 0, 39, '478'),
	(243, 1, 0, -50945, 480, 0, 0, 39, '479'),
	(243, 1, 0, -50945, 481, 0, 0, 39, '480'),
	(243, 1, 0, -50945, 482, 0, 0, 39, '481'),
	(243, 1, 0, -50945, 483, 0, 0, 39, '482'),
	(243, 1, 0, -50945, 484, 0, 0, 39, '483'),
	(243, 1, 0, -50945, 485, 0, 0, 39, '484'),
	(243, 1, 0, -50945, 486, 0, 0, 39, '485'),
	(243, 1, 0, -50945, 487, 0, 0, 39, '486'),
	(243, 1, 0, -50945, 488, 0, 0, 39, '487'),
	(243, 1, 0, -50945, 489, 0, 0, 39, '488'),
	(243, 1, 0, -50945, 490, 0, 0, 39, '489'),
	(243, 1, 0, -50945, 491, 0, 0, 39, '490'),
	(243, 1, 0, -50945, 492, 0, 0, 39, '491'),
	(243, 1, 0, -50945, 493, 0, 0, 39, '492'),
	(243, 1, 0, -50945, 494, 0, 0, 39, '493'),
	(243, 1, 0, -50945, 495, 0, 0, 39, '494'),
	(243, 1, 0, -50945, 496, 0, 0, 39, '495'),
	(243, 1, 0, -50945, 497, 0, 0, 39, '496'),
	(243, 1, 0, -50945, 498, 0, 0, 39, '497'),
	(243, 1, 0, -50945, 499, 0, 0, 39, '498'),
	(243, 1, 0, -50945, 500, 0, 0, 39, '499'),
	(243, 1, 0, -50945, 501, 0, 0, 39, '500'),
	(243, 1, 0, -50945, 502, 0, 0, 39, '501'),
	(243, 1, 0, -50945, 503, 0, 0, 39, '502'),
	(243, 1, 0, -50945, 504, 0, 0, 39, '503'),
	(243, 1, 0, -50945, 505, 0, 0, 39, '504'),
	(243, 1, 0, -50945, 506, 0, 0, 39, '505'),
	(243, 1, 0, -50945, 507, 0, 0, 39, '506'),
	(243, 1, 0, -50945, 508, 0, 0, 39, '507'),
	(243, 1, 0, -50945, 509, 0, 0, 39, '508'),
	(243, 1, 0, -50945, 510, 0, 0, 39, '509'),
	(243, 1, 0, -50945, 511, 0, 0, 39, '510'),
	(243, 1, 0, -50945, 512, 0, 0, 39, '511'),
	(243, 1, 0, -50945, 513, 0, 0, 39, '512'),
	(243, 1, 0, -50945, 514, 0, 0, 39, '513'),
	(243, 1, 0, -50945, 515, 0, 0, 39, '514'),
	(243, 1, 0, -50945, 516, 0, 0, 39, '515'),
	(243, 1, 0, -50945, 517, 0, 0, 39, '516'),
	(243, 1, 0, -50945, 518, 0, 0, 39, '517'),
	(243, 1, 0, -50945, 519, 0, 0, 39, '518'),
	(243, 1, 0, -50945, 520, 0, 0, 39, '519'),
	(243, 1, 0, -50945, 521, 0, 0, 39, '520'),
	(243, 1, 0, -50945, 522, 0, 0, 39, '521'),
	(243, 1, 0, -50945, 523, 0, 0, 39, '522'),
	(243, 1, 0, -50945, 524, 0, 0, 39, '523'),
	(243, 1, 0, -50945, 525, 0, 0, 39, '524'),
	(243, 1, 0, -50945, 526, 0, 0, 39, '525'),
	(243, 1, 0, -50945, 527, 0, 0, 39, '526'),
	(243, 1, 0, -50945, 528, 0, 0, 39, '527'),
	(243, 1, 0, -50945, 529, 0, 0, 39, '528'),
	(243, 1, 0, -50945, 530, 0, 0, 39, '529'),
	(243, 1, 0, -50945, 531, 0, 0, 39, '530'),
	(243, 1, 0, -50945, 532, 0, 0, 39, '531'),
	(243, 1, 0, -50945, 533, 0, 0, 39, '532'),
	(243, 1, 0, -50945, 534, 0, 0, 39, '533'),
	(243, 1, 0, -50945, 535, 0, 0, 39, '534'),
	(243, 1, 0, -50945, 536, 0, 0, 39, '535'),
	(243, 1, 0, -50945, 537, 0, 0, 39, '536'),
	(243, 1, 0, -50945, 538, 0, 0, 39, '537'),
	(243, 1, 0, -50945, 539, 0, 0, 39, '538'),
	(243, 1, 0, -50945, 540, 0, 0, 39, '539'),
	(243, 1, 0, -50945, 541, 0, 0, 39, '540'),
	(243, 1, 0, -50945, 542, 0, 0, 39, '541'),
	(243, 1, 0, -50945, 543, 0, 0, 39, '542'),
	(243, 1, 0, -50945, 544, 0, 0, 39, '543'),
	(243, 1, 0, -50945, 545, 0, 0, 39, '544'),
	(243, 1, 0, -50945, 546, 0, 0, 39, '545'),
	(243, 1, 0, -50945, 547, 0, 0, 39, '546'),
	(243, 1, 0, -50945, 548, 0, 0, 39, '547'),
	(243, 1, 0, -50945, 549, 0, 0, 39, '548'),
	(243, 1, 0, -50945, 550, 0, 0, 39, '549'),
	(243, 1, 0, -50945, 551, 0, 0, 39, '550'),
	(243, 1, 0, -50945, 552, 0, 0, 39, '551'),
	(243, 1, 0, -50945, 553, 0, 0, 39, '552'),
	(243, 1, 0, -50945, 554, 0, 0, 39, '553'),
	(243, 1, 0, -50945, 555, 0, 0, 39, '554'),
	(243, 1, 0, -50945, 556, 0, 0, 39, '555'),
	(243, 1, 0, -50945, 557, 0, 0, 39, '556'),
	(243, 1, 0, -50945, 558, 0, 0, 39, '557'),
	(243, 1, 0, -50945, 559, 0, 0, 39, '558'),
	(243, 1, 0, -50945, 560, 0, 0, 39, '559'),
	(243, 1, 0, -50945, 561, 0, 0, 39, '560'),
	(243, 1, 0, -50945, 562, 0, 0, 39, '561'),
	(243, 1, 0, -50945, 563, 0, 0, 39, '562'),
	(243, 1, 0, -50945, 564, 0, 0, 39, '563'),
	(243, 1, 0, -50945, 565, 0, 0, 39, '564'),
	(243, 1, 0, -50945, 566, 0, 0, 39, '565'),
	(243, 1, 0, -50945, 567, 0, 0, 39, '566'),
	(243, 1, 0, -50945, 568, 0, 0, 39, '567'),
	(243, 1, 0, -50945, 569, 0, 0, 39, '568'),
	(243, 1, 0, -50945, 570, 0, 0, 39, '569'),
	(243, 1, 0, -50945, 571, 0, 0, 39, '570'),
	(243, 1, 0, -50945, 572, 0, 0, 39, '571'),
	(243, 1, 0, -50945, 573, 0, 0, 39, '572'),
	(243, 1, 0, -50945, 574, 0, 0, 39, '573'),
	(243, 1, 0, -50945, 575, 0, 0, 39, '574'),
	(243, 1, 0, -50945, 576, 0, 0, 39, '575'),
	(243, 1, 0, -50945, 577, 0, 0, 39, '576'),
	(243, 1, 0, -50945, 578, 0, 0, 39, '577'),
	(243, 1, 0, -50945, 579, 0, 0, 39, '578'),
	(243, 1, 0, -50945, 580, 0, 0, 39, '579'),
	(243, 1, 0, -50945, 581, 0, 0, 39, '580'),
	(243, 1, 0, -50945, 582, 0, 0, 39, '581'),
	(243, 1, 0, -50945, 583, 0, 0, 39, '582'),
	(243, 1, 0, -50945, 584, 0, 0, 39, '583'),
	(243, 1, 0, -50945, 585, 0, 0, 39, '584'),
	(243, 1, 0, -50945, 586, 0, 0, 39, '585'),
	(243, 1, 0, -50945, 587, 0, 0, 39, '586'),
	(243, 1, 0, -50945, 588, 0, 0, 39, '587'),
	(243, 1, 0, -50945, 589, 0, 0, 39, '588'),
	(243, 1, 0, -50945, 590, 0, 0, 39, '589'),
	(243, 1, 0, -50945, 591, 0, 0, 39, '590'),
	(243, 1, 0, -50945, 592, 0, 0, 39, '591'),
	(243, 1, 0, -50945, 593, 0, 0, 39, '592'),
	(243, 1, 0, -50945, 594, 0, 0, 39, '593'),
	(243, 1, 0, -50945, 595, 0, 0, 39, '594'),
	(243, 1, 0, -50945, 596, 0, 0, 39, '595'),
	(243, 1, 0, -50945, 597, 0, 0, 39, '596'),
	(243, 1, 0, -50945, 598, 0, 0, 39, '597'),
	(243, 1, 0, -50945, 599, 0, 0, 39, '598'),
	(243, 1, 0, -50945, 600, 0, 0, 39, '599'),
	(243, 1, 0, -50945, 601, 0, 0, 39, '600'),
	(243, 1, 0, -50945, 602, 0, 0, 39, '601'),
	(243, 1, 0, -50945, 603, 0, 0, 39, '602'),
	(243, 1, 0, -50945, 604, 0, 0, 39, '603'),
	(243, 1, 0, -50945, 605, 0, 0, 39, '604'),
	(243, 1, 0, -50945, 606, 0, 0, 39, '605'),
	(243, 1, 0, -50945, 607, 0, 0, 39, '606'),
	(243, 1, 0, -50945, 608, 0, 0, 39, '607'),
	(243, 1, 0, -50945, 609, 0, 0, 39, '608'),
	(243, 1, 0, -50945, 610, 0, 0, 39, '609'),
	(243, 1, 0, -50945, 611, 0, 0, 39, '610'),
	(243, 1, 0, -50945, 612, 0, 0, 39, '611'),
	(243, 1, 0, -50945, 613, 0, 0, 39, '612'),
	(243, 1, 0, -50945, 614, 0, 0, 39, '613'),
	(243, 1, 0, -50945, 615, 0, 0, 39, '614'),
	(243, 1, 0, -50945, 616, 0, 0, 39, '615'),
	(243, 1, 0, -50945, 617, 0, 0, 39, '616'),
	(243, 1, 0, -50945, 618, 0, 0, 39, '617'),
	(243, 1, 0, -50945, 619, 0, 0, 39, '618'),
	(243, 1, 0, -50945, 620, 0, 0, 39, '619'),
	(243, 1, 0, -50945, 621, 0, 0, 39, '620'),
	(243, 1, 0, -50945, 622, 0, 0, 39, '621'),
	(243, 1, 0, -50945, 623, 0, 0, 39, '622'),
	(243, 1, 0, -50945, 624, 0, 0, 39, '623'),
	(243, 1, 0, -50945, 625, 0, 0, 39, '624'),
	(243, 1, 0, -50945, 626, 0, 0, 39, '625'),
	(243, 1, 0, -50945, 627, 0, 0, 39, '626'),
	(243, 1, 0, -50945, 628, 0, 0, 39, '627'),
	(243, 1, 0, -50945, 629, 0, 0, 39, '628'),
	(243, 1, 0, -50945, 630, 0, 0, 39, '629'),
	(243, 1, 0, -50945, 631, 0, 0, 39, '630'),
	(243, 1, 0, -50945, 632, 0, 0, 39, '631'),
	(243, 1, 0, -50945, 633, 0, 0, 39, '632'),
	(243, 1, 0, -50945, 634, 0, 0, 39, '633'),
	(243, 1, 0, -50945, 635, 0, 0, 39, '634'),
	(243, 1, 0, -50945, 636, 0, 0, 39, '635'),
	(243, 1, 0, -50945, 637, 0, 0, 39, '636'),
	(243, 1, 0, -50945, 638, 0, 0, 39, '637'),
	(243, 1, 0, -50945, 639, 0, 0, 39, '638'),
	(243, 1, 0, -50945, 640, 0, 0, 39, '639'),
	(243, 1, 0, -50945, 641, 0, 0, 39, '640'),
	(243, 1, 0, -50945, 642, 0, 0, 39, '641'),
	(243, 1, 0, -50945, 643, 0, 0, 39, '642'),
	(243, 1, 0, -50945, 644, 0, 0, 39, '643'),
	(243, 1, 0, -50945, 645, 0, 0, 39, '644'),
	(243, 1, 0, -50945, 646, 0, 0, 39, '645'),
	(243, 1, 0, -50945, 647, 0, 0, 39, '646'),
	(243, 1, 0, -50945, 648, 0, 0, 39, '647'),
	(243, 1, 0, -50945, 649, 0, 0, 39, '648'),
	(243, 1, 0, -50945, 650, 0, 0, 39, '649'),
	(243, 1, 0, -50945, 651, 0, 0, 39, '650'),
	(243, 1, 0, -50945, 652, 0, 0, 39, '651'),
	(243, 1, 0, -50945, 653, 0, 0, 39, '652'),
	(243, 1, 0, -50945, 654, 0, 0, 39, '653'),
	(243, 1, 0, -50945, 655, 0, 0, 39, '654'),
	(243, 1, 0, -50945, 656, 0, 0, 39, '655'),
	(243, 1, 0, -50945, 657, 0, 0, 39, '656'),
	(243, 1, 0, -50945, 658, 0, 0, 39, '657'),
	(243, 1, 0, -50945, 659, 0, 0, 39, '658'),
	(243, 1, 0, -50945, 660, 0, 0, 39, '659'),
	(243, 1, 0, -50945, 661, 0, 0, 39, '660'),
	(243, 1, 0, -50945, 662, 0, 0, 39, '661'),
	(243, 1, 0, -50945, 663, 0, 0, 39, '662'),
	(243, 1, 0, -50945, 664, 0, 0, 39, '663'),
	(243, 1, 0, -50945, 665, 0, 0, 39, '664'),
	(243, 1, 0, -50945, 666, 0, 0, 39, '665'),
	(243, 1, 0, -50945, 667, 0, 0, 39, '666'),
	(243, 1, 0, -50945, 668, 0, 0, 39, '667'),
	(243, 1, 0, -50945, 669, 0, 0, 39, '668'),
	(243, 1, 0, -50945, 670, 0, 0, 39, '669'),
	(243, 1, 0, -50945, 671, 0, 0, 39, '670'),
	(243, 1, 0, -50945, 672, 0, 0, 39, '671'),
	(243, 1, 0, -50945, 673, 0, 0, 39, '672'),
	(243, 1, 0, -50945, 674, 0, 0, 39, '673'),
	(243, 1, 0, -50945, 675, 0, 0, 39, '674'),
	(243, 1, 0, -50945, 676, 0, 0, 39, '675'),
	(243, 1, 0, -50945, 677, 0, 0, 39, '676'),
	(243, 1, 0, -50945, 678, 0, 0, 39, '677'),
	(243, 1, 0, -50945, 679, 0, 0, 39, '678'),
	(243, 1, 0, -50945, 680, 0, 0, 39, '679'),
	(243, 1, 0, -50945, 681, 0, 0, 39, '680'),
	(243, 1, 0, -50945, 682, 0, 0, 39, '681'),
	(243, 1, 0, -50945, 683, 0, 0, 39, '682'),
	(243, 1, 0, -50945, 684, 0, 0, 39, '683'),
	(243, 1, 0, -50945, 685, 0, 0, 39, '684'),
	(243, 1, 0, -50945, 686, 0, 0, 39, '685'),
	(243, 1, 0, -50945, 687, 0, 0, 39, '686'),
	(243, 1, 0, -50945, 688, 0, 0, 39, '687'),
	(243, 1, 0, -50945, 689, 0, 0, 39, '688'),
	(243, 1, 0, -50945, 690, 0, 0, 39, '689'),
	(243, 1, 0, -50945, 691, 0, 0, 39, '690'),
	(243, 1, 0, -50945, 692, 0, 0, 39, '691'),
	(243, 1, 0, -50945, 693, 0, 0, 39, '692'),
	(243, 1, 0, -50945, 694, 0, 0, 39, '693'),
	(243, 1, 0, -50945, 695, 0, 0, 39, '694'),
	(243, 1, 0, -50945, 696, 0, 0, 39, '695'),
	(243, 1, 0, -50945, 697, 0, 0, 39, '696'),
	(243, 1, 0, -50945, 698, 0, 0, 39, '697'),
	(243, 1, 0, -50945, 699, 0, 0, 39, '698'),
	(243, 1, 0, -50945, 700, 0, 0, 39, '699'),
	(243, 1, 0, -50945, 701, 0, 0, 39, '700'),
	(243, 1, 0, -50945, 702, 0, 0, 39, '701'),
	(243, 1, 0, -50945, 703, 0, 0, 39, '702'),
	(243, 1, 0, -50945, 704, 0, 0, 39, '703'),
	(243, 1, 0, -50945, 705, 0, 0, 39, '704'),
	(243, 1, 0, -50945, 706, 0, 0, 39, '705'),
	(243, 1, 0, -50945, 707, 0, 0, 39, '706'),
	(243, 1, 0, -50945, 708, 0, 0, 39, '707'),
	(243, 1, 0, -50945, 709, 0, 0, 39, '708'),
	(243, 1, 0, -50945, 710, 0, 0, 39, '709'),
	(243, 1, 0, -50945, 711, 0, 0, 39, '710'),
	(243, 1, 0, -50945, 712, 0, 0, 39, '711'),
	(243, 1, 0, -50945, 713, 0, 0, 39, '712'),
	(243, 1, 0, -50945, 714, 0, 0, 39, '713'),
	(243, 1, 0, -50945, 715, 0, 0, 39, '714'),
	(243, 1, 0, -50945, 716, 0, 0, 39, '715'),
	(243, 1, 0, -50945, 717, 0, 0, 39, '716'),
	(243, 1, 0, -50945, 718, 0, 0, 39, '717'),
	(243, 1, 0, -50945, 719, 0, 0, 39, '718'),
	(243, 1, 0, -50945, 720, 0, 0, 39, '719'),
	(243, 1, 0, -50945, 721, 0, 0, 39, '720'),
	(243, 1, 0, -50945, 722, 0, 0, 39, '721'),
	(243, 1, 0, -50945, 723, 0, 0, 39, '722'),
	(243, 1, 0, -50945, 724, 0, 0, 39, '723'),
	(243, 1, 0, -50945, 725, 0, 0, 39, '724'),
	(243, 1, 0, -50945, 726, 0, 0, 39, '725'),
	(243, 1, 0, -50945, 727, 0, 0, 39, '726'),
	(243, 1, 0, -50945, 728, 0, 0, 39, '727'),
	(243, 1, 0, -50945, 729, 0, 0, 39, '728'),
	(243, 1, 0, -50945, 730, 0, 0, 39, '729'),
	(243, 1, 0, -50945, 731, 0, 0, 39, '730'),
	(243, 1, 0, -50945, 732, 0, 0, 39, '731'),
	(243, 1, 0, -50945, 733, 0, 0, 39, '732'),
	(243, 1, 0, -50945, 734, 0, 0, 39, '733'),
	(243, 1, 0, -50945, 735, 0, 0, 39, '734'),
	(243, 1, 0, -50945, 736, 0, 0, 39, '735'),
	(243, 1, 0, -50945, 737, 0, 0, 39, '736'),
	(243, 1, 0, -50945, 738, 0, 0, 39, '737'),
	(243, 1, 0, -50945, 739, 0, 0, 39, '738'),
	(243, 1, 0, -50945, 740, 0, 0, 39, '739'),
	(243, 1, 0, -50945, 741, 0, 0, 39, '740'),
	(243, 1, 0, -50945, 742, 0, 0, 39, '741'),
	(243, 1, 0, -50945, 743, 0, 0, 39, '742'),
	(243, 1, 0, -50945, 744, 0, 0, 39, '743'),
	(243, 1, 0, -50945, 745, 0, 0, 39, '744'),
	(243, 1, 0, -50945, 746, 0, 0, 39, '745'),
	(243, 1, 0, -50945, 747, 0, 0, 39, '746'),
	(243, 1, 0, -50945, 748, 0, 0, 39, '747'),
	(243, 1, 0, -50945, 749, 0, 0, 39, '748'),
	(243, 1, 0, -50945, 750, 0, 0, 39, '749'),
	(243, 1, 0, -50945, 751, 0, 0, 39, '750'),
	(243, 1, 0, -50945, 752, 0, 0, 39, '751'),
	(243, 1, 0, -50945, 753, 0, 0, 39, '752'),
	(243, 1, 0, -50945, 754, 0, 0, 39, '753'),
	(243, 1, 0, -50945, 755, 0, 0, 39, '754'),
	(243, 1, 0, -50945, 756, 0, 0, 39, '755'),
	(243, 1, 0, -50945, 757, 0, 0, 39, '756'),
	(243, 1, 0, -50945, 758, 0, 0, 39, '757'),
	(243, 1, 0, -50945, 759, 0, 0, 39, '758'),
	(243, 1, 0, -50945, 760, 0, 0, 39, '759'),
	(243, 1, 0, -50945, 761, 0, 0, 39, '760'),
	(243, 1, 0, -50945, 762, 0, 0, 39, '761'),
	(243, 1, 0, -50945, 763, 0, 0, 39, '762'),
	(243, 1, 0, -50945, 764, 0, 0, 39, '763'),
	(243, 1, 0, -50945, 765, 0, 0, 39, '764'),
	(243, 1, 0, -50945, 766, 0, 0, 39, '765'),
	(243, 1, 0, -50945, 767, 0, 0, 39, '766'),
	(243, 1, 0, -50945, 768, 0, 0, 39, '767'),
	(243, 1, 0, -50945, 769, 0, 0, 39, '768'),
	(243, 1, 0, -50945, 770, 0, 0, 39, '769'),
	(243, 1, 0, -50945, 771, 0, 0, 39, '770'),
	(243, 1, 0, -50945, 772, 0, 0, 39, '771'),
	(243, 1, 0, -50945, 773, 0, 0, 39, '772'),
	(243, 1, 0, -50945, 774, 0, 0, 39, '773'),
	(243, 1, 0, -50945, 775, 0, 0, 39, '774'),
	(243, 1, 0, -50945, 776, 0, 0, 39, '775'),
	(243, 1, 0, -50945, 777, 0, 0, 39, '776'),
	(243, 1, 0, -50945, 778, 0, 0, 39, '777'),
	(243, 1, 0, -50945, 779, 0, 0, 39, '778'),
	(243, 1, 0, -50945, 780, 0, 0, 39, '779'),
	(243, 1, 0, -50945, 781, 0, 0, 39, '780'),
	(243, 1, 0, -50945, 782, 0, 0, 39, '781'),
	(243, 1, 0, -50945, 783, 0, 0, 39, '782'),
	(243, 1, 0, -50945, 784, 0, 0, 39, '783'),
	(243, 1, 0, -50945, 785, 0, 0, 39, '784'),
	(243, 1, 0, -50945, 786, 0, 0, 39, '785'),
	(243, 1, 0, -50945, 787, 0, 0, 39, '786'),
	(243, 1, 0, -50945, 788, 0, 0, 39, '787'),
	(243, 1, 0, -50945, 789, 0, 0, 39, '788'),
	(243, 1, 0, -50945, 790, 0, 0, 39, '789'),
	(243, 1, 0, -50945, 791, 0, 0, 39, '790'),
	(243, 1, 0, -50945, 792, 0, 0, 39, '791'),
	(243, 1, 0, -50945, 793, 0, 0, 39, '792'),
	(243, 1, 0, -50945, 794, 0, 0, 39, '793'),
	(243, 1, 0, -50945, 795, 0, 0, 39, '794'),
	(243, 1, 0, -50945, 796, 0, 0, 39, '795'),
	(243, 1, 0, -50945, 797, 0, 0, 39, '796'),
	(243, 1, 0, -50945, 798, 0, 0, 39, '797'),
	(243, 1, 0, -50945, 799, 0, 0, 39, '798'),
	(243, 1, 0, -50945, 800, 0, 0, 39, '799'),
	(243, 1, 0, -50945, 801, 0, 0, 39, '800'),
	(243, 1, 0, -50945, 802, 0, 0, 39, '801'),
	(243, 1, 0, -50945, 803, 0, 0, 39, '802'),
	(243, 1, 0, -50945, 804, 0, 0, 39, '803'),
	(243, 1, 0, -50945, 805, 0, 0, 39, '804'),
	(243, 1, 0, -50945, 806, 0, 0, 39, '805'),
	(243, 1, 0, -50945, 807, 0, 0, 39, '806'),
	(243, 1, 0, -50945, 808, 0, 0, 39, '807'),
	(243, 1, 0, -50945, 809, 0, 0, 39, '808'),
	(243, 1, 0, -50945, 810, 0, 0, 39, '809'),
	(243, 1, 0, -50945, 811, 0, 0, 39, '810'),
	(243, 1, 0, -50945, 812, 0, 0, 39, '811'),
	(243, 1, 0, -50945, 813, 0, 0, 39, '812'),
	(243, 1, 0, -50945, 814, 0, 0, 39, '813'),
	(243, 1, 0, -50945, 815, 0, 0, 39, '814'),
	(243, 1, 0, -50945, 816, 0, 0, 39, '815'),
	(243, 1, 0, -50945, 817, 0, 0, 39, '816'),
	(243, 1, 0, -50945, 818, 0, 0, 39, '817'),
	(243, 1, 0, -50945, 819, 0, 0, 39, '818'),
	(243, 1, 0, -50945, 820, 0, 0, 39, '819'),
	(243, 1, 0, -50945, 821, 0, 0, 39, '820'),
	(243, 1, 0, -50945, 822, 0, 0, 39, '821'),
	(243, 1, 0, -50945, 823, 0, 0, 39, '822'),
	(243, 1, 0, -50945, 824, 0, 0, 39, '823'),
	(243, 1, 0, -50945, 825, 0, 0, 39, '824'),
	(243, 1, 0, -50945, 826, 0, 0, 39, '825'),
	(243, 1, 0, -50945, 827, 0, 0, 39, '826'),
	(243, 1, 0, -50945, 828, 0, 0, 39, '827'),
	(243, 1, 0, -50945, 829, 0, 0, 39, '828'),
	(243, 1, 0, -50945, 830, 0, 0, 39, '829'),
	(243, 1, 0, -50945, 831, 0, 0, 39, '830'),
	(243, 1, 0, -50945, 832, 0, 0, 39, '831'),
	(243, 1, 0, -50945, 833, 0, 0, 39, '832'),
	(243, 1, 0, -50945, 834, 0, 0, 39, '833'),
	(243, 1, 0, -50945, 835, 0, 0, 39, '834'),
	(243, 1, 0, -50945, 836, 0, 0, 39, '835'),
	(243, 1, 0, -50945, 837, 0, 0, 39, '836'),
	(243, 1, 0, -50945, 838, 0, 0, 39, '837'),
	(243, 1, 0, -50945, 839, 0, 0, 39, '838'),
	(243, 1, 0, -50945, 840, 0, 0, 39, '839'),
	(243, 1, 0, -50945, 841, 0, 0, 39, '840'),
	(243, 1, 0, -50945, 842, 0, 0, 39, '841'),
	(243, 1, 0, -50945, 843, 0, 0, 39, '842'),
	(243, 1, 0, -50945, 844, 0, 0, 39, '843'),
	(243, 1, 0, -50945, 845, 0, 0, 39, '844'),
	(243, 1, 0, -50945, 846, 0, 0, 39, '845'),
	(243, 1, 0, -50945, 847, 0, 0, 39, '846'),
	(243, 1, 0, -50945, 848, 0, 0, 39, '847'),
	(243, 1, 0, -50945, 849, 0, 0, 39, '848'),
	(243, 1, 0, -50945, 850, 0, 0, 39, '849'),
	(243, 1, 0, -50945, 851, 0, 0, 39, '850'),
	(243, 1, 0, -50945, 852, 0, 0, 39, '851'),
	(243, 1, 0, -50945, 853, 0, 0, 39, '852'),
	(243, 1, 0, -50945, 854, 0, 0, 39, '853'),
	(243, 1, 0, -50945, 855, 0, 0, 39, '854'),
	(243, 1, 0, -50945, 856, 0, 0, 39, '855'),
	(243, 1, 0, -50945, 857, 0, 0, 39, '856'),
	(243, 1, 0, -50945, 858, 0, 0, 39, '857'),
	(243, 1, 0, -50945, 859, 0, 0, 39, '858'),
	(243, 1, 0, -50945, 860, 0, 0, 39, '859'),
	(243, 1, 0, -50945, 861, 0, 0, 39, '860'),
	(243, 1, 0, -50945, 862, 0, 0, 39, '861'),
	(243, 1, 0, -50945, 863, 0, 0, 39, '862'),
	(243, 1, 0, -50945, 864, 0, 0, 39, '863'),
	(243, 1, 0, -50945, 865, 0, 0, 39, '864'),
	(243, 1, 0, -50945, 866, 0, 0, 39, '865'),
	(243, 1, 0, -50945, 867, 0, 0, 39, '866'),
	(243, 1, 0, -50945, 868, 0, 0, 39, '867'),
	(243, 1, 0, -50945, 869, 0, 0, 39, '868'),
	(243, 1, 0, -50945, 870, 0, 0, 39, '869'),
	(243, 1, 0, -50945, 871, 0, 0, 39, '870'),
	(243, 1, 0, -50945, 872, 0, 0, 39, '871'),
	(243, 1, 0, -50945, 873, 0, 0, 39, '872'),
	(243, 1, 0, -50945, 874, 0, 0, 39, '873'),
	(243, 1, 0, -50945, 875, 0, 0, 39, '874'),
	(243, 1, 0, -50945, 876, 0, 0, 39, '875'),
	(243, 1, 0, -50945, 877, 0, 0, 39, '876'),
	(243, 1, 0, -50945, 878, 0, 0, 39, '877'),
	(243, 1, 0, -50945, 879, 0, 0, 39, '878'),
	(243, 1, 0, -50945, 880, 0, 0, 39, '879'),
	(243, 1, 0, -50945, 881, 0, 0, 39, '880'),
	(243, 1, 0, -50945, 882, 0, 0, 39, '881'),
	(243, 1, 0, -50945, 883, 0, 0, 39, '882'),
	(243, 1, 0, -50945, 884, 0, 0, 39, '883'),
	(243, 1, 0, -50945, 885, 0, 0, 39, '884'),
	(243, 1, 0, -50945, 886, 0, 0, 39, '885'),
	(243, 1, 0, -50945, 887, 0, 0, 39, '886'),
	(243, 1, 0, -50945, 888, 0, 0, 39, '887'),
	(243, 1, 0, -50945, 889, 0, 0, 39, '888'),
	(243, 1, 0, -50945, 890, 0, 0, 39, '889'),
	(243, 1, 0, -50945, 891, 0, 0, 39, '890'),
	(243, 1, 0, -50945, 892, 0, 0, 39, '891'),
	(243, 1, 0, -50945, 893, 0, 0, 39, '892'),
	(243, 1, 0, -50945, 894, 0, 0, 39, '893'),
	(243, 1, 0, -50945, 895, 0, 0, 39, '894'),
	(243, 1, 0, -50945, 896, 0, 0, 39, '895'),
	(243, 1, 0, -50945, 897, 0, 0, 39, '896'),
	(243, 1, 0, -50945, 898, 0, 0, 39, '897'),
	(243, 1, 0, -50945, 899, 0, 0, 39, '898'),
	(243, 1, 0, -50945, 900, 0, 0, 39, '899'),
	(243, 1, 0, -50945, 901, 0, 0, 39, '900'),
	(243, 1, 0, -50945, 902, 0, 0, 39, '901'),
	(243, 1, 0, -50945, 903, 0, 0, 39, '902'),
	(243, 1, 0, -50945, 904, 0, 0, 39, '903'),
	(243, 1, 0, -50945, 905, 0, 0, 39, '904'),
	(243, 1, 0, -50945, 906, 0, 0, 39, '905'),
	(243, 1, 0, -50945, 907, 0, 0, 39, '906'),
	(243, 1, 0, -50945, 908, 0, 0, 39, '907'),
	(243, 1, 0, -50945, 909, 0, 0, 39, '908'),
	(243, 1, 0, -50945, 910, 0, 0, 39, '909'),
	(243, 1, 0, -50945, 911, 0, 0, 39, '910'),
	(243, 1, 0, -50945, 912, 0, 0, 39, '911'),
	(243, 1, 0, -50945, 913, 0, 0, 39, '912'),
	(243, 1, 0, -50945, 914, 0, 0, 39, '913'),
	(243, 1, 0, -50945, 915, 0, 0, 39, '914'),
	(243, 1, 0, -50945, 916, 0, 0, 39, '915'),
	(243, 1, 0, -50945, 917, 0, 0, 39, '916'),
	(243, 1, 0, -50945, 918, 0, 0, 39, '917'),
	(243, 1, 0, -50945, 919, 0, 0, 39, '918'),
	(243, 1, 0, -50945, 920, 0, 0, 39, '919'),
	(243, 1, 0, -50945, 921, 0, 0, 39, '920'),
	(243, 1, 0, -50945, 922, 0, 0, 39, '921'),
	(243, 1, 0, -50945, 923, 0, 0, 39, '922'),
	(243, 1, 0, -50945, 924, 0, 0, 39, '923'),
	(243, 1, 0, -50945, 925, 0, 0, 39, '924'),
	(243, 1, 0, -50945, 926, 0, 0, 39, '925'),
	(243, 1, 0, -50945, 927, 0, 0, 39, '926'),
	(243, 1, 0, -50945, 928, 0, 0, 39, '927'),
	(243, 1, 0, -50945, 929, 0, 0, 39, '928'),
	(243, 1, 0, -50945, 930, 0, 0, 39, '929'),
	(243, 1, 0, -50945, 931, 0, 0, 39, '930'),
	(243, 1, 0, -50945, 932, 0, 0, 39, '931'),
	(243, 1, 0, -50945, 933, 0, 0, 39, '932'),
	(243, 1, 0, -50945, 934, 0, 0, 39, '933'),
	(243, 1, 0, -50945, 935, 0, 0, 39, '934'),
	(243, 1, 0, -50945, 936, 0, 0, 39, '935'),
	(243, 1, 0, -50945, 937, 0, 0, 39, '936'),
	(243, 1, 0, -50945, 938, 0, 0, 39, '937'),
	(243, 1, 0, -50945, 939, 0, 0, 39, '938'),
	(243, 1, 0, -50945, 940, 0, 0, 39, '939'),
	(243, 1, 0, -50945, 941, 0, 0, 39, '940'),
	(243, 1, 0, -50945, 942, 0, 0, 39, '941'),
	(243, 1, 0, -50945, 943, 0, 0, 39, '942'),
	(243, 1, 0, -50945, 944, 0, 0, 39, '943'),
	(243, 1, 0, -50945, 945, 0, 0, 39, '944'),
	(243, 1, 0, -50945, 946, 0, 0, 39, '945'),
	(243, 1, 0, -50945, 947, 0, 0, 39, '946'),
	(243, 1, 0, -50945, 948, 0, 0, 39, '947'),
	(243, 1, 0, -50945, 949, 0, 0, 39, '948'),
	(243, 1, 0, -50945, 950, 0, 0, 39, '949'),
	(243, 1, 0, -50945, 951, 0, 0, 39, '950'),
	(243, 1, 0, -50945, 952, 0, 0, 39, '951'),
	(243, 1, 0, -50945, 953, 0, 0, 39, '952'),
	(243, 1, 0, -50945, 954, 0, 0, 39, '953'),
	(243, 1, 0, -50945, 955, 0, 0, 39, '954'),
	(243, 1, 0, -50945, 956, 0, 0, 39, '955'),
	(243, 1, 0, -50945, 957, 0, 0, 39, '956'),
	(243, 1, 0, -50945, 958, 0, 0, 39, '957'),
	(243, 1, 0, -50945, 959, 0, 0, 39, '958'),
	(243, 1, 0, -50945, 960, 0, 0, 39, '959'),
	(243, 1, 0, -50945, 961, 0, 0, 39, '960'),
	(243, 1, 0, -50945, 962, 0, 0, 39, '961'),
	(243, 1, 0, -50945, 963, 0, 0, 39, '962'),
	(243, 1, 0, -50945, 964, 0, 0, 39, '963'),
	(243, 1, 0, -50945, 965, 0, 0, 39, '964'),
	(243, 1, 0, -50945, 966, 0, 0, 39, '965'),
	(243, 1, 0, -50945, 967, 0, 0, 39, '966'),
	(243, 1, 0, -50945, 968, 0, 0, 39, '967'),
	(243, 1, 0, -50945, 969, 0, 0, 39, '968'),
	(243, 1, 0, -50945, 970, 0, 0, 39, '969'),
	(243, 1, 0, -50945, 971, 0, 0, 39, '970'),
	(243, 1, 0, -50945, 972, 0, 0, 39, '971'),
	(243, 1, 0, -50945, 973, 0, 0, 39, '972'),
	(243, 1, 0, -50945, 974, 0, 0, 39, '973'),
	(243, 1, 0, -50945, 975, 0, 0, 39, '974'),
	(243, 1, 0, -50945, 976, 0, 0, 39, '975'),
	(243, 1, 0, -50945, 977, 0, 0, 39, '976'),
	(243, 1, 0, -50945, 978, 0, 0, 39, '977'),
	(243, 1, 0, -50945, 979, 0, 0, 39, '978'),
	(243, 1, 0, -50945, 980, 0, 0, 39, '979'),
	(243, 1, 0, -50945, 981, 0, 0, 39, '980'),
	(243, 1, 0, -50945, 982, 0, 0, 39, '981'),
	(243, 1, 0, -50945, 983, 0, 0, 39, '982'),
	(243, 1, 0, -50945, 984, 0, 0, 39, '983'),
	(243, 1, 0, -50945, 985, 0, 0, 39, '984'),
	(243, 1, 0, -50945, 986, 0, 0, 39, '985'),
	(243, 1, 0, -50945, 987, 0, 0, 39, '986'),
	(243, 1, 0, -50945, 988, 0, 0, 39, '987'),
	(243, 1, 0, -50945, 989, 0, 0, 39, '988'),
	(243, 1, 0, -50945, 990, 0, 0, 39, '989'),
	(243, 1, 0, -50945, 991, 0, 0, 39, '990'),
	(243, 1, 0, -50945, 992, 0, 0, 39, '991'),
	(243, 1, 0, -50945, 993, 0, 0, 39, '992'),
	(243, 1, 0, -50945, 994, 0, 0, 39, '993'),
	(243, 1, 0, -50945, 995, 0, 0, 39, '994'),
	(243, 1, 0, -50945, 996, 0, 0, 39, '995'),
	(243, 1, 0, -50945, 997, 0, 0, 39, '996'),
	(243, 1, 0, -50945, 998, 0, 0, 39, '997'),
	(243, 1, 0, -50945, 999, 0, 0, 39, '998'),
	(243, 1, 0, -50945, 1000, 0, 0, 39, '999'),
	(243, 1, 0, -50945, 1001, 0, 0, 39, '1000'),
	(243, 1, 0, -50945, 1002, 0, 0, 39, '1001'),
	(243, 1, 0, -50945, 1003, 0, 0, 39, '1002'),
	(243, 1, 0, -50945, 1004, 0, 0, 39, '1003'),
	(243, 1, 0, -50945, 1005, 0, 0, 39, '1004'),
	(243, 1, 0, -50945, 1006, 0, 0, 39, '1005'),
	(243, 1, 0, -50945, 1007, 0, 0, 39, '1006'),
	(243, 1, 0, -50945, 1008, 0, 0, 39, '1007'),
	(243, 1, 0, -50945, 1009, 0, 0, 39, '1008'),
	(243, 1, 0, -50945, 1010, 0, 0, 39, '1009'),
	(243, 1, 0, -50945, 1011, 0, 0, 39, '1010'),
	(243, 1, 0, -50945, 1012, 0, 0, 39, '1011'),
	(243, 1, 0, -50945, 1013, 0, 0, 39, '1012'),
	(243, 1, 0, -50945, 1014, 0, 0, 39, '1013'),
	(243, 1, 0, -50945, 1015, 0, 0, 39, '1014'),
	(243, 1, 0, -50945, 1016, 0, 0, 39, '1015'),
	(243, 1, 0, -50945, 1017, 0, 0, 39, '1016'),
	(243, 1, 0, -50945, 1018, 0, 0, 39, '1017'),
	(243, 1, 0, -50945, 1019, 0, 0, 39, '1018'),
	(243, 1, 0, -50945, 1020, 0, 0, 39, '1019'),
	(243, 1, 0, -50945, 1021, 0, 0, 39, '1020'),
	(243, 1, 0, -50945, 1022, 0, 0, 39, '1021'),
	(243, 1, 0, -50945, 1023, 0, 0, 39, '1022'),
	(243, 1, 0, -50945, 1024, 0, 0, 39, '1023'),
	(243, 1, 0, -50945, 1025, 0, 0, 39, '1024'),
	(243, 1, 0, -50945, 1026, 0, 0, 39, '1025'),
	(243, 1, 0, -50945, 1027, 0, 0, 39, '1026'),
	(243, 1, 0, -50945, 1028, 0, 0, 39, '1027'),
	(243, 1, 0, -50945, 1029, 0, 0, 39, '1028'),
	(243, 1, 0, -50945, 1030, 0, 0, 39, '1029'),
	(243, 1, 0, -50945, 1031, 0, 0, 39, '1030'),
	(243, 1, 0, -50945, 1032, 0, 0, 39, '1031'),
	(243, 1, 0, -50945, 1033, 0, 0, 39, '1032'),
	(243, 1, 0, -50945, 1034, 0, 0, 39, '1033'),
	(243, 1, 0, -50945, 1035, 0, 0, 39, '1034'),
	(243, 1, 0, -50945, 1036, 0, 0, 39, '1035'),
	(243, 1, 0, -50945, 1037, 0, 0, 39, '1036'),
	(243, 1, 0, -50945, 1038, 0, 0, 39, '1037'),
	(243, 1, 0, -50945, 1039, 0, 0, 39, '1038'),
	(243, 1, 0, -50945, 1040, 0, 0, 39, '1039'),
	(243, 1, 0, -50945, 1041, 0, 0, 39, '1040'),
	(243, 1, 0, -50945, 1042, 0, 0, 39, '1041'),
	(243, 1, 0, -50945, 1043, 0, 0, 39, '1042'),
	(243, 1, 0, -50945, 1044, 0, 0, 39, '1043'),
	(243, 1, 0, -50945, 1045, 0, 0, 39, '1044'),
	(243, 1, 0, -50945, 1046, 0, 0, 39, '1045'),
	(243, 1, 0, -50945, 1047, 0, 0, 39, '1046'),
	(243, 1, 0, -50945, 1048, 0, 0, 39, '1047'),
	(243, 1, 0, -50945, 1049, 0, 0, 39, '1048'),
	(243, 1, 0, -50945, 1050, 0, 0, 39, '1049'),
	(243, 1, 0, -50945, 1051, 0, 0, 39, '1050'),
	(243, 1, 0, -50945, 1052, 0, 0, 39, '1051'),
	(243, 1, 0, -50945, 1053, 0, 0, 39, '1052'),
	(243, 1, 0, -50945, 1054, 0, 0, 39, '1053'),
	(243, 1, 0, -50945, 1055, 0, 0, 39, '1054'),
	(243, 1, 0, -50945, 1056, 0, 0, 39, '1055'),
	(243, 1, 0, -50945, 1057, 0, 0, 39, '1056'),
	(243, 1, 0, -50945, 1058, 0, 0, 39, '1057'),
	(243, 1, 0, -50945, 1059, 0, 0, 39, '1058'),
	(243, 1, 0, -50945, 1060, 0, 0, 39, '1059'),
	(243, 1, 0, -50945, 1061, 0, 0, 39, '1060'),
	(243, 1, 0, -50945, 1062, 0, 0, 39, '1061'),
	(243, 1, 0, -50945, 1063, 0, 0, 39, '1062'),
	(243, 1, 0, -50945, 1064, 0, 0, 39, '1063'),
	(243, 1, 0, -50945, 1065, 0, 0, 39, '1064'),
	(243, 1, 0, -50945, 1066, 0, 0, 39, '1065'),
	(243, 1, 0, -50945, 1067, 0, 0, 39, '1066'),
	(243, 1, 0, -50945, 1068, 0, 0, 39, '1067'),
	(243, 1, 0, -50945, 1069, 0, 0, 39, '1068'),
	(243, 1, 0, -50945, 1070, 0, 0, 39, '1069'),
	(243, 1, 0, -50945, 1071, 0, 0, 39, '1070'),
	(243, 1, 0, -50945, 1072, 0, 0, 39, '1071'),
	(243, 1, 0, -50945, 1073, 0, 0, 39, '1072'),
	(243, 1, 0, -50945, 1074, 0, 0, 39, '1073'),
	(243, 1, 0, -50945, 1075, 0, 0, 39, '1074'),
	(243, 1, 0, -50945, 1076, 0, 0, 39, '1075'),
	(243, 1, 0, -50945, 1077, 0, 0, 39, '1076'),
	(243, 1, 0, -50945, 1078, 0, 0, 39, '1077'),
	(243, 1, 0, -50945, 1079, 0, 0, 39, '1078'),
	(243, 1, 0, -50945, 1080, 0, 0, 39, '1079'),
	(243, 1, 0, -50945, 1081, 0, 0, 39, '1080'),
	(243, 1, 0, -50945, 1082, 0, 0, 39, '1081'),
	(243, 1, 0, -50945, 1083, 0, 0, 39, '1082'),
	(243, 1, 0, -50945, 1084, 0, 0, 39, '1083'),
	(243, 1, 0, -50945, 1085, 0, 0, 39, '1084'),
	(243, 1, 0, -50945, 1086, 0, 0, 39, '1085'),
	(243, 1, 0, -50945, 1087, 0, 0, 39, '1086'),
	(243, 1, 0, -50945, 1088, 0, 0, 39, '1087'),
	(243, 1, 0, -50945, 1089, 0, 0, 39, '1088'),
	(243, 1, 0, -50945, 1090, 0, 0, 39, '1089'),
	(243, 1, 0, -50945, 1091, 0, 0, 39, '1090'),
	(243, 1, 0, -50945, 1092, 0, 0, 39, '1091'),
	(243, 1, 0, -50945, 1093, 0, 0, 39, '1092'),
	(243, 1, 0, -50945, 1094, 0, 0, 39, '1093'),
	(243, 1, 0, -50945, 1095, 0, 0, 39, '1094'),
	(243, 1, 0, -50945, 1096, 0, 0, 39, '1095'),
	(243, 1, 0, -50945, 1097, 0, 0, 39, '1096'),
	(243, 1, 0, -50945, 1098, 0, 0, 39, '1097'),
	(243, 1, 0, -50945, 1099, 0, 0, 39, '1098'),
	(243, 1, 0, -50945, 1100, 0, 0, 39, '1099'),
	(243, 1, 0, -50945, 1101, 0, 0, 39, '1100'),
	(243, 1, 0, -50945, 1102, 0, 0, 39, '1101'),
	(243, 1, 0, -50945, 1103, 0, 0, 39, '1102'),
	(243, 1, 0, -50945, 1104, 0, 0, 39, '1103'),
	(243, 1, 0, -50945, 1105, 0, 0, 39, '1104'),
	(243, 1, 0, -50945, 1106, 0, 0, 39, '1105'),
	(243, 1, 0, -50945, 1107, 0, 0, 39, '1106'),
	(243, 1, 0, -50945, 1108, 0, 0, 39, '1107'),
	(243, 1, 0, -50945, 1109, 0, 0, 39, '1108'),
	(243, 1, 0, -50945, 1110, 0, 0, 39, '1109'),
	(243, 1, 0, -50945, 1111, 0, 0, 39, '1110'),
	(243, 1, 0, -50945, 1112, 0, 0, 39, '1111'),
	(243, 1, 0, -50945, 1113, 0, 0, 39, '1112'),
	(243, 1, 0, -50945, 1114, 0, 0, 39, '1113'),
	(243, 1, 0, -50945, 1115, 0, 0, 39, '1114'),
	(243, 1, 0, -50945, 1116, 0, 0, 39, '1115'),
	(243, 1, 0, -50945, 1117, 0, 0, 39, '1116'),
	(243, 1, 0, -50945, 1118, 0, 0, 39, '1117'),
	(243, 1, 0, -50945, 1119, 0, 0, 39, '1118'),
	(243, 1, 0, -50945, 1120, 0, 0, 39, '1119'),
	(243, 1, 0, -50945, 1121, 0, 0, 39, '1120'),
	(243, 1, 0, -50945, 1122, 0, 0, 39, '1121'),
	(243, 1, 0, -50945, 1123, 0, 0, 39, '1122'),
	(243, 1, 0, -50945, 1124, 0, 0, 39, '1123'),
	(243, 1, 0, -50945, 1125, 0, 0, 39, '1124'),
	(243, 1, 0, -50945, 1126, 0, 0, 39, '1125'),
	(243, 1, 0, -50945, 1127, 0, 0, 39, '1126'),
	(243, 1, 0, -50945, 1128, 0, 0, 39, '1127'),
	(243, 1, 0, -50945, 1129, 0, 0, 39, '1128'),
	(243, 1, 0, -50945, 1130, 0, 0, 39, '1129'),
	(243, 1, 0, -50945, 1131, 0, 0, 39, '1130'),
	(243, 1, 0, -50945, 1132, 0, 0, 39, '1131'),
	(243, 1, 0, -50945, 1133, 0, 0, 39, '1132'),
	(243, 1, 0, -50945, 1134, 0, 0, 39, '1133'),
	(243, 1, 0, -50945, 1135, 0, 0, 39, '1134'),
	(243, 1, 0, -50945, 1136, 0, 0, 39, '1135'),
	(243, 1, 0, -50945, 1137, 0, 0, 39, '1136'),
	(243, 1, 0, -50945, 1138, 0, 0, 39, '1137'),
	(243, 1, 0, -50945, 1139, 0, 0, 39, '1138'),
	(243, 1, 0, -50945, 1140, 0, 0, 39, '1139'),
	(243, 1, 0, -50945, 1141, 0, 0, 39, '1140'),
	(243, 1, 0, -50945, 1142, 0, 0, 39, '1141'),
	(243, 1, 0, -50945, 1143, 0, 0, 39, '1142'),
	(243, 1, 0, -50945, 1144, 0, 0, 39, '1143'),
	(243, 1, 0, -50945, 1145, 0, 0, 39, '1144'),
	(243, 1, 0, -50945, 1146, 0, 0, 39, '1145'),
	(243, 1, 0, -50945, 1147, 0, 0, 39, '1146'),
	(243, 1, 0, -50945, 1148, 0, 0, 39, '1147'),
	(243, 1, 0, -50945, 1149, 0, 0, 39, '1148'),
	(243, 1, 0, -50945, 1150, 0, 0, 39, '1149'),
	(243, 1, 0, -50945, 1151, 0, 0, 39, '1150'),
	(243, 1, 0, -50945, 1152, 0, 0, 39, '1151'),
	(243, 1, 0, -50945, 1153, 0, 0, 39, '1152'),
	(243, 1, 0, -50945, 1154, 0, 0, 39, '1153'),
	(243, 1, 0, -50945, 1155, 0, 0, 39, '1154'),
	(243, 1, 0, -50945, 1156, 0, 0, 39, '1155'),
	(243, 1, 0, -50945, 1157, 0, 0, 39, '1156'),
	(243, 1, 0, -50945, 1158, 0, 0, 39, '1157'),
	(243, 1, 0, -50945, 1159, 0, 0, 39, '1158'),
	(243, 1, 0, -50945, 1160, 0, 0, 39, '1159'),
	(243, 1, 0, -50945, 1161, 0, 0, 39, '1160'),
	(243, 1, 0, -50945, 1162, 0, 0, 39, '1161'),
	(243, 1, 0, -50945, 1163, 0, 0, 39, '1162'),
	(243, 1, 0, -50945, 1164, 0, 0, 39, '1163'),
	(243, 1, 0, -50945, 1165, 0, 0, 39, '1164'),
	(243, 1, 0, -50945, 1166, 0, 0, 39, '1165'),
	(243, 1, 0, -50945, 1167, 0, 0, 39, '1166'),
	(243, 1, 0, -50945, 1168, 0, 0, 39, '1167'),
	(243, 1, 0, -50945, 1169, 0, 0, 39, '1168'),
	(243, 1, 0, -50945, 1170, 0, 0, 39, '1169'),
	(243, 1, 0, -50945, 1171, 0, 0, 39, '1170'),
	(243, 1, 0, -50945, 1172, 0, 0, 39, '1171'),
	(243, 1, 0, -50945, 1173, 0, 0, 39, '1172'),
	(243, 1, 0, -50945, 1174, 0, 0, 39, '1173'),
	(243, 1, 0, -50945, 1175, 0, 0, 39, '1174'),
	(243, 1, 0, -50945, 1176, 0, 0, 39, '1175'),
	(243, 1, 0, -50945, 1177, 0, 0, 39, '1176'),
	(243, 1, 0, -50945, 1178, 0, 0, 39, '1177'),
	(243, 1, 0, -50945, 1179, 0, 0, 39, '1178'),
	(243, 1, 0, -50945, 1180, 0, 0, 39, '1179'),
	(243, 1, 0, -50945, 1181, 0, 0, 39, '1180'),
	(243, 1, 0, -50945, 1182, 0, 0, 39, '1181'),
	(243, 1, 0, -50945, 1183, 0, 0, 39, '1182'),
	(243, 1, 0, -50945, 1184, 0, 0, 39, '1183'),
	(243, 1, 0, -50945, 1185, 0, 0, 39, '1184'),
	(243, 1, 0, -50945, 1186, 0, 0, 39, '1185'),
	(243, 1, 0, -50945, 1187, 0, 0, 39, '1186'),
	(243, 1, 0, -50945, 1188, 0, 0, 39, '1187'),
	(243, 1, 0, -50945, 1189, 0, 0, 39, '1188'),
	(243, 1, 0, -50945, 1190, 0, 0, 39, '1189'),
	(243, 1, 0, -50945, 1191, 0, 0, 39, '1190'),
	(243, 1, 0, -50945, 1192, 0, 0, 39, '1191'),
	(243, 1, 0, -50945, 1193, 0, 0, 39, '1192'),
	(243, 1, 0, -50945, 1194, 0, 0, 39, '1193'),
	(243, 1, 0, -50945, 1195, 0, 0, 39, '1194'),
	(243, 1, 0, -50945, 1196, 0, 0, 39, '1195'),
	(243, 1, 0, -50945, 1197, 0, 0, 39, '1196'),
	(243, 1, 0, -50945, 1198, 0, 0, 39, '1197'),
	(243, 1, 0, -50945, 1199, 0, 0, 39, '1198'),
	(243, 1, 0, -50945, 1200, 0, 0, 39, '1199'),
	(243, 1, 0, -50945, 1201, 0, 0, 39, '1200'),
	(243, 1, 0, -50945, 1202, 0, 0, 39, '1201'),
	(243, 1, 0, -50945, 1203, 0, 0, 39, '1202'),
	(243, 1, 0, -50945, 1204, 0, 0, 39, '1203'),
	(243, 1, 0, -50945, 1205, 0, 0, 39, '1204'),
	(243, 1, 0, -50945, 1206, 0, 0, 39, '1205'),
	(243, 1, 0, -50945, 1207, 0, 0, 39, '1206'),
	(243, 1, 0, -50945, 1208, 0, 0, 39, '1207'),
	(243, 1, 0, -50945, 1209, 0, 0, 39, '1208'),
	(243, 1, 0, -50945, 1210, 0, 0, 39, '1209'),
	(243, 1, 0, -50945, 1211, 0, 0, 39, '1210'),
	(243, 1, 0, -50945, 1212, 0, 0, 39, '1211'),
	(243, 1, 0, -50945, 1213, 0, 0, 39, '1212'),
	(243, 1, 0, -50945, 1214, 0, 0, 39, '1213'),
	(243, 1, 0, -50945, 1215, 0, 0, 39, '1214'),
	(243, 1, 0, -50945, 1216, 0, 0, 39, '1215'),
	(243, 1, 0, -50945, 1217, 0, 0, 39, '1216'),
	(243, 1, 0, -50945, 1218, 0, 0, 39, '1217'),
	(243, 1, 0, -50945, 1219, 0, 0, 39, '1218'),
	(243, 1, 0, -50945, 1220, 0, 0, 39, '1219'),
	(243, 1, 0, -50945, 1221, 0, 0, 39, '1220'),
	(243, 1, 0, -50945, 1222, 0, 0, 39, '1221'),
	(243, 1, 0, -50945, 1223, 0, 0, 39, '1222'),
	(243, 1, 0, -50945, 1224, 0, 0, 39, '1223'),
	(243, 1, 0, -50945, 1225, 0, 0, 39, '1224'),
	(243, 1, 0, -50945, 1226, 0, 0, 39, '1225'),
	(243, 1, 0, -50945, 1227, 0, 0, 39, '1226'),
	(243, 1, 0, -50945, 1228, 0, 0, 39, '1227'),
	(243, 1, 0, -50945, 1229, 0, 0, 39, '1228'),
	(243, 1, 0, -50945, 1230, 0, 0, 39, '1229'),
	(243, 1, 0, -50945, 1231, 0, 0, 39, '1230'),
	(243, 1, 0, -50945, 1232, 0, 0, 39, '1231'),
	(243, 1, 0, -50945, 1233, 0, 0, 39, '1232'),
	(243, 1, 0, -50945, 1234, 0, 0, 39, '1233'),
	(243, 1, 0, -50945, 1235, 0, 0, 39, '1234'),
	(243, 1, 0, -50945, 1236, 0, 0, 39, '1235'),
	(243, 1, 0, -50945, 1237, 0, 0, 39, '1236'),
	(243, 1, 0, -50945, 1238, 0, 0, 39, '1237'),
	(243, 1, 0, -50945, 1239, 0, 0, 39, '1238'),
	(243, 1, 0, -50945, 1240, 0, 0, 39, '1239'),
	(243, 1, 0, -50945, 1241, 0, 0, 39, '1240'),
	(243, 1, 0, -50945, 1242, 0, 0, 39, '1241'),
	(243, 1, 0, -50945, 1243, 0, 0, 39, '1242'),
	(243, 1, 0, -50945, 1244, 0, 0, 39, '1243'),
	(243, 1, 0, -50945, 1245, 0, 0, 39, '1244'),
	(243, 1, 0, -50945, 1246, 0, 0, 39, '1245'),
	(243, 1, 0, -50945, 1247, 0, 0, 39, '1246'),
	(243, 1, 0, -50945, 1248, 0, 0, 39, '1247'),
	(243, 1, 0, -50945, 1249, 0, 0, 39, '1248'),
	(243, 1, 0, -50945, 1250, 0, 0, 39, '1249'),
	(243, 1, 0, -50945, 1251, 0, 0, 39, '1250'),
	(243, 1, 0, -50945, 1252, 0, 0, 39, '1251'),
	(243, 1, 0, -50945, 1253, 0, 0, 39, '1252'),
	(243, 1, 0, -50945, 1254, 0, 0, 39, '1253'),
	(243, 1, 0, -50945, 1255, 0, 0, 39, '1254'),
	(243, 1, 0, -50945, 1256, 0, 0, 39, '1255'),
	(243, 1, 0, -50945, 1257, 0, 0, 39, '1256'),
	(243, 1, 0, -50945, 1258, 0, 0, 39, '1257'),
	(243, 1, 0, -50945, 1259, 0, 0, 39, '1258'),
	(243, 1, 0, -50945, 1260, 0, 0, 39, '1259'),
	(243, 1, 0, -50945, 1261, 0, 0, 39, '1260'),
	(243, 1, 0, -50945, 1262, 0, 0, 39, '1261'),
	(243, 1, 0, -50945, 1263, 0, 0, 39, '1262'),
	(243, 1, 0, -50945, 1264, 0, 0, 39, '1263'),
	(243, 1, 0, -50945, 1265, 0, 0, 39, '1264'),
	(243, 1, 0, -50945, 1266, 0, 0, 39, '1265'),
	(243, 1, 0, -50945, 1267, 0, 0, 39, '1266'),
	(243, 1, 0, -50945, 1268, 0, 0, 39, '1267'),
	(243, 1, 0, -50945, 1269, 0, 0, 39, '1268'),
	(243, 1, 0, -50945, 1270, 0, 0, 39, '1269'),
	(243, 1, 0, -50945, 1271, 0, 0, 39, '1270'),
	(243, 1, 0, -50945, 1272, 0, 0, 39, '1271'),
	(243, 1, 0, -50945, 1273, 0, 0, 39, '1272'),
	(243, 1, 0, -50945, 1274, 0, 0, 39, '1273'),
	(243, 1, 0, -50945, 1275, 0, 0, 39, '1274'),
	(243, 1, 0, -50945, 1276, 0, 0, 39, '1275'),
	(243, 1, 0, -50945, 1277, 0, 0, 39, '1276'),
	(243, 1, 0, -50945, 1278, 0, 0, 39, '1277'),
	(243, 1, 0, -50945, 1279, 0, 0, 39, '1278'),
	(243, 1, 0, -50945, 1280, 0, 0, 39, '1279'),
	(243, 1, 0, -50945, 1281, 0, 0, 39, '1280'),
	(243, 1, 0, -50945, 1282, 0, 0, 39, '1281'),
	(243, 1, 0, -50945, 1283, 0, 0, 39, '1282'),
	(243, 1, 0, -50945, 1284, 0, 0, 39, '1283'),
	(243, 1, 0, -50945, 1285, 0, 0, 39, '1284'),
	(243, 1, 0, -50945, 1286, 0, 0, 39, '1285'),
	(243, 1, 0, -50945, 1287, 0, 0, 39, '1286'),
	(243, 1, 0, -50945, 1288, 0, 0, 39, '1287'),
	(243, 1, 0, -50945, 1289, 0, 0, 39, '1288'),
	(243, 1, 0, -50945, 1290, 0, 0, 39, '1289'),
	(243, 1, 0, -50945, 1291, 0, 0, 39, '1290'),
	(243, 1, 0, -50945, 1292, 0, 0, 39, '1291'),
	(243, 1, 0, -50945, 1293, 0, 0, 39, '1292'),
	(243, 1, 0, -50945, 1294, 0, 0, 39, '1293'),
	(243, 1, 0, -50945, 1295, 0, 0, 39, '1294'),
	(243, 1, 0, -50945, 1296, 0, 0, 39, '1295'),
	(243, 1, 0, -50945, 1297, 0, 0, 39, '1296'),
	(243, 1, 0, -50945, 1298, 0, 0, 39, '1297'),
	(243, 1, 0, -50945, 1299, 0, 0, 39, '1298'),
	(243, 1, 0, -50945, 1300, 0, 0, 39, '1299'),
	(243, 1, 0, -50945, 1301, 0, 0, 39, '1300'),
	(243, 1, 0, -50945, 1302, 0, 0, 39, '1301'),
	(243, 1, 0, -50945, 1303, 0, 0, 39, '1302'),
	(243, 1, 0, -50945, 1304, 0, 0, 39, '1303'),
	(243, 1, 0, -50945, 1305, 0, 0, 39, '1304'),
	(243, 1, 0, -50945, 1306, 0, 0, 39, '1305'),
	(243, 1, 0, -50945, 1307, 0, 0, 39, '1306'),
	(243, 1, 0, -50945, 1308, 0, 0, 39, '1307'),
	(243, 1, 0, -50945, 1309, 0, 0, 39, '1308'),
	(243, 1, 0, -50945, 1310, 0, 0, 39, '1309'),
	(243, 1, 0, -50945, 1311, 0, 0, 39, '1310'),
	(243, 1, 0, -50945, 1312, 0, 0, 39, '1311'),
	(243, 1, 0, -50945, 1313, 0, 0, 39, '1312'),
	(243, 1, 0, -50945, 1314, 0, 0, 39, '1313'),
	(243, 1, 0, -50945, 1315, 0, 0, 39, '1314'),
	(243, 1, 0, -50945, 1316, 0, 0, 39, '1315'),
	(243, 1, 0, -50945, 1317, 0, 0, 39, '1316'),
	(243, 1, 0, -50945, 1318, 0, 0, 39, '1317'),
	(243, 1, 0, -50945, 1319, 0, 0, 39, '1318'),
	(243, 1, 0, -50945, 1320, 0, 0, 39, '1319'),
	(243, 1, 0, -50945, 1321, 0, 0, 39, '1320'),
	(243, 1, 0, -50945, 1322, 0, 0, 39, '1321'),
	(243, 1, 0, -50945, 1323, 0, 0, 39, '1322'),
	(243, 1, 0, -50945, 1324, 0, 0, 39, '1323'),
	(243, 1, 0, -50945, 1325, 0, 0, 39, '1324'),
	(243, 1, 0, -50945, 1326, 0, 0, 39, '1325'),
	(243, 1, 0, -50945, 1327, 0, 0, 39, '1326'),
	(243, 1, 0, -50945, 1328, 0, 0, 39, '1327'),
	(243, 1, 0, -50945, 1329, 0, 0, 39, '1328'),
	(243, 1, 0, -50945, 1330, 0, 0, 39, '1329'),
	(243, 1, 0, -50945, 1331, 0, 0, 39, '1330'),
	(243, 1, 0, -50945, 1332, 0, 0, 39, '1331'),
	(243, 1, 0, -50945, 1333, 0, 0, 39, '1332'),
	(243, 1, 0, -50945, 1334, 0, 0, 39, '1333'),
	(243, 1, 0, -50945, 1335, 0, 0, 39, '1334'),
	(243, 1, 0, -50945, 1336, 0, 0, 39, '1335'),
	(243, 1, 0, -50945, 1337, 0, 0, 39, '1336'),
	(243, 1, 0, -50945, 1338, 0, 0, 39, '1337'),
	(243, 1, 0, -50945, 1339, 0, 0, 39, '1338'),
	(243, 1, 0, -50945, 1340, 0, 0, 39, '1339'),
	(243, 1, 0, -50945, 1341, 0, 0, 39, '1340'),
	(243, 1, 0, -50945, 1342, 0, 0, 39, '1341'),
	(243, 1, 0, -50945, 1343, 0, 0, 39, '1342'),
	(243, 1, 0, -50945, 1344, 0, 0, 39, '1343'),
	(243, 1, 0, -50945, 1345, 0, 0, 39, '1344'),
	(243, 1, 0, -50945, 1346, 0, 0, 39, '1345'),
	(243, 1, 0, -50945, 1347, 0, 0, 39, '1346'),
	(243, 1, 0, -50945, 1348, 0, 0, 39, '1347'),
	(243, 1, 0, -50945, 1349, 0, 0, 39, '1348'),
	(243, 1, 0, -50945, 1350, 0, 0, 39, '1349'),
	(243, 1, 0, -50945, 1351, 0, 0, 39, '1350'),
	(243, 1, 0, -50945, 1352, 0, 0, 39, '1351'),
	(243, 1, 0, -50945, 1353, 0, 0, 39, '1352'),
	(243, 1, 0, -50945, 1354, 0, 0, 39, '1353'),
	(243, 1, 0, -50945, 1355, 0, 0, 39, '1354'),
	(243, 1, 0, -50945, 1356, 0, 0, 39, '1355'),
	(243, 1, 0, -50945, 1357, 0, 0, 39, '1356'),
	(243, 1, 0, -50945, 1358, 0, 0, 39, '1357'),
	(243, 1, 0, -50945, 1359, 0, 0, 39, '1358'),
	(243, 1, 0, -50945, 1360, 0, 0, 39, '1359'),
	(243, 1, 0, -50945, 1361, 0, 0, 39, '1360'),
	(243, 1, 0, -50945, 1362, 0, 0, 39, '1361'),
	(243, 1, 0, -50945, 1363, 0, 0, 39, '1362'),
	(243, 1, 0, -50945, 1364, 0, 0, 39, '1363'),
	(243, 1, 0, -50945, 1365, 0, 0, 39, '1364'),
	(243, 1, 0, -50945, 1366, 0, 0, 39, '1365'),
	(243, 1, 0, -50945, 1367, 0, 0, 39, '1366'),
	(243, 1, 0, -50945, 1368, 0, 0, 39, '1367'),
	(243, 1, 0, -50945, 1369, 0, 0, 39, '1368'),
	(243, 1, 0, -50945, 1370, 0, 0, 39, '1369'),
	(243, 1, 0, -50945, 1371, 0, 0, 39, '1370'),
	(243, 1, 0, -50945, 1372, 0, 0, 39, '1371'),
	(243, 1, 0, -50945, 1373, 0, 0, 39, '1372'),
	(243, 1, 0, -50945, 1374, 0, 0, 39, '1373'),
	(243, 1, 0, -50945, 1375, 0, 0, 39, '1374'),
	(243, 1, 0, -50945, 1376, 0, 0, 39, '1375'),
	(243, 1, 0, -50945, 1377, 0, 0, 39, '1376'),
	(243, 1, 0, -50945, 1378, 0, 0, 39, '1377'),
	(243, 1, 0, -50945, 1379, 0, 0, 39, '1378'),
	(243, 1, 0, -50945, 1380, 0, 0, 39, '1379'),
	(243, 1, 0, -50945, 1381, 0, 0, 39, '1380'),
	(243, 1, 0, -50945, 1382, 0, 0, 39, '1381'),
	(243, 1, 0, -50945, 1383, 0, 0, 39, '1382'),
	(243, 1, 0, -50945, 1384, 0, 0, 39, '1383'),
	(243, 1, 0, -50945, 1385, 0, 0, 39, '1384'),
	(243, 1, 0, -50945, 1386, 0, 0, 39, '1385'),
	(243, 1, 0, -50945, 1387, 0, 0, 39, '1386'),
	(243, 1, 0, -50945, 1388, 0, 0, 39, '1387'),
	(243, 1, 0, -50945, 1389, 0, 0, 39, '1388'),
	(243, 1, 0, -50945, 1390, 0, 0, 39, '1389'),
	(243, 1, 0, -50945, 1391, 0, 0, 39, '1390'),
	(243, 1, 0, -50945, 1392, 0, 0, 39, '1391'),
	(243, 1, 0, -50945, 1393, 0, 0, 39, '1392'),
	(243, 1, 0, -50945, 1394, 0, 0, 39, '1393'),
	(243, 1, 0, -50945, 1395, 0, 0, 39, '1394'),
	(243, 1, 0, -50945, 1396, 0, 0, 39, '1395'),
	(243, 1, 0, -50945, 1397, 0, 0, 39, '1396'),
	(243, 1, 0, -50945, 1398, 0, 0, 39, '1397'),
	(243, 1, 0, -50945, 1399, 0, 0, 39, '1398'),
	(243, 1, 0, -50945, 1400, 0, 0, 39, '1399'),
	(243, 1, 0, -50945, 1401, 0, 0, 39, '1400'),
	(243, 1, 0, -50945, 1402, 0, 0, 39, '1401'),
	(243, 1, 0, -50945, 1403, 0, 0, 39, '1402'),
	(243, 1, 0, -50945, 1404, 0, 0, 39, '1403'),
	(243, 1, 0, -50945, 1405, 0, 0, 39, '1404'),
	(243, 1, 0, -50945, 1406, 0, 0, 39, '1405'),
	(243, 1, 0, -50945, 1407, 0, 0, 39, '1406'),
	(243, 1, 0, -50945, 1408, 0, 0, 39, '1407'),
	(243, 1, 0, -50945, 1409, 0, 0, 39, '1408'),
	(243, 1, 0, -50945, 1410, 0, 0, 39, '1409'),
	(243, 1, 0, -50945, 1411, 0, 0, 39, '1410'),
	(243, 1, 0, -50945, 1412, 0, 0, 39, '1411'),
	(243, 1, 0, -50945, 1413, 0, 0, 39, '1412'),
	(243, 1, 0, -50945, 1414, 0, 0, 39, '1413'),
	(243, 1, 0, -50945, 1415, 0, 0, 39, '1414'),
	(243, 1, 0, -50945, 1416, 0, 0, 39, '1415'),
	(243, 1, 0, -50945, 1417, 0, 0, 39, '1416'),
	(243, 1, 0, -50945, 1418, 0, 0, 39, '1417'),
	(243, 1, 0, -50945, 1419, 0, 0, 39, '1418'),
	(243, 1, 0, -50945, 1420, 0, 0, 39, '1419'),
	(243, 1, 0, -50945, 1421, 0, 0, 39, '1420'),
	(243, 1, 0, -50945, 1422, 0, 0, 39, '1421'),
	(243, 1, 0, -50945, 1423, 0, 0, 39, '1422'),
	(243, 1, 0, -50945, 1424, 0, 0, 39, '1423'),
	(243, 1, 0, -50945, 1425, 0, 0, 39, '1424'),
	(243, 1, 0, -50945, 1426, 0, 0, 39, '1425'),
	(243, 1, 0, -50945, 1427, 0, 0, 39, '1426'),
	(243, 1, 0, -50945, 1428, 0, 0, 39, '1427'),
	(243, 1, 0, -50945, 1429, 0, 0, 39, '1428'),
	(243, 1, 0, -50945, 1430, 0, 0, 39, '1429'),
	(243, 1, 0, -50945, 1431, 0, 0, 39, '1430'),
	(243, 1, 0, -50945, 1432, 0, 0, 39, '1431'),
	(243, 1, 0, -50945, 1433, 0, 0, 39, '1432'),
	(243, 1, 0, -50945, 1434, 0, 0, 39, '1433'),
	(243, 1, 0, -50945, 1435, 0, 0, 39, '1434'),
	(243, 1, 0, -50945, 1436, 0, 0, 39, '1435'),
	(243, 1, 0, -50945, 1437, 0, 0, 39, '1436'),
	(243, 1, 0, -50945, 1438, 0, 0, 39, '1437'),
	(243, 1, 0, -50945, 1439, 0, 0, 39, '1438'),
	(243, 1, 0, -50945, 1440, 0, 0, 39, '1439'),
	(243, 1, 0, -50945, 1441, 0, 0, 39, '1440'),
	(243, 1, 0, -50945, 1442, 0, 0, 39, '1441'),
	(243, 1, 0, -50945, 1443, 0, 0, 39, '1442'),
	(243, 1, 0, -50945, 1444, 0, 0, 39, '1443'),
	(243, 1, 0, -50945, 1445, 0, 0, 39, '1444'),
	(243, 1, 0, -50945, 1446, 0, 0, 39, '1445'),
	(243, 1, 0, -50945, 1447, 0, 0, 39, '1446'),
	(243, 1, 0, -50945, 1448, 0, 0, 39, '1447'),
	(243, 1, 0, -50945, 1449, 0, 0, 39, '1448'),
	(243, 1, 0, -50945, 1450, 0, 0, 39, '1449'),
	(243, 1, 0, -50945, 1451, 0, 0, 39, '1450'),
	(243, 1, 0, -50945, 1452, 0, 0, 39, '1451'),
	(243, 1, 0, -50945, 1453, 0, 0, 39, '1452'),
	(243, 1, 0, -50945, 1454, 0, 0, 39, '1453'),
	(243, 1, 0, -50945, 1455, 0, 0, 39, '1454'),
	(243, 1, 0, -50945, 1456, 0, 0, 39, '1455'),
	(243, 1, 0, -50945, 1457, 0, 0, 39, '1456'),
	(243, 1, 0, -50945, 1458, 0, 0, 39, '1457'),
	(243, 1, 0, -50945, 1459, 0, 0, 39, '1458'),
	(243, 1, 0, -50945, 1460, 0, 0, 39, '1459'),
	(243, 1, 0, -50945, 1461, 0, 0, 39, '1460'),
	(243, 1, 0, -50945, 1462, 0, 0, 39, '1461'),
	(243, 1, 0, -50945, 1463, 0, 0, 39, '1462'),
	(243, 1, 0, -50945, 1464, 0, 0, 39, '1463'),
	(243, 1, 0, -50945, 1465, 0, 0, 39, '1464'),
	(243, 1, 0, -50945, 1466, 0, 0, 39, '1465'),
	(243, 1, 0, -50945, 1467, 0, 0, 39, '1466'),
	(243, 1, 0, -50945, 1468, 0, 0, 39, '1467'),
	(243, 1, 0, -50945, 1469, 0, 0, 39, '1468'),
	(243, 1, 0, -50945, 1470, 0, 0, 39, '1469'),
	(243, 1, 0, -50945, 1471, 0, 0, 39, '1470'),
	(243, 1, 0, -50945, 1472, 0, 0, 39, '1471'),
	(243, 1, 0, -50945, 1473, 0, 0, 39, '1472'),
	(243, 1, 0, -50945, 1474, 0, 0, 39, '1473'),
	(243, 1, 0, -50945, 1475, 0, 0, 39, '1474'),
	(243, 1, 0, -50945, 1476, 0, 0, 39, '1475'),
	(243, 1, 0, -50945, 1477, 0, 0, 39, '1476'),
	(243, 1, 0, -50945, 1478, 0, 0, 39, '1477'),
	(243, 1, 0, -50945, 1479, 0, 0, 39, '1478'),
	(243, 1, 0, -50945, 1480, 0, 0, 39, '1479'),
	(243, 1, 0, -50945, 1481, 0, 0, 39, '1480'),
	(243, 1, 0, -50945, 1482, 0, 0, 39, '1481'),
	(243, 1, 0, -50945, 1483, 0, 0, 39, '1482'),
	(243, 1, 0, -50945, 1484, 0, 0, 39, '1483'),
	(243, 1, 0, -50945, 1485, 0, 0, 39, '1484'),
	(243, 1, 0, -50945, 1486, 0, 0, 39, '1485'),
	(243, 1, 0, -50945, 1487, 0, 0, 39, '1486'),
	(243, 1, 0, -50945, 1488, 0, 0, 39, '1487'),
	(243, 1, 0, -50945, 1489, 0, 0, 39, '1488'),
	(243, 1, 0, -50945, 1490, 0, 0, 39, '1489'),
	(243, 1, 0, -50945, 1491, 0, 0, 39, '1490'),
	(243, 1, 0, -50945, 1492, 0, 0, 39, '1491'),
	(243, 1, 0, -50945, 1493, 0, 0, 39, '1492'),
	(243, 1, 0, -50945, 1494, 0, 0, 39, '1493'),
	(243, 1, 0, -50945, 1495, 0, 0, 39, '1494'),
	(243, 1, 0, -50945, 1496, 0, 0, 39, '1495'),
	(243, 1, 0, -50945, 1497, 0, 0, 39, '1496'),
	(243, 1, 0, -50945, 1498, 0, 0, 39, '1497'),
	(243, 1, 0, -50945, 1499, 0, 0, 39, '1498'),
	(243, 1, 0, -50945, 1500, 0, 0, 39, '1499'),
	(243, 1, 0, -50945, 1501, 0, 0, 39, '1500'),
	(243, 1, 0, -50945, 1502, 0, 0, 39, '1501'),
	(243, 1, 0, -50945, 1503, 0, 0, 39, '1502'),
	(243, 1, 0, -50945, 1504, 0, 0, 39, '1503'),
	(243, 1, 0, -50945, 1505, 0, 0, 39, '1504'),
	(243, 1, 0, -50945, 1506, 0, 0, 39, '1505'),
	(243, 1, 0, -50945, 1507, 0, 0, 39, '1506'),
	(243, 1, 0, -50945, 1508, 0, 0, 39, '1507'),
	(243, 1, 0, -50945, 1509, 0, 0, 39, '1508'),
	(243, 1, 0, -50945, 1510, 0, 0, 39, '1509'),
	(243, 1, 0, -50945, 1511, 0, 0, 39, '1510'),
	(243, 1, 0, -50945, 1512, 0, 0, 39, '1511'),
	(243, 1, 0, -50945, 1513, 0, 0, 39, '1512'),
	(243, 1, 0, -50945, 1514, 0, 0, 39, '1513'),
	(243, 1, 0, -50945, 1515, 0, 0, 39, '1514'),
	(243, 1, 0, -50945, 1516, 0, 0, 39, '1515'),
	(243, 1, 0, -50945, 1517, 0, 0, 39, '1516'),
	(243, 1, 0, -50945, 1518, 0, 0, 39, '1517'),
	(243, 1, 0, -50945, 1519, 0, 0, 39, '1518'),
	(243, 1, 0, -50945, 1520, 0, 0, 39, '1519'),
	(243, 1, 0, -50945, 1521, 0, 0, 39, '1520'),
	(243, 1, 0, -50945, 1522, 0, 0, 39, '1521'),
	(243, 1, 0, -50945, 1523, 0, 0, 39, '1522'),
	(243, 1, 0, -50945, 1524, 0, 0, 39, '1523'),
	(243, 1, 0, -50945, 1525, 0, 0, 39, '1524'),
	(243, 1, 0, -50945, 1526, 0, 0, 39, '1525'),
	(243, 1, 0, -50945, 1527, 0, 0, 39, '1526'),
	(243, 1, 0, -50945, 1528, 0, 0, 39, '1527'),
	(243, 1, 0, -50945, 1529, 0, 0, 39, '1528'),
	(243, 1, 0, -50945, 1530, 0, 0, 39, '1529'),
	(243, 1, 0, -50945, 1531, 0, 0, 39, '1530'),
	(243, 1, 0, -50945, 1532, 0, 0, 39, '1531'),
	(243, 1, 0, -50945, 1533, 0, 0, 39, '1532'),
	(243, 1, 0, -50945, 1534, 0, 0, 39, '1533'),
	(243, 1, 0, -50945, 1535, 0, 0, 39, '1534'),
	(243, 1, 0, -50945, 1536, 0, 0, 39, '1535'),
	(243, 1, 0, -50945, 1537, 0, 0, 39, '1536'),
	(243, 1, 0, -50945, 1538, 0, 0, 39, '1537'),
	(243, 1, 0, -50945, 1539, 0, 0, 39, '1538'),
	(243, 1, 0, -50945, 1540, 0, 0, 39, '1539'),
	(243, 1, 0, -50945, 1541, 0, 0, 39, '1540'),
	(243, 1, 0, -50945, 1542, 0, 0, 39, '1541'),
	(243, 1, 0, -50945, 1543, 0, 0, 39, '1542'),
	(243, 1, 0, -50945, 1544, 0, 0, 39, '1543'),
	(243, 1, 0, -50945, 1545, 0, 0, 39, '1544'),
	(243, 1, 0, -50945, 1546, 0, 0, 39, '1545'),
	(243, 1, 0, -50945, 1547, 0, 0, 39, '1546'),
	(243, 1, 0, -50945, 1548, 0, 0, 39, '1547'),
	(243, 1, 0, -50945, 1549, 0, 0, 39, '1548'),
	(243, 1, 0, -50945, 1550, 0, 0, 39, '1549'),
	(243, 1, 0, -50945, 1551, 0, 0, 39, '1550'),
	(243, 1, 0, -50945, 1552, 0, 0, 39, '1551'),
	(243, 1, 0, -50945, 1553, 0, 0, 39, '1552'),
	(243, 1, 0, -50945, 1554, 0, 0, 39, '1553'),
	(243, 1, 0, -50945, 1555, 0, 0, 39, '1554'),
	(243, 1, 0, -50945, 1556, 0, 0, 39, '1555'),
	(243, 1, 0, -50945, 1557, 0, 0, 39, '1556'),
	(243, 1, 0, -50945, 1558, 0, 0, 39, '1557'),
	(243, 1, 0, -50945, 1559, 0, 0, 39, '1558'),
	(243, 1, 0, -50945, 1560, 0, 0, 39, '1559'),
	(243, 1, 0, -50945, 1561, 0, 0, 39, '1560'),
	(243, 1, 0, -50945, 1562, 0, 0, 39, '1561'),
	(243, 1, 0, -50945, 1563, 0, 0, 39, '1562'),
	(243, 1, 0, -50945, 1564, 0, 0, 39, '1563'),
	(243, 1, 0, -50945, 1565, 0, 0, 39, '1564'),
	(243, 1, 0, -50945, 1566, 0, 0, 39, '1565'),
	(243, 1, 0, -50945, 1567, 0, 0, 39, '1566'),
	(243, 1, 0, -50945, 1568, 0, 0, 39, '1567'),
	(243, 1, 0, -50945, 1569, 0, 0, 39, '1568'),
	(243, 1, 0, -50945, 1570, 0, 0, 39, '1569'),
	(243, 1, 0, -50945, 1571, 0, 0, 39, '1570'),
	(243, 1, 0, -50945, 1572, 0, 0, 39, '1571'),
	(243, 1, 0, -50945, 1573, 0, 0, 39, '1572'),
	(243, 1, 0, -50945, 1574, 0, 0, 39, '1573'),
	(243, 1, 0, -50945, 1575, 0, 0, 39, '1574'),
	(243, 1, 0, -50945, 1576, 0, 0, 39, '1575'),
	(243, 1, 0, -50945, 1577, 0, 0, 39, '1576'),
	(243, 1, 0, -50945, 1578, 0, 0, 39, '1577'),
	(243, 1, 0, -50945, 1579, 0, 0, 39, '1578'),
	(243, 1, 0, -50945, 1580, 0, 0, 39, '1579'),
	(243, 1, 0, -50945, 1581, 0, 0, 39, '1580'),
	(243, 1, 0, -50945, 1582, 0, 0, 39, '1581'),
	(243, 1, 0, -50945, 1583, 0, 0, 39, '1582'),
	(243, 1, 0, -50945, 1584, 0, 0, 39, '1583'),
	(243, 1, 0, -50945, 1585, 0, 0, 39, '1584'),
	(243, 1, 0, -50945, 1586, 0, 0, 39, '1585'),
	(243, 1, 0, -50945, 1587, 0, 0, 39, '1586'),
	(243, 1, 0, -50945, 1588, 0, 0, 39, '1587'),
	(243, 1, 0, -50945, 1589, 0, 0, 39, '1588'),
	(243, 1, 0, -50945, 1590, 0, 0, 39, '1589'),
	(243, 1, 0, -50945, 1591, 0, 0, 39, '1590'),
	(243, 1, 0, -50945, 1592, 0, 0, 39, '1591'),
	(243, 1, 0, -50945, 1593, 0, 0, 39, '1592'),
	(243, 1, 0, -50945, 1594, 0, 0, 39, '1593'),
	(243, 1, 0, -50945, 1595, 0, 0, 39, '1594'),
	(243, 1, 0, -50945, 1596, 0, 0, 39, '1595'),
	(243, 1, 0, -50945, 1597, 0, 0, 39, '1596'),
	(243, 1, 0, -50945, 1598, 0, 0, 39, '1597'),
	(243, 1, 0, -50945, 1599, 0, 0, 39, '1598'),
	(243, 1, 0, -50945, 1600, 0, 0, 39, '1599'),
	(243, 1, 0, -50945, 1601, 0, 0, 39, '1600'),
	(243, 1, 0, -50945, 1602, 0, 0, 39, '1601'),
	(243, 1, 0, -50945, 1603, 0, 0, 39, '1602'),
	(243, 1, 0, -50945, 1604, 0, 0, 39, '1603'),
	(243, 1, 0, -50945, 1605, 0, 0, 39, '1604'),
	(243, 1, 0, -50945, 1606, 0, 0, 39, '1605'),
	(243, 1, 0, -50945, 1607, 0, 0, 39, '1606'),
	(243, 1, 0, -50945, 1608, 0, 0, 39, '1607'),
	(243, 1, 0, -50945, 1609, 0, 0, 39, '1608'),
	(243, 1, 0, -50945, 1610, 0, 0, 39, '1609'),
	(243, 1, 0, -50945, 1611, 0, 0, 39, '1610'),
	(243, 1, 0, -50945, 1612, 0, 0, 39, '1611'),
	(243, 1, 0, -50945, 1613, 0, 0, 39, '1612'),
	(243, 1, 0, -50945, 1614, 0, 0, 39, '1613'),
	(243, 1, 0, -50945, 1615, 0, 0, 39, '1614'),
	(243, 1, 0, -50945, 1616, 0, 0, 39, '1615'),
	(243, 1, 0, -50945, 1617, 0, 0, 39, '1616'),
	(243, 1, 0, -50945, 1618, 0, 0, 39, '1617'),
	(243, 1, 0, -50945, 1619, 0, 0, 39, '1618'),
	(243, 1, 0, -50945, 1620, 0, 0, 39, '1619'),
	(243, 1, 0, -50945, 1621, 0, 0, 39, '1620'),
	(243, 1, 0, -50945, 1622, 0, 0, 39, '1621'),
	(243, 1, 0, -50945, 1623, 0, 0, 39, '1622'),
	(243, 1, 0, -50945, 1624, 0, 0, 39, '1623'),
	(243, 1, 0, -50945, 1625, 0, 0, 39, '1624'),
	(243, 1, 0, -50945, 1626, 0, 0, 39, '1625'),
	(243, 1, 0, -50945, 1627, 0, 0, 39, '1626'),
	(243, 1, 0, -50945, 1628, 0, 0, 39, '1627'),
	(243, 1, 0, -50945, 1629, 0, 0, 39, '1628'),
	(243, 1, 0, -50945, 1630, 0, 0, 39, '1629'),
	(243, 1, 0, -50945, 1631, 0, 0, 39, '1630'),
	(243, 1, 0, -50945, 1632, 0, 0, 39, '1631'),
	(243, 1, 0, -50945, 1633, 0, 0, 39, '1632'),
	(243, 1, 0, -50945, 1634, 0, 0, 39, '1633'),
	(243, 1, 0, -50945, 1635, 0, 0, 39, '1634'),
	(243, 1, 0, -50945, 1636, 0, 0, 39, '1635'),
	(243, 1, 0, -50945, 1637, 0, 0, 39, '1636'),
	(243, 1, 0, -50945, 1638, 0, 0, 39, '1637'),
	(243, 1, 0, -50945, 1639, 0, 0, 39, '1638'),
	(243, 1, 0, -50945, 1640, 0, 0, 39, '1639'),
	(243, 1, 0, -50945, 1641, 0, 0, 39, '1640'),
	(243, 1, 0, -50945, 1642, 0, 0, 39, '1641'),
	(243, 1, 0, -50945, 1643, 0, 0, 39, '1642'),
	(243, 1, 0, -50945, 1644, 0, 0, 39, '1643'),
	(243, 1, 0, -50945, 1645, 0, 0, 39, '1644'),
	(243, 1, 0, -50945, 1646, 0, 0, 39, '1645'),
	(243, 1, 0, -50945, 1647, 0, 0, 39, '1646'),
	(243, 1, 0, -50945, 1648, 0, 0, 39, '1647'),
	(243, 1, 0, -50945, 1649, 0, 0, 39, '1648'),
	(243, 1, 0, -50945, 1650, 0, 0, 39, '1649'),
	(243, 1, 0, -50945, 1651, 0, 0, 39, '1650'),
	(243, 1, 0, -50945, 1652, 0, 0, 39, '1651'),
	(243, 1, 0, -50945, 1653, 0, 0, 39, '1652'),
	(243, 1, 0, -50945, 1654, 0, 0, 39, '1653'),
	(243, 1, 0, -50945, 1655, 0, 0, 39, '1654'),
	(243, 1, 0, -50945, 1656, 0, 0, 39, '1655'),
	(243, 1, 0, -50945, 1657, 0, 0, 39, '1656'),
	(243, 1, 0, -50945, 1658, 0, 0, 39, '1657'),
	(243, 1, 0, -50945, 1659, 0, 0, 39, '1658'),
	(243, 1, 0, -50945, 1660, 0, 0, 39, '1659'),
	(243, 1, 0, -50945, 1661, 0, 0, 39, '1660'),
	(243, 1, 0, -50945, 1662, 0, 0, 39, '1661'),
	(243, 1, 0, -50945, 1663, 0, 0, 39, '1662'),
	(243, 1, 0, -50945, 1664, 0, 0, 39, '1663'),
	(243, 1, 0, -50945, 1665, 0, 0, 39, '1664'),
	(243, 1, 0, -50945, 1666, 0, 0, 39, '1665'),
	(243, 1, 0, -50945, 1667, 0, 0, 39, '1666'),
	(243, 1, 0, -50945, 1668, 0, 0, 39, '1667'),
	(243, 1, 0, -50945, 1669, 0, 0, 39, '1668'),
	(243, 1, 0, -50945, 1670, 0, 0, 39, '1669'),
	(243, 1, 0, -50945, 1671, 0, 0, 39, '1670'),
	(243, 1, 0, -50945, 1672, 0, 0, 39, '1671'),
	(243, 1, 0, -50945, 1673, 0, 0, 39, '1672'),
	(243, 1, 0, -50945, 1674, 0, 0, 39, '1673'),
	(243, 1, 0, -50945, 1675, 0, 0, 39, '1674'),
	(243, 1, 0, -50945, 1676, 0, 0, 39, '1675'),
	(243, 1, 0, -50945, 1677, 0, 0, 39, '1676'),
	(243, 1, 0, -50945, 1678, 0, 0, 39, '1677'),
	(243, 1, 0, -50945, 1679, 0, 0, 39, '1678'),
	(243, 1, 0, -50945, 1680, 0, 0, 39, '1679'),
	(243, 1, 0, -50945, 1681, 0, 0, 39, '1680'),
	(243, 1, 0, -50945, 1682, 0, 0, 39, '1681'),
	(243, 1, 0, -50945, 1683, 0, 0, 39, '1682'),
	(243, 1, 0, -50945, 1684, 0, 0, 39, '1683'),
	(243, 1, 0, -50945, 1685, 0, 0, 39, '1684'),
	(243, 1, 0, -50945, 1686, 0, 0, 39, '1685'),
	(243, 1, 0, -50945, 1687, 0, 0, 39, '1686'),
	(243, 1, 0, -50945, 1688, 0, 0, 39, '1687'),
	(243, 1, 0, -50945, 1689, 0, 0, 39, '1688'),
	(243, 1, 0, -50945, 1690, 0, 0, 39, '1689'),
	(243, 1, 0, -50945, 1691, 0, 0, 39, '1690'),
	(243, 1, 0, -50945, 1692, 0, 0, 39, '1691'),
	(243, 1, 0, -50945, 1693, 0, 0, 39, '1692'),
	(243, 1, 0, -50945, 1694, 0, 0, 39, '1693'),
	(243, 1, 0, -50945, 1695, 0, 0, 39, '1694'),
	(243, 1, 0, -50945, 1696, 0, 0, 39, '1695'),
	(243, 1, 0, -50945, 1697, 0, 0, 39, '1696'),
	(243, 1, 0, -50945, 1698, 0, 0, 39, '1697'),
	(243, 1, 0, -50945, 1699, 0, 0, 39, '1698'),
	(243, 1, 0, -50945, 1700, 0, 0, 39, '1699'),
	(243, 1, 0, -50945, 1701, 0, 0, 39, '1700'),
	(243, 1, 0, -50945, 1702, 0, 0, 39, '1701'),
	(243, 1, 0, -50945, 1703, 0, 0, 39, '1702'),
	(243, 1, 0, -50945, 1704, 0, 0, 39, '1703'),
	(243, 1, 0, -50945, 1705, 0, 0, 39, '1704'),
	(243, 1, 0, -50945, 1706, 0, 0, 39, '1705'),
	(243, 1, 0, -50945, 1707, 0, 0, 39, '1706'),
	(243, 1, 0, -50945, 1708, 0, 0, 39, '1707'),
	(243, 1, 0, -50945, 1709, 0, 0, 39, '1708'),
	(243, 1, 0, -50945, 1710, 0, 0, 39, '1709'),
	(243, 1, 0, -50945, 1711, 0, 0, 39, '1710'),
	(243, 1, 0, -50945, 1712, 0, 0, 39, '1711'),
	(243, 1, 0, -50945, 1713, 0, 0, 39, '1712'),
	(243, 1, 0, -50945, 1714, 0, 0, 39, '1713'),
	(243, 1, 0, -50945, 1715, 0, 0, 39, '1714'),
	(243, 1, 0, -50945, 1716, 0, 0, 39, '1715'),
	(243, 1, 0, -50945, 1717, 0, 0, 39, '1716'),
	(243, 1, 0, -50945, 1718, 0, 0, 39, '1717'),
	(243, 1, 0, -50945, 1719, 0, 0, 39, '1718'),
	(243, 1, 0, -50945, 1720, 0, 0, 39, '1719'),
	(243, 1, 0, -50945, 1721, 0, 0, 39, '1720'),
	(243, 1, 0, -50945, 1722, 0, 0, 39, '1721'),
	(243, 1, 0, -50945, 1723, 0, 0, 39, '1722'),
	(243, 1, 0, -50945, 1724, 0, 0, 39, '1723'),
	(243, 1, 0, -50945, 1725, 0, 0, 39, '1724'),
	(243, 1, 0, -50945, 1726, 0, 0, 39, '1725'),
	(243, 1, 0, -50945, 1727, 0, 0, 39, '1726'),
	(243, 1, 0, -50945, 1728, 0, 0, 39, '1727'),
	(243, 1, 0, -50945, 1729, 0, 0, 39, '1728'),
	(243, 1, 0, -50945, 1730, 0, 0, 39, '1729'),
	(243, 1, 0, -50945, 1731, 0, 0, 39, '1730'),
	(243, 1, 0, -50945, 1732, 0, 0, 39, '1731'),
	(243, 1, 0, -50945, 1733, 0, 0, 39, '1732'),
	(243, 1, 0, -50945, 1734, 0, 0, 39, '1733'),
	(243, 1, 0, -50945, 1735, 0, 0, 39, '1734'),
	(243, 1, 0, -50945, 1736, 0, 0, 39, '1735'),
	(243, 1, 0, -50945, 1737, 0, 0, 39, '1736'),
	(243, 1, 0, -50945, 1738, 0, 0, 39, '1737'),
	(243, 1, 0, -50945, 1739, 0, 0, 39, '1738'),
	(243, 1, 0, -50945, 1740, 0, 0, 39, '1739'),
	(243, 1, 0, -50945, 1741, 0, 0, 39, '1740'),
	(243, 1, 0, -50945, 1742, 0, 0, 39, '1741'),
	(243, 1, 0, -50945, 1743, 0, 0, 39, '1742'),
	(243, 1, 0, -50945, 1744, 0, 0, 39, '1743'),
	(243, 1, 0, -50945, 1745, 0, 0, 39, '1744'),
	(243, 1, 0, -50945, 1746, 0, 0, 39, '1745'),
	(243, 1, 0, -50945, 1747, 0, 0, 39, '1746'),
	(243, 1, 0, -50945, 1748, 0, 0, 39, '1747'),
	(243, 1, 0, -50945, 1749, 0, 0, 39, '1748'),
	(243, 1, 0, -50945, 1750, 0, 0, 39, '1749'),
	(243, 1, 0, -50945, 1751, 0, 0, 39, '1750'),
	(243, 1, 0, -50945, 1752, 0, 0, 39, '1751'),
	(243, 1, 0, -50945, 1753, 0, 0, 39, '1752'),
	(243, 1, 0, -50945, 1754, 0, 0, 39, '1753'),
	(243, 1, 0, -50945, 1755, 0, 0, 39, '1754'),
	(243, 1, 0, -50945, 1756, 0, 0, 39, '1755'),
	(243, 1, 0, -50945, 1757, 0, 0, 39, '1756'),
	(243, 1, 0, -50945, 1758, 0, 0, 39, '1757'),
	(243, 1, 0, -50945, 1759, 0, 0, 39, '1758'),
	(243, 1, 0, -50945, 1760, 0, 0, 39, '1759'),
	(243, 1, 0, -50945, 1761, 0, 0, 39, '1760'),
	(243, 1, 0, -50945, 1762, 0, 0, 39, '1761'),
	(243, 1, 0, -50945, 1763, 0, 0, 39, '1762'),
	(243, 1, 0, -50945, 1764, 0, 0, 39, '1763'),
	(243, 1, 0, -50945, 1765, 0, 0, 39, '1764'),
	(243, 1, 0, -50945, 1766, 0, 0, 39, '1765'),
	(243, 1, 0, -50945, 1767, 0, 0, 39, '1766'),
	(243, 1, 0, -50945, 1768, 0, 0, 39, '1767'),
	(243, 1, 0, -50945, 1769, 0, 0, 39, '1768'),
	(243, 1, 0, -50945, 1770, 0, 0, 39, '1769'),
	(243, 1, 0, -50945, 1771, 0, 0, 39, '1770'),
	(243, 1, 0, -50945, 1772, 0, 0, 39, '1771'),
	(243, 1, 0, -50945, 1773, 0, 0, 39, '1772'),
	(243, 1, 0, -50945, 1774, 0, 0, 39, '1773'),
	(243, 1, 0, -50945, 1775, 0, 0, 39, '1774'),
	(243, 1, 0, -50945, 1776, 0, 0, 39, '1775'),
	(243, 1, 0, -50945, 1777, 0, 0, 39, '1776'),
	(243, 1, 0, -50945, 1778, 0, 0, 39, '1777'),
	(243, 1, 0, -50945, 1779, 0, 0, 39, '1778'),
	(243, 1, 0, -50945, 1780, 0, 0, 39, '1779'),
	(243, 1, 0, -50945, 1781, 0, 0, 39, '1780'),
	(243, 1, 0, -50945, 1782, 0, 0, 39, '1781'),
	(243, 1, 0, -50945, 1783, 0, 0, 39, '1782'),
	(243, 1, 0, -50945, 1784, 0, 0, 39, '1783'),
	(243, 1, 0, -50945, 1785, 0, 0, 39, '1784'),
	(243, 1, 0, -50945, 1786, 0, 0, 39, '1785'),
	(243, 1, 0, -50945, 1787, 0, 0, 39, '1786'),
	(243, 1, 0, -50945, 1788, 0, 0, 39, '1787'),
	(243, 1, 0, -50945, 1789, 0, 0, 39, '1788'),
	(243, 1, 0, -50945, 1790, 0, 0, 39, '1789'),
	(243, 1, 0, -50945, 1791, 0, 0, 39, '1790'),
	(243, 1, 0, -50945, 1792, 0, 0, 39, '1791'),
	(243, 1, 0, -50945, 1793, 0, 0, 39, '1792'),
	(243, 1, 0, -50945, 1794, 0, 0, 39, '1793'),
	(243, 1, 0, -50945, 1795, 0, 0, 39, '1794'),
	(243, 1, 0, -50945, 1796, 0, 0, 39, '1795'),
	(243, 1, 0, -50945, 1797, 0, 0, 39, '1796'),
	(243, 1, 0, -50945, 1798, 0, 0, 39, '1797'),
	(243, 1, 0, -50945, 1799, 0, 0, 39, '1798'),
	(243, 1, 0, -50945, 1800, 0, 0, 39, '1799'),
	(243, 1, 0, -50945, 1801, 0, 0, 39, '1800'),
	(243, 1, 0, -50945, 1802, 0, 0, 39, '1801'),
	(243, 1, 0, -50945, 1803, 0, 0, 39, '1802'),
	(243, 1, 0, -50945, 1804, 0, 0, 39, '1803'),
	(243, 1, 0, -50945, 1805, 0, 0, 39, '1804'),
	(243, 1, 0, -50945, 1806, 0, 0, 39, '1805'),
	(243, 1, 0, -50945, 1807, 0, 0, 39, '1806'),
	(243, 1, 0, -50945, 1808, 0, 0, 39, '1807'),
	(243, 1, 0, -50945, 1809, 0, 0, 39, '1808'),
	(243, 1, 0, -50945, 1810, 0, 0, 39, '1809'),
	(243, 1, 0, -50945, 1811, 0, 0, 39, '1810'),
	(243, 1, 0, -50945, 1812, 0, 0, 39, '1811'),
	(243, 1, 0, -50945, 1813, 0, 0, 39, '1812'),
	(243, 1, 0, -50945, 1814, 0, 0, 39, '1813'),
	(243, 1, 0, -50945, 1815, 0, 0, 39, '1814'),
	(243, 1, 0, -50945, 1816, 0, 0, 39, '1815'),
	(243, 1, 0, -50945, 1817, 0, 0, 39, '1816'),
	(243, 1, 0, -50945, 1818, 0, 0, 39, '1817'),
	(243, 1, 0, -50945, 1819, 0, 0, 39, '1818'),
	(243, 1, 0, -50945, 1820, 0, 0, 39, '1819'),
	(243, 1, 0, -50945, 1821, 0, 0, 39, '1820'),
	(243, 1, 0, -50945, 1822, 0, 0, 39, '1821'),
	(243, 1, 0, -50945, 1823, 0, 0, 39, '1822'),
	(243, 1, 0, -50945, 1824, 0, 0, 39, '1823'),
	(243, 1, 0, -50945, 1825, 0, 0, 39, '1824'),
	(243, 1, 0, -50945, 1826, 0, 0, 39, '1825'),
	(243, 1, 0, -50945, 1827, 0, 0, 39, '1826'),
	(243, 1, 0, -50945, 1828, 0, 0, 39, '1827'),
	(243, 1, 0, -50945, 1829, 0, 0, 39, '1828'),
	(243, 1, 0, -50945, 1830, 0, 0, 39, '1829'),
	(243, 1, 0, -50945, 1831, 0, 0, 39, '1830'),
	(243, 1, 0, -50945, 1832, 0, 0, 39, '1831'),
	(243, 1, 0, -50945, 1833, 0, 0, 39, '1832'),
	(243, 1, 0, -50945, 1834, 0, 0, 39, '1833'),
	(243, 1, 0, -50945, 1835, 0, 0, 39, '1834'),
	(243, 1, 0, -50945, 1836, 0, 0, 39, '1835'),
	(243, 1, 0, -50945, 1837, 0, 0, 39, '1836'),
	(243, 1, 0, -50945, 1838, 0, 0, 39, '1837'),
	(243, 1, 0, -50945, 1839, 0, 0, 39, '1838'),
	(243, 1, 0, -50945, 1840, 0, 0, 39, '1839'),
	(243, 1, 0, -50945, 1841, 0, 0, 39, '1840'),
	(243, 1, 0, -50945, 1842, 0, 0, 39, '1841'),
	(243, 1, 0, -50945, 1843, 0, 0, 39, '1842'),
	(243, 1, 0, -50945, 1844, 0, 0, 39, '1843'),
	(243, 1, 0, -50945, 1845, 0, 0, 39, '1844'),
	(243, 1, 0, -50945, 1846, 0, 0, 39, '1845'),
	(243, 1, 0, -50945, 1847, 0, 0, 39, '1846'),
	(243, 1, 0, -50945, 1848, 0, 0, 39, '1847'),
	(243, 1, 0, -50945, 1849, 0, 0, 39, '1848'),
	(243, 1, 0, -50945, 1850, 0, 0, 39, '1849'),
	(243, 1, 0, -50945, 1851, 0, 0, 39, '1850'),
	(243, 1, 0, -50945, 1852, 0, 0, 39, '1851'),
	(243, 1, 0, -50945, 1853, 0, 0, 39, '1852'),
	(243, 1, 0, -50945, 1854, 0, 0, 39, '1853'),
	(243, 1, 0, -50945, 1855, 0, 0, 39, '1854'),
	(243, 1, 0, -50945, 1856, 0, 0, 39, '1855'),
	(243, 1, 0, -50945, 1857, 0, 0, 39, '1856'),
	(243, 1, 0, -50945, 1858, 0, 0, 39, '1857'),
	(243, 1, 0, -50945, 1859, 0, 0, 39, '1858'),
	(243, 1, 0, -50945, 1860, 0, 0, 39, '1859'),
	(243, 1, 0, -50945, 1861, 0, 0, 39, '1860'),
	(243, 1, 0, -50945, 1862, 0, 0, 39, '1861'),
	(243, 1, 0, -50945, 1863, 0, 0, 39, '1862'),
	(243, 1, 0, -50945, 1864, 0, 0, 39, '1863'),
	(243, 1, 0, -50945, 1865, 0, 0, 39, '1864'),
	(243, 1, 0, -50945, 1866, 0, 0, 39, '1865'),
	(243, 1, 0, -50945, 1867, 0, 0, 39, '1866'),
	(243, 1, 0, -50945, 1868, 0, 0, 39, '1867'),
	(243, 1, 0, -50945, 1869, 0, 0, 39, '1868'),
	(243, 1, 0, -50945, 1870, 0, 0, 39, '1869'),
	(243, 1, 0, -50945, 1871, 0, 0, 39, '1870'),
	(243, 1, 0, -50945, 1872, 0, 0, 39, '1871'),
	(243, 1, 0, -50945, 1873, 0, 0, 39, '1872'),
	(243, 1, 0, -50945, 1874, 0, 0, 39, '1873'),
	(243, 1, 0, -50945, 1875, 0, 0, 39, '1874'),
	(243, 1, 0, -50945, 1876, 0, 0, 39, '1875'),
	(243, 1, 0, -50945, 1877, 0, 0, 39, '1876'),
	(243, 1, 0, -50945, 1878, 0, 0, 39, '1877'),
	(243, 1, 0, -50945, 1879, 0, 0, 39, '1878'),
	(243, 1, 0, -50945, 1880, 0, 0, 39, '1879'),
	(243, 1, 0, -50945, 1881, 0, 0, 39, '1880'),
	(243, 1, 0, -50945, 1882, 0, 0, 39, '1881'),
	(243, 1, 0, -50945, 1883, 0, 0, 39, '1882'),
	(243, 1, 0, -50945, 1884, 0, 0, 39, '1883'),
	(243, 1, 0, -50945, 1885, 0, 0, 39, '1884'),
	(243, 1, 0, -50945, 1886, 0, 0, 39, '1885'),
	(243, 1, 0, -50945, 1887, 0, 0, 39, '1886'),
	(243, 1, 0, -50945, 1888, 0, 0, 39, '1887'),
	(243, 1, 0, -50945, 1889, 0, 0, 39, '1888'),
	(243, 1, 0, -50945, 1890, 0, 0, 39, '1889'),
	(243, 1, 0, -50945, 1891, 0, 0, 39, '1890'),
	(243, 1, 0, -50945, 1892, 0, 0, 39, '1891'),
	(243, 1, 0, -50945, 1893, 0, 0, 39, '1892'),
	(243, 1, 0, -50945, 1894, 0, 0, 39, '1893'),
	(243, 1, 0, -50945, 1895, 0, 0, 39, '1894'),
	(243, 1, 0, -50945, 1896, 0, 0, 39, '1895'),
	(243, 1, 0, -50945, 1897, 0, 0, 39, '1896'),
	(243, 1, 0, -50945, 1898, 0, 0, 39, '1897'),
	(243, 1, 0, -50945, 1899, 0, 0, 39, '1898'),
	(243, 1, 0, -50945, 1900, 0, 0, 39, '1899'),
	(243, 1, 0, -50945, 1901, 0, 0, 39, '1900'),
	(243, 1, 0, -50945, 1902, 0, 0, 39, '1901'),
	(243, 1, 0, -50945, 1903, 0, 0, 39, '1902'),
	(243, 1, 0, -50945, 1904, 0, 0, 39, '1903'),
	(243, 1, 0, -50945, 1905, 0, 0, 39, '1904'),
	(243, 1, 0, -50945, 1906, 0, 0, 39, '1905'),
	(243, 1, 0, -50945, 1907, 0, 0, 39, '1906'),
	(243, 1, 0, -50945, 1908, 0, 0, 39, '1907'),
	(243, 1, 0, -50945, 1909, 0, 0, 39, '1908'),
	(243, 1, 0, -50945, 1910, 0, 0, 39, '1909'),
	(243, 1, 0, -50945, 1911, 0, 0, 39, '1910'),
	(243, 1, 0, -50945, 1912, 0, 0, 39, '1911'),
	(243, 1, 0, -50945, 1913, 0, 0, 39, '1912'),
	(243, 1, 0, -50945, 1914, 0, 0, 39, '1913'),
	(243, 1, 0, -50945, 1915, 0, 0, 39, '1914'),
	(243, 1, 0, -50945, 1916, 0, 0, 39, '1915'),
	(243, 1, 0, -50945, 1917, 0, 0, 39, '1916'),
	(243, 1, 0, -50945, 1918, 0, 0, 39, '1917'),
	(243, 1, 0, -50945, 1919, 0, 0, 39, '1918'),
	(243, 1, 0, -50945, 1920, 0, 0, 39, '1919'),
	(243, 1, 0, -50945, 1921, 0, 0, 39, '1920'),
	(243, 1, 0, -50945, 1922, 0, 0, 39, '1921'),
	(243, 1, 0, -50945, 1923, 0, 0, 39, '1922'),
	(243, 1, 0, -50945, 1924, 0, 0, 39, '1923'),
	(243, 1, 0, -50945, 1925, 0, 0, 39, '1924'),
	(243, 1, 0, -50945, 1926, 0, 0, 39, '1925'),
	(243, 1, 0, -50945, 1927, 0, 0, 39, '1926'),
	(243, 1, 0, -50945, 1928, 0, 0, 39, '1927'),
	(243, 1, 0, -50945, 1929, 0, 0, 39, '1928'),
	(243, 1, 0, -50945, 1930, 0, 0, 39, '1929'),
	(243, 1, 0, -50945, 1931, 0, 0, 39, '1930'),
	(243, 1, 0, -50945, 1932, 0, 0, 39, '1931'),
	(243, 1, 0, -50945, 1933, 0, 0, 39, '1932'),
	(243, 1, 0, -50945, 1934, 0, 0, 39, '1933'),
	(243, 1, 0, -50945, 1935, 0, 0, 39, '1934'),
	(243, 1, 0, -50945, 1936, 0, 0, 39, '1935'),
	(243, 1, 0, -50945, 1937, 0, 0, 39, '1936'),
	(243, 1, 0, -50945, 1938, 0, 0, 39, '1937'),
	(243, 1, 0, -50945, 1939, 0, 0, 39, '1938'),
	(243, 1, 0, -50945, 1940, 0, 0, 39, '1939'),
	(243, 1, 0, -50945, 1941, 0, 0, 39, '1940'),
	(243, 1, 0, -50945, 1942, 0, 0, 39, '1941'),
	(243, 1, 0, -50945, 1943, 0, 0, 39, '1942'),
	(243, 1, 0, -50945, 1944, 0, 0, 39, '1943'),
	(243, 1, 0, -50945, 1945, 0, 0, 39, '1944'),
	(243, 1, 0, -50945, 1946, 0, 0, 39, '1945'),
	(243, 1, 0, -50945, 1947, 0, 0, 39, '1946'),
	(243, 1, 0, -50945, 1948, 0, 0, 39, '1947'),
	(243, 1, 0, -50945, 1949, 0, 0, 39, '1948'),
	(243, 1, 0, -50945, 1950, 0, 0, 39, '1949'),
	(243, 1, 0, -50945, 1951, 0, 0, 39, '1950'),
	(243, 1, 0, -50945, 1952, 0, 0, 39, '1951'),
	(243, 1, 0, -50945, 1953, 0, 0, 39, '1952'),
	(243, 1, 0, -50945, 1954, 0, 0, 39, '1953'),
	(243, 1, 0, -50945, 1955, 0, 0, 39, '1954'),
	(243, 1, 0, -50945, 1956, 0, 0, 39, '1955'),
	(243, 1, 0, -50945, 1957, 0, 0, 39, '1956'),
	(243, 1, 0, -50945, 1958, 0, 0, 39, '1957'),
	(243, 1, 0, -50945, 1959, 0, 0, 39, '1958'),
	(243, 1, 0, -50945, 1960, 0, 0, 39, '1959'),
	(243, 1, 0, -50945, 1961, 0, 0, 39, '1960'),
	(243, 1, 0, -50945, 1962, 0, 0, 39, '1961'),
	(243, 1, 0, -50945, 1963, 0, 0, 39, '1962'),
	(243, 1, 0, -50945, 1964, 0, 0, 39, '1963'),
	(243, 1, 0, -50945, 1965, 0, 0, 39, '1964'),
	(243, 1, 0, -50945, 1966, 0, 0, 39, '1965'),
	(243, 1, 0, -50945, 1967, 0, 0, 39, '1966'),
	(243, 1, 0, -50945, 1968, 0, 0, 39, '1967'),
	(243, 1, 0, -50945, 1969, 0, 0, 39, '1968'),
	(243, 1, 0, -50945, 1970, 0, 0, 39, '1969'),
	(243, 1, 0, -50945, 1971, 0, 0, 39, '1970'),
	(243, 1, 0, -50945, 1972, 0, 0, 39, '1971'),
	(243, 1, 0, -50945, 1973, 0, 0, 39, '1972'),
	(243, 1, 0, -50945, 1974, 0, 0, 39, '1973'),
	(243, 1, 0, -50945, 1975, 0, 0, 39, '1974'),
	(243, 1, 0, -50945, 1976, 0, 0, 39, '1975'),
	(243, 1, 0, -50945, 1977, 0, 0, 39, '1976'),
	(243, 1, 0, -50945, 1978, 0, 0, 39, '1977'),
	(243, 1, 0, -50945, 1979, 0, 0, 39, '1978'),
	(243, 1, 0, -50945, 1980, 0, 0, 39, '1979'),
	(243, 1, 0, -50945, 1981, 0, 0, 39, '1980'),
	(243, 1, 0, -50945, 1982, 0, 0, 39, '1981'),
	(243, 1, 0, -50945, 1983, 0, 0, 39, '1982'),
	(243, 1, 0, -50945, 1984, 0, 0, 39, '1983'),
	(243, 1, 0, -50945, 1985, 0, 0, 39, '1984'),
	(243, 1, 0, -50945, 1986, 0, 0, 39, '1985'),
	(243, 1, 0, -50945, 1987, 0, 0, 39, '1986'),
	(243, 1, 0, -50945, 1988, 0, 0, 39, '1987'),
	(243, 1, 0, -50945, 1989, 0, 0, 39, '1988'),
	(243, 1, 0, -50945, 1990, 0, 0, 39, '1989'),
	(243, 1, 0, -50945, 1991, 0, 0, 39, '1990'),
	(243, 1, 0, -50945, 1992, 0, 0, 39, '1991'),
	(243, 1, 0, -50945, 1993, 0, 0, 39, '1992'),
	(243, 1, 0, -50945, 1994, 0, 0, 39, '1993'),
	(243, 1, 0, -50945, 1995, 0, 0, 39, '1994'),
	(243, 1, 0, -50945, 1996, 0, 0, 39, '1995'),
	(243, 1, 0, -50945, 1997, 0, 0, 39, '1996'),
	(243, 1, 0, -50945, 1998, 0, 0, 39, '1997'),
	(243, 1, 0, -50945, 1999, 0, 0, 39, '1998'),
	(243, 1, 0, -50945, 2000, 0, 0, 39, '1999'),
	(243, 1, 0, -50945, 2001, 0, 0, 39, '2000'),
	(243, 1, 0, -50945, 2002, 0, 0, 39, '2001'),
	(243, 1, 0, -50945, 2003, 0, 0, 39, '2002'),
	(243, 1, 0, -50945, 2004, 0, 0, 39, '2003'),
	(243, 1, 0, -50945, 2005, 0, 0, 39, '2004'),
	(243, 1, 0, -50945, 2006, 0, 0, 39, '2005'),
	(243, 1, 0, -50945, 2007, 0, 0, 39, '2006'),
	(243, 1, 0, -50945, 2008, 0, 0, 39, '2007'),
	(243, 1, 0, -50945, 2009, 0, 0, 39, '2008'),
	(243, 1, 0, -50945, 2010, 0, 0, 39, '2009'),
	(243, 1, 0, -50945, 2011, 0, 0, 39, '2010'),
	(243, 1, 0, -50945, 2012, 0, 0, 39, '2011'),
	(243, 1, 0, -50945, 2013, 0, 0, 39, '2012'),
	(243, 1, 0, -50945, 2014, 0, 0, 39, '2013'),
	(243, 1, 0, -50945, 2015, 0, 0, 39, '2014'),
	(243, 1, 0, -50945, 2016, 0, 0, 39, '2015'),
	(243, 1, 0, -50945, 2017, 0, 0, 39, '2016'),
	(243, 1, 0, -50945, 2018, 0, 0, 39, '2017'),
	(243, 1, 0, -50945, 2019, 0, 0, 39, '2018'),
	(243, 1, 0, -50945, 2020, 0, 0, 39, '2019'),
	(243, 1, 0, -50945, 2021, 0, 0, 39, '2020'),
	(243, 1, 0, -50945, 2022, 0, 0, 39, '2021'),
	(243, 1, 0, -50945, 2023, 0, 0, 39, '2022'),
	(243, 1, 0, -50945, 2024, 0, 0, 39, '2023'),
	(243, 1, 0, -50945, 2025, 0, 0, 39, '2024'),
	(243, 1, 0, -50945, 2026, 0, 0, 39, '2025'),
	(243, 1, 0, -50945, 2027, 0, 0, 39, '2026'),
	(243, 1, 0, -50945, 2028, 0, 0, 39, '2027'),
	(243, 1, 0, -50945, 2029, 0, 0, 39, '2028'),
	(243, 1, 0, -50945, 2030, 0, 0, 39, '2029'),
	(243, 1, 0, -50945, 2031, 0, 0, 39, '2030'),
	(243, 1, 0, -50945, 2032, 0, 0, 39, '2031'),
	(243, 1, 0, -50945, 2033, 0, 0, 39, '2032'),
	(243, 1, 0, -50945, 2034, 0, 0, 39, '2033'),
	(243, 1, 0, -50945, 2035, 0, 0, 39, '2034'),
	(243, 1, 0, -50945, 2036, 0, 0, 39, '2035'),
	(243, 1, 0, -50945, 2037, 0, 0, 39, '2036'),
	(243, 1, 0, -50945, 2038, 0, 0, 39, '2037'),
	(243, 1, 0, -50945, 2039, 0, 0, 39, '2038'),
	(243, 1, 0, -50945, 2040, 0, 0, 39, '2039'),
	(243, 1, 0, -50945, 2041, 0, 0, 39, '2040'),
	(243, 1, 0, -50945, 2042, 0, 0, 39, '2041'),
	(243, 1, 0, -50945, 2043, 0, 0, 39, '2042'),
	(243, 1, 0, -50945, 2044, 0, 0, 39, '2043'),
	(243, 1, 0, -50945, 2045, 0, 0, 39, '2044'),
	(243, 1, 0, -50945, 2046, 0, 0, 39, '2045'),
	(243, 1, 0, -50945, 2047, 0, 0, 39, '2046'),
	(243, 1, 0, -50945, 2048, 0, 0, 39, '2047'),
	(243, 1, 0, -50944, 1, 0, 0, 39, '0'),
	(243, 1, 0, -50944, 2, 0, 0, 39, '1'),
	(243, 1, 0, -50944, 3, 0, 0, 39, '2'),
	(243, 1, 0, -50944, 4, 0, 0, 39, '3'),
	(243, 1, 0, -50944, 5, 0, 0, 39, '4'),
	(243, 1, 0, -50944, 6, 0, 0, 39, '5'),
	(243, 1, 0, -50944, 7, 0, 0, 39, '6'),
	(243, 1, 0, -50944, 8, 0, 0, 39, '7'),
	(243, 1, 0, -50944, 9, 0, 0, 39, '8'),
	(243, 1, 0, -50944, 10, 0, 0, 39, '9'),
	(243, 1, 0, -50944, 11, 0, 0, 39, '10'),
	(243, 1, 0, -50944, 12, 0, 0, 39, '11'),
	(243, 1, 0, -50944, 13, 0, 0, 39, '12'),
	(243, 1, 0, -50944, 14, 0, 0, 39, '13'),
	(243, 1, 0, -50944, 15, 0, 0, 39, '14'),
	(243, 1, 0, -50944, 16, 0, 0, 39, '15'),
	(243, 1, 0, -50944, 17, 0, 0, 39, '16'),
	(243, 1, 0, -50944, 18, 0, 0, 39, '17'),
	(243, 1, 0, -50944, 19, 0, 0, 39, '18'),
	(243, 1, 0, -50944, 20, 0, 0, 39, '19'),
	(243, 1, 0, -50944, 21, 0, 0, 39, '20'),
	(243, 1, 0, -50944, 22, 0, 0, 39, '21'),
	(243, 1, 0, -50944, 23, 0, 0, 39, '22'),
	(243, 1, 0, -50944, 24, 0, 0, 39, '23'),
	(243, 1, 0, -50944, 25, 0, 0, 39, '24'),
	(243, 1, 0, -50944, 26, 0, 0, 39, '25'),
	(243, 1, 0, -50944, 27, 0, 0, 39, '26'),
	(243, 1, 0, -50944, 28, 0, 0, 39, '27'),
	(243, 1, 0, -50944, 29, 0, 0, 39, '28'),
	(243, 1, 0, -50944, 30, 0, 0, 39, '29'),
	(243, 1, 0, -50944, 31, 0, 0, 39, '30'),
	(243, 1, 0, -50944, 32, 0, 0, 39, '31'),
	(243, 1, 0, -50944, 33, 0, 0, 39, '32'),
	(243, 1, 0, -50944, 34, 0, 0, 39, '33'),
	(243, 1, 0, -50944, 35, 0, 0, 39, '34'),
	(243, 1, 0, -50944, 36, 0, 0, 39, '35'),
	(243, 1, 0, -50944, 37, 0, 0, 39, '36'),
	(243, 1, 0, -50944, 38, 0, 0, 39, '37'),
	(243, 1, 0, -50944, 39, 0, 0, 39, '38'),
	(243, 1, 0, -50944, 40, 0, 0, 39, '39'),
	(243, 1, 0, -50944, 41, 0, 0, 39, '40'),
	(243, 1, 0, -50944, 42, 0, 0, 39, '41'),
	(243, 1, 0, -50944, 43, 0, 0, 39, '42'),
	(243, 1, 0, -50944, 44, 0, 0, 39, '43'),
	(243, 1, 0, -50944, 45, 0, 0, 39, '44'),
	(243, 1, 0, -50944, 46, 0, 0, 39, '45'),
	(243, 1, 0, -50944, 47, 0, 0, 39, '46'),
	(243, 1, 0, -50944, 48, 0, 0, 39, '47'),
	(243, 1, 0, -50944, 49, 0, 0, 39, '48'),
	(243, 1, 0, -50944, 50, 0, 0, 39, '49'),
	(243, 1, 0, -50944, 51, 0, 0, 39, '50'),
	(243, 1, 0, -50944, 52, 0, 0, 39, '51'),
	(243, 1, 0, -50944, 53, 0, 0, 39, '52'),
	(243, 1, 0, -50944, 54, 0, 0, 39, '53'),
	(243, 1, 0, -50944, 55, 0, 0, 39, '54'),
	(243, 1, 0, -50944, 56, 0, 0, 39, '55'),
	(243, 1, 0, -50944, 57, 0, 0, 39, '56'),
	(243, 1, 0, -50944, 58, 0, 0, 39, '57'),
	(243, 1, 0, -50944, 59, 0, 0, 39, '58'),
	(243, 1, 0, -50944, 60, 0, 0, 39, '59'),
	(243, 1, 0, -50944, 61, 0, 0, 39, '60'),
	(243, 1, 0, -50944, 62, 0, 0, 39, '61'),
	(243, 1, 0, -50944, 63, 0, 0, 39, '62'),
	(243, 1, 0, -50944, 64, 0, 0, 39, '63'),
	(243, 1, 0, -50944, 65, 0, 0, 39, '64'),
	(243, 1, 0, -50944, 66, 0, 0, 39, '65'),
	(243, 1, 0, -50944, 67, 0, 0, 39, '66'),
	(243, 1, 0, -50944, 68, 0, 0, 39, '67'),
	(243, 1, 0, -50944, 69, 0, 0, 39, '68'),
	(243, 1, 0, -50944, 70, 0, 0, 39, '69'),
	(243, 1, 0, -50944, 71, 0, 0, 39, '70'),
	(243, 1, 0, -50944, 72, 0, 0, 39, '71'),
	(243, 1, 0, -50944, 73, 0, 0, 39, '72'),
	(243, 1, 0, -50944, 74, 0, 0, 39, '73'),
	(243, 1, 0, -50944, 75, 0, 0, 39, '74'),
	(243, 1, 0, -50944, 76, 0, 0, 39, '75'),
	(243, 1, 0, -50944, 77, 0, 0, 39, '76'),
	(243, 1, 0, -50944, 78, 0, 0, 39, '77'),
	(243, 1, 0, -50944, 79, 0, 0, 39, '78'),
	(243, 1, 0, -50944, 80, 0, 0, 39, '79'),
	(243, 1, 0, -50944, 81, 0, 0, 39, '80'),
	(243, 1, 0, -50944, 82, 0, 0, 39, '81'),
	(243, 1, 0, -50944, 83, 0, 0, 39, '82'),
	(243, 1, 0, -50944, 84, 0, 0, 39, '83'),
	(243, 1, 0, -50944, 85, 0, 0, 39, '84'),
	(243, 1, 0, -50944, 86, 0, 0, 39, '85'),
	(243, 1, 0, -50944, 87, 0, 0, 39, '86'),
	(243, 1, 0, -50944, 88, 0, 0, 39, '87'),
	(243, 1, 0, -50944, 89, 0, 0, 39, '88'),
	(243, 1, 0, -50944, 90, 0, 0, 39, '89'),
	(243, 1, 0, -50944, 91, 0, 0, 39, '90'),
	(243, 1, 0, -50944, 92, 0, 0, 39, '91'),
	(243, 1, 0, -50944, 93, 0, 0, 39, '92'),
	(243, 1, 0, -50944, 94, 0, 0, 39, '93'),
	(243, 1, 0, -50944, 95, 0, 0, 39, '94'),
	(243, 1, 0, -50944, 96, 0, 0, 39, '95'),
	(243, 1, 0, -50944, 97, 0, 0, 39, '96'),
	(243, 1, 0, -50944, 98, 0, 0, 39, '97'),
	(243, 1, 0, -50944, 99, 0, 0, 39, '98'),
	(243, 1, 0, -50944, 100, 0, 0, 39, '99'),
	(243, 1, 0, -50944, 101, 0, 0, 39, '100'),
	(243, 1, 0, -50944, 102, 0, 0, 39, '101'),
	(243, 1, 0, -50944, 103, 0, 0, 39, '102'),
	(243, 1, 0, -50944, 104, 0, 0, 39, '103'),
	(243, 1, 0, -50944, 105, 0, 0, 39, '104'),
	(243, 1, 0, -50944, 106, 0, 0, 39, '105'),
	(243, 1, 0, -50944, 107, 0, 0, 39, '106'),
	(243, 1, 0, -50944, 108, 0, 0, 39, '107'),
	(243, 1, 0, -50944, 109, 0, 0, 39, '108'),
	(243, 1, 0, -50944, 110, 0, 0, 39, '109'),
	(243, 1, 0, -50944, 111, 0, 0, 39, '110'),
	(243, 1, 0, -50944, 112, 0, 0, 39, '111'),
	(243, 1, 0, -50944, 113, 0, 0, 39, '112'),
	(243, 1, 0, -50944, 114, 0, 0, 39, '113'),
	(243, 1, 0, -50944, 115, 0, 0, 39, '114'),
	(243, 1, 0, -50944, 116, 0, 0, 39, '115'),
	(243, 1, 0, -50944, 117, 0, 0, 39, '116'),
	(243, 1, 0, -50944, 118, 0, 0, 39, '117'),
	(243, 1, 0, -50944, 119, 0, 0, 39, '118'),
	(243, 1, 0, -50944, 120, 0, 0, 39, '119'),
	(243, 1, 0, -50944, 121, 0, 0, 39, '120'),
	(243, 1, 0, -50944, 122, 0, 0, 39, '121'),
	(243, 1, 0, -50944, 123, 0, 0, 39, '122'),
	(243, 1, 0, -50944, 124, 0, 0, 39, '123'),
	(243, 1, 0, -50944, 125, 0, 0, 39, '124'),
	(243, 1, 0, -50944, 126, 0, 0, 39, '125'),
	(243, 1, 0, -50944, 127, 0, 0, 39, '126'),
	(243, 1, 0, -50944, 128, 0, 0, 39, '127'),
	(243, 1, 0, -50944, 129, 0, 0, 39, '128'),
	(243, 1, 0, -50944, 130, 0, 0, 39, '129'),
	(243, 1, 0, -50944, 131, 0, 0, 39, '130'),
	(243, 1, 0, -50944, 132, 0, 0, 39, '131'),
	(243, 1, 0, -50944, 133, 0, 0, 39, '132'),
	(243, 1, 0, -50944, 134, 0, 0, 39, '133'),
	(243, 1, 0, -50944, 135, 0, 0, 39, '134'),
	(243, 1, 0, -50944, 136, 0, 0, 39, '135'),
	(243, 1, 0, -50944, 137, 0, 0, 39, '136'),
	(243, 1, 0, -50944, 138, 0, 0, 39, '137'),
	(243, 1, 0, -50944, 139, 0, 0, 39, '138'),
	(243, 1, 0, -50944, 140, 0, 0, 39, '139'),
	(243, 1, 0, -50944, 141, 0, 0, 39, '140'),
	(243, 1, 0, -50944, 142, 0, 0, 39, '141'),
	(243, 1, 0, -50944, 143, 0, 0, 39, '142'),
	(243, 1, 0, -50944, 144, 0, 0, 39, '143'),
	(243, 1, 0, -50944, 145, 0, 0, 39, '144'),
	(243, 1, 0, -50944, 146, 0, 0, 39, '145'),
	(243, 1, 0, -50944, 147, 0, 0, 39, '146'),
	(243, 1, 0, -50944, 148, 0, 0, 39, '147'),
	(243, 1, 0, -50944, 149, 0, 0, 39, '148'),
	(243, 1, 0, -50944, 150, 0, 0, 39, '149'),
	(243, 1, 0, -50944, 151, 0, 0, 39, '150'),
	(243, 1, 0, -50944, 152, 0, 0, 39, '151'),
	(243, 1, 0, -50944, 153, 0, 0, 39, '152'),
	(243, 1, 0, -50944, 154, 0, 0, 39, '153'),
	(243, 1, 0, -50944, 155, 0, 0, 39, '154'),
	(243, 1, 0, -50944, 156, 0, 0, 39, '155'),
	(243, 1, 0, -50944, 157, 0, 0, 39, '156'),
	(243, 1, 0, -50944, 158, 0, 0, 39, '157'),
	(243, 1, 0, -50944, 159, 0, 0, 39, '158'),
	(243, 1, 0, -50944, 160, 0, 0, 39, '159'),
	(243, 1, 0, -50944, 161, 0, 0, 39, '160'),
	(243, 1, 0, -50944, 162, 0, 0, 39, '161'),
	(243, 1, 0, -50944, 163, 0, 0, 39, '162'),
	(243, 1, 0, -50944, 164, 0, 0, 39, '163'),
	(243, 1, 0, -50944, 165, 0, 0, 39, '164'),
	(243, 1, 0, -50944, 166, 0, 0, 39, '165'),
	(243, 1, 0, -50944, 167, 0, 0, 39, '166'),
	(243, 1, 0, -50944, 168, 0, 0, 39, '167'),
	(243, 1, 0, -50944, 169, 0, 0, 39, '168'),
	(243, 1, 0, -50944, 170, 0, 0, 39, '169'),
	(243, 1, 0, -50944, 171, 0, 0, 39, '170'),
	(243, 1, 0, -50944, 172, 0, 0, 39, '171'),
	(243, 1, 0, -50944, 173, 0, 0, 39, '172'),
	(243, 1, 0, -50944, 174, 0, 0, 39, '173'),
	(243, 1, 0, -50944, 175, 0, 0, 39, '174'),
	(243, 1, 0, -50944, 176, 0, 0, 39, '175'),
	(243, 1, 0, -50944, 177, 0, 0, 39, '176'),
	(243, 1, 0, -50944, 178, 0, 0, 39, '177'),
	(243, 1, 0, -50944, 179, 0, 0, 39, '178'),
	(243, 1, 0, -50944, 180, 0, 0, 39, '179'),
	(243, 1, 0, -50944, 181, 0, 0, 39, '180'),
	(243, 1, 0, -50944, 182, 0, 0, 39, '181'),
	(243, 1, 0, -50944, 183, 0, 0, 39, '182'),
	(243, 1, 0, -50944, 184, 0, 0, 39, '183'),
	(243, 1, 0, -50944, 185, 0, 0, 39, '184'),
	(243, 1, 0, -50944, 186, 0, 0, 39, '185'),
	(243, 1, 0, -50944, 187, 0, 0, 39, '186'),
	(243, 1, 0, -50944, 188, 0, 0, 39, '187'),
	(243, 1, 0, -50944, 189, 0, 0, 39, '188'),
	(243, 1, 0, -50944, 190, 0, 0, 39, '189'),
	(243, 1, 0, -50944, 191, 0, 0, 39, '190'),
	(243, 1, 0, -50944, 192, 0, 0, 39, '191'),
	(243, 1, 0, -50944, 193, 0, 0, 39, '192'),
	(243, 1, 0, -50944, 194, 0, 0, 39, '193'),
	(243, 1, 0, -50944, 195, 0, 0, 39, '194'),
	(243, 1, 0, -50944, 196, 0, 0, 39, '195'),
	(243, 1, 0, -50944, 197, 0, 0, 39, '196'),
	(243, 1, 0, -50944, 198, 0, 0, 39, '197'),
	(243, 1, 0, -50944, 199, 0, 0, 39, '198'),
	(243, 1, 0, -50944, 200, 0, 0, 39, '199'),
	(243, 1, 0, -50944, 201, 0, 0, 39, '200'),
	(243, 1, 0, -50944, 202, 0, 0, 39, '201'),
	(243, 1, 0, -50944, 203, 0, 0, 39, '202'),
	(243, 1, 0, -50944, 204, 0, 0, 39, '203'),
	(243, 1, 0, -50944, 205, 0, 0, 39, '204'),
	(243, 1, 0, -50944, 206, 0, 0, 39, '205'),
	(243, 1, 0, -50944, 207, 0, 0, 39, '206'),
	(243, 1, 0, -50944, 208, 0, 0, 39, '207'),
	(243, 1, 0, -50944, 209, 0, 0, 39, '208'),
	(243, 1, 0, -50944, 210, 0, 0, 39, '209'),
	(243, 1, 0, -50944, 211, 0, 0, 39, '210'),
	(243, 1, 0, -50944, 212, 0, 0, 39, '211'),
	(243, 1, 0, -50944, 213, 0, 0, 39, '212'),
	(243, 1, 0, -50944, 214, 0, 0, 39, '213'),
	(243, 1, 0, -50944, 215, 0, 0, 39, '214'),
	(243, 1, 0, -50944, 216, 0, 0, 39, '215'),
	(243, 1, 0, -50944, 217, 0, 0, 39, '216'),
	(243, 1, 0, -50944, 218, 0, 0, 39, '217'),
	(243, 1, 0, -50944, 219, 0, 0, 39, '218'),
	(243, 1, 0, -50944, 220, 0, 0, 39, '219'),
	(243, 1, 0, -50944, 221, 0, 0, 39, '220'),
	(243, 1, 0, -50944, 222, 0, 0, 39, '221'),
	(243, 1, 0, -50944, 223, 0, 0, 39, '222'),
	(243, 1, 0, -50944, 224, 0, 0, 39, '223'),
	(243, 1, 0, -50944, 225, 0, 0, 39, '224'),
	(243, 1, 0, -50944, 226, 0, 0, 39, '225'),
	(243, 1, 0, -50944, 227, 0, 0, 39, '226'),
	(243, 1, 0, -50944, 228, 0, 0, 39, '227'),
	(243, 1, 0, -50944, 229, 0, 0, 39, '228'),
	(243, 1, 0, -50944, 230, 0, 0, 39, '229'),
	(243, 1, 0, -50944, 231, 0, 0, 39, '230'),
	(243, 1, 0, -50944, 232, 0, 0, 39, '231'),
	(243, 1, 0, -50944, 233, 0, 0, 39, '232'),
	(243, 1, 0, -50944, 234, 0, 0, 39, '233'),
	(243, 1, 0, -50944, 235, 0, 0, 39, '234'),
	(243, 1, 0, -50944, 236, 0, 0, 39, '235'),
	(243, 1, 0, -50944, 237, 0, 0, 39, '236'),
	(243, 1, 0, -50944, 238, 0, 0, 39, '237'),
	(243, 1, 0, -50944, 239, 0, 0, 39, '238'),
	(243, 1, 0, -50944, 240, 0, 0, 39, '239'),
	(243, 1, 0, -50944, 241, 0, 0, 39, '240'),
	(243, 1, 0, -50944, 242, 0, 0, 39, '241'),
	(243, 1, 0, -50944, 243, 0, 0, 39, '242'),
	(243, 1, 0, -50944, 244, 0, 0, 39, '243'),
	(243, 1, 0, -50944, 245, 0, 0, 39, '244'),
	(243, 1, 0, -50944, 246, 0, 0, 39, '245'),
	(243, 1, 0, -50944, 247, 0, 0, 39, '246'),
	(243, 1, 0, -50944, 248, 0, 0, 39, '247'),
	(243, 1, 0, -50944, 249, 0, 0, 39, '248'),
	(243, 1, 0, -50944, 250, 0, 0, 39, '249'),
	(243, 1, 0, -50944, 251, 0, 0, 39, '250'),
	(243, 1, 0, -50944, 252, 0, 0, 39, '251'),
	(243, 1, 0, -50944, 253, 0, 0, 39, '252'),
	(243, 1, 0, -50944, 254, 0, 0, 39, '253'),
	(243, 1, 0, -50944, 255, 0, 0, 39, '254'),
	(243, 1, 0, -50944, 256, 0, 0, 39, '255'),
	(243, 1, 0, -50944, 257, 0, 0, 39, '256'),
	(243, 1, 0, -50944, 258, 0, 0, 39, '257'),
	(243, 1, 0, -50944, 259, 0, 0, 39, '258'),
	(243, 1, 0, -50944, 260, 0, 0, 39, '259'),
	(243, 1, 0, -50944, 261, 0, 0, 39, '260'),
	(243, 1, 0, -50944, 262, 0, 0, 39, '261'),
	(243, 1, 0, -50944, 263, 0, 0, 39, '262'),
	(243, 1, 0, -50944, 264, 0, 0, 39, '263'),
	(243, 1, 0, -50944, 265, 0, 0, 39, '264'),
	(243, 1, 0, -50944, 266, 0, 0, 39, '265'),
	(243, 1, 0, -50944, 267, 0, 0, 39, '266'),
	(243, 1, 0, -50944, 268, 0, 0, 39, '267'),
	(243, 1, 0, -50944, 269, 0, 0, 39, '268'),
	(243, 1, 0, -50944, 270, 0, 0, 39, '269'),
	(243, 1, 0, -50944, 271, 0, 0, 39, '270'),
	(243, 1, 0, -50944, 272, 0, 0, 39, '271'),
	(243, 1, 0, -50944, 273, 0, 0, 39, '272'),
	(243, 1, 0, -50944, 274, 0, 0, 39, '273'),
	(243, 1, 0, -50944, 275, 0, 0, 39, '274'),
	(243, 1, 0, -50944, 276, 0, 0, 39, '275'),
	(243, 1, 0, -50944, 277, 0, 0, 39, '276'),
	(243, 1, 0, -50944, 278, 0, 0, 39, '277'),
	(243, 1, 0, -50944, 279, 0, 0, 39, '278'),
	(243, 1, 0, -50944, 280, 0, 0, 39, '279'),
	(243, 1, 0, -50944, 281, 0, 0, 39, '280'),
	(243, 1, 0, -50944, 282, 0, 0, 39, '281'),
	(243, 1, 0, -50944, 283, 0, 0, 39, '282'),
	(243, 1, 0, -50944, 284, 0, 0, 39, '283'),
	(243, 1, 0, -50944, 285, 0, 0, 39, '284'),
	(243, 1, 0, -50944, 286, 0, 0, 39, '285'),
	(243, 1, 0, -50944, 287, 0, 0, 39, '286'),
	(243, 1, 0, -50944, 288, 0, 0, 39, '287'),
	(243, 1, 0, -50944, 289, 0, 0, 39, '288'),
	(243, 1, 0, -50944, 290, 0, 0, 39, '289'),
	(243, 1, 0, -50944, 291, 0, 0, 39, '290'),
	(243, 1, 0, -50944, 292, 0, 0, 39, '291'),
	(243, 1, 0, -50944, 293, 0, 0, 39, '292'),
	(243, 1, 0, -50944, 294, 0, 0, 39, '293'),
	(243, 1, 0, -50944, 295, 0, 0, 39, '294'),
	(243, 1, 0, -50944, 296, 0, 0, 39, '295'),
	(243, 1, 0, -50944, 297, 0, 0, 39, '296'),
	(243, 1, 0, -50944, 298, 0, 0, 39, '297'),
	(243, 1, 0, -50944, 299, 0, 0, 39, '298'),
	(243, 1, 0, -50944, 300, 0, 0, 39, '299'),
	(243, 1, 0, -50944, 301, 0, 0, 39, '300'),
	(243, 1, 0, -50944, 302, 0, 0, 39, '301'),
	(243, 1, 0, -50944, 303, 0, 0, 39, '302'),
	(243, 1, 0, -50944, 304, 0, 0, 39, '303'),
	(243, 1, 0, -50944, 305, 0, 0, 39, '304'),
	(243, 1, 0, -50944, 306, 0, 0, 39, '305'),
	(243, 1, 0, -50944, 307, 0, 0, 39, '306'),
	(243, 1, 0, -50944, 308, 0, 0, 39, '307'),
	(243, 1, 0, -50944, 309, 0, 0, 39, '308'),
	(243, 1, 0, -50944, 310, 0, 0, 39, '309'),
	(243, 1, 0, -50944, 311, 0, 0, 39, '310'),
	(243, 1, 0, -50944, 312, 0, 0, 39, '311'),
	(243, 1, 0, -50944, 313, 0, 0, 39, '312'),
	(243, 1, 0, -50944, 314, 0, 0, 39, '313'),
	(243, 1, 0, -50944, 315, 0, 0, 39, '314'),
	(243, 1, 0, -50944, 316, 0, 0, 39, '315'),
	(243, 1, 0, -50944, 317, 0, 0, 39, '316'),
	(243, 1, 0, -50944, 318, 0, 0, 39, '317'),
	(243, 1, 0, -50944, 319, 0, 0, 39, '318'),
	(243, 1, 0, -50944, 320, 0, 0, 39, '319'),
	(243, 1, 0, -50944, 321, 0, 0, 39, '320'),
	(243, 1, 0, -50944, 322, 0, 0, 39, '321'),
	(243, 1, 0, -50944, 323, 0, 0, 39, '322'),
	(243, 1, 0, -50944, 324, 0, 0, 39, '323'),
	(243, 1, 0, -50944, 325, 0, 0, 39, '324'),
	(243, 1, 0, -50944, 326, 0, 0, 39, '325'),
	(243, 1, 0, -50944, 327, 0, 0, 39, '326'),
	(243, 1, 0, -50944, 328, 0, 0, 39, '327'),
	(243, 1, 0, -50944, 329, 0, 0, 39, '328'),
	(243, 1, 0, -50944, 330, 0, 0, 39, '329'),
	(243, 1, 0, -50944, 331, 0, 0, 39, '330'),
	(243, 1, 0, -50944, 332, 0, 0, 39, '331'),
	(243, 1, 0, -50944, 333, 0, 0, 39, '332'),
	(243, 1, 0, -50944, 334, 0, 0, 39, '333'),
	(243, 1, 0, -50944, 335, 0, 0, 39, '334'),
	(243, 1, 0, -50944, 336, 0, 0, 39, '335'),
	(243, 1, 0, -50944, 337, 0, 0, 39, '336'),
	(243, 1, 0, -50944, 338, 0, 0, 39, '337'),
	(243, 1, 0, -50944, 339, 0, 0, 39, '338'),
	(243, 1, 0, -50944, 340, 0, 0, 39, '339'),
	(243, 1, 0, -50944, 341, 0, 0, 39, '340'),
	(243, 1, 0, -50944, 342, 0, 0, 39, '341'),
	(243, 1, 0, -50944, 343, 0, 0, 39, '342'),
	(243, 1, 0, -50944, 344, 0, 0, 39, '343'),
	(243, 1, 0, -50944, 345, 0, 0, 39, '344'),
	(243, 1, 0, -50944, 346, 0, 0, 39, '345'),
	(243, 1, 0, -50944, 347, 0, 0, 39, '346'),
	(243, 1, 0, -50944, 348, 0, 0, 39, '347'),
	(243, 1, 0, -50944, 349, 0, 0, 39, '348'),
	(243, 1, 0, -50944, 350, 0, 0, 39, '349'),
	(243, 1, 0, -50944, 351, 0, 0, 39, '350'),
	(243, 1, 0, -50944, 352, 0, 0, 39, '351'),
	(243, 1, 0, -50944, 353, 0, 0, 39, '352'),
	(243, 1, 0, -50944, 354, 0, 0, 39, '353'),
	(243, 1, 0, -50944, 355, 0, 0, 39, '354'),
	(243, 1, 0, -50944, 356, 0, 0, 39, '355'),
	(243, 1, 0, -50944, 357, 0, 0, 39, '356'),
	(243, 1, 0, -50944, 358, 0, 0, 39, '357'),
	(243, 1, 0, -50944, 359, 0, 0, 39, '358'),
	(243, 1, 0, -50944, 360, 0, 0, 39, '359'),
	(243, 1, 0, -50944, 361, 0, 0, 39, '360'),
	(243, 1, 0, -50944, 362, 0, 0, 39, '361'),
	(243, 1, 0, -50944, 363, 0, 0, 39, '362'),
	(243, 1, 0, -50944, 364, 0, 0, 39, '363'),
	(243, 1, 0, -50944, 365, 0, 0, 39, '364'),
	(243, 1, 0, -50944, 366, 0, 0, 39, '365'),
	(243, 1, 0, -50944, 367, 0, 0, 39, '366'),
	(243, 1, 0, -50944, 368, 0, 0, 39, '367'),
	(243, 1, 0, -50944, 369, 0, 0, 39, '368'),
	(243, 1, 0, -50944, 370, 0, 0, 39, '369'),
	(243, 1, 0, -50944, 371, 0, 0, 39, '370'),
	(243, 1, 0, -50944, 372, 0, 0, 39, '371'),
	(243, 1, 0, -50944, 373, 0, 0, 39, '372'),
	(243, 1, 0, -50944, 374, 0, 0, 39, '373'),
	(243, 1, 0, -50944, 375, 0, 0, 39, '374'),
	(243, 1, 0, -50944, 376, 0, 0, 39, '375'),
	(243, 1, 0, -50944, 377, 0, 0, 39, '376'),
	(243, 1, 0, -50944, 378, 0, 0, 39, '377'),
	(243, 1, 0, -50944, 379, 0, 0, 39, '378'),
	(243, 1, 0, -50944, 380, 0, 0, 39, '379'),
	(243, 1, 0, -50944, 381, 0, 0, 39, '380'),
	(243, 1, 0, -50944, 382, 0, 0, 39, '381'),
	(243, 1, 0, -50944, 383, 0, 0, 39, '382'),
	(243, 1, 0, -50944, 384, 0, 0, 39, '383'),
	(243, 1, 0, -50944, 385, 0, 0, 39, '384'),
	(243, 1, 0, -50944, 386, 0, 0, 39, '385'),
	(243, 1, 0, -50944, 387, 0, 0, 39, '386'),
	(243, 1, 0, -50944, 388, 0, 0, 39, '387'),
	(243, 1, 0, -50944, 389, 0, 0, 39, '388'),
	(243, 1, 0, -50944, 390, 0, 0, 39, '389'),
	(243, 1, 0, -50944, 391, 0, 0, 39, '390'),
	(243, 1, 0, -50944, 392, 0, 0, 39, '391'),
	(243, 1, 0, -50944, 393, 0, 0, 39, '392'),
	(243, 1, 0, -50944, 394, 0, 0, 39, '393'),
	(243, 1, 0, -50944, 395, 0, 0, 39, '394'),
	(243, 1, 0, -50944, 396, 0, 0, 39, '395'),
	(243, 1, 0, -50944, 397, 0, 0, 39, '396'),
	(243, 1, 0, -50944, 398, 0, 0, 39, '397'),
	(243, 1, 0, -50944, 399, 0, 0, 39, '398'),
	(243, 1, 0, -50944, 400, 0, 0, 39, '399'),
	(243, 1, 0, -50944, 401, 0, 0, 39, '400'),
	(243, 1, 0, -50944, 402, 0, 0, 39, '401'),
	(243, 1, 0, -50944, 403, 0, 0, 39, '402'),
	(243, 1, 0, -50944, 404, 0, 0, 39, '403'),
	(243, 1, 0, -50944, 405, 0, 0, 39, '404'),
	(243, 1, 0, -50944, 406, 0, 0, 39, '405'),
	(243, 1, 0, -50944, 407, 0, 0, 39, '406'),
	(243, 1, 0, -50944, 408, 0, 0, 39, '407'),
	(243, 1, 0, -50944, 409, 0, 0, 39, '408'),
	(243, 1, 0, -50944, 410, 0, 0, 39, '409'),
	(243, 1, 0, -50944, 411, 0, 0, 39, '410'),
	(243, 1, 0, -50944, 412, 0, 0, 39, '411'),
	(243, 1, 0, -50944, 413, 0, 0, 39, '412'),
	(243, 1, 0, -50944, 414, 0, 0, 39, '413'),
	(243, 1, 0, -50944, 415, 0, 0, 39, '414'),
	(243, 1, 0, -50944, 416, 0, 0, 39, '415'),
	(243, 1, 0, -50944, 417, 0, 0, 39, '416'),
	(243, 1, 0, -50944, 418, 0, 0, 39, '417'),
	(243, 1, 0, -50944, 419, 0, 0, 39, '418'),
	(243, 1, 0, -50944, 420, 0, 0, 39, '419'),
	(243, 1, 0, -50944, 421, 0, 0, 39, '420'),
	(243, 1, 0, -50944, 422, 0, 0, 39, '421'),
	(243, 1, 0, -50944, 423, 0, 0, 39, '422'),
	(243, 1, 0, -50944, 424, 0, 0, 39, '423'),
	(243, 1, 0, -50944, 425, 0, 0, 39, '424'),
	(243, 1, 0, -50944, 426, 0, 0, 39, '425'),
	(243, 1, 0, -50944, 427, 0, 0, 39, '426'),
	(243, 1, 0, -50944, 428, 0, 0, 39, '427'),
	(243, 1, 0, -50944, 429, 0, 0, 39, '428'),
	(243, 1, 0, -50944, 430, 0, 0, 39, '429'),
	(243, 1, 0, -50944, 431, 0, 0, 39, '430'),
	(243, 1, 0, -50944, 432, 0, 0, 39, '431'),
	(243, 1, 0, -50944, 433, 0, 0, 39, '432'),
	(243, 1, 0, -50944, 434, 0, 0, 39, '433'),
	(243, 1, 0, -50944, 435, 0, 0, 39, '434'),
	(243, 1, 0, -50944, 436, 0, 0, 39, '435'),
	(243, 1, 0, -50944, 437, 0, 0, 39, '436'),
	(243, 1, 0, -50944, 438, 0, 0, 39, '437'),
	(243, 1, 0, -50944, 439, 0, 0, 39, '438'),
	(243, 1, 0, -50944, 440, 0, 0, 39, '439'),
	(243, 1, 0, -50944, 441, 0, 0, 39, '440'),
	(243, 1, 0, -50944, 442, 0, 0, 39, '441'),
	(243, 1, 0, -50944, 443, 0, 0, 39, '442'),
	(243, 1, 0, -50944, 444, 0, 0, 39, '443'),
	(243, 1, 0, -50944, 445, 0, 0, 39, '444'),
	(243, 1, 0, -50944, 446, 0, 0, 39, '445'),
	(243, 1, 0, -50944, 447, 0, 0, 39, '446'),
	(243, 1, 0, -50944, 448, 0, 0, 39, '447'),
	(243, 1, 0, -50944, 449, 0, 0, 39, '448'),
	(243, 1, 0, -50944, 450, 0, 0, 39, '449'),
	(243, 1, 0, -50944, 451, 0, 0, 39, '450'),
	(243, 1, 0, -50944, 452, 0, 0, 39, '451'),
	(243, 1, 0, -50944, 453, 0, 0, 39, '452'),
	(243, 1, 0, -50944, 454, 0, 0, 39, '453'),
	(243, 1, 0, -50944, 455, 0, 0, 39, '454'),
	(243, 1, 0, -50944, 456, 0, 0, 39, '455'),
	(243, 1, 0, -50944, 457, 0, 0, 39, '456'),
	(243, 1, 0, -50944, 458, 0, 0, 39, '457'),
	(243, 1, 0, -50944, 459, 0, 0, 39, '458'),
	(243, 1, 0, -50944, 460, 0, 0, 39, '459'),
	(243, 1, 0, -50944, 461, 0, 0, 39, '460'),
	(243, 1, 0, -50944, 462, 0, 0, 39, '461'),
	(243, 1, 0, -50944, 463, 0, 0, 39, '462'),
	(243, 1, 0, -50944, 464, 0, 0, 39, '463'),
	(243, 1, 0, -50944, 465, 0, 0, 39, '464'),
	(243, 1, 0, -50944, 466, 0, 0, 39, '465'),
	(243, 1, 0, -50944, 467, 0, 0, 39, '466'),
	(243, 1, 0, -50944, 468, 0, 0, 39, '467'),
	(243, 1, 0, -50944, 469, 0, 0, 39, '468'),
	(243, 1, 0, -50944, 470, 0, 0, 39, '469'),
	(243, 1, 0, -50944, 471, 0, 0, 39, '470'),
	(243, 1, 0, -50944, 472, 0, 0, 39, '471'),
	(243, 1, 0, -50944, 473, 0, 0, 39, '472'),
	(243, 1, 0, -50944, 474, 0, 0, 39, '473'),
	(243, 1, 0, -50944, 475, 0, 0, 39, '474'),
	(243, 1, 0, -50944, 476, 0, 0, 39, '475'),
	(243, 1, 0, -50944, 477, 0, 0, 39, '476'),
	(243, 1, 0, -50944, 478, 0, 0, 39, '477'),
	(243, 1, 0, -50944, 479, 0, 0, 39, '478'),
	(243, 1, 0, -50944, 480, 0, 0, 39, '479'),
	(243, 1, 0, -50944, 481, 0, 0, 39, '480'),
	(243, 1, 0, -50944, 482, 0, 0, 39, '481'),
	(243, 1, 0, -50944, 483, 0, 0, 39, '482'),
	(243, 1, 0, -50944, 484, 0, 0, 39, '483'),
	(243, 1, 0, -50944, 485, 0, 0, 39, '484'),
	(243, 1, 0, -50944, 486, 0, 0, 39, '485'),
	(243, 1, 0, -50944, 487, 0, 0, 39, '486'),
	(243, 1, 0, -50944, 488, 0, 0, 39, '487'),
	(243, 1, 0, -50944, 489, 0, 0, 39, '488'),
	(243, 1, 0, -50944, 490, 0, 0, 39, '489'),
	(243, 1, 0, -50944, 491, 0, 0, 39, '490'),
	(243, 1, 0, -50944, 492, 0, 0, 39, '491'),
	(243, 1, 0, -50944, 493, 0, 0, 39, '492'),
	(243, 1, 0, -50944, 494, 0, 0, 39, '493'),
	(243, 1, 0, -50944, 495, 0, 0, 39, '494'),
	(243, 1, 0, -50944, 496, 0, 0, 39, '495'),
	(243, 1, 0, -50944, 497, 0, 0, 39, '496'),
	(243, 1, 0, -50944, 498, 0, 0, 39, '497'),
	(243, 1, 0, -50944, 499, 0, 0, 39, '498'),
	(243, 1, 0, -50944, 500, 0, 0, 39, '499'),
	(243, 1, 0, -50944, 501, 0, 0, 39, '500'),
	(243, 1, 0, -50944, 502, 0, 0, 39, '501'),
	(243, 1, 0, -50944, 503, 0, 0, 39, '502'),
	(243, 1, 0, -50944, 504, 0, 0, 39, '503'),
	(243, 1, 0, -50944, 505, 0, 0, 39, '504'),
	(243, 1, 0, -50944, 506, 0, 0, 39, '505'),
	(243, 1, 0, -50944, 507, 0, 0, 39, '506'),
	(243, 1, 0, -50944, 508, 0, 0, 39, '507'),
	(243, 1, 0, -50944, 509, 0, 0, 39, '508'),
	(243, 1, 0, -50944, 510, 0, 0, 39, '509'),
	(243, 1, 0, -50944, 511, 0, 0, 39, '510'),
	(243, 1, 0, -50944, 512, 0, 0, 39, '511'),
	(243, 1, 0, -50944, 513, 0, 0, 39, '512'),
	(243, 1, 0, -50944, 514, 0, 0, 39, '513'),
	(243, 1, 0, -50944, 515, 0, 0, 39, '514'),
	(243, 1, 0, -50944, 516, 0, 0, 39, '515'),
	(243, 1, 0, -50944, 517, 0, 0, 39, '516'),
	(243, 1, 0, -50944, 518, 0, 0, 39, '517'),
	(243, 1, 0, -50944, 519, 0, 0, 39, '518'),
	(243, 1, 0, -50944, 520, 0, 0, 39, '519'),
	(243, 1, 0, -50944, 521, 0, 0, 39, '520'),
	(243, 1, 0, -50944, 522, 0, 0, 39, '521'),
	(243, 1, 0, -50944, 523, 0, 0, 39, '522'),
	(243, 1, 0, -50944, 524, 0, 0, 39, '523'),
	(243, 1, 0, -50944, 525, 0, 0, 39, '524'),
	(243, 1, 0, -50944, 526, 0, 0, 39, '525'),
	(243, 1, 0, -50944, 527, 0, 0, 39, '526'),
	(243, 1, 0, -50944, 528, 0, 0, 39, '527'),
	(243, 1, 0, -50944, 529, 0, 0, 39, '528'),
	(243, 1, 0, -50944, 530, 0, 0, 39, '529'),
	(243, 1, 0, -50944, 531, 0, 0, 39, '530'),
	(243, 1, 0, -50944, 532, 0, 0, 39, '531'),
	(243, 1, 0, -50944, 533, 0, 0, 39, '532'),
	(243, 1, 0, -50944, 534, 0, 0, 39, '533'),
	(243, 1, 0, -50944, 535, 0, 0, 39, '534'),
	(243, 1, 0, -50944, 536, 0, 0, 39, '535'),
	(243, 1, 0, -50944, 537, 0, 0, 39, '536'),
	(243, 1, 0, -50944, 538, 0, 0, 39, '537'),
	(243, 1, 0, -50944, 539, 0, 0, 39, '538'),
	(243, 1, 0, -50944, 540, 0, 0, 39, '539'),
	(243, 1, 0, -50944, 541, 0, 0, 39, '540'),
	(243, 1, 0, -50944, 542, 0, 0, 39, '541'),
	(243, 1, 0, -50944, 543, 0, 0, 39, '542'),
	(243, 1, 0, -50944, 544, 0, 0, 39, '543'),
	(243, 1, 0, -50944, 545, 0, 0, 39, '544'),
	(243, 1, 0, -50944, 546, 0, 0, 39, '545'),
	(243, 1, 0, -50944, 547, 0, 0, 39, '546'),
	(243, 1, 0, -50944, 548, 0, 0, 39, '547'),
	(243, 1, 0, -50944, 549, 0, 0, 39, '548'),
	(243, 1, 0, -50944, 550, 0, 0, 39, '549'),
	(243, 1, 0, -50944, 551, 0, 0, 39, '550'),
	(243, 1, 0, -50944, 552, 0, 0, 39, '551'),
	(243, 1, 0, -50944, 553, 0, 0, 39, '552'),
	(243, 1, 0, -50944, 554, 0, 0, 39, '553'),
	(243, 1, 0, -50944, 555, 0, 0, 39, '554'),
	(243, 1, 0, -50944, 556, 0, 0, 39, '555'),
	(243, 1, 0, -50944, 557, 0, 0, 39, '556'),
	(243, 1, 0, -50944, 558, 0, 0, 39, '557'),
	(243, 1, 0, -50944, 559, 0, 0, 39, '558'),
	(243, 1, 0, -50944, 560, 0, 0, 39, '559'),
	(243, 1, 0, -50944, 561, 0, 0, 39, '560'),
	(243, 1, 0, -50944, 562, 0, 0, 39, '561'),
	(243, 1, 0, -50944, 563, 0, 0, 39, '562'),
	(243, 1, 0, -50944, 564, 0, 0, 39, '563'),
	(243, 1, 0, -50944, 565, 0, 0, 39, '564'),
	(243, 1, 0, -50944, 566, 0, 0, 39, '565'),
	(243, 1, 0, -50944, 567, 0, 0, 39, '566'),
	(243, 1, 0, -50944, 568, 0, 0, 39, '567'),
	(243, 1, 0, -50944, 569, 0, 0, 39, '568'),
	(243, 1, 0, -50944, 570, 0, 0, 39, '569'),
	(243, 1, 0, -50944, 571, 0, 0, 39, '570'),
	(243, 1, 0, -50944, 572, 0, 0, 39, '571'),
	(243, 1, 0, -50944, 573, 0, 0, 39, '572'),
	(243, 1, 0, -50944, 574, 0, 0, 39, '573'),
	(243, 1, 0, -50944, 575, 0, 0, 39, '574'),
	(243, 1, 0, -50944, 576, 0, 0, 39, '575'),
	(243, 1, 0, -50944, 577, 0, 0, 39, '576'),
	(243, 1, 0, -50944, 578, 0, 0, 39, '577'),
	(243, 1, 0, -50944, 579, 0, 0, 39, '578'),
	(243, 1, 0, -50944, 580, 0, 0, 39, '579'),
	(243, 1, 0, -50944, 581, 0, 0, 39, '580'),
	(243, 1, 0, -50944, 582, 0, 0, 39, '581'),
	(243, 1, 0, -50944, 583, 0, 0, 39, '582'),
	(243, 1, 0, -50944, 584, 0, 0, 39, '583'),
	(243, 1, 0, -50944, 585, 0, 0, 39, '584'),
	(243, 1, 0, -50944, 586, 0, 0, 39, '585'),
	(243, 1, 0, -50944, 587, 0, 0, 39, '586'),
	(243, 1, 0, -50944, 588, 0, 0, 39, '587'),
	(243, 1, 0, -50944, 589, 0, 0, 39, '588'),
	(243, 1, 0, -50944, 590, 0, 0, 39, '589'),
	(243, 1, 0, -50944, 591, 0, 0, 39, '590'),
	(243, 1, 0, -50944, 592, 0, 0, 39, '591'),
	(243, 1, 0, -50944, 593, 0, 0, 39, '592'),
	(243, 1, 0, -50944, 594, 0, 0, 39, '593'),
	(243, 1, 0, -50944, 595, 0, 0, 39, '594'),
	(243, 1, 0, -50944, 596, 0, 0, 39, '595'),
	(243, 1, 0, -50944, 597, 0, 0, 39, '596'),
	(243, 1, 0, -50944, 598, 0, 0, 39, '597'),
	(243, 1, 0, -50944, 599, 0, 0, 39, '598'),
	(243, 1, 0, -50944, 600, 0, 0, 39, '599'),
	(243, 1, 0, -50944, 601, 0, 0, 39, '600'),
	(243, 1, 0, -50944, 602, 0, 0, 39, '601'),
	(243, 1, 0, -50944, 603, 0, 0, 39, '602'),
	(243, 1, 0, -50944, 604, 0, 0, 39, '603'),
	(243, 1, 0, -50944, 605, 0, 0, 39, '604'),
	(243, 1, 0, -50944, 606, 0, 0, 39, '605'),
	(243, 1, 0, -50944, 607, 0, 0, 39, '606'),
	(243, 1, 0, -50944, 608, 0, 0, 39, '607'),
	(243, 1, 0, -50944, 609, 0, 0, 39, '608'),
	(243, 1, 0, -50944, 610, 0, 0, 39, '609'),
	(243, 1, 0, -50944, 611, 0, 0, 39, '610'),
	(243, 1, 0, -50944, 612, 0, 0, 39, '611'),
	(243, 1, 0, -50944, 613, 0, 0, 39, '612'),
	(243, 1, 0, -50944, 614, 0, 0, 39, '613'),
	(243, 1, 0, -50944, 615, 0, 0, 39, '614'),
	(243, 1, 0, -50944, 616, 0, 0, 39, '615'),
	(243, 1, 0, -50944, 617, 0, 0, 39, '616'),
	(243, 1, 0, -50944, 618, 0, 0, 39, '617'),
	(243, 1, 0, -50944, 619, 0, 0, 39, '618'),
	(243, 1, 0, -50944, 620, 0, 0, 39, '619'),
	(243, 1, 0, -50944, 621, 0, 0, 39, '620'),
	(243, 1, 0, -50944, 622, 0, 0, 39, '621'),
	(243, 1, 0, -50944, 623, 0, 0, 39, '622'),
	(243, 1, 0, -50944, 624, 0, 0, 39, '623'),
	(243, 1, 0, -50944, 625, 0, 0, 39, '624'),
	(243, 1, 0, -50944, 626, 0, 0, 39, '625'),
	(243, 1, 0, -50944, 627, 0, 0, 39, '626'),
	(243, 1, 0, -50944, 628, 0, 0, 39, '627'),
	(243, 1, 0, -50944, 629, 0, 0, 39, '628'),
	(243, 1, 0, -50944, 630, 0, 0, 39, '629'),
	(243, 1, 0, -50944, 631, 0, 0, 39, '630'),
	(243, 1, 0, -50944, 632, 0, 0, 39, '631'),
	(243, 1, 0, -50944, 633, 0, 0, 39, '632'),
	(243, 1, 0, -50944, 634, 0, 0, 39, '633'),
	(243, 1, 0, -50944, 635, 0, 0, 39, '634'),
	(243, 1, 0, -50944, 636, 0, 0, 39, '635'),
	(243, 1, 0, -50944, 637, 0, 0, 39, '636'),
	(243, 1, 0, -50944, 638, 0, 0, 39, '637'),
	(243, 1, 0, -50944, 639, 0, 0, 39, '638'),
	(243, 1, 0, -50944, 640, 0, 0, 39, '639'),
	(243, 1, 0, -50944, 641, 0, 0, 39, '640'),
	(243, 1, 0, -50944, 642, 0, 0, 39, '641'),
	(243, 1, 0, -50944, 643, 0, 0, 39, '642'),
	(243, 1, 0, -50944, 644, 0, 0, 39, '643'),
	(243, 1, 0, -50944, 645, 0, 0, 39, '644'),
	(243, 1, 0, -50944, 646, 0, 0, 39, '645'),
	(243, 1, 0, -50944, 647, 0, 0, 39, '646'),
	(243, 1, 0, -50944, 648, 0, 0, 39, '647'),
	(243, 1, 0, -50944, 649, 0, 0, 39, '648'),
	(243, 1, 0, -50944, 650, 0, 0, 39, '649'),
	(243, 1, 0, -50944, 651, 0, 0, 39, '650'),
	(243, 1, 0, -50944, 652, 0, 0, 39, '651'),
	(243, 1, 0, -50944, 653, 0, 0, 39, '652'),
	(243, 1, 0, -50944, 654, 0, 0, 39, '653'),
	(243, 1, 0, -50944, 655, 0, 0, 39, '654'),
	(243, 1, 0, -50944, 656, 0, 0, 39, '655'),
	(243, 1, 0, -50944, 657, 0, 0, 39, '656'),
	(243, 1, 0, -50944, 658, 0, 0, 39, '657'),
	(243, 1, 0, -50944, 659, 0, 0, 39, '658'),
	(243, 1, 0, -50944, 660, 0, 0, 39, '659'),
	(243, 1, 0, -50944, 661, 0, 0, 39, '660'),
	(243, 1, 0, -50944, 662, 0, 0, 39, '661'),
	(243, 1, 0, -50944, 663, 0, 0, 39, '662'),
	(243, 1, 0, -50944, 664, 0, 0, 39, '663'),
	(243, 1, 0, -50944, 665, 0, 0, 39, '664'),
	(243, 1, 0, -50944, 666, 0, 0, 39, '665'),
	(243, 1, 0, -50944, 667, 0, 0, 39, '666'),
	(243, 1, 0, -50944, 668, 0, 0, 39, '667'),
	(243, 1, 0, -50944, 669, 0, 0, 39, '668'),
	(243, 1, 0, -50944, 670, 0, 0, 39, '669'),
	(243, 1, 0, -50944, 671, 0, 0, 39, '670'),
	(243, 1, 0, -50944, 672, 0, 0, 39, '671'),
	(243, 1, 0, -50944, 673, 0, 0, 39, '672'),
	(243, 1, 0, -50944, 674, 0, 0, 39, '673'),
	(243, 1, 0, -50944, 675, 0, 0, 39, '674'),
	(243, 1, 0, -50944, 676, 0, 0, 39, '675'),
	(243, 1, 0, -50944, 677, 0, 0, 39, '676'),
	(243, 1, 0, -50944, 678, 0, 0, 39, '677'),
	(243, 1, 0, -50944, 679, 0, 0, 39, '678'),
	(243, 1, 0, -50944, 680, 0, 0, 39, '679'),
	(243, 1, 0, -50944, 681, 0, 0, 39, '680'),
	(243, 1, 0, -50944, 682, 0, 0, 39, '681'),
	(243, 1, 0, -50944, 683, 0, 0, 39, '682'),
	(243, 1, 0, -50944, 684, 0, 0, 39, '683'),
	(243, 1, 0, -50944, 685, 0, 0, 39, '684'),
	(243, 1, 0, -50944, 686, 0, 0, 39, '685'),
	(243, 1, 0, -50944, 687, 0, 0, 39, '686'),
	(243, 1, 0, -50944, 688, 0, 0, 39, '687'),
	(243, 1, 0, -50944, 689, 0, 0, 39, '688'),
	(243, 1, 0, -50944, 690, 0, 0, 39, '689'),
	(243, 1, 0, -50944, 691, 0, 0, 39, '690'),
	(243, 1, 0, -50944, 692, 0, 0, 39, '691'),
	(243, 1, 0, -50944, 693, 0, 0, 39, '692'),
	(243, 1, 0, -50944, 694, 0, 0, 39, '693'),
	(243, 1, 0, -50944, 695, 0, 0, 39, '694'),
	(243, 1, 0, -50944, 696, 0, 0, 39, '695'),
	(243, 1, 0, -50944, 697, 0, 0, 39, '696'),
	(243, 1, 0, -50944, 698, 0, 0, 39, '697'),
	(243, 1, 0, -50944, 699, 0, 0, 39, '698'),
	(243, 1, 0, -50944, 700, 0, 0, 39, '699'),
	(243, 1, 0, -50944, 701, 0, 0, 39, '700'),
	(243, 1, 0, -50944, 702, 0, 0, 39, '701'),
	(243, 1, 0, -50944, 703, 0, 0, 39, '702'),
	(243, 1, 0, -50944, 704, 0, 0, 39, '703'),
	(243, 1, 0, -50944, 705, 0, 0, 39, '704'),
	(243, 1, 0, -50944, 706, 0, 0, 39, '705'),
	(243, 1, 0, -50944, 707, 0, 0, 39, '706'),
	(243, 1, 0, -50944, 708, 0, 0, 39, '707'),
	(243, 1, 0, -50944, 709, 0, 0, 39, '708'),
	(243, 1, 0, -50944, 710, 0, 0, 39, '709'),
	(243, 1, 0, -50944, 711, 0, 0, 39, '710'),
	(243, 1, 0, -50944, 712, 0, 0, 39, '711'),
	(243, 1, 0, -50944, 713, 0, 0, 39, '712'),
	(243, 1, 0, -50944, 714, 0, 0, 39, '713'),
	(243, 1, 0, -50944, 715, 0, 0, 39, '714'),
	(243, 1, 0, -50944, 716, 0, 0, 39, '715'),
	(243, 1, 0, -50944, 717, 0, 0, 39, '716'),
	(243, 1, 0, -50944, 718, 0, 0, 39, '717'),
	(243, 1, 0, -50944, 719, 0, 0, 39, '718'),
	(243, 1, 0, -50944, 720, 0, 0, 39, '719'),
	(243, 1, 0, -50944, 721, 0, 0, 39, '720'),
	(243, 1, 0, -50944, 722, 0, 0, 39, '721'),
	(243, 1, 0, -50944, 723, 0, 0, 39, '722'),
	(243, 1, 0, -50944, 724, 0, 0, 39, '723'),
	(243, 1, 0, -50944, 725, 0, 0, 39, '724'),
	(243, 1, 0, -50944, 726, 0, 0, 39, '725'),
	(243, 1, 0, -50944, 727, 0, 0, 39, '726'),
	(243, 1, 0, -50944, 728, 0, 0, 39, '727'),
	(243, 1, 0, -50944, 729, 0, 0, 39, '728'),
	(243, 1, 0, -50944, 730, 0, 0, 39, '729'),
	(243, 1, 0, -50944, 731, 0, 0, 39, '730'),
	(243, 1, 0, -50944, 732, 0, 0, 39, '731'),
	(243, 1, 0, -50944, 733, 0, 0, 39, '732'),
	(243, 1, 0, -50944, 734, 0, 0, 39, '733'),
	(243, 1, 0, -50944, 735, 0, 0, 39, '734'),
	(243, 1, 0, -50944, 736, 0, 0, 39, '735'),
	(243, 1, 0, -50944, 737, 0, 0, 39, '736'),
	(243, 1, 0, -50944, 738, 0, 0, 39, '737'),
	(243, 1, 0, -50944, 739, 0, 0, 39, '738'),
	(243, 1, 0, -50944, 740, 0, 0, 39, '739'),
	(243, 1, 0, -50944, 741, 0, 0, 39, '740'),
	(243, 1, 0, -50944, 742, 0, 0, 39, '741'),
	(243, 1, 0, -50944, 743, 0, 0, 39, '742'),
	(243, 1, 0, -50944, 744, 0, 0, 39, '743'),
	(243, 1, 0, -50944, 745, 0, 0, 39, '744'),
	(243, 1, 0, -50944, 746, 0, 0, 39, '745'),
	(243, 1, 0, -50944, 747, 0, 0, 39, '746'),
	(243, 1, 0, -50944, 748, 0, 0, 39, '747'),
	(243, 1, 0, -50944, 749, 0, 0, 39, '748'),
	(243, 1, 0, -50944, 750, 0, 0, 39, '749'),
	(243, 1, 0, -50944, 751, 0, 0, 39, '750'),
	(243, 1, 0, -50944, 752, 0, 0, 39, '751'),
	(243, 1, 0, -50944, 753, 0, 0, 39, '752'),
	(243, 1, 0, -50944, 754, 0, 0, 39, '753'),
	(243, 1, 0, -50944, 755, 0, 0, 39, '754'),
	(243, 1, 0, -50944, 756, 0, 0, 39, '755'),
	(243, 1, 0, -50944, 757, 0, 0, 39, '756'),
	(243, 1, 0, -50944, 758, 0, 0, 39, '757'),
	(243, 1, 0, -50944, 759, 0, 0, 39, '758'),
	(243, 1, 0, -50944, 760, 0, 0, 39, '759'),
	(243, 1, 0, -50944, 761, 0, 0, 39, '760'),
	(243, 1, 0, -50944, 762, 0, 0, 39, '761'),
	(243, 1, 0, -50944, 763, 0, 0, 39, '762'),
	(243, 1, 0, -50944, 764, 0, 0, 39, '763'),
	(243, 1, 0, -50944, 765, 0, 0, 39, '764'),
	(243, 1, 0, -50944, 766, 0, 0, 39, '765'),
	(243, 1, 0, -50944, 767, 0, 0, 39, '766'),
	(243, 1, 0, -50944, 768, 0, 0, 39, '767'),
	(243, 1, 0, -50944, 769, 0, 0, 39, '768'),
	(243, 1, 0, -50944, 770, 0, 0, 39, '769'),
	(243, 1, 0, -50944, 771, 0, 0, 39, '770'),
	(243, 1, 0, -50944, 772, 0, 0, 39, '771'),
	(243, 1, 0, -50944, 773, 0, 0, 39, '772'),
	(243, 1, 0, -50944, 774, 0, 0, 39, '773'),
	(243, 1, 0, -50944, 775, 0, 0, 39, '774'),
	(243, 1, 0, -50944, 776, 0, 0, 39, '775'),
	(243, 1, 0, -50944, 777, 0, 0, 39, '776'),
	(243, 1, 0, -50944, 778, 0, 0, 39, '777'),
	(243, 1, 0, -50944, 779, 0, 0, 39, '778'),
	(243, 1, 0, -50944, 780, 0, 0, 39, '779'),
	(243, 1, 0, -50944, 781, 0, 0, 39, '780'),
	(243, 1, 0, -50944, 782, 0, 0, 39, '781'),
	(243, 1, 0, -50944, 783, 0, 0, 39, '782'),
	(243, 1, 0, -50944, 784, 0, 0, 39, '783'),
	(243, 1, 0, -50944, 785, 0, 0, 39, '784'),
	(243, 1, 0, -50944, 786, 0, 0, 39, '785'),
	(243, 1, 0, -50944, 787, 0, 0, 39, '786'),
	(243, 1, 0, -50944, 788, 0, 0, 39, '787'),
	(243, 1, 0, -50944, 789, 0, 0, 39, '788'),
	(243, 1, 0, -50944, 790, 0, 0, 39, '789'),
	(243, 1, 0, -50944, 791, 0, 0, 39, '790'),
	(243, 1, 0, -50944, 792, 0, 0, 39, '791'),
	(243, 1, 0, -50944, 793, 0, 0, 39, '792'),
	(243, 1, 0, -50944, 794, 0, 0, 39, '793'),
	(243, 1, 0, -50944, 795, 0, 0, 39, '794'),
	(243, 1, 0, -50944, 796, 0, 0, 39, '795'),
	(243, 1, 0, -50944, 797, 0, 0, 39, '796'),
	(243, 1, 0, -50944, 798, 0, 0, 39, '797'),
	(243, 1, 0, -50944, 799, 0, 0, 39, '798'),
	(243, 1, 0, -50944, 800, 0, 0, 39, '799'),
	(243, 1, 0, -50944, 801, 0, 0, 39, '800'),
	(243, 1, 0, -50944, 802, 0, 0, 39, '801'),
	(243, 1, 0, -50944, 803, 0, 0, 39, '802'),
	(243, 1, 0, -50944, 804, 0, 0, 39, '803'),
	(243, 1, 0, -50944, 805, 0, 0, 39, '804'),
	(243, 1, 0, -50944, 806, 0, 0, 39, '805'),
	(243, 1, 0, -50944, 807, 0, 0, 39, '806'),
	(243, 1, 0, -50944, 808, 0, 0, 39, '807'),
	(243, 1, 0, -50944, 809, 0, 0, 39, '808'),
	(243, 1, 0, -50944, 810, 0, 0, 39, '809'),
	(243, 1, 0, -50944, 811, 0, 0, 39, '810'),
	(243, 1, 0, -50944, 812, 0, 0, 39, '811'),
	(243, 1, 0, -50944, 813, 0, 0, 39, '812'),
	(243, 1, 0, -50944, 814, 0, 0, 39, '813'),
	(243, 1, 0, -50944, 815, 0, 0, 39, '814'),
	(243, 1, 0, -50944, 816, 0, 0, 39, '815'),
	(243, 1, 0, -50944, 817, 0, 0, 39, '816'),
	(243, 1, 0, -50944, 818, 0, 0, 39, '817'),
	(243, 1, 0, -50944, 819, 0, 0, 39, '818'),
	(243, 1, 0, -50944, 820, 0, 0, 39, '819'),
	(243, 1, 0, -50944, 821, 0, 0, 39, '820'),
	(243, 1, 0, -50944, 822, 0, 0, 39, '821'),
	(243, 1, 0, -50944, 823, 0, 0, 39, '822'),
	(243, 1, 0, -50944, 824, 0, 0, 39, '823'),
	(243, 1, 0, -50944, 825, 0, 0, 39, '824'),
	(243, 1, 0, -50944, 826, 0, 0, 39, '825'),
	(243, 1, 0, -50944, 827, 0, 0, 39, '826'),
	(243, 1, 0, -50944, 828, 0, 0, 39, '827'),
	(243, 1, 0, -50944, 829, 0, 0, 39, '828'),
	(243, 1, 0, -50944, 830, 0, 0, 39, '829'),
	(243, 1, 0, -50944, 831, 0, 0, 39, '830'),
	(243, 1, 0, -50944, 832, 0, 0, 39, '831'),
	(243, 1, 0, -50944, 833, 0, 0, 39, '832'),
	(243, 1, 0, -50944, 834, 0, 0, 39, '833'),
	(243, 1, 0, -50944, 835, 0, 0, 39, '834'),
	(243, 1, 0, -50944, 836, 0, 0, 39, '835'),
	(243, 1, 0, -50944, 837, 0, 0, 39, '836'),
	(243, 1, 0, -50944, 838, 0, 0, 39, '837'),
	(243, 1, 0, -50944, 839, 0, 0, 39, '838'),
	(243, 1, 0, -50944, 840, 0, 0, 39, '839'),
	(243, 1, 0, -50944, 841, 0, 0, 39, '840'),
	(243, 1, 0, -50944, 842, 0, 0, 39, '841'),
	(243, 1, 0, -50944, 843, 0, 0, 39, '842'),
	(243, 1, 0, -50944, 844, 0, 0, 39, '843'),
	(243, 1, 0, -50944, 845, 0, 0, 39, '844'),
	(243, 1, 0, -50944, 846, 0, 0, 39, '845'),
	(243, 1, 0, -50944, 847, 0, 0, 39, '846'),
	(243, 1, 0, -50944, 848, 0, 0, 39, '847'),
	(243, 1, 0, -50944, 849, 0, 0, 39, '848'),
	(243, 1, 0, -50944, 850, 0, 0, 39, '849'),
	(243, 1, 0, -50944, 851, 0, 0, 39, '850'),
	(243, 1, 0, -50944, 852, 0, 0, 39, '851'),
	(243, 1, 0, -50944, 853, 0, 0, 39, '852'),
	(243, 1, 0, -50944, 854, 0, 0, 39, '853'),
	(243, 1, 0, -50944, 855, 0, 0, 39, '854'),
	(243, 1, 0, -50944, 856, 0, 0, 39, '855'),
	(243, 1, 0, -50944, 857, 0, 0, 39, '856'),
	(243, 1, 0, -50944, 858, 0, 0, 39, '857'),
	(243, 1, 0, -50944, 859, 0, 0, 39, '858'),
	(243, 1, 0, -50944, 860, 0, 0, 39, '859'),
	(243, 1, 0, -50944, 861, 0, 0, 39, '860'),
	(243, 1, 0, -50944, 862, 0, 0, 39, '861'),
	(243, 1, 0, -50944, 863, 0, 0, 39, '862'),
	(243, 1, 0, -50944, 864, 0, 0, 39, '863'),
	(243, 1, 0, -50944, 865, 0, 0, 39, '864'),
	(243, 1, 0, -50944, 866, 0, 0, 39, '865'),
	(243, 1, 0, -50944, 867, 0, 0, 39, '866'),
	(243, 1, 0, -50944, 868, 0, 0, 39, '867'),
	(243, 1, 0, -50944, 869, 0, 0, 39, '868'),
	(243, 1, 0, -50944, 870, 0, 0, 39, '869'),
	(243, 1, 0, -50944, 871, 0, 0, 39, '870'),
	(243, 1, 0, -50944, 872, 0, 0, 39, '871'),
	(243, 1, 0, -50944, 873, 0, 0, 39, '872'),
	(243, 1, 0, -50944, 874, 0, 0, 39, '873'),
	(243, 1, 0, -50944, 875, 0, 0, 39, '874'),
	(243, 1, 0, -50944, 876, 0, 0, 39, '875'),
	(243, 1, 0, -50944, 877, 0, 0, 39, '876'),
	(243, 1, 0, -50944, 878, 0, 0, 39, '877'),
	(243, 1, 0, -50944, 879, 0, 0, 39, '878'),
	(243, 1, 0, -50944, 880, 0, 0, 39, '879'),
	(243, 1, 0, -50944, 881, 0, 0, 39, '880'),
	(243, 1, 0, -50944, 882, 0, 0, 39, '881'),
	(243, 1, 0, -50944, 883, 0, 0, 39, '882'),
	(243, 1, 0, -50944, 884, 0, 0, 39, '883'),
	(243, 1, 0, -50944, 885, 0, 0, 39, '884'),
	(243, 1, 0, -50944, 886, 0, 0, 39, '885'),
	(243, 1, 0, -50944, 887, 0, 0, 39, '886'),
	(243, 1, 0, -50944, 888, 0, 0, 39, '887'),
	(243, 1, 0, -50944, 889, 0, 0, 39, '888'),
	(243, 1, 0, -50944, 890, 0, 0, 39, '889'),
	(243, 1, 0, -50944, 891, 0, 0, 39, '890'),
	(243, 1, 0, -50944, 892, 0, 0, 39, '891'),
	(243, 1, 0, -50944, 893, 0, 0, 39, '892'),
	(243, 1, 0, -50944, 894, 0, 0, 39, '893'),
	(243, 1, 0, -50944, 895, 0, 0, 39, '894'),
	(243, 1, 0, -50944, 896, 0, 0, 39, '895'),
	(243, 1, 0, -50944, 897, 0, 0, 39, '896'),
	(243, 1, 0, -50944, 898, 0, 0, 39, '897'),
	(243, 1, 0, -50944, 899, 0, 0, 39, '898'),
	(243, 1, 0, -50944, 900, 0, 0, 39, '899'),
	(243, 1, 0, -50944, 901, 0, 0, 39, '900'),
	(243, 1, 0, -50944, 902, 0, 0, 39, '901'),
	(243, 1, 0, -50944, 903, 0, 0, 39, '902'),
	(243, 1, 0, -50944, 904, 0, 0, 39, '903'),
	(243, 1, 0, -50944, 905, 0, 0, 39, '904'),
	(243, 1, 0, -50944, 906, 0, 0, 39, '905'),
	(243, 1, 0, -50944, 907, 0, 0, 39, '906'),
	(243, 1, 0, -50944, 908, 0, 0, 39, '907'),
	(243, 1, 0, -50944, 909, 0, 0, 39, '908'),
	(243, 1, 0, -50944, 910, 0, 0, 39, '909'),
	(243, 1, 0, -50944, 911, 0, 0, 39, '910'),
	(243, 1, 0, -50944, 912, 0, 0, 39, '911'),
	(243, 1, 0, -50944, 913, 0, 0, 39, '912'),
	(243, 1, 0, -50944, 914, 0, 0, 39, '913'),
	(243, 1, 0, -50944, 915, 0, 0, 39, '914'),
	(243, 1, 0, -50944, 916, 0, 0, 39, '915'),
	(243, 1, 0, -50944, 917, 0, 0, 39, '916'),
	(243, 1, 0, -50944, 918, 0, 0, 39, '917'),
	(243, 1, 0, -50944, 919, 0, 0, 39, '918'),
	(243, 1, 0, -50944, 920, 0, 0, 39, '919'),
	(243, 1, 0, -50944, 921, 0, 0, 39, '920'),
	(243, 1, 0, -50944, 922, 0, 0, 39, '921'),
	(243, 1, 0, -50944, 923, 0, 0, 39, '922'),
	(243, 1, 0, -50944, 924, 0, 0, 39, '923'),
	(243, 1, 0, -50944, 925, 0, 0, 39, '924'),
	(243, 1, 0, -50944, 926, 0, 0, 39, '925'),
	(243, 1, 0, -50944, 927, 0, 0, 39, '926'),
	(243, 1, 0, -50944, 928, 0, 0, 39, '927'),
	(243, 1, 0, -50944, 929, 0, 0, 39, '928'),
	(243, 1, 0, -50944, 930, 0, 0, 39, '929'),
	(243, 1, 0, -50944, 931, 0, 0, 39, '930'),
	(243, 1, 0, -50944, 932, 0, 0, 39, '931'),
	(243, 1, 0, -50944, 933, 0, 0, 39, '932'),
	(243, 1, 0, -50944, 934, 0, 0, 39, '933'),
	(243, 1, 0, -50944, 935, 0, 0, 39, '934'),
	(243, 1, 0, -50944, 936, 0, 0, 39, '935'),
	(243, 1, 0, -50944, 937, 0, 0, 39, '936'),
	(243, 1, 0, -50944, 938, 0, 0, 39, '937'),
	(243, 1, 0, -50944, 939, 0, 0, 39, '938'),
	(243, 1, 0, -50944, 940, 0, 0, 39, '939'),
	(243, 1, 0, -50944, 941, 0, 0, 39, '940'),
	(243, 1, 0, -50944, 942, 0, 0, 39, '941'),
	(243, 1, 0, -50944, 943, 0, 0, 39, '942'),
	(243, 1, 0, -50944, 944, 0, 0, 39, '943'),
	(243, 1, 0, -50944, 945, 0, 0, 39, '944'),
	(243, 1, 0, -50944, 946, 0, 0, 39, '945'),
	(243, 1, 0, -50944, 947, 0, 0, 39, '946'),
	(243, 1, 0, -50944, 948, 0, 0, 39, '947'),
	(243, 1, 0, -50944, 949, 0, 0, 39, '948'),
	(243, 1, 0, -50944, 950, 0, 0, 39, '949'),
	(243, 1, 0, -50944, 951, 0, 0, 39, '950'),
	(243, 1, 0, -50944, 952, 0, 0, 39, '951'),
	(243, 1, 0, -50944, 953, 0, 0, 39, '952'),
	(243, 1, 0, -50944, 954, 0, 0, 39, '953'),
	(243, 1, 0, -50944, 955, 0, 0, 39, '954'),
	(243, 1, 0, -50944, 956, 0, 0, 39, '955'),
	(243, 1, 0, -50944, 957, 0, 0, 39, '956'),
	(243, 1, 0, -50944, 958, 0, 0, 39, '957'),
	(243, 1, 0, -50944, 959, 0, 0, 39, '958'),
	(243, 1, 0, -50944, 960, 0, 0, 39, '959'),
	(243, 1, 0, -50944, 961, 0, 0, 39, '960'),
	(243, 1, 0, -50944, 962, 0, 0, 39, '961'),
	(243, 1, 0, -50944, 963, 0, 0, 39, '962'),
	(243, 1, 0, -50944, 964, 0, 0, 39, '963'),
	(243, 1, 0, -50944, 965, 0, 0, 39, '964'),
	(243, 1, 0, -50944, 966, 0, 0, 39, '965'),
	(243, 1, 0, -50944, 967, 0, 0, 39, '966'),
	(243, 1, 0, -50944, 968, 0, 0, 39, '967'),
	(243, 1, 0, -50944, 969, 0, 0, 39, '968'),
	(243, 1, 0, -50944, 970, 0, 0, 39, '969'),
	(243, 1, 0, -50944, 971, 0, 0, 39, '970'),
	(243, 1, 0, -50944, 972, 0, 0, 39, '971'),
	(243, 1, 0, -50944, 973, 0, 0, 39, '972'),
	(243, 1, 0, -50944, 974, 0, 0, 39, '973'),
	(243, 1, 0, -50944, 975, 0, 0, 39, '974'),
	(243, 1, 0, -50944, 976, 0, 0, 39, '975'),
	(243, 1, 0, -50944, 977, 0, 0, 39, '976'),
	(243, 1, 0, -50944, 978, 0, 0, 39, '977'),
	(243, 1, 0, -50944, 979, 0, 0, 39, '978'),
	(243, 1, 0, -50944, 980, 0, 0, 39, '979'),
	(243, 1, 0, -50944, 981, 0, 0, 39, '980'),
	(243, 1, 0, -50944, 982, 0, 0, 39, '981'),
	(243, 1, 0, -50944, 983, 0, 0, 39, '982'),
	(243, 1, 0, -50944, 984, 0, 0, 39, '983'),
	(243, 1, 0, -50944, 985, 0, 0, 39, '984'),
	(243, 1, 0, -50944, 986, 0, 0, 39, '985'),
	(243, 1, 0, -50944, 987, 0, 0, 39, '986'),
	(243, 1, 0, -50944, 988, 0, 0, 39, '987'),
	(243, 1, 0, -50944, 989, 0, 0, 39, '988'),
	(243, 1, 0, -50944, 990, 0, 0, 39, '989'),
	(243, 1, 0, -50944, 991, 0, 0, 39, '990'),
	(243, 1, 0, -50944, 992, 0, 0, 39, '991'),
	(243, 1, 0, -50944, 993, 0, 0, 39, '992'),
	(243, 1, 0, -50944, 994, 0, 0, 39, '993'),
	(243, 1, 0, -50944, 995, 0, 0, 39, '994'),
	(243, 1, 0, -50944, 996, 0, 0, 39, '995'),
	(243, 1, 0, -50944, 997, 0, 0, 39, '996'),
	(243, 1, 0, -50944, 998, 0, 0, 39, '997'),
	(243, 1, 0, -50944, 999, 0, 0, 39, '998'),
	(243, 1, 0, -50944, 1000, 0, 0, 39, '999'),
	(243, 1, 0, -50944, 1001, 0, 0, 39, '1000'),
	(243, 1, 0, -50944, 1002, 0, 0, 39, '1001'),
	(243, 1, 0, -50944, 1003, 0, 0, 39, '1002'),
	(243, 1, 0, -50944, 1004, 0, 0, 39, '1003'),
	(243, 1, 0, -50944, 1005, 0, 0, 39, '1004'),
	(243, 1, 0, -50944, 1006, 0, 0, 39, '1005'),
	(243, 1, 0, -50944, 1007, 0, 0, 39, '1006'),
	(243, 1, 0, -50944, 1008, 0, 0, 39, '1007'),
	(243, 1, 0, -50944, 1009, 0, 0, 39, '1008'),
	(243, 1, 0, -50944, 1010, 0, 0, 39, '1009'),
	(243, 1, 0, -50944, 1011, 0, 0, 39, '1010'),
	(243, 1, 0, -50944, 1012, 0, 0, 39, '1011'),
	(243, 1, 0, -50944, 1013, 0, 0, 39, '1012'),
	(243, 1, 0, -50944, 1014, 0, 0, 39, '1013'),
	(243, 1, 0, -50944, 1015, 0, 0, 39, '1014'),
	(243, 1, 0, -50944, 1016, 0, 0, 39, '1015'),
	(243, 1, 0, -50944, 1017, 0, 0, 39, '1016'),
	(243, 1, 0, -50944, 1018, 0, 0, 39, '1017'),
	(243, 1, 0, -50944, 1019, 0, 0, 39, '1018'),
	(243, 1, 0, -50944, 1020, 0, 0, 39, '1019'),
	(243, 1, 0, -50944, 1021, 0, 0, 39, '1020'),
	(243, 1, 0, -50944, 1022, 0, 0, 39, '1021'),
	(243, 1, 0, -50944, 1023, 0, 0, 39, '1022'),
	(243, 1, 0, -50944, 1024, 0, 0, 39, '1023'),
	(243, 1, 0, -50944, 1025, 0, 0, 39, '1024'),
	(243, 1, 0, -50944, 1026, 0, 0, 39, '1025'),
	(243, 1, 0, -50944, 1027, 0, 0, 39, '1026'),
	(243, 1, 0, -50944, 1028, 0, 0, 39, '1027'),
	(243, 1, 0, -50944, 1029, 0, 0, 39, '1028'),
	(243, 1, 0, -50944, 1030, 0, 0, 39, '1029'),
	(243, 1, 0, -50944, 1031, 0, 0, 39, '1030'),
	(243, 1, 0, -50944, 1032, 0, 0, 39, '1031'),
	(243, 1, 0, -50944, 1033, 0, 0, 39, '1032'),
	(243, 1, 0, -50944, 1034, 0, 0, 39, '1033'),
	(243, 1, 0, -50944, 1035, 0, 0, 39, '1034'),
	(243, 1, 0, -50944, 1036, 0, 0, 39, '1035'),
	(243, 1, 0, -50944, 1037, 0, 0, 39, '1036'),
	(243, 1, 0, -50944, 1038, 0, 0, 39, '1037'),
	(243, 1, 0, -50944, 1039, 0, 0, 39, '1038'),
	(243, 1, 0, -50944, 1040, 0, 0, 39, '1039'),
	(243, 1, 0, -50944, 1041, 0, 0, 39, '1040'),
	(243, 1, 0, -50944, 1042, 0, 0, 39, '1041'),
	(243, 1, 0, -50944, 1043, 0, 0, 39, '1042'),
	(243, 1, 0, -50944, 1044, 0, 0, 39, '1043'),
	(243, 1, 0, -50944, 1045, 0, 0, 39, '1044'),
	(243, 1, 0, -50944, 1046, 0, 0, 39, '1045'),
	(243, 1, 0, -50944, 1047, 0, 0, 39, '1046'),
	(243, 1, 0, -50944, 1048, 0, 0, 39, '1047'),
	(243, 1, 0, -50944, 1049, 0, 0, 39, '1048'),
	(243, 1, 0, -50944, 1050, 0, 0, 39, '1049'),
	(243, 1, 0, -50944, 1051, 0, 0, 39, '1050'),
	(243, 1, 0, -50944, 1052, 0, 0, 39, '1051'),
	(243, 1, 0, -50944, 1053, 0, 0, 39, '1052'),
	(243, 1, 0, -50944, 1054, 0, 0, 39, '1053'),
	(243, 1, 0, -50944, 1055, 0, 0, 39, '1054'),
	(243, 1, 0, -50944, 1056, 0, 0, 39, '1055'),
	(243, 1, 0, -50944, 1057, 0, 0, 39, '1056'),
	(243, 1, 0, -50944, 1058, 0, 0, 39, '1057'),
	(243, 1, 0, -50944, 1059, 0, 0, 39, '1058'),
	(243, 1, 0, -50944, 1060, 0, 0, 39, '1059'),
	(243, 1, 0, -50944, 1061, 0, 0, 39, '1060'),
	(243, 1, 0, -50944, 1062, 0, 0, 39, '1061'),
	(243, 1, 0, -50944, 1063, 0, 0, 39, '1062'),
	(243, 1, 0, -50944, 1064, 0, 0, 39, '1063'),
	(243, 1, 0, -50944, 1065, 0, 0, 39, '1064'),
	(243, 1, 0, -50944, 1066, 0, 0, 39, '1065'),
	(243, 1, 0, -50944, 1067, 0, 0, 39, '1066'),
	(243, 1, 0, -50944, 1068, 0, 0, 39, '1067'),
	(243, 1, 0, -50944, 1069, 0, 0, 39, '1068'),
	(243, 1, 0, -50944, 1070, 0, 0, 39, '1069'),
	(243, 1, 0, -50944, 1071, 0, 0, 39, '1070'),
	(243, 1, 0, -50944, 1072, 0, 0, 39, '1071'),
	(243, 1, 0, -50944, 1073, 0, 0, 39, '1072'),
	(243, 1, 0, -50944, 1074, 0, 0, 39, '1073'),
	(243, 1, 0, -50944, 1075, 0, 0, 39, '1074'),
	(243, 1, 0, -50944, 1076, 0, 0, 39, '1075'),
	(243, 1, 0, -50944, 1077, 0, 0, 39, '1076'),
	(243, 1, 0, -50944, 1078, 0, 0, 39, '1077'),
	(243, 1, 0, -50944, 1079, 0, 0, 39, '1078'),
	(243, 1, 0, -50944, 1080, 0, 0, 39, '1079'),
	(243, 1, 0, -50944, 1081, 0, 0, 39, '1080'),
	(243, 1, 0, -50944, 1082, 0, 0, 39, '1081'),
	(243, 1, 0, -50944, 1083, 0, 0, 39, '1082'),
	(243, 1, 0, -50944, 1084, 0, 0, 39, '1083'),
	(243, 1, 0, -50944, 1085, 0, 0, 39, '1084'),
	(243, 1, 0, -50944, 1086, 0, 0, 39, '1085'),
	(243, 1, 0, -50944, 1087, 0, 0, 39, '1086'),
	(243, 1, 0, -50944, 1088, 0, 0, 39, '1087'),
	(243, 1, 0, -50944, 1089, 0, 0, 39, '1088'),
	(243, 1, 0, -50944, 1090, 0, 0, 39, '1089'),
	(243, 1, 0, -50944, 1091, 0, 0, 39, '1090'),
	(243, 1, 0, -50944, 1092, 0, 0, 39, '1091'),
	(243, 1, 0, -50944, 1093, 0, 0, 39, '1092'),
	(243, 1, 0, -50944, 1094, 0, 0, 39, '1093'),
	(243, 1, 0, -50944, 1095, 0, 0, 39, '1094'),
	(243, 1, 0, -50944, 1096, 0, 0, 39, '1095'),
	(243, 1, 0, -50944, 1097, 0, 0, 39, '1096'),
	(243, 1, 0, -50944, 1098, 0, 0, 39, '1097'),
	(243, 1, 0, -50944, 1099, 0, 0, 39, '1098'),
	(243, 1, 0, -50944, 1100, 0, 0, 39, '1099'),
	(243, 1, 0, -50944, 1101, 0, 0, 39, '1100'),
	(243, 1, 0, -50944, 1102, 0, 0, 39, '1101'),
	(243, 1, 0, -50944, 1103, 0, 0, 39, '1102'),
	(243, 1, 0, -50944, 1104, 0, 0, 39, '1103'),
	(243, 1, 0, -50944, 1105, 0, 0, 39, '1104'),
	(243, 1, 0, -50944, 1106, 0, 0, 39, '1105'),
	(243, 1, 0, -50944, 1107, 0, 0, 39, '1106'),
	(243, 1, 0, -50944, 1108, 0, 0, 39, '1107'),
	(243, 1, 0, -50944, 1109, 0, 0, 39, '1108'),
	(243, 1, 0, -50944, 1110, 0, 0, 39, '1109'),
	(243, 1, 0, -50944, 1111, 0, 0, 39, '1110'),
	(243, 1, 0, -50944, 1112, 0, 0, 39, '1111'),
	(243, 1, 0, -50944, 1113, 0, 0, 39, '1112'),
	(243, 1, 0, -50944, 1114, 0, 0, 39, '1113'),
	(243, 1, 0, -50944, 1115, 0, 0, 39, '1114'),
	(243, 1, 0, -50944, 1116, 0, 0, 39, '1115'),
	(243, 1, 0, -50944, 1117, 0, 0, 39, '1116'),
	(243, 1, 0, -50944, 1118, 0, 0, 39, '1117'),
	(243, 1, 0, -50944, 1119, 0, 0, 39, '1118'),
	(243, 1, 0, -50944, 1120, 0, 0, 39, '1119'),
	(243, 1, 0, -50944, 1121, 0, 0, 39, '1120'),
	(243, 1, 0, -50944, 1122, 0, 0, 39, '1121'),
	(243, 1, 0, -50944, 1123, 0, 0, 39, '1122'),
	(243, 1, 0, -50944, 1124, 0, 0, 39, '1123'),
	(243, 1, 0, -50944, 1125, 0, 0, 39, '1124'),
	(243, 1, 0, -50944, 1126, 0, 0, 39, '1125'),
	(243, 1, 0, -50944, 1127, 0, 0, 39, '1126'),
	(243, 1, 0, -50944, 1128, 0, 0, 39, '1127'),
	(243, 1, 0, -50944, 1129, 0, 0, 39, '1128'),
	(243, 1, 0, -50944, 1130, 0, 0, 39, '1129'),
	(243, 1, 0, -50944, 1131, 0, 0, 39, '1130'),
	(243, 1, 0, -50944, 1132, 0, 0, 39, '1131'),
	(243, 1, 0, -50944, 1133, 0, 0, 39, '1132'),
	(243, 1, 0, -50944, 1134, 0, 0, 39, '1133'),
	(243, 1, 0, -50944, 1135, 0, 0, 39, '1134'),
	(243, 1, 0, -50944, 1136, 0, 0, 39, '1135'),
	(243, 1, 0, -50944, 1137, 0, 0, 39, '1136'),
	(243, 1, 0, -50944, 1138, 0, 0, 39, '1137'),
	(243, 1, 0, -50944, 1139, 0, 0, 39, '1138'),
	(243, 1, 0, -50944, 1140, 0, 0, 39, '1139'),
	(243, 1, 0, -50944, 1141, 0, 0, 39, '1140'),
	(243, 1, 0, -50944, 1142, 0, 0, 39, '1141'),
	(243, 1, 0, -50944, 1143, 0, 0, 39, '1142'),
	(243, 1, 0, -50944, 1144, 0, 0, 39, '1143'),
	(243, 1, 0, -50944, 1145, 0, 0, 39, '1144'),
	(243, 1, 0, -50944, 1146, 0, 0, 39, '1145'),
	(243, 1, 0, -50944, 1147, 0, 0, 39, '1146'),
	(243, 1, 0, -50944, 1148, 0, 0, 39, '1147'),
	(243, 1, 0, -50944, 1149, 0, 0, 39, '1148'),
	(243, 1, 0, -50944, 1150, 0, 0, 39, '1149'),
	(243, 1, 0, -50944, 1151, 0, 0, 39, '1150'),
	(243, 1, 0, -50944, 1152, 0, 0, 39, '1151'),
	(243, 1, 0, -50944, 1153, 0, 0, 39, '1152'),
	(243, 1, 0, -50944, 1154, 0, 0, 39, '1153'),
	(243, 1, 0, -50944, 1155, 0, 0, 39, '1154'),
	(243, 1, 0, -50944, 1156, 0, 0, 39, '1155'),
	(243, 1, 0, -50944, 1157, 0, 0, 39, '1156'),
	(243, 1, 0, -50944, 1158, 0, 0, 39, '1157'),
	(243, 1, 0, -50944, 1159, 0, 0, 39, '1158'),
	(243, 1, 0, -50944, 1160, 0, 0, 39, '1159'),
	(243, 1, 0, -50944, 1161, 0, 0, 39, '1160'),
	(243, 1, 0, -50944, 1162, 0, 0, 39, '1161'),
	(243, 1, 0, -50944, 1163, 0, 0, 39, '1162'),
	(243, 1, 0, -50944, 1164, 0, 0, 39, '1163'),
	(243, 1, 0, -50944, 1165, 0, 0, 39, '1164'),
	(243, 1, 0, -50944, 1166, 0, 0, 39, '1165'),
	(243, 1, 0, -50944, 1167, 0, 0, 39, '1166'),
	(243, 1, 0, -50944, 1168, 0, 0, 39, '1167'),
	(243, 1, 0, -50944, 1169, 0, 0, 39, '1168'),
	(243, 1, 0, -50944, 1170, 0, 0, 39, '1169'),
	(243, 1, 0, -50944, 1171, 0, 0, 39, '1170'),
	(243, 1, 0, -50944, 1172, 0, 0, 39, '1171'),
	(243, 1, 0, -50944, 1173, 0, 0, 39, '1172'),
	(243, 1, 0, -50944, 1174, 0, 0, 39, '1173'),
	(243, 1, 0, -50944, 1175, 0, 0, 39, '1174'),
	(243, 1, 0, -50944, 1176, 0, 0, 39, '1175'),
	(243, 1, 0, -50944, 1177, 0, 0, 39, '1176'),
	(243, 1, 0, -50944, 1178, 0, 0, 39, '1177'),
	(243, 1, 0, -50944, 1179, 0, 0, 39, '1178'),
	(243, 1, 0, -50944, 1180, 0, 0, 39, '1179'),
	(243, 1, 0, -50944, 1181, 0, 0, 39, '1180'),
	(243, 1, 0, -50944, 1182, 0, 0, 39, '1181'),
	(243, 1, 0, -50944, 1183, 0, 0, 39, '1182'),
	(243, 1, 0, -50944, 1184, 0, 0, 39, '1183'),
	(243, 1, 0, -50944, 1185, 0, 0, 39, '1184'),
	(243, 1, 0, -50944, 1186, 0, 0, 39, '1185'),
	(243, 1, 0, -50944, 1187, 0, 0, 39, '1186'),
	(243, 1, 0, -50944, 1188, 0, 0, 39, '1187'),
	(243, 1, 0, -50944, 1189, 0, 0, 39, '1188'),
	(243, 1, 0, -50944, 1190, 0, 0, 39, '1189'),
	(243, 1, 0, -50944, 1191, 0, 0, 39, '1190'),
	(243, 1, 0, -50944, 1192, 0, 0, 39, '1191'),
	(243, 1, 0, -50944, 1193, 0, 0, 39, '1192'),
	(243, 1, 0, -50944, 1194, 0, 0, 39, '1193'),
	(243, 1, 0, -50944, 1195, 0, 0, 39, '1194'),
	(243, 1, 0, -50944, 1196, 0, 0, 39, '1195'),
	(243, 1, 0, -50944, 1197, 0, 0, 39, '1196'),
	(243, 1, 0, -50944, 1198, 0, 0, 39, '1197'),
	(243, 1, 0, -50944, 1199, 0, 0, 39, '1198'),
	(243, 1, 0, -50944, 1200, 0, 0, 39, '1199'),
	(243, 1, 0, -50944, 1201, 0, 0, 39, '1200'),
	(243, 1, 0, -50944, 1202, 0, 0, 39, '1201'),
	(243, 1, 0, -50944, 1203, 0, 0, 39, '1202'),
	(243, 1, 0, -50944, 1204, 0, 0, 39, '1203'),
	(243, 1, 0, -50944, 1205, 0, 0, 39, '1204'),
	(243, 1, 0, -50944, 1206, 0, 0, 39, '1205'),
	(243, 1, 0, -50944, 1207, 0, 0, 39, '1206'),
	(243, 1, 0, -50944, 1208, 0, 0, 39, '1207'),
	(243, 1, 0, -50944, 1209, 0, 0, 39, '1208'),
	(243, 1, 0, -50944, 1210, 0, 0, 39, '1209'),
	(243, 1, 0, -50944, 1211, 0, 0, 39, '1210'),
	(243, 1, 0, -50944, 1212, 0, 0, 39, '1211'),
	(243, 1, 0, -50944, 1213, 0, 0, 39, '1212'),
	(243, 1, 0, -50944, 1214, 0, 0, 39, '1213'),
	(243, 1, 0, -50944, 1215, 0, 0, 39, '1214'),
	(243, 1, 0, -50944, 1216, 0, 0, 39, '1215'),
	(243, 1, 0, -50944, 1217, 0, 0, 39, '1216'),
	(243, 1, 0, -50944, 1218, 0, 0, 39, '1217'),
	(243, 1, 0, -50944, 1219, 0, 0, 39, '1218'),
	(243, 1, 0, -50944, 1220, 0, 0, 39, '1219'),
	(243, 1, 0, -50944, 1221, 0, 0, 39, '1220'),
	(243, 1, 0, -50944, 1222, 0, 0, 39, '1221'),
	(243, 1, 0, -50944, 1223, 0, 0, 39, '1222'),
	(243, 1, 0, -50944, 1224, 0, 0, 39, '1223'),
	(243, 1, 0, -50944, 1225, 0, 0, 39, '1224'),
	(243, 1, 0, -50944, 1226, 0, 0, 39, '1225'),
	(243, 1, 0, -50944, 1227, 0, 0, 39, '1226'),
	(243, 1, 0, -50944, 1228, 0, 0, 39, '1227'),
	(243, 1, 0, -50944, 1229, 0, 0, 39, '1228'),
	(243, 1, 0, -50944, 1230, 0, 0, 39, '1229'),
	(243, 1, 0, -50944, 1231, 0, 0, 39, '1230'),
	(243, 1, 0, -50944, 1232, 0, 0, 39, '1231'),
	(243, 1, 0, -50944, 1233, 0, 0, 39, '1232'),
	(243, 1, 0, -50944, 1234, 0, 0, 39, '1233'),
	(243, 1, 0, -50944, 1235, 0, 0, 39, '1234'),
	(243, 1, 0, -50944, 1236, 0, 0, 39, '1235'),
	(243, 1, 0, -50944, 1237, 0, 0, 39, '1236'),
	(243, 1, 0, -50944, 1238, 0, 0, 39, '1237'),
	(243, 1, 0, -50944, 1239, 0, 0, 39, '1238'),
	(243, 1, 0, -50944, 1240, 0, 0, 39, '1239'),
	(243, 1, 0, -50944, 1241, 0, 0, 39, '1240'),
	(243, 1, 0, -50944, 1242, 0, 0, 39, '1241'),
	(243, 1, 0, -50944, 1243, 0, 0, 39, '1242'),
	(243, 1, 0, -50944, 1244, 0, 0, 39, '1243'),
	(243, 1, 0, -50944, 1245, 0, 0, 39, '1244'),
	(243, 1, 0, -50944, 1246, 0, 0, 39, '1245'),
	(243, 1, 0, -50944, 1247, 0, 0, 39, '1246'),
	(243, 1, 0, -50944, 1248, 0, 0, 39, '1247'),
	(243, 1, 0, -50944, 1249, 0, 0, 39, '1248'),
	(243, 1, 0, -50944, 1250, 0, 0, 39, '1249'),
	(243, 1, 0, -50944, 1251, 0, 0, 39, '1250'),
	(243, 1, 0, -50944, 1252, 0, 0, 39, '1251'),
	(243, 1, 0, -50944, 1253, 0, 0, 39, '1252'),
	(243, 1, 0, -50944, 1254, 0, 0, 39, '1253'),
	(243, 1, 0, -50944, 1255, 0, 0, 39, '1254'),
	(243, 1, 0, -50944, 1256, 0, 0, 39, '1255'),
	(243, 1, 0, -50944, 1257, 0, 0, 39, '1256'),
	(243, 1, 0, -50944, 1258, 0, 0, 39, '1257'),
	(243, 1, 0, -50944, 1259, 0, 0, 39, '1258'),
	(243, 1, 0, -50944, 1260, 0, 0, 39, '1259'),
	(243, 1, 0, -50944, 1261, 0, 0, 39, '1260'),
	(243, 1, 0, -50944, 1262, 0, 0, 39, '1261'),
	(243, 1, 0, -50944, 1263, 0, 0, 39, '1262'),
	(243, 1, 0, -50944, 1264, 0, 0, 39, '1263'),
	(243, 1, 0, -50944, 1265, 0, 0, 39, '1264'),
	(243, 1, 0, -50944, 1266, 0, 0, 39, '1265'),
	(243, 1, 0, -50944, 1267, 0, 0, 39, '1266'),
	(243, 1, 0, -50944, 1268, 0, 0, 39, '1267'),
	(243, 1, 0, -50944, 1269, 0, 0, 39, '1268'),
	(243, 1, 0, -50944, 1270, 0, 0, 39, '1269'),
	(243, 1, 0, -50944, 1271, 0, 0, 39, '1270'),
	(243, 1, 0, -50944, 1272, 0, 0, 39, '1271'),
	(243, 1, 0, -50944, 1273, 0, 0, 39, '1272'),
	(243, 1, 0, -50944, 1274, 0, 0, 39, '1273'),
	(243, 1, 0, -50944, 1275, 0, 0, 39, '1274'),
	(243, 1, 0, -50944, 1276, 0, 0, 39, '1275'),
	(243, 1, 0, -50944, 1277, 0, 0, 39, '1276'),
	(243, 1, 0, -50944, 1278, 0, 0, 39, '1277'),
	(243, 1, 0, -50944, 1279, 0, 0, 39, '1278'),
	(243, 1, 0, -50944, 1280, 0, 0, 39, '1279'),
	(243, 1, 0, -50944, 1281, 0, 0, 39, '1280'),
	(243, 1, 0, -50944, 1282, 0, 0, 39, '1281'),
	(243, 1, 0, -50944, 1283, 0, 0, 39, '1282'),
	(243, 1, 0, -50944, 1284, 0, 0, 39, '1283'),
	(243, 1, 0, -50944, 1285, 0, 0, 39, '1284'),
	(243, 1, 0, -50944, 1286, 0, 0, 39, '1285'),
	(243, 1, 0, -50944, 1287, 0, 0, 39, '1286'),
	(243, 1, 0, -50944, 1288, 0, 0, 39, '1287'),
	(243, 1, 0, -50944, 1289, 0, 0, 39, '1288'),
	(243, 1, 0, -50944, 1290, 0, 0, 39, '1289'),
	(243, 1, 0, -50944, 1291, 0, 0, 39, '1290'),
	(243, 1, 0, -50944, 1292, 0, 0, 39, '1291'),
	(243, 1, 0, -50944, 1293, 0, 0, 39, '1292'),
	(243, 1, 0, -50944, 1294, 0, 0, 39, '1293'),
	(243, 1, 0, -50944, 1295, 0, 0, 39, '1294'),
	(243, 1, 0, -50944, 1296, 0, 0, 39, '1295'),
	(243, 1, 0, -50944, 1297, 0, 0, 39, '1296'),
	(243, 1, 0, -50944, 1298, 0, 0, 39, '1297'),
	(243, 1, 0, -50944, 1299, 0, 0, 39, '1298'),
	(243, 1, 0, -50944, 1300, 0, 0, 39, '1299'),
	(243, 1, 0, -50944, 1301, 0, 0, 39, '1300'),
	(243, 1, 0, -50944, 1302, 0, 0, 39, '1301'),
	(243, 1, 0, -50944, 1303, 0, 0, 39, '1302'),
	(243, 1, 0, -50944, 1304, 0, 0, 39, '1303'),
	(243, 1, 0, -50944, 1305, 0, 0, 39, '1304'),
	(243, 1, 0, -50944, 1306, 0, 0, 39, '1305'),
	(243, 1, 0, -50944, 1307, 0, 0, 39, '1306'),
	(243, 1, 0, -50944, 1308, 0, 0, 39, '1307'),
	(243, 1, 0, -50944, 1309, 0, 0, 39, '1308'),
	(243, 1, 0, -50944, 1310, 0, 0, 39, '1309'),
	(243, 1, 0, -50944, 1311, 0, 0, 39, '1310'),
	(243, 1, 0, -50944, 1312, 0, 0, 39, '1311'),
	(243, 1, 0, -50944, 1313, 0, 0, 39, '1312'),
	(243, 1, 0, -50944, 1314, 0, 0, 39, '1313'),
	(243, 1, 0, -50944, 1315, 0, 0, 39, '1314'),
	(243, 1, 0, -50944, 1316, 0, 0, 39, '1315'),
	(243, 1, 0, -50944, 1317, 0, 0, 39, '1316'),
	(243, 1, 0, -50944, 1318, 0, 0, 39, '1317'),
	(243, 1, 0, -50944, 1319, 0, 0, 39, '1318'),
	(243, 1, 0, -50944, 1320, 0, 0, 39, '1319'),
	(243, 1, 0, -50944, 1321, 0, 0, 39, '1320'),
	(243, 1, 0, -50944, 1322, 0, 0, 39, '1321'),
	(243, 1, 0, -50944, 1323, 0, 0, 39, '1322'),
	(243, 1, 0, -50944, 1324, 0, 0, 39, '1323'),
	(243, 1, 0, -50944, 1325, 0, 0, 39, '1324'),
	(243, 1, 0, -50944, 1326, 0, 0, 39, '1325'),
	(243, 1, 0, -50944, 1327, 0, 0, 39, '1326'),
	(243, 1, 0, -50944, 1328, 0, 0, 39, '1327'),
	(243, 1, 0, -50944, 1329, 0, 0, 39, '1328'),
	(243, 1, 0, -50944, 1330, 0, 0, 39, '1329'),
	(243, 1, 0, -50944, 1331, 0, 0, 39, '1330'),
	(243, 1, 0, -50944, 1332, 0, 0, 39, '1331'),
	(243, 1, 0, -50944, 1333, 0, 0, 39, '1332'),
	(243, 1, 0, -50944, 1334, 0, 0, 39, '1333'),
	(243, 1, 0, -50944, 1335, 0, 0, 39, '1334'),
	(243, 1, 0, -50944, 1336, 0, 0, 39, '1335'),
	(243, 1, 0, -50944, 1337, 0, 0, 39, '1336'),
	(243, 1, 0, -50944, 1338, 0, 0, 39, '1337'),
	(243, 1, 0, -50944, 1339, 0, 0, 39, '1338'),
	(243, 1, 0, -50944, 1340, 0, 0, 39, '1339'),
	(243, 1, 0, -50944, 1341, 0, 0, 39, '1340'),
	(243, 1, 0, -50944, 1342, 0, 0, 39, '1341'),
	(243, 1, 0, -50944, 1343, 0, 0, 39, '1342'),
	(243, 1, 0, -50944, 1344, 0, 0, 39, '1343'),
	(243, 1, 0, -50944, 1345, 0, 0, 39, '1344'),
	(243, 1, 0, -50944, 1346, 0, 0, 39, '1345'),
	(243, 1, 0, -50944, 1347, 0, 0, 39, '1346'),
	(243, 1, 0, -50944, 1348, 0, 0, 39, '1347'),
	(243, 1, 0, -50944, 1349, 0, 0, 39, '1348'),
	(243, 1, 0, -50944, 1350, 0, 0, 39, '1349'),
	(243, 1, 0, -50944, 1351, 0, 0, 39, '1350'),
	(243, 1, 0, -50944, 1352, 0, 0, 39, '1351'),
	(243, 1, 0, -50944, 1353, 0, 0, 39, '1352'),
	(243, 1, 0, -50944, 1354, 0, 0, 39, '1353'),
	(243, 1, 0, -50944, 1355, 0, 0, 39, '1354'),
	(243, 1, 0, -50944, 1356, 0, 0, 39, '1355'),
	(243, 1, 0, -50944, 1357, 0, 0, 39, '1356'),
	(243, 1, 0, -50944, 1358, 0, 0, 39, '1357'),
	(243, 1, 0, -50944, 1359, 0, 0, 39, '1358'),
	(243, 1, 0, -50944, 1360, 0, 0, 39, '1359'),
	(243, 1, 0, -50944, 1361, 0, 0, 39, '1360'),
	(243, 1, 0, -50944, 1362, 0, 0, 39, '1361'),
	(243, 1, 0, -50944, 1363, 0, 0, 39, '1362'),
	(243, 1, 0, -50944, 1364, 0, 0, 39, '1363'),
	(243, 1, 0, -50944, 1365, 0, 0, 39, '1364'),
	(243, 1, 0, -50944, 1366, 0, 0, 39, '1365'),
	(243, 1, 0, -50944, 1367, 0, 0, 39, '1366'),
	(243, 1, 0, -50944, 1368, 0, 0, 39, '1367'),
	(243, 1, 0, -50944, 1369, 0, 0, 39, '1368'),
	(243, 1, 0, -50944, 1370, 0, 0, 39, '1369'),
	(243, 1, 0, -50944, 1371, 0, 0, 39, '1370'),
	(243, 1, 0, -50944, 1372, 0, 0, 39, '1371'),
	(243, 1, 0, -50944, 1373, 0, 0, 39, '1372'),
	(243, 1, 0, -50944, 1374, 0, 0, 39, '1373'),
	(243, 1, 0, -50944, 1375, 0, 0, 39, '1374'),
	(243, 1, 0, -50944, 1376, 0, 0, 39, '1375'),
	(243, 1, 0, -50944, 1377, 0, 0, 39, '1376'),
	(243, 1, 0, -50944, 1378, 0, 0, 39, '1377'),
	(243, 1, 0, -50944, 1379, 0, 0, 39, '1378'),
	(243, 1, 0, -50944, 1380, 0, 0, 39, '1379'),
	(243, 1, 0, -50944, 1381, 0, 0, 39, '1380'),
	(243, 1, 0, -50944, 1382, 0, 0, 39, '1381'),
	(243, 1, 0, -50944, 1383, 0, 0, 39, '1382'),
	(243, 1, 0, -50944, 1384, 0, 0, 39, '1383'),
	(243, 1, 0, -50944, 1385, 0, 0, 39, '1384'),
	(243, 1, 0, -50944, 1386, 0, 0, 39, '1385'),
	(243, 1, 0, -50944, 1387, 0, 0, 39, '1386'),
	(243, 1, 0, -50944, 1388, 0, 0, 39, '1387'),
	(243, 1, 0, -50944, 1389, 0, 0, 39, '1388'),
	(243, 1, 0, -50944, 1390, 0, 0, 39, '1389'),
	(243, 1, 0, -50944, 1391, 0, 0, 39, '1390'),
	(243, 1, 0, -50944, 1392, 0, 0, 39, '1391'),
	(243, 1, 0, -50944, 1393, 0, 0, 39, '1392'),
	(243, 1, 0, -50944, 1394, 0, 0, 39, '1393'),
	(243, 1, 0, -50944, 1395, 0, 0, 39, '1394'),
	(243, 1, 0, -50944, 1396, 0, 0, 39, '1395'),
	(243, 1, 0, -50944, 1397, 0, 0, 39, '1396'),
	(243, 1, 0, -50944, 1398, 0, 0, 39, '1397'),
	(243, 1, 0, -50944, 1399, 0, 0, 39, '1398'),
	(243, 1, 0, -50944, 1400, 0, 0, 39, '1399'),
	(243, 1, 0, -50944, 1401, 0, 0, 39, '1400'),
	(243, 1, 0, -50944, 1402, 0, 0, 39, '1401'),
	(243, 1, 0, -50944, 1403, 0, 0, 39, '1402'),
	(243, 1, 0, -50944, 1404, 0, 0, 39, '1403'),
	(243, 1, 0, -50944, 1405, 0, 0, 39, '1404'),
	(243, 1, 0, -50944, 1406, 0, 0, 39, '1405'),
	(243, 1, 0, -50944, 1407, 0, 0, 39, '1406'),
	(243, 1, 0, -50944, 1408, 0, 0, 39, '1407'),
	(243, 1, 0, -50944, 1409, 0, 0, 39, '1408'),
	(243, 1, 0, -50944, 1410, 0, 0, 39, '1409'),
	(243, 1, 0, -50944, 1411, 0, 0, 39, '1410'),
	(243, 1, 0, -50944, 1412, 0, 0, 39, '1411'),
	(243, 1, 0, -50944, 1413, 0, 0, 39, '1412'),
	(243, 1, 0, -50944, 1414, 0, 0, 39, '1413'),
	(243, 1, 0, -50944, 1415, 0, 0, 39, '1414'),
	(243, 1, 0, -50944, 1416, 0, 0, 39, '1415'),
	(243, 1, 0, -50944, 1417, 0, 0, 39, '1416'),
	(243, 1, 0, -50944, 1418, 0, 0, 39, '1417'),
	(243, 1, 0, -50944, 1419, 0, 0, 39, '1418'),
	(243, 1, 0, -50944, 1420, 0, 0, 39, '1419'),
	(243, 1, 0, -50944, 1421, 0, 0, 39, '1420'),
	(243, 1, 0, -50944, 1422, 0, 0, 39, '1421'),
	(243, 1, 0, -50944, 1423, 0, 0, 39, '1422'),
	(243, 1, 0, -50944, 1424, 0, 0, 39, '1423'),
	(243, 1, 0, -50944, 1425, 0, 0, 39, '1424'),
	(243, 1, 0, -50944, 1426, 0, 0, 39, '1425'),
	(243, 1, 0, -50944, 1427, 0, 0, 39, '1426'),
	(243, 1, 0, -50944, 1428, 0, 0, 39, '1427'),
	(243, 1, 0, -50944, 1429, 0, 0, 39, '1428'),
	(243, 1, 0, -50944, 1430, 0, 0, 39, '1429'),
	(243, 1, 0, -50944, 1431, 0, 0, 39, '1430'),
	(243, 1, 0, -50944, 1432, 0, 0, 39, '1431'),
	(243, 1, 0, -50944, 1433, 0, 0, 39, '1432'),
	(243, 1, 0, -50944, 1434, 0, 0, 39, '1433'),
	(243, 1, 0, -50944, 1435, 0, 0, 39, '1434'),
	(243, 1, 0, -50944, 1436, 0, 0, 39, '1435'),
	(243, 1, 0, -50944, 1437, 0, 0, 39, '1436'),
	(243, 1, 0, -50944, 1438, 0, 0, 39, '1437'),
	(243, 1, 0, -50944, 1439, 0, 0, 39, '1438'),
	(243, 1, 0, -50944, 1440, 0, 0, 39, '1439'),
	(243, 1, 0, -50944, 1441, 0, 0, 39, '1440'),
	(243, 1, 0, -50944, 1442, 0, 0, 39, '1441'),
	(243, 1, 0, -50944, 1443, 0, 0, 39, '1442'),
	(243, 1, 0, -50944, 1444, 0, 0, 39, '1443'),
	(243, 1, 0, -50944, 1445, 0, 0, 39, '1444'),
	(243, 1, 0, -50944, 1446, 0, 0, 39, '1445'),
	(243, 1, 0, -50944, 1447, 0, 0, 39, '1446'),
	(243, 1, 0, -50944, 1448, 0, 0, 39, '1447'),
	(243, 1, 0, -50944, 1449, 0, 0, 39, '1448'),
	(243, 1, 0, -50944, 1450, 0, 0, 39, '1449'),
	(243, 1, 0, -50944, 1451, 0, 0, 39, '1450'),
	(243, 1, 0, -50944, 1452, 0, 0, 39, '1451'),
	(243, 1, 0, -50944, 1453, 0, 0, 39, '1452'),
	(243, 1, 0, -50944, 1454, 0, 0, 39, '1453'),
	(243, 1, 0, -50944, 1455, 0, 0, 39, '1454'),
	(243, 1, 0, -50944, 1456, 0, 0, 39, '1455'),
	(243, 1, 0, -50944, 1457, 0, 0, 39, '1456'),
	(243, 1, 0, -50944, 1458, 0, 0, 39, '1457'),
	(243, 1, 0, -50944, 1459, 0, 0, 39, '1458'),
	(243, 1, 0, -50944, 1460, 0, 0, 39, '1459'),
	(243, 1, 0, -50944, 1461, 0, 0, 39, '1460'),
	(243, 1, 0, -50944, 1462, 0, 0, 39, '1461'),
	(243, 1, 0, -50944, 1463, 0, 0, 39, '1462'),
	(243, 1, 0, -50944, 1464, 0, 0, 39, '1463'),
	(243, 1, 0, -50944, 1465, 0, 0, 39, '1464'),
	(243, 1, 0, -50944, 1466, 0, 0, 39, '1465'),
	(243, 1, 0, -50944, 1467, 0, 0, 39, '1466'),
	(243, 1, 0, -50944, 1468, 0, 0, 39, '1467'),
	(243, 1, 0, -50944, 1469, 0, 0, 39, '1468'),
	(243, 1, 0, -50944, 1470, 0, 0, 39, '1469'),
	(243, 1, 0, -50944, 1471, 0, 0, 39, '1470'),
	(243, 1, 0, -50944, 1472, 0, 0, 39, '1471'),
	(243, 1, 0, -50944, 1473, 0, 0, 39, '1472'),
	(243, 1, 0, -50944, 1474, 0, 0, 39, '1473'),
	(243, 1, 0, -50944, 1475, 0, 0, 39, '1474'),
	(243, 1, 0, -50944, 1476, 0, 0, 39, '1475'),
	(243, 1, 0, -50944, 1477, 0, 0, 39, '1476'),
	(243, 1, 0, -50944, 1478, 0, 0, 39, '1477'),
	(243, 1, 0, -50944, 1479, 0, 0, 39, '1478'),
	(243, 1, 0, -50944, 1480, 0, 0, 39, '1479'),
	(243, 1, 0, -50944, 1481, 0, 0, 39, '1480'),
	(243, 1, 0, -50944, 1482, 0, 0, 39, '1481'),
	(243, 1, 0, -50944, 1483, 0, 0, 39, '1482'),
	(243, 1, 0, -50944, 1484, 0, 0, 39, '1483'),
	(243, 1, 0, -50944, 1485, 0, 0, 39, '1484'),
	(243, 1, 0, -50944, 1486, 0, 0, 39, '1485'),
	(243, 1, 0, -50944, 1487, 0, 0, 39, '1486'),
	(243, 1, 0, -50944, 1488, 0, 0, 39, '1487'),
	(243, 1, 0, -50944, 1489, 0, 0, 39, '1488'),
	(243, 1, 0, -50944, 1490, 0, 0, 39, '1489'),
	(243, 1, 0, -50944, 1491, 0, 0, 39, '1490'),
	(243, 1, 0, -50944, 1492, 0, 0, 39, '1491'),
	(243, 1, 0, -50944, 1493, 0, 0, 39, '1492'),
	(243, 1, 0, -50944, 1494, 0, 0, 39, '1493'),
	(243, 1, 0, -50944, 1495, 0, 0, 39, '1494'),
	(243, 1, 0, -50944, 1496, 0, 0, 39, '1495'),
	(243, 1, 0, -50944, 1497, 0, 0, 39, '1496'),
	(243, 1, 0, -50944, 1498, 0, 0, 39, '1497'),
	(243, 1, 0, -50944, 1499, 0, 0, 39, '1498'),
	(243, 1, 0, -50944, 1500, 0, 0, 39, '1499'),
	(243, 1, 0, -50944, 1501, 0, 0, 39, '1500'),
	(243, 1, 0, -50944, 1502, 0, 0, 39, '1501'),
	(243, 1, 0, -50944, 1503, 0, 0, 39, '1502'),
	(243, 1, 0, -50944, 1504, 0, 0, 39, '1503'),
	(243, 1, 0, -50944, 1505, 0, 0, 39, '1504'),
	(243, 1, 0, -50944, 1506, 0, 0, 39, '1505'),
	(243, 1, 0, -50944, 1507, 0, 0, 39, '1506'),
	(243, 1, 0, -50944, 1508, 0, 0, 39, '1507'),
	(243, 1, 0, -50944, 1509, 0, 0, 39, '1508'),
	(243, 1, 0, -50944, 1510, 0, 0, 39, '1509'),
	(243, 1, 0, -50944, 1511, 0, 0, 39, '1510'),
	(243, 1, 0, -50944, 1512, 0, 0, 39, '1511'),
	(243, 1, 0, -50944, 1513, 0, 0, 39, '1512'),
	(243, 1, 0, -50944, 1514, 0, 0, 39, '1513'),
	(243, 1, 0, -50944, 1515, 0, 0, 39, '1514'),
	(243, 1, 0, -50944, 1516, 0, 0, 39, '1515'),
	(243, 1, 0, -50944, 1517, 0, 0, 39, '1516'),
	(243, 1, 0, -50944, 1518, 0, 0, 39, '1517'),
	(243, 1, 0, -50944, 1519, 0, 0, 39, '1518'),
	(243, 1, 0, -50944, 1520, 0, 0, 39, '1519'),
	(243, 1, 0, -50944, 1521, 0, 0, 39, '1520'),
	(243, 1, 0, -50944, 1522, 0, 0, 39, '1521'),
	(243, 1, 0, -50944, 1523, 0, 0, 39, '1522'),
	(243, 1, 0, -50944, 1524, 0, 0, 39, '1523'),
	(243, 1, 0, -50944, 1525, 0, 0, 39, '1524'),
	(243, 1, 0, -50944, 1526, 0, 0, 39, '1525'),
	(243, 1, 0, -50944, 1527, 0, 0, 39, '1526'),
	(243, 1, 0, -50944, 1528, 0, 0, 39, '1527'),
	(243, 1, 0, -50944, 1529, 0, 0, 39, '1528'),
	(243, 1, 0, -50944, 1530, 0, 0, 39, '1529'),
	(243, 1, 0, -50944, 1531, 0, 0, 39, '1530'),
	(243, 1, 0, -50944, 1532, 0, 0, 39, '1531'),
	(243, 1, 0, -50944, 1533, 0, 0, 39, '1532'),
	(243, 1, 0, -50944, 1534, 0, 0, 39, '1533'),
	(243, 1, 0, -50944, 1535, 0, 0, 39, '1534'),
	(243, 1, 0, -50944, 1536, 0, 0, 39, '1535'),
	(243, 1, 0, -50944, 1537, 0, 0, 39, '1536'),
	(243, 1, 0, -50944, 1538, 0, 0, 39, '1537'),
	(243, 1, 0, -50944, 1539, 0, 0, 39, '1538'),
	(243, 1, 0, -50944, 1540, 0, 0, 39, '1539'),
	(243, 1, 0, -50944, 1541, 0, 0, 39, '1540'),
	(243, 1, 0, -50944, 1542, 0, 0, 39, '1541'),
	(243, 1, 0, -50944, 1543, 0, 0, 39, '1542'),
	(243, 1, 0, -50944, 1544, 0, 0, 39, '1543'),
	(243, 1, 0, -50944, 1545, 0, 0, 39, '1544'),
	(243, 1, 0, -50944, 1546, 0, 0, 39, '1545'),
	(243, 1, 0, -50944, 1547, 0, 0, 39, '1546'),
	(243, 1, 0, -50944, 1548, 0, 0, 39, '1547'),
	(243, 1, 0, -50944, 1549, 0, 0, 39, '1548'),
	(243, 1, 0, -50944, 1550, 0, 0, 39, '1549'),
	(243, 1, 0, -50944, 1551, 0, 0, 39, '1550'),
	(243, 1, 0, -50944, 1552, 0, 0, 39, '1551'),
	(243, 1, 0, -50944, 1553, 0, 0, 39, '1552'),
	(243, 1, 0, -50944, 1554, 0, 0, 39, '1553'),
	(243, 1, 0, -50944, 1555, 0, 0, 39, '1554'),
	(243, 1, 0, -50944, 1556, 0, 0, 39, '1555'),
	(243, 1, 0, -50944, 1557, 0, 0, 39, '1556'),
	(243, 1, 0, -50944, 1558, 0, 0, 39, '1557'),
	(243, 1, 0, -50944, 1559, 0, 0, 39, '1558'),
	(243, 1, 0, -50944, 1560, 0, 0, 39, '1559'),
	(243, 1, 0, -50944, 1561, 0, 0, 39, '1560'),
	(243, 1, 0, -50944, 1562, 0, 0, 39, '1561'),
	(243, 1, 0, -50944, 1563, 0, 0, 39, '1562'),
	(243, 1, 0, -50944, 1564, 0, 0, 39, '1563'),
	(243, 1, 0, -50944, 1565, 0, 0, 39, '1564'),
	(243, 1, 0, -50944, 1566, 0, 0, 39, '1565'),
	(243, 1, 0, -50944, 1567, 0, 0, 39, '1566'),
	(243, 1, 0, -50944, 1568, 0, 0, 39, '1567'),
	(243, 1, 0, -50944, 1569, 0, 0, 39, '1568'),
	(243, 1, 0, -50944, 1570, 0, 0, 39, '1569'),
	(243, 1, 0, -50944, 1571, 0, 0, 39, '1570'),
	(243, 1, 0, -50944, 1572, 0, 0, 39, '1571'),
	(243, 1, 0, -50944, 1573, 0, 0, 39, '1572'),
	(243, 1, 0, -50944, 1574, 0, 0, 39, '1573'),
	(243, 1, 0, -50944, 1575, 0, 0, 39, '1574'),
	(243, 1, 0, -50944, 1576, 0, 0, 39, '1575'),
	(243, 1, 0, -50944, 1577, 0, 0, 39, '1576'),
	(243, 1, 0, -50944, 1578, 0, 0, 39, '1577'),
	(243, 1, 0, -50944, 1579, 0, 0, 39, '1578'),
	(243, 1, 0, -50944, 1580, 0, 0, 39, '1579'),
	(243, 1, 0, -50944, 1581, 0, 0, 39, '1580'),
	(243, 1, 0, -50944, 1582, 0, 0, 39, '1581'),
	(243, 1, 0, -50944, 1583, 0, 0, 39, '1582'),
	(243, 1, 0, -50944, 1584, 0, 0, 39, '1583'),
	(243, 1, 0, -50944, 1585, 0, 0, 39, '1584'),
	(243, 1, 0, -50944, 1586, 0, 0, 39, '1585'),
	(243, 1, 0, -50944, 1587, 0, 0, 39, '1586'),
	(243, 1, 0, -50944, 1588, 0, 0, 39, '1587'),
	(243, 1, 0, -50944, 1589, 0, 0, 39, '1588'),
	(243, 1, 0, -50944, 1590, 0, 0, 39, '1589'),
	(243, 1, 0, -50944, 1591, 0, 0, 39, '1590'),
	(243, 1, 0, -50944, 1592, 0, 0, 39, '1591'),
	(243, 1, 0, -50944, 1593, 0, 0, 39, '1592'),
	(243, 1, 0, -50944, 1594, 0, 0, 39, '1593'),
	(243, 1, 0, -50944, 1595, 0, 0, 39, '1594'),
	(243, 1, 0, -50944, 1596, 0, 0, 39, '1595'),
	(243, 1, 0, -50944, 1597, 0, 0, 39, '1596'),
	(243, 1, 0, -50944, 1598, 0, 0, 39, '1597'),
	(243, 1, 0, -50944, 1599, 0, 0, 39, '1598'),
	(243, 1, 0, -50944, 1600, 0, 0, 39, '1599'),
	(243, 1, 0, -50944, 1601, 0, 0, 39, '1600'),
	(243, 1, 0, -50944, 1602, 0, 0, 39, '1601'),
	(243, 1, 0, -50944, 1603, 0, 0, 39, '1602'),
	(243, 1, 0, -50944, 1604, 0, 0, 39, '1603'),
	(243, 1, 0, -50944, 1605, 0, 0, 39, '1604'),
	(243, 1, 0, -50944, 1606, 0, 0, 39, '1605'),
	(243, 1, 0, -50944, 1607, 0, 0, 39, '1606'),
	(243, 1, 0, -50944, 1608, 0, 0, 39, '1607'),
	(243, 1, 0, -50944, 1609, 0, 0, 39, '1608'),
	(243, 1, 0, -50944, 1610, 0, 0, 39, '1609'),
	(243, 1, 0, -50944, 1611, 0, 0, 39, '1610'),
	(243, 1, 0, -50944, 1612, 0, 0, 39, '1611'),
	(243, 1, 0, -50944, 1613, 0, 0, 39, '1612'),
	(243, 1, 0, -50944, 1614, 0, 0, 39, '1613'),
	(243, 1, 0, -50944, 1615, 0, 0, 39, '1614'),
	(243, 1, 0, -50944, 1616, 0, 0, 39, '1615'),
	(243, 1, 0, -50944, 1617, 0, 0, 39, '1616'),
	(243, 1, 0, -50944, 1618, 0, 0, 39, '1617'),
	(243, 1, 0, -50944, 1619, 0, 0, 39, '1618'),
	(243, 1, 0, -50944, 1620, 0, 0, 39, '1619'),
	(243, 1, 0, -50944, 1621, 0, 0, 39, '1620'),
	(243, 1, 0, -50944, 1622, 0, 0, 39, '1621'),
	(243, 1, 0, -50944, 1623, 0, 0, 39, '1622'),
	(243, 1, 0, -50944, 1624, 0, 0, 39, '1623'),
	(243, 1, 0, -50944, 1625, 0, 0, 39, '1624'),
	(243, 1, 0, -50944, 1626, 0, 0, 39, '1625'),
	(243, 1, 0, -50944, 1627, 0, 0, 39, '1626'),
	(243, 1, 0, -50944, 1628, 0, 0, 39, '1627'),
	(243, 1, 0, -50944, 1629, 0, 0, 39, '1628'),
	(243, 1, 0, -50944, 1630, 0, 0, 39, '1629'),
	(243, 1, 0, -50944, 1631, 0, 0, 39, '1630'),
	(243, 1, 0, -50944, 1632, 0, 0, 39, '1631'),
	(243, 1, 0, -50944, 1633, 0, 0, 39, '1632'),
	(243, 1, 0, -50944, 1634, 0, 0, 39, '1633'),
	(243, 1, 0, -50944, 1635, 0, 0, 39, '1634'),
	(243, 1, 0, -50944, 1636, 0, 0, 39, '1635'),
	(243, 1, 0, -50944, 1637, 0, 0, 39, '1636'),
	(243, 1, 0, -50944, 1638, 0, 0, 39, '1637'),
	(243, 1, 0, -50944, 1639, 0, 0, 39, '1638'),
	(243, 1, 0, -50944, 1640, 0, 0, 39, '1639'),
	(243, 1, 0, -50944, 1641, 0, 0, 39, '1640'),
	(243, 1, 0, -50944, 1642, 0, 0, 39, '1641'),
	(243, 1, 0, -50944, 1643, 0, 0, 39, '1642'),
	(243, 1, 0, -50944, 1644, 0, 0, 39, '1643'),
	(243, 1, 0, -50944, 1645, 0, 0, 39, '1644'),
	(243, 1, 0, -50944, 1646, 0, 0, 39, '1645'),
	(243, 1, 0, -50944, 1647, 0, 0, 39, '1646'),
	(243, 1, 0, -50944, 1648, 0, 0, 39, '1647'),
	(243, 1, 0, -50944, 1649, 0, 0, 39, '1648'),
	(243, 1, 0, -50944, 1650, 0, 0, 39, '1649'),
	(243, 1, 0, -50944, 1651, 0, 0, 39, '1650'),
	(243, 1, 0, -50944, 1652, 0, 0, 39, '1651'),
	(243, 1, 0, -50944, 1653, 0, 0, 39, '1652'),
	(243, 1, 0, -50944, 1654, 0, 0, 39, '1653'),
	(243, 1, 0, -50944, 1655, 0, 0, 39, '1654'),
	(243, 1, 0, -50944, 1656, 0, 0, 39, '1655'),
	(243, 1, 0, -50944, 1657, 0, 0, 39, '1656'),
	(243, 1, 0, -50944, 1658, 0, 0, 39, '1657'),
	(243, 1, 0, -50944, 1659, 0, 0, 39, '1658'),
	(243, 1, 0, -50944, 1660, 0, 0, 39, '1659'),
	(243, 1, 0, -50944, 1661, 0, 0, 39, '1660'),
	(243, 1, 0, -50944, 1662, 0, 0, 39, '1661'),
	(243, 1, 0, -50944, 1663, 0, 0, 39, '1662'),
	(243, 1, 0, -50944, 1664, 0, 0, 39, '1663'),
	(243, 1, 0, -50944, 1665, 0, 0, 39, '1664'),
	(243, 1, 0, -50944, 1666, 0, 0, 39, '1665'),
	(243, 1, 0, -50944, 1667, 0, 0, 39, '1666'),
	(243, 1, 0, -50944, 1668, 0, 0, 39, '1667'),
	(243, 1, 0, -50944, 1669, 0, 0, 39, '1668'),
	(243, 1, 0, -50944, 1670, 0, 0, 39, '1669'),
	(243, 1, 0, -50944, 1671, 0, 0, 39, '1670'),
	(243, 1, 0, -50944, 1672, 0, 0, 39, '1671'),
	(243, 1, 0, -50944, 1673, 0, 0, 39, '1672'),
	(243, 1, 0, -50944, 1674, 0, 0, 39, '1673'),
	(243, 1, 0, -50944, 1675, 0, 0, 39, '1674'),
	(243, 1, 0, -50944, 1676, 0, 0, 39, '1675'),
	(243, 1, 0, -50944, 1677, 0, 0, 39, '1676'),
	(243, 1, 0, -50944, 1678, 0, 0, 39, '1677'),
	(243, 1, 0, -50944, 1679, 0, 0, 39, '1678'),
	(243, 1, 0, -50944, 1680, 0, 0, 39, '1679'),
	(243, 1, 0, -50944, 1681, 0, 0, 39, '1680'),
	(243, 1, 0, -50944, 1682, 0, 0, 39, '1681'),
	(243, 1, 0, -50944, 1683, 0, 0, 39, '1682'),
	(243, 1, 0, -50944, 1684, 0, 0, 39, '1683'),
	(243, 1, 0, -50944, 1685, 0, 0, 39, '1684'),
	(243, 1, 0, -50944, 1686, 0, 0, 39, '1685'),
	(243, 1, 0, -50944, 1687, 0, 0, 39, '1686'),
	(243, 1, 0, -50944, 1688, 0, 0, 39, '1687'),
	(243, 1, 0, -50944, 1689, 0, 0, 39, '1688'),
	(243, 1, 0, -50944, 1690, 0, 0, 39, '1689'),
	(243, 1, 0, -50944, 1691, 0, 0, 39, '1690'),
	(243, 1, 0, -50944, 1692, 0, 0, 39, '1691'),
	(243, 1, 0, -50944, 1693, 0, 0, 39, '1692'),
	(243, 1, 0, -50944, 1694, 0, 0, 39, '1693'),
	(243, 1, 0, -50944, 1695, 0, 0, 39, '1694'),
	(243, 1, 0, -50944, 1696, 0, 0, 39, '1695'),
	(243, 1, 0, -50944, 1697, 0, 0, 39, '1696'),
	(243, 1, 0, -50944, 1698, 0, 0, 39, '1697'),
	(243, 1, 0, -50944, 1699, 0, 0, 39, '1698'),
	(243, 1, 0, -50944, 1700, 0, 0, 39, '1699'),
	(243, 1, 0, -50944, 1701, 0, 0, 39, '1700'),
	(243, 1, 0, -50944, 1702, 0, 0, 39, '1701'),
	(243, 1, 0, -50944, 1703, 0, 0, 39, '1702'),
	(243, 1, 0, -50944, 1704, 0, 0, 39, '1703'),
	(243, 1, 0, -50944, 1705, 0, 0, 39, '1704'),
	(243, 1, 0, -50944, 1706, 0, 0, 39, '1705'),
	(243, 1, 0, -50944, 1707, 0, 0, 39, '1706'),
	(243, 1, 0, -50944, 1708, 0, 0, 39, '1707'),
	(243, 1, 0, -50944, 1709, 0, 0, 39, '1708'),
	(243, 1, 0, -50944, 1710, 0, 0, 39, '1709'),
	(243, 1, 0, -50944, 1711, 0, 0, 39, '1710'),
	(243, 1, 0, -50944, 1712, 0, 0, 39, '1711'),
	(243, 1, 0, -50944, 1713, 0, 0, 39, '1712'),
	(243, 1, 0, -50944, 1714, 0, 0, 39, '1713'),
	(243, 1, 0, -50944, 1715, 0, 0, 39, '1714'),
	(243, 1, 0, -50944, 1716, 0, 0, 39, '1715'),
	(243, 1, 0, -50944, 1717, 0, 0, 39, '1716'),
	(243, 1, 0, -50944, 1718, 0, 0, 39, '1717'),
	(243, 1, 0, -50944, 1719, 0, 0, 39, '1718'),
	(243, 1, 0, -50944, 1720, 0, 0, 39, '1719'),
	(243, 1, 0, -50944, 1721, 0, 0, 39, '1720'),
	(243, 1, 0, -50944, 1722, 0, 0, 39, '1721'),
	(243, 1, 0, -50944, 1723, 0, 0, 39, '1722'),
	(243, 1, 0, -50944, 1724, 0, 0, 39, '1723'),
	(243, 1, 0, -50944, 1725, 0, 0, 39, '1724'),
	(243, 1, 0, -50944, 1726, 0, 0, 39, '1725'),
	(243, 1, 0, -50944, 1727, 0, 0, 39, '1726'),
	(243, 1, 0, -50944, 1728, 0, 0, 39, '1727'),
	(243, 1, 0, -50944, 1729, 0, 0, 39, '1728'),
	(243, 1, 0, -50944, 1730, 0, 0, 39, '1729'),
	(243, 1, 0, -50944, 1731, 0, 0, 39, '1730'),
	(243, 1, 0, -50944, 1732, 0, 0, 39, '1731'),
	(243, 1, 0, -50944, 1733, 0, 0, 39, '1732'),
	(243, 1, 0, -50944, 1734, 0, 0, 39, '1733'),
	(243, 1, 0, -50944, 1735, 0, 0, 39, '1734'),
	(243, 1, 0, -50944, 1736, 0, 0, 39, '1735'),
	(243, 1, 0, -50944, 1737, 0, 0, 39, '1736'),
	(243, 1, 0, -50944, 1738, 0, 0, 39, '1737'),
	(243, 1, 0, -50944, 1739, 0, 0, 39, '1738'),
	(243, 1, 0, -50944, 1740, 0, 0, 39, '1739'),
	(243, 1, 0, -50944, 1741, 0, 0, 39, '1740'),
	(243, 1, 0, -50944, 1742, 0, 0, 39, '1741'),
	(243, 1, 0, -50944, 1743, 0, 0, 39, '1742'),
	(243, 1, 0, -50944, 1744, 0, 0, 39, '1743'),
	(243, 1, 0, -50944, 1745, 0, 0, 39, '1744'),
	(243, 1, 0, -50944, 1746, 0, 0, 39, '1745'),
	(243, 1, 0, -50944, 1747, 0, 0, 39, '1746'),
	(243, 1, 0, -50944, 1748, 0, 0, 39, '1747'),
	(243, 1, 0, -50944, 1749, 0, 0, 39, '1748'),
	(243, 1, 0, -50944, 1750, 0, 0, 39, '1749'),
	(243, 1, 0, -50944, 1751, 0, 0, 39, '1750'),
	(243, 1, 0, -50944, 1752, 0, 0, 39, '1751'),
	(243, 1, 0, -50944, 1753, 0, 0, 39, '1752'),
	(243, 1, 0, -50944, 1754, 0, 0, 39, '1753'),
	(243, 1, 0, -50944, 1755, 0, 0, 39, '1754'),
	(243, 1, 0, -50944, 1756, 0, 0, 39, '1755'),
	(243, 1, 0, -50944, 1757, 0, 0, 39, '1756'),
	(243, 1, 0, -50944, 1758, 0, 0, 39, '1757'),
	(243, 1, 0, -50944, 1759, 0, 0, 39, '1758'),
	(243, 1, 0, -50944, 1760, 0, 0, 39, '1759'),
	(243, 1, 0, -50944, 1761, 0, 0, 39, '1760'),
	(243, 1, 0, -50944, 1762, 0, 0, 39, '1761'),
	(243, 1, 0, -50944, 1763, 0, 0, 39, '1762'),
	(243, 1, 0, -50944, 1764, 0, 0, 39, '1763'),
	(243, 1, 0, -50944, 1765, 0, 0, 39, '1764'),
	(243, 1, 0, -50944, 1766, 0, 0, 39, '1765'),
	(243, 1, 0, -50944, 1767, 0, 0, 39, '1766'),
	(243, 1, 0, -50944, 1768, 0, 0, 39, '1767'),
	(243, 1, 0, -50944, 1769, 0, 0, 39, '1768'),
	(243, 1, 0, -50944, 1770, 0, 0, 39, '1769'),
	(243, 1, 0, -50944, 1771, 0, 0, 39, '1770'),
	(243, 1, 0, -50944, 1772, 0, 0, 39, '1771'),
	(243, 1, 0, -50944, 1773, 0, 0, 39, '1772'),
	(243, 1, 0, -50944, 1774, 0, 0, 39, '1773'),
	(243, 1, 0, -50944, 1775, 0, 0, 39, '1774'),
	(243, 1, 0, -50944, 1776, 0, 0, 39, '1775'),
	(243, 1, 0, -50944, 1777, 0, 0, 39, '1776'),
	(243, 1, 0, -50944, 1778, 0, 0, 39, '1777'),
	(243, 1, 0, -50944, 1779, 0, 0, 39, '1778'),
	(243, 1, 0, -50944, 1780, 0, 0, 39, '1779'),
	(243, 1, 0, -50944, 1781, 0, 0, 39, '1780'),
	(243, 1, 0, -50944, 1782, 0, 0, 39, '1781'),
	(243, 1, 0, -50944, 1783, 0, 0, 39, '1782'),
	(243, 1, 0, -50944, 1784, 0, 0, 39, '1783'),
	(243, 1, 0, -50944, 1785, 0, 0, 39, '1784'),
	(243, 1, 0, -50944, 1786, 0, 0, 39, '1785'),
	(243, 1, 0, -50944, 1787, 0, 0, 39, '1786'),
	(243, 1, 0, -50944, 1788, 0, 0, 39, '1787'),
	(243, 1, 0, -50944, 1789, 0, 0, 39, '1788'),
	(243, 1, 0, -50944, 1790, 0, 0, 39, '1789'),
	(243, 1, 0, -50944, 1791, 0, 0, 39, '1790'),
	(243, 1, 0, -50944, 1792, 0, 0, 39, '1791'),
	(243, 1, 0, -50944, 1793, 0, 0, 39, '1792'),
	(243, 1, 0, -50944, 1794, 0, 0, 39, '1793'),
	(243, 1, 0, -50944, 1795, 0, 0, 39, '1794'),
	(243, 1, 0, -50944, 1796, 0, 0, 39, '1795'),
	(243, 1, 0, -50944, 1797, 0, 0, 39, '1796'),
	(243, 1, 0, -50944, 1798, 0, 0, 39, '1797'),
	(243, 1, 0, -50944, 1799, 0, 0, 39, '1798'),
	(243, 1, 0, -50944, 1800, 0, 0, 39, '1799'),
	(243, 1, 0, -50944, 1801, 0, 0, 39, '1800'),
	(243, 1, 0, -50944, 1802, 0, 0, 39, '1801'),
	(243, 1, 0, -50944, 1803, 0, 0, 39, '1802'),
	(243, 1, 0, -50944, 1804, 0, 0, 39, '1803'),
	(243, 1, 0, -50944, 1805, 0, 0, 39, '1804'),
	(243, 1, 0, -50944, 1806, 0, 0, 39, '1805'),
	(243, 1, 0, -50944, 1807, 0, 0, 39, '1806'),
	(243, 1, 0, -50944, 1808, 0, 0, 39, '1807'),
	(243, 1, 0, -50944, 1809, 0, 0, 39, '1808'),
	(243, 1, 0, -50944, 1810, 0, 0, 39, '1809'),
	(243, 1, 0, -50944, 1811, 0, 0, 39, '1810'),
	(243, 1, 0, -50944, 1812, 0, 0, 39, '1811'),
	(243, 1, 0, -50944, 1813, 0, 0, 39, '1812'),
	(243, 1, 0, -50944, 1814, 0, 0, 39, '1813'),
	(243, 1, 0, -50944, 1815, 0, 0, 39, '1814'),
	(243, 1, 0, -50944, 1816, 0, 0, 39, '1815'),
	(243, 1, 0, -50944, 1817, 0, 0, 39, '1816'),
	(243, 1, 0, -50944, 1818, 0, 0, 39, '1817'),
	(243, 1, 0, -50944, 1819, 0, 0, 39, '1818'),
	(243, 1, 0, -50944, 1820, 0, 0, 39, '1819'),
	(243, 1, 0, -50944, 1821, 0, 0, 39, '1820'),
	(243, 1, 0, -50944, 1822, 0, 0, 39, '1821'),
	(243, 1, 0, -50944, 1823, 0, 0, 39, '1822'),
	(243, 1, 0, -50944, 1824, 0, 0, 39, '1823'),
	(243, 1, 0, -50944, 1825, 0, 0, 39, '1824'),
	(243, 1, 0, -50944, 1826, 0, 0, 39, '1825'),
	(243, 1, 0, -50944, 1827, 0, 0, 39, '1826'),
	(243, 1, 0, -50944, 1828, 0, 0, 39, '1827'),
	(243, 1, 0, -50944, 1829, 0, 0, 39, '1828'),
	(243, 1, 0, -50944, 1830, 0, 0, 39, '1829'),
	(243, 1, 0, -50944, 1831, 0, 0, 39, '1830'),
	(243, 1, 0, -50944, 1832, 0, 0, 39, '1831'),
	(243, 1, 0, -50944, 1833, 0, 0, 39, '1832'),
	(243, 1, 0, -50944, 1834, 0, 0, 39, '1833'),
	(243, 1, 0, -50944, 1835, 0, 0, 39, '1834'),
	(243, 1, 0, -50944, 1836, 0, 0, 39, '1835'),
	(243, 1, 0, -50944, 1837, 0, 0, 39, '1836'),
	(243, 1, 0, -50944, 1838, 0, 0, 39, '1837'),
	(243, 1, 0, -50944, 1839, 0, 0, 39, '1838'),
	(243, 1, 0, -50944, 1840, 0, 0, 39, '1839'),
	(243, 1, 0, -50944, 1841, 0, 0, 39, '1840'),
	(243, 1, 0, -50944, 1842, 0, 0, 39, '1841'),
	(243, 1, 0, -50944, 1843, 0, 0, 39, '1842'),
	(243, 1, 0, -50944, 1844, 0, 0, 39, '1843'),
	(243, 1, 0, -50944, 1845, 0, 0, 39, '1844'),
	(243, 1, 0, -50944, 1846, 0, 0, 39, '1845'),
	(243, 1, 0, -50944, 1847, 0, 0, 39, '1846'),
	(243, 1, 0, -50944, 1848, 0, 0, 39, '1847'),
	(243, 1, 0, -50944, 1849, 0, 0, 39, '1848'),
	(243, 1, 0, -50944, 1850, 0, 0, 39, '1849'),
	(243, 1, 0, -50944, 1851, 0, 0, 39, '1850'),
	(243, 1, 0, -50944, 1852, 0, 0, 39, '1851'),
	(243, 1, 0, -50944, 1853, 0, 0, 39, '1852'),
	(243, 1, 0, -50944, 1854, 0, 0, 39, '1853'),
	(243, 1, 0, -50944, 1855, 0, 0, 39, '1854'),
	(243, 1, 0, -50944, 1856, 0, 0, 39, '1855'),
	(243, 1, 0, -50944, 1857, 0, 0, 39, '1856'),
	(243, 1, 0, -50944, 1858, 0, 0, 39, '1857'),
	(243, 1, 0, -50944, 1859, 0, 0, 39, '1858'),
	(243, 1, 0, -50944, 1860, 0, 0, 39, '1859'),
	(243, 1, 0, -50944, 1861, 0, 0, 39, '1860'),
	(243, 1, 0, -50944, 1862, 0, 0, 39, '1861'),
	(243, 1, 0, -50944, 1863, 0, 0, 39, '1862'),
	(243, 1, 0, -50944, 1864, 0, 0, 39, '1863'),
	(243, 1, 0, -50944, 1865, 0, 0, 39, '1864'),
	(243, 1, 0, -50944, 1866, 0, 0, 39, '1865'),
	(243, 1, 0, -50944, 1867, 0, 0, 39, '1866'),
	(243, 1, 0, -50944, 1868, 0, 0, 39, '1867'),
	(243, 1, 0, -50944, 1869, 0, 0, 39, '1868'),
	(243, 1, 0, -50944, 1870, 0, 0, 39, '1869'),
	(243, 1, 0, -50944, 1871, 0, 0, 39, '1870'),
	(243, 1, 0, -50944, 1872, 0, 0, 39, '1871'),
	(243, 1, 0, -50944, 1873, 0, 0, 39, '1872'),
	(243, 1, 0, -50944, 1874, 0, 0, 39, '1873'),
	(243, 1, 0, -50944, 1875, 0, 0, 39, '1874'),
	(243, 1, 0, -50944, 1876, 0, 0, 39, '1875'),
	(243, 1, 0, -50944, 1877, 0, 0, 39, '1876'),
	(243, 1, 0, -50944, 1878, 0, 0, 39, '1877'),
	(243, 1, 0, -50944, 1879, 0, 0, 39, '1878'),
	(243, 1, 0, -50944, 1880, 0, 0, 39, '1879'),
	(243, 1, 0, -50944, 1881, 0, 0, 39, '1880'),
	(243, 1, 0, -50944, 1882, 0, 0, 39, '1881'),
	(243, 1, 0, -50944, 1883, 0, 0, 39, '1882'),
	(243, 1, 0, -50944, 1884, 0, 0, 39, '1883'),
	(243, 1, 0, -50944, 1885, 0, 0, 39, '1884'),
	(243, 1, 0, -50944, 1886, 0, 0, 39, '1885'),
	(243, 1, 0, -50944, 1887, 0, 0, 39, '1886'),
	(243, 1, 0, -50944, 1888, 0, 0, 39, '1887'),
	(243, 1, 0, -50944, 1889, 0, 0, 39, '1888'),
	(243, 1, 0, -50944, 1890, 0, 0, 39, '1889'),
	(243, 1, 0, -50944, 1891, 0, 0, 39, '1890'),
	(243, 1, 0, -50944, 1892, 0, 0, 39, '1891'),
	(243, 1, 0, -50944, 1893, 0, 0, 39, '1892'),
	(243, 1, 0, -50944, 1894, 0, 0, 39, '1893'),
	(243, 1, 0, -50944, 1895, 0, 0, 39, '1894'),
	(243, 1, 0, -50944, 1896, 0, 0, 39, '1895'),
	(243, 1, 0, -50944, 1897, 0, 0, 39, '1896'),
	(243, 1, 0, -50944, 1898, 0, 0, 39, '1897'),
	(243, 1, 0, -50944, 1899, 0, 0, 39, '1898'),
	(243, 1, 0, -50944, 1900, 0, 0, 39, '1899'),
	(243, 1, 0, -50944, 1901, 0, 0, 39, '1900'),
	(243, 1, 0, -50944, 1902, 0, 0, 39, '1901'),
	(243, 1, 0, -50944, 1903, 0, 0, 39, '1902'),
	(243, 1, 0, -50944, 1904, 0, 0, 39, '1903'),
	(243, 1, 0, -50944, 1905, 0, 0, 39, '1904'),
	(243, 1, 0, -50944, 1906, 0, 0, 39, '1905'),
	(243, 1, 0, -50944, 1907, 0, 0, 39, '1906'),
	(243, 1, 0, -50944, 1908, 0, 0, 39, '1907'),
	(243, 1, 0, -50944, 1909, 0, 0, 39, '1908'),
	(243, 1, 0, -50944, 1910, 0, 0, 39, '1909'),
	(243, 1, 0, -50944, 1911, 0, 0, 39, '1910'),
	(243, 1, 0, -50944, 1912, 0, 0, 39, '1911'),
	(243, 1, 0, -50944, 1913, 0, 0, 39, '1912'),
	(243, 1, 0, -50944, 1914, 0, 0, 39, '1913'),
	(243, 1, 0, -50944, 1915, 0, 0, 39, '1914'),
	(243, 1, 0, -50944, 1916, 0, 0, 39, '1915'),
	(243, 1, 0, -50944, 1917, 0, 0, 39, '1916'),
	(243, 1, 0, -50944, 1918, 0, 0, 39, '1917'),
	(243, 1, 0, -50944, 1919, 0, 0, 39, '1918'),
	(243, 1, 0, -50944, 1920, 0, 0, 39, '1919'),
	(243, 1, 0, -50944, 1921, 0, 0, 39, '1920'),
	(243, 1, 0, -50944, 1922, 0, 0, 39, '1921'),
	(243, 1, 0, -50944, 1923, 0, 0, 39, '1922'),
	(243, 1, 0, -50944, 1924, 0, 0, 39, '1923'),
	(243, 1, 0, -50944, 1925, 0, 0, 39, '1924'),
	(243, 1, 0, -50944, 1926, 0, 0, 39, '1925'),
	(243, 1, 0, -50944, 1927, 0, 0, 39, '1926'),
	(243, 1, 0, -50944, 1928, 0, 0, 39, '1927'),
	(243, 1, 0, -50944, 1929, 0, 0, 39, '1928'),
	(243, 1, 0, -50944, 1930, 0, 0, 39, '1929'),
	(243, 1, 0, -50944, 1931, 0, 0, 39, '1930'),
	(243, 1, 0, -50944, 1932, 0, 0, 39, '1931'),
	(243, 1, 0, -50944, 1933, 0, 0, 39, '1932'),
	(243, 1, 0, -50944, 1934, 0, 0, 39, '1933'),
	(243, 1, 0, -50944, 1935, 0, 0, 39, '1934'),
	(243, 1, 0, -50944, 1936, 0, 0, 39, '1935'),
	(243, 1, 0, -50944, 1937, 0, 0, 39, '1936'),
	(243, 1, 0, -50944, 1938, 0, 0, 39, '1937'),
	(243, 1, 0, -50944, 1939, 0, 0, 39, '1938'),
	(243, 1, 0, -50944, 1940, 0, 0, 39, '1939'),
	(243, 1, 0, -50944, 1941, 0, 0, 39, '1940'),
	(243, 1, 0, -50944, 1942, 0, 0, 39, '1941'),
	(243, 1, 0, -50944, 1943, 0, 0, 39, '1942'),
	(243, 1, 0, -50944, 1944, 0, 0, 39, '1943'),
	(243, 1, 0, -50944, 1945, 0, 0, 39, '1944'),
	(243, 1, 0, -50944, 1946, 0, 0, 39, '1945'),
	(243, 1, 0, -50944, 1947, 0, 0, 39, '1946'),
	(243, 1, 0, -50944, 1948, 0, 0, 39, '1947'),
	(243, 1, 0, -50944, 1949, 0, 0, 39, '1948'),
	(243, 1, 0, -50944, 1950, 0, 0, 39, '1949'),
	(243, 1, 0, -50944, 1951, 0, 0, 39, '1950'),
	(243, 1, 0, -50944, 1952, 0, 0, 39, '1951'),
	(243, 1, 0, -50944, 1953, 0, 0, 39, '1952'),
	(243, 1, 0, -50944, 1954, 0, 0, 39, '1953'),
	(243, 1, 0, -50944, 1955, 0, 0, 39, '1954'),
	(243, 1, 0, -50944, 1956, 0, 0, 39, '1955'),
	(243, 1, 0, -50944, 1957, 0, 0, 39, '1956'),
	(243, 1, 0, -50944, 1958, 0, 0, 39, '1957'),
	(243, 1, 0, -50944, 1959, 0, 0, 39, '1958'),
	(243, 1, 0, -50944, 1960, 0, 0, 39, '1959'),
	(243, 1, 0, -50944, 1961, 0, 0, 39, '1960'),
	(243, 1, 0, -50944, 1962, 0, 0, 39, '1961'),
	(243, 1, 0, -50944, 1963, 0, 0, 39, '1962'),
	(243, 1, 0, -50944, 1964, 0, 0, 39, '1963'),
	(243, 1, 0, -50944, 1965, 0, 0, 39, '1964'),
	(243, 1, 0, -50944, 1966, 0, 0, 39, '1965'),
	(243, 1, 0, -50944, 1967, 0, 0, 39, '1966'),
	(243, 1, 0, -50944, 1968, 0, 0, 39, '1967'),
	(243, 1, 0, -50944, 1969, 0, 0, 39, '1968'),
	(243, 1, 0, -50944, 1970, 0, 0, 39, '1969'),
	(243, 1, 0, -50944, 1971, 0, 0, 39, '1970'),
	(243, 1, 0, -50944, 1972, 0, 0, 39, '1971'),
	(243, 1, 0, -50944, 1973, 0, 0, 39, '1972'),
	(243, 1, 0, -50944, 1974, 0, 0, 39, '1973'),
	(243, 1, 0, -50944, 1975, 0, 0, 39, '1974'),
	(243, 1, 0, -50944, 1976, 0, 0, 39, '1975'),
	(243, 1, 0, -50944, 1977, 0, 0, 39, '1976'),
	(243, 1, 0, -50944, 1978, 0, 0, 39, '1977'),
	(243, 1, 0, -50944, 1979, 0, 0, 39, '1978'),
	(243, 1, 0, -50944, 1980, 0, 0, 39, '1979'),
	(243, 1, 0, -50944, 1981, 0, 0, 39, '1980'),
	(243, 1, 0, -50944, 1982, 0, 0, 39, '1981'),
	(243, 1, 0, -50944, 1983, 0, 0, 39, '1982'),
	(243, 1, 0, -50944, 1984, 0, 0, 39, '1983'),
	(243, 1, 0, -50944, 1985, 0, 0, 39, '1984'),
	(243, 1, 0, -50944, 1986, 0, 0, 39, '1985'),
	(243, 1, 0, -50944, 1987, 0, 0, 39, '1986'),
	(243, 1, 0, -50944, 1988, 0, 0, 39, '1987'),
	(243, 1, 0, -50944, 1989, 0, 0, 39, '1988'),
	(243, 1, 0, -50944, 1990, 0, 0, 39, '1989'),
	(243, 1, 0, -50944, 1991, 0, 0, 39, '1990'),
	(243, 1, 0, -50944, 1992, 0, 0, 39, '1991'),
	(243, 1, 0, -50944, 1993, 0, 0, 39, '1992'),
	(243, 1, 0, -50944, 1994, 0, 0, 39, '1993'),
	(243, 1, 0, -50944, 1995, 0, 0, 39, '1994'),
	(243, 1, 0, -50944, 1996, 0, 0, 39, '1995'),
	(243, 1, 0, -50944, 1997, 0, 0, 39, '1996'),
	(243, 1, 0, -50944, 1998, 0, 0, 39, '1997'),
	(243, 1, 0, -50944, 1999, 0, 0, 39, '1998'),
	(243, 1, 0, -50944, 2000, 0, 0, 39, '1999'),
	(243, 1, 0, -50944, 2001, 0, 0, 39, '2000'),
	(243, 1, 0, -50944, 2002, 0, 0, 39, '2001'),
	(243, 1, 0, -50944, 2003, 0, 0, 39, '2002'),
	(243, 1, 0, -50944, 2004, 0, 0, 39, '2003'),
	(243, 1, 0, -50944, 2005, 0, 0, 39, '2004'),
	(243, 1, 0, -50944, 2006, 0, 0, 39, '2005'),
	(243, 1, 0, -50944, 2007, 0, 0, 39, '2006'),
	(243, 1, 0, -50944, 2008, 0, 0, 39, '2007'),
	(243, 1, 0, -50944, 2009, 0, 0, 39, '2008'),
	(243, 1, 0, -50944, 2010, 0, 0, 39, '2009'),
	(243, 1, 0, -50944, 2011, 0, 0, 39, '2010'),
	(243, 1, 0, -50944, 2012, 0, 0, 39, '2011'),
	(243, 1, 0, -50944, 2013, 0, 0, 39, '2012'),
	(243, 1, 0, -50944, 2014, 0, 0, 39, '2013'),
	(243, 1, 0, -50944, 2015, 0, 0, 39, '2014'),
	(243, 1, 0, -50944, 2016, 0, 0, 39, '2015'),
	(243, 1, 0, -50944, 2017, 0, 0, 39, '2016'),
	(243, 1, 0, -50944, 2018, 0, 0, 39, '2017'),
	(243, 1, 0, -50944, 2019, 0, 0, 39, '2018'),
	(243, 1, 0, -50944, 2020, 0, 0, 39, '2019'),
	(243, 1, 0, -50944, 2021, 0, 0, 39, '2020'),
	(243, 1, 0, -50944, 2022, 0, 0, 39, '2021'),
	(243, 1, 0, -50944, 2023, 0, 0, 39, '2022'),
	(243, 1, 0, -50944, 2024, 0, 0, 39, '2023'),
	(243, 1, 0, -50944, 2025, 0, 0, 39, '2024'),
	(243, 1, 0, -50944, 2026, 0, 0, 39, '2025'),
	(243, 1, 0, -50944, 2027, 0, 0, 39, '2026'),
	(243, 1, 0, -50944, 2028, 0, 0, 39, '2027'),
	(243, 1, 0, -50944, 2029, 0, 0, 39, '2028'),
	(243, 1, 0, -50944, 2030, 0, 0, 39, '2029'),
	(243, 1, 0, -50944, 2031, 0, 0, 39, '2030'),
	(243, 1, 0, -50944, 2032, 0, 0, 39, '2031'),
	(243, 1, 0, -50944, 2033, 0, 0, 39, '2032'),
	(243, 1, 0, -50944, 2034, 0, 0, 39, '2033'),
	(243, 1, 0, -50944, 2035, 0, 0, 39, '2034'),
	(243, 1, 0, -50944, 2036, 0, 0, 39, '2035'),
	(243, 1, 0, -50944, 2037, 0, 0, 39, '2036'),
	(243, 1, 0, -50944, 2038, 0, 0, 39, '2037'),
	(243, 1, 0, -50944, 2039, 0, 0, 39, '2038'),
	(243, 1, 0, -50944, 2040, 0, 0, 39, '2039'),
	(243, 1, 0, -50944, 2041, 0, 0, 39, '2040'),
	(243, 1, 0, -50944, 2042, 0, 0, 39, '2041'),
	(243, 1, 0, -50944, 2043, 0, 0, 39, '2042'),
	(243, 1, 0, -50944, 2044, 0, 0, 39, '2043'),
	(243, 1, 0, -50944, 2045, 0, 0, 39, '2044'),
	(243, 1, 0, -50944, 2046, 0, 0, 39, '2045'),
	(243, 1, 0, -50944, 2047, 0, 0, 39, '2046'),
	(243, 1, 0, -50944, 2048, 0, 0, 39, '2047'),
	(243, 1, 0, -50943, 1, 0, 0, 39, '0'),
	(243, 1, 0, -50943, 2, 0, 0, 39, '1'),
	(243, 1, 0, -50943, 3, 0, 0, 39, '2'),
	(243, 1, 0, -50943, 4, 0, 0, 39, '3'),
	(243, 1, 0, -50943, 5, 0, 0, 39, '4'),
	(243, 1, 0, -50943, 6, 0, 0, 39, '5'),
	(243, 1, 0, -50943, 7, 0, 0, 39, '6'),
	(243, 1, 0, -50943, 8, 0, 0, 39, '7'),
	(243, 1, 0, -50943, 9, 0, 0, 39, '8'),
	(243, 1, 0, -50943, 10, 0, 0, 39, '9'),
	(243, 1, 0, -50943, 11, 0, 0, 39, '10'),
	(243, 1, 0, -50943, 12, 0, 0, 39, '11'),
	(243, 1, 0, -50943, 13, 0, 0, 39, '12'),
	(243, 1, 0, -50943, 14, 0, 0, 39, '13'),
	(243, 1, 0, -50943, 15, 0, 0, 39, '14'),
	(243, 1, 0, -50943, 16, 0, 0, 39, '15'),
	(243, 1, 0, -50943, 17, 0, 0, 39, '16'),
	(243, 1, 0, -50943, 18, 0, 0, 39, '17'),
	(243, 1, 0, -50943, 19, 0, 0, 39, '18'),
	(243, 1, 0, -50943, 20, 0, 0, 39, '19'),
	(243, 1, 0, -50943, 21, 0, 0, 39, '20'),
	(243, 1, 0, -50943, 22, 0, 0, 39, '21'),
	(243, 1, 0, -50943, 23, 0, 0, 39, '22'),
	(243, 1, 0, -50943, 24, 0, 0, 39, '23'),
	(243, 1, 0, -50943, 25, 0, 0, 39, '24'),
	(243, 1, 0, -50943, 26, 0, 0, 39, '25'),
	(243, 1, 0, -50943, 27, 0, 0, 39, '26'),
	(243, 1, 0, -50943, 28, 0, 0, 39, '27'),
	(243, 1, 0, -50943, 29, 0, 0, 39, '28'),
	(243, 1, 0, -50943, 30, 0, 0, 39, '29'),
	(243, 1, 0, -50943, 31, 0, 0, 39, '30'),
	(243, 1, 0, -50943, 32, 0, 0, 39, '31'),
	(243, 1, 0, -50943, 33, 0, 0, 39, '32'),
	(243, 1, 0, -50943, 34, 0, 0, 39, '33'),
	(243, 1, 0, -50943, 35, 0, 0, 39, '34'),
	(243, 1, 0, -50943, 36, 0, 0, 39, '35'),
	(243, 1, 0, -50943, 37, 0, 0, 39, '36'),
	(243, 1, 0, -50943, 38, 0, 0, 39, '37'),
	(243, 1, 0, -50943, 39, 0, 0, 39, '38'),
	(243, 1, 0, -50943, 40, 0, 0, 39, '39'),
	(243, 1, 0, -50943, 41, 0, 0, 39, '40'),
	(243, 1, 0, -50943, 42, 0, 0, 39, '41'),
	(243, 1, 0, -50943, 43, 0, 0, 39, '42'),
	(243, 1, 0, -50943, 44, 0, 0, 39, '43'),
	(243, 1, 0, -50943, 45, 0, 0, 39, '44'),
	(243, 1, 0, -50943, 46, 0, 0, 39, '45'),
	(243, 1, 0, -50943, 47, 0, 0, 39, '46'),
	(243, 1, 0, -50943, 48, 0, 0, 39, '47'),
	(243, 1, 0, -50943, 49, 0, 0, 39, '48'),
	(243, 1, 0, -50943, 50, 0, 0, 39, '49'),
	(243, 1, 0, -50943, 51, 0, 0, 39, '50'),
	(243, 1, 0, -50943, 52, 0, 0, 39, '51'),
	(243, 1, 0, -50943, 53, 0, 0, 39, '52'),
	(243, 1, 0, -50943, 54, 0, 0, 39, '53'),
	(243, 1, 0, -50943, 55, 0, 0, 39, '54'),
	(243, 1, 0, -50943, 56, 0, 0, 39, '55'),
	(243, 1, 0, -50943, 57, 0, 0, 39, '56'),
	(243, 1, 0, -50943, 58, 0, 0, 39, '57'),
	(243, 1, 0, -50943, 59, 0, 0, 39, '58'),
	(243, 1, 0, -50943, 60, 0, 0, 39, '59'),
	(243, 1, 0, -50943, 61, 0, 0, 39, '60'),
	(243, 1, 0, -50943, 62, 0, 0, 39, '61'),
	(243, 1, 0, -50943, 63, 0, 0, 39, '62'),
	(243, 1, 0, -50943, 64, 0, 0, 39, '63'),
	(243, 1, 0, -50943, 65, 0, 0, 39, '64'),
	(243, 1, 0, -50943, 66, 0, 0, 39, '65'),
	(243, 1, 0, -50943, 67, 0, 0, 39, '66'),
	(243, 1, 0, -50943, 68, 0, 0, 39, '67'),
	(243, 1, 0, -50943, 69, 0, 0, 39, '68'),
	(243, 1, 0, -50943, 70, 0, 0, 39, '69'),
	(243, 1, 0, -50943, 71, 0, 0, 39, '70'),
	(243, 1, 0, -50943, 72, 0, 0, 39, '71'),
	(243, 1, 0, -50943, 73, 0, 0, 39, '72'),
	(243, 1, 0, -50943, 74, 0, 0, 39, '73'),
	(243, 1, 0, -50943, 75, 0, 0, 39, '74'),
	(243, 1, 0, -50943, 76, 0, 0, 39, '75'),
	(243, 1, 0, -50943, 77, 0, 0, 39, '76'),
	(243, 1, 0, -50943, 78, 0, 0, 39, '77'),
	(243, 1, 0, -50943, 79, 0, 0, 39, '78'),
	(243, 1, 0, -50943, 80, 0, 0, 39, '79'),
	(243, 1, 0, -50943, 81, 0, 0, 39, '80'),
	(243, 1, 0, -50943, 82, 0, 0, 39, '81'),
	(243, 1, 0, -50943, 83, 0, 0, 39, '82'),
	(243, 1, 0, -50943, 84, 0, 0, 39, '83'),
	(243, 1, 0, -50943, 85, 0, 0, 39, '84'),
	(243, 1, 0, -50943, 86, 0, 0, 39, '85'),
	(243, 1, 0, -50943, 87, 0, 0, 39, '86'),
	(243, 1, 0, -50943, 88, 0, 0, 39, '87'),
	(243, 1, 0, -50943, 89, 0, 0, 39, '88'),
	(243, 1, 0, -50943, 90, 0, 0, 39, '89'),
	(243, 1, 0, -50943, 91, 0, 0, 39, '90'),
	(243, 1, 0, -50943, 92, 0, 0, 39, '91'),
	(243, 1, 0, -50943, 93, 0, 0, 39, '92'),
	(243, 1, 0, -50943, 94, 0, 0, 39, '93'),
	(243, 1, 0, -50943, 95, 0, 0, 39, '94'),
	(243, 1, 0, -50943, 96, 0, 0, 39, '95'),
	(243, 1, 0, -50943, 97, 0, 0, 39, '96'),
	(243, 1, 0, -50943, 98, 0, 0, 39, '97'),
	(243, 1, 0, -50943, 99, 0, 0, 39, '98'),
	(243, 1, 0, -50943, 100, 0, 0, 39, '99'),
	(243, 1, 0, -50943, 101, 0, 0, 39, '100'),
	(243, 1, 0, -50943, 102, 0, 0, 39, '101'),
	(243, 1, 0, -50943, 103, 0, 0, 39, '102'),
	(243, 1, 0, -50943, 104, 0, 0, 39, '103'),
	(243, 1, 0, -50943, 105, 0, 0, 39, '104'),
	(243, 1, 0, -50943, 106, 0, 0, 39, '105'),
	(243, 1, 0, -50943, 107, 0, 0, 39, '106'),
	(243, 1, 0, -50943, 108, 0, 0, 39, '107'),
	(243, 1, 0, -50943, 109, 0, 0, 39, '108'),
	(243, 1, 0, -50943, 110, 0, 0, 39, '109'),
	(243, 1, 0, -50943, 111, 0, 0, 39, '110'),
	(243, 1, 0, -50943, 112, 0, 0, 39, '111'),
	(243, 1, 0, -50943, 113, 0, 0, 39, '112'),
	(243, 1, 0, -50943, 114, 0, 0, 39, '113'),
	(243, 1, 0, -50943, 115, 0, 0, 39, '114'),
	(243, 1, 0, -50943, 116, 0, 0, 39, '115'),
	(243, 1, 0, -50943, 117, 0, 0, 39, '116'),
	(243, 1, 0, -50943, 118, 0, 0, 39, '117'),
	(243, 1, 0, -50943, 119, 0, 0, 39, '118'),
	(243, 1, 0, -50943, 120, 0, 0, 39, '119'),
	(243, 1, 0, -50943, 121, 0, 0, 39, '120'),
	(243, 1, 0, -50943, 122, 0, 0, 39, '121'),
	(243, 1, 0, -50943, 123, 0, 0, 39, '122'),
	(243, 1, 0, -50943, 124, 0, 0, 39, '123'),
	(243, 1, 0, -50943, 125, 0, 0, 39, '124'),
	(243, 1, 0, -50943, 126, 0, 0, 39, '125'),
	(243, 1, 0, -50943, 127, 0, 0, 39, '126'),
	(243, 1, 0, -50943, 128, 0, 0, 39, '127'),
	(243, 1, 0, -50943, 129, 0, 0, 39, '128'),
	(243, 1, 0, -50943, 130, 0, 0, 39, '129'),
	(243, 1, 0, -50943, 131, 0, 0, 39, '130'),
	(243, 1, 0, -50943, 132, 0, 0, 39, '131'),
	(243, 1, 0, -50943, 133, 0, 0, 39, '132'),
	(243, 1, 0, -50943, 134, 0, 0, 39, '133'),
	(243, 1, 0, -50943, 135, 0, 0, 39, '134'),
	(243, 1, 0, -50943, 136, 0, 0, 39, '135'),
	(243, 1, 0, -50943, 137, 0, 0, 39, '136'),
	(243, 1, 0, -50943, 138, 0, 0, 39, '137'),
	(243, 1, 0, -50943, 139, 0, 0, 39, '138'),
	(243, 1, 0, -50943, 140, 0, 0, 39, '139'),
	(243, 1, 0, -50943, 141, 0, 0, 39, '140'),
	(243, 1, 0, -50943, 142, 0, 0, 39, '141'),
	(243, 1, 0, -50943, 143, 0, 0, 39, '142'),
	(243, 1, 0, -50943, 144, 0, 0, 39, '143'),
	(243, 1, 0, -50943, 145, 0, 0, 39, '144'),
	(243, 1, 0, -50943, 146, 0, 0, 39, '145'),
	(243, 1, 0, -50943, 147, 0, 0, 39, '146'),
	(243, 1, 0, -50943, 148, 0, 0, 39, '147'),
	(243, 1, 0, -50943, 149, 0, 0, 39, '148'),
	(243, 1, 0, -50943, 150, 0, 0, 39, '149'),
	(243, 1, 0, -50943, 151, 0, 0, 39, '150'),
	(243, 1, 0, -50943, 152, 0, 0, 39, '151'),
	(243, 1, 0, -50943, 153, 0, 0, 39, '152'),
	(243, 1, 0, -50943, 154, 0, 0, 39, '153'),
	(243, 1, 0, -50943, 155, 0, 0, 39, '154'),
	(243, 1, 0, -50943, 156, 0, 0, 39, '155'),
	(243, 1, 0, -50943, 157, 0, 0, 39, '156'),
	(243, 1, 0, -50943, 158, 0, 0, 39, '157'),
	(243, 1, 0, -50943, 159, 0, 0, 39, '158'),
	(243, 1, 0, -50943, 160, 0, 0, 39, '159'),
	(243, 1, 0, -50943, 161, 0, 0, 39, '160'),
	(243, 1, 0, -50943, 162, 0, 0, 39, '161'),
	(243, 1, 0, -50943, 163, 0, 0, 39, '162'),
	(243, 1, 0, -50943, 164, 0, 0, 39, '163'),
	(243, 1, 0, -50943, 165, 0, 0, 39, '164'),
	(243, 1, 0, -50943, 166, 0, 0, 39, '165'),
	(243, 1, 0, -50943, 167, 0, 0, 39, '166'),
	(243, 1, 0, -50943, 168, 0, 0, 39, '167'),
	(243, 1, 0, -50943, 169, 0, 0, 39, '168'),
	(243, 1, 0, -50943, 170, 0, 0, 39, '169'),
	(243, 1, 0, -50943, 171, 0, 0, 39, '170'),
	(243, 1, 0, -50943, 172, 0, 0, 39, '171'),
	(243, 1, 0, -50943, 173, 0, 0, 39, '172'),
	(243, 1, 0, -50943, 174, 0, 0, 39, '173'),
	(243, 1, 0, -50943, 175, 0, 0, 39, '174'),
	(243, 1, 0, -50943, 176, 0, 0, 39, '175'),
	(243, 1, 0, -50943, 177, 0, 0, 39, '176'),
	(243, 1, 0, -50943, 178, 0, 0, 39, '177'),
	(243, 1, 0, -50943, 179, 0, 0, 39, '178'),
	(243, 1, 0, -50943, 180, 0, 0, 39, '179'),
	(243, 1, 0, -50943, 181, 0, 0, 39, '180'),
	(243, 1, 0, -50943, 182, 0, 0, 39, '181'),
	(243, 1, 0, -50943, 183, 0, 0, 39, '182'),
	(243, 1, 0, -50943, 184, 0, 0, 39, '183'),
	(243, 1, 0, -50943, 185, 0, 0, 39, '184'),
	(243, 1, 0, -50943, 186, 0, 0, 39, '185'),
	(243, 1, 0, -50943, 187, 0, 0, 39, '186'),
	(243, 1, 0, -50943, 188, 0, 0, 39, '187'),
	(243, 1, 0, -50943, 189, 0, 0, 39, '188'),
	(243, 1, 0, -50943, 190, 0, 0, 39, '189'),
	(243, 1, 0, -50943, 191, 0, 0, 39, '190'),
	(243, 1, 0, -50943, 192, 0, 0, 39, '191'),
	(243, 1, 0, -50943, 193, 0, 0, 39, '192'),
	(243, 1, 0, -50943, 194, 0, 0, 39, '193'),
	(243, 1, 0, -50943, 195, 0, 0, 39, '194'),
	(243, 1, 0, -50943, 196, 0, 0, 39, '195'),
	(243, 1, 0, -50943, 197, 0, 0, 39, '196'),
	(243, 1, 0, -50943, 198, 0, 0, 39, '197'),
	(243, 1, 0, -50943, 199, 0, 0, 39, '198'),
	(243, 1, 0, -50943, 200, 0, 0, 39, '199'),
	(243, 1, 0, -50943, 201, 0, 0, 39, '200'),
	(243, 1, 0, -50943, 202, 0, 0, 39, '201'),
	(243, 1, 0, -50943, 203, 0, 0, 39, '202'),
	(243, 1, 0, -50943, 204, 0, 0, 39, '203'),
	(243, 1, 0, -50943, 205, 0, 0, 39, '204'),
	(243, 1, 0, -50943, 206, 0, 0, 39, '205'),
	(243, 1, 0, -50943, 207, 0, 0, 39, '206'),
	(243, 1, 0, -50943, 208, 0, 0, 39, '207'),
	(243, 1, 0, -50943, 209, 0, 0, 39, '208'),
	(243, 1, 0, -50943, 210, 0, 0, 39, '209'),
	(243, 1, 0, -50943, 211, 0, 0, 39, '210'),
	(243, 1, 0, -50943, 212, 0, 0, 39, '211'),
	(243, 1, 0, -50943, 213, 0, 0, 39, '212'),
	(243, 1, 0, -50943, 214, 0, 0, 39, '213'),
	(243, 1, 0, -50943, 215, 0, 0, 39, '214'),
	(243, 1, 0, -50943, 216, 0, 0, 39, '215'),
	(243, 1, 0, -50943, 217, 0, 0, 39, '216'),
	(243, 1, 0, -50943, 218, 0, 0, 39, '217'),
	(243, 1, 0, -50943, 219, 0, 0, 39, '218'),
	(243, 1, 0, -50943, 220, 0, 0, 39, '219'),
	(243, 1, 0, -50943, 221, 0, 0, 39, '220'),
	(243, 1, 0, -50943, 222, 0, 0, 39, '221'),
	(243, 1, 0, -50943, 223, 0, 0, 39, '222'),
	(243, 1, 0, -50943, 224, 0, 0, 39, '223'),
	(243, 1, 0, -50943, 225, 0, 0, 39, '224'),
	(243, 1, 0, -50943, 226, 0, 0, 39, '225'),
	(243, 1, 0, -50943, 227, 0, 0, 39, '226'),
	(243, 1, 0, -50943, 228, 0, 0, 39, '227'),
	(243, 1, 0, -50943, 229, 0, 0, 39, '228'),
	(243, 1, 0, -50943, 230, 0, 0, 39, '229'),
	(243, 1, 0, -50943, 231, 0, 0, 39, '230'),
	(243, 1, 0, -50943, 232, 0, 0, 39, '231'),
	(243, 1, 0, -50943, 233, 0, 0, 39, '232'),
	(243, 1, 0, -50943, 234, 0, 0, 39, '233'),
	(243, 1, 0, -50943, 235, 0, 0, 39, '234'),
	(243, 1, 0, -50943, 236, 0, 0, 39, '235'),
	(243, 1, 0, -50943, 237, 0, 0, 39, '236'),
	(243, 1, 0, -50943, 238, 0, 0, 39, '237'),
	(243, 1, 0, -50943, 239, 0, 0, 39, '238'),
	(243, 1, 0, -50943, 240, 0, 0, 39, '239'),
	(243, 1, 0, -50943, 241, 0, 0, 39, '240'),
	(243, 1, 0, -50943, 242, 0, 0, 39, '241'),
	(243, 1, 0, -50943, 243, 0, 0, 39, '242'),
	(243, 1, 0, -50943, 244, 0, 0, 39, '243'),
	(243, 1, 0, -50943, 245, 0, 0, 39, '244'),
	(243, 1, 0, -50943, 246, 0, 0, 39, '245'),
	(243, 1, 0, -50943, 247, 0, 0, 39, '246'),
	(243, 1, 0, -50943, 248, 0, 0, 39, '247'),
	(243, 1, 0, -50943, 249, 0, 0, 39, '248'),
	(243, 1, 0, -50943, 250, 0, 0, 39, '249'),
	(243, 1, 0, -50943, 251, 0, 0, 39, '250'),
	(243, 1, 0, -50943, 252, 0, 0, 39, '251'),
	(243, 1, 0, -50943, 253, 0, 0, 39, '252'),
	(243, 1, 0, -50943, 254, 0, 0, 39, '253'),
	(243, 1, 0, -50943, 255, 0, 0, 39, '254'),
	(243, 1, 0, -50943, 256, 0, 0, 39, '255'),
	(243, 1, 0, -50943, 257, 0, 0, 39, '256'),
	(243, 1, 0, -50943, 258, 0, 0, 39, '257'),
	(243, 1, 0, -50943, 259, 0, 0, 39, '258'),
	(243, 1, 0, -50943, 260, 0, 0, 39, '259'),
	(243, 1, 0, -50943, 261, 0, 0, 39, '260'),
	(243, 1, 0, -50943, 262, 0, 0, 39, '261'),
	(243, 1, 0, -50943, 263, 0, 0, 39, '262'),
	(243, 1, 0, -50943, 264, 0, 0, 39, '263'),
	(243, 1, 0, -50943, 265, 0, 0, 39, '264'),
	(243, 1, 0, -50943, 266, 0, 0, 39, '265'),
	(243, 1, 0, -50943, 267, 0, 0, 39, '266'),
	(243, 1, 0, -50943, 268, 0, 0, 39, '267'),
	(243, 1, 0, -50943, 269, 0, 0, 39, '268'),
	(243, 1, 0, -50943, 270, 0, 0, 39, '269'),
	(243, 1, 0, -50943, 271, 0, 0, 39, '270'),
	(243, 1, 0, -50943, 272, 0, 0, 39, '271'),
	(243, 1, 0, -50943, 273, 0, 0, 39, '272'),
	(243, 1, 0, -50943, 274, 0, 0, 39, '273'),
	(243, 1, 0, -50943, 275, 0, 0, 39, '274'),
	(243, 1, 0, -50943, 276, 0, 0, 39, '275'),
	(243, 1, 0, -50943, 277, 0, 0, 39, '276'),
	(243, 1, 0, -50943, 278, 0, 0, 39, '277'),
	(243, 1, 0, -50943, 279, 0, 0, 39, '278'),
	(243, 1, 0, -50943, 280, 0, 0, 39, '279'),
	(243, 1, 0, -50943, 281, 0, 0, 39, '280'),
	(243, 1, 0, -50943, 282, 0, 0, 39, '281'),
	(243, 1, 0, -50943, 283, 0, 0, 39, '282'),
	(243, 1, 0, -50943, 284, 0, 0, 39, '283'),
	(243, 1, 0, -50943, 285, 0, 0, 39, '284'),
	(243, 1, 0, -50943, 286, 0, 0, 39, '285'),
	(243, 1, 0, -50943, 287, 0, 0, 39, '286'),
	(243, 1, 0, -50943, 288, 0, 0, 39, '287'),
	(243, 1, 0, -50943, 289, 0, 0, 39, '288'),
	(243, 1, 0, -50943, 290, 0, 0, 39, '289'),
	(243, 1, 0, -50943, 291, 0, 0, 39, '290'),
	(243, 1, 0, -50943, 292, 0, 0, 39, '291'),
	(243, 1, 0, -50943, 293, 0, 0, 39, '292'),
	(243, 1, 0, -50943, 294, 0, 0, 39, '293'),
	(243, 1, 0, -50943, 295, 0, 0, 39, '294'),
	(243, 1, 0, -50943, 296, 0, 0, 39, '295'),
	(243, 1, 0, -50943, 297, 0, 0, 39, '296'),
	(243, 1, 0, -50943, 298, 0, 0, 39, '297'),
	(243, 1, 0, -50943, 299, 0, 0, 39, '298'),
	(243, 1, 0, -50943, 300, 0, 0, 39, '299'),
	(243, 1, 0, -50943, 301, 0, 0, 39, '300'),
	(243, 1, 0, -50943, 302, 0, 0, 39, '301'),
	(243, 1, 0, -50943, 303, 0, 0, 39, '302'),
	(243, 1, 0, -50943, 304, 0, 0, 39, '303'),
	(243, 1, 0, -50943, 305, 0, 0, 39, '304'),
	(243, 1, 0, -50943, 306, 0, 0, 39, '305'),
	(243, 1, 0, -50943, 307, 0, 0, 39, '306'),
	(243, 1, 0, -50943, 308, 0, 0, 39, '307'),
	(243, 1, 0, -50943, 309, 0, 0, 39, '308'),
	(243, 1, 0, -50943, 310, 0, 0, 39, '309'),
	(243, 1, 0, -50943, 311, 0, 0, 39, '310'),
	(243, 1, 0, -50943, 312, 0, 0, 39, '311'),
	(243, 1, 0, -50943, 313, 0, 0, 39, '312'),
	(243, 1, 0, -50943, 314, 0, 0, 39, '313'),
	(243, 1, 0, -50943, 315, 0, 0, 39, '314'),
	(243, 1, 0, -50943, 316, 0, 0, 39, '315'),
	(243, 1, 0, -50943, 317, 0, 0, 39, '316'),
	(243, 1, 0, -50943, 318, 0, 0, 39, '317'),
	(243, 1, 0, -50943, 319, 0, 0, 39, '318'),
	(243, 1, 0, -50943, 320, 0, 0, 39, '319'),
	(243, 1, 0, -50943, 321, 0, 0, 39, '320'),
	(243, 1, 0, -50943, 322, 0, 0, 39, '321'),
	(243, 1, 0, -50943, 323, 0, 0, 39, '322'),
	(243, 1, 0, -50943, 324, 0, 0, 39, '323'),
	(243, 1, 0, -50943, 325, 0, 0, 39, '324'),
	(243, 1, 0, -50943, 326, 0, 0, 39, '325'),
	(243, 1, 0, -50943, 327, 0, 0, 39, '326'),
	(243, 1, 0, -50943, 328, 0, 0, 39, '327'),
	(243, 1, 0, -50943, 329, 0, 0, 39, '328'),
	(243, 1, 0, -50943, 330, 0, 0, 39, '329'),
	(243, 1, 0, -50943, 331, 0, 0, 39, '330'),
	(243, 1, 0, -50943, 332, 0, 0, 39, '331'),
	(243, 1, 0, -50943, 333, 0, 0, 39, '332'),
	(243, 1, 0, -50943, 334, 0, 0, 39, '333'),
	(243, 1, 0, -50943, 335, 0, 0, 39, '334'),
	(243, 1, 0, -50943, 336, 0, 0, 39, '335'),
	(243, 1, 0, -50943, 337, 0, 0, 39, '336'),
	(243, 1, 0, -50943, 338, 0, 0, 39, '337'),
	(243, 1, 0, -50943, 339, 0, 0, 39, '338'),
	(243, 1, 0, -50943, 340, 0, 0, 39, '339'),
	(243, 1, 0, -50943, 341, 0, 0, 39, '340'),
	(243, 1, 0, -50943, 342, 0, 0, 39, '341'),
	(243, 1, 0, -50943, 343, 0, 0, 39, '342'),
	(243, 1, 0, -50943, 344, 0, 0, 39, '343'),
	(243, 1, 0, -50943, 345, 0, 0, 39, '344'),
	(243, 1, 0, -50943, 346, 0, 0, 39, '345'),
	(243, 1, 0, -50943, 347, 0, 0, 39, '346'),
	(243, 1, 0, -50943, 348, 0, 0, 39, '347'),
	(243, 1, 0, -50943, 349, 0, 0, 39, '348'),
	(243, 1, 0, -50943, 350, 0, 0, 39, '349'),
	(243, 1, 0, -50943, 351, 0, 0, 39, '350'),
	(243, 1, 0, -50943, 352, 0, 0, 39, '351'),
	(243, 1, 0, -50943, 353, 0, 0, 39, '352'),
	(243, 1, 0, -50943, 354, 0, 0, 39, '353'),
	(243, 1, 0, -50943, 355, 0, 0, 39, '354'),
	(243, 1, 0, -50943, 356, 0, 0, 39, '355'),
	(243, 1, 0, -50943, 357, 0, 0, 39, '356'),
	(243, 1, 0, -50943, 358, 0, 0, 39, '357'),
	(243, 1, 0, -50943, 359, 0, 0, 39, '358'),
	(243, 1, 0, -50943, 360, 0, 0, 39, '359'),
	(243, 1, 0, -50943, 361, 0, 0, 39, '360'),
	(243, 1, 0, -50943, 362, 0, 0, 39, '361'),
	(243, 1, 0, -50943, 363, 0, 0, 39, '362'),
	(243, 1, 0, -50943, 364, 0, 0, 39, '363'),
	(243, 1, 0, -50943, 365, 0, 0, 39, '364'),
	(243, 1, 0, -50943, 366, 0, 0, 39, '365'),
	(243, 1, 0, -50943, 367, 0, 0, 39, '366'),
	(243, 1, 0, -50943, 368, 0, 0, 39, '367'),
	(243, 1, 0, -50943, 369, 0, 0, 39, '368'),
	(243, 1, 0, -50943, 370, 0, 0, 39, '369'),
	(243, 1, 0, -50943, 371, 0, 0, 39, '370'),
	(243, 1, 0, -50943, 372, 0, 0, 39, '371'),
	(243, 1, 0, -50943, 373, 0, 0, 39, '372'),
	(243, 1, 0, -50943, 374, 0, 0, 39, '373'),
	(243, 1, 0, -50943, 375, 0, 0, 39, '374'),
	(243, 1, 0, -50943, 376, 0, 0, 39, '375'),
	(243, 1, 0, -50943, 377, 0, 0, 39, '376'),
	(243, 1, 0, -50943, 378, 0, 0, 39, '377'),
	(243, 1, 0, -50943, 379, 0, 0, 39, '378'),
	(243, 1, 0, -50943, 380, 0, 0, 39, '379'),
	(243, 1, 0, -50943, 381, 0, 0, 39, '380'),
	(243, 1, 0, -50943, 382, 0, 0, 39, '381'),
	(243, 1, 0, -50943, 383, 0, 0, 39, '382'),
	(243, 1, 0, -50943, 384, 0, 0, 39, '383'),
	(243, 1, 0, -50943, 385, 0, 0, 39, '384'),
	(243, 1, 0, -50943, 386, 0, 0, 39, '385'),
	(243, 1, 0, -50943, 387, 0, 0, 39, '386'),
	(243, 1, 0, -50943, 388, 0, 0, 39, '387'),
	(243, 1, 0, -50943, 389, 0, 0, 39, '388'),
	(243, 1, 0, -50943, 390, 0, 0, 39, '389'),
	(243, 1, 0, -50943, 391, 0, 0, 39, '390'),
	(243, 1, 0, -50943, 392, 0, 0, 39, '391'),
	(243, 1, 0, -50943, 393, 0, 0, 39, '392'),
	(243, 1, 0, -50943, 394, 0, 0, 39, '393'),
	(243, 1, 0, -50943, 395, 0, 0, 39, '394'),
	(243, 1, 0, -50943, 396, 0, 0, 39, '395'),
	(243, 1, 0, -50943, 397, 0, 0, 39, '396'),
	(243, 1, 0, -50943, 398, 0, 0, 39, '397'),
	(243, 1, 0, -50943, 399, 0, 0, 39, '398'),
	(243, 1, 0, -50943, 400, 0, 0, 39, '399'),
	(243, 1, 0, -50943, 401, 0, 0, 39, '400'),
	(243, 1, 0, -50943, 402, 0, 0, 39, '401'),
	(243, 1, 0, -50943, 403, 0, 0, 39, '402'),
	(243, 1, 0, -50943, 404, 0, 0, 39, '403'),
	(243, 1, 0, -50943, 405, 0, 0, 39, '404'),
	(243, 1, 0, -50943, 406, 0, 0, 39, '405'),
	(243, 1, 0, -50943, 407, 0, 0, 39, '406'),
	(243, 1, 0, -50943, 408, 0, 0, 39, '407'),
	(243, 1, 0, -50943, 409, 0, 0, 39, '408'),
	(243, 1, 0, -50943, 410, 0, 0, 39, '409'),
	(243, 1, 0, -50943, 411, 0, 0, 39, '410'),
	(243, 1, 0, -50943, 412, 0, 0, 39, '411'),
	(243, 1, 0, -50943, 413, 0, 0, 39, '412'),
	(243, 1, 0, -50943, 414, 0, 0, 39, '413'),
	(243, 1, 0, -50943, 415, 0, 0, 39, '414'),
	(243, 1, 0, -50943, 416, 0, 0, 39, '415'),
	(243, 1, 0, -50943, 417, 0, 0, 39, '416'),
	(243, 1, 0, -50943, 418, 0, 0, 39, '417'),
	(243, 1, 0, -50943, 419, 0, 0, 39, '418'),
	(243, 1, 0, -50943, 420, 0, 0, 39, '419'),
	(243, 1, 0, -50943, 421, 0, 0, 39, '420'),
	(243, 1, 0, -50943, 422, 0, 0, 39, '421'),
	(243, 1, 0, -50943, 423, 0, 0, 39, '422'),
	(243, 1, 0, -50943, 424, 0, 0, 39, '423'),
	(243, 1, 0, -50943, 425, 0, 0, 39, '424'),
	(243, 1, 0, -50943, 426, 0, 0, 39, '425'),
	(243, 1, 0, -50943, 427, 0, 0, 39, '426'),
	(243, 1, 0, -50943, 428, 0, 0, 39, '427'),
	(243, 1, 0, -50943, 429, 0, 0, 39, '428'),
	(243, 1, 0, -50943, 430, 0, 0, 39, '429'),
	(243, 1, 0, -50943, 431, 0, 0, 39, '430'),
	(243, 1, 0, -50943, 432, 0, 0, 39, '431'),
	(243, 1, 0, -50943, 433, 0, 0, 39, '432'),
	(243, 1, 0, -50943, 434, 0, 0, 39, '433'),
	(243, 1, 0, -50943, 435, 0, 0, 39, '434'),
	(243, 1, 0, -50943, 436, 0, 0, 39, '435'),
	(243, 1, 0, -50943, 437, 0, 0, 39, '436'),
	(243, 1, 0, -50943, 438, 0, 0, 39, '437'),
	(243, 1, 0, -50943, 439, 0, 0, 39, '438'),
	(243, 1, 0, -50943, 440, 0, 0, 39, '439'),
	(243, 1, 0, -50943, 441, 0, 0, 39, '440'),
	(243, 1, 0, -50943, 442, 0, 0, 39, '441'),
	(243, 1, 0, -50943, 443, 0, 0, 39, '442'),
	(243, 1, 0, -50943, 444, 0, 0, 39, '443'),
	(243, 1, 0, -50943, 445, 0, 0, 39, '444'),
	(243, 1, 0, -50943, 446, 0, 0, 39, '445'),
	(243, 1, 0, -50943, 447, 0, 0, 39, '446'),
	(243, 1, 0, -50943, 448, 0, 0, 39, '447'),
	(243, 1, 0, -50943, 449, 0, 0, 39, '448'),
	(243, 1, 0, -50943, 450, 0, 0, 39, '449'),
	(243, 1, 0, -50943, 451, 0, 0, 39, '450'),
	(243, 1, 0, -50943, 452, 0, 0, 39, '451'),
	(243, 1, 0, -50943, 453, 0, 0, 39, '452'),
	(243, 1, 0, -50943, 454, 0, 0, 39, '453'),
	(243, 1, 0, -50943, 455, 0, 0, 39, '454'),
	(243, 1, 0, -50943, 456, 0, 0, 39, '455'),
	(243, 1, 0, -50943, 457, 0, 0, 39, '456'),
	(243, 1, 0, -50943, 458, 0, 0, 39, '457'),
	(243, 1, 0, -50943, 459, 0, 0, 39, '458'),
	(243, 1, 0, -50943, 460, 0, 0, 39, '459'),
	(243, 1, 0, -50943, 461, 0, 0, 39, '460'),
	(243, 1, 0, -50943, 462, 0, 0, 39, '461'),
	(243, 1, 0, -50943, 463, 0, 0, 39, '462'),
	(243, 1, 0, -50943, 464, 0, 0, 39, '463'),
	(243, 1, 0, -50943, 465, 0, 0, 39, '464'),
	(243, 1, 0, -50943, 466, 0, 0, 39, '465'),
	(243, 1, 0, -50943, 467, 0, 0, 39, '466'),
	(243, 1, 0, -50943, 468, 0, 0, 39, '467'),
	(243, 1, 0, -50943, 469, 0, 0, 39, '468'),
	(243, 1, 0, -50943, 470, 0, 0, 39, '469'),
	(243, 1, 0, -50943, 471, 0, 0, 39, '470'),
	(243, 1, 0, -50943, 472, 0, 0, 39, '471'),
	(243, 1, 0, -50943, 473, 0, 0, 39, '472'),
	(243, 1, 0, -50943, 474, 0, 0, 39, '473'),
	(243, 1, 0, -50943, 475, 0, 0, 39, '474'),
	(243, 1, 0, -50943, 476, 0, 0, 39, '475'),
	(243, 1, 0, -50943, 477, 0, 0, 39, '476'),
	(243, 1, 0, -50943, 478, 0, 0, 39, '477'),
	(243, 1, 0, -50943, 479, 0, 0, 39, '478'),
	(243, 1, 0, -50943, 480, 0, 0, 39, '479'),
	(243, 1, 0, -50943, 481, 0, 0, 39, '480'),
	(243, 1, 0, -50943, 482, 0, 0, 39, '481'),
	(243, 1, 0, -50943, 483, 0, 0, 39, '482'),
	(243, 1, 0, -50943, 484, 0, 0, 39, '483'),
	(243, 1, 0, -50943, 485, 0, 0, 39, '484'),
	(243, 1, 0, -50943, 486, 0, 0, 39, '485'),
	(243, 1, 0, -50943, 487, 0, 0, 39, '486'),
	(243, 1, 0, -50943, 488, 0, 0, 39, '487'),
	(243, 1, 0, -50943, 489, 0, 0, 39, '488'),
	(243, 1, 0, -50943, 490, 0, 0, 39, '489'),
	(243, 1, 0, -50943, 491, 0, 0, 39, '490'),
	(243, 1, 0, -50943, 492, 0, 0, 39, '491'),
	(243, 1, 0, -50943, 493, 0, 0, 39, '492'),
	(243, 1, 0, -50943, 494, 0, 0, 39, '493'),
	(243, 1, 0, -50943, 495, 0, 0, 39, '494'),
	(243, 1, 0, -50943, 496, 0, 0, 39, '495'),
	(243, 1, 0, -50943, 497, 0, 0, 39, '496'),
	(243, 1, 0, -50943, 498, 0, 0, 39, '497'),
	(243, 1, 0, -50943, 499, 0, 0, 39, '498'),
	(243, 1, 0, -50943, 500, 0, 0, 39, '499'),
	(243, 1, 0, -50943, 501, 0, 0, 39, '500'),
	(243, 1, 0, -50943, 502, 0, 0, 39, '501'),
	(243, 1, 0, -50943, 503, 0, 0, 39, '502'),
	(243, 1, 0, -50943, 504, 0, 0, 39, '503'),
	(243, 1, 0, -50943, 505, 0, 0, 39, '504'),
	(243, 1, 0, -50943, 506, 0, 0, 39, '505'),
	(243, 1, 0, -50943, 507, 0, 0, 39, '506'),
	(243, 1, 0, -50943, 508, 0, 0, 39, '507'),
	(243, 1, 0, -50943, 509, 0, 0, 39, '508'),
	(243, 1, 0, -50943, 510, 0, 0, 39, '509'),
	(243, 1, 0, -50943, 511, 0, 0, 39, '510'),
	(243, 1, 0, -50943, 512, 0, 0, 39, '511'),
	(243, 1, 0, -50943, 513, 0, 0, 39, '512'),
	(243, 1, 0, -50943, 514, 0, 0, 39, '513'),
	(243, 1, 0, -50943, 515, 0, 0, 39, '514'),
	(243, 1, 0, -50943, 516, 0, 0, 39, '515'),
	(243, 1, 0, -50943, 517, 0, 0, 39, '516'),
	(243, 1, 0, -50943, 518, 0, 0, 39, '517'),
	(243, 1, 0, -50943, 519, 0, 0, 39, '518'),
	(243, 1, 0, -50943, 520, 0, 0, 39, '519'),
	(243, 1, 0, -50943, 521, 0, 0, 39, '520'),
	(243, 1, 0, -50943, 522, 0, 0, 39, '521'),
	(243, 1, 0, -50943, 523, 0, 0, 39, '522'),
	(243, 1, 0, -50943, 524, 0, 0, 39, '523'),
	(243, 1, 0, -50943, 525, 0, 0, 39, '524'),
	(243, 1, 0, -50943, 526, 0, 0, 39, '525'),
	(243, 1, 0, -50943, 527, 0, 0, 39, '526'),
	(243, 1, 0, -50943, 528, 0, 0, 39, '527'),
	(243, 1, 0, -50943, 529, 0, 0, 39, '528'),
	(243, 1, 0, -50943, 530, 0, 0, 39, '529'),
	(243, 1, 0, -50943, 531, 0, 0, 39, '530'),
	(243, 1, 0, -50943, 532, 0, 0, 39, '531'),
	(243, 1, 0, -50943, 533, 0, 0, 39, '532'),
	(243, 1, 0, -50943, 534, 0, 0, 39, '533'),
	(243, 1, 0, -50943, 535, 0, 0, 39, '534'),
	(243, 1, 0, -50943, 536, 0, 0, 39, '535'),
	(243, 1, 0, -50943, 537, 0, 0, 39, '536'),
	(243, 1, 0, -50943, 538, 0, 0, 39, '537'),
	(243, 1, 0, -50943, 539, 0, 0, 39, '538'),
	(243, 1, 0, -50943, 540, 0, 0, 39, '539'),
	(243, 1, 0, -50943, 541, 0, 0, 39, '540'),
	(243, 1, 0, -50943, 542, 0, 0, 39, '541'),
	(243, 1, 0, -50943, 543, 0, 0, 39, '542'),
	(243, 1, 0, -50943, 544, 0, 0, 39, '543'),
	(243, 1, 0, -50943, 545, 0, 0, 39, '544'),
	(243, 1, 0, -50943, 546, 0, 0, 39, '545'),
	(243, 1, 0, -50943, 547, 0, 0, 39, '546'),
	(243, 1, 0, -50943, 548, 0, 0, 39, '547'),
	(243, 1, 0, -50943, 549, 0, 0, 39, '548'),
	(243, 1, 0, -50943, 550, 0, 0, 39, '549'),
	(243, 1, 0, -50943, 551, 0, 0, 39, '550'),
	(243, 1, 0, -50943, 552, 0, 0, 39, '551'),
	(243, 1, 0, -50943, 553, 0, 0, 39, '552'),
	(243, 1, 0, -50943, 554, 0, 0, 39, '553'),
	(243, 1, 0, -50943, 555, 0, 0, 39, '554'),
	(243, 1, 0, -50943, 556, 0, 0, 39, '555'),
	(243, 1, 0, -50943, 557, 0, 0, 39, '556'),
	(243, 1, 0, -50943, 558, 0, 0, 39, '557'),
	(243, 1, 0, -50943, 559, 0, 0, 39, '558'),
	(243, 1, 0, -50943, 560, 0, 0, 39, '559'),
	(243, 1, 0, -50943, 561, 0, 0, 39, '560'),
	(243, 1, 0, -50943, 562, 0, 0, 39, '561'),
	(243, 1, 0, -50943, 563, 0, 0, 39, '562'),
	(243, 1, 0, -50943, 564, 0, 0, 39, '563'),
	(243, 1, 0, -50943, 565, 0, 0, 39, '564'),
	(243, 1, 0, -50943, 566, 0, 0, 39, '565'),
	(243, 1, 0, -50943, 567, 0, 0, 39, '566'),
	(243, 1, 0, -50943, 568, 0, 0, 39, '567'),
	(243, 1, 0, -50943, 569, 0, 0, 39, '568'),
	(243, 1, 0, -50943, 570, 0, 0, 39, '569'),
	(243, 1, 0, -50943, 571, 0, 0, 39, '570'),
	(243, 1, 0, -50943, 572, 0, 0, 39, '571'),
	(243, 1, 0, -50943, 573, 0, 0, 39, '572'),
	(243, 1, 0, -50943, 574, 0, 0, 39, '573'),
	(243, 1, 0, -50943, 575, 0, 0, 39, '574'),
	(243, 1, 0, -50943, 576, 0, 0, 39, '575'),
	(243, 1, 0, -50943, 577, 0, 0, 39, '576'),
	(243, 1, 0, -50943, 578, 0, 0, 39, '577'),
	(243, 1, 0, -50943, 579, 0, 0, 39, '578'),
	(243, 1, 0, -50943, 580, 0, 0, 39, '579'),
	(243, 1, 0, -50943, 581, 0, 0, 39, '580'),
	(243, 1, 0, -50943, 582, 0, 0, 39, '581'),
	(243, 1, 0, -50943, 583, 0, 0, 39, '582'),
	(243, 1, 0, -50943, 584, 0, 0, 39, '583'),
	(243, 1, 0, -50943, 585, 0, 0, 39, '584'),
	(243, 1, 0, -50943, 586, 0, 0, 39, '585'),
	(243, 1, 0, -50943, 587, 0, 0, 39, '586'),
	(243, 1, 0, -50943, 588, 0, 0, 39, '587'),
	(243, 1, 0, -50943, 589, 0, 0, 39, '588'),
	(243, 1, 0, -50943, 590, 0, 0, 39, '589'),
	(243, 1, 0, -50943, 591, 0, 0, 39, '590'),
	(243, 1, 0, -50943, 592, 0, 0, 39, '591'),
	(243, 1, 0, -50943, 593, 0, 0, 39, '592'),
	(243, 1, 0, -50943, 594, 0, 0, 39, '593'),
	(243, 1, 0, -50943, 595, 0, 0, 39, '594'),
	(243, 1, 0, -50943, 596, 0, 0, 39, '595'),
	(243, 1, 0, -50943, 597, 0, 0, 39, '596'),
	(243, 1, 0, -50943, 598, 0, 0, 39, '597'),
	(243, 1, 0, -50943, 599, 0, 0, 39, '598'),
	(243, 1, 0, -50943, 600, 0, 0, 39, '599'),
	(243, 1, 0, -50943, 601, 0, 0, 39, '600'),
	(243, 1, 0, -50943, 602, 0, 0, 39, '601'),
	(243, 1, 0, -50943, 603, 0, 0, 39, '602'),
	(243, 1, 0, -50943, 604, 0, 0, 39, '603'),
	(243, 1, 0, -50943, 605, 0, 0, 39, '604'),
	(243, 1, 0, -50943, 606, 0, 0, 39, '605'),
	(243, 1, 0, -50943, 607, 0, 0, 39, '606'),
	(243, 1, 0, -50943, 608, 0, 0, 39, '607'),
	(243, 1, 0, -50943, 609, 0, 0, 39, '608'),
	(243, 1, 0, -50943, 610, 0, 0, 39, '609'),
	(243, 1, 0, -50943, 611, 0, 0, 39, '610'),
	(243, 1, 0, -50943, 612, 0, 0, 39, '611'),
	(243, 1, 0, -50943, 613, 0, 0, 39, '612'),
	(243, 1, 0, -50943, 614, 0, 0, 39, '613'),
	(243, 1, 0, -50943, 615, 0, 0, 39, '614'),
	(243, 1, 0, -50943, 616, 0, 0, 39, '615'),
	(243, 1, 0, -50943, 617, 0, 0, 39, '616'),
	(243, 1, 0, -50943, 618, 0, 0, 39, '617'),
	(243, 1, 0, -50943, 619, 0, 0, 39, '618'),
	(243, 1, 0, -50943, 620, 0, 0, 39, '619'),
	(243, 1, 0, -50943, 621, 0, 0, 39, '620'),
	(243, 1, 0, -50943, 622, 0, 0, 39, '621'),
	(243, 1, 0, -50943, 623, 0, 0, 39, '622'),
	(243, 1, 0, -50943, 624, 0, 0, 39, '623'),
	(243, 1, 0, -50943, 625, 0, 0, 39, '624'),
	(243, 1, 0, -50943, 626, 0, 0, 39, '625'),
	(243, 1, 0, -50943, 627, 0, 0, 39, '626'),
	(243, 1, 0, -50943, 628, 0, 0, 39, '627'),
	(243, 1, 0, -50943, 629, 0, 0, 39, '628'),
	(243, 1, 0, -50943, 630, 0, 0, 39, '629'),
	(243, 1, 0, -50943, 631, 0, 0, 39, '630'),
	(243, 1, 0, -50943, 632, 0, 0, 39, '631'),
	(243, 1, 0, -50943, 633, 0, 0, 39, '632'),
	(243, 1, 0, -50943, 634, 0, 0, 39, '633'),
	(243, 1, 0, -50943, 635, 0, 0, 39, '634'),
	(243, 1, 0, -50943, 636, 0, 0, 39, '635'),
	(243, 1, 0, -50943, 637, 0, 0, 39, '636'),
	(243, 1, 0, -50943, 638, 0, 0, 39, '637'),
	(243, 1, 0, -50943, 639, 0, 0, 39, '638'),
	(243, 1, 0, -50943, 640, 0, 0, 39, '639'),
	(243, 1, 0, -50943, 641, 0, 0, 39, '640'),
	(243, 1, 0, -50943, 642, 0, 0, 39, '641'),
	(243, 1, 0, -50943, 643, 0, 0, 39, '642'),
	(243, 1, 0, -50943, 644, 0, 0, 39, '643'),
	(243, 1, 0, -50943, 645, 0, 0, 39, '644'),
	(243, 1, 0, -50943, 646, 0, 0, 39, '645'),
	(243, 1, 0, -50943, 647, 0, 0, 39, '646'),
	(243, 1, 0, -50943, 648, 0, 0, 39, '647'),
	(243, 1, 0, -50943, 649, 0, 0, 39, '648'),
	(243, 1, 0, -50943, 650, 0, 0, 39, '649'),
	(243, 1, 0, -50943, 651, 0, 0, 39, '650'),
	(243, 1, 0, -50943, 652, 0, 0, 39, '651'),
	(243, 1, 0, -50943, 653, 0, 0, 39, '652'),
	(243, 1, 0, -50943, 654, 0, 0, 39, '653'),
	(243, 1, 0, -50943, 655, 0, 0, 39, '654'),
	(243, 1, 0, -50943, 656, 0, 0, 39, '655'),
	(243, 1, 0, -50943, 657, 0, 0, 39, '656'),
	(243, 1, 0, -50943, 658, 0, 0, 39, '657'),
	(243, 1, 0, -50943, 659, 0, 0, 39, '658'),
	(243, 1, 0, -50943, 660, 0, 0, 39, '659'),
	(243, 1, 0, -50943, 661, 0, 0, 39, '660'),
	(243, 1, 0, -50943, 662, 0, 0, 39, '661'),
	(243, 1, 0, -50943, 663, 0, 0, 39, '662'),
	(243, 1, 0, -50943, 664, 0, 0, 39, '663'),
	(243, 1, 0, -50943, 665, 0, 0, 39, '664'),
	(243, 1, 0, -50943, 666, 0, 0, 39, '665'),
	(243, 1, 0, -50943, 667, 0, 0, 39, '666'),
	(243, 1, 0, -50943, 668, 0, 0, 39, '667'),
	(243, 1, 0, -50943, 669, 0, 0, 39, '668'),
	(243, 1, 0, -50943, 670, 0, 0, 39, '669'),
	(243, 1, 0, -50943, 671, 0, 0, 39, '670'),
	(243, 1, 0, -50943, 672, 0, 0, 39, '671'),
	(243, 1, 0, -50943, 673, 0, 0, 39, '672'),
	(243, 1, 0, -50943, 674, 0, 0, 39, '673'),
	(243, 1, 0, -50943, 675, 0, 0, 39, '674'),
	(243, 1, 0, -50943, 676, 0, 0, 39, '675'),
	(243, 1, 0, -50943, 677, 0, 0, 39, '676'),
	(243, 1, 0, -50943, 678, 0, 0, 39, '677'),
	(243, 1, 0, -50943, 679, 0, 0, 39, '678'),
	(243, 1, 0, -50943, 680, 0, 0, 39, '679'),
	(243, 1, 0, -50943, 681, 0, 0, 39, '680'),
	(243, 1, 0, -50943, 682, 0, 0, 39, '681'),
	(243, 1, 0, -50943, 683, 0, 0, 39, '682'),
	(243, 1, 0, -50943, 684, 0, 0, 39, '683'),
	(243, 1, 0, -50943, 685, 0, 0, 39, '684'),
	(243, 1, 0, -50943, 686, 0, 0, 39, '685'),
	(243, 1, 0, -50943, 687, 0, 0, 39, '686'),
	(243, 1, 0, -50943, 688, 0, 0, 39, '687'),
	(243, 1, 0, -50943, 689, 0, 0, 39, '688'),
	(243, 1, 0, -50943, 690, 0, 0, 39, '689'),
	(243, 1, 0, -50943, 691, 0, 0, 39, '690'),
	(243, 1, 0, -50943, 692, 0, 0, 39, '691'),
	(243, 1, 0, -50943, 693, 0, 0, 39, '692'),
	(243, 1, 0, -50943, 694, 0, 0, 39, '693'),
	(243, 1, 0, -50943, 695, 0, 0, 39, '694'),
	(243, 1, 0, -50943, 696, 0, 0, 39, '695'),
	(243, 1, 0, -50943, 697, 0, 0, 39, '696'),
	(243, 1, 0, -50943, 698, 0, 0, 39, '697'),
	(243, 1, 0, -50943, 699, 0, 0, 39, '698'),
	(243, 1, 0, -50943, 700, 0, 0, 39, '699'),
	(243, 1, 0, -50943, 701, 0, 0, 39, '700'),
	(243, 1, 0, -50943, 702, 0, 0, 39, '701'),
	(243, 1, 0, -50943, 703, 0, 0, 39, '702'),
	(243, 1, 0, -50943, 704, 0, 0, 39, '703'),
	(243, 1, 0, -50943, 705, 0, 0, 39, '704'),
	(243, 1, 0, -50943, 706, 0, 0, 39, '705'),
	(243, 1, 0, -50943, 707, 0, 0, 39, '706'),
	(243, 1, 0, -50943, 708, 0, 0, 39, '707'),
	(243, 1, 0, -50943, 709, 0, 0, 39, '708'),
	(243, 1, 0, -50943, 710, 0, 0, 39, '709'),
	(243, 1, 0, -50943, 711, 0, 0, 39, '710'),
	(243, 1, 0, -50943, 712, 0, 0, 39, '711'),
	(243, 1, 0, -50943, 713, 0, 0, 39, '712'),
	(243, 1, 0, -50943, 714, 0, 0, 39, '713'),
	(243, 1, 0, -50943, 715, 0, 0, 39, '714'),
	(243, 1, 0, -50943, 716, 0, 0, 39, '715'),
	(243, 1, 0, -50943, 717, 0, 0, 39, '716'),
	(243, 1, 0, -50943, 718, 0, 0, 39, '717'),
	(243, 1, 0, -50943, 719, 0, 0, 39, '718'),
	(243, 1, 0, -50943, 720, 0, 0, 39, '719'),
	(243, 1, 0, -50943, 721, 0, 0, 39, '720'),
	(243, 1, 0, -50943, 722, 0, 0, 39, '721'),
	(243, 1, 0, -50943, 723, 0, 0, 39, '722'),
	(243, 1, 0, -50943, 724, 0, 0, 39, '723'),
	(243, 1, 0, -50943, 725, 0, 0, 39, '724'),
	(243, 1, 0, -50943, 726, 0, 0, 39, '725'),
	(243, 1, 0, -50943, 727, 0, 0, 39, '726'),
	(243, 1, 0, -50943, 728, 0, 0, 39, '727'),
	(243, 1, 0, -50943, 729, 0, 0, 39, '728'),
	(243, 1, 0, -50943, 730, 0, 0, 39, '729'),
	(243, 1, 0, -50943, 731, 0, 0, 39, '730'),
	(243, 1, 0, -50943, 732, 0, 0, 39, '731'),
	(243, 1, 0, -50943, 733, 0, 0, 39, '732'),
	(243, 1, 0, -50943, 734, 0, 0, 39, '733'),
	(243, 1, 0, -50943, 735, 0, 0, 39, '734'),
	(243, 1, 0, -50943, 736, 0, 0, 39, '735'),
	(243, 1, 0, -50943, 737, 0, 0, 39, '736'),
	(243, 1, 0, -50943, 738, 0, 0, 39, '737'),
	(243, 1, 0, -50943, 739, 0, 0, 39, '738'),
	(243, 1, 0, -50943, 740, 0, 0, 39, '739'),
	(243, 1, 0, -50943, 741, 0, 0, 39, '740'),
	(243, 1, 0, -50943, 742, 0, 0, 39, '741'),
	(243, 1, 0, -50943, 743, 0, 0, 39, '742'),
	(243, 1, 0, -50943, 744, 0, 0, 39, '743'),
	(243, 1, 0, -50943, 745, 0, 0, 39, '744'),
	(243, 1, 0, -50943, 746, 0, 0, 39, '745'),
	(243, 1, 0, -50943, 747, 0, 0, 39, '746'),
	(243, 1, 0, -50943, 748, 0, 0, 39, '747'),
	(243, 1, 0, -50943, 749, 0, 0, 39, '748'),
	(243, 1, 0, -50943, 750, 0, 0, 39, '749'),
	(243, 1, 0, -50943, 751, 0, 0, 39, '750'),
	(243, 1, 0, -50943, 752, 0, 0, 39, '751'),
	(243, 1, 0, -50943, 753, 0, 0, 39, '752'),
	(243, 1, 0, -50943, 754, 0, 0, 39, '753'),
	(243, 1, 0, -50943, 755, 0, 0, 39, '754'),
	(243, 1, 0, -50943, 756, 0, 0, 39, '755'),
	(243, 1, 0, -50943, 757, 0, 0, 39, '756'),
	(243, 1, 0, -50943, 758, 0, 0, 39, '757'),
	(243, 1, 0, -50943, 759, 0, 0, 39, '758'),
	(243, 1, 0, -50943, 760, 0, 0, 39, '759'),
	(243, 1, 0, -50943, 761, 0, 0, 39, '760'),
	(243, 1, 0, -50943, 762, 0, 0, 39, '761'),
	(243, 1, 0, -50943, 763, 0, 0, 39, '762'),
	(243, 1, 0, -50943, 764, 0, 0, 39, '763'),
	(243, 1, 0, -50943, 765, 0, 0, 39, '764'),
	(243, 1, 0, -50943, 766, 0, 0, 39, '765'),
	(243, 1, 0, -50943, 767, 0, 0, 39, '766'),
	(243, 1, 0, -50943, 768, 0, 0, 39, '767'),
	(243, 1, 0, -50943, 769, 0, 0, 39, '768'),
	(243, 1, 0, -50943, 770, 0, 0, 39, '769'),
	(243, 1, 0, -50943, 771, 0, 0, 39, '770'),
	(243, 1, 0, -50943, 772, 0, 0, 39, '771'),
	(243, 1, 0, -50943, 773, 0, 0, 39, '772'),
	(243, 1, 0, -50943, 774, 0, 0, 39, '773'),
	(243, 1, 0, -50943, 775, 0, 0, 39, '774'),
	(243, 1, 0, -50943, 776, 0, 0, 39, '775'),
	(243, 1, 0, -50943, 777, 0, 0, 39, '776'),
	(243, 1, 0, -50943, 778, 0, 0, 39, '777'),
	(243, 1, 0, -50943, 779, 0, 0, 39, '778'),
	(243, 1, 0, -50943, 780, 0, 0, 39, '779'),
	(243, 1, 0, -50943, 781, 0, 0, 39, '780'),
	(243, 1, 0, -50943, 782, 0, 0, 39, '781'),
	(243, 1, 0, -50943, 783, 0, 0, 39, '782'),
	(243, 1, 0, -50943, 784, 0, 0, 39, '783'),
	(243, 1, 0, -50943, 785, 0, 0, 39, '784'),
	(243, 1, 0, -50943, 786, 0, 0, 39, '785'),
	(243, 1, 0, -50943, 787, 0, 0, 39, '786'),
	(243, 1, 0, -50943, 788, 0, 0, 39, '787'),
	(243, 1, 0, -50943, 789, 0, 0, 39, '788'),
	(243, 1, 0, -50943, 790, 0, 0, 39, '789'),
	(243, 1, 0, -50943, 791, 0, 0, 39, '790'),
	(243, 1, 0, -50943, 792, 0, 0, 39, '791'),
	(243, 1, 0, -50943, 793, 0, 0, 39, '792'),
	(243, 1, 0, -50943, 794, 0, 0, 39, '793'),
	(243, 1, 0, -50943, 795, 0, 0, 39, '794'),
	(243, 1, 0, -50943, 796, 0, 0, 39, '795'),
	(243, 1, 0, -50943, 797, 0, 0, 39, '796'),
	(243, 1, 0, -50943, 798, 0, 0, 39, '797'),
	(243, 1, 0, -50943, 799, 0, 0, 39, '798'),
	(243, 1, 0, -50943, 800, 0, 0, 39, '799'),
	(243, 1, 0, -50943, 801, 0, 0, 39, '800'),
	(243, 1, 0, -50943, 802, 0, 0, 39, '801'),
	(243, 1, 0, -50943, 803, 0, 0, 39, '802'),
	(243, 1, 0, -50943, 804, 0, 0, 39, '803'),
	(243, 1, 0, -50943, 805, 0, 0, 39, '804'),
	(243, 1, 0, -50943, 806, 0, 0, 39, '805'),
	(243, 1, 0, -50943, 807, 0, 0, 39, '806'),
	(243, 1, 0, -50943, 808, 0, 0, 39, '807'),
	(243, 1, 0, -50943, 809, 0, 0, 39, '808'),
	(243, 1, 0, -50943, 810, 0, 0, 39, '809'),
	(243, 1, 0, -50943, 811, 0, 0, 39, '810'),
	(243, 1, 0, -50943, 812, 0, 0, 39, '811'),
	(243, 1, 0, -50943, 813, 0, 0, 39, '812'),
	(243, 1, 0, -50943, 814, 0, 0, 39, '813'),
	(243, 1, 0, -50943, 815, 0, 0, 39, '814'),
	(243, 1, 0, -50943, 816, 0, 0, 39, '815'),
	(243, 1, 0, -50943, 817, 0, 0, 39, '816'),
	(243, 1, 0, -50943, 818, 0, 0, 39, '817'),
	(243, 1, 0, -50943, 819, 0, 0, 39, '818'),
	(243, 1, 0, -50943, 820, 0, 0, 39, '819'),
	(243, 1, 0, -50943, 821, 0, 0, 39, '820'),
	(243, 1, 0, -50943, 822, 0, 0, 39, '821'),
	(243, 1, 0, -50943, 823, 0, 0, 39, '822'),
	(243, 1, 0, -50943, 824, 0, 0, 39, '823'),
	(243, 1, 0, -50943, 825, 0, 0, 39, '824'),
	(243, 1, 0, -50943, 826, 0, 0, 39, '825'),
	(243, 1, 0, -50943, 827, 0, 0, 39, '826'),
	(243, 1, 0, -50943, 828, 0, 0, 39, '827'),
	(243, 1, 0, -50943, 829, 0, 0, 39, '828'),
	(243, 1, 0, -50943, 830, 0, 0, 39, '829'),
	(243, 1, 0, -50943, 831, 0, 0, 39, '830'),
	(243, 1, 0, -50943, 832, 0, 0, 39, '831'),
	(243, 1, 0, -50943, 833, 0, 0, 39, '832'),
	(243, 1, 0, -50943, 834, 0, 0, 39, '833'),
	(243, 1, 0, -50943, 835, 0, 0, 39, '834'),
	(243, 1, 0, -50943, 836, 0, 0, 39, '835'),
	(243, 1, 0, -50943, 837, 0, 0, 39, '836'),
	(243, 1, 0, -50943, 838, 0, 0, 39, '837'),
	(243, 1, 0, -50943, 839, 0, 0, 39, '838'),
	(243, 1, 0, -50943, 840, 0, 0, 39, '839'),
	(243, 1, 0, -50943, 841, 0, 0, 39, '840'),
	(243, 1, 0, -50943, 842, 0, 0, 39, '841'),
	(243, 1, 0, -50943, 843, 0, 0, 39, '842'),
	(243, 1, 0, -50943, 844, 0, 0, 39, '843'),
	(243, 1, 0, -50943, 845, 0, 0, 39, '844'),
	(243, 1, 0, -50943, 846, 0, 0, 39, '845'),
	(243, 1, 0, -50943, 847, 0, 0, 39, '846'),
	(243, 1, 0, -50943, 848, 0, 0, 39, '847'),
	(243, 1, 0, -50943, 849, 0, 0, 39, '848'),
	(243, 1, 0, -50943, 850, 0, 0, 39, '849'),
	(243, 1, 0, -50943, 851, 0, 0, 39, '850'),
	(243, 1, 0, -50943, 852, 0, 0, 39, '851'),
	(243, 1, 0, -50943, 853, 0, 0, 39, '852'),
	(243, 1, 0, -50943, 854, 0, 0, 39, '853'),
	(243, 1, 0, -50943, 855, 0, 0, 39, '854'),
	(243, 1, 0, -50943, 856, 0, 0, 39, '855'),
	(243, 1, 0, -50943, 857, 0, 0, 39, '856'),
	(243, 1, 0, -50943, 858, 0, 0, 39, '857'),
	(243, 1, 0, -50943, 859, 0, 0, 39, '858'),
	(243, 1, 0, -50943, 860, 0, 0, 39, '859'),
	(243, 1, 0, -50943, 861, 0, 0, 39, '860'),
	(243, 1, 0, -50943, 862, 0, 0, 39, '861'),
	(243, 1, 0, -50943, 863, 0, 0, 39, '862'),
	(243, 1, 0, -50943, 864, 0, 0, 39, '863'),
	(243, 1, 0, -50943, 865, 0, 0, 39, '864'),
	(243, 1, 0, -50943, 866, 0, 0, 39, '865'),
	(243, 1, 0, -50943, 867, 0, 0, 39, '866'),
	(243, 1, 0, -50943, 868, 0, 0, 39, '867'),
	(243, 1, 0, -50943, 869, 0, 0, 39, '868'),
	(243, 1, 0, -50943, 870, 0, 0, 39, '869'),
	(243, 1, 0, -50943, 871, 0, 0, 39, '870'),
	(243, 1, 0, -50943, 872, 0, 0, 39, '871'),
	(243, 1, 0, -50943, 873, 0, 0, 39, '872'),
	(243, 1, 0, -50943, 874, 0, 0, 39, '873'),
	(243, 1, 0, -50943, 875, 0, 0, 39, '874'),
	(243, 1, 0, -50943, 876, 0, 0, 39, '875'),
	(243, 1, 0, -50943, 877, 0, 0, 39, '876'),
	(243, 1, 0, -50943, 878, 0, 0, 39, '877'),
	(243, 1, 0, -50943, 879, 0, 0, 39, '878'),
	(243, 1, 0, -50943, 880, 0, 0, 39, '879'),
	(243, 1, 0, -50943, 881, 0, 0, 39, '880'),
	(243, 1, 0, -50943, 882, 0, 0, 39, '881'),
	(243, 1, 0, -50943, 883, 0, 0, 39, '882'),
	(243, 1, 0, -50943, 884, 0, 0, 39, '883'),
	(243, 1, 0, -50943, 885, 0, 0, 39, '884'),
	(243, 1, 0, -50943, 886, 0, 0, 39, '885'),
	(243, 1, 0, -50943, 887, 0, 0, 39, '886'),
	(243, 1, 0, -50943, 888, 0, 0, 39, '887'),
	(243, 1, 0, -50943, 889, 0, 0, 39, '888'),
	(243, 1, 0, -50943, 890, 0, 0, 39, '889'),
	(243, 1, 0, -50943, 891, 0, 0, 39, '890'),
	(243, 1, 0, -50943, 892, 0, 0, 39, '891'),
	(243, 1, 0, -50943, 893, 0, 0, 39, '892'),
	(243, 1, 0, -50943, 894, 0, 0, 39, '893'),
	(243, 1, 0, -50943, 895, 0, 0, 39, '894'),
	(243, 1, 0, -50943, 896, 0, 0, 39, '895'),
	(243, 1, 0, -50943, 897, 0, 0, 39, '896'),
	(243, 1, 0, -50943, 898, 0, 0, 39, '897'),
	(243, 1, 0, -50943, 899, 0, 0, 39, '898'),
	(243, 1, 0, -50943, 900, 0, 0, 39, '899'),
	(243, 1, 0, -50943, 901, 0, 0, 39, '900'),
	(243, 1, 0, -50943, 902, 0, 0, 39, '901'),
	(243, 1, 0, -50943, 903, 0, 0, 39, '902'),
	(243, 1, 0, -50943, 904, 0, 0, 39, '903'),
	(243, 1, 0, -50943, 905, 0, 0, 39, '904'),
	(243, 1, 0, -50943, 906, 0, 0, 39, '905'),
	(243, 1, 0, -50943, 907, 0, 0, 39, '906'),
	(243, 1, 0, -50943, 908, 0, 0, 39, '907'),
	(243, 1, 0, -50943, 909, 0, 0, 39, '908'),
	(243, 1, 0, -50943, 910, 0, 0, 39, '909'),
	(243, 1, 0, -50943, 911, 0, 0, 39, '910'),
	(243, 1, 0, -50943, 912, 0, 0, 39, '911'),
	(243, 1, 0, -50943, 913, 0, 0, 39, '912'),
	(243, 1, 0, -50943, 914, 0, 0, 39, '913'),
	(243, 1, 0, -50943, 915, 0, 0, 39, '914'),
	(243, 1, 0, -50943, 916, 0, 0, 39, '915'),
	(243, 1, 0, -50943, 917, 0, 0, 39, '916'),
	(243, 1, 0, -50943, 918, 0, 0, 39, '917'),
	(243, 1, 0, -50943, 919, 0, 0, 39, '918'),
	(243, 1, 0, -50943, 920, 0, 0, 39, '919'),
	(243, 1, 0, -50943, 921, 0, 0, 39, '920'),
	(243, 1, 0, -50943, 922, 0, 0, 39, '921'),
	(243, 1, 0, -50943, 923, 0, 0, 39, '922'),
	(243, 1, 0, -50943, 924, 0, 0, 39, '923'),
	(243, 1, 0, -50943, 925, 0, 0, 39, '924'),
	(243, 1, 0, -50943, 926, 0, 0, 39, '925'),
	(243, 1, 0, -50943, 927, 0, 0, 39, '926'),
	(243, 1, 0, -50943, 928, 0, 0, 39, '927'),
	(243, 1, 0, -50943, 929, 0, 0, 39, '928'),
	(243, 1, 0, -50943, 930, 0, 0, 39, '929'),
	(243, 1, 0, -50943, 931, 0, 0, 39, '930'),
	(243, 1, 0, -50943, 932, 0, 0, 39, '931'),
	(243, 1, 0, -50943, 933, 0, 0, 39, '932'),
	(243, 1, 0, -50943, 934, 0, 0, 39, '933'),
	(243, 1, 0, -50943, 935, 0, 0, 39, '934'),
	(243, 1, 0, -50943, 936, 0, 0, 39, '935'),
	(243, 1, 0, -50943, 937, 0, 0, 39, '936'),
	(243, 1, 0, -50943, 938, 0, 0, 39, '937'),
	(243, 1, 0, -50943, 939, 0, 0, 39, '938'),
	(243, 1, 0, -50943, 940, 0, 0, 39, '939'),
	(243, 1, 0, -50943, 941, 0, 0, 39, '940'),
	(243, 1, 0, -50943, 942, 0, 0, 39, '941'),
	(243, 1, 0, -50943, 943, 0, 0, 39, '942'),
	(243, 1, 0, -50943, 944, 0, 0, 39, '943'),
	(243, 1, 0, -50943, 945, 0, 0, 39, '944'),
	(243, 1, 0, -50943, 946, 0, 0, 39, '945'),
	(243, 1, 0, -50943, 947, 0, 0, 39, '946'),
	(243, 1, 0, -50943, 948, 0, 0, 39, '947'),
	(243, 1, 0, -50943, 949, 0, 0, 39, '948'),
	(243, 1, 0, -50943, 950, 0, 0, 39, '949'),
	(243, 1, 0, -50943, 951, 0, 0, 39, '950'),
	(243, 1, 0, -50943, 952, 0, 0, 39, '951'),
	(243, 1, 0, -50943, 953, 0, 0, 39, '952'),
	(243, 1, 0, -50943, 954, 0, 0, 39, '953'),
	(243, 1, 0, -50943, 955, 0, 0, 39, '954'),
	(243, 1, 0, -50943, 956, 0, 0, 39, '955'),
	(243, 1, 0, -50943, 957, 0, 0, 39, '956'),
	(243, 1, 0, -50943, 958, 0, 0, 39, '957'),
	(243, 1, 0, -50943, 959, 0, 0, 39, '958'),
	(243, 1, 0, -50943, 960, 0, 0, 39, '959'),
	(243, 1, 0, -50943, 961, 0, 0, 39, '960'),
	(243, 1, 0, -50943, 962, 0, 0, 39, '961'),
	(243, 1, 0, -50943, 963, 0, 0, 39, '962'),
	(243, 1, 0, -50943, 964, 0, 0, 39, '963'),
	(243, 1, 0, -50943, 965, 0, 0, 39, '964'),
	(243, 1, 0, -50943, 966, 0, 0, 39, '965'),
	(243, 1, 0, -50943, 967, 0, 0, 39, '966'),
	(243, 1, 0, -50943, 968, 0, 0, 39, '967'),
	(243, 1, 0, -50943, 969, 0, 0, 39, '968'),
	(243, 1, 0, -50943, 970, 0, 0, 39, '969'),
	(243, 1, 0, -50943, 971, 0, 0, 39, '970'),
	(243, 1, 0, -50943, 972, 0, 0, 39, '971'),
	(243, 1, 0, -50943, 973, 0, 0, 39, '972'),
	(243, 1, 0, -50943, 974, 0, 0, 39, '973'),
	(243, 1, 0, -50943, 975, 0, 0, 39, '974'),
	(243, 1, 0, -50943, 976, 0, 0, 39, '975'),
	(243, 1, 0, -50943, 977, 0, 0, 39, '976'),
	(243, 1, 0, -50943, 978, 0, 0, 39, '977'),
	(243, 1, 0, -50943, 979, 0, 0, 39, '978'),
	(243, 1, 0, -50943, 980, 0, 0, 39, '979'),
	(243, 1, 0, -50943, 981, 0, 0, 39, '980'),
	(243, 1, 0, -50943, 982, 0, 0, 39, '981'),
	(243, 1, 0, -50943, 983, 0, 0, 39, '982'),
	(243, 1, 0, -50943, 984, 0, 0, 39, '983'),
	(243, 1, 0, -50943, 985, 0, 0, 39, '984'),
	(243, 1, 0, -50943, 986, 0, 0, 39, '985'),
	(243, 1, 0, -50943, 987, 0, 0, 39, '986'),
	(243, 1, 0, -50943, 988, 0, 0, 39, '987'),
	(243, 1, 0, -50943, 989, 0, 0, 39, '988'),
	(243, 1, 0, -50943, 990, 0, 0, 39, '989'),
	(243, 1, 0, -50943, 991, 0, 0, 39, '990'),
	(243, 1, 0, -50943, 992, 0, 0, 39, '991'),
	(243, 1, 0, -50943, 993, 0, 0, 39, '992'),
	(243, 1, 0, -50943, 994, 0, 0, 39, '993'),
	(243, 1, 0, -50943, 995, 0, 0, 39, '994'),
	(243, 1, 0, -50943, 996, 0, 0, 39, '995'),
	(243, 1, 0, -50943, 997, 0, 0, 39, '996'),
	(243, 1, 0, -50943, 998, 0, 0, 39, '997'),
	(243, 1, 0, -50943, 999, 0, 0, 39, '998'),
	(243, 1, 0, -50943, 1000, 0, 0, 39, '999'),
	(243, 1, 0, -50943, 1001, 0, 0, 39, '1000'),
	(243, 1, 0, -50943, 1002, 0, 0, 39, '1001'),
	(243, 1, 0, -50943, 1003, 0, 0, 39, '1002'),
	(243, 1, 0, -50943, 1004, 0, 0, 39, '1003'),
	(243, 1, 0, -50943, 1005, 0, 0, 39, '1004'),
	(243, 1, 0, -50943, 1006, 0, 0, 39, '1005'),
	(243, 1, 0, -50943, 1007, 0, 0, 39, '1006'),
	(243, 1, 0, -50943, 1008, 0, 0, 39, '1007'),
	(243, 1, 0, -50943, 1009, 0, 0, 39, '1008'),
	(243, 1, 0, -50943, 1010, 0, 0, 39, '1009'),
	(243, 1, 0, -50943, 1011, 0, 0, 39, '1010'),
	(243, 1, 0, -50943, 1012, 0, 0, 39, '1011'),
	(243, 1, 0, -50943, 1013, 0, 0, 39, '1012'),
	(243, 1, 0, -50943, 1014, 0, 0, 39, '1013'),
	(243, 1, 0, -50943, 1015, 0, 0, 39, '1014'),
	(243, 1, 0, -50943, 1016, 0, 0, 39, '1015'),
	(243, 1, 0, -50943, 1017, 0, 0, 39, '1016'),
	(243, 1, 0, -50943, 1018, 0, 0, 39, '1017'),
	(243, 1, 0, -50943, 1019, 0, 0, 39, '1018'),
	(243, 1, 0, -50943, 1020, 0, 0, 39, '1019'),
	(243, 1, 0, -50943, 1021, 0, 0, 39, '1020'),
	(243, 1, 0, -50943, 1022, 0, 0, 39, '1021'),
	(243, 1, 0, -50943, 1023, 0, 0, 39, '1022'),
	(243, 1, 0, -50943, 1024, 0, 0, 39, '1023'),
	(243, 1, 0, -50943, 1025, 0, 0, 39, '1024'),
	(243, 1, 0, -50943, 1026, 0, 0, 39, '1025'),
	(243, 1, 0, -50943, 1027, 0, 0, 39, '1026'),
	(243, 1, 0, -50943, 1028, 0, 0, 39, '1027'),
	(243, 1, 0, -50943, 1029, 0, 0, 39, '1028'),
	(243, 1, 0, -50943, 1030, 0, 0, 39, '1029'),
	(243, 1, 0, -50943, 1031, 0, 0, 39, '1030'),
	(243, 1, 0, -50943, 1032, 0, 0, 39, '1031'),
	(243, 1, 0, -50943, 1033, 0, 0, 39, '1032'),
	(243, 1, 0, -50943, 1034, 0, 0, 39, '1033'),
	(243, 1, 0, -50943, 1035, 0, 0, 39, '1034'),
	(243, 1, 0, -50943, 1036, 0, 0, 39, '1035'),
	(243, 1, 0, -50943, 1037, 0, 0, 39, '1036'),
	(243, 1, 0, -50943, 1038, 0, 0, 39, '1037'),
	(243, 1, 0, -50943, 1039, 0, 0, 39, '1038'),
	(243, 1, 0, -50943, 1040, 0, 0, 39, '1039'),
	(243, 1, 0, -50943, 1041, 0, 0, 39, '1040'),
	(243, 1, 0, -50943, 1042, 0, 0, 39, '1041'),
	(243, 1, 0, -50943, 1043, 0, 0, 39, '1042'),
	(243, 1, 0, -50943, 1044, 0, 0, 39, '1043'),
	(243, 1, 0, -50943, 1045, 0, 0, 39, '1044'),
	(243, 1, 0, -50943, 1046, 0, 0, 39, '1045'),
	(243, 1, 0, -50943, 1047, 0, 0, 39, '1046'),
	(243, 1, 0, -50943, 1048, 0, 0, 39, '1047'),
	(243, 1, 0, -50943, 1049, 0, 0, 39, '1048'),
	(243, 1, 0, -50943, 1050, 0, 0, 39, '1049'),
	(243, 1, 0, -50943, 1051, 0, 0, 39, '1050'),
	(243, 1, 0, -50943, 1052, 0, 0, 39, '1051'),
	(243, 1, 0, -50943, 1053, 0, 0, 39, '1052'),
	(243, 1, 0, -50943, 1054, 0, 0, 39, '1053'),
	(243, 1, 0, -50943, 1055, 0, 0, 39, '1054'),
	(243, 1, 0, -50943, 1056, 0, 0, 39, '1055'),
	(243, 1, 0, -50943, 1057, 0, 0, 39, '1056'),
	(243, 1, 0, -50943, 1058, 0, 0, 39, '1057'),
	(243, 1, 0, -50943, 1059, 0, 0, 39, '1058'),
	(243, 1, 0, -50943, 1060, 0, 0, 39, '1059'),
	(243, 1, 0, -50943, 1061, 0, 0, 39, '1060'),
	(243, 1, 0, -50943, 1062, 0, 0, 39, '1061'),
	(243, 1, 0, -50943, 1063, 0, 0, 39, '1062'),
	(243, 1, 0, -50943, 1064, 0, 0, 39, '1063'),
	(243, 1, 0, -50943, 1065, 0, 0, 39, '1064'),
	(243, 1, 0, -50943, 1066, 0, 0, 39, '1065'),
	(243, 1, 0, -50943, 1067, 0, 0, 39, '1066'),
	(243, 1, 0, -50943, 1068, 0, 0, 39, '1067'),
	(243, 1, 0, -50943, 1069, 0, 0, 39, '1068'),
	(243, 1, 0, -50943, 1070, 0, 0, 39, '1069'),
	(243, 1, 0, -50943, 1071, 0, 0, 39, '1070'),
	(243, 1, 0, -50943, 1072, 0, 0, 39, '1071'),
	(243, 1, 0, -50943, 1073, 0, 0, 39, '1072'),
	(243, 1, 0, -50943, 1074, 0, 0, 39, '1073'),
	(243, 1, 0, -50943, 1075, 0, 0, 39, '1074'),
	(243, 1, 0, -50943, 1076, 0, 0, 39, '1075'),
	(243, 1, 0, -50943, 1077, 0, 0, 39, '1076'),
	(243, 1, 0, -50943, 1078, 0, 0, 39, '1077'),
	(243, 1, 0, -50943, 1079, 0, 0, 39, '1078'),
	(243, 1, 0, -50943, 1080, 0, 0, 39, '1079'),
	(243, 1, 0, -50943, 1081, 0, 0, 39, '1080'),
	(243, 1, 0, -50943, 1082, 0, 0, 39, '1081'),
	(243, 1, 0, -50943, 1083, 0, 0, 39, '1082'),
	(243, 1, 0, -50943, 1084, 0, 0, 39, '1083'),
	(243, 1, 0, -50943, 1085, 0, 0, 39, '1084'),
	(243, 1, 0, -50943, 1086, 0, 0, 39, '1085'),
	(243, 1, 0, -50943, 1087, 0, 0, 39, '1086'),
	(243, 1, 0, -50943, 1088, 0, 0, 39, '1087'),
	(243, 1, 0, -50943, 1089, 0, 0, 39, '1088'),
	(243, 1, 0, -50943, 1090, 0, 0, 39, '1089'),
	(243, 1, 0, -50943, 1091, 0, 0, 39, '1090'),
	(243, 1, 0, -50943, 1092, 0, 0, 39, '1091'),
	(243, 1, 0, -50943, 1093, 0, 0, 39, '1092'),
	(243, 1, 0, -50943, 1094, 0, 0, 39, '1093'),
	(243, 1, 0, -50943, 1095, 0, 0, 39, '1094'),
	(243, 1, 0, -50943, 1096, 0, 0, 39, '1095'),
	(243, 1, 0, -50943, 1097, 0, 0, 39, '1096'),
	(243, 1, 0, -50943, 1098, 0, 0, 39, '1097'),
	(243, 1, 0, -50943, 1099, 0, 0, 39, '1098'),
	(243, 1, 0, -50943, 1100, 0, 0, 39, '1099'),
	(243, 1, 0, -50943, 1101, 0, 0, 39, '1100'),
	(243, 1, 0, -50943, 1102, 0, 0, 39, '1101'),
	(243, 1, 0, -50943, 1103, 0, 0, 39, '1102'),
	(243, 1, 0, -50943, 1104, 0, 0, 39, '1103'),
	(243, 1, 0, -50943, 1105, 0, 0, 39, '1104'),
	(243, 1, 0, -50943, 1106, 0, 0, 39, '1105'),
	(243, 1, 0, -50943, 1107, 0, 0, 39, '1106'),
	(243, 1, 0, -50943, 1108, 0, 0, 39, '1107'),
	(243, 1, 0, -50943, 1109, 0, 0, 39, '1108'),
	(243, 1, 0, -50943, 1110, 0, 0, 39, '1109'),
	(243, 1, 0, -50943, 1111, 0, 0, 39, '1110'),
	(243, 1, 0, -50943, 1112, 0, 0, 39, '1111'),
	(243, 1, 0, -50943, 1113, 0, 0, 39, '1112'),
	(243, 1, 0, -50943, 1114, 0, 0, 39, '1113'),
	(243, 1, 0, -50943, 1115, 0, 0, 39, '1114'),
	(243, 1, 0, -50943, 1116, 0, 0, 39, '1115'),
	(243, 1, 0, -50943, 1117, 0, 0, 39, '1116'),
	(243, 1, 0, -50943, 1118, 0, 0, 39, '1117'),
	(243, 1, 0, -50943, 1119, 0, 0, 39, '1118'),
	(243, 1, 0, -50943, 1120, 0, 0, 39, '1119'),
	(243, 1, 0, -50943, 1121, 0, 0, 39, '1120'),
	(243, 1, 0, -50943, 1122, 0, 0, 39, '1121'),
	(243, 1, 0, -50943, 1123, 0, 0, 39, '1122'),
	(243, 1, 0, -50943, 1124, 0, 0, 39, '1123'),
	(243, 1, 0, -50943, 1125, 0, 0, 39, '1124'),
	(243, 1, 0, -50943, 1126, 0, 0, 39, '1125'),
	(243, 1, 0, -50943, 1127, 0, 0, 39, '1126'),
	(243, 1, 0, -50943, 1128, 0, 0, 39, '1127'),
	(243, 1, 0, -50943, 1129, 0, 0, 39, '1128'),
	(243, 1, 0, -50943, 1130, 0, 0, 39, '1129'),
	(243, 1, 0, -50943, 1131, 0, 0, 39, '1130'),
	(243, 1, 0, -50943, 1132, 0, 0, 39, '1131'),
	(243, 1, 0, -50943, 1133, 0, 0, 39, '1132'),
	(243, 1, 0, -50943, 1134, 0, 0, 39, '1133'),
	(243, 1, 0, -50943, 1135, 0, 0, 39, '1134'),
	(243, 1, 0, -50943, 1136, 0, 0, 39, '1135'),
	(243, 1, 0, -50943, 1137, 0, 0, 39, '1136'),
	(243, 1, 0, -50943, 1138, 0, 0, 39, '1137'),
	(243, 1, 0, -50943, 1139, 0, 0, 39, '1138'),
	(243, 1, 0, -50943, 1140, 0, 0, 39, '1139'),
	(243, 1, 0, -50943, 1141, 0, 0, 39, '1140'),
	(243, 1, 0, -50943, 1142, 0, 0, 39, '1141'),
	(243, 1, 0, -50943, 1143, 0, 0, 39, '1142'),
	(243, 1, 0, -50943, 1144, 0, 0, 39, '1143'),
	(243, 1, 0, -50943, 1145, 0, 0, 39, '1144'),
	(243, 1, 0, -50943, 1146, 0, 0, 39, '1145'),
	(243, 1, 0, -50943, 1147, 0, 0, 39, '1146'),
	(243, 1, 0, -50943, 1148, 0, 0, 39, '1147'),
	(243, 1, 0, -50943, 1149, 0, 0, 39, '1148'),
	(243, 1, 0, -50943, 1150, 0, 0, 39, '1149'),
	(243, 1, 0, -50943, 1151, 0, 0, 39, '1150'),
	(243, 1, 0, -50943, 1152, 0, 0, 39, '1151'),
	(243, 1, 0, -50943, 1153, 0, 0, 39, '1152'),
	(243, 1, 0, -50943, 1154, 0, 0, 39, '1153'),
	(243, 1, 0, -50943, 1155, 0, 0, 39, '1154'),
	(243, 1, 0, -50943, 1156, 0, 0, 39, '1155'),
	(243, 1, 0, -50943, 1157, 0, 0, 39, '1156'),
	(243, 1, 0, -50943, 1158, 0, 0, 39, '1157'),
	(243, 1, 0, -50943, 1159, 0, 0, 39, '1158'),
	(243, 1, 0, -50943, 1160, 0, 0, 39, '1159'),
	(243, 1, 0, -50943, 1161, 0, 0, 39, '1160'),
	(243, 1, 0, -50943, 1162, 0, 0, 39, '1161'),
	(243, 1, 0, -50943, 1163, 0, 0, 39, '1162'),
	(243, 1, 0, -50943, 1164, 0, 0, 39, '1163'),
	(243, 1, 0, -50943, 1165, 0, 0, 39, '1164'),
	(243, 1, 0, -50943, 1166, 0, 0, 39, '1165'),
	(243, 1, 0, -50943, 1167, 0, 0, 39, '1166'),
	(243, 1, 0, -50943, 1168, 0, 0, 39, '1167'),
	(243, 1, 0, -50943, 1169, 0, 0, 39, '1168'),
	(243, 1, 0, -50943, 1170, 0, 0, 39, '1169'),
	(243, 1, 0, -50943, 1171, 0, 0, 39, '1170'),
	(243, 1, 0, -50943, 1172, 0, 0, 39, '1171'),
	(243, 1, 0, -50943, 1173, 0, 0, 39, '1172'),
	(243, 1, 0, -50943, 1174, 0, 0, 39, '1173'),
	(243, 1, 0, -50943, 1175, 0, 0, 39, '1174'),
	(243, 1, 0, -50943, 1176, 0, 0, 39, '1175'),
	(243, 1, 0, -50943, 1177, 0, 0, 39, '1176'),
	(243, 1, 0, -50943, 1178, 0, 0, 39, '1177'),
	(243, 1, 0, -50943, 1179, 0, 0, 39, '1178'),
	(243, 1, 0, -50943, 1180, 0, 0, 39, '1179'),
	(243, 1, 0, -50943, 1181, 0, 0, 39, '1180'),
	(243, 1, 0, -50943, 1182, 0, 0, 39, '1181'),
	(243, 1, 0, -50943, 1183, 0, 0, 39, '1182'),
	(243, 1, 0, -50943, 1184, 0, 0, 39, '1183'),
	(243, 1, 0, -50943, 1185, 0, 0, 39, '1184'),
	(243, 1, 0, -50943, 1186, 0, 0, 39, '1185'),
	(243, 1, 0, -50943, 1187, 0, 0, 39, '1186'),
	(243, 1, 0, -50943, 1188, 0, 0, 39, '1187'),
	(243, 1, 0, -50943, 1189, 0, 0, 39, '1188'),
	(243, 1, 0, -50943, 1190, 0, 0, 39, '1189'),
	(243, 1, 0, -50943, 1191, 0, 0, 39, '1190'),
	(243, 1, 0, -50943, 1192, 0, 0, 39, '1191'),
	(243, 1, 0, -50943, 1193, 0, 0, 39, '1192'),
	(243, 1, 0, -50943, 1194, 0, 0, 39, '1193'),
	(243, 1, 0, -50943, 1195, 0, 0, 39, '1194'),
	(243, 1, 0, -50943, 1196, 0, 0, 39, '1195'),
	(243, 1, 0, -50943, 1197, 0, 0, 39, '1196'),
	(243, 1, 0, -50943, 1198, 0, 0, 39, '1197'),
	(243, 1, 0, -50943, 1199, 0, 0, 39, '1198'),
	(243, 1, 0, -50943, 1200, 0, 0, 39, '1199'),
	(243, 1, 0, -50943, 1201, 0, 0, 39, '1200'),
	(243, 1, 0, -50943, 1202, 0, 0, 39, '1201'),
	(243, 1, 0, -50943, 1203, 0, 0, 39, '1202'),
	(243, 1, 0, -50943, 1204, 0, 0, 39, '1203'),
	(243, 1, 0, -50943, 1205, 0, 0, 39, '1204'),
	(243, 1, 0, -50943, 1206, 0, 0, 39, '1205'),
	(243, 1, 0, -50943, 1207, 0, 0, 39, '1206'),
	(243, 1, 0, -50943, 1208, 0, 0, 39, '1207'),
	(243, 1, 0, -50943, 1209, 0, 0, 39, '1208'),
	(243, 1, 0, -50943, 1210, 0, 0, 39, '1209'),
	(243, 1, 0, -50943, 1211, 0, 0, 39, '1210'),
	(243, 1, 0, -50943, 1212, 0, 0, 39, '1211'),
	(243, 1, 0, -50943, 1213, 0, 0, 39, '1212'),
	(243, 1, 0, -50943, 1214, 0, 0, 39, '1213'),
	(243, 1, 0, -50943, 1215, 0, 0, 39, '1214'),
	(243, 1, 0, -50943, 1216, 0, 0, 39, '1215'),
	(243, 1, 0, -50943, 1217, 0, 0, 39, '1216'),
	(243, 1, 0, -50943, 1218, 0, 0, 39, '1217'),
	(243, 1, 0, -50943, 1219, 0, 0, 39, '1218'),
	(243, 1, 0, -50943, 1220, 0, 0, 39, '1219'),
	(243, 1, 0, -50943, 1221, 0, 0, 39, '1220'),
	(243, 1, 0, -50943, 1222, 0, 0, 39, '1221'),
	(243, 1, 0, -50943, 1223, 0, 0, 39, '1222'),
	(243, 1, 0, -50943, 1224, 0, 0, 39, '1223'),
	(243, 1, 0, -50943, 1225, 0, 0, 39, '1224'),
	(243, 1, 0, -50943, 1226, 0, 0, 39, '1225'),
	(243, 1, 0, -50943, 1227, 0, 0, 39, '1226'),
	(243, 1, 0, -50943, 1228, 0, 0, 39, '1227'),
	(243, 1, 0, -50943, 1229, 0, 0, 39, '1228'),
	(243, 1, 0, -50943, 1230, 0, 0, 39, '1229'),
	(243, 1, 0, -50943, 1231, 0, 0, 39, '1230'),
	(243, 1, 0, -50943, 1232, 0, 0, 39, '1231'),
	(243, 1, 0, -50943, 1233, 0, 0, 39, '1232'),
	(243, 1, 0, -50943, 1234, 0, 0, 39, '1233'),
	(243, 1, 0, -50943, 1235, 0, 0, 39, '1234'),
	(243, 1, 0, -50943, 1236, 0, 0, 39, '1235'),
	(243, 1, 0, -50943, 1237, 0, 0, 39, '1236'),
	(243, 1, 0, -50943, 1238, 0, 0, 39, '1237'),
	(243, 1, 0, -50943, 1239, 0, 0, 39, '1238'),
	(243, 1, 0, -50943, 1240, 0, 0, 39, '1239'),
	(243, 1, 0, -50943, 1241, 0, 0, 39, '1240'),
	(243, 1, 0, -50943, 1242, 0, 0, 39, '1241'),
	(243, 1, 0, -50943, 1243, 0, 0, 39, '1242'),
	(243, 1, 0, -50943, 1244, 0, 0, 39, '1243'),
	(243, 1, 0, -50943, 1245, 0, 0, 39, '1244'),
	(243, 1, 0, -50943, 1246, 0, 0, 39, '1245'),
	(243, 1, 0, -50943, 1247, 0, 0, 39, '1246'),
	(243, 1, 0, -50943, 1248, 0, 0, 39, '1247'),
	(243, 1, 0, -50943, 1249, 0, 0, 39, '1248'),
	(243, 1, 0, -50943, 1250, 0, 0, 39, '1249'),
	(243, 1, 0, -50943, 1251, 0, 0, 39, '1250'),
	(243, 1, 0, -50943, 1252, 0, 0, 39, '1251'),
	(243, 1, 0, -50943, 1253, 0, 0, 39, '1252'),
	(243, 1, 0, -50943, 1254, 0, 0, 39, '1253'),
	(243, 1, 0, -50943, 1255, 0, 0, 39, '1254'),
	(243, 1, 0, -50943, 1256, 0, 0, 39, '1255'),
	(243, 1, 0, -50943, 1257, 0, 0, 39, '1256'),
	(243, 1, 0, -50943, 1258, 0, 0, 39, '1257'),
	(243, 1, 0, -50943, 1259, 0, 0, 39, '1258'),
	(243, 1, 0, -50943, 1260, 0, 0, 39, '1259'),
	(243, 1, 0, -50943, 1261, 0, 0, 39, '1260'),
	(243, 1, 0, -50943, 1262, 0, 0, 39, '1261'),
	(243, 1, 0, -50943, 1263, 0, 0, 39, '1262'),
	(243, 1, 0, -50943, 1264, 0, 0, 39, '1263'),
	(243, 1, 0, -50943, 1265, 0, 0, 39, '1264'),
	(243, 1, 0, -50943, 1266, 0, 0, 39, '1265'),
	(243, 1, 0, -50943, 1267, 0, 0, 39, '1266'),
	(243, 1, 0, -50943, 1268, 0, 0, 39, '1267'),
	(243, 1, 0, -50943, 1269, 0, 0, 39, '1268'),
	(243, 1, 0, -50943, 1270, 0, 0, 39, '1269'),
	(243, 1, 0, -50943, 1271, 0, 0, 39, '1270'),
	(243, 1, 0, -50943, 1272, 0, 0, 39, '1271'),
	(243, 1, 0, -50943, 1273, 0, 0, 39, '1272'),
	(243, 1, 0, -50943, 1274, 0, 0, 39, '1273'),
	(243, 1, 0, -50943, 1275, 0, 0, 39, '1274'),
	(243, 1, 0, -50943, 1276, 0, 0, 39, '1275'),
	(243, 1, 0, -50943, 1277, 0, 0, 39, '1276'),
	(243, 1, 0, -50943, 1278, 0, 0, 39, '1277'),
	(243, 1, 0, -50943, 1279, 0, 0, 39, '1278'),
	(243, 1, 0, -50943, 1280, 0, 0, 39, '1279'),
	(243, 1, 0, -50943, 1281, 0, 0, 39, '1280'),
	(243, 1, 0, -50943, 1282, 0, 0, 39, '1281'),
	(243, 1, 0, -50943, 1283, 0, 0, 39, '1282'),
	(243, 1, 0, -50943, 1284, 0, 0, 39, '1283'),
	(243, 1, 0, -50943, 1285, 0, 0, 39, '1284'),
	(243, 1, 0, -50943, 1286, 0, 0, 39, '1285'),
	(243, 1, 0, -50943, 1287, 0, 0, 39, '1286'),
	(243, 1, 0, -50943, 1288, 0, 0, 39, '1287'),
	(243, 1, 0, -50943, 1289, 0, 0, 39, '1288'),
	(243, 1, 0, -50943, 1290, 0, 0, 39, '1289'),
	(243, 1, 0, -50943, 1291, 0, 0, 39, '1290'),
	(243, 1, 0, -50943, 1292, 0, 0, 39, '1291'),
	(243, 1, 0, -50943, 1293, 0, 0, 39, '1292'),
	(243, 1, 0, -50943, 1294, 0, 0, 39, '1293'),
	(243, 1, 0, -50943, 1295, 0, 0, 39, '1294'),
	(243, 1, 0, -50943, 1296, 0, 0, 39, '1295'),
	(243, 1, 0, -50943, 1297, 0, 0, 39, '1296'),
	(243, 1, 0, -50943, 1298, 0, 0, 39, '1297'),
	(243, 1, 0, -50943, 1299, 0, 0, 39, '1298'),
	(243, 1, 0, -50943, 1300, 0, 0, 39, '1299'),
	(243, 1, 0, -50943, 1301, 0, 0, 39, '1300'),
	(243, 1, 0, -50943, 1302, 0, 0, 39, '1301'),
	(243, 1, 0, -50943, 1303, 0, 0, 39, '1302'),
	(243, 1, 0, -50943, 1304, 0, 0, 39, '1303'),
	(243, 1, 0, -50943, 1305, 0, 0, 39, '1304'),
	(243, 1, 0, -50943, 1306, 0, 0, 39, '1305'),
	(243, 1, 0, -50943, 1307, 0, 0, 39, '1306'),
	(243, 1, 0, -50943, 1308, 0, 0, 39, '1307'),
	(243, 1, 0, -50943, 1309, 0, 0, 39, '1308'),
	(243, 1, 0, -50943, 1310, 0, 0, 39, '1309'),
	(243, 1, 0, -50943, 1311, 0, 0, 39, '1310'),
	(243, 1, 0, -50943, 1312, 0, 0, 39, '1311'),
	(243, 1, 0, -50943, 1313, 0, 0, 39, '1312'),
	(243, 1, 0, -50943, 1314, 0, 0, 39, '1313'),
	(243, 1, 0, -50943, 1315, 0, 0, 39, '1314'),
	(243, 1, 0, -50943, 1316, 0, 0, 39, '1315'),
	(243, 1, 0, -50943, 1317, 0, 0, 39, '1316'),
	(243, 1, 0, -50943, 1318, 0, 0, 39, '1317'),
	(243, 1, 0, -50943, 1319, 0, 0, 39, '1318'),
	(243, 1, 0, -50943, 1320, 0, 0, 39, '1319'),
	(243, 1, 0, -50943, 1321, 0, 0, 39, '1320'),
	(243, 1, 0, -50943, 1322, 0, 0, 39, '1321'),
	(243, 1, 0, -50943, 1323, 0, 0, 39, '1322'),
	(243, 1, 0, -50943, 1324, 0, 0, 39, '1323'),
	(243, 1, 0, -50943, 1325, 0, 0, 39, '1324'),
	(243, 1, 0, -50943, 1326, 0, 0, 39, '1325'),
	(243, 1, 0, -50943, 1327, 0, 0, 39, '1326'),
	(243, 1, 0, -50943, 1328, 0, 0, 39, '1327'),
	(243, 1, 0, -50943, 1329, 0, 0, 39, '1328'),
	(243, 1, 0, -50943, 1330, 0, 0, 39, '1329'),
	(243, 1, 0, -50943, 1331, 0, 0, 39, '1330'),
	(243, 1, 0, -50943, 1332, 0, 0, 39, '1331'),
	(243, 1, 0, -50943, 1333, 0, 0, 39, '1332'),
	(243, 1, 0, -50943, 1334, 0, 0, 39, '1333'),
	(243, 1, 0, -50943, 1335, 0, 0, 39, '1334'),
	(243, 1, 0, -50943, 1336, 0, 0, 39, '1335'),
	(243, 1, 0, -50943, 1337, 0, 0, 39, '1336'),
	(243, 1, 0, -50943, 1338, 0, 0, 39, '1337'),
	(243, 1, 0, -50943, 1339, 0, 0, 39, '1338'),
	(243, 1, 0, -50943, 1340, 0, 0, 39, '1339'),
	(243, 1, 0, -50943, 1341, 0, 0, 39, '1340'),
	(243, 1, 0, -50943, 1342, 0, 0, 39, '1341'),
	(243, 1, 0, -50943, 1343, 0, 0, 39, '1342'),
	(243, 1, 0, -50943, 1344, 0, 0, 39, '1343'),
	(243, 1, 0, -50943, 1345, 0, 0, 39, '1344'),
	(243, 1, 0, -50943, 1346, 0, 0, 39, '1345'),
	(243, 1, 0, -50943, 1347, 0, 0, 39, '1346'),
	(243, 1, 0, -50943, 1348, 0, 0, 39, '1347'),
	(243, 1, 0, -50943, 1349, 0, 0, 39, '1348'),
	(243, 1, 0, -50943, 1350, 0, 0, 39, '1349'),
	(243, 1, 0, -50943, 1351, 0, 0, 39, '1350'),
	(243, 1, 0, -50943, 1352, 0, 0, 39, '1351'),
	(243, 1, 0, -50943, 1353, 0, 0, 39, '1352'),
	(243, 1, 0, -50943, 1354, 0, 0, 39, '1353'),
	(243, 1, 0, -50943, 1355, 0, 0, 39, '1354'),
	(243, 1, 0, -50943, 1356, 0, 0, 39, '1355'),
	(243, 1, 0, -50943, 1357, 0, 0, 39, '1356'),
	(243, 1, 0, -50943, 1358, 0, 0, 39, '1357'),
	(243, 1, 0, -50943, 1359, 0, 0, 39, '1358'),
	(243, 1, 0, -50943, 1360, 0, 0, 39, '1359'),
	(243, 1, 0, -50943, 1361, 0, 0, 39, '1360'),
	(243, 1, 0, -50943, 1362, 0, 0, 39, '1361'),
	(243, 1, 0, -50943, 1363, 0, 0, 39, '1362'),
	(243, 1, 0, -50943, 1364, 0, 0, 39, '1363'),
	(243, 1, 0, -50943, 1365, 0, 0, 39, '1364'),
	(243, 1, 0, -50943, 1366, 0, 0, 39, '1365'),
	(243, 1, 0, -50943, 1367, 0, 0, 39, '1366'),
	(243, 1, 0, -50943, 1368, 0, 0, 39, '1367'),
	(243, 1, 0, -50943, 1369, 0, 0, 39, '1368'),
	(243, 1, 0, -50943, 1370, 0, 0, 39, '1369'),
	(243, 1, 0, -50943, 1371, 0, 0, 39, '1370'),
	(243, 1, 0, -50943, 1372, 0, 0, 39, '1371'),
	(243, 1, 0, -50943, 1373, 0, 0, 39, '1372'),
	(243, 1, 0, -50943, 1374, 0, 0, 39, '1373'),
	(243, 1, 0, -50943, 1375, 0, 0, 39, '1374'),
	(243, 1, 0, -50943, 1376, 0, 0, 39, '1375'),
	(243, 1, 0, -50943, 1377, 0, 0, 39, '1376'),
	(243, 1, 0, -50943, 1378, 0, 0, 39, '1377'),
	(243, 1, 0, -50943, 1379, 0, 0, 39, '1378'),
	(243, 1, 0, -50943, 1380, 0, 0, 39, '1379'),
	(243, 1, 0, -50943, 1381, 0, 0, 39, '1380'),
	(243, 1, 0, -50943, 1382, 0, 0, 39, '1381'),
	(243, 1, 0, -50943, 1383, 0, 0, 39, '1382'),
	(243, 1, 0, -50943, 1384, 0, 0, 39, '1383'),
	(243, 1, 0, -50943, 1385, 0, 0, 39, '1384'),
	(243, 1, 0, -50943, 1386, 0, 0, 39, '1385'),
	(243, 1, 0, -50943, 1387, 0, 0, 39, '1386'),
	(243, 1, 0, -50943, 1388, 0, 0, 39, '1387'),
	(243, 1, 0, -50943, 1389, 0, 0, 39, '1388'),
	(243, 1, 0, -50943, 1390, 0, 0, 39, '1389'),
	(243, 1, 0, -50943, 1391, 0, 0, 39, '1390'),
	(243, 1, 0, -50943, 1392, 0, 0, 39, '1391'),
	(243, 1, 0, -50943, 1393, 0, 0, 39, '1392'),
	(243, 1, 0, -50943, 1394, 0, 0, 39, '1393'),
	(243, 1, 0, -50943, 1395, 0, 0, 39, '1394'),
	(243, 1, 0, -50943, 1396, 0, 0, 39, '1395'),
	(243, 1, 0, -50943, 1397, 0, 0, 39, '1396'),
	(243, 1, 0, -50943, 1398, 0, 0, 39, '1397'),
	(243, 1, 0, -50943, 1399, 0, 0, 39, '1398'),
	(243, 1, 0, -50943, 1400, 0, 0, 39, '1399'),
	(243, 1, 0, -50943, 1401, 0, 0, 39, '1400'),
	(243, 1, 0, -50943, 1402, 0, 0, 39, '1401'),
	(243, 1, 0, -50943, 1403, 0, 0, 39, '1402'),
	(243, 1, 0, -50943, 1404, 0, 0, 39, '1403'),
	(243, 1, 0, -50943, 1405, 0, 0, 39, '1404'),
	(243, 1, 0, -50943, 1406, 0, 0, 39, '1405'),
	(243, 1, 0, -50943, 1407, 0, 0, 39, '1406'),
	(243, 1, 0, -50943, 1408, 0, 0, 39, '1407'),
	(243, 1, 0, -50943, 1409, 0, 0, 39, '1408'),
	(243, 1, 0, -50943, 1410, 0, 0, 39, '1409'),
	(243, 1, 0, -50943, 1411, 0, 0, 39, '1410'),
	(243, 1, 0, -50943, 1412, 0, 0, 39, '1411'),
	(243, 1, 0, -50943, 1413, 0, 0, 39, '1412'),
	(243, 1, 0, -50943, 1414, 0, 0, 39, '1413'),
	(243, 1, 0, -50943, 1415, 0, 0, 39, '1414'),
	(243, 1, 0, -50943, 1416, 0, 0, 39, '1415'),
	(243, 1, 0, -50943, 1417, 0, 0, 39, '1416'),
	(243, 1, 0, -50943, 1418, 0, 0, 39, '1417'),
	(243, 1, 0, -50943, 1419, 0, 0, 39, '1418'),
	(243, 1, 0, -50943, 1420, 0, 0, 39, '1419'),
	(243, 1, 0, -50943, 1421, 0, 0, 39, '1420'),
	(243, 1, 0, -50943, 1422, 0, 0, 39, '1421'),
	(243, 1, 0, -50943, 1423, 0, 0, 39, '1422'),
	(243, 1, 0, -50943, 1424, 0, 0, 39, '1423'),
	(243, 1, 0, -50943, 1425, 0, 0, 39, '1424'),
	(243, 1, 0, -50943, 1426, 0, 0, 39, '1425'),
	(243, 1, 0, -50943, 1427, 0, 0, 39, '1426'),
	(243, 1, 0, -50943, 1428, 0, 0, 39, '1427'),
	(243, 1, 0, -50943, 1429, 0, 0, 39, '1428'),
	(243, 1, 0, -50943, 1430, 0, 0, 39, '1429'),
	(243, 1, 0, -50943, 1431, 0, 0, 39, '1430'),
	(243, 1, 0, -50943, 1432, 0, 0, 39, '1431'),
	(243, 1, 0, -50943, 1433, 0, 0, 39, '1432'),
	(243, 1, 0, -50943, 1434, 0, 0, 39, '1433'),
	(243, 1, 0, -50943, 1435, 0, 0, 39, '1434'),
	(243, 1, 0, -50943, 1436, 0, 0, 39, '1435'),
	(243, 1, 0, -50943, 1437, 0, 0, 39, '1436'),
	(243, 1, 0, -50943, 1438, 0, 0, 39, '1437'),
	(243, 1, 0, -50943, 1439, 0, 0, 39, '1438'),
	(243, 1, 0, -50943, 1440, 0, 0, 39, '1439'),
	(243, 1, 0, -50943, 1441, 0, 0, 39, '1440'),
	(243, 1, 0, -50943, 1442, 0, 0, 39, '1441'),
	(243, 1, 0, -50943, 1443, 0, 0, 39, '1442'),
	(243, 1, 0, -50943, 1444, 0, 0, 39, '1443'),
	(243, 1, 0, -50943, 1445, 0, 0, 39, '1444'),
	(243, 1, 0, -50943, 1446, 0, 0, 39, '1445'),
	(243, 1, 0, -50943, 1447, 0, 0, 39, '1446'),
	(243, 1, 0, -50943, 1448, 0, 0, 39, '1447'),
	(243, 1, 0, -50943, 1449, 0, 0, 39, '1448'),
	(243, 1, 0, -50943, 1450, 0, 0, 39, '1449'),
	(243, 1, 0, -50943, 1451, 0, 0, 39, '1450'),
	(243, 1, 0, -50943, 1452, 0, 0, 39, '1451'),
	(243, 1, 0, -50943, 1453, 0, 0, 39, '1452'),
	(243, 1, 0, -50943, 1454, 0, 0, 39, '1453'),
	(243, 1, 0, -50943, 1455, 0, 0, 39, '1454'),
	(243, 1, 0, -50943, 1456, 0, 0, 39, '1455'),
	(243, 1, 0, -50943, 1457, 0, 0, 39, '1456'),
	(243, 1, 0, -50943, 1458, 0, 0, 39, '1457'),
	(243, 1, 0, -50943, 1459, 0, 0, 39, '1458'),
	(243, 1, 0, -50943, 1460, 0, 0, 39, '1459'),
	(243, 1, 0, -50943, 1461, 0, 0, 39, '1460'),
	(243, 1, 0, -50943, 1462, 0, 0, 39, '1461'),
	(243, 1, 0, -50943, 1463, 0, 0, 39, '1462'),
	(243, 1, 0, -50943, 1464, 0, 0, 39, '1463'),
	(243, 1, 0, -50943, 1465, 0, 0, 39, '1464'),
	(243, 1, 0, -50943, 1466, 0, 0, 39, '1465'),
	(243, 1, 0, -50943, 1467, 0, 0, 39, '1466'),
	(243, 1, 0, -50943, 1468, 0, 0, 39, '1467'),
	(243, 1, 0, -50943, 1469, 0, 0, 39, '1468'),
	(243, 1, 0, -50943, 1470, 0, 0, 39, '1469'),
	(243, 1, 0, -50943, 1471, 0, 0, 39, '1470'),
	(243, 1, 0, -50943, 1472, 0, 0, 39, '1471'),
	(243, 1, 0, -50943, 1473, 0, 0, 39, '1472'),
	(243, 1, 0, -50943, 1474, 0, 0, 39, '1473'),
	(243, 1, 0, -50943, 1475, 0, 0, 39, '1474'),
	(243, 1, 0, -50943, 1476, 0, 0, 39, '1475'),
	(243, 1, 0, -50943, 1477, 0, 0, 39, '1476'),
	(243, 1, 0, -50943, 1478, 0, 0, 39, '1477'),
	(243, 1, 0, -50943, 1479, 0, 0, 39, '1478'),
	(243, 1, 0, -50943, 1480, 0, 0, 39, '1479'),
	(243, 1, 0, -50943, 1481, 0, 0, 39, '1480'),
	(243, 1, 0, -50943, 1482, 0, 0, 39, '1481'),
	(243, 1, 0, -50943, 1483, 0, 0, 39, '1482'),
	(243, 1, 0, -50943, 1484, 0, 0, 39, '1483'),
	(243, 1, 0, -50943, 1485, 0, 0, 39, '1484'),
	(243, 1, 0, -50943, 1486, 0, 0, 39, '1485'),
	(243, 1, 0, -50943, 1487, 0, 0, 39, '1486'),
	(243, 1, 0, -50943, 1488, 0, 0, 39, '1487'),
	(243, 1, 0, -50943, 1489, 0, 0, 39, '1488'),
	(243, 1, 0, -50943, 1490, 0, 0, 39, '1489'),
	(243, 1, 0, -50943, 1491, 0, 0, 39, '1490'),
	(243, 1, 0, -50943, 1492, 0, 0, 39, '1491'),
	(243, 1, 0, -50943, 1493, 0, 0, 39, '1492'),
	(243, 1, 0, -50943, 1494, 0, 0, 39, '1493'),
	(243, 1, 0, -50943, 1495, 0, 0, 39, '1494'),
	(243, 1, 0, -50943, 1496, 0, 0, 39, '1495'),
	(243, 1, 0, -50943, 1497, 0, 0, 39, '1496'),
	(243, 1, 0, -50943, 1498, 0, 0, 39, '1497'),
	(243, 1, 0, -50943, 1499, 0, 0, 39, '1498'),
	(243, 1, 0, -50943, 1500, 0, 0, 39, '1499'),
	(243, 1, 0, -50943, 1501, 0, 0, 39, '1500'),
	(243, 1, 0, -50943, 1502, 0, 0, 39, '1501'),
	(243, 1, 0, -50943, 1503, 0, 0, 39, '1502'),
	(243, 1, 0, -50943, 1504, 0, 0, 39, '1503'),
	(243, 1, 0, -50943, 1505, 0, 0, 39, '1504'),
	(243, 1, 0, -50943, 1506, 0, 0, 39, '1505'),
	(243, 1, 0, -50943, 1507, 0, 0, 39, '1506'),
	(243, 1, 0, -50943, 1508, 0, 0, 39, '1507'),
	(243, 1, 0, -50943, 1509, 0, 0, 39, '1508'),
	(243, 1, 0, -50943, 1510, 0, 0, 39, '1509'),
	(243, 1, 0, -50943, 1511, 0, 0, 39, '1510'),
	(243, 1, 0, -50943, 1512, 0, 0, 39, '1511'),
	(243, 1, 0, -50943, 1513, 0, 0, 39, '1512'),
	(243, 1, 0, -50943, 1514, 0, 0, 39, '1513'),
	(243, 1, 0, -50943, 1515, 0, 0, 39, '1514'),
	(243, 1, 0, -50943, 1516, 0, 0, 39, '1515'),
	(243, 1, 0, -50943, 1517, 0, 0, 39, '1516'),
	(243, 1, 0, -50943, 1518, 0, 0, 39, '1517'),
	(243, 1, 0, -50943, 1519, 0, 0, 39, '1518'),
	(243, 1, 0, -50943, 1520, 0, 0, 39, '1519'),
	(243, 1, 0, -50943, 1521, 0, 0, 39, '1520'),
	(243, 1, 0, -50943, 1522, 0, 0, 39, '1521'),
	(243, 1, 0, -50943, 1523, 0, 0, 39, '1522'),
	(243, 1, 0, -50943, 1524, 0, 0, 39, '1523'),
	(243, 1, 0, -50943, 1525, 0, 0, 39, '1524'),
	(243, 1, 0, -50943, 1526, 0, 0, 39, '1525'),
	(243, 1, 0, -50943, 1527, 0, 0, 39, '1526'),
	(243, 1, 0, -50943, 1528, 0, 0, 39, '1527'),
	(243, 1, 0, -50943, 1529, 0, 0, 39, '1528'),
	(243, 1, 0, -50943, 1530, 0, 0, 39, '1529'),
	(243, 1, 0, -50943, 1531, 0, 0, 39, '1530'),
	(243, 1, 0, -50943, 1532, 0, 0, 39, '1531'),
	(243, 1, 0, -50943, 1533, 0, 0, 39, '1532'),
	(243, 1, 0, -50943, 1534, 0, 0, 39, '1533'),
	(243, 1, 0, -50943, 1535, 0, 0, 39, '1534'),
	(243, 1, 0, -50943, 1536, 0, 0, 39, '1535'),
	(243, 1, 0, -50943, 1537, 0, 0, 39, '1536'),
	(243, 1, 0, -50943, 1538, 0, 0, 39, '1537'),
	(243, 1, 0, -50943, 1539, 0, 0, 39, '1538'),
	(243, 1, 0, -50943, 1540, 0, 0, 39, '1539'),
	(243, 1, 0, -50943, 1541, 0, 0, 39, '1540'),
	(243, 1, 0, -50943, 1542, 0, 0, 39, '1541'),
	(243, 1, 0, -50943, 1543, 0, 0, 39, '1542'),
	(243, 1, 0, -50943, 1544, 0, 0, 39, '1543'),
	(243, 1, 0, -50943, 1545, 0, 0, 39, '1544'),
	(243, 1, 0, -50943, 1546, 0, 0, 39, '1545'),
	(243, 1, 0, -50943, 1547, 0, 0, 39, '1546'),
	(243, 1, 0, -50943, 1548, 0, 0, 39, '1547'),
	(243, 1, 0, -50943, 1549, 0, 0, 39, '1548'),
	(243, 1, 0, -50943, 1550, 0, 0, 39, '1549'),
	(243, 1, 0, -50943, 1551, 0, 0, 39, '1550'),
	(243, 1, 0, -50943, 1552, 0, 0, 39, '1551'),
	(243, 1, 0, -50943, 1553, 0, 0, 39, '1552'),
	(243, 1, 0, -50943, 1554, 0, 0, 39, '1553'),
	(243, 1, 0, -50943, 1555, 0, 0, 39, '1554'),
	(243, 1, 0, -50943, 1556, 0, 0, 39, '1555'),
	(243, 1, 0, -50943, 1557, 0, 0, 39, '1556'),
	(243, 1, 0, -50943, 1558, 0, 0, 39, '1557'),
	(243, 1, 0, -50943, 1559, 0, 0, 39, '1558'),
	(243, 1, 0, -50943, 1560, 0, 0, 39, '1559'),
	(243, 1, 0, -50943, 1561, 0, 0, 39, '1560'),
	(243, 1, 0, -50943, 1562, 0, 0, 39, '1561'),
	(243, 1, 0, -50943, 1563, 0, 0, 39, '1562'),
	(243, 1, 0, -50943, 1564, 0, 0, 39, '1563'),
	(243, 1, 0, -50943, 1565, 0, 0, 39, '1564'),
	(243, 1, 0, -50943, 1566, 0, 0, 39, '1565'),
	(243, 1, 0, -50943, 1567, 0, 0, 39, '1566'),
	(243, 1, 0, -50943, 1568, 0, 0, 39, '1567'),
	(243, 1, 0, -50943, 1569, 0, 0, 39, '1568'),
	(243, 1, 0, -50943, 1570, 0, 0, 39, '1569'),
	(243, 1, 0, -50943, 1571, 0, 0, 39, '1570'),
	(243, 1, 0, -50943, 1572, 0, 0, 39, '1571'),
	(243, 1, 0, -50943, 1573, 0, 0, 39, '1572'),
	(243, 1, 0, -50943, 1574, 0, 0, 39, '1573'),
	(243, 1, 0, -50943, 1575, 0, 0, 39, '1574'),
	(243, 1, 0, -50943, 1576, 0, 0, 39, '1575'),
	(243, 1, 0, -50943, 1577, 0, 0, 39, '1576'),
	(243, 1, 0, -50943, 1578, 0, 0, 39, '1577'),
	(243, 1, 0, -50943, 1579, 0, 0, 39, '1578'),
	(243, 1, 0, -50943, 1580, 0, 0, 39, '1579'),
	(243, 1, 0, -50943, 1581, 0, 0, 39, '1580'),
	(243, 1, 0, -50943, 1582, 0, 0, 39, '1581'),
	(243, 1, 0, -50943, 1583, 0, 0, 39, '1582'),
	(243, 1, 0, -50943, 1584, 0, 0, 39, '1583'),
	(243, 1, 0, -50943, 1585, 0, 0, 39, '1584'),
	(243, 1, 0, -50943, 1586, 0, 0, 39, '1585'),
	(243, 1, 0, -50943, 1587, 0, 0, 39, '1586'),
	(243, 1, 0, -50943, 1588, 0, 0, 39, '1587'),
	(243, 1, 0, -50943, 1589, 0, 0, 39, '1588'),
	(243, 1, 0, -50943, 1590, 0, 0, 39, '1589'),
	(243, 1, 0, -50943, 1591, 0, 0, 39, '1590'),
	(243, 1, 0, -50943, 1592, 0, 0, 39, '1591'),
	(243, 1, 0, -50943, 1593, 0, 0, 39, '1592'),
	(243, 1, 0, -50943, 1594, 0, 0, 39, '1593'),
	(243, 1, 0, -50943, 1595, 0, 0, 39, '1594'),
	(243, 1, 0, -50943, 1596, 0, 0, 39, '1595'),
	(243, 1, 0, -50943, 1597, 0, 0, 39, '1596'),
	(243, 1, 0, -50943, 1598, 0, 0, 39, '1597'),
	(243, 1, 0, -50943, 1599, 0, 0, 39, '1598'),
	(243, 1, 0, -50943, 1600, 0, 0, 39, '1599'),
	(243, 1, 0, -50943, 1601, 0, 0, 39, '1600'),
	(243, 1, 0, -50943, 1602, 0, 0, 39, '1601'),
	(243, 1, 0, -50943, 1603, 0, 0, 39, '1602'),
	(243, 1, 0, -50943, 1604, 0, 0, 39, '1603'),
	(243, 1, 0, -50943, 1605, 0, 0, 39, '1604'),
	(243, 1, 0, -50943, 1606, 0, 0, 39, '1605'),
	(243, 1, 0, -50943, 1607, 0, 0, 39, '1606'),
	(243, 1, 0, -50943, 1608, 0, 0, 39, '1607'),
	(243, 1, 0, -50943, 1609, 0, 0, 39, '1608'),
	(243, 1, 0, -50943, 1610, 0, 0, 39, '1609'),
	(243, 1, 0, -50943, 1611, 0, 0, 39, '1610'),
	(243, 1, 0, -50943, 1612, 0, 0, 39, '1611'),
	(243, 1, 0, -50943, 1613, 0, 0, 39, '1612'),
	(243, 1, 0, -50943, 1614, 0, 0, 39, '1613'),
	(243, 1, 0, -50943, 1615, 0, 0, 39, '1614'),
	(243, 1, 0, -50943, 1616, 0, 0, 39, '1615'),
	(243, 1, 0, -50943, 1617, 0, 0, 39, '1616'),
	(243, 1, 0, -50943, 1618, 0, 0, 39, '1617'),
	(243, 1, 0, -50943, 1619, 0, 0, 39, '1618'),
	(243, 1, 0, -50943, 1620, 0, 0, 39, '1619'),
	(243, 1, 0, -50943, 1621, 0, 0, 39, '1620'),
	(243, 1, 0, -50943, 1622, 0, 0, 39, '1621'),
	(243, 1, 0, -50943, 1623, 0, 0, 39, '1622'),
	(243, 1, 0, -50943, 1624, 0, 0, 39, '1623'),
	(243, 1, 0, -50943, 1625, 0, 0, 39, '1624'),
	(243, 1, 0, -50943, 1626, 0, 0, 39, '1625'),
	(243, 1, 0, -50943, 1627, 0, 0, 39, '1626'),
	(243, 1, 0, -50943, 1628, 0, 0, 39, '1627'),
	(243, 1, 0, -50943, 1629, 0, 0, 39, '1628'),
	(243, 1, 0, -50943, 1630, 0, 0, 39, '1629'),
	(243, 1, 0, -50943, 1631, 0, 0, 39, '1630'),
	(243, 1, 0, -50943, 1632, 0, 0, 39, '1631'),
	(243, 1, 0, -50943, 1633, 0, 0, 39, '1632'),
	(243, 1, 0, -50943, 1634, 0, 0, 39, '1633'),
	(243, 1, 0, -50943, 1635, 0, 0, 39, '1634'),
	(243, 1, 0, -50943, 1636, 0, 0, 39, '1635'),
	(243, 1, 0, -50943, 1637, 0, 0, 39, '1636'),
	(243, 1, 0, -50943, 1638, 0, 0, 39, '1637'),
	(243, 1, 0, -50943, 1639, 0, 0, 39, '1638'),
	(243, 1, 0, -50943, 1640, 0, 0, 39, '1639'),
	(243, 1, 0, -50943, 1641, 0, 0, 39, '1640'),
	(243, 1, 0, -50943, 1642, 0, 0, 39, '1641'),
	(243, 1, 0, -50943, 1643, 0, 0, 39, '1642'),
	(243, 1, 0, -50943, 1644, 0, 0, 39, '1643'),
	(243, 1, 0, -50943, 1645, 0, 0, 39, '1644'),
	(243, 1, 0, -50943, 1646, 0, 0, 39, '1645'),
	(243, 1, 0, -50943, 1647, 0, 0, 39, '1646'),
	(243, 1, 0, -50943, 1648, 0, 0, 39, '1647'),
	(243, 1, 0, -50943, 1649, 0, 0, 39, '1648'),
	(243, 1, 0, -50943, 1650, 0, 0, 39, '1649'),
	(243, 1, 0, -50943, 1651, 0, 0, 39, '1650'),
	(243, 1, 0, -50943, 1652, 0, 0, 39, '1651'),
	(243, 1, 0, -50943, 1653, 0, 0, 39, '1652'),
	(243, 1, 0, -50943, 1654, 0, 0, 39, '1653'),
	(243, 1, 0, -50943, 1655, 0, 0, 39, '1654'),
	(243, 1, 0, -50943, 1656, 0, 0, 39, '1655'),
	(243, 1, 0, -50943, 1657, 0, 0, 39, '1656'),
	(243, 1, 0, -50943, 1658, 0, 0, 39, '1657'),
	(243, 1, 0, -50943, 1659, 0, 0, 39, '1658'),
	(243, 1, 0, -50943, 1660, 0, 0, 39, '1659'),
	(243, 1, 0, -50943, 1661, 0, 0, 39, '1660'),
	(243, 1, 0, -50943, 1662, 0, 0, 39, '1661'),
	(243, 1, 0, -50943, 1663, 0, 0, 39, '1662'),
	(243, 1, 0, -50943, 1664, 0, 0, 39, '1663'),
	(243, 1, 0, -50943, 1665, 0, 0, 39, '1664'),
	(243, 1, 0, -50943, 1666, 0, 0, 39, '1665'),
	(243, 1, 0, -50943, 1667, 0, 0, 39, '1666'),
	(243, 1, 0, -50943, 1668, 0, 0, 39, '1667'),
	(243, 1, 0, -50943, 1669, 0, 0, 39, '1668'),
	(243, 1, 0, -50943, 1670, 0, 0, 39, '1669'),
	(243, 1, 0, -50943, 1671, 0, 0, 39, '1670'),
	(243, 1, 0, -50943, 1672, 0, 0, 39, '1671'),
	(243, 1, 0, -50943, 1673, 0, 0, 39, '1672'),
	(243, 1, 0, -50943, 1674, 0, 0, 39, '1673'),
	(243, 1, 0, -50943, 1675, 0, 0, 39, '1674'),
	(243, 1, 0, -50943, 1676, 0, 0, 39, '1675'),
	(243, 1, 0, -50943, 1677, 0, 0, 39, '1676'),
	(243, 1, 0, -50943, 1678, 0, 0, 39, '1677'),
	(243, 1, 0, -50943, 1679, 0, 0, 39, '1678'),
	(243, 1, 0, -50943, 1680, 0, 0, 39, '1679'),
	(243, 1, 0, -50943, 1681, 0, 0, 39, '1680'),
	(243, 1, 0, -50943, 1682, 0, 0, 39, '1681'),
	(243, 1, 0, -50943, 1683, 0, 0, 39, '1682'),
	(243, 1, 0, -50943, 1684, 0, 0, 39, '1683'),
	(243, 1, 0, -50943, 1685, 0, 0, 39, '1684'),
	(243, 1, 0, -50943, 1686, 0, 0, 39, '1685'),
	(243, 1, 0, -50943, 1687, 0, 0, 39, '1686'),
	(243, 1, 0, -50943, 1688, 0, 0, 39, '1687'),
	(243, 1, 0, -50943, 1689, 0, 0, 39, '1688'),
	(243, 1, 0, -50943, 1690, 0, 0, 39, '1689'),
	(243, 1, 0, -50943, 1691, 0, 0, 39, '1690'),
	(243, 1, 0, -50943, 1692, 0, 0, 39, '1691'),
	(243, 1, 0, -50943, 1693, 0, 0, 39, '1692'),
	(243, 1, 0, -50943, 1694, 0, 0, 39, '1693'),
	(243, 1, 0, -50943, 1695, 0, 0, 39, '1694'),
	(243, 1, 0, -50943, 1696, 0, 0, 39, '1695'),
	(243, 1, 0, -50943, 1697, 0, 0, 39, '1696'),
	(243, 1, 0, -50943, 1698, 0, 0, 39, '1697'),
	(243, 1, 0, -50943, 1699, 0, 0, 39, '1698'),
	(243, 1, 0, -50943, 1700, 0, 0, 39, '1699'),
	(243, 1, 0, -50943, 1701, 0, 0, 39, '1700'),
	(243, 1, 0, -50943, 1702, 0, 0, 39, '1701'),
	(243, 1, 0, -50943, 1703, 0, 0, 39, '1702'),
	(243, 1, 0, -50943, 1704, 0, 0, 39, '1703'),
	(243, 1, 0, -50943, 1705, 0, 0, 39, '1704'),
	(243, 1, 0, -50943, 1706, 0, 0, 39, '1705'),
	(243, 1, 0, -50943, 1707, 0, 0, 39, '1706'),
	(243, 1, 0, -50943, 1708, 0, 0, 39, '1707'),
	(243, 1, 0, -50943, 1709, 0, 0, 39, '1708'),
	(243, 1, 0, -50943, 1710, 0, 0, 39, '1709'),
	(243, 1, 0, -50943, 1711, 0, 0, 39, '1710'),
	(243, 1, 0, -50943, 1712, 0, 0, 39, '1711'),
	(243, 1, 0, -50943, 1713, 0, 0, 39, '1712'),
	(243, 1, 0, -50943, 1714, 0, 0, 39, '1713'),
	(243, 1, 0, -50943, 1715, 0, 0, 39, '1714'),
	(243, 1, 0, -50943, 1716, 0, 0, 39, '1715'),
	(243, 1, 0, -50943, 1717, 0, 0, 39, '1716'),
	(243, 1, 0, -50943, 1718, 0, 0, 39, '1717'),
	(243, 1, 0, -50943, 1719, 0, 0, 39, '1718'),
	(243, 1, 0, -50943, 1720, 0, 0, 39, '1719'),
	(243, 1, 0, -50943, 1721, 0, 0, 39, '1720'),
	(243, 1, 0, -50943, 1722, 0, 0, 39, '1721'),
	(243, 1, 0, -50943, 1723, 0, 0, 39, '1722'),
	(243, 1, 0, -50943, 1724, 0, 0, 39, '1723'),
	(243, 1, 0, -50943, 1725, 0, 0, 39, '1724'),
	(243, 1, 0, -50943, 1726, 0, 0, 39, '1725'),
	(243, 1, 0, -50943, 1727, 0, 0, 39, '1726'),
	(243, 1, 0, -50943, 1728, 0, 0, 39, '1727'),
	(243, 1, 0, -50943, 1729, 0, 0, 39, '1728'),
	(243, 1, 0, -50943, 1730, 0, 0, 39, '1729'),
	(243, 1, 0, -50943, 1731, 0, 0, 39, '1730'),
	(243, 1, 0, -50943, 1732, 0, 0, 39, '1731'),
	(243, 1, 0, -50943, 1733, 0, 0, 39, '1732'),
	(243, 1, 0, -50943, 1734, 0, 0, 39, '1733'),
	(243, 1, 0, -50943, 1735, 0, 0, 39, '1734'),
	(243, 1, 0, -50943, 1736, 0, 0, 39, '1735'),
	(243, 1, 0, -50943, 1737, 0, 0, 39, '1736'),
	(243, 1, 0, -50943, 1738, 0, 0, 39, '1737'),
	(243, 1, 0, -50943, 1739, 0, 0, 39, '1738'),
	(243, 1, 0, -50943, 1740, 0, 0, 39, '1739'),
	(243, 1, 0, -50943, 1741, 0, 0, 39, '1740'),
	(243, 1, 0, -50943, 1742, 0, 0, 39, '1741'),
	(243, 1, 0, -50943, 1743, 0, 0, 39, '1742'),
	(243, 1, 0, -50943, 1744, 0, 0, 39, '1743'),
	(243, 1, 0, -50943, 1745, 0, 0, 39, '1744'),
	(243, 1, 0, -50943, 1746, 0, 0, 39, '1745'),
	(243, 1, 0, -50943, 1747, 0, 0, 39, '1746'),
	(243, 1, 0, -50943, 1748, 0, 0, 39, '1747'),
	(243, 1, 0, -50943, 1749, 0, 0, 39, '1748'),
	(243, 1, 0, -50943, 1750, 0, 0, 39, '1749'),
	(243, 1, 0, -50943, 1751, 0, 0, 39, '1750'),
	(243, 1, 0, -50943, 1752, 0, 0, 39, '1751'),
	(243, 1, 0, -50943, 1753, 0, 0, 39, '1752'),
	(243, 1, 0, -50943, 1754, 0, 0, 39, '1753'),
	(243, 1, 0, -50943, 1755, 0, 0, 39, '1754'),
	(243, 1, 0, -50943, 1756, 0, 0, 39, '1755'),
	(243, 1, 0, -50943, 1757, 0, 0, 39, '1756'),
	(243, 1, 0, -50943, 1758, 0, 0, 39, '1757'),
	(243, 1, 0, -50943, 1759, 0, 0, 39, '1758'),
	(243, 1, 0, -50943, 1760, 0, 0, 39, '1759'),
	(243, 1, 0, -50943, 1761, 0, 0, 39, '1760'),
	(243, 1, 0, -50943, 1762, 0, 0, 39, '1761'),
	(243, 1, 0, -50943, 1763, 0, 0, 39, '1762'),
	(243, 1, 0, -50943, 1764, 0, 0, 39, '1763'),
	(243, 1, 0, -50943, 1765, 0, 0, 39, '1764'),
	(243, 1, 0, -50943, 1766, 0, 0, 39, '1765'),
	(243, 1, 0, -50943, 1767, 0, 0, 39, '1766'),
	(243, 1, 0, -50943, 1768, 0, 0, 39, '1767'),
	(243, 1, 0, -50943, 1769, 0, 0, 39, '1768'),
	(243, 1, 0, -50943, 1770, 0, 0, 39, '1769'),
	(243, 1, 0, -50943, 1771, 0, 0, 39, '1770'),
	(243, 1, 0, -50943, 1772, 0, 0, 39, '1771'),
	(243, 1, 0, -50943, 1773, 0, 0, 39, '1772'),
	(243, 1, 0, -50943, 1774, 0, 0, 39, '1773'),
	(243, 1, 0, -50943, 1775, 0, 0, 39, '1774'),
	(243, 1, 0, -50943, 1776, 0, 0, 39, '1775'),
	(243, 1, 0, -50943, 1777, 0, 0, 39, '1776'),
	(243, 1, 0, -50943, 1778, 0, 0, 39, '1777'),
	(243, 1, 0, -50943, 1779, 0, 0, 39, '1778'),
	(243, 1, 0, -50943, 1780, 0, 0, 39, '1779'),
	(243, 1, 0, -50943, 1781, 0, 0, 39, '1780'),
	(243, 1, 0, -50943, 1782, 0, 0, 39, '1781'),
	(243, 1, 0, -50943, 1783, 0, 0, 39, '1782'),
	(243, 1, 0, -50943, 1784, 0, 0, 39, '1783'),
	(243, 1, 0, -50943, 1785, 0, 0, 39, '1784'),
	(243, 1, 0, -50943, 1786, 0, 0, 39, '1785'),
	(243, 1, 0, -50943, 1787, 0, 0, 39, '1786'),
	(243, 1, 0, -50943, 1788, 0, 0, 39, '1787'),
	(243, 1, 0, -50943, 1789, 0, 0, 39, '1788'),
	(243, 1, 0, -50943, 1790, 0, 0, 39, '1789'),
	(243, 1, 0, -50943, 1791, 0, 0, 39, '1790'),
	(243, 1, 0, -50943, 1792, 0, 0, 39, '1791'),
	(243, 1, 0, -50943, 1793, 0, 0, 39, '1792'),
	(243, 1, 0, -50943, 1794, 0, 0, 39, '1793'),
	(243, 1, 0, -50943, 1795, 0, 0, 39, '1794'),
	(243, 1, 0, -50943, 1796, 0, 0, 39, '1795'),
	(243, 1, 0, -50943, 1797, 0, 0, 39, '1796'),
	(243, 1, 0, -50943, 1798, 0, 0, 39, '1797'),
	(243, 1, 0, -50943, 1799, 0, 0, 39, '1798'),
	(243, 1, 0, -50943, 1800, 0, 0, 39, '1799'),
	(243, 1, 0, -50943, 1801, 0, 0, 39, '1800'),
	(243, 1, 0, -50943, 1802, 0, 0, 39, '1801'),
	(243, 1, 0, -50943, 1803, 0, 0, 39, '1802'),
	(243, 1, 0, -50943, 1804, 0, 0, 39, '1803'),
	(243, 1, 0, -50943, 1805, 0, 0, 39, '1804'),
	(243, 1, 0, -50943, 1806, 0, 0, 39, '1805'),
	(243, 1, 0, -50943, 1807, 0, 0, 39, '1806'),
	(243, 1, 0, -50943, 1808, 0, 0, 39, '1807'),
	(243, 1, 0, -50943, 1809, 0, 0, 39, '1808'),
	(243, 1, 0, -50943, 1810, 0, 0, 39, '1809'),
	(243, 1, 0, -50943, 1811, 0, 0, 39, '1810'),
	(243, 1, 0, -50943, 1812, 0, 0, 39, '1811'),
	(243, 1, 0, -50943, 1813, 0, 0, 39, '1812'),
	(243, 1, 0, -50943, 1814, 0, 0, 39, '1813'),
	(243, 1, 0, -50943, 1815, 0, 0, 39, '1814'),
	(243, 1, 0, -50943, 1816, 0, 0, 39, '1815'),
	(243, 1, 0, -50943, 1817, 0, 0, 39, '1816'),
	(243, 1, 0, -50943, 1818, 0, 0, 39, '1817'),
	(243, 1, 0, -50943, 1819, 0, 0, 39, '1818'),
	(243, 1, 0, -50943, 1820, 0, 0, 39, '1819'),
	(243, 1, 0, -50943, 1821, 0, 0, 39, '1820'),
	(243, 1, 0, -50943, 1822, 0, 0, 39, '1821'),
	(243, 1, 0, -50943, 1823, 0, 0, 39, '1822'),
	(243, 1, 0, -50943, 1824, 0, 0, 39, '1823'),
	(243, 1, 0, -50943, 1825, 0, 0, 39, '1824'),
	(243, 1, 0, -50943, 1826, 0, 0, 39, '1825'),
	(243, 1, 0, -50943, 1827, 0, 0, 39, '1826'),
	(243, 1, 0, -50943, 1828, 0, 0, 39, '1827'),
	(243, 1, 0, -50943, 1829, 0, 0, 39, '1828'),
	(243, 1, 0, -50943, 1830, 0, 0, 39, '1829'),
	(243, 1, 0, -50943, 1831, 0, 0, 39, '1830'),
	(243, 1, 0, -50943, 1832, 0, 0, 39, '1831'),
	(243, 1, 0, -50943, 1833, 0, 0, 39, '1832'),
	(243, 1, 0, -50943, 1834, 0, 0, 39, '1833'),
	(243, 1, 0, -50943, 1835, 0, 0, 39, '1834'),
	(243, 1, 0, -50943, 1836, 0, 0, 39, '1835'),
	(243, 1, 0, -50943, 1837, 0, 0, 39, '1836'),
	(243, 1, 0, -50943, 1838, 0, 0, 39, '1837'),
	(243, 1, 0, -50943, 1839, 0, 0, 39, '1838'),
	(243, 1, 0, -50943, 1840, 0, 0, 39, '1839'),
	(243, 1, 0, -50943, 1841, 0, 0, 39, '1840'),
	(243, 1, 0, -50943, 1842, 0, 0, 39, '1841'),
	(243, 1, 0, -50943, 1843, 0, 0, 39, '1842'),
	(243, 1, 0, -50943, 1844, 0, 0, 39, '1843'),
	(243, 1, 0, -50943, 1845, 0, 0, 39, '1844'),
	(243, 1, 0, -50943, 1846, 0, 0, 39, '1845'),
	(243, 1, 0, -50943, 1847, 0, 0, 39, '1846'),
	(243, 1, 0, -50943, 1848, 0, 0, 39, '1847'),
	(243, 1, 0, -50943, 1849, 0, 0, 39, '1848'),
	(243, 1, 0, -50943, 1850, 0, 0, 39, '1849'),
	(243, 1, 0, -50943, 1851, 0, 0, 39, '1850'),
	(243, 1, 0, -50943, 1852, 0, 0, 39, '1851'),
	(243, 1, 0, -50943, 1853, 0, 0, 39, '1852'),
	(243, 1, 0, -50943, 1854, 0, 0, 39, '1853'),
	(243, 1, 0, -50943, 1855, 0, 0, 39, '1854'),
	(243, 1, 0, -50943, 1856, 0, 0, 39, '1855'),
	(243, 1, 0, -50943, 1857, 0, 0, 39, '1856'),
	(243, 1, 0, -50943, 1858, 0, 0, 39, '1857'),
	(243, 1, 0, -50943, 1859, 0, 0, 39, '1858'),
	(243, 1, 0, -50943, 1860, 0, 0, 39, '1859'),
	(243, 1, 0, -50943, 1861, 0, 0, 39, '1860'),
	(243, 1, 0, -50943, 1862, 0, 0, 39, '1861'),
	(243, 1, 0, -50943, 1863, 0, 0, 39, '1862'),
	(243, 1, 0, -50943, 1864, 0, 0, 39, '1863'),
	(243, 1, 0, -50943, 1865, 0, 0, 39, '1864'),
	(243, 1, 0, -50943, 1866, 0, 0, 39, '1865'),
	(243, 1, 0, -50943, 1867, 0, 0, 39, '1866'),
	(243, 1, 0, -50943, 1868, 0, 0, 39, '1867'),
	(243, 1, 0, -50943, 1869, 0, 0, 39, '1868'),
	(243, 1, 0, -50943, 1870, 0, 0, 39, '1869'),
	(243, 1, 0, -50943, 1871, 0, 0, 39, '1870'),
	(243, 1, 0, -50943, 1872, 0, 0, 39, '1871'),
	(243, 1, 0, -50943, 1873, 0, 0, 39, '1872'),
	(243, 1, 0, -50943, 1874, 0, 0, 39, '1873'),
	(243, 1, 0, -50943, 1875, 0, 0, 39, '1874'),
	(243, 1, 0, -50943, 1876, 0, 0, 39, '1875'),
	(243, 1, 0, -50943, 1877, 0, 0, 39, '1876'),
	(243, 1, 0, -50943, 1878, 0, 0, 39, '1877'),
	(243, 1, 0, -50943, 1879, 0, 0, 39, '1878'),
	(243, 1, 0, -50943, 1880, 0, 0, 39, '1879'),
	(243, 1, 0, -50943, 1881, 0, 0, 39, '1880'),
	(243, 1, 0, -50943, 1882, 0, 0, 39, '1881'),
	(243, 1, 0, -50943, 1883, 0, 0, 39, '1882'),
	(243, 1, 0, -50943, 1884, 0, 0, 39, '1883'),
	(243, 1, 0, -50943, 1885, 0, 0, 39, '1884'),
	(243, 1, 0, -50943, 1886, 0, 0, 39, '1885'),
	(243, 1, 0, -50943, 1887, 0, 0, 39, '1886'),
	(243, 1, 0, -50943, 1888, 0, 0, 39, '1887'),
	(243, 1, 0, -50943, 1889, 0, 0, 39, '1888'),
	(243, 1, 0, -50943, 1890, 0, 0, 39, '1889'),
	(243, 1, 0, -50943, 1891, 0, 0, 39, '1890'),
	(243, 1, 0, -50943, 1892, 0, 0, 39, '1891'),
	(243, 1, 0, -50943, 1893, 0, 0, 39, '1892'),
	(243, 1, 0, -50943, 1894, 0, 0, 39, '1893'),
	(243, 1, 0, -50943, 1895, 0, 0, 39, '1894'),
	(243, 1, 0, -50943, 1896, 0, 0, 39, '1895'),
	(243, 1, 0, -50943, 1897, 0, 0, 39, '1896'),
	(243, 1, 0, -50943, 1898, 0, 0, 39, '1897'),
	(243, 1, 0, -50943, 1899, 0, 0, 39, '1898'),
	(243, 1, 0, -50943, 1900, 0, 0, 39, '1899'),
	(243, 1, 0, -50943, 1901, 0, 0, 39, '1900'),
	(243, 1, 0, -50943, 1902, 0, 0, 39, '1901'),
	(243, 1, 0, -50943, 1903, 0, 0, 39, '1902'),
	(243, 1, 0, -50943, 1904, 0, 0, 39, '1903'),
	(243, 1, 0, -50943, 1905, 0, 0, 39, '1904'),
	(243, 1, 0, -50943, 1906, 0, 0, 39, '1905'),
	(243, 1, 0, -50943, 1907, 0, 0, 39, '1906'),
	(243, 1, 0, -50943, 1908, 0, 0, 39, '1907'),
	(243, 1, 0, -50943, 1909, 0, 0, 39, '1908'),
	(243, 1, 0, -50943, 1910, 0, 0, 39, '1909'),
	(243, 1, 0, -50943, 1911, 0, 0, 39, '1910'),
	(243, 1, 0, -50943, 1912, 0, 0, 39, '1911'),
	(243, 1, 0, -50943, 1913, 0, 0, 39, '1912'),
	(243, 1, 0, -50943, 1914, 0, 0, 39, '1913'),
	(243, 1, 0, -50943, 1915, 0, 0, 39, '1914'),
	(243, 1, 0, -50943, 1916, 0, 0, 39, '1915'),
	(243, 1, 0, -50943, 1917, 0, 0, 39, '1916'),
	(243, 1, 0, -50943, 1918, 0, 0, 39, '1917'),
	(243, 1, 0, -50943, 1919, 0, 0, 39, '1918'),
	(243, 1, 0, -50943, 1920, 0, 0, 39, '1919'),
	(243, 1, 0, -50943, 1921, 0, 0, 39, '1920'),
	(243, 1, 0, -50943, 1922, 0, 0, 39, '1921'),
	(243, 1, 0, -50943, 1923, 0, 0, 39, '1922'),
	(243, 1, 0, -50943, 1924, 0, 0, 39, '1923'),
	(243, 1, 0, -50943, 1925, 0, 0, 39, '1924'),
	(243, 1, 0, -50943, 1926, 0, 0, 39, '1925'),
	(243, 1, 0, -50943, 1927, 0, 0, 39, '1926'),
	(243, 1, 0, -50943, 1928, 0, 0, 39, '1927'),
	(243, 1, 0, -50943, 1929, 0, 0, 39, '1928'),
	(243, 1, 0, -50943, 1930, 0, 0, 39, '1929'),
	(243, 1, 0, -50943, 1931, 0, 0, 39, '1930'),
	(243, 1, 0, -50943, 1932, 0, 0, 39, '1931'),
	(243, 1, 0, -50943, 1933, 0, 0, 39, '1932'),
	(243, 1, 0, -50943, 1934, 0, 0, 39, '1933'),
	(243, 1, 0, -50943, 1935, 0, 0, 39, '1934'),
	(243, 1, 0, -50943, 1936, 0, 0, 39, '1935'),
	(243, 1, 0, -50943, 1937, 0, 0, 39, '1936'),
	(243, 1, 0, -50943, 1938, 0, 0, 39, '1937'),
	(243, 1, 0, -50943, 1939, 0, 0, 39, '1938'),
	(243, 1, 0, -50943, 1940, 0, 0, 39, '1939'),
	(243, 1, 0, -50943, 1941, 0, 0, 39, '1940'),
	(243, 1, 0, -50943, 1942, 0, 0, 39, '1941'),
	(243, 1, 0, -50943, 1943, 0, 0, 39, '1942'),
	(243, 1, 0, -50943, 1944, 0, 0, 39, '1943'),
	(243, 1, 0, -50943, 1945, 0, 0, 39, '1944'),
	(243, 1, 0, -50943, 1946, 0, 0, 39, '1945'),
	(243, 1, 0, -50943, 1947, 0, 0, 39, '1946'),
	(243, 1, 0, -50943, 1948, 0, 0, 39, '1947'),
	(243, 1, 0, -50943, 1949, 0, 0, 39, '1948'),
	(243, 1, 0, -50943, 1950, 0, 0, 39, '1949'),
	(243, 1, 0, -50943, 1951, 0, 0, 39, '1950'),
	(243, 1, 0, -50943, 1952, 0, 0, 39, '1951'),
	(243, 1, 0, -50943, 1953, 0, 0, 39, '1952'),
	(243, 1, 0, -50943, 1954, 0, 0, 39, '1953'),
	(243, 1, 0, -50943, 1955, 0, 0, 39, '1954'),
	(243, 1, 0, -50943, 1956, 0, 0, 39, '1955'),
	(243, 1, 0, -50943, 1957, 0, 0, 39, '1956'),
	(243, 1, 0, -50943, 1958, 0, 0, 39, '1957'),
	(243, 1, 0, -50943, 1959, 0, 0, 39, '1958'),
	(243, 1, 0, -50943, 1960, 0, 0, 39, '1959'),
	(243, 1, 0, -50943, 1961, 0, 0, 39, '1960'),
	(243, 1, 0, -50943, 1962, 0, 0, 39, '1961'),
	(243, 1, 0, -50943, 1963, 0, 0, 39, '1962'),
	(243, 1, 0, -50943, 1964, 0, 0, 39, '1963'),
	(243, 1, 0, -50943, 1965, 0, 0, 39, '1964'),
	(243, 1, 0, -50943, 1966, 0, 0, 39, '1965'),
	(243, 1, 0, -50943, 1967, 0, 0, 39, '1966'),
	(243, 1, 0, -50943, 1968, 0, 0, 39, '1967'),
	(243, 1, 0, -50943, 1969, 0, 0, 39, '1968'),
	(243, 1, 0, -50943, 1970, 0, 0, 39, '1969'),
	(243, 1, 0, -50943, 1971, 0, 0, 39, '1970'),
	(243, 1, 0, -50943, 1972, 0, 0, 39, '1971'),
	(243, 1, 0, -50943, 1973, 0, 0, 39, '1972'),
	(243, 1, 0, -50943, 1974, 0, 0, 39, '1973'),
	(243, 1, 0, -50943, 1975, 0, 0, 39, '1974'),
	(243, 1, 0, -50943, 1976, 0, 0, 39, '1975'),
	(243, 1, 0, -50943, 1977, 0, 0, 39, '1976'),
	(243, 1, 0, -50943, 1978, 0, 0, 39, '1977'),
	(243, 1, 0, -50943, 1979, 0, 0, 39, '1978'),
	(243, 1, 0, -50943, 1980, 0, 0, 39, '1979'),
	(243, 1, 0, -50943, 1981, 0, 0, 39, '1980'),
	(243, 1, 0, -50943, 1982, 0, 0, 39, '1981'),
	(243, 1, 0, -50943, 1983, 0, 0, 39, '1982'),
	(243, 1, 0, -50943, 1984, 0, 0, 39, '1983'),
	(243, 1, 0, -50943, 1985, 0, 0, 39, '1984'),
	(243, 1, 0, -50943, 1986, 0, 0, 39, '1985'),
	(243, 1, 0, -50943, 1987, 0, 0, 39, '1986'),
	(243, 1, 0, -50943, 1988, 0, 0, 39, '1987'),
	(243, 1, 0, -50943, 1989, 0, 0, 39, '1988'),
	(243, 1, 0, -50943, 1990, 0, 0, 39, '1989'),
	(243, 1, 0, -50943, 1991, 0, 0, 39, '1990'),
	(243, 1, 0, -50943, 1992, 0, 0, 39, '1991'),
	(243, 1, 0, -50943, 1993, 0, 0, 39, '1992'),
	(243, 1, 0, -50943, 1994, 0, 0, 39, '1993'),
	(243, 1, 0, -50943, 1995, 0, 0, 39, '1994'),
	(243, 1, 0, -50943, 1996, 0, 0, 39, '1995'),
	(243, 1, 0, -50943, 1997, 0, 0, 39, '1996'),
	(243, 1, 0, -50943, 1998, 0, 0, 39, '1997'),
	(243, 1, 0, -50943, 1999, 0, 0, 39, '1998'),
	(243, 1, 0, -50943, 2000, 0, 0, 39, '1999'),
	(243, 1, 0, -50943, 2001, 0, 0, 39, '2000'),
	(243, 1, 0, -50943, 2002, 0, 0, 39, '2001'),
	(243, 1, 0, -50943, 2003, 0, 0, 39, '2002'),
	(243, 1, 0, -50943, 2004, 0, 0, 39, '2003'),
	(243, 1, 0, -50943, 2005, 0, 0, 39, '2004'),
	(243, 1, 0, -50943, 2006, 0, 0, 39, '2005'),
	(243, 1, 0, -50943, 2007, 0, 0, 39, '2006'),
	(243, 1, 0, -50943, 2008, 0, 0, 39, '2007'),
	(243, 1, 0, -50943, 2009, 0, 0, 39, '2008'),
	(243, 1, 0, -50943, 2010, 0, 0, 39, '2009'),
	(243, 1, 0, -50943, 2011, 0, 0, 39, '2010'),
	(243, 1, 0, -50943, 2012, 0, 0, 39, '2011'),
	(243, 1, 0, -50943, 2013, 0, 0, 39, '2012'),
	(243, 1, 0, -50943, 2014, 0, 0, 39, '2013'),
	(243, 1, 0, -50943, 2015, 0, 0, 39, '2014'),
	(243, 1, 0, -50943, 2016, 0, 0, 39, '2015'),
	(243, 1, 0, -50943, 2017, 0, 0, 39, '2016'),
	(243, 1, 0, -50943, 2018, 0, 0, 39, '2017'),
	(243, 1, 0, -50943, 2019, 0, 0, 39, '2018'),
	(243, 1, 0, -50943, 2020, 0, 0, 39, '2019'),
	(243, 1, 0, -50943, 2021, 0, 0, 39, '2020'),
	(243, 1, 0, -50943, 2022, 0, 0, 39, '2021'),
	(243, 1, 0, -50943, 2023, 0, 0, 39, '2022'),
	(243, 1, 0, -50943, 2024, 0, 0, 39, '2023'),
	(243, 1, 0, -50943, 2025, 0, 0, 39, '2024'),
	(243, 1, 0, -50943, 2026, 0, 0, 39, '2025'),
	(243, 1, 0, -50943, 2027, 0, 0, 39, '2026'),
	(243, 1, 0, -50943, 2028, 0, 0, 39, '2027'),
	(243, 1, 0, -50943, 2029, 0, 0, 39, '2028'),
	(243, 1, 0, -50943, 2030, 0, 0, 39, '2029'),
	(243, 1, 0, -50943, 2031, 0, 0, 39, '2030'),
	(243, 1, 0, -50943, 2032, 0, 0, 39, '2031'),
	(243, 1, 0, -50943, 2033, 0, 0, 39, '2032'),
	(243, 1, 0, -50943, 2034, 0, 0, 39, '2033'),
	(243, 1, 0, -50943, 2035, 0, 0, 39, '2034'),
	(243, 1, 0, -50943, 2036, 0, 0, 39, '2035'),
	(243, 1, 0, -50943, 2037, 0, 0, 39, '2036'),
	(243, 1, 0, -50943, 2038, 0, 0, 39, '2037'),
	(243, 1, 0, -50943, 2039, 0, 0, 39, '2038'),
	(243, 1, 0, -50943, 2040, 0, 0, 39, '2039'),
	(243, 1, 0, -50943, 2041, 0, 0, 39, '2040'),
	(243, 1, 0, -50943, 2042, 0, 0, 39, '2041'),
	(243, 1, 0, -50943, 2043, 0, 0, 39, '2042'),
	(243, 1, 0, -50943, 2044, 0, 0, 39, '2043'),
	(243, 1, 0, -50943, 2045, 0, 0, 39, '2044'),
	(243, 1, 0, -50943, 2046, 0, 0, 39, '2045'),
	(243, 1, 0, -50943, 2047, 0, 0, 39, '2046'),
	(243, 1, 0, -50943, 2048, 0, 0, 39, '2047'),
	(243, 1, 0, -50942, 1, 0, 0, 39, '0'),
	(243, 1, 0, -50942, 2, 0, 0, 39, '1'),
	(243, 1, 0, -50942, 3, 0, 0, 39, '2'),
	(243, 1, 0, -50942, 4, 0, 0, 39, '3'),
	(243, 1, 0, -50942, 5, 0, 0, 39, '4'),
	(243, 1, 0, -50942, 6, 0, 0, 39, '5'),
	(243, 1, 0, -50942, 7, 0, 0, 39, '6'),
	(243, 1, 0, -50942, 8, 0, 0, 39, '7'),
	(243, 1, 0, -50942, 9, 0, 0, 39, '8'),
	(243, 1, 0, -50942, 10, 0, 0, 39, '9'),
	(243, 1, 0, -50942, 11, 0, 0, 39, '10'),
	(243, 1, 0, -50942, 12, 0, 0, 39, '11'),
	(243, 1, 0, -50942, 13, 0, 0, 39, '12'),
	(243, 1, 0, -50942, 14, 0, 0, 39, '13'),
	(243, 1, 0, -50942, 15, 0, 0, 39, '14'),
	(243, 1, 0, -50942, 16, 0, 0, 39, '15'),
	(243, 1, 0, -50942, 17, 0, 0, 39, '16'),
	(243, 1, 0, -50942, 18, 0, 0, 39, '17'),
	(243, 1, 0, -50942, 19, 0, 0, 39, '18'),
	(243, 1, 0, -50942, 20, 0, 0, 39, '19'),
	(243, 1, 0, -50942, 21, 0, 0, 39, '20'),
	(243, 1, 0, -50942, 22, 0, 0, 39, '21'),
	(243, 1, 0, -50942, 23, 0, 0, 39, '22'),
	(243, 1, 0, -50942, 24, 0, 0, 39, '23'),
	(243, 1, 0, -50942, 25, 0, 0, 39, '24'),
	(243, 1, 0, -50942, 26, 0, 0, 39, '25'),
	(243, 1, 0, -50942, 27, 0, 0, 39, '26'),
	(243, 1, 0, -50942, 28, 0, 0, 39, '27'),
	(243, 1, 0, -50942, 29, 0, 0, 39, '28'),
	(243, 1, 0, -50942, 30, 0, 0, 39, '29'),
	(243, 1, 0, -50942, 31, 0, 0, 39, '30'),
	(243, 1, 0, -50942, 32, 0, 0, 39, '31'),
	(243, 1, 0, -50942, 33, 0, 0, 39, '32'),
	(243, 1, 0, -50942, 34, 0, 0, 39, '33'),
	(243, 1, 0, -50942, 35, 0, 0, 39, '34'),
	(243, 1, 0, -50942, 36, 0, 0, 39, '35'),
	(243, 1, 0, -50942, 37, 0, 0, 39, '36'),
	(243, 1, 0, -50942, 38, 0, 0, 39, '37'),
	(243, 1, 0, -50942, 39, 0, 0, 39, '38'),
	(243, 1, 0, -50942, 40, 0, 0, 39, '39'),
	(243, 1, 0, -50942, 41, 0, 0, 39, '40'),
	(243, 1, 0, -50942, 42, 0, 0, 39, '41'),
	(243, 1, 0, -50942, 43, 0, 0, 39, '42'),
	(243, 1, 0, -50942, 44, 0, 0, 39, '43'),
	(243, 1, 0, -50942, 45, 0, 0, 39, '44'),
	(243, 1, 0, -50942, 46, 0, 0, 39, '45'),
	(243, 1, 0, -50942, 47, 0, 0, 39, '46'),
	(243, 1, 0, -50942, 48, 0, 0, 39, '47'),
	(243, 1, 0, -50942, 49, 0, 0, 39, '48'),
	(243, 1, 0, -50942, 50, 0, 0, 39, '49'),
	(243, 1, 0, -50942, 51, 0, 0, 39, '50'),
	(243, 1, 0, -50942, 52, 0, 0, 39, '51'),
	(243, 1, 0, -50942, 53, 0, 0, 39, '52'),
	(243, 1, 0, -50942, 54, 0, 0, 39, '53'),
	(243, 1, 0, -50942, 55, 0, 0, 39, '54'),
	(243, 1, 0, -50942, 56, 0, 0, 39, '55'),
	(243, 1, 0, -50942, 57, 0, 0, 39, '56'),
	(243, 1, 0, -50942, 58, 0, 0, 39, '57'),
	(243, 1, 0, -50942, 59, 0, 0, 39, '58'),
	(243, 1, 0, -50942, 60, 0, 0, 39, '59'),
	(243, 1, 0, -50942, 61, 0, 0, 39, '60'),
	(243, 1, 0, -50942, 62, 0, 0, 39, '61'),
	(243, 1, 0, -50942, 63, 0, 0, 39, '62'),
	(243, 1, 0, -50942, 64, 0, 0, 39, '63'),
	(243, 1, 0, -50942, 65, 0, 0, 39, '64'),
	(243, 1, 0, -50942, 66, 0, 0, 39, '65'),
	(243, 1, 0, -50942, 67, 0, 0, 39, '66'),
	(243, 1, 0, -50942, 68, 0, 0, 39, '67'),
	(243, 1, 0, -50942, 69, 0, 0, 39, '68'),
	(243, 1, 0, -50942, 70, 0, 0, 39, '69'),
	(243, 1, 0, -50942, 71, 0, 0, 39, '70'),
	(243, 1, 0, -50942, 72, 0, 0, 39, '71'),
	(243, 1, 0, -50942, 73, 0, 0, 39, '72'),
	(243, 1, 0, -50942, 74, 0, 0, 39, '73'),
	(243, 1, 0, -50942, 75, 0, 0, 39, '74'),
	(243, 1, 0, -50942, 76, 0, 0, 39, '75'),
	(243, 1, 0, -50942, 77, 0, 0, 39, '76'),
	(243, 1, 0, -50942, 78, 0, 0, 39, '77'),
	(243, 1, 0, -50942, 79, 0, 0, 39, '78'),
	(243, 1, 0, -50942, 80, 0, 0, 39, '79'),
	(243, 1, 0, -50942, 81, 0, 0, 39, '80'),
	(243, 1, 0, -50942, 82, 0, 0, 39, '81'),
	(243, 1, 0, -50942, 83, 0, 0, 39, '82'),
	(243, 1, 0, -50942, 84, 0, 0, 39, '83'),
	(243, 1, 0, -50942, 85, 0, 0, 39, '84'),
	(243, 1, 0, -50942, 86, 0, 0, 39, '85'),
	(243, 1, 0, -50942, 87, 0, 0, 39, '86'),
	(243, 1, 0, -50942, 88, 0, 0, 39, '87'),
	(243, 1, 0, -50942, 89, 0, 0, 39, '88'),
	(243, 1, 0, -50942, 90, 0, 0, 39, '89'),
	(243, 1, 0, -50942, 91, 0, 0, 39, '90'),
	(243, 1, 0, -50942, 92, 0, 0, 39, '91'),
	(243, 1, 0, -50942, 93, 0, 0, 39, '92'),
	(243, 1, 0, -50942, 94, 0, 0, 39, '93'),
	(243, 1, 0, -50942, 95, 0, 0, 39, '94'),
	(243, 1, 0, -50942, 96, 0, 0, 39, '95'),
	(243, 1, 0, -50942, 97, 0, 0, 39, '96'),
	(243, 1, 0, -50942, 98, 0, 0, 39, '97'),
	(243, 1, 0, -50942, 99, 0, 0, 39, '98'),
	(243, 1, 0, -50942, 100, 0, 0, 39, '99'),
	(243, 1, 0, -50942, 101, 0, 0, 39, '100'),
	(243, 1, 0, -50942, 102, 0, 0, 39, '101'),
	(243, 1, 0, -50942, 103, 0, 0, 39, '102'),
	(243, 1, 0, -50942, 104, 0, 0, 39, '103'),
	(243, 1, 0, -50942, 105, 0, 0, 39, '104'),
	(243, 1, 0, -50942, 106, 0, 0, 39, '105'),
	(243, 1, 0, -50942, 107, 0, 0, 39, '106'),
	(243, 1, 0, -50942, 108, 0, 0, 39, '107'),
	(243, 1, 0, -50942, 109, 0, 0, 39, '108'),
	(243, 1, 0, -50942, 110, 0, 0, 39, '109'),
	(243, 1, 0, -50942, 111, 0, 0, 39, '110'),
	(243, 1, 0, -50942, 112, 0, 0, 39, '111'),
	(243, 1, 0, -50942, 113, 0, 0, 39, '112'),
	(243, 1, 0, -50942, 114, 0, 0, 39, '113'),
	(243, 1, 0, -50942, 115, 0, 0, 39, '114'),
	(243, 1, 0, -50942, 116, 0, 0, 39, '115'),
	(243, 1, 0, -50942, 117, 0, 0, 39, '116'),
	(243, 1, 0, -50942, 118, 0, 0, 39, '117'),
	(243, 1, 0, -50942, 119, 0, 0, 39, '118'),
	(243, 1, 0, -50942, 120, 0, 0, 39, '119'),
	(243, 1, 0, -50942, 121, 0, 0, 39, '120'),
	(243, 1, 0, -50942, 122, 0, 0, 39, '121'),
	(243, 1, 0, -50942, 123, 0, 0, 39, '122'),
	(243, 1, 0, -50942, 124, 0, 0, 39, '123'),
	(243, 1, 0, -50942, 125, 0, 0, 39, '124'),
	(243, 1, 0, -50942, 126, 0, 0, 39, '125'),
	(243, 1, 0, -50942, 127, 0, 0, 39, '126'),
	(243, 1, 0, -50942, 128, 0, 0, 39, '127'),
	(243, 1, 0, -50942, 129, 0, 0, 39, '128'),
	(243, 1, 0, -50942, 130, 0, 0, 39, '129'),
	(243, 1, 0, -50942, 131, 0, 0, 39, '130'),
	(243, 1, 0, -50942, 132, 0, 0, 39, '131'),
	(243, 1, 0, -50942, 133, 0, 0, 39, '132'),
	(243, 1, 0, -50942, 134, 0, 0, 39, '133'),
	(243, 1, 0, -50942, 135, 0, 0, 39, '134'),
	(243, 1, 0, -50942, 136, 0, 0, 39, '135'),
	(243, 1, 0, -50942, 137, 0, 0, 39, '136'),
	(243, 1, 0, -50942, 138, 0, 0, 39, '137'),
	(243, 1, 0, -50942, 139, 0, 0, 39, '138'),
	(243, 1, 0, -50942, 140, 0, 0, 39, '139'),
	(243, 1, 0, -50942, 141, 0, 0, 39, '140'),
	(243, 1, 0, -50942, 142, 0, 0, 39, '141'),
	(243, 1, 0, -50942, 143, 0, 0, 39, '142'),
	(243, 1, 0, -50942, 144, 0, 0, 39, '143'),
	(243, 1, 0, -50942, 145, 0, 0, 39, '144'),
	(243, 1, 0, -50942, 146, 0, 0, 39, '145'),
	(243, 1, 0, -50942, 147, 0, 0, 39, '146'),
	(243, 1, 0, -50942, 148, 0, 0, 39, '147'),
	(243, 1, 0, -50942, 149, 0, 0, 39, '148'),
	(243, 1, 0, -50942, 150, 0, 0, 39, '149'),
	(243, 1, 0, -50942, 151, 0, 0, 39, '150'),
	(243, 1, 0, -50942, 152, 0, 0, 39, '151'),
	(243, 1, 0, -50942, 153, 0, 0, 39, '152'),
	(243, 1, 0, -50942, 154, 0, 0, 39, '153'),
	(243, 1, 0, -50942, 155, 0, 0, 39, '154'),
	(243, 1, 0, -50942, 156, 0, 0, 39, '155'),
	(243, 1, 0, -50942, 157, 0, 0, 39, '156'),
	(243, 1, 0, -50942, 158, 0, 0, 39, '157'),
	(243, 1, 0, -50942, 159, 0, 0, 39, '158'),
	(243, 1, 0, -50942, 160, 0, 0, 39, '159'),
	(243, 1, 0, -50942, 161, 0, 0, 39, '160'),
	(243, 1, 0, -50942, 162, 0, 0, 39, '161'),
	(243, 1, 0, -50942, 163, 0, 0, 39, '162'),
	(243, 1, 0, -50942, 164, 0, 0, 39, '163'),
	(243, 1, 0, -50942, 165, 0, 0, 39, '164'),
	(243, 1, 0, -50942, 166, 0, 0, 39, '165'),
	(243, 1, 0, -50942, 167, 0, 0, 39, '166'),
	(243, 1, 0, -50942, 168, 0, 0, 39, '167'),
	(243, 1, 0, -50942, 169, 0, 0, 39, '168'),
	(243, 1, 0, -50942, 170, 0, 0, 39, '169'),
	(243, 1, 0, -50942, 171, 0, 0, 39, '170'),
	(243, 1, 0, -50942, 172, 0, 0, 39, '171'),
	(243, 1, 0, -50942, 173, 0, 0, 39, '172'),
	(243, 1, 0, -50942, 174, 0, 0, 39, '173'),
	(243, 1, 0, -50942, 175, 0, 0, 39, '174'),
	(243, 1, 0, -50942, 176, 0, 0, 39, '175'),
	(243, 1, 0, -50942, 177, 0, 0, 39, '176'),
	(243, 1, 0, -50942, 178, 0, 0, 39, '177'),
	(243, 1, 0, -50942, 179, 0, 0, 39, '178'),
	(243, 1, 0, -50942, 180, 0, 0, 39, '179'),
	(243, 1, 0, -50942, 181, 0, 0, 39, '180'),
	(243, 1, 0, -50942, 182, 0, 0, 39, '181'),
	(243, 1, 0, -50942, 183, 0, 0, 39, '182'),
	(243, 1, 0, -50942, 184, 0, 0, 39, '183'),
	(243, 1, 0, -50942, 185, 0, 0, 39, '184'),
	(243, 1, 0, -50942, 186, 0, 0, 39, '185'),
	(243, 1, 0, -50942, 187, 0, 0, 39, '186'),
	(243, 1, 0, -50942, 188, 0, 0, 39, '187'),
	(243, 1, 0, -50942, 189, 0, 0, 39, '188'),
	(243, 1, 0, -50942, 190, 0, 0, 39, '189'),
	(243, 1, 0, -50942, 191, 0, 0, 39, '190'),
	(243, 1, 0, -50942, 192, 0, 0, 39, '191'),
	(243, 1, 0, -50942, 193, 0, 0, 39, '192'),
	(243, 1, 0, -50942, 194, 0, 0, 39, '193'),
	(243, 1, 0, -50942, 195, 0, 0, 39, '194'),
	(243, 1, 0, -50942, 196, 0, 0, 39, '195'),
	(243, 1, 0, -50942, 197, 0, 0, 39, '196'),
	(243, 1, 0, -50942, 198, 0, 0, 39, '197'),
	(243, 1, 0, -50942, 199, 0, 0, 39, '198'),
	(243, 1, 0, -50942, 200, 0, 0, 39, '199'),
	(243, 1, 0, -50942, 201, 0, 0, 39, '200'),
	(243, 1, 0, -50942, 202, 0, 0, 39, '201'),
	(243, 1, 0, -50942, 203, 0, 0, 39, '202'),
	(243, 1, 0, -50942, 204, 0, 0, 39, '203'),
	(243, 1, 0, -50942, 205, 0, 0, 39, '204'),
	(243, 1, 0, -50942, 206, 0, 0, 39, '205'),
	(243, 1, 0, -50942, 207, 0, 0, 39, '206'),
	(243, 1, 0, -50942, 208, 0, 0, 39, '207'),
	(243, 1, 0, -50942, 209, 0, 0, 39, '208'),
	(243, 1, 0, -50942, 210, 0, 0, 39, '209'),
	(243, 1, 0, -50942, 211, 0, 0, 39, '210'),
	(243, 1, 0, -50942, 212, 0, 0, 39, '211'),
	(243, 1, 0, -50942, 213, 0, 0, 39, '212'),
	(243, 1, 0, -50942, 214, 0, 0, 39, '213'),
	(243, 1, 0, -50942, 215, 0, 0, 39, '214'),
	(243, 1, 0, -50942, 216, 0, 0, 39, '215'),
	(243, 1, 0, -50942, 217, 0, 0, 39, '216'),
	(243, 1, 0, -50942, 218, 0, 0, 39, '217'),
	(243, 1, 0, -50942, 219, 0, 0, 39, '218'),
	(243, 1, 0, -50942, 220, 0, 0, 39, '219'),
	(243, 1, 0, -50942, 221, 0, 0, 39, '220'),
	(243, 1, 0, -50942, 222, 0, 0, 39, '221'),
	(243, 1, 0, -50942, 223, 0, 0, 39, '222'),
	(243, 1, 0, -50942, 224, 0, 0, 39, '223'),
	(243, 1, 0, -50942, 225, 0, 0, 39, '224'),
	(243, 1, 0, -50942, 226, 0, 0, 39, '225'),
	(243, 1, 0, -50942, 227, 0, 0, 39, '226'),
	(243, 1, 0, -50942, 228, 0, 0, 39, '227'),
	(243, 1, 0, -50942, 229, 0, 0, 39, '228'),
	(243, 1, 0, -50942, 230, 0, 0, 39, '229'),
	(243, 1, 0, -50942, 231, 0, 0, 39, '230'),
	(243, 1, 0, -50942, 232, 0, 0, 39, '231'),
	(243, 1, 0, -50942, 233, 0, 0, 39, '232'),
	(243, 1, 0, -50942, 234, 0, 0, 39, '233'),
	(243, 1, 0, -50942, 235, 0, 0, 39, '234'),
	(243, 1, 0, -50942, 236, 0, 0, 39, '235'),
	(243, 1, 0, -50942, 237, 0, 0, 39, '236'),
	(243, 1, 0, -50942, 238, 0, 0, 39, '237'),
	(243, 1, 0, -50942, 239, 0, 0, 39, '238'),
	(243, 1, 0, -50942, 240, 0, 0, 39, '239'),
	(243, 1, 0, -50942, 241, 0, 0, 39, '240'),
	(243, 1, 0, -50942, 242, 0, 0, 39, '241'),
	(243, 1, 0, -50942, 243, 0, 0, 39, '242'),
	(243, 1, 0, -50942, 244, 0, 0, 39, '243'),
	(243, 1, 0, -50942, 245, 0, 0, 39, '244'),
	(243, 1, 0, -50942, 246, 0, 0, 39, '245'),
	(243, 1, 0, -50942, 247, 0, 0, 39, '246'),
	(243, 1, 0, -50942, 248, 0, 0, 39, '247'),
	(243, 1, 0, -50942, 249, 0, 0, 39, '248'),
	(243, 1, 0, -50942, 250, 0, 0, 39, '249'),
	(243, 1, 0, -50942, 251, 0, 0, 39, '250'),
	(243, 1, 0, -50942, 252, 0, 0, 39, '251'),
	(243, 1, 0, -50942, 253, 0, 0, 39, '252'),
	(243, 1, 0, -50942, 254, 0, 0, 39, '253'),
	(243, 1, 0, -50942, 255, 0, 0, 39, '254'),
	(243, 1, 0, -50942, 256, 0, 0, 39, '255'),
	(243, 1, 0, -50942, 257, 0, 0, 39, '256'),
	(243, 1, 0, -50942, 258, 0, 0, 39, '257'),
	(243, 1, 0, -50942, 259, 0, 0, 39, '258'),
	(243, 1, 0, -50942, 260, 0, 0, 39, '259'),
	(243, 1, 0, -50942, 261, 0, 0, 39, '260'),
	(243, 1, 0, -50942, 262, 0, 0, 39, '261'),
	(243, 1, 0, -50942, 263, 0, 0, 39, '262'),
	(243, 1, 0, -50942, 264, 0, 0, 39, '263'),
	(243, 1, 0, -50942, 265, 0, 0, 39, '264'),
	(243, 1, 0, -50942, 266, 0, 0, 39, '265'),
	(243, 1, 0, -50942, 267, 0, 0, 39, '266'),
	(243, 1, 0, -50942, 268, 0, 0, 39, '267'),
	(243, 1, 0, -50942, 269, 0, 0, 39, '268'),
	(243, 1, 0, -50942, 270, 0, 0, 39, '269'),
	(243, 1, 0, -50942, 271, 0, 0, 39, '270'),
	(243, 1, 0, -50942, 272, 0, 0, 39, '271'),
	(243, 1, 0, -50942, 273, 0, 0, 39, '272'),
	(243, 1, 0, -50942, 274, 0, 0, 39, '273'),
	(243, 1, 0, -50942, 275, 0, 0, 39, '274'),
	(243, 1, 0, -50942, 276, 0, 0, 39, '275'),
	(243, 1, 0, -50942, 277, 0, 0, 39, '276'),
	(243, 1, 0, -50942, 278, 0, 0, 39, '277'),
	(243, 1, 0, -50942, 279, 0, 0, 39, '278'),
	(243, 1, 0, -50942, 280, 0, 0, 39, '279'),
	(243, 1, 0, -50942, 281, 0, 0, 39, '280'),
	(243, 1, 0, -50942, 282, 0, 0, 39, '281'),
	(243, 1, 0, -50942, 283, 0, 0, 39, '282'),
	(243, 1, 0, -50942, 284, 0, 0, 39, '283'),
	(243, 1, 0, -50942, 285, 0, 0, 39, '284'),
	(243, 1, 0, -50942, 286, 0, 0, 39, '285'),
	(243, 1, 0, -50942, 287, 0, 0, 39, '286'),
	(243, 1, 0, -50942, 288, 0, 0, 39, '287'),
	(243, 1, 0, -50942, 289, 0, 0, 39, '288'),
	(243, 1, 0, -50942, 290, 0, 0, 39, '289'),
	(243, 1, 0, -50942, 291, 0, 0, 39, '290'),
	(243, 1, 0, -50942, 292, 0, 0, 39, '291'),
	(243, 1, 0, -50942, 293, 0, 0, 39, '292'),
	(243, 1, 0, -50942, 294, 0, 0, 39, '293'),
	(243, 1, 0, -50942, 295, 0, 0, 39, '294'),
	(243, 1, 0, -50942, 296, 0, 0, 39, '295'),
	(243, 1, 0, -50942, 297, 0, 0, 39, '296'),
	(243, 1, 0, -50942, 298, 0, 0, 39, '297'),
	(243, 1, 0, -50942, 299, 0, 0, 39, '298'),
	(243, 1, 0, -50942, 300, 0, 0, 39, '299'),
	(243, 1, 0, -50942, 301, 0, 0, 39, '300'),
	(243, 1, 0, -50942, 302, 0, 0, 39, '301'),
	(243, 1, 0, -50942, 303, 0, 0, 39, '302'),
	(243, 1, 0, -50942, 304, 0, 0, 39, '303'),
	(243, 1, 0, -50942, 305, 0, 0, 39, '304'),
	(243, 1, 0, -50942, 306, 0, 0, 39, '305'),
	(243, 1, 0, -50942, 307, 0, 0, 39, '306'),
	(243, 1, 0, -50942, 308, 0, 0, 39, '307'),
	(243, 1, 0, -50942, 309, 0, 0, 39, '308'),
	(243, 1, 0, -50942, 310, 0, 0, 39, '309'),
	(243, 1, 0, -50942, 311, 0, 0, 39, '310'),
	(243, 1, 0, -50942, 312, 0, 0, 39, '311'),
	(243, 1, 0, -50942, 313, 0, 0, 39, '312'),
	(243, 1, 0, -50942, 314, 0, 0, 39, '313'),
	(243, 1, 0, -50942, 315, 0, 0, 39, '314'),
	(243, 1, 0, -50942, 316, 0, 0, 39, '315'),
	(243, 1, 0, -50942, 317, 0, 0, 39, '316'),
	(243, 1, 0, -50942, 318, 0, 0, 39, '317'),
	(243, 1, 0, -50942, 319, 0, 0, 39, '318'),
	(243, 1, 0, -50942, 320, 0, 0, 39, '319'),
	(243, 1, 0, -50942, 321, 0, 0, 39, '320'),
	(243, 1, 0, -50942, 322, 0, 0, 39, '321'),
	(243, 1, 0, -50942, 323, 0, 0, 39, '322'),
	(243, 1, 0, -50942, 324, 0, 0, 39, '323'),
	(243, 1, 0, -50942, 325, 0, 0, 39, '324'),
	(243, 1, 0, -50942, 326, 0, 0, 39, '325'),
	(243, 1, 0, -50942, 327, 0, 0, 39, '326'),
	(243, 1, 0, -50942, 328, 0, 0, 39, '327'),
	(243, 1, 0, -50942, 329, 0, 0, 39, '328'),
	(243, 1, 0, -50942, 330, 0, 0, 39, '329'),
	(243, 1, 0, -50942, 331, 0, 0, 39, '330'),
	(243, 1, 0, -50942, 332, 0, 0, 39, '331'),
	(243, 1, 0, -50942, 333, 0, 0, 39, '332'),
	(243, 1, 0, -50942, 334, 0, 0, 39, '333'),
	(243, 1, 0, -50942, 335, 0, 0, 39, '334'),
	(243, 1, 0, -50942, 336, 0, 0, 39, '335'),
	(243, 1, 0, -50942, 337, 0, 0, 39, '336'),
	(243, 1, 0, -50942, 338, 0, 0, 39, '337'),
	(243, 1, 0, -50942, 339, 0, 0, 39, '338'),
	(243, 1, 0, -50942, 340, 0, 0, 39, '339'),
	(243, 1, 0, -50942, 341, 0, 0, 39, '340'),
	(243, 1, 0, -50942, 342, 0, 0, 39, '341'),
	(243, 1, 0, -50942, 343, 0, 0, 39, '342'),
	(243, 1, 0, -50942, 344, 0, 0, 39, '343'),
	(243, 1, 0, -50942, 345, 0, 0, 39, '344'),
	(243, 1, 0, -50942, 346, 0, 0, 39, '345'),
	(243, 1, 0, -50942, 347, 0, 0, 39, '346'),
	(243, 1, 0, -50942, 348, 0, 0, 39, '347'),
	(243, 1, 0, -50942, 349, 0, 0, 39, '348'),
	(243, 1, 0, -50942, 350, 0, 0, 39, '349'),
	(243, 1, 0, -50942, 351, 0, 0, 39, '350'),
	(243, 1, 0, -50942, 352, 0, 0, 39, '351'),
	(243, 1, 0, -50942, 353, 0, 0, 39, '352'),
	(243, 1, 0, -50942, 354, 0, 0, 39, '353'),
	(243, 1, 0, -50942, 355, 0, 0, 39, '354'),
	(243, 1, 0, -50942, 356, 0, 0, 39, '355'),
	(243, 1, 0, -50942, 357, 0, 0, 39, '356'),
	(243, 1, 0, -50942, 358, 0, 0, 39, '357'),
	(243, 1, 0, -50942, 359, 0, 0, 39, '358'),
	(243, 1, 0, -50942, 360, 0, 0, 39, '359'),
	(243, 1, 0, -50942, 361, 0, 0, 39, '360'),
	(243, 1, 0, -50942, 362, 0, 0, 39, '361'),
	(243, 1, 0, -50942, 363, 0, 0, 39, '362'),
	(243, 1, 0, -50942, 364, 0, 0, 39, '363'),
	(243, 1, 0, -50942, 365, 0, 0, 39, '364'),
	(243, 1, 0, -50942, 366, 0, 0, 39, '365'),
	(243, 1, 0, -50942, 367, 0, 0, 39, '366'),
	(243, 1, 0, -50942, 368, 0, 0, 39, '367'),
	(243, 1, 0, -50942, 369, 0, 0, 39, '368'),
	(243, 1, 0, -50942, 370, 0, 0, 39, '369'),
	(243, 1, 0, -50942, 371, 0, 0, 39, '370'),
	(243, 1, 0, -50942, 372, 0, 0, 39, '371'),
	(243, 1, 0, -50942, 373, 0, 0, 39, '372'),
	(243, 1, 0, -50942, 374, 0, 0, 39, '373'),
	(243, 1, 0, -50942, 375, 0, 0, 39, '374'),
	(243, 1, 0, -50942, 376, 0, 0, 39, '375'),
	(243, 1, 0, -50942, 377, 0, 0, 39, '376'),
	(243, 1, 0, -50942, 378, 0, 0, 39, '377'),
	(243, 1, 0, -50942, 379, 0, 0, 39, '378'),
	(243, 1, 0, -50942, 380, 0, 0, 39, '379'),
	(243, 1, 0, -50942, 381, 0, 0, 39, '380'),
	(243, 1, 0, -50942, 382, 0, 0, 39, '381'),
	(243, 1, 0, -50942, 383, 0, 0, 39, '382'),
	(243, 1, 0, -50942, 384, 0, 0, 39, '383'),
	(243, 1, 0, -50942, 385, 0, 0, 39, '384'),
	(243, 1, 0, -50942, 386, 0, 0, 39, '385'),
	(243, 1, 0, -50942, 387, 0, 0, 39, '386'),
	(243, 1, 0, -50942, 388, 0, 0, 39, '387'),
	(243, 1, 0, -50942, 389, 0, 0, 39, '388'),
	(243, 1, 0, -50942, 390, 0, 0, 39, '389'),
	(243, 1, 0, -50942, 391, 0, 0, 39, '390'),
	(243, 1, 0, -50942, 392, 0, 0, 39, '391'),
	(243, 1, 0, -50942, 393, 0, 0, 39, '392'),
	(243, 1, 0, -50942, 394, 0, 0, 39, '393'),
	(243, 1, 0, -50942, 395, 0, 0, 39, '394'),
	(243, 1, 0, -50942, 396, 0, 0, 39, '395'),
	(243, 1, 0, -50942, 397, 0, 0, 39, '396'),
	(243, 1, 0, -50942, 398, 0, 0, 39, '397'),
	(243, 1, 0, -50942, 399, 0, 0, 39, '398'),
	(243, 1, 0, -50942, 400, 0, 0, 39, '399'),
	(243, 1, 0, -50942, 401, 0, 0, 39, '400'),
	(243, 1, 0, -50942, 402, 0, 0, 39, '401'),
	(243, 1, 0, -50942, 403, 0, 0, 39, '402'),
	(243, 1, 0, -50942, 404, 0, 0, 39, '403'),
	(243, 1, 0, -50942, 405, 0, 0, 39, '404'),
	(243, 1, 0, -50942, 406, 0, 0, 39, '405'),
	(243, 1, 0, -50942, 407, 0, 0, 39, '406'),
	(243, 1, 0, -50942, 408, 0, 0, 39, '407'),
	(243, 1, 0, -50942, 409, 0, 0, 39, '408'),
	(243, 1, 0, -50942, 410, 0, 0, 39, '409'),
	(243, 1, 0, -50942, 411, 0, 0, 39, '410'),
	(243, 1, 0, -50942, 412, 0, 0, 39, '411'),
	(243, 1, 0, -50942, 413, 0, 0, 39, '412'),
	(243, 1, 0, -50942, 414, 0, 0, 39, '413'),
	(243, 1, 0, -50942, 415, 0, 0, 39, '414'),
	(243, 1, 0, -50942, 416, 0, 0, 39, '415'),
	(243, 1, 0, -50942, 417, 0, 0, 39, '416'),
	(243, 1, 0, -50942, 418, 0, 0, 39, '417'),
	(243, 1, 0, -50942, 419, 0, 0, 39, '418'),
	(243, 1, 0, -50942, 420, 0, 0, 39, '419'),
	(243, 1, 0, -50942, 421, 0, 0, 39, '420'),
	(243, 1, 0, -50942, 422, 0, 0, 39, '421'),
	(243, 1, 0, -50942, 423, 0, 0, 39, '422'),
	(243, 1, 0, -50942, 424, 0, 0, 39, '423'),
	(243, 1, 0, -50942, 425, 0, 0, 39, '424'),
	(243, 1, 0, -50942, 426, 0, 0, 39, '425'),
	(243, 1, 0, -50942, 427, 0, 0, 39, '426'),
	(243, 1, 0, -50942, 428, 0, 0, 39, '427'),
	(243, 1, 0, -50942, 429, 0, 0, 39, '428'),
	(243, 1, 0, -50942, 430, 0, 0, 39, '429'),
	(243, 1, 0, -50942, 431, 0, 0, 39, '430'),
	(243, 1, 0, -50942, 432, 0, 0, 39, '431'),
	(243, 1, 0, -50942, 433, 0, 0, 39, '432'),
	(243, 1, 0, -50942, 434, 0, 0, 39, '433'),
	(243, 1, 0, -50942, 435, 0, 0, 39, '434'),
	(243, 1, 0, -50942, 436, 0, 0, 39, '435'),
	(243, 1, 0, -50942, 437, 0, 0, 39, '436'),
	(243, 1, 0, -50942, 438, 0, 0, 39, '437'),
	(243, 1, 0, -50942, 439, 0, 0, 39, '438'),
	(243, 1, 0, -50942, 440, 0, 0, 39, '439'),
	(243, 1, 0, -50942, 441, 0, 0, 39, '440'),
	(243, 1, 0, -50942, 442, 0, 0, 39, '441'),
	(243, 1, 0, -50942, 443, 0, 0, 39, '442'),
	(243, 1, 0, -50942, 444, 0, 0, 39, '443'),
	(243, 1, 0, -50942, 445, 0, 0, 39, '444'),
	(243, 1, 0, -50942, 446, 0, 0, 39, '445'),
	(243, 1, 0, -50942, 447, 0, 0, 39, '446'),
	(243, 1, 0, -50942, 448, 0, 0, 39, '447'),
	(243, 1, 0, -50942, 449, 0, 0, 39, '448'),
	(243, 1, 0, -50942, 450, 0, 0, 39, '449'),
	(243, 1, 0, -50942, 451, 0, 0, 39, '450'),
	(243, 1, 0, -50942, 452, 0, 0, 39, '451'),
	(243, 1, 0, -50942, 453, 0, 0, 39, '452'),
	(243, 1, 0, -50942, 454, 0, 0, 39, '453'),
	(243, 1, 0, -50942, 455, 0, 0, 39, '454'),
	(243, 1, 0, -50942, 456, 0, 0, 39, '455'),
	(243, 1, 0, -50942, 457, 0, 0, 39, '456'),
	(243, 1, 0, -50942, 458, 0, 0, 39, '457'),
	(243, 1, 0, -50942, 459, 0, 0, 39, '458'),
	(243, 1, 0, -50942, 460, 0, 0, 39, '459'),
	(243, 1, 0, -50942, 461, 0, 0, 39, '460'),
	(243, 1, 0, -50942, 462, 0, 0, 39, '461'),
	(243, 1, 0, -50942, 463, 0, 0, 39, '462'),
	(243, 1, 0, -50942, 464, 0, 0, 39, '463'),
	(243, 1, 0, -50942, 465, 0, 0, 39, '464'),
	(243, 1, 0, -50942, 466, 0, 0, 39, '465'),
	(243, 1, 0, -50942, 467, 0, 0, 39, '466'),
	(243, 1, 0, -50942, 468, 0, 0, 39, '467'),
	(243, 1, 0, -50942, 469, 0, 0, 39, '468'),
	(243, 1, 0, -50942, 470, 0, 0, 39, '469'),
	(243, 1, 0, -50942, 471, 0, 0, 39, '470'),
	(243, 1, 0, -50942, 472, 0, 0, 39, '471'),
	(243, 1, 0, -50942, 473, 0, 0, 39, '472'),
	(243, 1, 0, -50942, 474, 0, 0, 39, '473'),
	(243, 1, 0, -50942, 475, 0, 0, 39, '474'),
	(243, 1, 0, -50942, 476, 0, 0, 39, '475'),
	(243, 1, 0, -50942, 477, 0, 0, 39, '476'),
	(243, 1, 0, -50942, 478, 0, 0, 39, '477'),
	(243, 1, 0, -50942, 479, 0, 0, 39, '478'),
	(243, 1, 0, -50942, 480, 0, 0, 39, '479'),
	(243, 1, 0, -50942, 481, 0, 0, 39, '480'),
	(243, 1, 0, -50942, 482, 0, 0, 39, '481'),
	(243, 1, 0, -50942, 483, 0, 0, 39, '482'),
	(243, 1, 0, -50942, 484, 0, 0, 39, '483'),
	(243, 1, 0, -50942, 485, 0, 0, 39, '484'),
	(243, 1, 0, -50942, 486, 0, 0, 39, '485'),
	(243, 1, 0, -50942, 487, 0, 0, 39, '486'),
	(243, 1, 0, -50942, 488, 0, 0, 39, '487'),
	(243, 1, 0, -50942, 489, 0, 0, 39, '488'),
	(243, 1, 0, -50942, 490, 0, 0, 39, '489'),
	(243, 1, 0, -50942, 491, 0, 0, 39, '490'),
	(243, 1, 0, -50942, 492, 0, 0, 39, '491'),
	(243, 1, 0, -50942, 493, 0, 0, 39, '492'),
	(243, 1, 0, -50942, 494, 0, 0, 39, '493'),
	(243, 1, 0, -50942, 495, 0, 0, 39, '494'),
	(243, 1, 0, -50942, 496, 0, 0, 39, '495'),
	(243, 1, 0, -50942, 497, 0, 0, 39, '496'),
	(243, 1, 0, -50942, 498, 0, 0, 39, '497'),
	(243, 1, 0, -50942, 499, 0, 0, 39, '498'),
	(243, 1, 0, -50942, 500, 0, 0, 39, '499'),
	(243, 1, 0, -50942, 501, 0, 0, 39, '500'),
	(243, 1, 0, -50942, 502, 0, 0, 39, '501'),
	(243, 1, 0, -50942, 503, 0, 0, 39, '502'),
	(243, 1, 0, -50942, 504, 0, 0, 39, '503'),
	(243, 1, 0, -50942, 505, 0, 0, 39, '504'),
	(243, 1, 0, -50942, 506, 0, 0, 39, '505'),
	(243, 1, 0, -50942, 507, 0, 0, 39, '506'),
	(243, 1, 0, -50942, 508, 0, 0, 39, '507'),
	(243, 1, 0, -50942, 509, 0, 0, 39, '508'),
	(243, 1, 0, -50942, 510, 0, 0, 39, '509'),
	(243, 1, 0, -50942, 511, 0, 0, 39, '510'),
	(243, 1, 0, -50942, 512, 0, 0, 39, '511'),
	(243, 1, 0, -50942, 513, 0, 0, 39, '512'),
	(243, 1, 0, -50942, 514, 0, 0, 39, '513'),
	(243, 1, 0, -50942, 515, 0, 0, 39, '514'),
	(243, 1, 0, -50942, 516, 0, 0, 39, '515'),
	(243, 1, 0, -50942, 517, 0, 0, 39, '516'),
	(243, 1, 0, -50942, 518, 0, 0, 39, '517'),
	(243, 1, 0, -50942, 519, 0, 0, 39, '518'),
	(243, 1, 0, -50942, 520, 0, 0, 39, '519'),
	(243, 1, 0, -50942, 521, 0, 0, 39, '520'),
	(243, 1, 0, -50942, 522, 0, 0, 39, '521'),
	(243, 1, 0, -50942, 523, 0, 0, 39, '522'),
	(243, 1, 0, -50942, 524, 0, 0, 39, '523'),
	(243, 1, 0, -50942, 525, 0, 0, 39, '524'),
	(243, 1, 0, -50942, 526, 0, 0, 39, '525'),
	(243, 1, 0, -50942, 527, 0, 0, 39, '526'),
	(243, 1, 0, -50942, 528, 0, 0, 39, '527'),
	(243, 1, 0, -50942, 529, 0, 0, 39, '528'),
	(243, 1, 0, -50942, 530, 0, 0, 39, '529'),
	(243, 1, 0, -50942, 531, 0, 0, 39, '530'),
	(243, 1, 0, -50942, 532, 0, 0, 39, '531'),
	(243, 1, 0, -50942, 533, 0, 0, 39, '532'),
	(243, 1, 0, -50942, 534, 0, 0, 39, '533'),
	(243, 1, 0, -50942, 535, 0, 0, 39, '534'),
	(243, 1, 0, -50942, 536, 0, 0, 39, '535'),
	(243, 1, 0, -50942, 537, 0, 0, 39, '536'),
	(243, 1, 0, -50942, 538, 0, 0, 39, '537'),
	(243, 1, 0, -50942, 539, 0, 0, 39, '538'),
	(243, 1, 0, -50942, 540, 0, 0, 39, '539'),
	(243, 1, 0, -50942, 541, 0, 0, 39, '540'),
	(243, 1, 0, -50942, 542, 0, 0, 39, '541'),
	(243, 1, 0, -50942, 543, 0, 0, 39, '542'),
	(243, 1, 0, -50942, 544, 0, 0, 39, '543'),
	(243, 1, 0, -50942, 545, 0, 0, 39, '544'),
	(243, 1, 0, -50942, 546, 0, 0, 39, '545'),
	(243, 1, 0, -50942, 547, 0, 0, 39, '546'),
	(243, 1, 0, -50942, 548, 0, 0, 39, '547'),
	(243, 1, 0, -50942, 549, 0, 0, 39, '548'),
	(243, 1, 0, -50942, 550, 0, 0, 39, '549'),
	(243, 1, 0, -50942, 551, 0, 0, 39, '550'),
	(243, 1, 0, -50942, 552, 0, 0, 39, '551'),
	(243, 1, 0, -50942, 553, 0, 0, 39, '552'),
	(243, 1, 0, -50942, 554, 0, 0, 39, '553'),
	(243, 1, 0, -50942, 555, 0, 0, 39, '554'),
	(243, 1, 0, -50942, 556, 0, 0, 39, '555'),
	(243, 1, 0, -50942, 557, 0, 0, 39, '556'),
	(243, 1, 0, -50942, 558, 0, 0, 39, '557'),
	(243, 1, 0, -50942, 559, 0, 0, 39, '558'),
	(243, 1, 0, -50942, 560, 0, 0, 39, '559'),
	(243, 1, 0, -50942, 561, 0, 0, 39, '560'),
	(243, 1, 0, -50942, 562, 0, 0, 39, '561'),
	(243, 1, 0, -50942, 563, 0, 0, 39, '562'),
	(243, 1, 0, -50942, 564, 0, 0, 39, '563'),
	(243, 1, 0, -50942, 565, 0, 0, 39, '564'),
	(243, 1, 0, -50942, 566, 0, 0, 39, '565'),
	(243, 1, 0, -50942, 567, 0, 0, 39, '566'),
	(243, 1, 0, -50942, 568, 0, 0, 39, '567'),
	(243, 1, 0, -50942, 569, 0, 0, 39, '568'),
	(243, 1, 0, -50942, 570, 0, 0, 39, '569'),
	(243, 1, 0, -50942, 571, 0, 0, 39, '570'),
	(243, 1, 0, -50942, 572, 0, 0, 39, '571'),
	(243, 1, 0, -50942, 573, 0, 0, 39, '572'),
	(243, 1, 0, -50942, 574, 0, 0, 39, '573'),
	(243, 1, 0, -50942, 575, 0, 0, 39, '574'),
	(243, 1, 0, -50942, 576, 0, 0, 39, '575'),
	(243, 1, 0, -50942, 577, 0, 0, 39, '576'),
	(243, 1, 0, -50942, 578, 0, 0, 39, '577'),
	(243, 1, 0, -50942, 579, 0, 0, 39, '578'),
	(243, 1, 0, -50942, 580, 0, 0, 39, '579'),
	(243, 1, 0, -50942, 581, 0, 0, 39, '580'),
	(243, 1, 0, -50942, 582, 0, 0, 39, '581'),
	(243, 1, 0, -50942, 583, 0, 0, 39, '582'),
	(243, 1, 0, -50942, 584, 0, 0, 39, '583'),
	(243, 1, 0, -50942, 585, 0, 0, 39, '584'),
	(243, 1, 0, -50942, 586, 0, 0, 39, '585'),
	(243, 1, 0, -50942, 587, 0, 0, 39, '586'),
	(243, 1, 0, -50942, 588, 0, 0, 39, '587'),
	(243, 1, 0, -50942, 589, 0, 0, 39, '588'),
	(243, 1, 0, -50942, 590, 0, 0, 39, '589'),
	(243, 1, 0, -50942, 591, 0, 0, 39, '590'),
	(243, 1, 0, -50942, 592, 0, 0, 39, '591'),
	(243, 1, 0, -50942, 593, 0, 0, 39, '592'),
	(243, 1, 0, -50942, 594, 0, 0, 39, '593'),
	(243, 1, 0, -50942, 595, 0, 0, 39, '594'),
	(243, 1, 0, -50942, 596, 0, 0, 39, '595'),
	(243, 1, 0, -50942, 597, 0, 0, 39, '596'),
	(243, 1, 0, -50942, 598, 0, 0, 39, '597'),
	(243, 1, 0, -50942, 599, 0, 0, 39, '598'),
	(243, 1, 0, -50942, 600, 0, 0, 39, '599'),
	(243, 1, 0, -50942, 601, 0, 0, 39, '600'),
	(243, 1, 0, -50942, 602, 0, 0, 39, '601'),
	(243, 1, 0, -50942, 603, 0, 0, 39, '602'),
	(243, 1, 0, -50942, 604, 0, 0, 39, '603'),
	(243, 1, 0, -50942, 605, 0, 0, 39, '604'),
	(243, 1, 0, -50942, 606, 0, 0, 39, '605'),
	(243, 1, 0, -50942, 607, 0, 0, 39, '606'),
	(243, 1, 0, -50942, 608, 0, 0, 39, '607'),
	(243, 1, 0, -50942, 609, 0, 0, 39, '608'),
	(243, 1, 0, -50942, 610, 0, 0, 39, '609'),
	(243, 1, 0, -50942, 611, 0, 0, 39, '610'),
	(243, 1, 0, -50942, 612, 0, 0, 39, '611'),
	(243, 1, 0, -50942, 613, 0, 0, 39, '612'),
	(243, 1, 0, -50942, 614, 0, 0, 39, '613'),
	(243, 1, 0, -50942, 615, 0, 0, 39, '614'),
	(243, 1, 0, -50942, 616, 0, 0, 39, '615'),
	(243, 1, 0, -50942, 617, 0, 0, 39, '616'),
	(243, 1, 0, -50942, 618, 0, 0, 39, '617'),
	(243, 1, 0, -50942, 619, 0, 0, 39, '618'),
	(243, 1, 0, -50942, 620, 0, 0, 39, '619'),
	(243, 1, 0, -50942, 621, 0, 0, 39, '620'),
	(243, 1, 0, -50942, 622, 0, 0, 39, '621'),
	(243, 1, 0, -50942, 623, 0, 0, 39, '622'),
	(243, 1, 0, -50942, 624, 0, 0, 39, '623'),
	(243, 1, 0, -50942, 625, 0, 0, 39, '624'),
	(243, 1, 0, -50942, 626, 0, 0, 39, '625'),
	(243, 1, 0, -50942, 627, 0, 0, 39, '626'),
	(243, 1, 0, -50942, 628, 0, 0, 39, '627'),
	(243, 1, 0, -50942, 629, 0, 0, 39, '628'),
	(243, 1, 0, -50942, 630, 0, 0, 39, '629'),
	(243, 1, 0, -50942, 631, 0, 0, 39, '630'),
	(243, 1, 0, -50942, 632, 0, 0, 39, '631'),
	(243, 1, 0, -50942, 633, 0, 0, 39, '632'),
	(243, 1, 0, -50942, 634, 0, 0, 39, '633'),
	(243, 1, 0, -50942, 635, 0, 0, 39, '634'),
	(243, 1, 0, -50942, 636, 0, 0, 39, '635'),
	(243, 1, 0, -50942, 637, 0, 0, 39, '636'),
	(243, 1, 0, -50942, 638, 0, 0, 39, '637'),
	(243, 1, 0, -50942, 639, 0, 0, 39, '638'),
	(243, 1, 0, -50942, 640, 0, 0, 39, '639'),
	(243, 1, 0, -50942, 641, 0, 0, 39, '640'),
	(243, 1, 0, -50942, 642, 0, 0, 39, '641'),
	(243, 1, 0, -50942, 643, 0, 0, 39, '642'),
	(243, 1, 0, -50942, 644, 0, 0, 39, '643'),
	(243, 1, 0, -50942, 645, 0, 0, 39, '644'),
	(243, 1, 0, -50942, 646, 0, 0, 39, '645'),
	(243, 1, 0, -50942, 647, 0, 0, 39, '646'),
	(243, 1, 0, -50942, 648, 0, 0, 39, '647'),
	(243, 1, 0, -50942, 649, 0, 0, 39, '648'),
	(243, 1, 0, -50942, 650, 0, 0, 39, '649'),
	(243, 1, 0, -50942, 651, 0, 0, 39, '650'),
	(243, 1, 0, -50942, 652, 0, 0, 39, '651'),
	(243, 1, 0, -50942, 653, 0, 0, 39, '652'),
	(243, 1, 0, -50942, 654, 0, 0, 39, '653'),
	(243, 1, 0, -50942, 655, 0, 0, 39, '654'),
	(243, 1, 0, -50942, 656, 0, 0, 39, '655'),
	(243, 1, 0, -50942, 657, 0, 0, 39, '656'),
	(243, 1, 0, -50942, 658, 0, 0, 39, '657'),
	(243, 1, 0, -50942, 659, 0, 0, 39, '658'),
	(243, 1, 0, -50942, 660, 0, 0, 39, '659'),
	(243, 1, 0, -50942, 661, 0, 0, 39, '660'),
	(243, 1, 0, -50942, 662, 0, 0, 39, '661'),
	(243, 1, 0, -50942, 663, 0, 0, 39, '662'),
	(243, 1, 0, -50942, 664, 0, 0, 39, '663'),
	(243, 1, 0, -50942, 665, 0, 0, 39, '664'),
	(243, 1, 0, -50942, 666, 0, 0, 39, '665'),
	(243, 1, 0, -50942, 667, 0, 0, 39, '666'),
	(243, 1, 0, -50942, 668, 0, 0, 39, '667'),
	(243, 1, 0, -50942, 669, 0, 0, 39, '668'),
	(243, 1, 0, -50942, 670, 0, 0, 39, '669'),
	(243, 1, 0, -50942, 671, 0, 0, 39, '670'),
	(243, 1, 0, -50942, 672, 0, 0, 39, '671'),
	(243, 1, 0, -50942, 673, 0, 0, 39, '672'),
	(243, 1, 0, -50942, 674, 0, 0, 39, '673'),
	(243, 1, 0, -50942, 675, 0, 0, 39, '674'),
	(243, 1, 0, -50942, 676, 0, 0, 39, '675'),
	(243, 1, 0, -50942, 677, 0, 0, 39, '676'),
	(243, 1, 0, -50942, 678, 0, 0, 39, '677'),
	(243, 1, 0, -50942, 679, 0, 0, 39, '678'),
	(243, 1, 0, -50942, 680, 0, 0, 39, '679'),
	(243, 1, 0, -50942, 681, 0, 0, 39, '680'),
	(243, 1, 0, -50942, 682, 0, 0, 39, '681'),
	(243, 1, 0, -50942, 683, 0, 0, 39, '682'),
	(243, 1, 0, -50942, 684, 0, 0, 39, '683'),
	(243, 1, 0, -50942, 685, 0, 0, 39, '684'),
	(243, 1, 0, -50942, 686, 0, 0, 39, '685'),
	(243, 1, 0, -50942, 687, 0, 0, 39, '686'),
	(243, 1, 0, -50942, 688, 0, 0, 39, '687'),
	(243, 1, 0, -50942, 689, 0, 0, 39, '688'),
	(243, 1, 0, -50942, 690, 0, 0, 39, '689'),
	(243, 1, 0, -50942, 691, 0, 0, 39, '690'),
	(243, 1, 0, -50942, 692, 0, 0, 39, '691'),
	(243, 1, 0, -50942, 693, 0, 0, 39, '692'),
	(243, 1, 0, -50942, 694, 0, 0, 39, '693'),
	(243, 1, 0, -50942, 695, 0, 0, 39, '694'),
	(243, 1, 0, -50942, 696, 0, 0, 39, '695'),
	(243, 1, 0, -50942, 697, 0, 0, 39, '696'),
	(243, 1, 0, -50942, 698, 0, 0, 39, '697'),
	(243, 1, 0, -50942, 699, 0, 0, 39, '698'),
	(243, 1, 0, -50942, 700, 0, 0, 39, '699'),
	(243, 1, 0, -50942, 701, 0, 0, 39, '700'),
	(243, 1, 0, -50942, 702, 0, 0, 39, '701'),
	(243, 1, 0, -50942, 703, 0, 0, 39, '702'),
	(243, 1, 0, -50942, 704, 0, 0, 39, '703'),
	(243, 1, 0, -50942, 705, 0, 0, 39, '704'),
	(243, 1, 0, -50942, 706, 0, 0, 39, '705'),
	(243, 1, 0, -50942, 707, 0, 0, 39, '706'),
	(243, 1, 0, -50942, 708, 0, 0, 39, '707'),
	(243, 1, 0, -50942, 709, 0, 0, 39, '708'),
	(243, 1, 0, -50942, 710, 0, 0, 39, '709'),
	(243, 1, 0, -50942, 711, 0, 0, 39, '710'),
	(243, 1, 0, -50942, 712, 0, 0, 39, '711'),
	(243, 1, 0, -50942, 713, 0, 0, 39, '712'),
	(243, 1, 0, -50942, 714, 0, 0, 39, '713'),
	(243, 1, 0, -50942, 715, 0, 0, 39, '714'),
	(243, 1, 0, -50942, 716, 0, 0, 39, '715'),
	(243, 1, 0, -50942, 717, 0, 0, 39, '716'),
	(243, 1, 0, -50942, 718, 0, 0, 39, '717'),
	(243, 1, 0, -50942, 719, 0, 0, 39, '718'),
	(243, 1, 0, -50942, 720, 0, 0, 39, '719'),
	(243, 1, 0, -50942, 721, 0, 0, 39, '720'),
	(243, 1, 0, -50942, 722, 0, 0, 39, '721'),
	(243, 1, 0, -50942, 723, 0, 0, 39, '722'),
	(243, 1, 0, -50942, 724, 0, 0, 39, '723'),
	(243, 1, 0, -50942, 725, 0, 0, 39, '724'),
	(243, 1, 0, -50942, 726, 0, 0, 39, '725'),
	(243, 1, 0, -50942, 727, 0, 0, 39, '726'),
	(243, 1, 0, -50942, 728, 0, 0, 39, '727'),
	(243, 1, 0, -50942, 729, 0, 0, 39, '728'),
	(243, 1, 0, -50942, 730, 0, 0, 39, '729'),
	(243, 1, 0, -50942, 731, 0, 0, 39, '730'),
	(243, 1, 0, -50942, 732, 0, 0, 39, '731'),
	(243, 1, 0, -50942, 733, 0, 0, 39, '732'),
	(243, 1, 0, -50942, 734, 0, 0, 39, '733'),
	(243, 1, 0, -50942, 735, 0, 0, 39, '734'),
	(243, 1, 0, -50942, 736, 0, 0, 39, '735'),
	(243, 1, 0, -50942, 737, 0, 0, 39, '736'),
	(243, 1, 0, -50942, 738, 0, 0, 39, '737'),
	(243, 1, 0, -50942, 739, 0, 0, 39, '738'),
	(243, 1, 0, -50942, 740, 0, 0, 39, '739'),
	(243, 1, 0, -50942, 741, 0, 0, 39, '740'),
	(243, 1, 0, -50942, 742, 0, 0, 39, '741'),
	(243, 1, 0, -50942, 743, 0, 0, 39, '742'),
	(243, 1, 0, -50942, 744, 0, 0, 39, '743'),
	(243, 1, 0, -50942, 745, 0, 0, 39, '744'),
	(243, 1, 0, -50942, 746, 0, 0, 39, '745'),
	(243, 1, 0, -50942, 747, 0, 0, 39, '746'),
	(243, 1, 0, -50942, 748, 0, 0, 39, '747'),
	(243, 1, 0, -50942, 749, 0, 0, 39, '748'),
	(243, 1, 0, -50942, 750, 0, 0, 39, '749'),
	(243, 1, 0, -50942, 751, 0, 0, 39, '750'),
	(243, 1, 0, -50942, 752, 0, 0, 39, '751'),
	(243, 1, 0, -50942, 753, 0, 0, 39, '752'),
	(243, 1, 0, -50942, 754, 0, 0, 39, '753'),
	(243, 1, 0, -50942, 755, 0, 0, 39, '754'),
	(243, 1, 0, -50942, 756, 0, 0, 39, '755'),
	(243, 1, 0, -50942, 757, 0, 0, 39, '756'),
	(243, 1, 0, -50942, 758, 0, 0, 39, '757'),
	(243, 1, 0, -50942, 759, 0, 0, 39, '758'),
	(243, 1, 0, -50942, 760, 0, 0, 39, '759'),
	(243, 1, 0, -50942, 761, 0, 0, 39, '760'),
	(243, 1, 0, -50942, 762, 0, 0, 39, '761'),
	(243, 1, 0, -50942, 763, 0, 0, 39, '762'),
	(243, 1, 0, -50942, 764, 0, 0, 39, '763'),
	(243, 1, 0, -50942, 765, 0, 0, 39, '764'),
	(243, 1, 0, -50942, 766, 0, 0, 39, '765'),
	(243, 1, 0, -50942, 767, 0, 0, 39, '766'),
	(243, 1, 0, -50942, 768, 0, 0, 39, '767'),
	(243, 1, 0, -50942, 769, 0, 0, 39, '768'),
	(243, 1, 0, -50942, 770, 0, 0, 39, '769'),
	(243, 1, 0, -50942, 771, 0, 0, 39, '770'),
	(243, 1, 0, -50942, 772, 0, 0, 39, '771'),
	(243, 1, 0, -50942, 773, 0, 0, 39, '772'),
	(243, 1, 0, -50942, 774, 0, 0, 39, '773'),
	(243, 1, 0, -50942, 775, 0, 0, 39, '774'),
	(243, 1, 0, -50942, 776, 0, 0, 39, '775'),
	(243, 1, 0, -50942, 777, 0, 0, 39, '776'),
	(243, 1, 0, -50942, 778, 0, 0, 39, '777'),
	(243, 1, 0, -50942, 779, 0, 0, 39, '778'),
	(243, 1, 0, -50942, 780, 0, 0, 39, '779'),
	(243, 1, 0, -50942, 781, 0, 0, 39, '780'),
	(243, 1, 0, -50942, 782, 0, 0, 39, '781'),
	(243, 1, 0, -50942, 783, 0, 0, 39, '782'),
	(243, 1, 0, -50942, 784, 0, 0, 39, '783'),
	(243, 1, 0, -50942, 785, 0, 0, 39, '784'),
	(243, 1, 0, -50942, 786, 0, 0, 39, '785'),
	(243, 1, 0, -50942, 787, 0, 0, 39, '786'),
	(243, 1, 0, -50942, 788, 0, 0, 39, '787'),
	(243, 1, 0, -50942, 789, 0, 0, 39, '788'),
	(243, 1, 0, -50942, 790, 0, 0, 39, '789'),
	(243, 1, 0, -50942, 791, 0, 0, 39, '790'),
	(243, 1, 0, -50942, 792, 0, 0, 39, '791'),
	(243, 1, 0, -50942, 793, 0, 0, 39, '792'),
	(243, 1, 0, -50942, 794, 0, 0, 39, '793'),
	(243, 1, 0, -50942, 795, 0, 0, 39, '794'),
	(243, 1, 0, -50942, 796, 0, 0, 39, '795'),
	(243, 1, 0, -50942, 797, 0, 0, 39, '796'),
	(243, 1, 0, -50942, 798, 0, 0, 39, '797'),
	(243, 1, 0, -50942, 799, 0, 0, 39, '798'),
	(243, 1, 0, -50942, 800, 0, 0, 39, '799'),
	(243, 1, 0, -50942, 801, 0, 0, 39, '800'),
	(243, 1, 0, -50942, 802, 0, 0, 39, '801'),
	(243, 1, 0, -50942, 803, 0, 0, 39, '802'),
	(243, 1, 0, -50942, 804, 0, 0, 39, '803'),
	(243, 1, 0, -50942, 805, 0, 0, 39, '804'),
	(243, 1, 0, -50942, 806, 0, 0, 39, '805'),
	(243, 1, 0, -50942, 807, 0, 0, 39, '806'),
	(243, 1, 0, -50942, 808, 0, 0, 39, '807'),
	(243, 1, 0, -50942, 809, 0, 0, 39, '808'),
	(243, 1, 0, -50942, 810, 0, 0, 39, '809'),
	(243, 1, 0, -50942, 811, 0, 0, 39, '810'),
	(243, 1, 0, -50942, 812, 0, 0, 39, '811'),
	(243, 1, 0, -50942, 813, 0, 0, 39, '812'),
	(243, 1, 0, -50942, 814, 0, 0, 39, '813'),
	(243, 1, 0, -50942, 815, 0, 0, 39, '814'),
	(243, 1, 0, -50942, 816, 0, 0, 39, '815'),
	(243, 1, 0, -50942, 817, 0, 0, 39, '816'),
	(243, 1, 0, -50942, 818, 0, 0, 39, '817'),
	(243, 1, 0, -50942, 819, 0, 0, 39, '818'),
	(243, 1, 0, -50942, 820, 0, 0, 39, '819'),
	(243, 1, 0, -50942, 821, 0, 0, 39, '820'),
	(243, 1, 0, -50942, 822, 0, 0, 39, '821'),
	(243, 1, 0, -50942, 823, 0, 0, 39, '822'),
	(243, 1, 0, -50942, 824, 0, 0, 39, '823'),
	(243, 1, 0, -50942, 825, 0, 0, 39, '824'),
	(243, 1, 0, -50942, 826, 0, 0, 39, '825'),
	(243, 1, 0, -50942, 827, 0, 0, 39, '826'),
	(243, 1, 0, -50942, 828, 0, 0, 39, '827'),
	(243, 1, 0, -50942, 829, 0, 0, 39, '828'),
	(243, 1, 0, -50942, 830, 0, 0, 39, '829'),
	(243, 1, 0, -50942, 831, 0, 0, 39, '830'),
	(243, 1, 0, -50942, 832, 0, 0, 39, '831'),
	(243, 1, 0, -50942, 833, 0, 0, 39, '832'),
	(243, 1, 0, -50942, 834, 0, 0, 39, '833'),
	(243, 1, 0, -50942, 835, 0, 0, 39, '834'),
	(243, 1, 0, -50942, 836, 0, 0, 39, '835'),
	(243, 1, 0, -50942, 837, 0, 0, 39, '836'),
	(243, 1, 0, -50942, 838, 0, 0, 39, '837'),
	(243, 1, 0, -50942, 839, 0, 0, 39, '838'),
	(243, 1, 0, -50942, 840, 0, 0, 39, '839'),
	(243, 1, 0, -50942, 841, 0, 0, 39, '840'),
	(243, 1, 0, -50942, 842, 0, 0, 39, '841'),
	(243, 1, 0, -50942, 843, 0, 0, 39, '842'),
	(243, 1, 0, -50942, 844, 0, 0, 39, '843'),
	(243, 1, 0, -50942, 845, 0, 0, 39, '844'),
	(243, 1, 0, -50942, 846, 0, 0, 39, '845'),
	(243, 1, 0, -50942, 847, 0, 0, 39, '846'),
	(243, 1, 0, -50942, 848, 0, 0, 39, '847'),
	(243, 1, 0, -50942, 849, 0, 0, 39, '848'),
	(243, 1, 0, -50942, 850, 0, 0, 39, '849'),
	(243, 1, 0, -50942, 851, 0, 0, 39, '850'),
	(243, 1, 0, -50942, 852, 0, 0, 39, '851'),
	(243, 1, 0, -50942, 853, 0, 0, 39, '852'),
	(243, 1, 0, -50942, 854, 0, 0, 39, '853'),
	(243, 1, 0, -50942, 855, 0, 0, 39, '854'),
	(243, 1, 0, -50942, 856, 0, 0, 39, '855'),
	(243, 1, 0, -50942, 857, 0, 0, 39, '856'),
	(243, 1, 0, -50942, 858, 0, 0, 39, '857'),
	(243, 1, 0, -50942, 859, 0, 0, 39, '858'),
	(243, 1, 0, -50942, 860, 0, 0, 39, '859'),
	(243, 1, 0, -50942, 861, 0, 0, 39, '860'),
	(243, 1, 0, -50942, 862, 0, 0, 39, '861'),
	(243, 1, 0, -50942, 863, 0, 0, 39, '862'),
	(243, 1, 0, -50942, 864, 0, 0, 39, '863'),
	(243, 1, 0, -50942, 865, 0, 0, 39, '864'),
	(243, 1, 0, -50942, 866, 0, 0, 39, '865'),
	(243, 1, 0, -50942, 867, 0, 0, 39, '866'),
	(243, 1, 0, -50942, 868, 0, 0, 39, '867'),
	(243, 1, 0, -50942, 869, 0, 0, 39, '868'),
	(243, 1, 0, -50942, 870, 0, 0, 39, '869'),
	(243, 1, 0, -50942, 871, 0, 0, 39, '870'),
	(243, 1, 0, -50942, 872, 0, 0, 39, '871'),
	(243, 1, 0, -50942, 873, 0, 0, 39, '872'),
	(243, 1, 0, -50942, 874, 0, 0, 39, '873'),
	(243, 1, 0, -50942, 875, 0, 0, 39, '874'),
	(243, 1, 0, -50942, 876, 0, 0, 39, '875'),
	(243, 1, 0, -50942, 877, 0, 0, 39, '876'),
	(243, 1, 0, -50942, 878, 0, 0, 39, '877'),
	(243, 1, 0, -50942, 879, 0, 0, 39, '878'),
	(243, 1, 0, -50942, 880, 0, 0, 39, '879'),
	(243, 1, 0, -50942, 881, 0, 0, 39, '880'),
	(243, 1, 0, -50942, 882, 0, 0, 39, '881'),
	(243, 1, 0, -50942, 883, 0, 0, 39, '882'),
	(243, 1, 0, -50942, 884, 0, 0, 39, '883'),
	(243, 1, 0, -50942, 885, 0, 0, 39, '884'),
	(243, 1, 0, -50942, 886, 0, 0, 39, '885'),
	(243, 1, 0, -50942, 887, 0, 0, 39, '886'),
	(243, 1, 0, -50942, 888, 0, 0, 39, '887'),
	(243, 1, 0, -50942, 889, 0, 0, 39, '888'),
	(243, 1, 0, -50942, 890, 0, 0, 39, '889'),
	(243, 1, 0, -50942, 891, 0, 0, 39, '890'),
	(243, 1, 0, -50942, 892, 0, 0, 39, '891'),
	(243, 1, 0, -50942, 893, 0, 0, 39, '892'),
	(243, 1, 0, -50942, 894, 0, 0, 39, '893'),
	(243, 1, 0, -50942, 895, 0, 0, 39, '894'),
	(243, 1, 0, -50942, 896, 0, 0, 39, '895'),
	(243, 1, 0, -50942, 897, 0, 0, 39, '896'),
	(243, 1, 0, -50942, 898, 0, 0, 39, '897'),
	(243, 1, 0, -50942, 899, 0, 0, 39, '898'),
	(243, 1, 0, -50942, 900, 0, 0, 39, '899'),
	(243, 1, 0, -50942, 901, 0, 0, 39, '900'),
	(243, 1, 0, -50942, 902, 0, 0, 39, '901'),
	(243, 1, 0, -50942, 903, 0, 0, 39, '902'),
	(243, 1, 0, -50942, 904, 0, 0, 39, '903'),
	(243, 1, 0, -50942, 905, 0, 0, 39, '904'),
	(243, 1, 0, -50942, 906, 0, 0, 39, '905'),
	(243, 1, 0, -50942, 907, 0, 0, 39, '906'),
	(243, 1, 0, -50942, 908, 0, 0, 39, '907'),
	(243, 1, 0, -50942, 909, 0, 0, 39, '908'),
	(243, 1, 0, -50942, 910, 0, 0, 39, '909'),
	(243, 1, 0, -50942, 911, 0, 0, 39, '910'),
	(243, 1, 0, -50942, 912, 0, 0, 39, '911'),
	(243, 1, 0, -50942, 913, 0, 0, 39, '912'),
	(243, 1, 0, -50942, 914, 0, 0, 39, '913'),
	(243, 1, 0, -50942, 915, 0, 0, 39, '914'),
	(243, 1, 0, -50942, 916, 0, 0, 39, '915'),
	(243, 1, 0, -50942, 917, 0, 0, 39, '916'),
	(243, 1, 0, -50942, 918, 0, 0, 39, '917'),
	(243, 1, 0, -50942, 919, 0, 0, 39, '918'),
	(243, 1, 0, -50942, 920, 0, 0, 39, '919'),
	(243, 1, 0, -50942, 921, 0, 0, 39, '920'),
	(243, 1, 0, -50942, 922, 0, 0, 39, '921'),
	(243, 1, 0, -50942, 923, 0, 0, 39, '922'),
	(243, 1, 0, -50942, 924, 0, 0, 39, '923'),
	(243, 1, 0, -50942, 925, 0, 0, 39, '924'),
	(243, 1, 0, -50942, 926, 0, 0, 39, '925'),
	(243, 1, 0, -50942, 927, 0, 0, 39, '926'),
	(243, 1, 0, -50942, 928, 0, 0, 39, '927'),
	(243, 1, 0, -50942, 929, 0, 0, 39, '928'),
	(243, 1, 0, -50942, 930, 0, 0, 39, '929'),
	(243, 1, 0, -50942, 931, 0, 0, 39, '930'),
	(243, 1, 0, -50942, 932, 0, 0, 39, '931'),
	(243, 1, 0, -50942, 933, 0, 0, 39, '932'),
	(243, 1, 0, -50942, 934, 0, 0, 39, '933'),
	(243, 1, 0, -50942, 935, 0, 0, 39, '934'),
	(243, 1, 0, -50942, 936, 0, 0, 39, '935'),
	(243, 1, 0, -50942, 937, 0, 0, 39, '936'),
	(243, 1, 0, -50942, 938, 0, 0, 39, '937'),
	(243, 1, 0, -50942, 939, 0, 0, 39, '938'),
	(243, 1, 0, -50942, 940, 0, 0, 39, '939'),
	(243, 1, 0, -50942, 941, 0, 0, 39, '940'),
	(243, 1, 0, -50942, 942, 0, 0, 39, '941'),
	(243, 1, 0, -50942, 943, 0, 0, 39, '942'),
	(243, 1, 0, -50942, 944, 0, 0, 39, '943'),
	(243, 1, 0, -50942, 945, 0, 0, 39, '944'),
	(243, 1, 0, -50942, 946, 0, 0, 39, '945'),
	(243, 1, 0, -50942, 947, 0, 0, 39, '946'),
	(243, 1, 0, -50942, 948, 0, 0, 39, '947'),
	(243, 1, 0, -50942, 949, 0, 0, 39, '948'),
	(243, 1, 0, -50942, 950, 0, 0, 39, '949'),
	(243, 1, 0, -50942, 951, 0, 0, 39, '950'),
	(243, 1, 0, -50942, 952, 0, 0, 39, '951'),
	(243, 1, 0, -50942, 953, 0, 0, 39, '952'),
	(243, 1, 0, -50942, 954, 0, 0, 39, '953'),
	(243, 1, 0, -50942, 955, 0, 0, 39, '954'),
	(243, 1, 0, -50942, 956, 0, 0, 39, '955'),
	(243, 1, 0, -50942, 957, 0, 0, 39, '956'),
	(243, 1, 0, -50942, 958, 0, 0, 39, '957'),
	(243, 1, 0, -50942, 959, 0, 0, 39, '958'),
	(243, 1, 0, -50942, 960, 0, 0, 39, '959'),
	(243, 1, 0, -50942, 961, 0, 0, 39, '960'),
	(243, 1, 0, -50942, 962, 0, 0, 39, '961'),
	(243, 1, 0, -50942, 963, 0, 0, 39, '962'),
	(243, 1, 0, -50942, 964, 0, 0, 39, '963'),
	(243, 1, 0, -50942, 965, 0, 0, 39, '964'),
	(243, 1, 0, -50942, 966, 0, 0, 39, '965'),
	(243, 1, 0, -50942, 967, 0, 0, 39, '966'),
	(243, 1, 0, -50942, 968, 0, 0, 39, '967'),
	(243, 1, 0, -50942, 969, 0, 0, 39, '968'),
	(243, 1, 0, -50942, 970, 0, 0, 39, '969'),
	(243, 1, 0, -50942, 971, 0, 0, 39, '970'),
	(243, 1, 0, -50942, 972, 0, 0, 39, '971'),
	(243, 1, 0, -50942, 973, 0, 0, 39, '972'),
	(243, 1, 0, -50942, 974, 0, 0, 39, '973'),
	(243, 1, 0, -50942, 975, 0, 0, 39, '974'),
	(243, 1, 0, -50942, 976, 0, 0, 39, '975'),
	(243, 1, 0, -50942, 977, 0, 0, 39, '976'),
	(243, 1, 0, -50942, 978, 0, 0, 39, '977'),
	(243, 1, 0, -50942, 979, 0, 0, 39, '978'),
	(243, 1, 0, -50942, 980, 0, 0, 39, '979'),
	(243, 1, 0, -50942, 981, 0, 0, 39, '980'),
	(243, 1, 0, -50942, 982, 0, 0, 39, '981'),
	(243, 1, 0, -50942, 983, 0, 0, 39, '982'),
	(243, 1, 0, -50942, 984, 0, 0, 39, '983'),
	(243, 1, 0, -50942, 985, 0, 0, 39, '984'),
	(243, 1, 0, -50942, 986, 0, 0, 39, '985'),
	(243, 1, 0, -50942, 987, 0, 0, 39, '986'),
	(243, 1, 0, -50942, 988, 0, 0, 39, '987'),
	(243, 1, 0, -50942, 989, 0, 0, 39, '988'),
	(243, 1, 0, -50942, 990, 0, 0, 39, '989'),
	(243, 1, 0, -50942, 991, 0, 0, 39, '990'),
	(243, 1, 0, -50942, 992, 0, 0, 39, '991'),
	(243, 1, 0, -50942, 993, 0, 0, 39, '992'),
	(243, 1, 0, -50942, 994, 0, 0, 39, '993'),
	(243, 1, 0, -50942, 995, 0, 0, 39, '994'),
	(243, 1, 0, -50942, 996, 0, 0, 39, '995'),
	(243, 1, 0, -50942, 997, 0, 0, 39, '996'),
	(243, 1, 0, -50942, 998, 0, 0, 39, '997'),
	(243, 1, 0, -50942, 999, 0, 0, 39, '998'),
	(243, 1, 0, -50942, 1000, 0, 0, 39, '999'),
	(243, 1, 0, -50942, 1001, 0, 0, 39, '1000'),
	(243, 1, 0, -50942, 1002, 0, 0, 39, '1001'),
	(243, 1, 0, -50942, 1003, 0, 0, 39, '1002'),
	(243, 1, 0, -50942, 1004, 0, 0, 39, '1003'),
	(243, 1, 0, -50942, 1005, 0, 0, 39, '1004'),
	(243, 1, 0, -50942, 1006, 0, 0, 39, '1005'),
	(243, 1, 0, -50942, 1007, 0, 0, 39, '1006'),
	(243, 1, 0, -50942, 1008, 0, 0, 39, '1007'),
	(243, 1, 0, -50942, 1009, 0, 0, 39, '1008'),
	(243, 1, 0, -50942, 1010, 0, 0, 39, '1009'),
	(243, 1, 0, -50942, 1011, 0, 0, 39, '1010'),
	(243, 1, 0, -50942, 1012, 0, 0, 39, '1011'),
	(243, 1, 0, -50942, 1013, 0, 0, 39, '1012'),
	(243, 1, 0, -50942, 1014, 0, 0, 39, '1013'),
	(243, 1, 0, -50942, 1015, 0, 0, 39, '1014'),
	(243, 1, 0, -50942, 1016, 0, 0, 39, '1015'),
	(243, 1, 0, -50942, 1017, 0, 0, 39, '1016'),
	(243, 1, 0, -50942, 1018, 0, 0, 39, '1017'),
	(243, 1, 0, -50942, 1019, 0, 0, 39, '1018'),
	(243, 1, 0, -50942, 1020, 0, 0, 39, '1019'),
	(243, 1, 0, -50942, 1021, 0, 0, 39, '1020'),
	(243, 1, 0, -50942, 1022, 0, 0, 39, '1021'),
	(243, 1, 0, -50942, 1023, 0, 0, 39, '1022'),
	(243, 1, 0, -50942, 1024, 0, 0, 39, '1023'),
	(243, 1, 0, -50942, 1025, 0, 0, 39, '1024'),
	(243, 1, 0, -50942, 1026, 0, 0, 39, '1025'),
	(243, 1, 0, -50942, 1027, 0, 0, 39, '1026'),
	(243, 1, 0, -50942, 1028, 0, 0, 39, '1027'),
	(243, 1, 0, -50942, 1029, 0, 0, 39, '1028'),
	(243, 1, 0, -50942, 1030, 0, 0, 39, '1029'),
	(243, 1, 0, -50942, 1031, 0, 0, 39, '1030'),
	(243, 1, 0, -50942, 1032, 0, 0, 39, '1031'),
	(243, 1, 0, -50942, 1033, 0, 0, 39, '1032'),
	(243, 1, 0, -50942, 1034, 0, 0, 39, '1033'),
	(243, 1, 0, -50942, 1035, 0, 0, 39, '1034'),
	(243, 1, 0, -50942, 1036, 0, 0, 39, '1035'),
	(243, 1, 0, -50942, 1037, 0, 0, 39, '1036'),
	(243, 1, 0, -50942, 1038, 0, 0, 39, '1037'),
	(243, 1, 0, -50942, 1039, 0, 0, 39, '1038'),
	(243, 1, 0, -50942, 1040, 0, 0, 39, '1039'),
	(243, 1, 0, -50942, 1041, 0, 0, 39, '1040'),
	(243, 1, 0, -50942, 1042, 0, 0, 39, '1041'),
	(243, 1, 0, -50942, 1043, 0, 0, 39, '1042'),
	(243, 1, 0, -50942, 1044, 0, 0, 39, '1043'),
	(243, 1, 0, -50942, 1045, 0, 0, 39, '1044'),
	(243, 1, 0, -50942, 1046, 0, 0, 39, '1045'),
	(243, 1, 0, -50942, 1047, 0, 0, 39, '1046'),
	(243, 1, 0, -50942, 1048, 0, 0, 39, '1047'),
	(243, 1, 0, -50942, 1049, 0, 0, 39, '1048'),
	(243, 1, 0, -50942, 1050, 0, 0, 39, '1049'),
	(243, 1, 0, -50942, 1051, 0, 0, 39, '1050'),
	(243, 1, 0, -50942, 1052, 0, 0, 39, '1051'),
	(243, 1, 0, -50942, 1053, 0, 0, 39, '1052'),
	(243, 1, 0, -50942, 1054, 0, 0, 39, '1053'),
	(243, 1, 0, -50942, 1055, 0, 0, 39, '1054'),
	(243, 1, 0, -50942, 1056, 0, 0, 39, '1055'),
	(243, 1, 0, -50942, 1057, 0, 0, 39, '1056'),
	(243, 1, 0, -50942, 1058, 0, 0, 39, '1057'),
	(243, 1, 0, -50942, 1059, 0, 0, 39, '1058'),
	(243, 1, 0, -50942, 1060, 0, 0, 39, '1059'),
	(243, 1, 0, -50942, 1061, 0, 0, 39, '1060'),
	(243, 1, 0, -50942, 1062, 0, 0, 39, '1061'),
	(243, 1, 0, -50942, 1063, 0, 0, 39, '1062'),
	(243, 1, 0, -50942, 1064, 0, 0, 39, '1063'),
	(243, 1, 0, -50942, 1065, 0, 0, 39, '1064'),
	(243, 1, 0, -50942, 1066, 0, 0, 39, '1065'),
	(243, 1, 0, -50942, 1067, 0, 0, 39, '1066'),
	(243, 1, 0, -50942, 1068, 0, 0, 39, '1067'),
	(243, 1, 0, -50942, 1069, 0, 0, 39, '1068'),
	(243, 1, 0, -50942, 1070, 0, 0, 39, '1069'),
	(243, 1, 0, -50942, 1071, 0, 0, 39, '1070'),
	(243, 1, 0, -50942, 1072, 0, 0, 39, '1071'),
	(243, 1, 0, -50942, 1073, 0, 0, 39, '1072'),
	(243, 1, 0, -50942, 1074, 0, 0, 39, '1073'),
	(243, 1, 0, -50942, 1075, 0, 0, 39, '1074'),
	(243, 1, 0, -50942, 1076, 0, 0, 39, '1075'),
	(243, 1, 0, -50942, 1077, 0, 0, 39, '1076'),
	(243, 1, 0, -50942, 1078, 0, 0, 39, '1077'),
	(243, 1, 0, -50942, 1079, 0, 0, 39, '1078'),
	(243, 1, 0, -50942, 1080, 0, 0, 39, '1079'),
	(243, 1, 0, -50942, 1081, 0, 0, 39, '1080'),
	(243, 1, 0, -50942, 1082, 0, 0, 39, '1081'),
	(243, 1, 0, -50942, 1083, 0, 0, 39, '1082'),
	(243, 1, 0, -50942, 1084, 0, 0, 39, '1083'),
	(243, 1, 0, -50942, 1085, 0, 0, 39, '1084'),
	(243, 1, 0, -50942, 1086, 0, 0, 39, '1085'),
	(243, 1, 0, -50942, 1087, 0, 0, 39, '1086'),
	(243, 1, 0, -50942, 1088, 0, 0, 39, '1087'),
	(243, 1, 0, -50942, 1089, 0, 0, 39, '1088'),
	(243, 1, 0, -50942, 1090, 0, 0, 39, '1089'),
	(243, 1, 0, -50942, 1091, 0, 0, 39, '1090'),
	(243, 1, 0, -50942, 1092, 0, 0, 39, '1091'),
	(243, 1, 0, -50942, 1093, 0, 0, 39, '1092'),
	(243, 1, 0, -50942, 1094, 0, 0, 39, '1093'),
	(243, 1, 0, -50942, 1095, 0, 0, 39, '1094'),
	(243, 1, 0, -50942, 1096, 0, 0, 39, '1095'),
	(243, 1, 0, -50942, 1097, 0, 0, 39, '1096'),
	(243, 1, 0, -50942, 1098, 0, 0, 39, '1097'),
	(243, 1, 0, -50942, 1099, 0, 0, 39, '1098'),
	(243, 1, 0, -50942, 1100, 0, 0, 39, '1099'),
	(243, 1, 0, -50942, 1101, 0, 0, 39, '1100'),
	(243, 1, 0, -50942, 1102, 0, 0, 39, '1101'),
	(243, 1, 0, -50942, 1103, 0, 0, 39, '1102'),
	(243, 1, 0, -50942, 1104, 0, 0, 39, '1103'),
	(243, 1, 0, -50942, 1105, 0, 0, 39, '1104'),
	(243, 1, 0, -50942, 1106, 0, 0, 39, '1105'),
	(243, 1, 0, -50942, 1107, 0, 0, 39, '1106'),
	(243, 1, 0, -50942, 1108, 0, 0, 39, '1107'),
	(243, 1, 0, -50942, 1109, 0, 0, 39, '1108'),
	(243, 1, 0, -50942, 1110, 0, 0, 39, '1109'),
	(243, 1, 0, -50942, 1111, 0, 0, 39, '1110'),
	(243, 1, 0, -50942, 1112, 0, 0, 39, '1111'),
	(243, 1, 0, -50942, 1113, 0, 0, 39, '1112'),
	(243, 1, 0, -50942, 1114, 0, 0, 39, '1113'),
	(243, 1, 0, -50942, 1115, 0, 0, 39, '1114'),
	(243, 1, 0, -50942, 1116, 0, 0, 39, '1115'),
	(243, 1, 0, -50942, 1117, 0, 0, 39, '1116'),
	(243, 1, 0, -50942, 1118, 0, 0, 39, '1117'),
	(243, 1, 0, -50942, 1119, 0, 0, 39, '1118'),
	(243, 1, 0, -50942, 1120, 0, 0, 39, '1119'),
	(243, 1, 0, -50942, 1121, 0, 0, 39, '1120'),
	(243, 1, 0, -50942, 1122, 0, 0, 39, '1121'),
	(243, 1, 0, -50942, 1123, 0, 0, 39, '1122'),
	(243, 1, 0, -50942, 1124, 0, 0, 39, '1123'),
	(243, 1, 0, -50942, 1125, 0, 0, 39, '1124'),
	(243, 1, 0, -50942, 1126, 0, 0, 39, '1125'),
	(243, 1, 0, -50942, 1127, 0, 0, 39, '1126'),
	(243, 1, 0, -50942, 1128, 0, 0, 39, '1127'),
	(243, 1, 0, -50942, 1129, 0, 0, 39, '1128'),
	(243, 1, 0, -50942, 1130, 0, 0, 39, '1129'),
	(243, 1, 0, -50942, 1131, 0, 0, 39, '1130'),
	(243, 1, 0, -50942, 1132, 0, 0, 39, '1131'),
	(243, 1, 0, -50942, 1133, 0, 0, 39, '1132'),
	(243, 1, 0, -50942, 1134, 0, 0, 39, '1133'),
	(243, 1, 0, -50942, 1135, 0, 0, 39, '1134'),
	(243, 1, 0, -50942, 1136, 0, 0, 39, '1135'),
	(243, 1, 0, -50942, 1137, 0, 0, 39, '1136'),
	(243, 1, 0, -50942, 1138, 0, 0, 39, '1137'),
	(243, 1, 0, -50942, 1139, 0, 0, 39, '1138'),
	(243, 1, 0, -50942, 1140, 0, 0, 39, '1139'),
	(243, 1, 0, -50942, 1141, 0, 0, 39, '1140'),
	(243, 1, 0, -50942, 1142, 0, 0, 39, '1141'),
	(243, 1, 0, -50942, 1143, 0, 0, 39, '1142'),
	(243, 1, 0, -50942, 1144, 0, 0, 39, '1143'),
	(243, 1, 0, -50942, 1145, 0, 0, 39, '1144'),
	(243, 1, 0, -50942, 1146, 0, 0, 39, '1145'),
	(243, 1, 0, -50942, 1147, 0, 0, 39, '1146'),
	(243, 1, 0, -50942, 1148, 0, 0, 39, '1147'),
	(243, 1, 0, -50942, 1149, 0, 0, 39, '1148'),
	(243, 1, 0, -50942, 1150, 0, 0, 39, '1149'),
	(243, 1, 0, -50942, 1151, 0, 0, 39, '1150'),
	(243, 1, 0, -50942, 1152, 0, 0, 39, '1151'),
	(243, 1, 0, -50942, 1153, 0, 0, 39, '1152'),
	(243, 1, 0, -50942, 1154, 0, 0, 39, '1153'),
	(243, 1, 0, -50942, 1155, 0, 0, 39, '1154'),
	(243, 1, 0, -50942, 1156, 0, 0, 39, '1155'),
	(243, 1, 0, -50942, 1157, 0, 0, 39, '1156'),
	(243, 1, 0, -50942, 1158, 0, 0, 39, '1157'),
	(243, 1, 0, -50942, 1159, 0, 0, 39, '1158'),
	(243, 1, 0, -50942, 1160, 0, 0, 39, '1159'),
	(243, 1, 0, -50942, 1161, 0, 0, 39, '1160'),
	(243, 1, 0, -50942, 1162, 0, 0, 39, '1161'),
	(243, 1, 0, -50942, 1163, 0, 0, 39, '1162'),
	(243, 1, 0, -50942, 1164, 0, 0, 39, '1163'),
	(243, 1, 0, -50942, 1165, 0, 0, 39, '1164'),
	(243, 1, 0, -50942, 1166, 0, 0, 39, '1165'),
	(243, 1, 0, -50942, 1167, 0, 0, 39, '1166'),
	(243, 1, 0, -50942, 1168, 0, 0, 39, '1167'),
	(243, 1, 0, -50942, 1169, 0, 0, 39, '1168'),
	(243, 1, 0, -50942, 1170, 0, 0, 39, '1169'),
	(243, 1, 0, -50942, 1171, 0, 0, 39, '1170'),
	(243, 1, 0, -50942, 1172, 0, 0, 39, '1171'),
	(243, 1, 0, -50942, 1173, 0, 0, 39, '1172'),
	(243, 1, 0, -50942, 1174, 0, 0, 39, '1173'),
	(243, 1, 0, -50942, 1175, 0, 0, 39, '1174'),
	(243, 1, 0, -50942, 1176, 0, 0, 39, '1175'),
	(243, 1, 0, -50942, 1177, 0, 0, 39, '1176'),
	(243, 1, 0, -50942, 1178, 0, 0, 39, '1177'),
	(243, 1, 0, -50942, 1179, 0, 0, 39, '1178'),
	(243, 1, 0, -50942, 1180, 0, 0, 39, '1179'),
	(243, 1, 0, -50942, 1181, 0, 0, 39, '1180'),
	(243, 1, 0, -50942, 1182, 0, 0, 39, '1181'),
	(243, 1, 0, -50942, 1183, 0, 0, 39, '1182'),
	(243, 1, 0, -50942, 1184, 0, 0, 39, '1183'),
	(243, 1, 0, -50942, 1185, 0, 0, 39, '1184'),
	(243, 1, 0, -50942, 1186, 0, 0, 39, '1185'),
	(243, 1, 0, -50942, 1187, 0, 0, 39, '1186'),
	(243, 1, 0, -50942, 1188, 0, 0, 39, '1187'),
	(243, 1, 0, -50942, 1189, 0, 0, 39, '1188'),
	(243, 1, 0, -50942, 1190, 0, 0, 39, '1189'),
	(243, 1, 0, -50942, 1191, 0, 0, 39, '1190'),
	(243, 1, 0, -50942, 1192, 0, 0, 39, '1191'),
	(243, 1, 0, -50942, 1193, 0, 0, 39, '1192'),
	(243, 1, 0, -50942, 1194, 0, 0, 39, '1193'),
	(243, 1, 0, -50942, 1195, 0, 0, 39, '1194'),
	(243, 1, 0, -50942, 1196, 0, 0, 39, '1195'),
	(243, 1, 0, -50942, 1197, 0, 0, 39, '1196'),
	(243, 1, 0, -50942, 1198, 0, 0, 39, '1197'),
	(243, 1, 0, -50942, 1199, 0, 0, 39, '1198'),
	(243, 1, 0, -50942, 1200, 0, 0, 39, '1199'),
	(243, 1, 0, -50942, 1201, 0, 0, 39, '1200'),
	(243, 1, 0, -50942, 1202, 0, 0, 39, '1201'),
	(243, 1, 0, -50942, 1203, 0, 0, 39, '1202'),
	(243, 1, 0, -50942, 1204, 0, 0, 39, '1203'),
	(243, 1, 0, -50942, 1205, 0, 0, 39, '1204'),
	(243, 1, 0, -50942, 1206, 0, 0, 39, '1205'),
	(243, 1, 0, -50942, 1207, 0, 0, 39, '1206'),
	(243, 1, 0, -50942, 1208, 0, 0, 39, '1207'),
	(243, 1, 0, -50942, 1209, 0, 0, 39, '1208'),
	(243, 1, 0, -50942, 1210, 0, 0, 39, '1209'),
	(243, 1, 0, -50942, 1211, 0, 0, 39, '1210'),
	(243, 1, 0, -50942, 1212, 0, 0, 39, '1211'),
	(243, 1, 0, -50942, 1213, 0, 0, 39, '1212'),
	(243, 1, 0, -50942, 1214, 0, 0, 39, '1213'),
	(243, 1, 0, -50942, 1215, 0, 0, 39, '1214'),
	(243, 1, 0, -50942, 1216, 0, 0, 39, '1215'),
	(243, 1, 0, -50942, 1217, 0, 0, 39, '1216'),
	(243, 1, 0, -50942, 1218, 0, 0, 39, '1217'),
	(243, 1, 0, -50942, 1219, 0, 0, 39, '1218'),
	(243, 1, 0, -50942, 1220, 0, 0, 39, '1219'),
	(243, 1, 0, -50942, 1221, 0, 0, 39, '1220'),
	(243, 1, 0, -50942, 1222, 0, 0, 39, '1221'),
	(243, 1, 0, -50942, 1223, 0, 0, 39, '1222'),
	(243, 1, 0, -50942, 1224, 0, 0, 39, '1223'),
	(243, 1, 0, -50942, 1225, 0, 0, 39, '1224'),
	(243, 1, 0, -50942, 1226, 0, 0, 39, '1225'),
	(243, 1, 0, -50942, 1227, 0, 0, 39, '1226'),
	(243, 1, 0, -50942, 1228, 0, 0, 39, '1227'),
	(243, 1, 0, -50942, 1229, 0, 0, 39, '1228'),
	(243, 1, 0, -50942, 1230, 0, 0, 39, '1229'),
	(243, 1, 0, -50942, 1231, 0, 0, 39, '1230'),
	(243, 1, 0, -50942, 1232, 0, 0, 39, '1231'),
	(243, 1, 0, -50942, 1233, 0, 0, 39, '1232'),
	(243, 1, 0, -50942, 1234, 0, 0, 39, '1233'),
	(243, 1, 0, -50942, 1235, 0, 0, 39, '1234'),
	(243, 1, 0, -50942, 1236, 0, 0, 39, '1235'),
	(243, 1, 0, -50942, 1237, 0, 0, 39, '1236'),
	(243, 1, 0, -50942, 1238, 0, 0, 39, '1237'),
	(243, 1, 0, -50942, 1239, 0, 0, 39, '1238'),
	(243, 1, 0, -50942, 1240, 0, 0, 39, '1239'),
	(243, 1, 0, -50942, 1241, 0, 0, 39, '1240'),
	(243, 1, 0, -50942, 1242, 0, 0, 39, '1241'),
	(243, 1, 0, -50942, 1243, 0, 0, 39, '1242'),
	(243, 1, 0, -50942, 1244, 0, 0, 39, '1243'),
	(243, 1, 0, -50942, 1245, 0, 0, 39, '1244'),
	(243, 1, 0, -50942, 1246, 0, 0, 39, '1245'),
	(243, 1, 0, -50942, 1247, 0, 0, 39, '1246'),
	(243, 1, 0, -50942, 1248, 0, 0, 39, '1247'),
	(243, 1, 0, -50942, 1249, 0, 0, 39, '1248'),
	(243, 1, 0, -50942, 1250, 0, 0, 39, '1249'),
	(243, 1, 0, -50942, 1251, 0, 0, 39, '1250'),
	(243, 1, 0, -50942, 1252, 0, 0, 39, '1251'),
	(243, 1, 0, -50942, 1253, 0, 0, 39, '1252'),
	(243, 1, 0, -50942, 1254, 0, 0, 39, '1253'),
	(243, 1, 0, -50942, 1255, 0, 0, 39, '1254'),
	(243, 1, 0, -50942, 1256, 0, 0, 39, '1255'),
	(243, 1, 0, -50942, 1257, 0, 0, 39, '1256'),
	(243, 1, 0, -50942, 1258, 0, 0, 39, '1257'),
	(243, 1, 0, -50942, 1259, 0, 0, 39, '1258'),
	(243, 1, 0, -50942, 1260, 0, 0, 39, '1259'),
	(243, 1, 0, -50942, 1261, 0, 0, 39, '1260'),
	(243, 1, 0, -50942, 1262, 0, 0, 39, '1261'),
	(243, 1, 0, -50942, 1263, 0, 0, 39, '1262'),
	(243, 1, 0, -50942, 1264, 0, 0, 39, '1263'),
	(243, 1, 0, -50942, 1265, 0, 0, 39, '1264'),
	(243, 1, 0, -50942, 1266, 0, 0, 39, '1265'),
	(243, 1, 0, -50942, 1267, 0, 0, 39, '1266'),
	(243, 1, 0, -50942, 1268, 0, 0, 39, '1267'),
	(243, 1, 0, -50942, 1269, 0, 0, 39, '1268'),
	(243, 1, 0, -50942, 1270, 0, 0, 39, '1269'),
	(243, 1, 0, -50942, 1271, 0, 0, 39, '1270'),
	(243, 1, 0, -50942, 1272, 0, 0, 39, '1271'),
	(243, 1, 0, -50942, 1273, 0, 0, 39, '1272'),
	(243, 1, 0, -50942, 1274, 0, 0, 39, '1273'),
	(243, 1, 0, -50942, 1275, 0, 0, 39, '1274'),
	(243, 1, 0, -50942, 1276, 0, 0, 39, '1275'),
	(243, 1, 0, -50942, 1277, 0, 0, 39, '1276'),
	(243, 1, 0, -50942, 1278, 0, 0, 39, '1277'),
	(243, 1, 0, -50942, 1279, 0, 0, 39, '1278'),
	(243, 1, 0, -50942, 1280, 0, 0, 39, '1279'),
	(243, 1, 0, -50942, 1281, 0, 0, 39, '1280'),
	(243, 1, 0, -50942, 1282, 0, 0, 39, '1281'),
	(243, 1, 0, -50942, 1283, 0, 0, 39, '1282'),
	(243, 1, 0, -50942, 1284, 0, 0, 39, '1283'),
	(243, 1, 0, -50942, 1285, 0, 0, 39, '1284'),
	(243, 1, 0, -50942, 1286, 0, 0, 39, '1285'),
	(243, 1, 0, -50942, 1287, 0, 0, 39, '1286'),
	(243, 1, 0, -50942, 1288, 0, 0, 39, '1287'),
	(243, 1, 0, -50942, 1289, 0, 0, 39, '1288'),
	(243, 1, 0, -50942, 1290, 0, 0, 39, '1289'),
	(243, 1, 0, -50942, 1291, 0, 0, 39, '1290'),
	(243, 1, 0, -50942, 1292, 0, 0, 39, '1291'),
	(243, 1, 0, -50942, 1293, 0, 0, 39, '1292'),
	(243, 1, 0, -50942, 1294, 0, 0, 39, '1293'),
	(243, 1, 0, -50942, 1295, 0, 0, 39, '1294'),
	(243, 1, 0, -50942, 1296, 0, 0, 39, '1295'),
	(243, 1, 0, -50942, 1297, 0, 0, 39, '1296'),
	(243, 1, 0, -50942, 1298, 0, 0, 39, '1297'),
	(243, 1, 0, -50942, 1299, 0, 0, 39, '1298'),
	(243, 1, 0, -50942, 1300, 0, 0, 39, '1299'),
	(243, 1, 0, -50942, 1301, 0, 0, 39, '1300'),
	(243, 1, 0, -50942, 1302, 0, 0, 39, '1301'),
	(243, 1, 0, -50942, 1303, 0, 0, 39, '1302'),
	(243, 1, 0, -50942, 1304, 0, 0, 39, '1303'),
	(243, 1, 0, -50942, 1305, 0, 0, 39, '1304'),
	(243, 1, 0, -50942, 1306, 0, 0, 39, '1305'),
	(243, 1, 0, -50942, 1307, 0, 0, 39, '1306'),
	(243, 1, 0, -50942, 1308, 0, 0, 39, '1307'),
	(243, 1, 0, -50942, 1309, 0, 0, 39, '1308'),
	(243, 1, 0, -50942, 1310, 0, 0, 39, '1309'),
	(243, 1, 0, -50942, 1311, 0, 0, 39, '1310'),
	(243, 1, 0, -50942, 1312, 0, 0, 39, '1311'),
	(243, 1, 0, -50942, 1313, 0, 0, 39, '1312'),
	(243, 1, 0, -50942, 1314, 0, 0, 39, '1313'),
	(243, 1, 0, -50942, 1315, 0, 0, 39, '1314'),
	(243, 1, 0, -50942, 1316, 0, 0, 39, '1315'),
	(243, 1, 0, -50942, 1317, 0, 0, 39, '1316'),
	(243, 1, 0, -50942, 1318, 0, 0, 39, '1317'),
	(243, 1, 0, -50942, 1319, 0, 0, 39, '1318'),
	(243, 1, 0, -50942, 1320, 0, 0, 39, '1319'),
	(243, 1, 0, -50942, 1321, 0, 0, 39, '1320'),
	(243, 1, 0, -50942, 1322, 0, 0, 39, '1321'),
	(243, 1, 0, -50942, 1323, 0, 0, 39, '1322'),
	(243, 1, 0, -50942, 1324, 0, 0, 39, '1323'),
	(243, 1, 0, -50942, 1325, 0, 0, 39, '1324'),
	(243, 1, 0, -50942, 1326, 0, 0, 39, '1325'),
	(243, 1, 0, -50942, 1327, 0, 0, 39, '1326'),
	(243, 1, 0, -50942, 1328, 0, 0, 39, '1327'),
	(243, 1, 0, -50942, 1329, 0, 0, 39, '1328'),
	(243, 1, 0, -50942, 1330, 0, 0, 39, '1329'),
	(243, 1, 0, -50942, 1331, 0, 0, 39, '1330'),
	(243, 1, 0, -50942, 1332, 0, 0, 39, '1331'),
	(243, 1, 0, -50942, 1333, 0, 0, 39, '1332'),
	(243, 1, 0, -50942, 1334, 0, 0, 39, '1333'),
	(243, 1, 0, -50942, 1335, 0, 0, 39, '1334'),
	(243, 1, 0, -50942, 1336, 0, 0, 39, '1335'),
	(243, 1, 0, -50942, 1337, 0, 0, 39, '1336'),
	(243, 1, 0, -50942, 1338, 0, 0, 39, '1337'),
	(243, 1, 0, -50942, 1339, 0, 0, 39, '1338'),
	(243, 1, 0, -50942, 1340, 0, 0, 39, '1339'),
	(243, 1, 0, -50942, 1341, 0, 0, 39, '1340'),
	(243, 1, 0, -50942, 1342, 0, 0, 39, '1341'),
	(243, 1, 0, -50942, 1343, 0, 0, 39, '1342'),
	(243, 1, 0, -50942, 1344, 0, 0, 39, '1343'),
	(243, 1, 0, -50942, 1345, 0, 0, 39, '1344'),
	(243, 1, 0, -50942, 1346, 0, 0, 39, '1345'),
	(243, 1, 0, -50942, 1347, 0, 0, 39, '1346'),
	(243, 1, 0, -50942, 1348, 0, 0, 39, '1347'),
	(243, 1, 0, -50942, 1349, 0, 0, 39, '1348'),
	(243, 1, 0, -50942, 1350, 0, 0, 39, '1349'),
	(243, 1, 0, -50942, 1351, 0, 0, 39, '1350'),
	(243, 1, 0, -50942, 1352, 0, 0, 39, '1351'),
	(243, 1, 0, -50942, 1353, 0, 0, 39, '1352'),
	(243, 1, 0, -50942, 1354, 0, 0, 39, '1353'),
	(243, 1, 0, -50942, 1355, 0, 0, 39, '1354'),
	(243, 1, 0, -50942, 1356, 0, 0, 39, '1355'),
	(243, 1, 0, -50942, 1357, 0, 0, 39, '1356'),
	(243, 1, 0, -50942, 1358, 0, 0, 39, '1357'),
	(243, 1, 0, -50942, 1359, 0, 0, 39, '1358'),
	(243, 1, 0, -50942, 1360, 0, 0, 39, '1359'),
	(243, 1, 0, -50942, 1361, 0, 0, 39, '1360'),
	(243, 1, 0, -50942, 1362, 0, 0, 39, '1361'),
	(243, 1, 0, -50942, 1363, 0, 0, 39, '1362'),
	(243, 1, 0, -50942, 1364, 0, 0, 39, '1363'),
	(243, 1, 0, -50942, 1365, 0, 0, 39, '1364'),
	(243, 1, 0, -50942, 1366, 0, 0, 39, '1365'),
	(243, 1, 0, -50942, 1367, 0, 0, 39, '1366'),
	(243, 1, 0, -50942, 1368, 0, 0, 39, '1367'),
	(243, 1, 0, -50942, 1369, 0, 0, 39, '1368'),
	(243, 1, 0, -50942, 1370, 0, 0, 39, '1369'),
	(243, 1, 0, -50942, 1371, 0, 0, 39, '1370'),
	(243, 1, 0, -50942, 1372, 0, 0, 39, '1371'),
	(243, 1, 0, -50942, 1373, 0, 0, 39, '1372'),
	(243, 1, 0, -50942, 1374, 0, 0, 39, '1373'),
	(243, 1, 0, -50942, 1375, 0, 0, 39, '1374'),
	(243, 1, 0, -50942, 1376, 0, 0, 39, '1375'),
	(243, 1, 0, -50942, 1377, 0, 0, 39, '1376'),
	(243, 1, 0, -50942, 1378, 0, 0, 39, '1377'),
	(243, 1, 0, -50942, 1379, 0, 0, 39, '1378'),
	(243, 1, 0, -50942, 1380, 0, 0, 39, '1379'),
	(243, 1, 0, -50942, 1381, 0, 0, 39, '1380'),
	(243, 1, 0, -50942, 1382, 0, 0, 39, '1381'),
	(243, 1, 0, -50942, 1383, 0, 0, 39, '1382'),
	(243, 1, 0, -50942, 1384, 0, 0, 39, '1383'),
	(243, 1, 0, -50942, 1385, 0, 0, 39, '1384'),
	(243, 1, 0, -50942, 1386, 0, 0, 39, '1385'),
	(243, 1, 0, -50942, 1387, 0, 0, 39, '1386'),
	(243, 1, 0, -50942, 1388, 0, 0, 39, '1387'),
	(243, 1, 0, -50942, 1389, 0, 0, 39, '1388'),
	(243, 1, 0, -50942, 1390, 0, 0, 39, '1389'),
	(243, 1, 0, -50942, 1391, 0, 0, 39, '1390'),
	(243, 1, 0, -50942, 1392, 0, 0, 39, '1391'),
	(243, 1, 0, -50942, 1393, 0, 0, 39, '1392'),
	(243, 1, 0, -50942, 1394, 0, 0, 39, '1393'),
	(243, 1, 0, -50942, 1395, 0, 0, 39, '1394'),
	(243, 1, 0, -50942, 1396, 0, 0, 39, '1395'),
	(243, 1, 0, -50942, 1397, 0, 0, 39, '1396'),
	(243, 1, 0, -50942, 1398, 0, 0, 39, '1397'),
	(243, 1, 0, -50942, 1399, 0, 0, 39, '1398'),
	(243, 1, 0, -50942, 1400, 0, 0, 39, '1399'),
	(243, 1, 0, -50942, 1401, 0, 0, 39, '1400'),
	(243, 1, 0, -50942, 1402, 0, 0, 39, '1401'),
	(243, 1, 0, -50942, 1403, 0, 0, 39, '1402'),
	(243, 1, 0, -50942, 1404, 0, 0, 39, '1403'),
	(243, 1, 0, -50942, 1405, 0, 0, 39, '1404'),
	(243, 1, 0, -50942, 1406, 0, 0, 39, '1405'),
	(243, 1, 0, -50942, 1407, 0, 0, 39, '1406'),
	(243, 1, 0, -50942, 1408, 0, 0, 39, '1407'),
	(243, 1, 0, -50942, 1409, 0, 0, 39, '1408'),
	(243, 1, 0, -50942, 1410, 0, 0, 39, '1409'),
	(243, 1, 0, -50942, 1411, 0, 0, 39, '1410'),
	(243, 1, 0, -50942, 1412, 0, 0, 39, '1411'),
	(243, 1, 0, -50942, 1413, 0, 0, 39, '1412'),
	(243, 1, 0, -50942, 1414, 0, 0, 39, '1413'),
	(243, 1, 0, -50942, 1415, 0, 0, 39, '1414'),
	(243, 1, 0, -50942, 1416, 0, 0, 39, '1415'),
	(243, 1, 0, -50942, 1417, 0, 0, 39, '1416'),
	(243, 1, 0, -50942, 1418, 0, 0, 39, '1417'),
	(243, 1, 0, -50942, 1419, 0, 0, 39, '1418'),
	(243, 1, 0, -50942, 1420, 0, 0, 39, '1419'),
	(243, 1, 0, -50942, 1421, 0, 0, 39, '1420'),
	(243, 1, 0, -50942, 1422, 0, 0, 39, '1421'),
	(243, 1, 0, -50942, 1423, 0, 0, 39, '1422'),
	(243, 1, 0, -50942, 1424, 0, 0, 39, '1423'),
	(243, 1, 0, -50942, 1425, 0, 0, 39, '1424'),
	(243, 1, 0, -50942, 1426, 0, 0, 39, '1425'),
	(243, 1, 0, -50942, 1427, 0, 0, 39, '1426'),
	(243, 1, 0, -50942, 1428, 0, 0, 39, '1427'),
	(243, 1, 0, -50942, 1429, 0, 0, 39, '1428'),
	(243, 1, 0, -50942, 1430, 0, 0, 39, '1429'),
	(243, 1, 0, -50942, 1431, 0, 0, 39, '1430'),
	(243, 1, 0, -50942, 1432, 0, 0, 39, '1431'),
	(243, 1, 0, -50942, 1433, 0, 0, 39, '1432'),
	(243, 1, 0, -50942, 1434, 0, 0, 39, '1433'),
	(243, 1, 0, -50942, 1435, 0, 0, 39, '1434'),
	(243, 1, 0, -50942, 1436, 0, 0, 39, '1435'),
	(243, 1, 0, -50942, 1437, 0, 0, 39, '1436'),
	(243, 1, 0, -50942, 1438, 0, 0, 39, '1437'),
	(243, 1, 0, -50942, 1439, 0, 0, 39, '1438'),
	(243, 1, 0, -50942, 1440, 0, 0, 39, '1439'),
	(243, 1, 0, -50942, 1441, 0, 0, 39, '1440'),
	(243, 1, 0, -50942, 1442, 0, 0, 39, '1441'),
	(243, 1, 0, -50942, 1443, 0, 0, 39, '1442'),
	(243, 1, 0, -50942, 1444, 0, 0, 39, '1443'),
	(243, 1, 0, -50942, 1445, 0, 0, 39, '1444'),
	(243, 1, 0, -50942, 1446, 0, 0, 39, '1445'),
	(243, 1, 0, -50942, 1447, 0, 0, 39, '1446'),
	(243, 1, 0, -50942, 1448, 0, 0, 39, '1447'),
	(243, 1, 0, -50942, 1449, 0, 0, 39, '1448'),
	(243, 1, 0, -50942, 1450, 0, 0, 39, '1449'),
	(243, 1, 0, -50942, 1451, 0, 0, 39, '1450'),
	(243, 1, 0, -50942, 1452, 0, 0, 39, '1451'),
	(243, 1, 0, -50942, 1453, 0, 0, 39, '1452'),
	(243, 1, 0, -50942, 1454, 0, 0, 39, '1453'),
	(243, 1, 0, -50942, 1455, 0, 0, 39, '1454'),
	(243, 1, 0, -50942, 1456, 0, 0, 39, '1455'),
	(243, 1, 0, -50942, 1457, 0, 0, 39, '1456'),
	(243, 1, 0, -50942, 1458, 0, 0, 39, '1457'),
	(243, 1, 0, -50942, 1459, 0, 0, 39, '1458'),
	(243, 1, 0, -50942, 1460, 0, 0, 39, '1459'),
	(243, 1, 0, -50942, 1461, 0, 0, 39, '1460'),
	(243, 1, 0, -50942, 1462, 0, 0, 39, '1461'),
	(243, 1, 0, -50942, 1463, 0, 0, 39, '1462'),
	(243, 1, 0, -50942, 1464, 0, 0, 39, '1463'),
	(243, 1, 0, -50942, 1465, 0, 0, 39, '1464'),
	(243, 1, 0, -50942, 1466, 0, 0, 39, '1465'),
	(243, 1, 0, -50942, 1467, 0, 0, 39, '1466'),
	(243, 1, 0, -50942, 1468, 0, 0, 39, '1467'),
	(243, 1, 0, -50942, 1469, 0, 0, 39, '1468'),
	(243, 1, 0, -50942, 1470, 0, 0, 39, '1469'),
	(243, 1, 0, -50942, 1471, 0, 0, 39, '1470'),
	(243, 1, 0, -50942, 1472, 0, 0, 39, '1471'),
	(243, 1, 0, -50942, 1473, 0, 0, 39, '1472'),
	(243, 1, 0, -50942, 1474, 0, 0, 39, '1473'),
	(243, 1, 0, -50942, 1475, 0, 0, 39, '1474'),
	(243, 1, 0, -50942, 1476, 0, 0, 39, '1475'),
	(243, 1, 0, -50942, 1477, 0, 0, 39, '1476'),
	(243, 1, 0, -50942, 1478, 0, 0, 39, '1477'),
	(243, 1, 0, -50942, 1479, 0, 0, 39, '1478'),
	(243, 1, 0, -50942, 1480, 0, 0, 39, '1479'),
	(243, 1, 0, -50942, 1481, 0, 0, 39, '1480'),
	(243, 1, 0, -50942, 1482, 0, 0, 39, '1481'),
	(243, 1, 0, -50942, 1483, 0, 0, 39, '1482'),
	(243, 1, 0, -50942, 1484, 0, 0, 39, '1483'),
	(243, 1, 0, -50942, 1485, 0, 0, 39, '1484'),
	(243, 1, 0, -50942, 1486, 0, 0, 39, '1485'),
	(243, 1, 0, -50942, 1487, 0, 0, 39, '1486'),
	(243, 1, 0, -50942, 1488, 0, 0, 39, '1487'),
	(243, 1, 0, -50942, 1489, 0, 0, 39, '1488'),
	(243, 1, 0, -50942, 1490, 0, 0, 39, '1489'),
	(243, 1, 0, -50942, 1491, 0, 0, 39, '1490'),
	(243, 1, 0, -50942, 1492, 0, 0, 39, '1491'),
	(243, 1, 0, -50942, 1493, 0, 0, 39, '1492'),
	(243, 1, 0, -50942, 1494, 0, 0, 39, '1493'),
	(243, 1, 0, -50942, 1495, 0, 0, 39, '1494'),
	(243, 1, 0, -50942, 1496, 0, 0, 39, '1495'),
	(243, 1, 0, -50942, 1497, 0, 0, 39, '1496'),
	(243, 1, 0, -50942, 1498, 0, 0, 39, '1497'),
	(243, 1, 0, -50942, 1499, 0, 0, 39, '1498'),
	(243, 1, 0, -50942, 1500, 0, 0, 39, '1499'),
	(243, 1, 0, -50942, 1501, 0, 0, 39, '1500'),
	(243, 1, 0, -50942, 1502, 0, 0, 39, '1501'),
	(243, 1, 0, -50942, 1503, 0, 0, 39, '1502'),
	(243, 1, 0, -50942, 1504, 0, 0, 39, '1503'),
	(243, 1, 0, -50942, 1505, 0, 0, 39, '1504'),
	(243, 1, 0, -50942, 1506, 0, 0, 39, '1505'),
	(243, 1, 0, -50942, 1507, 0, 0, 39, '1506'),
	(243, 1, 0, -50942, 1508, 0, 0, 39, '1507'),
	(243, 1, 0, -50942, 1509, 0, 0, 39, '1508'),
	(243, 1, 0, -50942, 1510, 0, 0, 39, '1509'),
	(243, 1, 0, -50942, 1511, 0, 0, 39, '1510'),
	(243, 1, 0, -50942, 1512, 0, 0, 39, '1511'),
	(243, 1, 0, -50942, 1513, 0, 0, 39, '1512'),
	(243, 1, 0, -50942, 1514, 0, 0, 39, '1513'),
	(243, 1, 0, -50942, 1515, 0, 0, 39, '1514'),
	(243, 1, 0, -50942, 1516, 0, 0, 39, '1515'),
	(243, 1, 0, -50942, 1517, 0, 0, 39, '1516'),
	(243, 1, 0, -50942, 1518, 0, 0, 39, '1517'),
	(243, 1, 0, -50942, 1519, 0, 0, 39, '1518'),
	(243, 1, 0, -50942, 1520, 0, 0, 39, '1519'),
	(243, 1, 0, -50942, 1521, 0, 0, 39, '1520'),
	(243, 1, 0, -50942, 1522, 0, 0, 39, '1521'),
	(243, 1, 0, -50942, 1523, 0, 0, 39, '1522'),
	(243, 1, 0, -50942, 1524, 0, 0, 39, '1523'),
	(243, 1, 0, -50942, 1525, 0, 0, 39, '1524'),
	(243, 1, 0, -50942, 1526, 0, 0, 39, '1525'),
	(243, 1, 0, -50942, 1527, 0, 0, 39, '1526'),
	(243, 1, 0, -50942, 1528, 0, 0, 39, '1527'),
	(243, 1, 0, -50942, 1529, 0, 0, 39, '1528'),
	(243, 1, 0, -50942, 1530, 0, 0, 39, '1529'),
	(243, 1, 0, -50942, 1531, 0, 0, 39, '1530'),
	(243, 1, 0, -50942, 1532, 0, 0, 39, '1531'),
	(243, 1, 0, -50942, 1533, 0, 0, 39, '1532'),
	(243, 1, 0, -50942, 1534, 0, 0, 39, '1533'),
	(243, 1, 0, -50942, 1535, 0, 0, 39, '1534'),
	(243, 1, 0, -50942, 1536, 0, 0, 39, '1535'),
	(243, 1, 0, -50942, 1537, 0, 0, 39, '1536'),
	(243, 1, 0, -50942, 1538, 0, 0, 39, '1537'),
	(243, 1, 0, -50942, 1539, 0, 0, 39, '1538'),
	(243, 1, 0, -50942, 1540, 0, 0, 39, '1539'),
	(243, 1, 0, -50942, 1541, 0, 0, 39, '1540'),
	(243, 1, 0, -50942, 1542, 0, 0, 39, '1541'),
	(243, 1, 0, -50942, 1543, 0, 0, 39, '1542'),
	(243, 1, 0, -50942, 1544, 0, 0, 39, '1543'),
	(243, 1, 0, -50942, 1545, 0, 0, 39, '1544'),
	(243, 1, 0, -50942, 1546, 0, 0, 39, '1545'),
	(243, 1, 0, -50942, 1547, 0, 0, 39, '1546'),
	(243, 1, 0, -50942, 1548, 0, 0, 39, '1547'),
	(243, 1, 0, -50942, 1549, 0, 0, 39, '1548'),
	(243, 1, 0, -50942, 1550, 0, 0, 39, '1549'),
	(243, 1, 0, -50942, 1551, 0, 0, 39, '1550'),
	(243, 1, 0, -50942, 1552, 0, 0, 39, '1551'),
	(243, 1, 0, -50942, 1553, 0, 0, 39, '1552'),
	(243, 1, 0, -50942, 1554, 0, 0, 39, '1553'),
	(243, 1, 0, -50942, 1555, 0, 0, 39, '1554'),
	(243, 1, 0, -50942, 1556, 0, 0, 39, '1555'),
	(243, 1, 0, -50942, 1557, 0, 0, 39, '1556'),
	(243, 1, 0, -50942, 1558, 0, 0, 39, '1557'),
	(243, 1, 0, -50942, 1559, 0, 0, 39, '1558'),
	(243, 1, 0, -50942, 1560, 0, 0, 39, '1559'),
	(243, 1, 0, -50942, 1561, 0, 0, 39, '1560'),
	(243, 1, 0, -50942, 1562, 0, 0, 39, '1561'),
	(243, 1, 0, -50942, 1563, 0, 0, 39, '1562'),
	(243, 1, 0, -50942, 1564, 0, 0, 39, '1563'),
	(243, 1, 0, -50942, 1565, 0, 0, 39, '1564'),
	(243, 1, 0, -50942, 1566, 0, 0, 39, '1565'),
	(243, 1, 0, -50942, 1567, 0, 0, 39, '1566'),
	(243, 1, 0, -50942, 1568, 0, 0, 39, '1567'),
	(243, 1, 0, -50942, 1569, 0, 0, 39, '1568'),
	(243, 1, 0, -50942, 1570, 0, 0, 39, '1569'),
	(243, 1, 0, -50942, 1571, 0, 0, 39, '1570'),
	(243, 1, 0, -50942, 1572, 0, 0, 39, '1571'),
	(243, 1, 0, -50942, 1573, 0, 0, 39, '1572'),
	(243, 1, 0, -50942, 1574, 0, 0, 39, '1573'),
	(243, 1, 0, -50942, 1575, 0, 0, 39, '1574'),
	(243, 1, 0, -50942, 1576, 0, 0, 39, '1575'),
	(243, 1, 0, -50942, 1577, 0, 0, 39, '1576'),
	(243, 1, 0, -50942, 1578, 0, 0, 39, '1577'),
	(243, 1, 0, -50942, 1579, 0, 0, 39, '1578'),
	(243, 1, 0, -50942, 1580, 0, 0, 39, '1579'),
	(243, 1, 0, -50942, 1581, 0, 0, 39, '1580'),
	(243, 1, 0, -50942, 1582, 0, 0, 39, '1581'),
	(243, 1, 0, -50942, 1583, 0, 0, 39, '1582'),
	(243, 1, 0, -50942, 1584, 0, 0, 39, '1583'),
	(243, 1, 0, -50942, 1585, 0, 0, 39, '1584'),
	(243, 1, 0, -50942, 1586, 0, 0, 39, '1585'),
	(243, 1, 0, -50942, 1587, 0, 0, 39, '1586'),
	(243, 1, 0, -50942, 1588, 0, 0, 39, '1587'),
	(243, 1, 0, -50942, 1589, 0, 0, 39, '1588'),
	(243, 1, 0, -50942, 1590, 0, 0, 39, '1589'),
	(243, 1, 0, -50942, 1591, 0, 0, 39, '1590'),
	(243, 1, 0, -50942, 1592, 0, 0, 39, '1591'),
	(243, 1, 0, -50942, 1593, 0, 0, 39, '1592'),
	(243, 1, 0, -50942, 1594, 0, 0, 39, '1593'),
	(243, 1, 0, -50942, 1595, 0, 0, 39, '1594'),
	(243, 1, 0, -50942, 1596, 0, 0, 39, '1595'),
	(243, 1, 0, -50942, 1597, 0, 0, 39, '1596'),
	(243, 1, 0, -50942, 1598, 0, 0, 39, '1597'),
	(243, 1, 0, -50942, 1599, 0, 0, 39, '1598'),
	(243, 1, 0, -50942, 1600, 0, 0, 39, '1599'),
	(243, 1, 0, -50942, 1601, 0, 0, 39, '1600'),
	(243, 1, 0, -50942, 1602, 0, 0, 39, '1601'),
	(243, 1, 0, -50942, 1603, 0, 0, 39, '1602'),
	(243, 1, 0, -50942, 1604, 0, 0, 39, '1603'),
	(243, 1, 0, -50942, 1605, 0, 0, 39, '1604'),
	(243, 1, 0, -50942, 1606, 0, 0, 39, '1605'),
	(243, 1, 0, -50942, 1607, 0, 0, 39, '1606'),
	(243, 1, 0, -50942, 1608, 0, 0, 39, '1607'),
	(243, 1, 0, -50942, 1609, 0, 0, 39, '1608'),
	(243, 1, 0, -50942, 1610, 0, 0, 39, '1609'),
	(243, 1, 0, -50942, 1611, 0, 0, 39, '1610'),
	(243, 1, 0, -50942, 1612, 0, 0, 39, '1611'),
	(243, 1, 0, -50942, 1613, 0, 0, 39, '1612'),
	(243, 1, 0, -50942, 1614, 0, 0, 39, '1613'),
	(243, 1, 0, -50942, 1615, 0, 0, 39, '1614'),
	(243, 1, 0, -50942, 1616, 0, 0, 39, '1615'),
	(243, 1, 0, -50942, 1617, 0, 0, 39, '1616'),
	(243, 1, 0, -50942, 1618, 0, 0, 39, '1617'),
	(243, 1, 0, -50942, 1619, 0, 0, 39, '1618'),
	(243, 1, 0, -50942, 1620, 0, 0, 39, '1619'),
	(243, 1, 0, -50942, 1621, 0, 0, 39, '1620'),
	(243, 1, 0, -50942, 1622, 0, 0, 39, '1621'),
	(243, 1, 0, -50942, 1623, 0, 0, 39, '1622'),
	(243, 1, 0, -50942, 1624, 0, 0, 39, '1623'),
	(243, 1, 0, -50942, 1625, 0, 0, 39, '1624'),
	(243, 1, 0, -50942, 1626, 0, 0, 39, '1625'),
	(243, 1, 0, -50942, 1627, 0, 0, 39, '1626'),
	(243, 1, 0, -50942, 1628, 0, 0, 39, '1627'),
	(243, 1, 0, -50942, 1629, 0, 0, 39, '1628'),
	(243, 1, 0, -50942, 1630, 0, 0, 39, '1629'),
	(243, 1, 0, -50942, 1631, 0, 0, 39, '1630'),
	(243, 1, 0, -50942, 1632, 0, 0, 39, '1631'),
	(243, 1, 0, -50942, 1633, 0, 0, 39, '1632'),
	(243, 1, 0, -50942, 1634, 0, 0, 39, '1633'),
	(243, 1, 0, -50942, 1635, 0, 0, 39, '1634'),
	(243, 1, 0, -50942, 1636, 0, 0, 39, '1635'),
	(243, 1, 0, -50942, 1637, 0, 0, 39, '1636'),
	(243, 1, 0, -50942, 1638, 0, 0, 39, '1637'),
	(243, 1, 0, -50942, 1639, 0, 0, 39, '1638'),
	(243, 1, 0, -50942, 1640, 0, 0, 39, '1639'),
	(243, 1, 0, -50942, 1641, 0, 0, 39, '1640'),
	(243, 1, 0, -50942, 1642, 0, 0, 39, '1641'),
	(243, 1, 0, -50942, 1643, 0, 0, 39, '1642'),
	(243, 1, 0, -50942, 1644, 0, 0, 39, '1643'),
	(243, 1, 0, -50942, 1645, 0, 0, 39, '1644'),
	(243, 1, 0, -50942, 1646, 0, 0, 39, '1645'),
	(243, 1, 0, -50942, 1647, 0, 0, 39, '1646'),
	(243, 1, 0, -50942, 1648, 0, 0, 39, '1647'),
	(243, 1, 0, -50942, 1649, 0, 0, 39, '1648'),
	(243, 1, 0, -50942, 1650, 0, 0, 39, '1649'),
	(243, 1, 0, -50942, 1651, 0, 0, 39, '1650'),
	(243, 1, 0, -50942, 1652, 0, 0, 39, '1651'),
	(243, 1, 0, -50942, 1653, 0, 0, 39, '1652'),
	(243, 1, 0, -50942, 1654, 0, 0, 39, '1653'),
	(243, 1, 0, -50942, 1655, 0, 0, 39, '1654'),
	(243, 1, 0, -50942, 1656, 0, 0, 39, '1655'),
	(243, 1, 0, -50942, 1657, 0, 0, 39, '1656'),
	(243, 1, 0, -50942, 1658, 0, 0, 39, '1657'),
	(243, 1, 0, -50942, 1659, 0, 0, 39, '1658'),
	(243, 1, 0, -50942, 1660, 0, 0, 39, '1659'),
	(243, 1, 0, -50942, 1661, 0, 0, 39, '1660'),
	(243, 1, 0, -50942, 1662, 0, 0, 39, '1661'),
	(243, 1, 0, -50942, 1663, 0, 0, 39, '1662'),
	(243, 1, 0, -50942, 1664, 0, 0, 39, '1663'),
	(243, 1, 0, -50942, 1665, 0, 0, 39, '1664'),
	(243, 1, 0, -50942, 1666, 0, 0, 39, '1665'),
	(243, 1, 0, -50942, 1667, 0, 0, 39, '1666'),
	(243, 1, 0, -50942, 1668, 0, 0, 39, '1667'),
	(243, 1, 0, -50942, 1669, 0, 0, 39, '1668'),
	(243, 1, 0, -50942, 1670, 0, 0, 39, '1669'),
	(243, 1, 0, -50942, 1671, 0, 0, 39, '1670'),
	(243, 1, 0, -50942, 1672, 0, 0, 39, '1671'),
	(243, 1, 0, -50942, 1673, 0, 0, 39, '1672'),
	(243, 1, 0, -50942, 1674, 0, 0, 39, '1673'),
	(243, 1, 0, -50942, 1675, 0, 0, 39, '1674'),
	(243, 1, 0, -50942, 1676, 0, 0, 39, '1675'),
	(243, 1, 0, -50942, 1677, 0, 0, 39, '1676'),
	(243, 1, 0, -50942, 1678, 0, 0, 39, '1677'),
	(243, 1, 0, -50942, 1679, 0, 0, 39, '1678'),
	(243, 1, 0, -50942, 1680, 0, 0, 39, '1679'),
	(243, 1, 0, -50942, 1681, 0, 0, 39, '1680'),
	(243, 1, 0, -50942, 1682, 0, 0, 39, '1681'),
	(243, 1, 0, -50942, 1683, 0, 0, 39, '1682'),
	(243, 1, 0, -50942, 1684, 0, 0, 39, '1683'),
	(243, 1, 0, -50942, 1685, 0, 0, 39, '1684'),
	(243, 1, 0, -50942, 1686, 0, 0, 39, '1685'),
	(243, 1, 0, -50942, 1687, 0, 0, 39, '1686'),
	(243, 1, 0, -50942, 1688, 0, 0, 39, '1687'),
	(243, 1, 0, -50942, 1689, 0, 0, 39, '1688'),
	(243, 1, 0, -50942, 1690, 0, 0, 39, '1689'),
	(243, 1, 0, -50942, 1691, 0, 0, 39, '1690'),
	(243, 1, 0, -50942, 1692, 0, 0, 39, '1691'),
	(243, 1, 0, -50942, 1693, 0, 0, 39, '1692'),
	(243, 1, 0, -50942, 1694, 0, 0, 39, '1693'),
	(243, 1, 0, -50942, 1695, 0, 0, 39, '1694'),
	(243, 1, 0, -50942, 1696, 0, 0, 39, '1695'),
	(243, 1, 0, -50942, 1697, 0, 0, 39, '1696'),
	(243, 1, 0, -50942, 1698, 0, 0, 39, '1697'),
	(243, 1, 0, -50942, 1699, 0, 0, 39, '1698'),
	(243, 1, 0, -50942, 1700, 0, 0, 39, '1699'),
	(243, 1, 0, -50942, 1701, 0, 0, 39, '1700'),
	(243, 1, 0, -50942, 1702, 0, 0, 39, '1701'),
	(243, 1, 0, -50942, 1703, 0, 0, 39, '1702'),
	(243, 1, 0, -50942, 1704, 0, 0, 39, '1703'),
	(243, 1, 0, -50942, 1705, 0, 0, 39, '1704'),
	(243, 1, 0, -50942, 1706, 0, 0, 39, '1705'),
	(243, 1, 0, -50942, 1707, 0, 0, 39, '1706'),
	(243, 1, 0, -50942, 1708, 0, 0, 39, '1707'),
	(243, 1, 0, -50942, 1709, 0, 0, 39, '1708'),
	(243, 1, 0, -50942, 1710, 0, 0, 39, '1709'),
	(243, 1, 0, -50942, 1711, 0, 0, 39, '1710'),
	(243, 1, 0, -50942, 1712, 0, 0, 39, '1711'),
	(243, 1, 0, -50942, 1713, 0, 0, 39, '1712'),
	(243, 1, 0, -50942, 1714, 0, 0, 39, '1713'),
	(243, 1, 0, -50942, 1715, 0, 0, 39, '1714'),
	(243, 1, 0, -50942, 1716, 0, 0, 39, '1715'),
	(243, 1, 0, -50942, 1717, 0, 0, 39, '1716'),
	(243, 1, 0, -50942, 1718, 0, 0, 39, '1717'),
	(243, 1, 0, -50942, 1719, 0, 0, 39, '1718'),
	(243, 1, 0, -50942, 1720, 0, 0, 39, '1719'),
	(243, 1, 0, -50942, 1721, 0, 0, 39, '1720'),
	(243, 1, 0, -50942, 1722, 0, 0, 39, '1721'),
	(243, 1, 0, -50942, 1723, 0, 0, 39, '1722'),
	(243, 1, 0, -50942, 1724, 0, 0, 39, '1723'),
	(243, 1, 0, -50942, 1725, 0, 0, 39, '1724'),
	(243, 1, 0, -50942, 1726, 0, 0, 39, '1725'),
	(243, 1, 0, -50942, 1727, 0, 0, 39, '1726'),
	(243, 1, 0, -50942, 1728, 0, 0, 39, '1727'),
	(243, 1, 0, -50942, 1729, 0, 0, 39, '1728'),
	(243, 1, 0, -50942, 1730, 0, 0, 39, '1729'),
	(243, 1, 0, -50942, 1731, 0, 0, 39, '1730'),
	(243, 1, 0, -50942, 1732, 0, 0, 39, '1731'),
	(243, 1, 0, -50942, 1733, 0, 0, 39, '1732'),
	(243, 1, 0, -50942, 1734, 0, 0, 39, '1733'),
	(243, 1, 0, -50942, 1735, 0, 0, 39, '1734'),
	(243, 1, 0, -50942, 1736, 0, 0, 39, '1735'),
	(243, 1, 0, -50942, 1737, 0, 0, 39, '1736'),
	(243, 1, 0, -50942, 1738, 0, 0, 39, '1737'),
	(243, 1, 0, -50942, 1739, 0, 0, 39, '1738'),
	(243, 1, 0, -50942, 1740, 0, 0, 39, '1739'),
	(243, 1, 0, -50942, 1741, 0, 0, 39, '1740'),
	(243, 1, 0, -50942, 1742, 0, 0, 39, '1741'),
	(243, 1, 0, -50942, 1743, 0, 0, 39, '1742'),
	(243, 1, 0, -50942, 1744, 0, 0, 39, '1743'),
	(243, 1, 0, -50942, 1745, 0, 0, 39, '1744'),
	(243, 1, 0, -50942, 1746, 0, 0, 39, '1745'),
	(243, 1, 0, -50942, 1747, 0, 0, 39, '1746'),
	(243, 1, 0, -50942, 1748, 0, 0, 39, '1747'),
	(243, 1, 0, -50942, 1749, 0, 0, 39, '1748'),
	(243, 1, 0, -50942, 1750, 0, 0, 39, '1749'),
	(243, 1, 0, -50942, 1751, 0, 0, 39, '1750'),
	(243, 1, 0, -50942, 1752, 0, 0, 39, '1751'),
	(243, 1, 0, -50942, 1753, 0, 0, 39, '1752'),
	(243, 1, 0, -50942, 1754, 0, 0, 39, '1753'),
	(243, 1, 0, -50942, 1755, 0, 0, 39, '1754'),
	(243, 1, 0, -50942, 1756, 0, 0, 39, '1755'),
	(243, 1, 0, -50942, 1757, 0, 0, 39, '1756'),
	(243, 1, 0, -50942, 1758, 0, 0, 39, '1757'),
	(243, 1, 0, -50942, 1759, 0, 0, 39, '1758'),
	(243, 1, 0, -50942, 1760, 0, 0, 39, '1759'),
	(243, 1, 0, -50942, 1761, 0, 0, 39, '1760'),
	(243, 1, 0, -50942, 1762, 0, 0, 39, '1761'),
	(243, 1, 0, -50942, 1763, 0, 0, 39, '1762'),
	(243, 1, 0, -50942, 1764, 0, 0, 39, '1763'),
	(243, 1, 0, -50942, 1765, 0, 0, 39, '1764'),
	(243, 1, 0, -50942, 1766, 0, 0, 39, '1765'),
	(243, 1, 0, -50942, 1767, 0, 0, 39, '1766'),
	(243, 1, 0, -50942, 1768, 0, 0, 39, '1767'),
	(243, 1, 0, -50942, 1769, 0, 0, 39, '1768'),
	(243, 1, 0, -50942, 1770, 0, 0, 39, '1769'),
	(243, 1, 0, -50942, 1771, 0, 0, 39, '1770'),
	(243, 1, 0, -50942, 1772, 0, 0, 39, '1771'),
	(243, 1, 0, -50942, 1773, 0, 0, 39, '1772'),
	(243, 1, 0, -50942, 1774, 0, 0, 39, '1773'),
	(243, 1, 0, -50942, 1775, 0, 0, 39, '1774'),
	(243, 1, 0, -50942, 1776, 0, 0, 39, '1775'),
	(243, 1, 0, -50942, 1777, 0, 0, 39, '1776'),
	(243, 1, 0, -50942, 1778, 0, 0, 39, '1777'),
	(243, 1, 0, -50942, 1779, 0, 0, 39, '1778'),
	(243, 1, 0, -50942, 1780, 0, 0, 39, '1779'),
	(243, 1, 0, -50942, 1781, 0, 0, 39, '1780'),
	(243, 1, 0, -50942, 1782, 0, 0, 39, '1781'),
	(243, 1, 0, -50942, 1783, 0, 0, 39, '1782'),
	(243, 1, 0, -50942, 1784, 0, 0, 39, '1783'),
	(243, 1, 0, -50942, 1785, 0, 0, 39, '1784'),
	(243, 1, 0, -50942, 1786, 0, 0, 39, '1785'),
	(243, 1, 0, -50942, 1787, 0, 0, 39, '1786'),
	(243, 1, 0, -50942, 1788, 0, 0, 39, '1787'),
	(243, 1, 0, -50942, 1789, 0, 0, 39, '1788'),
	(243, 1, 0, -50942, 1790, 0, 0, 39, '1789'),
	(243, 1, 0, -50942, 1791, 0, 0, 39, '1790'),
	(243, 1, 0, -50942, 1792, 0, 0, 39, '1791'),
	(243, 1, 0, -50942, 1793, 0, 0, 39, '1792'),
	(243, 1, 0, -50942, 1794, 0, 0, 39, '1793'),
	(243, 1, 0, -50942, 1795, 0, 0, 39, '1794'),
	(243, 1, 0, -50942, 1796, 0, 0, 39, '1795'),
	(243, 1, 0, -50942, 1797, 0, 0, 39, '1796'),
	(243, 1, 0, -50942, 1798, 0, 0, 39, '1797'),
	(243, 1, 0, -50942, 1799, 0, 0, 39, '1798'),
	(243, 1, 0, -50942, 1800, 0, 0, 39, '1799'),
	(243, 1, 0, -50942, 1801, 0, 0, 39, '1800'),
	(243, 1, 0, -50942, 1802, 0, 0, 39, '1801'),
	(243, 1, 0, -50942, 1803, 0, 0, 39, '1802'),
	(243, 1, 0, -50942, 1804, 0, 0, 39, '1803'),
	(243, 1, 0, -50942, 1805, 0, 0, 39, '1804'),
	(243, 1, 0, -50942, 1806, 0, 0, 39, '1805'),
	(243, 1, 0, -50942, 1807, 0, 0, 39, '1806'),
	(243, 1, 0, -50942, 1808, 0, 0, 39, '1807'),
	(243, 1, 0, -50942, 1809, 0, 0, 39, '1808'),
	(243, 1, 0, -50942, 1810, 0, 0, 39, '1809'),
	(243, 1, 0, -50942, 1811, 0, 0, 39, '1810'),
	(243, 1, 0, -50942, 1812, 0, 0, 39, '1811'),
	(243, 1, 0, -50942, 1813, 0, 0, 39, '1812'),
	(243, 1, 0, -50942, 1814, 0, 0, 39, '1813'),
	(243, 1, 0, -50942, 1815, 0, 0, 39, '1814'),
	(243, 1, 0, -50942, 1816, 0, 0, 39, '1815'),
	(243, 1, 0, -50942, 1817, 0, 0, 39, '1816'),
	(243, 1, 0, -50942, 1818, 0, 0, 39, '1817'),
	(243, 1, 0, -50942, 1819, 0, 0, 39, '1818'),
	(243, 1, 0, -50942, 1820, 0, 0, 39, '1819'),
	(243, 1, 0, -50942, 1821, 0, 0, 39, '1820'),
	(243, 1, 0, -50942, 1822, 0, 0, 39, '1821'),
	(243, 1, 0, -50942, 1823, 0, 0, 39, '1822'),
	(243, 1, 0, -50942, 1824, 0, 0, 39, '1823'),
	(243, 1, 0, -50942, 1825, 0, 0, 39, '1824'),
	(243, 1, 0, -50942, 1826, 0, 0, 39, '1825'),
	(243, 1, 0, -50942, 1827, 0, 0, 39, '1826'),
	(243, 1, 0, -50942, 1828, 0, 0, 39, '1827'),
	(243, 1, 0, -50942, 1829, 0, 0, 39, '1828'),
	(243, 1, 0, -50942, 1830, 0, 0, 39, '1829'),
	(243, 1, 0, -50942, 1831, 0, 0, 39, '1830'),
	(243, 1, 0, -50942, 1832, 0, 0, 39, '1831'),
	(243, 1, 0, -50942, 1833, 0, 0, 39, '1832'),
	(243, 1, 0, -50942, 1834, 0, 0, 39, '1833'),
	(243, 1, 0, -50942, 1835, 0, 0, 39, '1834'),
	(243, 1, 0, -50942, 1836, 0, 0, 39, '1835'),
	(243, 1, 0, -50942, 1837, 0, 0, 39, '1836'),
	(243, 1, 0, -50942, 1838, 0, 0, 39, '1837'),
	(243, 1, 0, -50942, 1839, 0, 0, 39, '1838'),
	(243, 1, 0, -50942, 1840, 0, 0, 39, '1839'),
	(243, 1, 0, -50942, 1841, 0, 0, 39, '1840'),
	(243, 1, 0, -50942, 1842, 0, 0, 39, '1841'),
	(243, 1, 0, -50942, 1843, 0, 0, 39, '1842'),
	(243, 1, 0, -50942, 1844, 0, 0, 39, '1843'),
	(243, 1, 0, -50942, 1845, 0, 0, 39, '1844'),
	(243, 1, 0, -50942, 1846, 0, 0, 39, '1845'),
	(243, 1, 0, -50942, 1847, 0, 0, 39, '1846'),
	(243, 1, 0, -50942, 1848, 0, 0, 39, '1847'),
	(243, 1, 0, -50942, 1849, 0, 0, 39, '1848'),
	(243, 1, 0, -50942, 1850, 0, 0, 39, '1849'),
	(243, 1, 0, -50942, 1851, 0, 0, 39, '1850'),
	(243, 1, 0, -50942, 1852, 0, 0, 39, '1851'),
	(243, 1, 0, -50942, 1853, 0, 0, 39, '1852'),
	(243, 1, 0, -50942, 1854, 0, 0, 39, '1853'),
	(243, 1, 0, -50942, 1855, 0, 0, 39, '1854'),
	(243, 1, 0, -50942, 1856, 0, 0, 39, '1855'),
	(243, 1, 0, -50942, 1857, 0, 0, 39, '1856'),
	(243, 1, 0, -50942, 1858, 0, 0, 39, '1857'),
	(243, 1, 0, -50942, 1859, 0, 0, 39, '1858'),
	(243, 1, 0, -50942, 1860, 0, 0, 39, '1859'),
	(243, 1, 0, -50942, 1861, 0, 0, 39, '1860'),
	(243, 1, 0, -50942, 1862, 0, 0, 39, '1861'),
	(243, 1, 0, -50942, 1863, 0, 0, 39, '1862'),
	(243, 1, 0, -50942, 1864, 0, 0, 39, '1863'),
	(243, 1, 0, -50942, 1865, 0, 0, 39, '1864'),
	(243, 1, 0, -50942, 1866, 0, 0, 39, '1865'),
	(243, 1, 0, -50942, 1867, 0, 0, 39, '1866'),
	(243, 1, 0, -50942, 1868, 0, 0, 39, '1867'),
	(243, 1, 0, -50942, 1869, 0, 0, 39, '1868'),
	(243, 1, 0, -50942, 1870, 0, 0, 39, '1869'),
	(243, 1, 0, -50942, 1871, 0, 0, 39, '1870'),
	(243, 1, 0, -50942, 1872, 0, 0, 39, '1871'),
	(243, 1, 0, -50942, 1873, 0, 0, 39, '1872'),
	(243, 1, 0, -50942, 1874, 0, 0, 39, '1873'),
	(243, 1, 0, -50942, 1875, 0, 0, 39, '1874'),
	(243, 1, 0, -50942, 1876, 0, 0, 39, '1875'),
	(243, 1, 0, -50942, 1877, 0, 0, 39, '1876'),
	(243, 1, 0, -50942, 1878, 0, 0, 39, '1877'),
	(243, 1, 0, -50942, 1879, 0, 0, 39, '1878'),
	(243, 1, 0, -50942, 1880, 0, 0, 39, '1879'),
	(243, 1, 0, -50942, 1881, 0, 0, 39, '1880'),
	(243, 1, 0, -50942, 1882, 0, 0, 39, '1881'),
	(243, 1, 0, -50942, 1883, 0, 0, 39, '1882'),
	(243, 1, 0, -50942, 1884, 0, 0, 39, '1883'),
	(243, 1, 0, -50942, 1885, 0, 0, 39, '1884'),
	(243, 1, 0, -50942, 1886, 0, 0, 39, '1885'),
	(243, 1, 0, -50942, 1887, 0, 0, 39, '1886'),
	(243, 1, 0, -50942, 1888, 0, 0, 39, '1887'),
	(243, 1, 0, -50942, 1889, 0, 0, 39, '1888'),
	(243, 1, 0, -50942, 1890, 0, 0, 39, '1889'),
	(243, 1, 0, -50942, 1891, 0, 0, 39, '1890'),
	(243, 1, 0, -50942, 1892, 0, 0, 39, '1891'),
	(243, 1, 0, -50942, 1893, 0, 0, 39, '1892'),
	(243, 1, 0, -50942, 1894, 0, 0, 39, '1893'),
	(243, 1, 0, -50942, 1895, 0, 0, 39, '1894'),
	(243, 1, 0, -50942, 1896, 0, 0, 39, '1895'),
	(243, 1, 0, -50942, 1897, 0, 0, 39, '1896'),
	(243, 1, 0, -50942, 1898, 0, 0, 39, '1897'),
	(243, 1, 0, -50942, 1899, 0, 0, 39, '1898'),
	(243, 1, 0, -50942, 1900, 0, 0, 39, '1899'),
	(243, 1, 0, -50942, 1901, 0, 0, 39, '1900'),
	(243, 1, 0, -50942, 1902, 0, 0, 39, '1901'),
	(243, 1, 0, -50942, 1903, 0, 0, 39, '1902'),
	(243, 1, 0, -50942, 1904, 0, 0, 39, '1903'),
	(243, 1, 0, -50942, 1905, 0, 0, 39, '1904'),
	(243, 1, 0, -50942, 1906, 0, 0, 39, '1905'),
	(243, 1, 0, -50942, 1907, 0, 0, 39, '1906'),
	(243, 1, 0, -50942, 1908, 0, 0, 39, '1907'),
	(243, 1, 0, -50942, 1909, 0, 0, 39, '1908'),
	(243, 1, 0, -50942, 1910, 0, 0, 39, '1909'),
	(243, 1, 0, -50942, 1911, 0, 0, 39, '1910'),
	(243, 1, 0, -50942, 1912, 0, 0, 39, '1911'),
	(243, 1, 0, -50942, 1913, 0, 0, 39, '1912'),
	(243, 1, 0, -50942, 1914, 0, 0, 39, '1913'),
	(243, 1, 0, -50942, 1915, 0, 0, 39, '1914'),
	(243, 1, 0, -50942, 1916, 0, 0, 39, '1915'),
	(243, 1, 0, -50942, 1917, 0, 0, 39, '1916'),
	(243, 1, 0, -50942, 1918, 0, 0, 39, '1917'),
	(243, 1, 0, -50942, 1919, 0, 0, 39, '1918'),
	(243, 1, 0, -50942, 1920, 0, 0, 39, '1919'),
	(243, 1, 0, -50942, 1921, 0, 0, 39, '1920'),
	(243, 1, 0, -50942, 1922, 0, 0, 39, '1921'),
	(243, 1, 0, -50942, 1923, 0, 0, 39, '1922'),
	(243, 1, 0, -50942, 1924, 0, 0, 39, '1923'),
	(243, 1, 0, -50942, 1925, 0, 0, 39, '1924'),
	(243, 1, 0, -50942, 1926, 0, 0, 39, '1925'),
	(243, 1, 0, -50942, 1927, 0, 0, 39, '1926'),
	(243, 1, 0, -50942, 1928, 0, 0, 39, '1927'),
	(243, 1, 0, -50942, 1929, 0, 0, 39, '1928'),
	(243, 1, 0, -50942, 1930, 0, 0, 39, '1929'),
	(243, 1, 0, -50942, 1931, 0, 0, 39, '1930'),
	(243, 1, 0, -50942, 1932, 0, 0, 39, '1931'),
	(243, 1, 0, -50942, 1933, 0, 0, 39, '1932'),
	(243, 1, 0, -50942, 1934, 0, 0, 39, '1933'),
	(243, 1, 0, -50942, 1935, 0, 0, 39, '1934'),
	(243, 1, 0, -50942, 1936, 0, 0, 39, '1935'),
	(243, 1, 0, -50942, 1937, 0, 0, 39, '1936'),
	(243, 1, 0, -50942, 1938, 0, 0, 39, '1937'),
	(243, 1, 0, -50942, 1939, 0, 0, 39, '1938'),
	(243, 1, 0, -50942, 1940, 0, 0, 39, '1939'),
	(243, 1, 0, -50942, 1941, 0, 0, 39, '1940'),
	(243, 1, 0, -50942, 1942, 0, 0, 39, '1941'),
	(243, 1, 0, -50942, 1943, 0, 0, 39, '1942'),
	(243, 1, 0, -50942, 1944, 0, 0, 39, '1943'),
	(243, 1, 0, -50942, 1945, 0, 0, 39, '1944'),
	(243, 1, 0, -50942, 1946, 0, 0, 39, '1945'),
	(243, 1, 0, -50942, 1947, 0, 0, 39, '1946'),
	(243, 1, 0, -50942, 1948, 0, 0, 39, '1947'),
	(243, 1, 0, -50942, 1949, 0, 0, 39, '1948'),
	(243, 1, 0, -50942, 1950, 0, 0, 39, '1949'),
	(243, 1, 0, -50942, 1951, 0, 0, 39, '1950'),
	(243, 1, 0, -50942, 1952, 0, 0, 39, '1951'),
	(243, 1, 0, -50942, 1953, 0, 0, 39, '1952'),
	(243, 1, 0, -50942, 1954, 0, 0, 39, '1953'),
	(243, 1, 0, -50942, 1955, 0, 0, 39, '1954'),
	(243, 1, 0, -50942, 1956, 0, 0, 39, '1955'),
	(243, 1, 0, -50942, 1957, 0, 0, 39, '1956'),
	(243, 1, 0, -50942, 1958, 0, 0, 39, '1957'),
	(243, 1, 0, -50942, 1959, 0, 0, 39, '1958'),
	(243, 1, 0, -50942, 1960, 0, 0, 39, '1959'),
	(243, 1, 0, -50942, 1961, 0, 0, 39, '1960'),
	(243, 1, 0, -50942, 1962, 0, 0, 39, '1961'),
	(243, 1, 0, -50942, 1963, 0, 0, 39, '1962'),
	(243, 1, 0, -50942, 1964, 0, 0, 39, '1963'),
	(243, 1, 0, -50942, 1965, 0, 0, 39, '1964'),
	(243, 1, 0, -50942, 1966, 0, 0, 39, '1965'),
	(243, 1, 0, -50942, 1967, 0, 0, 39, '1966'),
	(243, 1, 0, -50942, 1968, 0, 0, 39, '1967'),
	(243, 1, 0, -50942, 1969, 0, 0, 39, '1968'),
	(243, 1, 0, -50942, 1970, 0, 0, 39, '1969'),
	(243, 1, 0, -50942, 1971, 0, 0, 39, '1970'),
	(243, 1, 0, -50942, 1972, 0, 0, 39, '1971'),
	(243, 1, 0, -50942, 1973, 0, 0, 39, '1972'),
	(243, 1, 0, -50942, 1974, 0, 0, 39, '1973'),
	(243, 1, 0, -50942, 1975, 0, 0, 39, '1974'),
	(243, 1, 0, -50942, 1976, 0, 0, 39, '1975'),
	(243, 1, 0, -50942, 1977, 0, 0, 39, '1976'),
	(243, 1, 0, -50942, 1978, 0, 0, 39, '1977'),
	(243, 1, 0, -50942, 1979, 0, 0, 39, '1978'),
	(243, 1, 0, -50942, 1980, 0, 0, 39, '1979'),
	(243, 1, 0, -50942, 1981, 0, 0, 39, '1980'),
	(243, 1, 0, -50942, 1982, 0, 0, 39, '1981'),
	(243, 1, 0, -50942, 1983, 0, 0, 39, '1982'),
	(243, 1, 0, -50942, 1984, 0, 0, 39, '1983'),
	(243, 1, 0, -50942, 1985, 0, 0, 39, '1984'),
	(243, 1, 0, -50942, 1986, 0, 0, 39, '1985'),
	(243, 1, 0, -50942, 1987, 0, 0, 39, '1986'),
	(243, 1, 0, -50942, 1988, 0, 0, 39, '1987'),
	(243, 1, 0, -50942, 1989, 0, 0, 39, '1988'),
	(243, 1, 0, -50942, 1990, 0, 0, 39, '1989'),
	(243, 1, 0, -50942, 1991, 0, 0, 39, '1990'),
	(243, 1, 0, -50942, 1992, 0, 0, 39, '1991'),
	(243, 1, 0, -50942, 1993, 0, 0, 39, '1992'),
	(243, 1, 0, -50942, 1994, 0, 0, 39, '1993'),
	(243, 1, 0, -50942, 1995, 0, 0, 39, '1994'),
	(243, 1, 0, -50942, 1996, 0, 0, 39, '1995'),
	(243, 1, 0, -50942, 1997, 0, 0, 39, '1996'),
	(243, 1, 0, -50942, 1998, 0, 0, 39, '1997'),
	(243, 1, 0, -50942, 1999, 0, 0, 39, '1998'),
	(243, 1, 0, -50942, 2000, 0, 0, 39, '1999'),
	(243, 1, 0, -50942, 2001, 0, 0, 39, '2000'),
	(243, 1, 0, -50942, 2002, 0, 0, 39, '2001'),
	(243, 1, 0, -50942, 2003, 0, 0, 39, '2002'),
	(243, 1, 0, -50942, 2004, 0, 0, 39, '2003'),
	(243, 1, 0, -50942, 2005, 0, 0, 39, '2004'),
	(243, 1, 0, -50942, 2006, 0, 0, 39, '2005'),
	(243, 1, 0, -50942, 2007, 0, 0, 39, '2006'),
	(243, 1, 0, -50942, 2008, 0, 0, 39, '2007'),
	(243, 1, 0, -50942, 2009, 0, 0, 39, '2008'),
	(243, 1, 0, -50942, 2010, 0, 0, 39, '2009'),
	(243, 1, 0, -50942, 2011, 0, 0, 39, '2010'),
	(243, 1, 0, -50942, 2012, 0, 0, 39, '2011'),
	(243, 1, 0, -50942, 2013, 0, 0, 39, '2012'),
	(243, 1, 0, -50942, 2014, 0, 0, 39, '2013'),
	(243, 1, 0, -50942, 2015, 0, 0, 39, '2014'),
	(243, 1, 0, -50942, 2016, 0, 0, 39, '2015'),
	(243, 1, 0, -50942, 2017, 0, 0, 39, '2016'),
	(243, 1, 0, -50942, 2018, 0, 0, 39, '2017'),
	(243, 1, 0, -50942, 2019, 0, 0, 39, '2018'),
	(243, 1, 0, -50942, 2020, 0, 0, 39, '2019'),
	(243, 1, 0, -50942, 2021, 0, 0, 39, '2020'),
	(243, 1, 0, -50942, 2022, 0, 0, 39, '2021'),
	(243, 1, 0, -50942, 2023, 0, 0, 39, '2022'),
	(243, 1, 0, -50942, 2024, 0, 0, 39, '2023'),
	(243, 1, 0, -50942, 2025, 0, 0, 39, '2024'),
	(243, 1, 0, -50942, 2026, 0, 0, 39, '2025'),
	(243, 1, 0, -50942, 2027, 0, 0, 39, '2026'),
	(243, 1, 0, -50942, 2028, 0, 0, 39, '2027'),
	(243, 1, 0, -50942, 2029, 0, 0, 39, '2028'),
	(243, 1, 0, -50942, 2030, 0, 0, 39, '2029'),
	(243, 1, 0, -50942, 2031, 0, 0, 39, '2030'),
	(243, 1, 0, -50942, 2032, 0, 0, 39, '2031'),
	(243, 1, 0, -50942, 2033, 0, 0, 39, '2032'),
	(243, 1, 0, -50942, 2034, 0, 0, 39, '2033'),
	(243, 1, 0, -50942, 2035, 0, 0, 39, '2034'),
	(243, 1, 0, -50942, 2036, 0, 0, 39, '2035'),
	(243, 1, 0, -50942, 2037, 0, 0, 39, '2036'),
	(243, 1, 0, -50942, 2038, 0, 0, 39, '2037'),
	(243, 1, 0, -50942, 2039, 0, 0, 39, '2038'),
	(243, 1, 0, -50942, 2040, 0, 0, 39, '2039'),
	(243, 1, 0, -50942, 2041, 0, 0, 39, '2040'),
	(243, 1, 0, -50942, 2042, 0, 0, 39, '2041'),
	(243, 1, 0, -50942, 2043, 0, 0, 39, '2042'),
	(243, 1, 0, -50942, 2044, 0, 0, 39, '2043'),
	(243, 1, 0, -50942, 2045, 0, 0, 39, '2044'),
	(243, 1, 0, -50942, 2046, 0, 0, 39, '2045'),
	(243, 1, 0, -50942, 2047, 0, 0, 39, '2046'),
	(243, 1, 0, -50942, 2048, 0, 0, 39, '2047'),
	(243, 1, 0, -50941, 1, 0, 0, 39, '0'),
	(243, 1, 0, -50941, 2, 0, 0, 39, '1'),
	(243, 1, 0, -50941, 3, 0, 0, 39, '2'),
	(243, 1, 0, -50941, 4, 0, 0, 39, '3'),
	(243, 1, 0, -50941, 5, 0, 0, 39, '4'),
	(243, 1, 0, -50941, 6, 0, 0, 39, '5'),
	(243, 1, 0, -50941, 7, 0, 0, 39, '6'),
	(243, 1, 0, -50941, 8, 0, 0, 39, '7'),
	(243, 1, 0, -50941, 9, 0, 0, 39, '8'),
	(243, 1, 0, -50941, 10, 0, 0, 39, '9'),
	(243, 1, 0, -50941, 11, 0, 0, 39, '10'),
	(243, 1, 0, -50941, 12, 0, 0, 39, '11'),
	(243, 1, 0, -50941, 13, 0, 0, 39, '12'),
	(243, 1, 0, -50941, 14, 0, 0, 39, '13'),
	(243, 1, 0, -50941, 15, 0, 0, 39, '14'),
	(243, 1, 0, -50941, 16, 0, 0, 39, '15'),
	(243, 1, 0, -50941, 17, 0, 0, 39, '16'),
	(243, 1, 0, -50941, 18, 0, 0, 39, '17'),
	(243, 1, 0, -50941, 19, 0, 0, 39, '18'),
	(243, 1, 0, -50941, 20, 0, 0, 39, '19'),
	(243, 1, 0, -50941, 21, 0, 0, 39, '20'),
	(243, 1, 0, -50941, 22, 0, 0, 39, '21'),
	(243, 1, 0, -50941, 23, 0, 0, 39, '22'),
	(243, 1, 0, -50941, 24, 0, 0, 39, '23'),
	(243, 1, 0, -50941, 25, 0, 0, 39, '24'),
	(243, 1, 0, -50941, 26, 0, 0, 39, '25'),
	(243, 1, 0, -50941, 27, 0, 0, 39, '26'),
	(243, 1, 0, -50941, 28, 0, 0, 39, '27'),
	(243, 1, 0, -50941, 29, 0, 0, 39, '28'),
	(243, 1, 0, -50941, 30, 0, 0, 39, '29'),
	(243, 1, 0, -50941, 31, 0, 0, 39, '30'),
	(243, 1, 0, -50941, 32, 0, 0, 39, '31'),
	(243, 1, 0, -50941, 33, 0, 0, 39, '32'),
	(243, 1, 0, -50941, 34, 0, 0, 39, '33'),
	(243, 1, 0, -50941, 35, 0, 0, 39, '34'),
	(243, 1, 0, -50941, 36, 0, 0, 39, '35'),
	(243, 1, 0, -50941, 37, 0, 0, 39, '36'),
	(243, 1, 0, -50941, 38, 0, 0, 39, '37'),
	(243, 1, 0, -50941, 39, 0, 0, 39, '38'),
	(243, 1, 0, -50941, 40, 0, 0, 39, '39'),
	(243, 1, 0, -50941, 41, 0, 0, 39, '40'),
	(243, 1, 0, -50941, 42, 0, 0, 39, '41'),
	(243, 1, 0, -50941, 43, 0, 0, 39, '42'),
	(243, 1, 0, -50941, 44, 0, 0, 39, '43'),
	(243, 1, 0, -50941, 45, 0, 0, 39, '44'),
	(243, 1, 0, -50941, 46, 0, 0, 39, '45'),
	(243, 1, 0, -50941, 47, 0, 0, 39, '46'),
	(243, 1, 0, -50941, 48, 0, 0, 39, '47'),
	(243, 1, 0, -50941, 49, 0, 0, 39, '48'),
	(243, 1, 0, -50941, 50, 0, 0, 39, '49'),
	(243, 1, 0, -50941, 51, 0, 0, 39, '50'),
	(243, 1, 0, -50941, 52, 0, 0, 39, '51'),
	(243, 1, 0, -50941, 53, 0, 0, 39, '52'),
	(243, 1, 0, -50941, 54, 0, 0, 39, '53'),
	(243, 1, 0, -50941, 55, 0, 0, 39, '54'),
	(243, 1, 0, -50941, 56, 0, 0, 39, '55'),
	(243, 1, 0, -50941, 57, 0, 0, 39, '56'),
	(243, 1, 0, -50941, 58, 0, 0, 39, '57'),
	(243, 1, 0, -50941, 59, 0, 0, 39, '58'),
	(243, 1, 0, -50941, 60, 0, 0, 39, '59'),
	(243, 1, 0, -50941, 61, 0, 0, 39, '60'),
	(243, 1, 0, -50941, 62, 0, 0, 39, '61'),
	(243, 1, 0, -50941, 63, 0, 0, 39, '62'),
	(243, 1, 0, -50941, 64, 0, 0, 39, '63'),
	(243, 1, 0, -50941, 65, 0, 0, 39, '64'),
	(243, 1, 0, -50941, 66, 0, 0, 39, '65'),
	(243, 1, 0, -50941, 67, 0, 0, 39, '66'),
	(243, 1, 0, -50941, 68, 0, 0, 39, '67'),
	(243, 1, 0, -50941, 69, 0, 0, 39, '68'),
	(243, 1, 0, -50941, 70, 0, 0, 39, '69'),
	(243, 1, 0, -50941, 71, 0, 0, 39, '70'),
	(243, 1, 0, -50941, 72, 0, 0, 39, '71'),
	(243, 1, 0, -50941, 73, 0, 0, 39, '72'),
	(243, 1, 0, -50941, 74, 0, 0, 39, '73'),
	(243, 1, 0, -50941, 75, 0, 0, 39, '74'),
	(243, 1, 0, -50941, 76, 0, 0, 39, '75'),
	(243, 1, 0, -50941, 77, 0, 0, 39, '76'),
	(243, 1, 0, -50941, 78, 0, 0, 39, '77'),
	(243, 1, 0, -50941, 79, 0, 0, 39, '78'),
	(243, 1, 0, -50941, 80, 0, 0, 39, '79'),
	(243, 1, 0, -50941, 81, 0, 0, 39, '80'),
	(243, 1, 0, -50941, 82, 0, 0, 39, '81'),
	(243, 1, 0, -50941, 83, 0, 0, 39, '82'),
	(243, 1, 0, -50941, 84, 0, 0, 39, '83'),
	(243, 1, 0, -50941, 85, 0, 0, 39, '84'),
	(243, 1, 0, -50941, 86, 0, 0, 39, '85'),
	(243, 1, 0, -50941, 87, 0, 0, 39, '86'),
	(243, 1, 0, -50941, 88, 0, 0, 39, '87'),
	(243, 1, 0, -50941, 89, 0, 0, 39, '88'),
	(243, 1, 0, -50941, 90, 0, 0, 39, '89'),
	(243, 1, 0, -50941, 91, 0, 0, 39, '90'),
	(243, 1, 0, -50941, 92, 0, 0, 39, '91'),
	(243, 1, 0, -50941, 93, 0, 0, 39, '92'),
	(243, 1, 0, -50941, 94, 0, 0, 39, '93'),
	(243, 1, 0, -50941, 95, 0, 0, 39, '94'),
	(243, 1, 0, -50941, 96, 0, 0, 39, '95'),
	(243, 1, 0, -50941, 97, 0, 0, 39, '96'),
	(243, 1, 0, -50941, 98, 0, 0, 39, '97'),
	(243, 1, 0, -50941, 99, 0, 0, 39, '98'),
	(243, 1, 0, -50941, 100, 0, 0, 39, '99'),
	(243, 1, 0, -50941, 101, 0, 0, 39, '100'),
	(243, 1, 0, -50941, 102, 0, 0, 39, '101'),
	(243, 1, 0, -50941, 103, 0, 0, 39, '102'),
	(243, 1, 0, -50941, 104, 0, 0, 39, '103'),
	(243, 1, 0, -50941, 105, 0, 0, 39, '104'),
	(243, 1, 0, -50941, 106, 0, 0, 39, '105'),
	(243, 1, 0, -50941, 107, 0, 0, 39, '106'),
	(243, 1, 0, -50941, 108, 0, 0, 39, '107'),
	(243, 1, 0, -50941, 109, 0, 0, 39, '108'),
	(243, 1, 0, -50941, 110, 0, 0, 39, '109'),
	(243, 1, 0, -50941, 111, 0, 0, 39, '110'),
	(243, 1, 0, -50941, 112, 0, 0, 39, '111'),
	(243, 1, 0, -50941, 113, 0, 0, 39, '112'),
	(243, 1, 0, -50941, 114, 0, 0, 39, '113'),
	(243, 1, 0, -50941, 115, 0, 0, 39, '114'),
	(243, 1, 0, -50941, 116, 0, 0, 39, '115'),
	(243, 1, 0, -50941, 117, 0, 0, 39, '116'),
	(243, 1, 0, -50941, 118, 0, 0, 39, '117'),
	(243, 1, 0, -50941, 119, 0, 0, 39, '118'),
	(243, 1, 0, -50941, 120, 0, 0, 39, '119'),
	(243, 1, 0, -50941, 121, 0, 0, 39, '120'),
	(243, 1, 0, -50941, 122, 0, 0, 39, '121'),
	(243, 1, 0, -50941, 123, 0, 0, 39, '122'),
	(243, 1, 0, -50941, 124, 0, 0, 39, '123'),
	(243, 1, 0, -50941, 125, 0, 0, 39, '124'),
	(243, 1, 0, -50941, 126, 0, 0, 39, '125'),
	(243, 1, 0, -50941, 127, 0, 0, 39, '126'),
	(243, 1, 0, -50941, 128, 0, 0, 39, '127'),
	(243, 1, 0, -50941, 129, 0, 0, 39, '128'),
	(243, 1, 0, -50941, 130, 0, 0, 39, '129'),
	(243, 1, 0, -50941, 131, 0, 0, 39, '130'),
	(243, 1, 0, -50941, 132, 0, 0, 39, '131'),
	(243, 1, 0, -50941, 133, 0, 0, 39, '132'),
	(243, 1, 0, -50941, 134, 0, 0, 39, '133'),
	(243, 1, 0, -50941, 135, 0, 0, 39, '134'),
	(243, 1, 0, -50941, 136, 0, 0, 39, '135'),
	(243, 1, 0, -50941, 137, 0, 0, 39, '136'),
	(243, 1, 0, -50941, 138, 0, 0, 39, '137'),
	(243, 1, 0, -50941, 139, 0, 0, 39, '138'),
	(243, 1, 0, -50941, 140, 0, 0, 39, '139'),
	(243, 1, 0, -50941, 141, 0, 0, 39, '140'),
	(243, 1, 0, -50941, 142, 0, 0, 39, '141'),
	(243, 1, 0, -50941, 143, 0, 0, 39, '142'),
	(243, 1, 0, -50941, 144, 0, 0, 39, '143'),
	(243, 1, 0, -50941, 145, 0, 0, 39, '144'),
	(243, 1, 0, -50941, 146, 0, 0, 39, '145'),
	(243, 1, 0, -50941, 147, 0, 0, 39, '146'),
	(243, 1, 0, -50941, 148, 0, 0, 39, '147'),
	(243, 1, 0, -50941, 149, 0, 0, 39, '148'),
	(243, 1, 0, -50941, 150, 0, 0, 39, '149'),
	(243, 1, 0, -50941, 151, 0, 0, 39, '150'),
	(243, 1, 0, -50941, 152, 0, 0, 39, '151'),
	(243, 1, 0, -50941, 153, 0, 0, 39, '152'),
	(243, 1, 0, -50941, 154, 0, 0, 39, '153'),
	(243, 1, 0, -50941, 155, 0, 0, 39, '154'),
	(243, 1, 0, -50941, 156, 0, 0, 39, '155'),
	(243, 1, 0, -50941, 157, 0, 0, 39, '156'),
	(243, 1, 0, -50941, 158, 0, 0, 39, '157'),
	(243, 1, 0, -50941, 159, 0, 0, 39, '158'),
	(243, 1, 0, -50941, 160, 0, 0, 39, '159'),
	(243, 1, 0, -50941, 161, 0, 0, 39, '160'),
	(243, 1, 0, -50941, 162, 0, 0, 39, '161'),
	(243, 1, 0, -50941, 163, 0, 0, 39, '162'),
	(243, 1, 0, -50941, 164, 0, 0, 39, '163'),
	(243, 1, 0, -50941, 165, 0, 0, 39, '164'),
	(243, 1, 0, -50941, 166, 0, 0, 39, '165'),
	(243, 1, 0, -50941, 167, 0, 0, 39, '166'),
	(243, 1, 0, -50941, 168, 0, 0, 39, '167'),
	(243, 1, 0, -50941, 169, 0, 0, 39, '168'),
	(243, 1, 0, -50941, 170, 0, 0, 39, '169'),
	(243, 1, 0, -50941, 171, 0, 0, 39, '170'),
	(243, 1, 0, -50941, 172, 0, 0, 39, '171'),
	(243, 1, 0, -50941, 173, 0, 0, 39, '172'),
	(243, 1, 0, -50941, 174, 0, 0, 39, '173'),
	(243, 1, 0, -50941, 175, 0, 0, 39, '174'),
	(243, 1, 0, -50941, 176, 0, 0, 39, '175'),
	(243, 1, 0, -50941, 177, 0, 0, 39, '176'),
	(243, 1, 0, -50941, 178, 0, 0, 39, '177'),
	(243, 1, 0, -50941, 179, 0, 0, 39, '178'),
	(243, 1, 0, -50941, 180, 0, 0, 39, '179'),
	(243, 1, 0, -50941, 181, 0, 0, 39, '180'),
	(243, 1, 0, -50941, 182, 0, 0, 39, '181'),
	(243, 1, 0, -50941, 183, 0, 0, 39, '182'),
	(243, 1, 0, -50941, 184, 0, 0, 39, '183'),
	(243, 1, 0, -50941, 185, 0, 0, 39, '184'),
	(243, 1, 0, -50941, 186, 0, 0, 39, '185'),
	(243, 1, 0, -50941, 187, 0, 0, 39, '186'),
	(243, 1, 0, -50941, 188, 0, 0, 39, '187'),
	(243, 1, 0, -50941, 189, 0, 0, 39, '188'),
	(243, 1, 0, -50941, 190, 0, 0, 39, '189'),
	(243, 1, 0, -50941, 191, 0, 0, 39, '190'),
	(243, 1, 0, -50941, 192, 0, 0, 39, '191'),
	(243, 1, 0, -50941, 193, 0, 0, 39, '192'),
	(243, 1, 0, -50941, 194, 0, 0, 39, '193'),
	(243, 1, 0, -50941, 195, 0, 0, 39, '194'),
	(243, 1, 0, -50941, 196, 0, 0, 39, '195'),
	(243, 1, 0, -50941, 197, 0, 0, 39, '196'),
	(243, 1, 0, -50941, 198, 0, 0, 39, '197'),
	(243, 1, 0, -50941, 199, 0, 0, 39, '198'),
	(243, 1, 0, -50941, 200, 0, 0, 39, '199'),
	(243, 1, 0, -50941, 201, 0, 0, 39, '200'),
	(243, 1, 0, -50941, 202, 0, 0, 39, '201'),
	(243, 1, 0, -50941, 203, 0, 0, 39, '202'),
	(243, 1, 0, -50941, 204, 0, 0, 39, '203'),
	(243, 1, 0, -50941, 205, 0, 0, 39, '204'),
	(243, 1, 0, -50941, 206, 0, 0, 39, '205'),
	(243, 1, 0, -50941, 207, 0, 0, 39, '206'),
	(243, 1, 0, -50941, 208, 0, 0, 39, '207'),
	(243, 1, 0, -50941, 209, 0, 0, 39, '208'),
	(243, 1, 0, -50941, 210, 0, 0, 39, '209'),
	(243, 1, 0, -50941, 211, 0, 0, 39, '210'),
	(243, 1, 0, -50941, 212, 0, 0, 39, '211'),
	(243, 1, 0, -50941, 213, 0, 0, 39, '212'),
	(243, 1, 0, -50941, 214, 0, 0, 39, '213'),
	(243, 1, 0, -50941, 215, 0, 0, 39, '214'),
	(243, 1, 0, -50941, 216, 0, 0, 39, '215'),
	(243, 1, 0, -50941, 217, 0, 0, 39, '216'),
	(243, 1, 0, -50941, 218, 0, 0, 39, '217'),
	(243, 1, 0, -50941, 219, 0, 0, 39, '218'),
	(243, 1, 0, -50941, 220, 0, 0, 39, '219'),
	(243, 1, 0, -50941, 221, 0, 0, 39, '220'),
	(243, 1, 0, -50941, 222, 0, 0, 39, '221'),
	(243, 1, 0, -50941, 223, 0, 0, 39, '222'),
	(243, 1, 0, -50941, 224, 0, 0, 39, '223'),
	(243, 1, 0, -50941, 225, 0, 0, 39, '224'),
	(243, 1, 0, -50941, 226, 0, 0, 39, '225'),
	(243, 1, 0, -50941, 227, 0, 0, 39, '226'),
	(243, 1, 0, -50941, 228, 0, 0, 39, '227'),
	(243, 1, 0, -50941, 229, 0, 0, 39, '228'),
	(243, 1, 0, -50941, 230, 0, 0, 39, '229'),
	(243, 1, 0, -50941, 231, 0, 0, 39, '230'),
	(243, 1, 0, -50941, 232, 0, 0, 39, '231'),
	(243, 1, 0, -50941, 233, 0, 0, 39, '232'),
	(243, 1, 0, -50941, 234, 0, 0, 39, '233'),
	(243, 1, 0, -50941, 235, 0, 0, 39, '234'),
	(243, 1, 0, -50941, 236, 0, 0, 39, '235'),
	(243, 1, 0, -50941, 237, 0, 0, 39, '236'),
	(243, 1, 0, -50941, 238, 0, 0, 39, '237'),
	(243, 1, 0, -50941, 239, 0, 0, 39, '238'),
	(243, 1, 0, -50941, 240, 0, 0, 39, '239'),
	(243, 1, 0, -50941, 241, 0, 0, 39, '240'),
	(243, 1, 0, -50941, 242, 0, 0, 39, '241'),
	(243, 1, 0, -50941, 243, 0, 0, 39, '242'),
	(243, 1, 0, -50941, 244, 0, 0, 39, '243'),
	(243, 1, 0, -50941, 245, 0, 0, 39, '244'),
	(243, 1, 0, -50941, 246, 0, 0, 39, '245'),
	(243, 1, 0, -50941, 247, 0, 0, 39, '246'),
	(243, 1, 0, -50941, 248, 0, 0, 39, '247'),
	(243, 1, 0, -50941, 249, 0, 0, 39, '248'),
	(243, 1, 0, -50941, 250, 0, 0, 39, '249'),
	(243, 1, 0, -50941, 251, 0, 0, 39, '250'),
	(243, 1, 0, -50941, 252, 0, 0, 39, '251'),
	(243, 1, 0, -50941, 253, 0, 0, 39, '252'),
	(243, 1, 0, -50941, 254, 0, 0, 39, '253'),
	(243, 1, 0, -50941, 255, 0, 0, 39, '254'),
	(243, 1, 0, -50941, 256, 0, 0, 39, '255'),
	(243, 1, 0, -50941, 257, 0, 0, 39, '256'),
	(243, 1, 0, -50941, 258, 0, 0, 39, '257'),
	(243, 1, 0, -50941, 259, 0, 0, 39, '258'),
	(243, 1, 0, -50941, 260, 0, 0, 39, '259'),
	(243, 1, 0, -50941, 261, 0, 0, 39, '260'),
	(243, 1, 0, -50941, 262, 0, 0, 39, '261'),
	(243, 1, 0, -50941, 263, 0, 0, 39, '262'),
	(243, 1, 0, -50941, 264, 0, 0, 39, '263'),
	(243, 1, 0, -50941, 265, 0, 0, 39, '264'),
	(243, 1, 0, -50941, 266, 0, 0, 39, '265'),
	(243, 1, 0, -50941, 267, 0, 0, 39, '266'),
	(243, 1, 0, -50941, 268, 0, 0, 39, '267'),
	(243, 1, 0, -50941, 269, 0, 0, 39, '268'),
	(243, 1, 0, -50941, 270, 0, 0, 39, '269'),
	(243, 1, 0, -50941, 271, 0, 0, 39, '270'),
	(243, 1, 0, -50941, 272, 0, 0, 39, '271'),
	(243, 1, 0, -50941, 273, 0, 0, 39, '272'),
	(243, 1, 0, -50941, 274, 0, 0, 39, '273'),
	(243, 1, 0, -50941, 275, 0, 0, 39, '274'),
	(243, 1, 0, -50941, 276, 0, 0, 39, '275'),
	(243, 1, 0, -50941, 277, 0, 0, 39, '276'),
	(243, 1, 0, -50941, 278, 0, 0, 39, '277'),
	(243, 1, 0, -50941, 279, 0, 0, 39, '278'),
	(243, 1, 0, -50941, 280, 0, 0, 39, '279'),
	(243, 1, 0, -50941, 281, 0, 0, 39, '280'),
	(243, 1, 0, -50941, 282, 0, 0, 39, '281'),
	(243, 1, 0, -50941, 283, 0, 0, 39, '282'),
	(243, 1, 0, -50941, 284, 0, 0, 39, '283'),
	(243, 1, 0, -50941, 285, 0, 0, 39, '284'),
	(243, 1, 0, -50941, 286, 0, 0, 39, '285'),
	(243, 1, 0, -50941, 287, 0, 0, 39, '286'),
	(243, 1, 0, -50941, 288, 0, 0, 39, '287'),
	(243, 1, 0, -50941, 289, 0, 0, 39, '288'),
	(243, 1, 0, -50941, 290, 0, 0, 39, '289'),
	(243, 1, 0, -50941, 291, 0, 0, 39, '290'),
	(243, 1, 0, -50941, 292, 0, 0, 39, '291'),
	(243, 1, 0, -50941, 293, 0, 0, 39, '292'),
	(243, 1, 0, -50941, 294, 0, 0, 39, '293'),
	(243, 1, 0, -50941, 295, 0, 0, 39, '294'),
	(243, 1, 0, -50941, 296, 0, 0, 39, '295'),
	(243, 1, 0, -50941, 297, 0, 0, 39, '296'),
	(243, 1, 0, -50941, 298, 0, 0, 39, '297'),
	(243, 1, 0, -50941, 299, 0, 0, 39, '298'),
	(243, 1, 0, -50941, 300, 0, 0, 39, '299'),
	(243, 1, 0, -50941, 301, 0, 0, 39, '300'),
	(243, 1, 0, -50941, 302, 0, 0, 39, '301'),
	(243, 1, 0, -50941, 303, 0, 0, 39, '302'),
	(243, 1, 0, -50941, 304, 0, 0, 39, '303'),
	(243, 1, 0, -50941, 305, 0, 0, 39, '304'),
	(243, 1, 0, -50941, 306, 0, 0, 39, '305'),
	(243, 1, 0, -50941, 307, 0, 0, 39, '306'),
	(243, 1, 0, -50941, 308, 0, 0, 39, '307'),
	(243, 1, 0, -50941, 309, 0, 0, 39, '308'),
	(243, 1, 0, -50941, 310, 0, 0, 39, '309'),
	(243, 1, 0, -50941, 311, 0, 0, 39, '310'),
	(243, 1, 0, -50941, 312, 0, 0, 39, '311'),
	(243, 1, 0, -50941, 313, 0, 0, 39, '312'),
	(243, 1, 0, -50941, 314, 0, 0, 39, '313'),
	(243, 1, 0, -50941, 315, 0, 0, 39, '314'),
	(243, 1, 0, -50941, 316, 0, 0, 39, '315'),
	(243, 1, 0, -50941, 317, 0, 0, 39, '316'),
	(243, 1, 0, -50941, 318, 0, 0, 39, '317'),
	(243, 1, 0, -50941, 319, 0, 0, 39, '318'),
	(243, 1, 0, -50941, 320, 0, 0, 39, '319'),
	(243, 1, 0, -50941, 321, 0, 0, 39, '320'),
	(243, 1, 0, -50941, 322, 0, 0, 39, '321'),
	(243, 1, 0, -50941, 323, 0, 0, 39, '322'),
	(243, 1, 0, -50941, 324, 0, 0, 39, '323'),
	(243, 1, 0, -50941, 325, 0, 0, 39, '324'),
	(243, 1, 0, -50941, 326, 0, 0, 39, '325'),
	(243, 1, 0, -50941, 327, 0, 0, 39, '326'),
	(243, 1, 0, -50941, 328, 0, 0, 39, '327'),
	(243, 1, 0, -50941, 329, 0, 0, 39, '328'),
	(243, 1, 0, -50941, 330, 0, 0, 39, '329'),
	(243, 1, 0, -50941, 331, 0, 0, 39, '330'),
	(243, 1, 0, -50941, 332, 0, 0, 39, '331'),
	(243, 1, 0, -50941, 333, 0, 0, 39, '332'),
	(243, 1, 0, -50941, 334, 0, 0, 39, '333'),
	(243, 1, 0, -50941, 335, 0, 0, 39, '334'),
	(243, 1, 0, -50941, 336, 0, 0, 39, '335'),
	(243, 1, 0, -50941, 337, 0, 0, 39, '336'),
	(243, 1, 0, -50941, 338, 0, 0, 39, '337'),
	(243, 1, 0, -50941, 339, 0, 0, 39, '338'),
	(243, 1, 0, -50941, 340, 0, 0, 39, '339'),
	(243, 1, 0, -50941, 341, 0, 0, 39, '340'),
	(243, 1, 0, -50941, 342, 0, 0, 39, '341'),
	(243, 1, 0, -50941, 343, 0, 0, 39, '342'),
	(243, 1, 0, -50941, 344, 0, 0, 39, '343'),
	(243, 1, 0, -50941, 345, 0, 0, 39, '344'),
	(243, 1, 0, -50941, 346, 0, 0, 39, '345'),
	(243, 1, 0, -50941, 347, 0, 0, 39, '346'),
	(243, 1, 0, -50941, 348, 0, 0, 39, '347'),
	(243, 1, 0, -50941, 349, 0, 0, 39, '348'),
	(243, 1, 0, -50941, 350, 0, 0, 39, '349'),
	(243, 1, 0, -50941, 351, 0, 0, 39, '350'),
	(243, 1, 0, -50941, 352, 0, 0, 39, '351'),
	(243, 1, 0, -50941, 353, 0, 0, 39, '352'),
	(243, 1, 0, -50941, 354, 0, 0, 39, '353'),
	(243, 1, 0, -50941, 355, 0, 0, 39, '354'),
	(243, 1, 0, -50941, 356, 0, 0, 39, '355'),
	(243, 1, 0, -50941, 357, 0, 0, 39, '356'),
	(243, 1, 0, -50941, 358, 0, 0, 39, '357'),
	(243, 1, 0, -50941, 359, 0, 0, 39, '358'),
	(243, 1, 0, -50941, 360, 0, 0, 39, '359'),
	(243, 1, 0, -50941, 361, 0, 0, 39, '360'),
	(243, 1, 0, -50941, 362, 0, 0, 39, '361'),
	(243, 1, 0, -50941, 363, 0, 0, 39, '362'),
	(243, 1, 0, -50941, 364, 0, 0, 39, '363'),
	(243, 1, 0, -50941, 365, 0, 0, 39, '364'),
	(243, 1, 0, -50941, 366, 0, 0, 39, '365'),
	(243, 1, 0, -50941, 367, 0, 0, 39, '366'),
	(243, 1, 0, -50941, 368, 0, 0, 39, '367'),
	(243, 1, 0, -50941, 369, 0, 0, 39, '368'),
	(243, 1, 0, -50941, 370, 0, 0, 39, '369'),
	(243, 1, 0, -50941, 371, 0, 0, 39, '370'),
	(243, 1, 0, -50941, 372, 0, 0, 39, '371'),
	(243, 1, 0, -50941, 373, 0, 0, 39, '372'),
	(243, 1, 0, -50941, 374, 0, 0, 39, '373'),
	(243, 1, 0, -50941, 375, 0, 0, 39, '374'),
	(243, 1, 0, -50941, 376, 0, 0, 39, '375'),
	(243, 1, 0, -50941, 377, 0, 0, 39, '376'),
	(243, 1, 0, -50941, 378, 0, 0, 39, '377'),
	(243, 1, 0, -50941, 379, 0, 0, 39, '378'),
	(243, 1, 0, -50941, 380, 0, 0, 39, '379'),
	(243, 1, 0, -50941, 381, 0, 0, 39, '380'),
	(243, 1, 0, -50941, 382, 0, 0, 39, '381'),
	(243, 1, 0, -50941, 383, 0, 0, 39, '382'),
	(243, 1, 0, -50941, 384, 0, 0, 39, '383'),
	(243, 1, 0, -50941, 385, 0, 0, 39, '384'),
	(243, 1, 0, -50941, 386, 0, 0, 39, '385'),
	(243, 1, 0, -50941, 387, 0, 0, 39, '386'),
	(243, 1, 0, -50941, 388, 0, 0, 39, '387'),
	(243, 1, 0, -50941, 389, 0, 0, 39, '388'),
	(243, 1, 0, -50941, 390, 0, 0, 39, '389'),
	(243, 1, 0, -50941, 391, 0, 0, 39, '390'),
	(243, 1, 0, -50941, 392, 0, 0, 39, '391'),
	(243, 1, 0, -50941, 393, 0, 0, 39, '392'),
	(243, 1, 0, -50941, 394, 0, 0, 39, '393'),
	(243, 1, 0, -50941, 395, 0, 0, 39, '394'),
	(243, 1, 0, -50941, 396, 0, 0, 39, '395'),
	(243, 1, 0, -50941, 397, 0, 0, 39, '396'),
	(243, 1, 0, -50941, 398, 0, 0, 39, '397'),
	(243, 1, 0, -50941, 399, 0, 0, 39, '398'),
	(243, 1, 0, -50941, 400, 0, 0, 39, '399'),
	(243, 1, 0, -50941, 401, 0, 0, 39, '400'),
	(243, 1, 0, -50941, 402, 0, 0, 39, '401'),
	(243, 1, 0, -50941, 403, 0, 0, 39, '402'),
	(243, 1, 0, -50941, 404, 0, 0, 39, '403'),
	(243, 1, 0, -50941, 405, 0, 0, 39, '404'),
	(243, 1, 0, -50941, 406, 0, 0, 39, '405'),
	(243, 1, 0, -50941, 407, 0, 0, 39, '406'),
	(243, 1, 0, -50941, 408, 0, 0, 39, '407'),
	(243, 1, 0, -50941, 409, 0, 0, 39, '408'),
	(243, 1, 0, -50941, 410, 0, 0, 39, '409'),
	(243, 1, 0, -50941, 411, 0, 0, 39, '410'),
	(243, 1, 0, -50941, 412, 0, 0, 39, '411'),
	(243, 1, 0, -50941, 413, 0, 0, 39, '412'),
	(243, 1, 0, -50941, 414, 0, 0, 39, '413'),
	(243, 1, 0, -50941, 415, 0, 0, 39, '414'),
	(243, 1, 0, -50941, 416, 0, 0, 39, '415'),
	(243, 1, 0, -50941, 417, 0, 0, 39, '416'),
	(243, 1, 0, -50941, 418, 0, 0, 39, '417'),
	(243, 1, 0, -50941, 419, 0, 0, 39, '418'),
	(243, 1, 0, -50941, 420, 0, 0, 39, '419'),
	(243, 1, 0, -50941, 421, 0, 0, 39, '420'),
	(243, 1, 0, -50941, 422, 0, 0, 39, '421'),
	(243, 1, 0, -50941, 423, 0, 0, 39, '422'),
	(243, 1, 0, -50941, 424, 0, 0, 39, '423'),
	(243, 1, 0, -50941, 425, 0, 0, 39, '424'),
	(243, 1, 0, -50941, 426, 0, 0, 39, '425'),
	(243, 1, 0, -50941, 427, 0, 0, 39, '426'),
	(243, 1, 0, -50941, 428, 0, 0, 39, '427'),
	(243, 1, 0, -50941, 429, 0, 0, 39, '428'),
	(243, 1, 0, -50941, 430, 0, 0, 39, '429'),
	(243, 1, 0, -50941, 431, 0, 0, 39, '430'),
	(243, 1, 0, -50941, 432, 0, 0, 39, '431'),
	(243, 1, 0, -50941, 433, 0, 0, 39, '432'),
	(243, 1, 0, -50941, 434, 0, 0, 39, '433'),
	(243, 1, 0, -50941, 435, 0, 0, 39, '434'),
	(243, 1, 0, -50941, 436, 0, 0, 39, '435'),
	(243, 1, 0, -50941, 437, 0, 0, 39, '436'),
	(243, 1, 0, -50941, 438, 0, 0, 39, '437'),
	(243, 1, 0, -50941, 439, 0, 0, 39, '438'),
	(243, 1, 0, -50941, 440, 0, 0, 39, '439'),
	(243, 1, 0, -50941, 441, 0, 0, 39, '440'),
	(243, 1, 0, -50941, 442, 0, 0, 39, '441'),
	(243, 1, 0, -50941, 443, 0, 0, 39, '442'),
	(243, 1, 0, -50941, 444, 0, 0, 39, '443'),
	(243, 1, 0, -50941, 445, 0, 0, 39, '444'),
	(243, 1, 0, -50941, 446, 0, 0, 39, '445'),
	(243, 1, 0, -50941, 447, 0, 0, 39, '446'),
	(243, 1, 0, -50941, 448, 0, 0, 39, '447'),
	(243, 1, 0, -50941, 449, 0, 0, 39, '448'),
	(243, 1, 0, -50941, 450, 0, 0, 39, '449'),
	(243, 1, 0, -50941, 451, 0, 0, 39, '450'),
	(243, 1, 0, -50941, 452, 0, 0, 39, '451'),
	(243, 1, 0, -50941, 453, 0, 0, 39, '452'),
	(243, 1, 0, -50941, 454, 0, 0, 39, '453'),
	(243, 1, 0, -50941, 455, 0, 0, 39, '454'),
	(243, 1, 0, -50941, 456, 0, 0, 39, '455'),
	(243, 1, 0, -50941, 457, 0, 0, 39, '456'),
	(243, 1, 0, -50941, 458, 0, 0, 39, '457'),
	(243, 1, 0, -50941, 459, 0, 0, 39, '458'),
	(243, 1, 0, -50941, 460, 0, 0, 39, '459'),
	(243, 1, 0, -50941, 461, 0, 0, 39, '460'),
	(243, 1, 0, -50941, 462, 0, 0, 39, '461'),
	(243, 1, 0, -50941, 463, 0, 0, 39, '462'),
	(243, 1, 0, -50941, 464, 0, 0, 39, '463'),
	(243, 1, 0, -50941, 465, 0, 0, 39, '464'),
	(243, 1, 0, -50941, 466, 0, 0, 39, '465'),
	(243, 1, 0, -50941, 467, 0, 0, 39, '466'),
	(243, 1, 0, -50941, 468, 0, 0, 39, '467'),
	(243, 1, 0, -50941, 469, 0, 0, 39, '468'),
	(243, 1, 0, -50941, 470, 0, 0, 39, '469'),
	(243, 1, 0, -50941, 471, 0, 0, 39, '470'),
	(243, 1, 0, -50941, 472, 0, 0, 39, '471'),
	(243, 1, 0, -50941, 473, 0, 0, 39, '472'),
	(243, 1, 0, -50941, 474, 0, 0, 39, '473'),
	(243, 1, 0, -50941, 475, 0, 0, 39, '474'),
	(243, 1, 0, -50941, 476, 0, 0, 39, '475'),
	(243, 1, 0, -50941, 477, 0, 0, 39, '476'),
	(243, 1, 0, -50941, 478, 0, 0, 39, '477'),
	(243, 1, 0, -50941, 479, 0, 0, 39, '478'),
	(243, 1, 0, -50941, 480, 0, 0, 39, '479'),
	(243, 1, 0, -50941, 481, 0, 0, 39, '480'),
	(243, 1, 0, -50941, 482, 0, 0, 39, '481'),
	(243, 1, 0, -50941, 483, 0, 0, 39, '482'),
	(243, 1, 0, -50941, 484, 0, 0, 39, '483'),
	(243, 1, 0, -50941, 485, 0, 0, 39, '484'),
	(243, 1, 0, -50941, 486, 0, 0, 39, '485'),
	(243, 1, 0, -50941, 487, 0, 0, 39, '486'),
	(243, 1, 0, -50941, 488, 0, 0, 39, '487'),
	(243, 1, 0, -50941, 489, 0, 0, 39, '488'),
	(243, 1, 0, -50941, 490, 0, 0, 39, '489'),
	(243, 1, 0, -50941, 491, 0, 0, 39, '490'),
	(243, 1, 0, -50941, 492, 0, 0, 39, '491'),
	(243, 1, 0, -50941, 493, 0, 0, 39, '492'),
	(243, 1, 0, -50941, 494, 0, 0, 39, '493'),
	(243, 1, 0, -50941, 495, 0, 0, 39, '494'),
	(243, 1, 0, -50941, 496, 0, 0, 39, '495'),
	(243, 1, 0, -50941, 497, 0, 0, 39, '496'),
	(243, 1, 0, -50941, 498, 0, 0, 39, '497'),
	(243, 1, 0, -50941, 499, 0, 0, 39, '498'),
	(243, 1, 0, -50941, 500, 0, 0, 39, '499'),
	(243, 1, 0, -50941, 501, 0, 0, 39, '500'),
	(243, 1, 0, -50941, 502, 0, 0, 39, '501'),
	(243, 1, 0, -50941, 503, 0, 0, 39, '502'),
	(243, 1, 0, -50941, 504, 0, 0, 39, '503'),
	(243, 1, 0, -50941, 505, 0, 0, 39, '504'),
	(243, 1, 0, -50941, 506, 0, 0, 39, '505'),
	(243, 1, 0, -50941, 507, 0, 0, 39, '506'),
	(243, 1, 0, -50941, 508, 0, 0, 39, '507'),
	(243, 1, 0, -50941, 509, 0, 0, 39, '508'),
	(243, 1, 0, -50941, 510, 0, 0, 39, '509'),
	(243, 1, 0, -50941, 511, 0, 0, 39, '510'),
	(243, 1, 0, -50941, 512, 0, 0, 39, '511'),
	(243, 1, 0, -50941, 513, 0, 0, 39, '512'),
	(243, 1, 0, -50941, 514, 0, 0, 39, '513'),
	(243, 1, 0, -50941, 515, 0, 0, 39, '514'),
	(243, 1, 0, -50941, 516, 0, 0, 39, '515'),
	(243, 1, 0, -50941, 517, 0, 0, 39, '516'),
	(243, 1, 0, -50941, 518, 0, 0, 39, '517'),
	(243, 1, 0, -50941, 519, 0, 0, 39, '518'),
	(243, 1, 0, -50941, 520, 0, 0, 39, '519'),
	(243, 1, 0, -50941, 521, 0, 0, 39, '520'),
	(243, 1, 0, -50941, 522, 0, 0, 39, '521'),
	(243, 1, 0, -50941, 523, 0, 0, 39, '522'),
	(243, 1, 0, -50941, 524, 0, 0, 39, '523'),
	(243, 1, 0, -50941, 525, 0, 0, 39, '524'),
	(243, 1, 0, -50941, 526, 0, 0, 39, '525'),
	(243, 1, 0, -50941, 527, 0, 0, 39, '526'),
	(243, 1, 0, -50941, 528, 0, 0, 39, '527'),
	(243, 1, 0, -50941, 529, 0, 0, 39, '528'),
	(243, 1, 0, -50941, 530, 0, 0, 39, '529'),
	(243, 1, 0, -50941, 531, 0, 0, 39, '530'),
	(243, 1, 0, -50941, 532, 0, 0, 39, '531'),
	(243, 1, 0, -50941, 533, 0, 0, 39, '532'),
	(243, 1, 0, -50941, 534, 0, 0, 39, '533'),
	(243, 1, 0, -50941, 535, 0, 0, 39, '534'),
	(243, 1, 0, -50941, 536, 0, 0, 39, '535'),
	(243, 1, 0, -50941, 537, 0, 0, 39, '536'),
	(243, 1, 0, -50941, 538, 0, 0, 39, '537'),
	(243, 1, 0, -50941, 539, 0, 0, 39, '538'),
	(243, 1, 0, -50941, 540, 0, 0, 39, '539'),
	(243, 1, 0, -50941, 541, 0, 0, 39, '540'),
	(243, 1, 0, -50941, 542, 0, 0, 39, '541'),
	(243, 1, 0, -50941, 543, 0, 0, 39, '542'),
	(243, 1, 0, -50941, 544, 0, 0, 39, '543'),
	(243, 1, 0, -50941, 545, 0, 0, 39, '544'),
	(243, 1, 0, -50941, 546, 0, 0, 39, '545'),
	(243, 1, 0, -50941, 547, 0, 0, 39, '546'),
	(243, 1, 0, -50941, 548, 0, 0, 39, '547'),
	(243, 1, 0, -50941, 549, 0, 0, 39, '548'),
	(243, 1, 0, -50941, 550, 0, 0, 39, '549'),
	(243, 1, 0, -50941, 551, 0, 0, 39, '550'),
	(243, 1, 0, -50941, 552, 0, 0, 39, '551'),
	(243, 1, 0, -50941, 553, 0, 0, 39, '552'),
	(243, 1, 0, -50941, 554, 0, 0, 39, '553'),
	(243, 1, 0, -50941, 555, 0, 0, 39, '554'),
	(243, 1, 0, -50941, 556, 0, 0, 39, '555'),
	(243, 1, 0, -50941, 557, 0, 0, 39, '556'),
	(243, 1, 0, -50941, 558, 0, 0, 39, '557'),
	(243, 1, 0, -50941, 559, 0, 0, 39, '558'),
	(243, 1, 0, -50941, 560, 0, 0, 39, '559'),
	(243, 1, 0, -50941, 561, 0, 0, 39, '560'),
	(243, 1, 0, -50941, 562, 0, 0, 39, '561'),
	(243, 1, 0, -50941, 563, 0, 0, 39, '562'),
	(243, 1, 0, -50941, 564, 0, 0, 39, '563'),
	(243, 1, 0, -50941, 565, 0, 0, 39, '564'),
	(243, 1, 0, -50941, 566, 0, 0, 39, '565'),
	(243, 1, 0, -50941, 567, 0, 0, 39, '566'),
	(243, 1, 0, -50941, 568, 0, 0, 39, '567'),
	(243, 1, 0, -50941, 569, 0, 0, 39, '568'),
	(243, 1, 0, -50941, 570, 0, 0, 39, '569'),
	(243, 1, 0, -50941, 571, 0, 0, 39, '570'),
	(243, 1, 0, -50941, 572, 0, 0, 39, '571'),
	(243, 1, 0, -50941, 573, 0, 0, 39, '572'),
	(243, 1, 0, -50941, 574, 0, 0, 39, '573'),
	(243, 1, 0, -50941, 575, 0, 0, 39, '574'),
	(243, 1, 0, -50941, 576, 0, 0, 39, '575'),
	(243, 1, 0, -50941, 577, 0, 0, 39, '576'),
	(243, 1, 0, -50941, 578, 0, 0, 39, '577'),
	(243, 1, 0, -50941, 579, 0, 0, 39, '578'),
	(243, 1, 0, -50941, 580, 0, 0, 39, '579'),
	(243, 1, 0, -50941, 581, 0, 0, 39, '580'),
	(243, 1, 0, -50941, 582, 0, 0, 39, '581'),
	(243, 1, 0, -50941, 583, 0, 0, 39, '582'),
	(243, 1, 0, -50941, 584, 0, 0, 39, '583'),
	(243, 1, 0, -50941, 585, 0, 0, 39, '584'),
	(243, 1, 0, -50941, 586, 0, 0, 39, '585'),
	(243, 1, 0, -50941, 587, 0, 0, 39, '586'),
	(243, 1, 0, -50941, 588, 0, 0, 39, '587'),
	(243, 1, 0, -50941, 589, 0, 0, 39, '588'),
	(243, 1, 0, -50941, 590, 0, 0, 39, '589'),
	(243, 1, 0, -50941, 591, 0, 0, 39, '590'),
	(243, 1, 0, -50941, 592, 0, 0, 39, '591'),
	(243, 1, 0, -50941, 593, 0, 0, 39, '592'),
	(243, 1, 0, -50941, 594, 0, 0, 39, '593'),
	(243, 1, 0, -50941, 595, 0, 0, 39, '594'),
	(243, 1, 0, -50941, 596, 0, 0, 39, '595'),
	(243, 1, 0, -50941, 597, 0, 0, 39, '596'),
	(243, 1, 0, -50941, 598, 0, 0, 39, '597'),
	(243, 1, 0, -50941, 599, 0, 0, 39, '598'),
	(243, 1, 0, -50941, 600, 0, 0, 39, '599'),
	(243, 1, 0, -50941, 601, 0, 0, 39, '600'),
	(243, 1, 0, -50941, 602, 0, 0, 39, '601'),
	(243, 1, 0, -50941, 603, 0, 0, 39, '602'),
	(243, 1, 0, -50941, 604, 0, 0, 39, '603'),
	(243, 1, 0, -50941, 605, 0, 0, 39, '604'),
	(243, 1, 0, -50941, 606, 0, 0, 39, '605'),
	(243, 1, 0, -50941, 607, 0, 0, 39, '606'),
	(243, 1, 0, -50941, 608, 0, 0, 39, '607'),
	(243, 1, 0, -50941, 609, 0, 0, 39, '608'),
	(243, 1, 0, -50941, 610, 0, 0, 39, '609'),
	(243, 1, 0, -50941, 611, 0, 0, 39, '610'),
	(243, 1, 0, -50941, 612, 0, 0, 39, '611'),
	(243, 1, 0, -50941, 613, 0, 0, 39, '612'),
	(243, 1, 0, -50941, 614, 0, 0, 39, '613'),
	(243, 1, 0, -50941, 615, 0, 0, 39, '614'),
	(243, 1, 0, -50941, 616, 0, 0, 39, '615'),
	(243, 1, 0, -50941, 617, 0, 0, 39, '616'),
	(243, 1, 0, -50941, 618, 0, 0, 39, '617'),
	(243, 1, 0, -50941, 619, 0, 0, 39, '618'),
	(243, 1, 0, -50941, 620, 0, 0, 39, '619'),
	(243, 1, 0, -50941, 621, 0, 0, 39, '620'),
	(243, 1, 0, -50941, 622, 0, 0, 39, '621'),
	(243, 1, 0, -50941, 623, 0, 0, 39, '622'),
	(243, 1, 0, -50941, 624, 0, 0, 39, '623'),
	(243, 1, 0, -50941, 625, 0, 0, 39, '624'),
	(243, 1, 0, -50941, 626, 0, 0, 39, '625'),
	(243, 1, 0, -50941, 627, 0, 0, 39, '626'),
	(243, 1, 0, -50941, 628, 0, 0, 39, '627'),
	(243, 1, 0, -50941, 629, 0, 0, 39, '628'),
	(243, 1, 0, -50941, 630, 0, 0, 39, '629'),
	(243, 1, 0, -50941, 631, 0, 0, 39, '630'),
	(243, 1, 0, -50941, 632, 0, 0, 39, '631'),
	(243, 1, 0, -50941, 633, 0, 0, 39, '632'),
	(243, 1, 0, -50941, 634, 0, 0, 39, '633'),
	(243, 1, 0, -50941, 635, 0, 0, 39, '634'),
	(243, 1, 0, -50941, 636, 0, 0, 39, '635'),
	(243, 1, 0, -50941, 637, 0, 0, 39, '636'),
	(243, 1, 0, -50941, 638, 0, 0, 39, '637'),
	(243, 1, 0, -50941, 639, 0, 0, 39, '638'),
	(243, 1, 0, -50941, 640, 0, 0, 39, '639'),
	(243, 1, 0, -50941, 641, 0, 0, 39, '640'),
	(243, 1, 0, -50941, 642, 0, 0, 39, '641'),
	(243, 1, 0, -50941, 643, 0, 0, 39, '642'),
	(243, 1, 0, -50941, 644, 0, 0, 39, '643'),
	(243, 1, 0, -50941, 645, 0, 0, 39, '644'),
	(243, 1, 0, -50941, 646, 0, 0, 39, '645'),
	(243, 1, 0, -50941, 647, 0, 0, 39, '646'),
	(243, 1, 0, -50941, 648, 0, 0, 39, '647'),
	(243, 1, 0, -50941, 649, 0, 0, 39, '648'),
	(243, 1, 0, -50941, 650, 0, 0, 39, '649'),
	(243, 1, 0, -50941, 651, 0, 0, 39, '650'),
	(243, 1, 0, -50941, 652, 0, 0, 39, '651'),
	(243, 1, 0, -50941, 653, 0, 0, 39, '652'),
	(243, 1, 0, -50941, 654, 0, 0, 39, '653'),
	(243, 1, 0, -50941, 655, 0, 0, 39, '654'),
	(243, 1, 0, -50941, 656, 0, 0, 39, '655'),
	(243, 1, 0, -50941, 657, 0, 0, 39, '656'),
	(243, 1, 0, -50941, 658, 0, 0, 39, '657'),
	(243, 1, 0, -50941, 659, 0, 0, 39, '658'),
	(243, 1, 0, -50941, 660, 0, 0, 39, '659'),
	(243, 1, 0, -50941, 661, 0, 0, 39, '660'),
	(243, 1, 0, -50941, 662, 0, 0, 39, '661'),
	(243, 1, 0, -50941, 663, 0, 0, 39, '662'),
	(243, 1, 0, -50941, 664, 0, 0, 39, '663'),
	(243, 1, 0, -50941, 665, 0, 0, 39, '664'),
	(243, 1, 0, -50941, 666, 0, 0, 39, '665'),
	(243, 1, 0, -50941, 667, 0, 0, 39, '666'),
	(243, 1, 0, -50941, 668, 0, 0, 39, '667'),
	(243, 1, 0, -50941, 669, 0, 0, 39, '668'),
	(243, 1, 0, -50941, 670, 0, 0, 39, '669'),
	(243, 1, 0, -50941, 671, 0, 0, 39, '670'),
	(243, 1, 0, -50941, 672, 0, 0, 39, '671'),
	(243, 1, 0, -50941, 673, 0, 0, 39, '672'),
	(243, 1, 0, -50941, 674, 0, 0, 39, '673'),
	(243, 1, 0, -50941, 675, 0, 0, 39, '674'),
	(243, 1, 0, -50941, 676, 0, 0, 39, '675'),
	(243, 1, 0, -50941, 677, 0, 0, 39, '676'),
	(243, 1, 0, -50941, 678, 0, 0, 39, '677'),
	(243, 1, 0, -50941, 679, 0, 0, 39, '678'),
	(243, 1, 0, -50941, 680, 0, 0, 39, '679'),
	(243, 1, 0, -50941, 681, 0, 0, 39, '680'),
	(243, 1, 0, -50941, 682, 0, 0, 39, '681'),
	(243, 1, 0, -50941, 683, 0, 0, 39, '682'),
	(243, 1, 0, -50941, 684, 0, 0, 39, '683'),
	(243, 1, 0, -50941, 685, 0, 0, 39, '684'),
	(243, 1, 0, -50941, 686, 0, 0, 39, '685'),
	(243, 1, 0, -50941, 687, 0, 0, 39, '686'),
	(243, 1, 0, -50941, 688, 0, 0, 39, '687'),
	(243, 1, 0, -50941, 689, 0, 0, 39, '688'),
	(243, 1, 0, -50941, 690, 0, 0, 39, '689'),
	(243, 1, 0, -50941, 691, 0, 0, 39, '690'),
	(243, 1, 0, -50941, 692, 0, 0, 39, '691'),
	(243, 1, 0, -50941, 693, 0, 0, 39, '692'),
	(243, 1, 0, -50941, 694, 0, 0, 39, '693'),
	(243, 1, 0, -50941, 695, 0, 0, 39, '694'),
	(243, 1, 0, -50941, 696, 0, 0, 39, '695'),
	(243, 1, 0, -50941, 697, 0, 0, 39, '696'),
	(243, 1, 0, -50941, 698, 0, 0, 39, '697'),
	(243, 1, 0, -50941, 699, 0, 0, 39, '698'),
	(243, 1, 0, -50941, 700, 0, 0, 39, '699'),
	(243, 1, 0, -50941, 701, 0, 0, 39, '700'),
	(243, 1, 0, -50941, 702, 0, 0, 39, '701'),
	(243, 1, 0, -50941, 703, 0, 0, 39, '702'),
	(243, 1, 0, -50941, 704, 0, 0, 39, '703'),
	(243, 1, 0, -50941, 705, 0, 0, 39, '704'),
	(243, 1, 0, -50941, 706, 0, 0, 39, '705'),
	(243, 1, 0, -50941, 707, 0, 0, 39, '706'),
	(243, 1, 0, -50941, 708, 0, 0, 39, '707'),
	(243, 1, 0, -50941, 709, 0, 0, 39, '708'),
	(243, 1, 0, -50941, 710, 0, 0, 39, '709'),
	(243, 1, 0, -50941, 711, 0, 0, 39, '710'),
	(243, 1, 0, -50941, 712, 0, 0, 39, '711'),
	(243, 1, 0, -50941, 713, 0, 0, 39, '712'),
	(243, 1, 0, -50941, 714, 0, 0, 39, '713'),
	(243, 1, 0, -50941, 715, 0, 0, 39, '714'),
	(243, 1, 0, -50941, 716, 0, 0, 39, '715'),
	(243, 1, 0, -50941, 717, 0, 0, 39, '716'),
	(243, 1, 0, -50941, 718, 0, 0, 39, '717'),
	(243, 1, 0, -50941, 719, 0, 0, 39, '718'),
	(243, 1, 0, -50941, 720, 0, 0, 39, '719'),
	(243, 1, 0, -50941, 721, 0, 0, 39, '720'),
	(243, 1, 0, -50941, 722, 0, 0, 39, '721'),
	(243, 1, 0, -50941, 723, 0, 0, 39, '722'),
	(243, 1, 0, -50941, 724, 0, 0, 39, '723'),
	(243, 1, 0, -50941, 725, 0, 0, 39, '724'),
	(243, 1, 0, -50941, 726, 0, 0, 39, '725'),
	(243, 1, 0, -50941, 727, 0, 0, 39, '726'),
	(243, 1, 0, -50941, 728, 0, 0, 39, '727'),
	(243, 1, 0, -50941, 729, 0, 0, 39, '728'),
	(243, 1, 0, -50941, 730, 0, 0, 39, '729'),
	(243, 1, 0, -50941, 731, 0, 0, 39, '730'),
	(243, 1, 0, -50941, 732, 0, 0, 39, '731'),
	(243, 1, 0, -50941, 733, 0, 0, 39, '732'),
	(243, 1, 0, -50941, 734, 0, 0, 39, '733'),
	(243, 1, 0, -50941, 735, 0, 0, 39, '734'),
	(243, 1, 0, -50941, 736, 0, 0, 39, '735'),
	(243, 1, 0, -50941, 737, 0, 0, 39, '736'),
	(243, 1, 0, -50941, 738, 0, 0, 39, '737'),
	(243, 1, 0, -50941, 739, 0, 0, 39, '738'),
	(243, 1, 0, -50941, 740, 0, 0, 39, '739'),
	(243, 1, 0, -50941, 741, 0, 0, 39, '740'),
	(243, 1, 0, -50941, 742, 0, 0, 39, '741'),
	(243, 1, 0, -50941, 743, 0, 0, 39, '742'),
	(243, 1, 0, -50941, 744, 0, 0, 39, '743'),
	(243, 1, 0, -50941, 745, 0, 0, 39, '744'),
	(243, 1, 0, -50941, 746, 0, 0, 39, '745'),
	(243, 1, 0, -50941, 747, 0, 0, 39, '746'),
	(243, 1, 0, -50941, 748, 0, 0, 39, '747'),
	(243, 1, 0, -50941, 749, 0, 0, 39, '748'),
	(243, 1, 0, -50941, 750, 0, 0, 39, '749'),
	(243, 1, 0, -50941, 751, 0, 0, 39, '750'),
	(243, 1, 0, -50941, 752, 0, 0, 39, '751'),
	(243, 1, 0, -50941, 753, 0, 0, 39, '752'),
	(243, 1, 0, -50941, 754, 0, 0, 39, '753'),
	(243, 1, 0, -50941, 755, 0, 0, 39, '754'),
	(243, 1, 0, -50941, 756, 0, 0, 39, '755'),
	(243, 1, 0, -50941, 757, 0, 0, 39, '756'),
	(243, 1, 0, -50941, 758, 0, 0, 39, '757'),
	(243, 1, 0, -50941, 759, 0, 0, 39, '758'),
	(243, 1, 0, -50941, 760, 0, 0, 39, '759'),
	(243, 1, 0, -50941, 761, 0, 0, 39, '760'),
	(243, 1, 0, -50941, 762, 0, 0, 39, '761'),
	(243, 1, 0, -50941, 763, 0, 0, 39, '762'),
	(243, 1, 0, -50941, 764, 0, 0, 39, '763'),
	(243, 1, 0, -50941, 765, 0, 0, 39, '764'),
	(243, 1, 0, -50941, 766, 0, 0, 39, '765'),
	(243, 1, 0, -50941, 767, 0, 0, 39, '766'),
	(243, 1, 0, -50941, 768, 0, 0, 39, '767'),
	(243, 1, 0, -50941, 769, 0, 0, 39, '768'),
	(243, 1, 0, -50941, 770, 0, 0, 39, '769'),
	(243, 1, 0, -50941, 771, 0, 0, 39, '770'),
	(243, 1, 0, -50941, 772, 0, 0, 39, '771'),
	(243, 1, 0, -50941, 773, 0, 0, 39, '772'),
	(243, 1, 0, -50941, 774, 0, 0, 39, '773'),
	(243, 1, 0, -50941, 775, 0, 0, 39, '774'),
	(243, 1, 0, -50941, 776, 0, 0, 39, '775'),
	(243, 1, 0, -50941, 777, 0, 0, 39, '776'),
	(243, 1, 0, -50941, 778, 0, 0, 39, '777'),
	(243, 1, 0, -50941, 779, 0, 0, 39, '778'),
	(243, 1, 0, -50941, 780, 0, 0, 39, '779'),
	(243, 1, 0, -50941, 781, 0, 0, 39, '780'),
	(243, 1, 0, -50941, 782, 0, 0, 39, '781'),
	(243, 1, 0, -50941, 783, 0, 0, 39, '782'),
	(243, 1, 0, -50941, 784, 0, 0, 39, '783'),
	(243, 1, 0, -50941, 785, 0, 0, 39, '784'),
	(243, 1, 0, -50941, 786, 0, 0, 39, '785'),
	(243, 1, 0, -50941, 787, 0, 0, 39, '786'),
	(243, 1, 0, -50941, 788, 0, 0, 39, '787'),
	(243, 1, 0, -50941, 789, 0, 0, 39, '788'),
	(243, 1, 0, -50941, 790, 0, 0, 39, '789'),
	(243, 1, 0, -50941, 791, 0, 0, 39, '790'),
	(243, 1, 0, -50941, 792, 0, 0, 39, '791'),
	(243, 1, 0, -50941, 793, 0, 0, 39, '792'),
	(243, 1, 0, -50941, 794, 0, 0, 39, '793'),
	(243, 1, 0, -50941, 795, 0, 0, 39, '794'),
	(243, 1, 0, -50941, 796, 0, 0, 39, '795'),
	(243, 1, 0, -50941, 797, 0, 0, 39, '796'),
	(243, 1, 0, -50941, 798, 0, 0, 39, '797'),
	(243, 1, 0, -50941, 799, 0, 0, 39, '798'),
	(243, 1, 0, -50941, 800, 0, 0, 39, '799'),
	(243, 1, 0, -50941, 801, 0, 0, 39, '800'),
	(243, 1, 0, -50941, 802, 0, 0, 39, '801'),
	(243, 1, 0, -50941, 803, 0, 0, 39, '802'),
	(243, 1, 0, -50941, 804, 0, 0, 39, '803'),
	(243, 1, 0, -50941, 805, 0, 0, 39, '804'),
	(243, 1, 0, -50941, 806, 0, 0, 39, '805'),
	(243, 1, 0, -50941, 807, 0, 0, 39, '806'),
	(243, 1, 0, -50941, 808, 0, 0, 39, '807'),
	(243, 1, 0, -50941, 809, 0, 0, 39, '808'),
	(243, 1, 0, -50941, 810, 0, 0, 39, '809'),
	(243, 1, 0, -50941, 811, 0, 0, 39, '810'),
	(243, 1, 0, -50941, 812, 0, 0, 39, '811'),
	(243, 1, 0, -50941, 813, 0, 0, 39, '812'),
	(243, 1, 0, -50941, 814, 0, 0, 39, '813'),
	(243, 1, 0, -50941, 815, 0, 0, 39, '814'),
	(243, 1, 0, -50941, 816, 0, 0, 39, '815'),
	(243, 1, 0, -50941, 817, 0, 0, 39, '816'),
	(243, 1, 0, -50941, 818, 0, 0, 39, '817'),
	(243, 1, 0, -50941, 819, 0, 0, 39, '818'),
	(243, 1, 0, -50941, 820, 0, 0, 39, '819'),
	(243, 1, 0, -50941, 821, 0, 0, 39, '820'),
	(243, 1, 0, -50941, 822, 0, 0, 39, '821'),
	(243, 1, 0, -50941, 823, 0, 0, 39, '822'),
	(243, 1, 0, -50941, 824, 0, 0, 39, '823'),
	(243, 1, 0, -50941, 825, 0, 0, 39, '824'),
	(243, 1, 0, -50941, 826, 0, 0, 39, '825'),
	(243, 1, 0, -50941, 827, 0, 0, 39, '826'),
	(243, 1, 0, -50941, 828, 0, 0, 39, '827'),
	(243, 1, 0, -50941, 829, 0, 0, 39, '828'),
	(243, 1, 0, -50941, 830, 0, 0, 39, '829'),
	(243, 1, 0, -50941, 831, 0, 0, 39, '830'),
	(243, 1, 0, -50941, 832, 0, 0, 39, '831'),
	(243, 1, 0, -50941, 833, 0, 0, 39, '832'),
	(243, 1, 0, -50941, 834, 0, 0, 39, '833'),
	(243, 1, 0, -50941, 835, 0, 0, 39, '834'),
	(243, 1, 0, -50941, 836, 0, 0, 39, '835'),
	(243, 1, 0, -50941, 837, 0, 0, 39, '836'),
	(243, 1, 0, -50941, 838, 0, 0, 39, '837'),
	(243, 1, 0, -50941, 839, 0, 0, 39, '838'),
	(243, 1, 0, -50941, 840, 0, 0, 39, '839'),
	(243, 1, 0, -50941, 841, 0, 0, 39, '840'),
	(243, 1, 0, -50941, 842, 0, 0, 39, '841'),
	(243, 1, 0, -50941, 843, 0, 0, 39, '842'),
	(243, 1, 0, -50941, 844, 0, 0, 39, '843'),
	(243, 1, 0, -50941, 845, 0, 0, 39, '844'),
	(243, 1, 0, -50941, 846, 0, 0, 39, '845'),
	(243, 1, 0, -50941, 847, 0, 0, 39, '846'),
	(243, 1, 0, -50941, 848, 0, 0, 39, '847'),
	(243, 1, 0, -50941, 849, 0, 0, 39, '848'),
	(243, 1, 0, -50941, 850, 0, 0, 39, '849'),
	(243, 1, 0, -50941, 851, 0, 0, 39, '850'),
	(243, 1, 0, -50941, 852, 0, 0, 39, '851'),
	(243, 1, 0, -50941, 853, 0, 0, 39, '852'),
	(243, 1, 0, -50941, 854, 0, 0, 39, '853'),
	(243, 1, 0, -50941, 855, 0, 0, 39, '854'),
	(243, 1, 0, -50941, 856, 0, 0, 39, '855'),
	(243, 1, 0, -50941, 857, 0, 0, 39, '856'),
	(243, 1, 0, -50941, 858, 0, 0, 39, '857'),
	(243, 1, 0, -50941, 859, 0, 0, 39, '858'),
	(243, 1, 0, -50941, 860, 0, 0, 39, '859'),
	(243, 1, 0, -50941, 861, 0, 0, 39, '860'),
	(243, 1, 0, -50941, 862, 0, 0, 39, '861'),
	(243, 1, 0, -50941, 863, 0, 0, 39, '862'),
	(243, 1, 0, -50941, 864, 0, 0, 39, '863'),
	(243, 1, 0, -50941, 865, 0, 0, 39, '864'),
	(243, 1, 0, -50941, 866, 0, 0, 39, '865'),
	(243, 1, 0, -50941, 867, 0, 0, 39, '866'),
	(243, 1, 0, -50941, 868, 0, 0, 39, '867'),
	(243, 1, 0, -50941, 869, 0, 0, 39, '868'),
	(243, 1, 0, -50941, 870, 0, 0, 39, '869'),
	(243, 1, 0, -50941, 871, 0, 0, 39, '870'),
	(243, 1, 0, -50941, 872, 0, 0, 39, '871'),
	(243, 1, 0, -50941, 873, 0, 0, 39, '872'),
	(243, 1, 0, -50941, 874, 0, 0, 39, '873'),
	(243, 1, 0, -50941, 875, 0, 0, 39, '874'),
	(243, 1, 0, -50941, 876, 0, 0, 39, '875'),
	(243, 1, 0, -50941, 877, 0, 0, 39, '876'),
	(243, 1, 0, -50941, 878, 0, 0, 39, '877'),
	(243, 1, 0, -50941, 879, 0, 0, 39, '878'),
	(243, 1, 0, -50941, 880, 0, 0, 39, '879'),
	(243, 1, 0, -50941, 881, 0, 0, 39, '880'),
	(243, 1, 0, -50941, 882, 0, 0, 39, '881'),
	(243, 1, 0, -50941, 883, 0, 0, 39, '882'),
	(243, 1, 0, -50941, 884, 0, 0, 39, '883'),
	(243, 1, 0, -50941, 885, 0, 0, 39, '884'),
	(243, 1, 0, -50941, 886, 0, 0, 39, '885'),
	(243, 1, 0, -50941, 887, 0, 0, 39, '886'),
	(243, 1, 0, -50941, 888, 0, 0, 39, '887'),
	(243, 1, 0, -50941, 889, 0, 0, 39, '888'),
	(243, 1, 0, -50941, 890, 0, 0, 39, '889'),
	(243, 1, 0, -50941, 891, 0, 0, 39, '890'),
	(243, 1, 0, -50941, 892, 0, 0, 39, '891'),
	(243, 1, 0, -50941, 893, 0, 0, 39, '892'),
	(243, 1, 0, -50941, 894, 0, 0, 39, '893'),
	(243, 1, 0, -50941, 895, 0, 0, 39, '894'),
	(243, 1, 0, -50941, 896, 0, 0, 39, '895'),
	(243, 1, 0, -50941, 897, 0, 0, 39, '896'),
	(243, 1, 0, -50941, 898, 0, 0, 39, '897'),
	(243, 1, 0, -50941, 899, 0, 0, 39, '898'),
	(243, 1, 0, -50941, 900, 0, 0, 39, '899'),
	(243, 1, 0, -50941, 901, 0, 0, 39, '900'),
	(243, 1, 0, -50941, 902, 0, 0, 39, '901'),
	(243, 1, 0, -50941, 903, 0, 0, 39, '902'),
	(243, 1, 0, -50941, 904, 0, 0, 39, '903'),
	(243, 1, 0, -50941, 905, 0, 0, 39, '904'),
	(243, 1, 0, -50941, 906, 0, 0, 39, '905'),
	(243, 1, 0, -50941, 907, 0, 0, 39, '906'),
	(243, 1, 0, -50941, 908, 0, 0, 39, '907'),
	(243, 1, 0, -50941, 909, 0, 0, 39, '908'),
	(243, 1, 0, -50941, 910, 0, 0, 39, '909'),
	(243, 1, 0, -50941, 911, 0, 0, 39, '910'),
	(243, 1, 0, -50941, 912, 0, 0, 39, '911'),
	(243, 1, 0, -50941, 913, 0, 0, 39, '912'),
	(243, 1, 0, -50941, 914, 0, 0, 39, '913'),
	(243, 1, 0, -50941, 915, 0, 0, 39, '914'),
	(243, 1, 0, -50941, 916, 0, 0, 39, '915'),
	(243, 1, 0, -50941, 917, 0, 0, 39, '916'),
	(243, 1, 0, -50941, 918, 0, 0, 39, '917'),
	(243, 1, 0, -50941, 919, 0, 0, 39, '918'),
	(243, 1, 0, -50941, 920, 0, 0, 39, '919'),
	(243, 1, 0, -50941, 921, 0, 0, 39, '920'),
	(243, 1, 0, -50941, 922, 0, 0, 39, '921'),
	(243, 1, 0, -50941, 923, 0, 0, 39, '922'),
	(243, 1, 0, -50941, 924, 0, 0, 39, '923'),
	(243, 1, 0, -50941, 925, 0, 0, 39, '924'),
	(243, 1, 0, -50941, 926, 0, 0, 39, '925'),
	(243, 1, 0, -50941, 927, 0, 0, 39, '926'),
	(243, 1, 0, -50941, 928, 0, 0, 39, '927'),
	(243, 1, 0, -50941, 929, 0, 0, 39, '928'),
	(243, 1, 0, -50941, 930, 0, 0, 39, '929'),
	(243, 1, 0, -50941, 931, 0, 0, 39, '930'),
	(243, 1, 0, -50941, 932, 0, 0, 39, '931'),
	(243, 1, 0, -50941, 933, 0, 0, 39, '932'),
	(243, 1, 0, -50941, 934, 0, 0, 39, '933'),
	(243, 1, 0, -50941, 935, 0, 0, 39, '934'),
	(243, 1, 0, -50941, 936, 0, 0, 39, '935'),
	(243, 1, 0, -50941, 937, 0, 0, 39, '936'),
	(243, 1, 0, -50941, 938, 0, 0, 39, '937'),
	(243, 1, 0, -50941, 939, 0, 0, 39, '938'),
	(243, 1, 0, -50941, 940, 0, 0, 39, '939'),
	(243, 1, 0, -50941, 941, 0, 0, 39, '940'),
	(243, 1, 0, -50941, 942, 0, 0, 39, '941'),
	(243, 1, 0, -50941, 943, 0, 0, 39, '942'),
	(243, 1, 0, -50941, 944, 0, 0, 39, '943'),
	(243, 1, 0, -50941, 945, 0, 0, 39, '944'),
	(243, 1, 0, -50941, 946, 0, 0, 39, '945'),
	(243, 1, 0, -50941, 947, 0, 0, 39, '946'),
	(243, 1, 0, -50941, 948, 0, 0, 39, '947'),
	(243, 1, 0, -50941, 949, 0, 0, 39, '948'),
	(243, 1, 0, -50941, 950, 0, 0, 39, '949'),
	(243, 1, 0, -50941, 951, 0, 0, 39, '950'),
	(243, 1, 0, -50941, 952, 0, 0, 39, '951'),
	(243, 1, 0, -50941, 953, 0, 0, 39, '952'),
	(243, 1, 0, -50941, 954, 0, 0, 39, '953'),
	(243, 1, 0, -50941, 955, 0, 0, 39, '954'),
	(243, 1, 0, -50941, 956, 0, 0, 39, '955'),
	(243, 1, 0, -50941, 957, 0, 0, 39, '956'),
	(243, 1, 0, -50941, 958, 0, 0, 39, '957'),
	(243, 1, 0, -50941, 959, 0, 0, 39, '958'),
	(243, 1, 0, -50941, 960, 0, 0, 39, '959'),
	(243, 1, 0, -50941, 961, 0, 0, 39, '960'),
	(243, 1, 0, -50941, 962, 0, 0, 39, '961'),
	(243, 1, 0, -50941, 963, 0, 0, 39, '962'),
	(243, 1, 0, -50941, 964, 0, 0, 39, '963'),
	(243, 1, 0, -50941, 965, 0, 0, 39, '964'),
	(243, 1, 0, -50941, 966, 0, 0, 39, '965'),
	(243, 1, 0, -50941, 967, 0, 0, 39, '966'),
	(243, 1, 0, -50941, 968, 0, 0, 39, '967'),
	(243, 1, 0, -50941, 969, 0, 0, 39, '968'),
	(243, 1, 0, -50941, 970, 0, 0, 39, '969'),
	(243, 1, 0, -50941, 971, 0, 0, 39, '970'),
	(243, 1, 0, -50941, 972, 0, 0, 39, '971'),
	(243, 1, 0, -50941, 973, 0, 0, 39, '972'),
	(243, 1, 0, -50941, 974, 0, 0, 39, '973'),
	(243, 1, 0, -50941, 975, 0, 0, 39, '974'),
	(243, 1, 0, -50941, 976, 0, 0, 39, '975'),
	(243, 1, 0, -50941, 977, 0, 0, 39, '976'),
	(243, 1, 0, -50941, 978, 0, 0, 39, '977'),
	(243, 1, 0, -50941, 979, 0, 0, 39, '978'),
	(243, 1, 0, -50941, 980, 0, 0, 39, '979'),
	(243, 1, 0, -50941, 981, 0, 0, 39, '980'),
	(243, 1, 0, -50941, 982, 0, 0, 39, '981'),
	(243, 1, 0, -50941, 983, 0, 0, 39, '982'),
	(243, 1, 0, -50941, 984, 0, 0, 39, '983'),
	(243, 1, 0, -50941, 985, 0, 0, 39, '984'),
	(243, 1, 0, -50941, 986, 0, 0, 39, '985'),
	(243, 1, 0, -50941, 987, 0, 0, 39, '986'),
	(243, 1, 0, -50941, 988, 0, 0, 39, '987'),
	(243, 1, 0, -50941, 989, 0, 0, 39, '988'),
	(243, 1, 0, -50941, 990, 0, 0, 39, '989'),
	(243, 1, 0, -50941, 991, 0, 0, 39, '990'),
	(243, 1, 0, -50941, 992, 0, 0, 39, '991'),
	(243, 1, 0, -50941, 993, 0, 0, 39, '992'),
	(243, 1, 0, -50941, 994, 0, 0, 39, '993'),
	(243, 1, 0, -50941, 995, 0, 0, 39, '994'),
	(243, 1, 0, -50941, 996, 0, 0, 39, '995'),
	(243, 1, 0, -50941, 997, 0, 0, 39, '996'),
	(243, 1, 0, -50941, 998, 0, 0, 39, '997'),
	(243, 1, 0, -50941, 999, 0, 0, 39, '998'),
	(243, 1, 0, -50941, 1000, 0, 0, 39, '999'),
	(243, 1, 0, -50941, 1001, 0, 0, 39, '1000'),
	(243, 1, 0, -50941, 1002, 0, 0, 39, '1001'),
	(243, 1, 0, -50941, 1003, 0, 0, 39, '1002'),
	(243, 1, 0, -50941, 1004, 0, 0, 39, '1003'),
	(243, 1, 0, -50941, 1005, 0, 0, 39, '1004'),
	(243, 1, 0, -50941, 1006, 0, 0, 39, '1005'),
	(243, 1, 0, -50941, 1007, 0, 0, 39, '1006'),
	(243, 1, 0, -50941, 1008, 0, 0, 39, '1007'),
	(243, 1, 0, -50941, 1009, 0, 0, 39, '1008'),
	(243, 1, 0, -50941, 1010, 0, 0, 39, '1009'),
	(243, 1, 0, -50941, 1011, 0, 0, 39, '1010'),
	(243, 1, 0, -50941, 1012, 0, 0, 39, '1011'),
	(243, 1, 0, -50941, 1013, 0, 0, 39, '1012'),
	(243, 1, 0, -50941, 1014, 0, 0, 39, '1013'),
	(243, 1, 0, -50941, 1015, 0, 0, 39, '1014'),
	(243, 1, 0, -50941, 1016, 0, 0, 39, '1015'),
	(243, 1, 0, -50941, 1017, 0, 0, 39, '1016'),
	(243, 1, 0, -50941, 1018, 0, 0, 39, '1017'),
	(243, 1, 0, -50941, 1019, 0, 0, 39, '1018'),
	(243, 1, 0, -50941, 1020, 0, 0, 39, '1019'),
	(243, 1, 0, -50941, 1021, 0, 0, 39, '1020'),
	(243, 1, 0, -50941, 1022, 0, 0, 39, '1021'),
	(243, 1, 0, -50941, 1023, 0, 0, 39, '1022'),
	(243, 1, 0, -50941, 1024, 0, 0, 39, '1023'),
	(243, 1, 0, -50941, 1025, 0, 0, 39, '1024'),
	(243, 1, 0, -50941, 1026, 0, 0, 39, '1025'),
	(243, 1, 0, -50941, 1027, 0, 0, 39, '1026'),
	(243, 1, 0, -50941, 1028, 0, 0, 39, '1027'),
	(243, 1, 0, -50941, 1029, 0, 0, 39, '1028'),
	(243, 1, 0, -50941, 1030, 0, 0, 39, '1029'),
	(243, 1, 0, -50941, 1031, 0, 0, 39, '1030'),
	(243, 1, 0, -50941, 1032, 0, 0, 39, '1031'),
	(243, 1, 0, -50941, 1033, 0, 0, 39, '1032'),
	(243, 1, 0, -50941, 1034, 0, 0, 39, '1033'),
	(243, 1, 0, -50941, 1035, 0, 0, 39, '1034'),
	(243, 1, 0, -50941, 1036, 0, 0, 39, '1035'),
	(243, 1, 0, -50941, 1037, 0, 0, 39, '1036'),
	(243, 1, 0, -50941, 1038, 0, 0, 39, '1037'),
	(243, 1, 0, -50941, 1039, 0, 0, 39, '1038'),
	(243, 1, 0, -50941, 1040, 0, 0, 39, '1039'),
	(243, 1, 0, -50941, 1041, 0, 0, 39, '1040'),
	(243, 1, 0, -50941, 1042, 0, 0, 39, '1041'),
	(243, 1, 0, -50941, 1043, 0, 0, 39, '1042'),
	(243, 1, 0, -50941, 1044, 0, 0, 39, '1043'),
	(243, 1, 0, -50941, 1045, 0, 0, 39, '1044'),
	(243, 1, 0, -50941, 1046, 0, 0, 39, '1045'),
	(243, 1, 0, -50941, 1047, 0, 0, 39, '1046'),
	(243, 1, 0, -50941, 1048, 0, 0, 39, '1047'),
	(243, 1, 0, -50941, 1049, 0, 0, 39, '1048'),
	(243, 1, 0, -50941, 1050, 0, 0, 39, '1049'),
	(243, 1, 0, -50941, 1051, 0, 0, 39, '1050'),
	(243, 1, 0, -50941, 1052, 0, 0, 39, '1051'),
	(243, 1, 0, -50941, 1053, 0, 0, 39, '1052'),
	(243, 1, 0, -50941, 1054, 0, 0, 39, '1053'),
	(243, 1, 0, -50941, 1055, 0, 0, 39, '1054'),
	(243, 1, 0, -50941, 1056, 0, 0, 39, '1055'),
	(243, 1, 0, -50941, 1057, 0, 0, 39, '1056'),
	(243, 1, 0, -50941, 1058, 0, 0, 39, '1057'),
	(243, 1, 0, -50941, 1059, 0, 0, 39, '1058'),
	(243, 1, 0, -50941, 1060, 0, 0, 39, '1059'),
	(243, 1, 0, -50941, 1061, 0, 0, 39, '1060'),
	(243, 1, 0, -50941, 1062, 0, 0, 39, '1061'),
	(243, 1, 0, -50941, 1063, 0, 0, 39, '1062'),
	(243, 1, 0, -50941, 1064, 0, 0, 39, '1063'),
	(243, 1, 0, -50941, 1065, 0, 0, 39, '1064'),
	(243, 1, 0, -50941, 1066, 0, 0, 39, '1065'),
	(243, 1, 0, -50941, 1067, 0, 0, 39, '1066'),
	(243, 1, 0, -50941, 1068, 0, 0, 39, '1067'),
	(243, 1, 0, -50941, 1069, 0, 0, 39, '1068'),
	(243, 1, 0, -50941, 1070, 0, 0, 39, '1069'),
	(243, 1, 0, -50941, 1071, 0, 0, 39, '1070'),
	(243, 1, 0, -50941, 1072, 0, 0, 39, '1071'),
	(243, 1, 0, -50941, 1073, 0, 0, 39, '1072'),
	(243, 1, 0, -50941, 1074, 0, 0, 39, '1073'),
	(243, 1, 0, -50941, 1075, 0, 0, 39, '1074'),
	(243, 1, 0, -50941, 1076, 0, 0, 39, '1075'),
	(243, 1, 0, -50941, 1077, 0, 0, 39, '1076'),
	(243, 1, 0, -50941, 1078, 0, 0, 39, '1077'),
	(243, 1, 0, -50941, 1079, 0, 0, 39, '1078'),
	(243, 1, 0, -50941, 1080, 0, 0, 39, '1079'),
	(243, 1, 0, -50941, 1081, 0, 0, 39, '1080'),
	(243, 1, 0, -50941, 1082, 0, 0, 39, '1081'),
	(243, 1, 0, -50941, 1083, 0, 0, 39, '1082'),
	(243, 1, 0, -50941, 1084, 0, 0, 39, '1083'),
	(243, 1, 0, -50941, 1085, 0, 0, 39, '1084'),
	(243, 1, 0, -50941, 1086, 0, 0, 39, '1085'),
	(243, 1, 0, -50941, 1087, 0, 0, 39, '1086'),
	(243, 1, 0, -50941, 1088, 0, 0, 39, '1087'),
	(243, 1, 0, -50941, 1089, 0, 0, 39, '1088'),
	(243, 1, 0, -50941, 1090, 0, 0, 39, '1089'),
	(243, 1, 0, -50941, 1091, 0, 0, 39, '1090'),
	(243, 1, 0, -50941, 1092, 0, 0, 39, '1091'),
	(243, 1, 0, -50941, 1093, 0, 0, 39, '1092'),
	(243, 1, 0, -50941, 1094, 0, 0, 39, '1093'),
	(243, 1, 0, -50941, 1095, 0, 0, 39, '1094'),
	(243, 1, 0, -50941, 1096, 0, 0, 39, '1095'),
	(243, 1, 0, -50941, 1097, 0, 0, 39, '1096'),
	(243, 1, 0, -50941, 1098, 0, 0, 39, '1097'),
	(243, 1, 0, -50941, 1099, 0, 0, 39, '1098'),
	(243, 1, 0, -50941, 1100, 0, 0, 39, '1099'),
	(243, 1, 0, -50941, 1101, 0, 0, 39, '1100'),
	(243, 1, 0, -50941, 1102, 0, 0, 39, '1101'),
	(243, 1, 0, -50941, 1103, 0, 0, 39, '1102'),
	(243, 1, 0, -50941, 1104, 0, 0, 39, '1103'),
	(243, 1, 0, -50941, 1105, 0, 0, 39, '1104'),
	(243, 1, 0, -50941, 1106, 0, 0, 39, '1105'),
	(243, 1, 0, -50941, 1107, 0, 0, 39, '1106'),
	(243, 1, 0, -50941, 1108, 0, 0, 39, '1107'),
	(243, 1, 0, -50941, 1109, 0, 0, 39, '1108'),
	(243, 1, 0, -50941, 1110, 0, 0, 39, '1109'),
	(243, 1, 0, -50941, 1111, 0, 0, 39, '1110'),
	(243, 1, 0, -50941, 1112, 0, 0, 39, '1111'),
	(243, 1, 0, -50941, 1113, 0, 0, 39, '1112'),
	(243, 1, 0, -50941, 1114, 0, 0, 39, '1113'),
	(243, 1, 0, -50941, 1115, 0, 0, 39, '1114'),
	(243, 1, 0, -50941, 1116, 0, 0, 39, '1115'),
	(243, 1, 0, -50941, 1117, 0, 0, 39, '1116'),
	(243, 1, 0, -50941, 1118, 0, 0, 39, '1117'),
	(243, 1, 0, -50941, 1119, 0, 0, 39, '1118'),
	(243, 1, 0, -50941, 1120, 0, 0, 39, '1119'),
	(243, 1, 0, -50941, 1121, 0, 0, 39, '1120'),
	(243, 1, 0, -50941, 1122, 0, 0, 39, '1121'),
	(243, 1, 0, -50941, 1123, 0, 0, 39, '1122'),
	(243, 1, 0, -50941, 1124, 0, 0, 39, '1123'),
	(243, 1, 0, -50941, 1125, 0, 0, 39, '1124'),
	(243, 1, 0, -50941, 1126, 0, 0, 39, '1125'),
	(243, 1, 0, -50941, 1127, 0, 0, 39, '1126'),
	(243, 1, 0, -50941, 1128, 0, 0, 39, '1127'),
	(243, 1, 0, -50941, 1129, 0, 0, 39, '1128'),
	(243, 1, 0, -50941, 1130, 0, 0, 39, '1129'),
	(243, 1, 0, -50941, 1131, 0, 0, 39, '1130'),
	(243, 1, 0, -50941, 1132, 0, 0, 39, '1131'),
	(243, 1, 0, -50941, 1133, 0, 0, 39, '1132'),
	(243, 1, 0, -50941, 1134, 0, 0, 39, '1133'),
	(243, 1, 0, -50941, 1135, 0, 0, 39, '1134'),
	(243, 1, 0, -50941, 1136, 0, 0, 39, '1135'),
	(243, 1, 0, -50941, 1137, 0, 0, 39, '1136'),
	(243, 1, 0, -50941, 1138, 0, 0, 39, '1137'),
	(243, 1, 0, -50941, 1139, 0, 0, 39, '1138'),
	(243, 1, 0, -50941, 1140, 0, 0, 39, '1139'),
	(243, 1, 0, -50941, 1141, 0, 0, 39, '1140'),
	(243, 1, 0, -50941, 1142, 0, 0, 39, '1141'),
	(243, 1, 0, -50941, 1143, 0, 0, 39, '1142'),
	(243, 1, 0, -50941, 1144, 0, 0, 39, '1143'),
	(243, 1, 0, -50941, 1145, 0, 0, 39, '1144'),
	(243, 1, 0, -50941, 1146, 0, 0, 39, '1145'),
	(243, 1, 0, -50941, 1147, 0, 0, 39, '1146'),
	(243, 1, 0, -50941, 1148, 0, 0, 39, '1147'),
	(243, 1, 0, -50941, 1149, 0, 0, 39, '1148'),
	(243, 1, 0, -50941, 1150, 0, 0, 39, '1149'),
	(243, 1, 0, -50941, 1151, 0, 0, 39, '1150'),
	(243, 1, 0, -50941, 1152, 0, 0, 39, '1151'),
	(243, 1, 0, -50941, 1153, 0, 0, 39, '1152'),
	(243, 1, 0, -50941, 1154, 0, 0, 39, '1153'),
	(243, 1, 0, -50941, 1155, 0, 0, 39, '1154'),
	(243, 1, 0, -50941, 1156, 0, 0, 39, '1155'),
	(243, 1, 0, -50941, 1157, 0, 0, 39, '1156'),
	(243, 1, 0, -50941, 1158, 0, 0, 39, '1157'),
	(243, 1, 0, -50941, 1159, 0, 0, 39, '1158'),
	(243, 1, 0, -50941, 1160, 0, 0, 39, '1159'),
	(243, 1, 0, -50941, 1161, 0, 0, 39, '1160'),
	(243, 1, 0, -50941, 1162, 0, 0, 39, '1161'),
	(243, 1, 0, -50941, 1163, 0, 0, 39, '1162'),
	(243, 1, 0, -50941, 1164, 0, 0, 39, '1163'),
	(243, 1, 0, -50941, 1165, 0, 0, 39, '1164'),
	(243, 1, 0, -50941, 1166, 0, 0, 39, '1165'),
	(243, 1, 0, -50941, 1167, 0, 0, 39, '1166'),
	(243, 1, 0, -50941, 1168, 0, 0, 39, '1167'),
	(243, 1, 0, -50941, 1169, 0, 0, 39, '1168'),
	(243, 1, 0, -50941, 1170, 0, 0, 39, '1169'),
	(243, 1, 0, -50941, 1171, 0, 0, 39, '1170'),
	(243, 1, 0, -50941, 1172, 0, 0, 39, '1171'),
	(243, 1, 0, -50941, 1173, 0, 0, 39, '1172'),
	(243, 1, 0, -50941, 1174, 0, 0, 39, '1173'),
	(243, 1, 0, -50941, 1175, 0, 0, 39, '1174'),
	(243, 1, 0, -50941, 1176, 0, 0, 39, '1175'),
	(243, 1, 0, -50941, 1177, 0, 0, 39, '1176'),
	(243, 1, 0, -50941, 1178, 0, 0, 39, '1177'),
	(243, 1, 0, -50941, 1179, 0, 0, 39, '1178'),
	(243, 1, 0, -50941, 1180, 0, 0, 39, '1179'),
	(243, 1, 0, -50941, 1181, 0, 0, 39, '1180'),
	(243, 1, 0, -50941, 1182, 0, 0, 39, '1181'),
	(243, 1, 0, -50941, 1183, 0, 0, 39, '1182'),
	(243, 1, 0, -50941, 1184, 0, 0, 39, '1183'),
	(243, 1, 0, -50941, 1185, 0, 0, 39, '1184'),
	(243, 1, 0, -50941, 1186, 0, 0, 39, '1185'),
	(243, 1, 0, -50941, 1187, 0, 0, 39, '1186'),
	(243, 1, 0, -50941, 1188, 0, 0, 39, '1187'),
	(243, 1, 0, -50941, 1189, 0, 0, 39, '1188'),
	(243, 1, 0, -50941, 1190, 0, 0, 39, '1189'),
	(243, 1, 0, -50941, 1191, 0, 0, 39, '1190'),
	(243, 1, 0, -50941, 1192, 0, 0, 39, '1191'),
	(243, 1, 0, -50941, 1193, 0, 0, 39, '1192'),
	(243, 1, 0, -50941, 1194, 0, 0, 39, '1193'),
	(243, 1, 0, -50941, 1195, 0, 0, 39, '1194'),
	(243, 1, 0, -50941, 1196, 0, 0, 39, '1195'),
	(243, 1, 0, -50941, 1197, 0, 0, 39, '1196'),
	(243, 1, 0, -50941, 1198, 0, 0, 39, '1197'),
	(243, 1, 0, -50941, 1199, 0, 0, 39, '1198'),
	(243, 1, 0, -50941, 1200, 0, 0, 39, '1199'),
	(243, 1, 0, -50941, 1201, 0, 0, 39, '1200'),
	(243, 1, 0, -50941, 1202, 0, 0, 39, '1201'),
	(243, 1, 0, -50941, 1203, 0, 0, 39, '1202'),
	(243, 1, 0, -50941, 1204, 0, 0, 39, '1203'),
	(243, 1, 0, -50941, 1205, 0, 0, 39, '1204'),
	(243, 1, 0, -50941, 1206, 0, 0, 39, '1205'),
	(243, 1, 0, -50941, 1207, 0, 0, 39, '1206'),
	(243, 1, 0, -50941, 1208, 0, 0, 39, '1207'),
	(243, 1, 0, -50941, 1209, 0, 0, 39, '1208'),
	(243, 1, 0, -50941, 1210, 0, 0, 39, '1209'),
	(243, 1, 0, -50941, 1211, 0, 0, 39, '1210'),
	(243, 1, 0, -50941, 1212, 0, 0, 39, '1211'),
	(243, 1, 0, -50941, 1213, 0, 0, 39, '1212'),
	(243, 1, 0, -50941, 1214, 0, 0, 39, '1213'),
	(243, 1, 0, -50941, 1215, 0, 0, 39, '1214'),
	(243, 1, 0, -50941, 1216, 0, 0, 39, '1215'),
	(243, 1, 0, -50941, 1217, 0, 0, 39, '1216'),
	(243, 1, 0, -50941, 1218, 0, 0, 39, '1217'),
	(243, 1, 0, -50941, 1219, 0, 0, 39, '1218'),
	(243, 1, 0, -50941, 1220, 0, 0, 39, '1219'),
	(243, 1, 0, -50941, 1221, 0, 0, 39, '1220'),
	(243, 1, 0, -50941, 1222, 0, 0, 39, '1221'),
	(243, 1, 0, -50941, 1223, 0, 0, 39, '1222'),
	(243, 1, 0, -50941, 1224, 0, 0, 39, '1223'),
	(243, 1, 0, -50941, 1225, 0, 0, 39, '1224'),
	(243, 1, 0, -50941, 1226, 0, 0, 39, '1225'),
	(243, 1, 0, -50941, 1227, 0, 0, 39, '1226'),
	(243, 1, 0, -50941, 1228, 0, 0, 39, '1227'),
	(243, 1, 0, -50941, 1229, 0, 0, 39, '1228'),
	(243, 1, 0, -50941, 1230, 0, 0, 39, '1229'),
	(243, 1, 0, -50941, 1231, 0, 0, 39, '1230'),
	(243, 1, 0, -50941, 1232, 0, 0, 39, '1231'),
	(243, 1, 0, -50941, 1233, 0, 0, 39, '1232'),
	(243, 1, 0, -50941, 1234, 0, 0, 39, '1233'),
	(243, 1, 0, -50941, 1235, 0, 0, 39, '1234'),
	(243, 1, 0, -50941, 1236, 0, 0, 39, '1235'),
	(243, 1, 0, -50941, 1237, 0, 0, 39, '1236'),
	(243, 1, 0, -50941, 1238, 0, 0, 39, '1237'),
	(243, 1, 0, -50941, 1239, 0, 0, 39, '1238'),
	(243, 1, 0, -50941, 1240, 0, 0, 39, '1239'),
	(243, 1, 0, -50941, 1241, 0, 0, 39, '1240'),
	(243, 1, 0, -50941, 1242, 0, 0, 39, '1241'),
	(243, 1, 0, -50941, 1243, 0, 0, 39, '1242'),
	(243, 1, 0, -50941, 1244, 0, 0, 39, '1243'),
	(243, 1, 0, -50941, 1245, 0, 0, 39, '1244'),
	(243, 1, 0, -50941, 1246, 0, 0, 39, '1245'),
	(243, 1, 0, -50941, 1247, 0, 0, 39, '1246'),
	(243, 1, 0, -50941, 1248, 0, 0, 39, '1247'),
	(243, 1, 0, -50941, 1249, 0, 0, 39, '1248'),
	(243, 1, 0, -50941, 1250, 0, 0, 39, '1249'),
	(243, 1, 0, -50941, 1251, 0, 0, 39, '1250'),
	(243, 1, 0, -50941, 1252, 0, 0, 39, '1251'),
	(243, 1, 0, -50941, 1253, 0, 0, 39, '1252'),
	(243, 1, 0, -50941, 1254, 0, 0, 39, '1253'),
	(243, 1, 0, -50941, 1255, 0, 0, 39, '1254'),
	(243, 1, 0, -50941, 1256, 0, 0, 39, '1255'),
	(243, 1, 0, -50941, 1257, 0, 0, 39, '1256'),
	(243, 1, 0, -50941, 1258, 0, 0, 39, '1257'),
	(243, 1, 0, -50941, 1259, 0, 0, 39, '1258'),
	(243, 1, 0, -50941, 1260, 0, 0, 39, '1259'),
	(243, 1, 0, -50941, 1261, 0, 0, 39, '1260'),
	(243, 1, 0, -50941, 1262, 0, 0, 39, '1261'),
	(243, 1, 0, -50941, 1263, 0, 0, 39, '1262'),
	(243, 1, 0, -50941, 1264, 0, 0, 39, '1263'),
	(243, 1, 0, -50941, 1265, 0, 0, 39, '1264'),
	(243, 1, 0, -50941, 1266, 0, 0, 39, '1265'),
	(243, 1, 0, -50941, 1267, 0, 0, 39, '1266'),
	(243, 1, 0, -50941, 1268, 0, 0, 39, '1267'),
	(243, 1, 0, -50941, 1269, 0, 0, 39, '1268'),
	(243, 1, 0, -50941, 1270, 0, 0, 39, '1269'),
	(243, 1, 0, -50941, 1271, 0, 0, 39, '1270'),
	(243, 1, 0, -50941, 1272, 0, 0, 39, '1271'),
	(243, 1, 0, -50941, 1273, 0, 0, 39, '1272'),
	(243, 1, 0, -50941, 1274, 0, 0, 39, '1273'),
	(243, 1, 0, -50941, 1275, 0, 0, 39, '1274'),
	(243, 1, 0, -50941, 1276, 0, 0, 39, '1275'),
	(243, 1, 0, -50941, 1277, 0, 0, 39, '1276'),
	(243, 1, 0, -50941, 1278, 0, 0, 39, '1277'),
	(243, 1, 0, -50941, 1279, 0, 0, 39, '1278'),
	(243, 1, 0, -50941, 1280, 0, 0, 39, '1279'),
	(243, 1, 0, -50941, 1281, 0, 0, 39, '1280'),
	(243, 1, 0, -50941, 1282, 0, 0, 39, '1281'),
	(243, 1, 0, -50941, 1283, 0, 0, 39, '1282'),
	(243, 1, 0, -50941, 1284, 0, 0, 39, '1283'),
	(243, 1, 0, -50941, 1285, 0, 0, 39, '1284'),
	(243, 1, 0, -50941, 1286, 0, 0, 39, '1285'),
	(243, 1, 0, -50941, 1287, 0, 0, 39, '1286'),
	(243, 1, 0, -50941, 1288, 0, 0, 39, '1287'),
	(243, 1, 0, -50941, 1289, 0, 0, 39, '1288'),
	(243, 1, 0, -50941, 1290, 0, 0, 39, '1289'),
	(243, 1, 0, -50941, 1291, 0, 0, 39, '1290'),
	(243, 1, 0, -50941, 1292, 0, 0, 39, '1291'),
	(243, 1, 0, -50941, 1293, 0, 0, 39, '1292'),
	(243, 1, 0, -50941, 1294, 0, 0, 39, '1293'),
	(243, 1, 0, -50941, 1295, 0, 0, 39, '1294'),
	(243, 1, 0, -50941, 1296, 0, 0, 39, '1295'),
	(243, 1, 0, -50941, 1297, 0, 0, 39, '1296'),
	(243, 1, 0, -50941, 1298, 0, 0, 39, '1297'),
	(243, 1, 0, -50941, 1299, 0, 0, 39, '1298'),
	(243, 1, 0, -50941, 1300, 0, 0, 39, '1299'),
	(243, 1, 0, -50941, 1301, 0, 0, 39, '1300'),
	(243, 1, 0, -50941, 1302, 0, 0, 39, '1301'),
	(243, 1, 0, -50941, 1303, 0, 0, 39, '1302'),
	(243, 1, 0, -50941, 1304, 0, 0, 39, '1303'),
	(243, 1, 0, -50941, 1305, 0, 0, 39, '1304'),
	(243, 1, 0, -50941, 1306, 0, 0, 39, '1305'),
	(243, 1, 0, -50941, 1307, 0, 0, 39, '1306'),
	(243, 1, 0, -50941, 1308, 0, 0, 39, '1307'),
	(243, 1, 0, -50941, 1309, 0, 0, 39, '1308'),
	(243, 1, 0, -50941, 1310, 0, 0, 39, '1309'),
	(243, 1, 0, -50941, 1311, 0, 0, 39, '1310'),
	(243, 1, 0, -50941, 1312, 0, 0, 39, '1311'),
	(243, 1, 0, -50941, 1313, 0, 0, 39, '1312'),
	(243, 1, 0, -50941, 1314, 0, 0, 39, '1313'),
	(243, 1, 0, -50941, 1315, 0, 0, 39, '1314'),
	(243, 1, 0, -50941, 1316, 0, 0, 39, '1315'),
	(243, 1, 0, -50941, 1317, 0, 0, 39, '1316'),
	(243, 1, 0, -50941, 1318, 0, 0, 39, '1317'),
	(243, 1, 0, -50941, 1319, 0, 0, 39, '1318'),
	(243, 1, 0, -50941, 1320, 0, 0, 39, '1319'),
	(243, 1, 0, -50941, 1321, 0, 0, 39, '1320'),
	(243, 1, 0, -50941, 1322, 0, 0, 39, '1321'),
	(243, 1, 0, -50941, 1323, 0, 0, 39, '1322'),
	(243, 1, 0, -50941, 1324, 0, 0, 39, '1323'),
	(243, 1, 0, -50941, 1325, 0, 0, 39, '1324'),
	(243, 1, 0, -50941, 1326, 0, 0, 39, '1325'),
	(243, 1, 0, -50941, 1327, 0, 0, 39, '1326'),
	(243, 1, 0, -50941, 1328, 0, 0, 39, '1327'),
	(243, 1, 0, -50941, 1329, 0, 0, 39, '1328'),
	(243, 1, 0, -50941, 1330, 0, 0, 39, '1329'),
	(243, 1, 0, -50941, 1331, 0, 0, 39, '1330'),
	(243, 1, 0, -50941, 1332, 0, 0, 39, '1331'),
	(243, 1, 0, -50941, 1333, 0, 0, 39, '1332'),
	(243, 1, 0, -50941, 1334, 0, 0, 39, '1333'),
	(243, 1, 0, -50941, 1335, 0, 0, 39, '1334'),
	(243, 1, 0, -50941, 1336, 0, 0, 39, '1335'),
	(243, 1, 0, -50941, 1337, 0, 0, 39, '1336'),
	(243, 1, 0, -50941, 1338, 0, 0, 39, '1337'),
	(243, 1, 0, -50941, 1339, 0, 0, 39, '1338'),
	(243, 1, 0, -50941, 1340, 0, 0, 39, '1339'),
	(243, 1, 0, -50941, 1341, 0, 0, 39, '1340'),
	(243, 1, 0, -50941, 1342, 0, 0, 39, '1341'),
	(243, 1, 0, -50941, 1343, 0, 0, 39, '1342'),
	(243, 1, 0, -50941, 1344, 0, 0, 39, '1343'),
	(243, 1, 0, -50941, 1345, 0, 0, 39, '1344'),
	(243, 1, 0, -50941, 1346, 0, 0, 39, '1345'),
	(243, 1, 0, -50941, 1347, 0, 0, 39, '1346'),
	(243, 1, 0, -50941, 1348, 0, 0, 39, '1347'),
	(243, 1, 0, -50941, 1349, 0, 0, 39, '1348'),
	(243, 1, 0, -50941, 1350, 0, 0, 39, '1349'),
	(243, 1, 0, -50941, 1351, 0, 0, 39, '1350'),
	(243, 1, 0, -50941, 1352, 0, 0, 39, '1351'),
	(243, 1, 0, -50941, 1353, 0, 0, 39, '1352'),
	(243, 1, 0, -50941, 1354, 0, 0, 39, '1353'),
	(243, 1, 0, -50941, 1355, 0, 0, 39, '1354'),
	(243, 1, 0, -50941, 1356, 0, 0, 39, '1355'),
	(243, 1, 0, -50941, 1357, 0, 0, 39, '1356'),
	(243, 1, 0, -50941, 1358, 0, 0, 39, '1357'),
	(243, 1, 0, -50941, 1359, 0, 0, 39, '1358'),
	(243, 1, 0, -50941, 1360, 0, 0, 39, '1359'),
	(243, 1, 0, -50941, 1361, 0, 0, 39, '1360'),
	(243, 1, 0, -50941, 1362, 0, 0, 39, '1361'),
	(243, 1, 0, -50941, 1363, 0, 0, 39, '1362'),
	(243, 1, 0, -50941, 1364, 0, 0, 39, '1363'),
	(243, 1, 0, -50941, 1365, 0, 0, 39, '1364'),
	(243, 1, 0, -50941, 1366, 0, 0, 39, '1365'),
	(243, 1, 0, -50941, 1367, 0, 0, 39, '1366'),
	(243, 1, 0, -50941, 1368, 0, 0, 39, '1367'),
	(243, 1, 0, -50941, 1369, 0, 0, 39, '1368'),
	(243, 1, 0, -50941, 1370, 0, 0, 39, '1369'),
	(243, 1, 0, -50941, 1371, 0, 0, 39, '1370'),
	(243, 1, 0, -50941, 1372, 0, 0, 39, '1371'),
	(243, 1, 0, -50941, 1373, 0, 0, 39, '1372'),
	(243, 1, 0, -50941, 1374, 0, 0, 39, '1373'),
	(243, 1, 0, -50941, 1375, 0, 0, 39, '1374'),
	(243, 1, 0, -50941, 1376, 0, 0, 39, '1375'),
	(243, 1, 0, -50941, 1377, 0, 0, 39, '1376'),
	(243, 1, 0, -50941, 1378, 0, 0, 39, '1377'),
	(243, 1, 0, -50941, 1379, 0, 0, 39, '1378'),
	(243, 1, 0, -50941, 1380, 0, 0, 39, '1379'),
	(243, 1, 0, -50941, 1381, 0, 0, 39, '1380'),
	(243, 1, 0, -50941, 1382, 0, 0, 39, '1381'),
	(243, 1, 0, -50941, 1383, 0, 0, 39, '1382'),
	(243, 1, 0, -50941, 1384, 0, 0, 39, '1383'),
	(243, 1, 0, -50941, 1385, 0, 0, 39, '1384'),
	(243, 1, 0, -50941, 1386, 0, 0, 39, '1385'),
	(243, 1, 0, -50941, 1387, 0, 0, 39, '1386'),
	(243, 1, 0, -50941, 1388, 0, 0, 39, '1387'),
	(243, 1, 0, -50941, 1389, 0, 0, 39, '1388'),
	(243, 1, 0, -50941, 1390, 0, 0, 39, '1389'),
	(243, 1, 0, -50941, 1391, 0, 0, 39, '1390'),
	(243, 1, 0, -50941, 1392, 0, 0, 39, '1391'),
	(243, 1, 0, -50941, 1393, 0, 0, 39, '1392'),
	(243, 1, 0, -50941, 1394, 0, 0, 39, '1393'),
	(243, 1, 0, -50941, 1395, 0, 0, 39, '1394'),
	(243, 1, 0, -50941, 1396, 0, 0, 39, '1395'),
	(243, 1, 0, -50941, 1397, 0, 0, 39, '1396'),
	(243, 1, 0, -50941, 1398, 0, 0, 39, '1397'),
	(243, 1, 0, -50941, 1399, 0, 0, 39, '1398'),
	(243, 1, 0, -50941, 1400, 0, 0, 39, '1399'),
	(243, 1, 0, -50941, 1401, 0, 0, 39, '1400'),
	(243, 1, 0, -50941, 1402, 0, 0, 39, '1401'),
	(243, 1, 0, -50941, 1403, 0, 0, 39, '1402'),
	(243, 1, 0, -50941, 1404, 0, 0, 39, '1403'),
	(243, 1, 0, -50941, 1405, 0, 0, 39, '1404'),
	(243, 1, 0, -50941, 1406, 0, 0, 39, '1405'),
	(243, 1, 0, -50941, 1407, 0, 0, 39, '1406'),
	(243, 1, 0, -50941, 1408, 0, 0, 39, '1407'),
	(243, 1, 0, -50941, 1409, 0, 0, 39, '1408'),
	(243, 1, 0, -50941, 1410, 0, 0, 39, '1409'),
	(243, 1, 0, -50941, 1411, 0, 0, 39, '1410'),
	(243, 1, 0, -50941, 1412, 0, 0, 39, '1411'),
	(243, 1, 0, -50941, 1413, 0, 0, 39, '1412'),
	(243, 1, 0, -50941, 1414, 0, 0, 39, '1413'),
	(243, 1, 0, -50941, 1415, 0, 0, 39, '1414'),
	(243, 1, 0, -50941, 1416, 0, 0, 39, '1415'),
	(243, 1, 0, -50941, 1417, 0, 0, 39, '1416'),
	(243, 1, 0, -50941, 1418, 0, 0, 39, '1417'),
	(243, 1, 0, -50941, 1419, 0, 0, 39, '1418'),
	(243, 1, 0, -50941, 1420, 0, 0, 39, '1419'),
	(243, 1, 0, -50941, 1421, 0, 0, 39, '1420'),
	(243, 1, 0, -50941, 1422, 0, 0, 39, '1421'),
	(243, 1, 0, -50941, 1423, 0, 0, 39, '1422'),
	(243, 1, 0, -50941, 1424, 0, 0, 39, '1423'),
	(243, 1, 0, -50941, 1425, 0, 0, 39, '1424'),
	(243, 1, 0, -50941, 1426, 0, 0, 39, '1425'),
	(243, 1, 0, -50941, 1427, 0, 0, 39, '1426'),
	(243, 1, 0, -50941, 1428, 0, 0, 39, '1427'),
	(243, 1, 0, -50941, 1429, 0, 0, 39, '1428'),
	(243, 1, 0, -50941, 1430, 0, 0, 39, '1429'),
	(243, 1, 0, -50941, 1431, 0, 0, 39, '1430'),
	(243, 1, 0, -50941, 1432, 0, 0, 39, '1431'),
	(243, 1, 0, -50941, 1433, 0, 0, 39, '1432'),
	(243, 1, 0, -50941, 1434, 0, 0, 39, '1433'),
	(243, 1, 0, -50941, 1435, 0, 0, 39, '1434'),
	(243, 1, 0, -50941, 1436, 0, 0, 39, '1435'),
	(243, 1, 0, -50941, 1437, 0, 0, 39, '1436'),
	(243, 1, 0, -50941, 1438, 0, 0, 39, '1437'),
	(243, 1, 0, -50941, 1439, 0, 0, 39, '1438'),
	(243, 1, 0, -50941, 1440, 0, 0, 39, '1439'),
	(243, 1, 0, -50941, 1441, 0, 0, 39, '1440'),
	(243, 1, 0, -50941, 1442, 0, 0, 39, '1441'),
	(243, 1, 0, -50941, 1443, 0, 0, 39, '1442'),
	(243, 1, 0, -50941, 1444, 0, 0, 39, '1443'),
	(243, 1, 0, -50941, 1445, 0, 0, 39, '1444'),
	(243, 1, 0, -50941, 1446, 0, 0, 39, '1445'),
	(243, 1, 0, -50941, 1447, 0, 0, 39, '1446'),
	(243, 1, 0, -50941, 1448, 0, 0, 39, '1447'),
	(243, 1, 0, -50941, 1449, 0, 0, 39, '1448'),
	(243, 1, 0, -50941, 1450, 0, 0, 39, '1449'),
	(243, 1, 0, -50941, 1451, 0, 0, 39, '1450'),
	(243, 1, 0, -50941, 1452, 0, 0, 39, '1451'),
	(243, 1, 0, -50941, 1453, 0, 0, 39, '1452'),
	(243, 1, 0, -50941, 1454, 0, 0, 39, '1453'),
	(243, 1, 0, -50941, 1455, 0, 0, 39, '1454'),
	(243, 1, 0, -50941, 1456, 0, 0, 39, '1455'),
	(243, 1, 0, -50941, 1457, 0, 0, 39, '1456'),
	(243, 1, 0, -50941, 1458, 0, 0, 39, '1457'),
	(243, 1, 0, -50941, 1459, 0, 0, 39, '1458'),
	(243, 1, 0, -50941, 1460, 0, 0, 39, '1459'),
	(243, 1, 0, -50941, 1461, 0, 0, 39, '1460'),
	(243, 1, 0, -50941, 1462, 0, 0, 39, '1461'),
	(243, 1, 0, -50941, 1463, 0, 0, 39, '1462'),
	(243, 1, 0, -50941, 1464, 0, 0, 39, '1463'),
	(243, 1, 0, -50941, 1465, 0, 0, 39, '1464'),
	(243, 1, 0, -50941, 1466, 0, 0, 39, '1465'),
	(243, 1, 0, -50941, 1467, 0, 0, 39, '1466'),
	(243, 1, 0, -50941, 1468, 0, 0, 39, '1467'),
	(243, 1, 0, -50941, 1469, 0, 0, 39, '1468'),
	(243, 1, 0, -50941, 1470, 0, 0, 39, '1469'),
	(243, 1, 0, -50941, 1471, 0, 0, 39, '1470'),
	(243, 1, 0, -50941, 1472, 0, 0, 39, '1471'),
	(243, 1, 0, -50941, 1473, 0, 0, 39, '1472'),
	(243, 1, 0, -50941, 1474, 0, 0, 39, '1473'),
	(243, 1, 0, -50941, 1475, 0, 0, 39, '1474'),
	(243, 1, 0, -50941, 1476, 0, 0, 39, '1475'),
	(243, 1, 0, -50941, 1477, 0, 0, 39, '1476'),
	(243, 1, 0, -50941, 1478, 0, 0, 39, '1477'),
	(243, 1, 0, -50941, 1479, 0, 0, 39, '1478'),
	(243, 1, 0, -50941, 1480, 0, 0, 39, '1479'),
	(243, 1, 0, -50941, 1481, 0, 0, 39, '1480'),
	(243, 1, 0, -50941, 1482, 0, 0, 39, '1481'),
	(243, 1, 0, -50941, 1483, 0, 0, 39, '1482'),
	(243, 1, 0, -50941, 1484, 0, 0, 39, '1483'),
	(243, 1, 0, -50941, 1485, 0, 0, 39, '1484'),
	(243, 1, 0, -50941, 1486, 0, 0, 39, '1485'),
	(243, 1, 0, -50941, 1487, 0, 0, 39, '1486'),
	(243, 1, 0, -50941, 1488, 0, 0, 39, '1487'),
	(243, 1, 0, -50941, 1489, 0, 0, 39, '1488'),
	(243, 1, 0, -50941, 1490, 0, 0, 39, '1489'),
	(243, 1, 0, -50941, 1491, 0, 0, 39, '1490'),
	(243, 1, 0, -50941, 1492, 0, 0, 39, '1491'),
	(243, 1, 0, -50941, 1493, 0, 0, 39, '1492'),
	(243, 1, 0, -50941, 1494, 0, 0, 39, '1493'),
	(243, 1, 0, -50941, 1495, 0, 0, 39, '1494'),
	(243, 1, 0, -50941, 1496, 0, 0, 39, '1495'),
	(243, 1, 0, -50941, 1497, 0, 0, 39, '1496'),
	(243, 1, 0, -50941, 1498, 0, 0, 39, '1497'),
	(243, 1, 0, -50941, 1499, 0, 0, 39, '1498'),
	(243, 1, 0, -50941, 1500, 0, 0, 39, '1499'),
	(243, 1, 0, -50941, 1501, 0, 0, 39, '1500'),
	(243, 1, 0, -50941, 1502, 0, 0, 39, '1501'),
	(243, 1, 0, -50941, 1503, 0, 0, 39, '1502'),
	(243, 1, 0, -50941, 1504, 0, 0, 39, '1503'),
	(243, 1, 0, -50941, 1505, 0, 0, 39, '1504'),
	(243, 1, 0, -50941, 1506, 0, 0, 39, '1505'),
	(243, 1, 0, -50941, 1507, 0, 0, 39, '1506'),
	(243, 1, 0, -50941, 1508, 0, 0, 39, '1507'),
	(243, 1, 0, -50941, 1509, 0, 0, 39, '1508'),
	(243, 1, 0, -50941, 1510, 0, 0, 39, '1509'),
	(243, 1, 0, -50941, 1511, 0, 0, 39, '1510'),
	(243, 1, 0, -50941, 1512, 0, 0, 39, '1511'),
	(243, 1, 0, -50941, 1513, 0, 0, 39, '1512'),
	(243, 1, 0, -50941, 1514, 0, 0, 39, '1513'),
	(243, 1, 0, -50941, 1515, 0, 0, 39, '1514'),
	(243, 1, 0, -50941, 1516, 0, 0, 39, '1515'),
	(243, 1, 0, -50941, 1517, 0, 0, 39, '1516'),
	(243, 1, 0, -50941, 1518, 0, 0, 39, '1517'),
	(243, 1, 0, -50941, 1519, 0, 0, 39, '1518'),
	(243, 1, 0, -50941, 1520, 0, 0, 39, '1519'),
	(243, 1, 0, -50941, 1521, 0, 0, 39, '1520'),
	(243, 1, 0, -50941, 1522, 0, 0, 39, '1521'),
	(243, 1, 0, -50941, 1523, 0, 0, 39, '1522'),
	(243, 1, 0, -50941, 1524, 0, 0, 39, '1523'),
	(243, 1, 0, -50941, 1525, 0, 0, 39, '1524'),
	(243, 1, 0, -50941, 1526, 0, 0, 39, '1525'),
	(243, 1, 0, -50941, 1527, 0, 0, 39, '1526'),
	(243, 1, 0, -50941, 1528, 0, 0, 39, '1527'),
	(243, 1, 0, -50941, 1529, 0, 0, 39, '1528'),
	(243, 1, 0, -50941, 1530, 0, 0, 39, '1529'),
	(243, 1, 0, -50941, 1531, 0, 0, 39, '1530'),
	(243, 1, 0, -50941, 1532, 0, 0, 39, '1531'),
	(243, 1, 0, -50941, 1533, 0, 0, 39, '1532'),
	(243, 1, 0, -50941, 1534, 0, 0, 39, '1533'),
	(243, 1, 0, -50941, 1535, 0, 0, 39, '1534'),
	(243, 1, 0, -50941, 1536, 0, 0, 39, '1535'),
	(243, 1, 0, -50941, 1537, 0, 0, 39, '1536'),
	(243, 1, 0, -50941, 1538, 0, 0, 39, '1537'),
	(243, 1, 0, -50941, 1539, 0, 0, 39, '1538'),
	(243, 1, 0, -50941, 1540, 0, 0, 39, '1539'),
	(243, 1, 0, -50941, 1541, 0, 0, 39, '1540'),
	(243, 1, 0, -50941, 1542, 0, 0, 39, '1541'),
	(243, 1, 0, -50941, 1543, 0, 0, 39, '1542'),
	(243, 1, 0, -50941, 1544, 0, 0, 39, '1543'),
	(243, 1, 0, -50941, 1545, 0, 0, 39, '1544'),
	(243, 1, 0, -50941, 1546, 0, 0, 39, '1545'),
	(243, 1, 0, -50941, 1547, 0, 0, 39, '1546'),
	(243, 1, 0, -50941, 1548, 0, 0, 39, '1547'),
	(243, 1, 0, -50941, 1549, 0, 0, 39, '1548'),
	(243, 1, 0, -50941, 1550, 0, 0, 39, '1549'),
	(243, 1, 0, -50941, 1551, 0, 0, 39, '1550'),
	(243, 1, 0, -50941, 1552, 0, 0, 39, '1551'),
	(243, 1, 0, -50941, 1553, 0, 0, 39, '1552'),
	(243, 1, 0, -50941, 1554, 0, 0, 39, '1553'),
	(243, 1, 0, -50941, 1555, 0, 0, 39, '1554'),
	(243, 1, 0, -50941, 1556, 0, 0, 39, '1555'),
	(243, 1, 0, -50941, 1557, 0, 0, 39, '1556'),
	(243, 1, 0, -50941, 1558, 0, 0, 39, '1557'),
	(243, 1, 0, -50941, 1559, 0, 0, 39, '1558'),
	(243, 1, 0, -50941, 1560, 0, 0, 39, '1559'),
	(243, 1, 0, -50941, 1561, 0, 0, 39, '1560'),
	(243, 1, 0, -50941, 1562, 0, 0, 39, '1561'),
	(243, 1, 0, -50941, 1563, 0, 0, 39, '1562'),
	(243, 1, 0, -50941, 1564, 0, 0, 39, '1563'),
	(243, 1, 0, -50941, 1565, 0, 0, 39, '1564'),
	(243, 1, 0, -50941, 1566, 0, 0, 39, '1565'),
	(243, 1, 0, -50941, 1567, 0, 0, 39, '1566'),
	(243, 1, 0, -50941, 1568, 0, 0, 39, '1567'),
	(243, 1, 0, -50941, 1569, 0, 0, 39, '1568'),
	(243, 1, 0, -50941, 1570, 0, 0, 39, '1569'),
	(243, 1, 0, -50941, 1571, 0, 0, 39, '1570'),
	(243, 1, 0, -50941, 1572, 0, 0, 39, '1571'),
	(243, 1, 0, -50941, 1573, 0, 0, 39, '1572'),
	(243, 1, 0, -50941, 1574, 0, 0, 39, '1573'),
	(243, 1, 0, -50941, 1575, 0, 0, 39, '1574'),
	(243, 1, 0, -50941, 1576, 0, 0, 39, '1575'),
	(243, 1, 0, -50941, 1577, 0, 0, 39, '1576'),
	(243, 1, 0, -50941, 1578, 0, 0, 39, '1577'),
	(243, 1, 0, -50941, 1579, 0, 0, 39, '1578'),
	(243, 1, 0, -50941, 1580, 0, 0, 39, '1579'),
	(243, 1, 0, -50941, 1581, 0, 0, 39, '1580'),
	(243, 1, 0, -50941, 1582, 0, 0, 39, '1581'),
	(243, 1, 0, -50941, 1583, 0, 0, 39, '1582'),
	(243, 1, 0, -50941, 1584, 0, 0, 39, '1583'),
	(243, 1, 0, -50941, 1585, 0, 0, 39, '1584'),
	(243, 1, 0, -50941, 1586, 0, 0, 39, '1585'),
	(243, 1, 0, -50941, 1587, 0, 0, 39, '1586'),
	(243, 1, 0, -50941, 1588, 0, 0, 39, '1587'),
	(243, 1, 0, -50941, 1589, 0, 0, 39, '1588'),
	(243, 1, 0, -50941, 1590, 0, 0, 39, '1589'),
	(243, 1, 0, -50941, 1591, 0, 0, 39, '1590'),
	(243, 1, 0, -50941, 1592, 0, 0, 39, '1591'),
	(243, 1, 0, -50941, 1593, 0, 0, 39, '1592'),
	(243, 1, 0, -50941, 1594, 0, 0, 39, '1593'),
	(243, 1, 0, -50941, 1595, 0, 0, 39, '1594'),
	(243, 1, 0, -50941, 1596, 0, 0, 39, '1595'),
	(243, 1, 0, -50941, 1597, 0, 0, 39, '1596'),
	(243, 1, 0, -50941, 1598, 0, 0, 39, '1597'),
	(243, 1, 0, -50941, 1599, 0, 0, 39, '1598'),
	(243, 1, 0, -50941, 1600, 0, 0, 39, '1599'),
	(243, 1, 0, -50941, 1601, 0, 0, 39, '1600'),
	(243, 1, 0, -50941, 1602, 0, 0, 39, '1601'),
	(243, 1, 0, -50941, 1603, 0, 0, 39, '1602'),
	(243, 1, 0, -50941, 1604, 0, 0, 39, '1603'),
	(243, 1, 0, -50941, 1605, 0, 0, 39, '1604'),
	(243, 1, 0, -50941, 1606, 0, 0, 39, '1605'),
	(243, 1, 0, -50941, 1607, 0, 0, 39, '1606'),
	(243, 1, 0, -50941, 1608, 0, 0, 39, '1607'),
	(243, 1, 0, -50941, 1609, 0, 0, 39, '1608'),
	(243, 1, 0, -50941, 1610, 0, 0, 39, '1609'),
	(243, 1, 0, -50941, 1611, 0, 0, 39, '1610'),
	(243, 1, 0, -50941, 1612, 0, 0, 39, '1611'),
	(243, 1, 0, -50941, 1613, 0, 0, 39, '1612'),
	(243, 1, 0, -50941, 1614, 0, 0, 39, '1613'),
	(243, 1, 0, -50941, 1615, 0, 0, 39, '1614'),
	(243, 1, 0, -50941, 1616, 0, 0, 39, '1615'),
	(243, 1, 0, -50941, 1617, 0, 0, 39, '1616'),
	(243, 1, 0, -50941, 1618, 0, 0, 39, '1617'),
	(243, 1, 0, -50941, 1619, 0, 0, 39, '1618'),
	(243, 1, 0, -50941, 1620, 0, 0, 39, '1619'),
	(243, 1, 0, -50941, 1621, 0, 0, 39, '1620'),
	(243, 1, 0, -50941, 1622, 0, 0, 39, '1621'),
	(243, 1, 0, -50941, 1623, 0, 0, 39, '1622'),
	(243, 1, 0, -50941, 1624, 0, 0, 39, '1623'),
	(243, 1, 0, -50941, 1625, 0, 0, 39, '1624'),
	(243, 1, 0, -50941, 1626, 0, 0, 39, '1625'),
	(243, 1, 0, -50941, 1627, 0, 0, 39, '1626'),
	(243, 1, 0, -50941, 1628, 0, 0, 39, '1627'),
	(243, 1, 0, -50941, 1629, 0, 0, 39, '1628'),
	(243, 1, 0, -50941, 1630, 0, 0, 39, '1629'),
	(243, 1, 0, -50941, 1631, 0, 0, 39, '1630'),
	(243, 1, 0, -50941, 1632, 0, 0, 39, '1631'),
	(243, 1, 0, -50941, 1633, 0, 0, 39, '1632'),
	(243, 1, 0, -50941, 1634, 0, 0, 39, '1633'),
	(243, 1, 0, -50941, 1635, 0, 0, 39, '1634'),
	(243, 1, 0, -50941, 1636, 0, 0, 39, '1635'),
	(243, 1, 0, -50941, 1637, 0, 0, 39, '1636'),
	(243, 1, 0, -50941, 1638, 0, 0, 39, '1637'),
	(243, 1, 0, -50941, 1639, 0, 0, 39, '1638'),
	(243, 1, 0, -50941, 1640, 0, 0, 39, '1639'),
	(243, 1, 0, -50941, 1641, 0, 0, 39, '1640'),
	(243, 1, 0, -50941, 1642, 0, 0, 39, '1641'),
	(243, 1, 0, -50941, 1643, 0, 0, 39, '1642'),
	(243, 1, 0, -50941, 1644, 0, 0, 39, '1643'),
	(243, 1, 0, -50941, 1645, 0, 0, 39, '1644'),
	(243, 1, 0, -50941, 1646, 0, 0, 39, '1645'),
	(243, 1, 0, -50941, 1647, 0, 0, 39, '1646'),
	(243, 1, 0, -50941, 1648, 0, 0, 39, '1647'),
	(243, 1, 0, -50941, 1649, 0, 0, 39, '1648'),
	(243, 1, 0, -50941, 1650, 0, 0, 39, '1649'),
	(243, 1, 0, -50941, 1651, 0, 0, 39, '1650'),
	(243, 1, 0, -50941, 1652, 0, 0, 39, '1651'),
	(243, 1, 0, -50941, 1653, 0, 0, 39, '1652'),
	(243, 1, 0, -50941, 1654, 0, 0, 39, '1653'),
	(243, 1, 0, -50941, 1655, 0, 0, 39, '1654'),
	(243, 1, 0, -50941, 1656, 0, 0, 39, '1655'),
	(243, 1, 0, -50941, 1657, 0, 0, 39, '1656'),
	(243, 1, 0, -50941, 1658, 0, 0, 39, '1657'),
	(243, 1, 0, -50941, 1659, 0, 0, 39, '1658'),
	(243, 1, 0, -50941, 1660, 0, 0, 39, '1659'),
	(243, 1, 0, -50941, 1661, 0, 0, 39, '1660'),
	(243, 1, 0, -50941, 1662, 0, 0, 39, '1661'),
	(243, 1, 0, -50941, 1663, 0, 0, 39, '1662'),
	(243, 1, 0, -50941, 1664, 0, 0, 39, '1663'),
	(243, 1, 0, -50941, 1665, 0, 0, 39, '1664'),
	(243, 1, 0, -50941, 1666, 0, 0, 39, '1665'),
	(243, 1, 0, -50941, 1667, 0, 0, 39, '1666'),
	(243, 1, 0, -50941, 1668, 0, 0, 39, '1667'),
	(243, 1, 0, -50941, 1669, 0, 0, 39, '1668'),
	(243, 1, 0, -50941, 1670, 0, 0, 39, '1669'),
	(243, 1, 0, -50941, 1671, 0, 0, 39, '1670'),
	(243, 1, 0, -50941, 1672, 0, 0, 39, '1671'),
	(243, 1, 0, -50941, 1673, 0, 0, 39, '1672'),
	(243, 1, 0, -50941, 1674, 0, 0, 39, '1673'),
	(243, 1, 0, -50941, 1675, 0, 0, 39, '1674'),
	(243, 1, 0, -50941, 1676, 0, 0, 39, '1675'),
	(243, 1, 0, -50941, 1677, 0, 0, 39, '1676'),
	(243, 1, 0, -50941, 1678, 0, 0, 39, '1677'),
	(243, 1, 0, -50941, 1679, 0, 0, 39, '1678'),
	(243, 1, 0, -50941, 1680, 0, 0, 39, '1679'),
	(243, 1, 0, -50941, 1681, 0, 0, 39, '1680'),
	(243, 1, 0, -50941, 1682, 0, 0, 39, '1681'),
	(243, 1, 0, -50941, 1683, 0, 0, 39, '1682'),
	(243, 1, 0, -50941, 1684, 0, 0, 39, '1683'),
	(243, 1, 0, -50941, 1685, 0, 0, 39, '1684'),
	(243, 1, 0, -50941, 1686, 0, 0, 39, '1685'),
	(243, 1, 0, -50941, 1687, 0, 0, 39, '1686'),
	(243, 1, 0, -50941, 1688, 0, 0, 39, '1687'),
	(243, 1, 0, -50941, 1689, 0, 0, 39, '1688'),
	(243, 1, 0, -50941, 1690, 0, 0, 39, '1689'),
	(243, 1, 0, -50941, 1691, 0, 0, 39, '1690'),
	(243, 1, 0, -50941, 1692, 0, 0, 39, '1691'),
	(243, 1, 0, -50941, 1693, 0, 0, 39, '1692'),
	(243, 1, 0, -50941, 1694, 0, 0, 39, '1693'),
	(243, 1, 0, -50941, 1695, 0, 0, 39, '1694'),
	(243, 1, 0, -50941, 1696, 0, 0, 39, '1695'),
	(243, 1, 0, -50941, 1697, 0, 0, 39, '1696'),
	(243, 1, 0, -50941, 1698, 0, 0, 39, '1697'),
	(243, 1, 0, -50941, 1699, 0, 0, 39, '1698'),
	(243, 1, 0, -50941, 1700, 0, 0, 39, '1699'),
	(243, 1, 0, -50941, 1701, 0, 0, 39, '1700'),
	(243, 1, 0, -50941, 1702, 0, 0, 39, '1701'),
	(243, 1, 0, -50941, 1703, 0, 0, 39, '1702'),
	(243, 1, 0, -50941, 1704, 0, 0, 39, '1703'),
	(243, 1, 0, -50941, 1705, 0, 0, 39, '1704'),
	(243, 1, 0, -50941, 1706, 0, 0, 39, '1705'),
	(243, 1, 0, -50941, 1707, 0, 0, 39, '1706'),
	(243, 1, 0, -50941, 1708, 0, 0, 39, '1707'),
	(243, 1, 0, -50941, 1709, 0, 0, 39, '1708'),
	(243, 1, 0, -50941, 1710, 0, 0, 39, '1709'),
	(243, 1, 0, -50941, 1711, 0, 0, 39, '1710'),
	(243, 1, 0, -50941, 1712, 0, 0, 39, '1711'),
	(243, 1, 0, -50941, 1713, 0, 0, 39, '1712'),
	(243, 1, 0, -50941, 1714, 0, 0, 39, '1713'),
	(243, 1, 0, -50941, 1715, 0, 0, 39, '1714'),
	(243, 1, 0, -50941, 1716, 0, 0, 39, '1715'),
	(243, 1, 0, -50941, 1717, 0, 0, 39, '1716'),
	(243, 1, 0, -50941, 1718, 0, 0, 39, '1717'),
	(243, 1, 0, -50941, 1719, 0, 0, 39, '1718'),
	(243, 1, 0, -50941, 1720, 0, 0, 39, '1719'),
	(243, 1, 0, -50941, 1721, 0, 0, 39, '1720'),
	(243, 1, 0, -50941, 1722, 0, 0, 39, '1721'),
	(243, 1, 0, -50941, 1723, 0, 0, 39, '1722'),
	(243, 1, 0, -50941, 1724, 0, 0, 39, '1723'),
	(243, 1, 0, -50941, 1725, 0, 0, 39, '1724'),
	(243, 1, 0, -50941, 1726, 0, 0, 39, '1725'),
	(243, 1, 0, -50941, 1727, 0, 0, 39, '1726'),
	(243, 1, 0, -50941, 1728, 0, 0, 39, '1727'),
	(243, 1, 0, -50941, 1729, 0, 0, 39, '1728'),
	(243, 1, 0, -50941, 1730, 0, 0, 39, '1729'),
	(243, 1, 0, -50941, 1731, 0, 0, 39, '1730'),
	(243, 1, 0, -50941, 1732, 0, 0, 39, '1731'),
	(243, 1, 0, -50941, 1733, 0, 0, 39, '1732'),
	(243, 1, 0, -50941, 1734, 0, 0, 39, '1733'),
	(243, 1, 0, -50941, 1735, 0, 0, 39, '1734'),
	(243, 1, 0, -50941, 1736, 0, 0, 39, '1735'),
	(243, 1, 0, -50941, 1737, 0, 0, 39, '1736'),
	(243, 1, 0, -50941, 1738, 0, 0, 39, '1737'),
	(243, 1, 0, -50941, 1739, 0, 0, 39, '1738'),
	(243, 1, 0, -50941, 1740, 0, 0, 39, '1739'),
	(243, 1, 0, -50941, 1741, 0, 0, 39, '1740'),
	(243, 1, 0, -50941, 1742, 0, 0, 39, '1741'),
	(243, 1, 0, -50941, 1743, 0, 0, 39, '1742'),
	(243, 1, 0, -50941, 1744, 0, 0, 39, '1743'),
	(243, 1, 0, -50941, 1745, 0, 0, 39, '1744'),
	(243, 1, 0, -50941, 1746, 0, 0, 39, '1745'),
	(243, 1, 0, -50941, 1747, 0, 0, 39, '1746'),
	(243, 1, 0, -50941, 1748, 0, 0, 39, '1747'),
	(243, 1, 0, -50941, 1749, 0, 0, 39, '1748'),
	(243, 1, 0, -50941, 1750, 0, 0, 39, '1749'),
	(243, 1, 0, -50941, 1751, 0, 0, 39, '1750'),
	(243, 1, 0, -50941, 1752, 0, 0, 39, '1751'),
	(243, 1, 0, -50941, 1753, 0, 0, 39, '1752'),
	(243, 1, 0, -50941, 1754, 0, 0, 39, '1753'),
	(243, 1, 0, -50941, 1755, 0, 0, 39, '1754'),
	(243, 1, 0, -50941, 1756, 0, 0, 39, '1755'),
	(243, 1, 0, -50941, 1757, 0, 0, 39, '1756'),
	(243, 1, 0, -50941, 1758, 0, 0, 39, '1757'),
	(243, 1, 0, -50941, 1759, 0, 0, 39, '1758'),
	(243, 1, 0, -50941, 1760, 0, 0, 39, '1759'),
	(243, 1, 0, -50941, 1761, 0, 0, 39, '1760'),
	(243, 1, 0, -50941, 1762, 0, 0, 39, '1761'),
	(243, 1, 0, -50941, 1763, 0, 0, 39, '1762'),
	(243, 1, 0, -50941, 1764, 0, 0, 39, '1763'),
	(243, 1, 0, -50941, 1765, 0, 0, 39, '1764'),
	(243, 1, 0, -50941, 1766, 0, 0, 39, '1765'),
	(243, 1, 0, -50941, 1767, 0, 0, 39, '1766'),
	(243, 1, 0, -50941, 1768, 0, 0, 39, '1767'),
	(243, 1, 0, -50941, 1769, 0, 0, 39, '1768'),
	(243, 1, 0, -50941, 1770, 0, 0, 39, '1769'),
	(243, 1, 0, -50941, 1771, 0, 0, 39, '1770'),
	(243, 1, 0, -50941, 1772, 0, 0, 39, '1771'),
	(243, 1, 0, -50941, 1773, 0, 0, 39, '1772'),
	(243, 1, 0, -50941, 1774, 0, 0, 39, '1773'),
	(243, 1, 0, -50941, 1775, 0, 0, 39, '1774'),
	(243, 1, 0, -50941, 1776, 0, 0, 39, '1775'),
	(243, 1, 0, -50941, 1777, 0, 0, 39, '1776'),
	(243, 1, 0, -50941, 1778, 0, 0, 39, '1777'),
	(243, 1, 0, -50941, 1779, 0, 0, 39, '1778'),
	(243, 1, 0, -50941, 1780, 0, 0, 39, '1779'),
	(243, 1, 0, -50941, 1781, 0, 0, 39, '1780'),
	(243, 1, 0, -50941, 1782, 0, 0, 39, '1781'),
	(243, 1, 0, -50941, 1783, 0, 0, 39, '1782'),
	(243, 1, 0, -50941, 1784, 0, 0, 39, '1783'),
	(243, 1, 0, -50941, 1785, 0, 0, 39, '1784'),
	(243, 1, 0, -50941, 1786, 0, 0, 39, '1785'),
	(243, 1, 0, -50941, 1787, 0, 0, 39, '1786'),
	(243, 1, 0, -50941, 1788, 0, 0, 39, '1787'),
	(243, 1, 0, -50941, 1789, 0, 0, 39, '1788'),
	(243, 1, 0, -50941, 1790, 0, 0, 39, '1789'),
	(243, 1, 0, -50941, 1791, 0, 0, 39, '1790'),
	(243, 1, 0, -50941, 1792, 0, 0, 39, '1791'),
	(243, 1, 0, -50941, 1793, 0, 0, 39, '1792'),
	(243, 1, 0, -50941, 1794, 0, 0, 39, '1793'),
	(243, 1, 0, -50941, 1795, 0, 0, 39, '1794'),
	(243, 1, 0, -50941, 1796, 0, 0, 39, '1795'),
	(243, 1, 0, -50941, 1797, 0, 0, 39, '1796'),
	(243, 1, 0, -50941, 1798, 0, 0, 39, '1797'),
	(243, 1, 0, -50941, 1799, 0, 0, 39, '1798'),
	(243, 1, 0, -50941, 1800, 0, 0, 39, '1799'),
	(243, 1, 0, -50941, 1801, 0, 0, 39, '1800'),
	(243, 1, 0, -50941, 1802, 0, 0, 39, '1801'),
	(243, 1, 0, -50941, 1803, 0, 0, 39, '1802'),
	(243, 1, 0, -50941, 1804, 0, 0, 39, '1803'),
	(243, 1, 0, -50941, 1805, 0, 0, 39, '1804'),
	(243, 1, 0, -50941, 1806, 0, 0, 39, '1805'),
	(243, 1, 0, -50941, 1807, 0, 0, 39, '1806'),
	(243, 1, 0, -50941, 1808, 0, 0, 39, '1807'),
	(243, 1, 0, -50941, 1809, 0, 0, 39, '1808'),
	(243, 1, 0, -50941, 1810, 0, 0, 39, '1809'),
	(243, 1, 0, -50941, 1811, 0, 0, 39, '1810'),
	(243, 1, 0, -50941, 1812, 0, 0, 39, '1811'),
	(243, 1, 0, -50941, 1813, 0, 0, 39, '1812'),
	(243, 1, 0, -50941, 1814, 0, 0, 39, '1813'),
	(243, 1, 0, -50941, 1815, 0, 0, 39, '1814'),
	(243, 1, 0, -50941, 1816, 0, 0, 39, '1815'),
	(243, 1, 0, -50941, 1817, 0, 0, 39, '1816'),
	(243, 1, 0, -50941, 1818, 0, 0, 39, '1817'),
	(243, 1, 0, -50941, 1819, 0, 0, 39, '1818'),
	(243, 1, 0, -50941, 1820, 0, 0, 39, '1819'),
	(243, 1, 0, -50941, 1821, 0, 0, 39, '1820'),
	(243, 1, 0, -50941, 1822, 0, 0, 39, '1821'),
	(243, 1, 0, -50941, 1823, 0, 0, 39, '1822'),
	(243, 1, 0, -50941, 1824, 0, 0, 39, '1823'),
	(243, 1, 0, -50941, 1825, 0, 0, 39, '1824'),
	(243, 1, 0, -50941, 1826, 0, 0, 39, '1825'),
	(243, 1, 0, -50941, 1827, 0, 0, 39, '1826'),
	(243, 1, 0, -50941, 1828, 0, 0, 39, '1827'),
	(243, 1, 0, -50941, 1829, 0, 0, 39, '1828'),
	(243, 1, 0, -50941, 1830, 0, 0, 39, '1829'),
	(243, 1, 0, -50941, 1831, 0, 0, 39, '1830'),
	(243, 1, 0, -50941, 1832, 0, 0, 39, '1831'),
	(243, 1, 0, -50941, 1833, 0, 0, 39, '1832'),
	(243, 1, 0, -50941, 1834, 0, 0, 39, '1833'),
	(243, 1, 0, -50941, 1835, 0, 0, 39, '1834'),
	(243, 1, 0, -50941, 1836, 0, 0, 39, '1835'),
	(243, 1, 0, -50941, 1837, 0, 0, 39, '1836'),
	(243, 1, 0, -50941, 1838, 0, 0, 39, '1837'),
	(243, 1, 0, -50941, 1839, 0, 0, 39, '1838'),
	(243, 1, 0, -50941, 1840, 0, 0, 39, '1839'),
	(243, 1, 0, -50941, 1841, 0, 0, 39, '1840'),
	(243, 1, 0, -50941, 1842, 0, 0, 39, '1841'),
	(243, 1, 0, -50941, 1843, 0, 0, 39, '1842'),
	(243, 1, 0, -50941, 1844, 0, 0, 39, '1843'),
	(243, 1, 0, -50941, 1845, 0, 0, 39, '1844'),
	(243, 1, 0, -50941, 1846, 0, 0, 39, '1845'),
	(243, 1, 0, -50941, 1847, 0, 0, 39, '1846'),
	(243, 1, 0, -50941, 1848, 0, 0, 39, '1847'),
	(243, 1, 0, -50941, 1849, 0, 0, 39, '1848'),
	(243, 1, 0, -50941, 1850, 0, 0, 39, '1849'),
	(243, 1, 0, -50941, 1851, 0, 0, 39, '1850'),
	(243, 1, 0, -50941, 1852, 0, 0, 39, '1851'),
	(243, 1, 0, -50941, 1853, 0, 0, 39, '1852'),
	(243, 1, 0, -50941, 1854, 0, 0, 39, '1853'),
	(243, 1, 0, -50941, 1855, 0, 0, 39, '1854'),
	(243, 1, 0, -50941, 1856, 0, 0, 39, '1855'),
	(243, 1, 0, -50941, 1857, 0, 0, 39, '1856'),
	(243, 1, 0, -50941, 1858, 0, 0, 39, '1857'),
	(243, 1, 0, -50941, 1859, 0, 0, 39, '1858'),
	(243, 1, 0, -50941, 1860, 0, 0, 39, '1859'),
	(243, 1, 0, -50941, 1861, 0, 0, 39, '1860'),
	(243, 1, 0, -50941, 1862, 0, 0, 39, '1861'),
	(243, 1, 0, -50941, 1863, 0, 0, 39, '1862'),
	(243, 1, 0, -50941, 1864, 0, 0, 39, '1863'),
	(243, 1, 0, -50941, 1865, 0, 0, 39, '1864'),
	(243, 1, 0, -50941, 1866, 0, 0, 39, '1865'),
	(243, 1, 0, -50941, 1867, 0, 0, 39, '1866'),
	(243, 1, 0, -50941, 1868, 0, 0, 39, '1867'),
	(243, 1, 0, -50941, 1869, 0, 0, 39, '1868'),
	(243, 1, 0, -50941, 1870, 0, 0, 39, '1869'),
	(243, 1, 0, -50941, 1871, 0, 0, 39, '1870'),
	(243, 1, 0, -50941, 1872, 0, 0, 39, '1871'),
	(243, 1, 0, -50941, 1873, 0, 0, 39, '1872'),
	(243, 1, 0, -50941, 1874, 0, 0, 39, '1873'),
	(243, 1, 0, -50941, 1875, 0, 0, 39, '1874'),
	(243, 1, 0, -50941, 1876, 0, 0, 39, '1875'),
	(243, 1, 0, -50941, 1877, 0, 0, 39, '1876'),
	(243, 1, 0, -50941, 1878, 0, 0, 39, '1877'),
	(243, 1, 0, -50941, 1879, 0, 0, 39, '1878'),
	(243, 1, 0, -50941, 1880, 0, 0, 39, '1879'),
	(243, 1, 0, -50941, 1881, 0, 0, 39, '1880'),
	(243, 1, 0, -50941, 1882, 0, 0, 39, '1881'),
	(243, 1, 0, -50941, 1883, 0, 0, 39, '1882'),
	(243, 1, 0, -50941, 1884, 0, 0, 39, '1883'),
	(243, 1, 0, -50941, 1885, 0, 0, 39, '1884'),
	(243, 1, 0, -50941, 1886, 0, 0, 39, '1885'),
	(243, 1, 0, -50941, 1887, 0, 0, 39, '1886'),
	(243, 1, 0, -50941, 1888, 0, 0, 39, '1887'),
	(243, 1, 0, -50941, 1889, 0, 0, 39, '1888'),
	(243, 1, 0, -50941, 1890, 0, 0, 39, '1889'),
	(243, 1, 0, -50941, 1891, 0, 0, 39, '1890'),
	(243, 1, 0, -50941, 1892, 0, 0, 39, '1891'),
	(243, 1, 0, -50941, 1893, 0, 0, 39, '1892'),
	(243, 1, 0, -50941, 1894, 0, 0, 39, '1893'),
	(243, 1, 0, -50941, 1895, 0, 0, 39, '1894'),
	(243, 1, 0, -50941, 1896, 0, 0, 39, '1895'),
	(243, 1, 0, -50941, 1897, 0, 0, 39, '1896'),
	(243, 1, 0, -50941, 1898, 0, 0, 39, '1897'),
	(243, 1, 0, -50941, 1899, 0, 0, 39, '1898'),
	(243, 1, 0, -50941, 1900, 0, 0, 39, '1899'),
	(243, 1, 0, -50941, 1901, 0, 0, 39, '1900'),
	(243, 1, 0, -50941, 1902, 0, 0, 39, '1901'),
	(243, 1, 0, -50941, 1903, 0, 0, 39, '1902'),
	(243, 1, 0, -50941, 1904, 0, 0, 39, '1903'),
	(243, 1, 0, -50941, 1905, 0, 0, 39, '1904'),
	(243, 1, 0, -50941, 1906, 0, 0, 39, '1905'),
	(243, 1, 0, -50941, 1907, 0, 0, 39, '1906'),
	(243, 1, 0, -50941, 1908, 0, 0, 39, '1907'),
	(243, 1, 0, -50941, 1909, 0, 0, 39, '1908'),
	(243, 1, 0, -50941, 1910, 0, 0, 39, '1909'),
	(243, 1, 0, -50941, 1911, 0, 0, 39, '1910'),
	(243, 1, 0, -50941, 1912, 0, 0, 39, '1911'),
	(243, 1, 0, -50941, 1913, 0, 0, 39, '1912'),
	(243, 1, 0, -50941, 1914, 0, 0, 39, '1913'),
	(243, 1, 0, -50941, 1915, 0, 0, 39, '1914'),
	(243, 1, 0, -50941, 1916, 0, 0, 39, '1915'),
	(243, 1, 0, -50941, 1917, 0, 0, 39, '1916'),
	(243, 1, 0, -50941, 1918, 0, 0, 39, '1917'),
	(243, 1, 0, -50941, 1919, 0, 0, 39, '1918'),
	(243, 1, 0, -50941, 1920, 0, 0, 39, '1919'),
	(243, 1, 0, -50941, 1921, 0, 0, 39, '1920'),
	(243, 1, 0, -50941, 1922, 0, 0, 39, '1921'),
	(243, 1, 0, -50941, 1923, 0, 0, 39, '1922'),
	(243, 1, 0, -50941, 1924, 0, 0, 39, '1923'),
	(243, 1, 0, -50941, 1925, 0, 0, 39, '1924'),
	(243, 1, 0, -50941, 1926, 0, 0, 39, '1925'),
	(243, 1, 0, -50941, 1927, 0, 0, 39, '1926'),
	(243, 1, 0, -50941, 1928, 0, 0, 39, '1927'),
	(243, 1, 0, -50941, 1929, 0, 0, 39, '1928'),
	(243, 1, 0, -50941, 1930, 0, 0, 39, '1929'),
	(243, 1, 0, -50941, 1931, 0, 0, 39, '1930'),
	(243, 1, 0, -50941, 1932, 0, 0, 39, '1931'),
	(243, 1, 0, -50941, 1933, 0, 0, 39, '1932'),
	(243, 1, 0, -50941, 1934, 0, 0, 39, '1933'),
	(243, 1, 0, -50941, 1935, 0, 0, 39, '1934'),
	(243, 1, 0, -50941, 1936, 0, 0, 39, '1935'),
	(243, 1, 0, -50941, 1937, 0, 0, 39, '1936'),
	(243, 1, 0, -50941, 1938, 0, 0, 39, '1937'),
	(243, 1, 0, -50941, 1939, 0, 0, 39, '1938'),
	(243, 1, 0, -50941, 1940, 0, 0, 39, '1939'),
	(243, 1, 0, -50941, 1941, 0, 0, 39, '1940'),
	(243, 1, 0, -50941, 1942, 0, 0, 39, '1941'),
	(243, 1, 0, -50941, 1943, 0, 0, 39, '1942'),
	(243, 1, 0, -50941, 1944, 0, 0, 39, '1943'),
	(243, 1, 0, -50941, 1945, 0, 0, 39, '1944'),
	(243, 1, 0, -50941, 1946, 0, 0, 39, '1945'),
	(243, 1, 0, -50941, 1947, 0, 0, 39, '1946'),
	(243, 1, 0, -50941, 1948, 0, 0, 39, '1947'),
	(243, 1, 0, -50941, 1949, 0, 0, 39, '1948'),
	(243, 1, 0, -50941, 1950, 0, 0, 39, '1949'),
	(243, 1, 0, -50941, 1951, 0, 0, 39, '1950'),
	(243, 1, 0, -50941, 1952, 0, 0, 39, '1951'),
	(243, 1, 0, -50941, 1953, 0, 0, 39, '1952'),
	(243, 1, 0, -50941, 1954, 0, 0, 39, '1953'),
	(243, 1, 0, -50941, 1955, 0, 0, 39, '1954'),
	(243, 1, 0, -50941, 1956, 0, 0, 39, '1955'),
	(243, 1, 0, -50941, 1957, 0, 0, 39, '1956'),
	(243, 1, 0, -50941, 1958, 0, 0, 39, '1957'),
	(243, 1, 0, -50941, 1959, 0, 0, 39, '1958'),
	(243, 1, 0, -50941, 1960, 0, 0, 39, '1959'),
	(243, 1, 0, -50941, 1961, 0, 0, 39, '1960'),
	(243, 1, 0, -50941, 1962, 0, 0, 39, '1961'),
	(243, 1, 0, -50941, 1963, 0, 0, 39, '1962'),
	(243, 1, 0, -50941, 1964, 0, 0, 39, '1963'),
	(243, 1, 0, -50941, 1965, 0, 0, 39, '1964'),
	(243, 1, 0, -50941, 1966, 0, 0, 39, '1965'),
	(243, 1, 0, -50941, 1967, 0, 0, 39, '1966'),
	(243, 1, 0, -50941, 1968, 0, 0, 39, '1967'),
	(243, 1, 0, -50941, 1969, 0, 0, 39, '1968'),
	(243, 1, 0, -50941, 1970, 0, 0, 39, '1969'),
	(243, 1, 0, -50941, 1971, 0, 0, 39, '1970'),
	(243, 1, 0, -50941, 1972, 0, 0, 39, '1971'),
	(243, 1, 0, -50941, 1973, 0, 0, 39, '1972'),
	(243, 1, 0, -50941, 1974, 0, 0, 39, '1973'),
	(243, 1, 0, -50941, 1975, 0, 0, 39, '1974'),
	(243, 1, 0, -50941, 1976, 0, 0, 39, '1975'),
	(243, 1, 0, -50941, 1977, 0, 0, 39, '1976'),
	(243, 1, 0, -50941, 1978, 0, 0, 39, '1977'),
	(243, 1, 0, -50941, 1979, 0, 0, 39, '1978'),
	(243, 1, 0, -50941, 1980, 0, 0, 39, '1979'),
	(243, 1, 0, -50941, 1981, 0, 0, 39, '1980'),
	(243, 1, 0, -50941, 1982, 0, 0, 39, '1981'),
	(243, 1, 0, -50941, 1983, 0, 0, 39, '1982'),
	(243, 1, 0, -50941, 1984, 0, 0, 39, '1983'),
	(243, 1, 0, -50941, 1985, 0, 0, 39, '1984'),
	(243, 1, 0, -50941, 1986, 0, 0, 39, '1985'),
	(243, 1, 0, -50941, 1987, 0, 0, 39, '1986'),
	(243, 1, 0, -50941, 1988, 0, 0, 39, '1987'),
	(243, 1, 0, -50941, 1989, 0, 0, 39, '1988'),
	(243, 1, 0, -50941, 1990, 0, 0, 39, '1989'),
	(243, 1, 0, -50941, 1991, 0, 0, 39, '1990'),
	(243, 1, 0, -50941, 1992, 0, 0, 39, '1991'),
	(243, 1, 0, -50941, 1993, 0, 0, 39, '1992'),
	(243, 1, 0, -50941, 1994, 0, 0, 39, '1993'),
	(243, 1, 0, -50941, 1995, 0, 0, 39, '1994'),
	(243, 1, 0, -50941, 1996, 0, 0, 39, '1995'),
	(243, 1, 0, -50941, 1997, 0, 0, 39, '1996'),
	(243, 1, 0, -50941, 1998, 0, 0, 39, '1997'),
	(243, 1, 0, -50941, 1999, 0, 0, 39, '1998'),
	(243, 1, 0, -50941, 2000, 0, 0, 39, '1999'),
	(243, 1, 0, -50941, 2001, 0, 0, 39, '2000'),
	(243, 1, 0, -50941, 2002, 0, 0, 39, '2001'),
	(243, 1, 0, -50941, 2003, 0, 0, 39, '2002'),
	(243, 1, 0, -50941, 2004, 0, 0, 39, '2003'),
	(243, 1, 0, -50941, 2005, 0, 0, 39, '2004'),
	(243, 1, 0, -50941, 2006, 0, 0, 39, '2005'),
	(243, 1, 0, -50941, 2007, 0, 0, 39, '2006'),
	(243, 1, 0, -50941, 2008, 0, 0, 39, '2007'),
	(243, 1, 0, -50941, 2009, 0, 0, 39, '2008'),
	(243, 1, 0, -50941, 2010, 0, 0, 39, '2009'),
	(243, 1, 0, -50941, 2011, 0, 0, 39, '2010'),
	(243, 1, 0, -50941, 2012, 0, 0, 39, '2011'),
	(243, 1, 0, -50941, 2013, 0, 0, 39, '2012'),
	(243, 1, 0, -50941, 2014, 0, 0, 39, '2013'),
	(243, 1, 0, -50941, 2015, 0, 0, 39, '2014'),
	(243, 1, 0, -50941, 2016, 0, 0, 39, '2015'),
	(243, 1, 0, -50941, 2017, 0, 0, 39, '2016'),
	(243, 1, 0, -50941, 2018, 0, 0, 39, '2017'),
	(243, 1, 0, -50941, 2019, 0, 0, 39, '2018'),
	(243, 1, 0, -50941, 2020, 0, 0, 39, '2019'),
	(243, 1, 0, -50941, 2021, 0, 0, 39, '2020'),
	(243, 1, 0, -50941, 2022, 0, 0, 39, '2021'),
	(243, 1, 0, -50941, 2023, 0, 0, 39, '2022'),
	(243, 1, 0, -50941, 2024, 0, 0, 39, '2023'),
	(243, 1, 0, -50941, 2025, 0, 0, 39, '2024'),
	(243, 1, 0, -50941, 2026, 0, 0, 39, '2025'),
	(243, 1, 0, -50941, 2027, 0, 0, 39, '2026'),
	(243, 1, 0, -50941, 2028, 0, 0, 39, '2027'),
	(243, 1, 0, -50941, 2029, 0, 0, 39, '2028'),
	(243, 1, 0, -50941, 2030, 0, 0, 39, '2029'),
	(243, 1, 0, -50941, 2031, 0, 0, 39, '2030'),
	(243, 1, 0, -50941, 2032, 0, 0, 39, '2031'),
	(243, 1, 0, -50941, 2033, 0, 0, 39, '2032'),
	(243, 1, 0, -50941, 2034, 0, 0, 39, '2033'),
	(243, 1, 0, -50941, 2035, 0, 0, 39, '2034'),
	(243, 1, 0, -50941, 2036, 0, 0, 39, '2035'),
	(243, 1, 0, -50941, 2037, 0, 0, 39, '2036'),
	(243, 1, 0, -50941, 2038, 0, 0, 39, '2037'),
	(243, 1, 0, -50941, 2039, 0, 0, 39, '2038'),
	(243, 1, 0, -50941, 2040, 0, 0, 39, '2039'),
	(243, 1, 0, -50941, 2041, 0, 0, 39, '2040'),
	(243, 1, 0, -50941, 2042, 0, 0, 39, '2041'),
	(243, 1, 0, -50941, 2043, 0, 0, 39, '2042'),
	(243, 1, 0, -50941, 2044, 0, 0, 39, '2043'),
	(243, 1, 0, -50941, 2045, 0, 0, 39, '2044'),
	(243, 1, 0, -50941, 2046, 0, 0, 39, '2045'),
	(243, 1, 0, -50941, 2047, 0, 0, 39, '2046'),
	(243, 1, 0, -50941, 2048, 0, 0, 39, '2047'),
	(243, 1, 0, -50940, 1, 0, 0, 39, '0'),
	(243, 1, 0, -50940, 2, 0, 0, 39, '1'),
	(243, 1, 0, -50940, 3, 0, 0, 39, '2'),
	(243, 1, 0, -50940, 4, 0, 0, 39, '3'),
	(243, 1, 0, -50940, 5, 0, 0, 39, '4'),
	(243, 1, 0, -50940, 6, 0, 0, 39, '5'),
	(243, 1, 0, -50940, 7, 0, 0, 39, '6'),
	(243, 1, 0, -50940, 8, 0, 0, 39, '7'),
	(243, 1, 0, -50940, 9, 0, 0, 39, '8'),
	(243, 1, 0, -50940, 10, 0, 0, 39, '9'),
	(243, 1, 0, -50940, 11, 0, 0, 39, '10'),
	(243, 1, 0, -50940, 12, 0, 0, 39, '11'),
	(243, 1, 0, -50940, 13, 0, 0, 39, '12'),
	(243, 1, 0, -50940, 14, 0, 0, 39, '13'),
	(243, 1, 0, -50940, 15, 0, 0, 39, '14'),
	(243, 1, 0, -50940, 16, 0, 0, 39, '15'),
	(243, 1, 0, -50940, 17, 0, 0, 39, '16'),
	(243, 1, 0, -50940, 18, 0, 0, 39, '17'),
	(243, 1, 0, -50940, 19, 0, 0, 39, '18'),
	(243, 1, 0, -50940, 20, 0, 0, 39, '19'),
	(243, 1, 0, -50940, 21, 0, 0, 39, '20'),
	(243, 1, 0, -50940, 22, 0, 0, 39, '21'),
	(243, 1, 0, -50940, 23, 0, 0, 39, '22'),
	(243, 1, 0, -50940, 24, 0, 0, 39, '23'),
	(243, 1, 0, -50940, 25, 0, 0, 39, '24'),
	(243, 1, 0, -50940, 26, 0, 0, 39, '25'),
	(243, 1, 0, -50940, 27, 0, 0, 39, '26'),
	(243, 1, 0, -50940, 28, 0, 0, 39, '27'),
	(243, 1, 0, -50940, 29, 0, 0, 39, '28'),
	(243, 1, 0, -50940, 30, 0, 0, 39, '29'),
	(243, 1, 0, -50940, 31, 0, 0, 39, '30'),
	(243, 1, 0, -50940, 32, 0, 0, 39, '31'),
	(243, 1, 0, -50940, 33, 0, 0, 39, '32'),
	(243, 1, 0, -50940, 34, 0, 0, 39, '33'),
	(243, 1, 0, -50940, 35, 0, 0, 39, '34'),
	(243, 1, 0, -50940, 36, 0, 0, 39, '35'),
	(243, 1, 0, -50940, 37, 0, 0, 39, '36'),
	(243, 1, 0, -50940, 38, 0, 0, 39, '37'),
	(243, 1, 0, -50940, 39, 0, 0, 39, '38'),
	(243, 1, 0, -50940, 40, 0, 0, 39, '39'),
	(243, 1, 0, -50940, 41, 0, 0, 39, '40'),
	(243, 1, 0, -50940, 42, 0, 0, 39, '41'),
	(243, 1, 0, -50940, 43, 0, 0, 39, '42'),
	(243, 1, 0, -50940, 44, 0, 0, 39, '43'),
	(243, 1, 0, -50940, 45, 0, 0, 39, '44'),
	(243, 1, 0, -50940, 46, 0, 0, 39, '45'),
	(243, 1, 0, -50940, 47, 0, 0, 39, '46'),
	(243, 1, 0, -50940, 48, 0, 0, 39, '47'),
	(243, 1, 0, -50940, 49, 0, 0, 39, '48'),
	(243, 1, 0, -50940, 50, 0, 0, 39, '49'),
	(243, 1, 0, -50940, 51, 0, 0, 39, '50'),
	(243, 1, 0, -50940, 52, 0, 0, 39, '51'),
	(243, 1, 0, -50940, 53, 0, 0, 39, '52'),
	(243, 1, 0, -50940, 54, 0, 0, 39, '53'),
	(243, 1, 0, -50940, 55, 0, 0, 39, '54'),
	(243, 1, 0, -50940, 56, 0, 0, 39, '55'),
	(243, 1, 0, -50940, 57, 0, 0, 39, '56'),
	(243, 1, 0, -50940, 58, 0, 0, 39, '57'),
	(243, 1, 0, -50940, 59, 0, 0, 39, '58'),
	(243, 1, 0, -50940, 60, 0, 0, 39, '59'),
	(243, 1, 0, -50940, 61, 0, 0, 39, '60'),
	(243, 1, 0, -50940, 62, 0, 0, 39, '61'),
	(243, 1, 0, -50940, 63, 0, 0, 39, '62'),
	(243, 1, 0, -50940, 64, 0, 0, 39, '63'),
	(243, 1, 0, -50940, 65, 0, 0, 39, '64'),
	(243, 1, 0, -50940, 66, 0, 0, 39, '65'),
	(243, 1, 0, -50940, 67, 0, 0, 39, '66'),
	(243, 1, 0, -50940, 68, 0, 0, 39, '67'),
	(243, 1, 0, -50940, 69, 0, 0, 39, '68'),
	(243, 1, 0, -50940, 70, 0, 0, 39, '69'),
	(243, 1, 0, -50940, 71, 0, 0, 39, '70'),
	(243, 1, 0, -50940, 72, 0, 0, 39, '71'),
	(243, 1, 0, -50940, 73, 0, 0, 39, '72'),
	(243, 1, 0, -50940, 74, 0, 0, 39, '73'),
	(243, 1, 0, -50940, 75, 0, 0, 39, '74'),
	(243, 1, 0, -50940, 76, 0, 0, 39, '75'),
	(243, 1, 0, -50940, 77, 0, 0, 39, '76'),
	(243, 1, 0, -50940, 78, 0, 0, 39, '77'),
	(243, 1, 0, -50940, 79, 0, 0, 39, '78'),
	(243, 1, 0, -50940, 80, 0, 0, 39, '79'),
	(243, 1, 0, -50940, 81, 0, 0, 39, '80'),
	(243, 1, 0, -50940, 82, 0, 0, 39, '81'),
	(243, 1, 0, -50940, 83, 0, 0, 39, '82'),
	(243, 1, 0, -50940, 84, 0, 0, 39, '83'),
	(243, 1, 0, -50940, 85, 0, 0, 39, '84'),
	(243, 1, 0, -50940, 86, 0, 0, 39, '85'),
	(243, 1, 0, -50940, 87, 0, 0, 39, '86'),
	(243, 1, 0, -50940, 88, 0, 0, 39, '87'),
	(243, 1, 0, -50940, 89, 0, 0, 39, '88'),
	(243, 1, 0, -50940, 90, 0, 0, 39, '89'),
	(243, 1, 0, -50940, 91, 0, 0, 39, '90'),
	(243, 1, 0, -50940, 92, 0, 0, 39, '91'),
	(243, 1, 0, -50940, 93, 0, 0, 39, '92'),
	(243, 1, 0, -50940, 94, 0, 0, 39, '93'),
	(243, 1, 0, -50940, 95, 0, 0, 39, '94'),
	(243, 1, 0, -50940, 96, 0, 0, 39, '95'),
	(243, 1, 0, -50940, 97, 0, 0, 39, '96'),
	(243, 1, 0, -50940, 98, 0, 0, 39, '97'),
	(243, 1, 0, -50940, 99, 0, 0, 39, '98'),
	(243, 1, 0, -50940, 100, 0, 0, 39, '99'),
	(243, 1, 0, -50940, 101, 0, 0, 39, '100'),
	(243, 1, 0, -50940, 102, 0, 0, 39, '101'),
	(243, 1, 0, -50940, 103, 0, 0, 39, '102'),
	(243, 1, 0, -50940, 104, 0, 0, 39, '103'),
	(243, 1, 0, -50940, 105, 0, 0, 39, '104'),
	(243, 1, 0, -50940, 106, 0, 0, 39, '105'),
	(243, 1, 0, -50940, 107, 0, 0, 39, '106'),
	(243, 1, 0, -50940, 108, 0, 0, 39, '107'),
	(243, 1, 0, -50940, 109, 0, 0, 39, '108'),
	(243, 1, 0, -50940, 110, 0, 0, 39, '109'),
	(243, 1, 0, -50940, 111, 0, 0, 39, '110'),
	(243, 1, 0, -50940, 112, 0, 0, 39, '111'),
	(243, 1, 0, -50940, 113, 0, 0, 39, '112'),
	(243, 1, 0, -50940, 114, 0, 0, 39, '113'),
	(243, 1, 0, -50940, 115, 0, 0, 39, '114'),
	(243, 1, 0, -50940, 116, 0, 0, 39, '115'),
	(243, 1, 0, -50940, 117, 0, 0, 39, '116'),
	(243, 1, 0, -50940, 118, 0, 0, 39, '117'),
	(243, 1, 0, -50940, 119, 0, 0, 39, '118'),
	(243, 1, 0, -50940, 120, 0, 0, 39, '119'),
	(243, 1, 0, -50940, 121, 0, 0, 39, '120'),
	(243, 1, 0, -50940, 122, 0, 0, 39, '121'),
	(243, 1, 0, -50940, 123, 0, 0, 39, '122'),
	(243, 1, 0, -50940, 124, 0, 0, 39, '123'),
	(243, 1, 0, -50940, 125, 0, 0, 39, '124'),
	(243, 1, 0, -50940, 126, 0, 0, 39, '125'),
	(243, 1, 0, -50940, 127, 0, 0, 39, '126'),
	(243, 1, 0, -50940, 128, 0, 0, 39, '127'),
	(243, 1, 0, -50940, 129, 0, 0, 39, '128'),
	(243, 1, 0, -50940, 130, 0, 0, 39, '129'),
	(243, 1, 0, -50940, 131, 0, 0, 39, '130'),
	(243, 1, 0, -50940, 132, 0, 0, 39, '131'),
	(243, 1, 0, -50940, 133, 0, 0, 39, '132'),
	(243, 1, 0, -50940, 134, 0, 0, 39, '133'),
	(243, 1, 0, -50940, 135, 0, 0, 39, '134'),
	(243, 1, 0, -50940, 136, 0, 0, 39, '135'),
	(243, 1, 0, -50940, 137, 0, 0, 39, '136'),
	(243, 1, 0, -50940, 138, 0, 0, 39, '137'),
	(243, 1, 0, -50940, 139, 0, 0, 39, '138'),
	(243, 1, 0, -50940, 140, 0, 0, 39, '139'),
	(243, 1, 0, -50940, 141, 0, 0, 39, '140'),
	(243, 1, 0, -50940, 142, 0, 0, 39, '141'),
	(243, 1, 0, -50940, 143, 0, 0, 39, '142'),
	(243, 1, 0, -50940, 144, 0, 0, 39, '143'),
	(243, 1, 0, -50940, 145, 0, 0, 39, '144'),
	(243, 1, 0, -50940, 146, 0, 0, 39, '145'),
	(243, 1, 0, -50940, 147, 0, 0, 39, '146'),
	(243, 1, 0, -50940, 148, 0, 0, 39, '147'),
	(243, 1, 0, -50940, 149, 0, 0, 39, '148'),
	(243, 1, 0, -50940, 150, 0, 0, 39, '149'),
	(243, 1, 0, -50940, 151, 0, 0, 39, '150'),
	(243, 1, 0, -50940, 152, 0, 0, 39, '151'),
	(243, 1, 0, -50940, 153, 0, 0, 39, '152'),
	(243, 1, 0, -50940, 154, 0, 0, 39, '153'),
	(243, 1, 0, -50940, 155, 0, 0, 39, '154'),
	(243, 1, 0, -50940, 156, 0, 0, 39, '155'),
	(243, 1, 0, -50940, 157, 0, 0, 39, '156'),
	(243, 1, 0, -50940, 158, 0, 0, 39, '157'),
	(243, 1, 0, -50940, 159, 0, 0, 39, '158'),
	(243, 1, 0, -50940, 160, 0, 0, 39, '159'),
	(243, 1, 0, -50940, 161, 0, 0, 39, '160'),
	(243, 1, 0, -50940, 162, 0, 0, 39, '161'),
	(243, 1, 0, -50940, 163, 0, 0, 39, '162'),
	(243, 1, 0, -50940, 164, 0, 0, 39, '163'),
	(243, 1, 0, -50940, 165, 0, 0, 39, '164'),
	(243, 1, 0, -50940, 166, 0, 0, 39, '165'),
	(243, 1, 0, -50940, 167, 0, 0, 39, '166'),
	(243, 1, 0, -50940, 168, 0, 0, 39, '167'),
	(243, 1, 0, -50940, 169, 0, 0, 39, '168'),
	(243, 1, 0, -50940, 170, 0, 0, 39, '169'),
	(243, 1, 0, -50940, 171, 0, 0, 39, '170'),
	(243, 1, 0, -50940, 172, 0, 0, 39, '171'),
	(243, 1, 0, -50940, 173, 0, 0, 39, '172'),
	(243, 1, 0, -50940, 174, 0, 0, 39, '173'),
	(243, 1, 0, -50940, 175, 0, 0, 39, '174'),
	(243, 1, 0, -50940, 176, 0, 0, 39, '175'),
	(243, 1, 0, -50940, 177, 0, 0, 39, '176'),
	(243, 1, 0, -50940, 178, 0, 0, 39, '177'),
	(243, 1, 0, -50940, 179, 0, 0, 39, '178'),
	(243, 1, 0, -50940, 180, 0, 0, 39, '179'),
	(243, 1, 0, -50940, 181, 0, 0, 39, '180'),
	(243, 1, 0, -50940, 182, 0, 0, 39, '181'),
	(243, 1, 0, -50940, 183, 0, 0, 39, '182'),
	(243, 1, 0, -50940, 184, 0, 0, 39, '183'),
	(243, 1, 0, -50940, 185, 0, 0, 39, '184'),
	(243, 1, 0, -50940, 186, 0, 0, 39, '185'),
	(243, 1, 0, -50940, 187, 0, 0, 39, '186'),
	(243, 1, 0, -50940, 188, 0, 0, 39, '187'),
	(243, 1, 0, -50940, 189, 0, 0, 39, '188'),
	(243, 1, 0, -50940, 190, 0, 0, 39, '189'),
	(243, 1, 0, -50940, 191, 0, 0, 39, '190'),
	(243, 1, 0, -50940, 192, 0, 0, 39, '191'),
	(243, 1, 0, -50940, 193, 0, 0, 39, '192'),
	(243, 1, 0, -50940, 194, 0, 0, 39, '193'),
	(243, 1, 0, -50940, 195, 0, 0, 39, '194'),
	(243, 1, 0, -50940, 196, 0, 0, 39, '195'),
	(243, 1, 0, -50940, 197, 0, 0, 39, '196'),
	(243, 1, 0, -50940, 198, 0, 0, 39, '197'),
	(243, 1, 0, -50940, 199, 0, 0, 39, '198'),
	(243, 1, 0, -50940, 200, 0, 0, 39, '199'),
	(243, 1, 0, -50940, 201, 0, 0, 39, '200'),
	(243, 1, 0, -50940, 202, 0, 0, 39, '201'),
	(243, 1, 0, -50940, 203, 0, 0, 39, '202'),
	(243, 1, 0, -50940, 204, 0, 0, 39, '203'),
	(243, 1, 0, -50940, 205, 0, 0, 39, '204'),
	(243, 1, 0, -50940, 206, 0, 0, 39, '205'),
	(243, 1, 0, -50940, 207, 0, 0, 39, '206'),
	(243, 1, 0, -50940, 208, 0, 0, 39, '207'),
	(243, 1, 0, -50940, 209, 0, 0, 39, '208'),
	(243, 1, 0, -50940, 210, 0, 0, 39, '209'),
	(243, 1, 0, -50940, 211, 0, 0, 39, '210'),
	(243, 1, 0, -50940, 212, 0, 0, 39, '211'),
	(243, 1, 0, -50940, 213, 0, 0, 39, '212'),
	(243, 1, 0, -50940, 214, 0, 0, 39, '213'),
	(243, 1, 0, -50940, 215, 0, 0, 39, '214'),
	(243, 1, 0, -50940, 216, 0, 0, 39, '215'),
	(243, 1, 0, -50940, 217, 0, 0, 39, '216'),
	(243, 1, 0, -50940, 218, 0, 0, 39, '217'),
	(243, 1, 0, -50940, 219, 0, 0, 39, '218'),
	(243, 1, 0, -50940, 220, 0, 0, 39, '219'),
	(243, 1, 0, -50940, 221, 0, 0, 39, '220'),
	(243, 1, 0, -50940, 222, 0, 0, 39, '221'),
	(243, 1, 0, -50940, 223, 0, 0, 39, '222'),
	(243, 1, 0, -50940, 224, 0, 0, 39, '223'),
	(243, 1, 0, -50940, 225, 0, 0, 39, '224'),
	(243, 1, 0, -50940, 226, 0, 0, 39, '225'),
	(243, 1, 0, -50940, 227, 0, 0, 39, '226'),
	(243, 1, 0, -50940, 228, 0, 0, 39, '227'),
	(243, 1, 0, -50940, 229, 0, 0, 39, '228'),
	(243, 1, 0, -50940, 230, 0, 0, 39, '229'),
	(243, 1, 0, -50940, 231, 0, 0, 39, '230'),
	(243, 1, 0, -50940, 232, 0, 0, 39, '231'),
	(243, 1, 0, -50940, 233, 0, 0, 39, '232'),
	(243, 1, 0, -50940, 234, 0, 0, 39, '233'),
	(243, 1, 0, -50940, 235, 0, 0, 39, '234'),
	(243, 1, 0, -50940, 236, 0, 0, 39, '235'),
	(243, 1, 0, -50940, 237, 0, 0, 39, '236'),
	(243, 1, 0, -50940, 238, 0, 0, 39, '237'),
	(243, 1, 0, -50940, 239, 0, 0, 39, '238'),
	(243, 1, 0, -50940, 240, 0, 0, 39, '239'),
	(243, 1, 0, -50940, 241, 0, 0, 39, '240'),
	(243, 1, 0, -50940, 242, 0, 0, 39, '241'),
	(243, 1, 0, -50940, 243, 0, 0, 39, '242'),
	(243, 1, 0, -50940, 244, 0, 0, 39, '243'),
	(243, 1, 0, -50940, 245, 0, 0, 39, '244'),
	(243, 1, 0, -50940, 246, 0, 0, 39, '245'),
	(243, 1, 0, -50940, 247, 0, 0, 39, '246'),
	(243, 1, 0, -50940, 248, 0, 0, 39, '247'),
	(243, 1, 0, -50940, 249, 0, 0, 39, '248'),
	(243, 1, 0, -50940, 250, 0, 0, 39, '249'),
	(243, 1, 0, -50940, 251, 0, 0, 39, '250'),
	(243, 1, 0, -50940, 252, 0, 0, 39, '251'),
	(243, 1, 0, -50940, 253, 0, 0, 39, '252'),
	(243, 1, 0, -50940, 254, 0, 0, 39, '253'),
	(243, 1, 0, -50940, 255, 0, 0, 39, '254'),
	(243, 1, 0, -50940, 256, 0, 0, 39, '255'),
	(243, 1, 0, -50940, 257, 0, 0, 39, '256'),
	(243, 1, 0, -50940, 258, 0, 0, 39, '257'),
	(243, 1, 0, -50940, 259, 0, 0, 39, '258'),
	(243, 1, 0, -50940, 260, 0, 0, 39, '259'),
	(243, 1, 0, -50940, 261, 0, 0, 39, '260'),
	(243, 1, 0, -50940, 262, 0, 0, 39, '261'),
	(243, 1, 0, -50940, 263, 0, 0, 39, '262'),
	(243, 1, 0, -50940, 264, 0, 0, 39, '263'),
	(243, 1, 0, -50940, 265, 0, 0, 39, '264'),
	(243, 1, 0, -50940, 266, 0, 0, 39, '265'),
	(243, 1, 0, -50940, 267, 0, 0, 39, '266'),
	(243, 1, 0, -50940, 268, 0, 0, 39, '267'),
	(243, 1, 0, -50940, 269, 0, 0, 39, '268'),
	(243, 1, 0, -50940, 270, 0, 0, 39, '269'),
	(243, 1, 0, -50940, 271, 0, 0, 39, '270'),
	(243, 1, 0, -50940, 272, 0, 0, 39, '271'),
	(243, 1, 0, -50940, 273, 0, 0, 39, '272'),
	(243, 1, 0, -50940, 274, 0, 0, 39, '273'),
	(243, 1, 0, -50940, 275, 0, 0, 39, '274'),
	(243, 1, 0, -50940, 276, 0, 0, 39, '275'),
	(243, 1, 0, -50940, 277, 0, 0, 39, '276'),
	(243, 1, 0, -50940, 278, 0, 0, 39, '277'),
	(243, 1, 0, -50940, 279, 0, 0, 39, '278'),
	(243, 1, 0, -50940, 280, 0, 0, 39, '279'),
	(243, 1, 0, -50940, 281, 0, 0, 39, '280'),
	(243, 1, 0, -50940, 282, 0, 0, 39, '281'),
	(243, 1, 0, -50940, 283, 0, 0, 39, '282'),
	(243, 1, 0, -50940, 284, 0, 0, 39, '283'),
	(243, 1, 0, -50940, 285, 0, 0, 39, '284'),
	(243, 1, 0, -50940, 286, 0, 0, 39, '285'),
	(243, 1, 0, -50940, 287, 0, 0, 39, '286'),
	(243, 1, 0, -50940, 288, 0, 0, 39, '287'),
	(243, 1, 0, -50940, 289, 0, 0, 39, '288'),
	(243, 1, 0, -50940, 290, 0, 0, 39, '289'),
	(243, 1, 0, -50940, 291, 0, 0, 39, '290'),
	(243, 1, 0, -50940, 292, 0, 0, 39, '291'),
	(243, 1, 0, -50940, 293, 0, 0, 39, '292'),
	(243, 1, 0, -50940, 294, 0, 0, 39, '293'),
	(243, 1, 0, -50940, 295, 0, 0, 39, '294'),
	(243, 1, 0, -50940, 296, 0, 0, 39, '295'),
	(243, 1, 0, -50940, 297, 0, 0, 39, '296'),
	(243, 1, 0, -50940, 298, 0, 0, 39, '297'),
	(243, 1, 0, -50940, 299, 0, 0, 39, '298'),
	(243, 1, 0, -50940, 300, 0, 0, 39, '299'),
	(243, 1, 0, -50940, 301, 0, 0, 39, '300'),
	(243, 1, 0, -50940, 302, 0, 0, 39, '301'),
	(243, 1, 0, -50940, 303, 0, 0, 39, '302'),
	(243, 1, 0, -50940, 304, 0, 0, 39, '303'),
	(243, 1, 0, -50940, 305, 0, 0, 39, '304'),
	(243, 1, 0, -50940, 306, 0, 0, 39, '305'),
	(243, 1, 0, -50940, 307, 0, 0, 39, '306'),
	(243, 1, 0, -50940, 308, 0, 0, 39, '307'),
	(243, 1, 0, -50940, 309, 0, 0, 39, '308'),
	(243, 1, 0, -50940, 310, 0, 0, 39, '309'),
	(243, 1, 0, -50940, 311, 0, 0, 39, '310'),
	(243, 1, 0, -50940, 312, 0, 0, 39, '311'),
	(243, 1, 0, -50940, 313, 0, 0, 39, '312'),
	(243, 1, 0, -50940, 314, 0, 0, 39, '313'),
	(243, 1, 0, -50940, 315, 0, 0, 39, '314'),
	(243, 1, 0, -50940, 316, 0, 0, 39, '315'),
	(243, 1, 0, -50940, 317, 0, 0, 39, '316'),
	(243, 1, 0, -50940, 318, 0, 0, 39, '317'),
	(243, 1, 0, -50940, 319, 0, 0, 39, '318'),
	(243, 1, 0, -50940, 320, 0, 0, 39, '319'),
	(243, 1, 0, -50940, 321, 0, 0, 39, '320'),
	(243, 1, 0, -50940, 322, 0, 0, 39, '321'),
	(243, 1, 0, -50940, 323, 0, 0, 39, '322'),
	(243, 1, 0, -50940, 324, 0, 0, 39, '323'),
	(243, 1, 0, -50940, 325, 0, 0, 39, '324'),
	(243, 1, 0, -50940, 326, 0, 0, 39, '325'),
	(243, 1, 0, -50940, 327, 0, 0, 39, '326'),
	(243, 1, 0, -50940, 328, 0, 0, 39, '327'),
	(243, 1, 0, -50940, 329, 0, 0, 39, '328'),
	(243, 1, 0, -50940, 330, 0, 0, 39, '329'),
	(243, 1, 0, -50940, 331, 0, 0, 39, '330'),
	(243, 1, 0, -50940, 332, 0, 0, 39, '331'),
	(243, 1, 0, -50940, 333, 0, 0, 39, '332'),
	(243, 1, 0, -50940, 334, 0, 0, 39, '333'),
	(243, 1, 0, -50940, 335, 0, 0, 39, '334'),
	(243, 1, 0, -50940, 336, 0, 0, 39, '335'),
	(243, 1, 0, -50940, 337, 0, 0, 39, '336'),
	(243, 1, 0, -50940, 338, 0, 0, 39, '337'),
	(243, 1, 0, -50940, 339, 0, 0, 39, '338'),
	(243, 1, 0, -50940, 340, 0, 0, 39, '339'),
	(243, 1, 0, -50940, 341, 0, 0, 39, '340'),
	(243, 1, 0, -50940, 342, 0, 0, 39, '341'),
	(243, 1, 0, -50940, 343, 0, 0, 39, '342'),
	(243, 1, 0, -50940, 344, 0, 0, 39, '343'),
	(243, 1, 0, -50940, 345, 0, 0, 39, '344'),
	(243, 1, 0, -50940, 346, 0, 0, 39, '345'),
	(243, 1, 0, -50940, 347, 0, 0, 39, '346'),
	(243, 1, 0, -50940, 348, 0, 0, 39, '347'),
	(243, 1, 0, -50940, 349, 0, 0, 39, '348'),
	(243, 1, 0, -50940, 350, 0, 0, 39, '349'),
	(243, 1, 0, -50940, 351, 0, 0, 39, '350'),
	(243, 1, 0, -50940, 352, 0, 0, 39, '351'),
	(243, 1, 0, -50940, 353, 0, 0, 39, '352'),
	(243, 1, 0, -50940, 354, 0, 0, 39, '353'),
	(243, 1, 0, -50940, 355, 0, 0, 39, '354'),
	(243, 1, 0, -50940, 356, 0, 0, 39, '355'),
	(243, 1, 0, -50940, 357, 0, 0, 39, '356'),
	(243, 1, 0, -50940, 358, 0, 0, 39, '357'),
	(243, 1, 0, -50940, 359, 0, 0, 39, '358'),
	(243, 1, 0, -50940, 360, 0, 0, 39, '359'),
	(243, 1, 0, -50940, 361, 0, 0, 39, '360'),
	(243, 1, 0, -50940, 362, 0, 0, 39, '361'),
	(243, 1, 0, -50940, 363, 0, 0, 39, '362'),
	(243, 1, 0, -50940, 364, 0, 0, 39, '363'),
	(243, 1, 0, -50940, 365, 0, 0, 39, '364'),
	(243, 1, 0, -50940, 366, 0, 0, 39, '365'),
	(243, 1, 0, -50940, 367, 0, 0, 39, '366'),
	(243, 1, 0, -50940, 368, 0, 0, 39, '367'),
	(243, 1, 0, -50940, 369, 0, 0, 39, '368'),
	(243, 1, 0, -50940, 370, 0, 0, 39, '369'),
	(243, 1, 0, -50940, 371, 0, 0, 39, '370'),
	(243, 1, 0, -50940, 372, 0, 0, 39, '371'),
	(243, 1, 0, -50940, 373, 0, 0, 39, '372'),
	(243, 1, 0, -50940, 374, 0, 0, 39, '373'),
	(243, 1, 0, -50940, 375, 0, 0, 39, '374'),
	(243, 1, 0, -50940, 376, 0, 0, 39, '375'),
	(243, 1, 0, -50940, 377, 0, 0, 39, '376'),
	(243, 1, 0, -50940, 378, 0, 0, 39, '377'),
	(243, 1, 0, -50940, 379, 0, 0, 39, '378'),
	(243, 1, 0, -50940, 380, 0, 0, 39, '379'),
	(243, 1, 0, -50940, 381, 0, 0, 39, '380'),
	(243, 1, 0, -50940, 382, 0, 0, 39, '381'),
	(243, 1, 0, -50940, 383, 0, 0, 39, '382'),
	(243, 1, 0, -50940, 384, 0, 0, 39, '383'),
	(243, 1, 0, -50940, 385, 0, 0, 39, '384'),
	(243, 1, 0, -50940, 386, 0, 0, 39, '385'),
	(243, 1, 0, -50940, 387, 0, 0, 39, '386'),
	(243, 1, 0, -50940, 388, 0, 0, 39, '387'),
	(243, 1, 0, -50940, 389, 0, 0, 39, '388'),
	(243, 1, 0, -50940, 390, 0, 0, 39, '389'),
	(243, 1, 0, -50940, 391, 0, 0, 39, '390'),
	(243, 1, 0, -50940, 392, 0, 0, 39, '391'),
	(243, 1, 0, -50940, 393, 0, 0, 39, '392'),
	(243, 1, 0, -50940, 394, 0, 0, 39, '393'),
	(243, 1, 0, -50940, 395, 0, 0, 39, '394'),
	(243, 1, 0, -50940, 396, 0, 0, 39, '395'),
	(243, 1, 0, -50940, 397, 0, 0, 39, '396'),
	(243, 1, 0, -50940, 398, 0, 0, 39, '397'),
	(243, 1, 0, -50940, 399, 0, 0, 39, '398'),
	(243, 1, 0, -50940, 400, 0, 0, 39, '399'),
	(243, 1, 0, -50940, 401, 0, 0, 39, '400'),
	(243, 1, 0, -50940, 402, 0, 0, 39, '401'),
	(243, 1, 0, -50940, 403, 0, 0, 39, '402'),
	(243, 1, 0, -50940, 404, 0, 0, 39, '403'),
	(243, 1, 0, -50940, 405, 0, 0, 39, '404'),
	(243, 1, 0, -50940, 406, 0, 0, 39, '405'),
	(243, 1, 0, -50940, 407, 0, 0, 39, '406'),
	(243, 1, 0, -50940, 408, 0, 0, 39, '407'),
	(243, 1, 0, -50940, 409, 0, 0, 39, '408'),
	(243, 1, 0, -50940, 410, 0, 0, 39, '409'),
	(243, 1, 0, -50940, 411, 0, 0, 39, '410'),
	(243, 1, 0, -50940, 412, 0, 0, 39, '411'),
	(243, 1, 0, -50940, 413, 0, 0, 39, '412'),
	(243, 1, 0, -50940, 414, 0, 0, 39, '413'),
	(243, 1, 0, -50940, 415, 0, 0, 39, '414'),
	(243, 1, 0, -50940, 416, 0, 0, 39, '415'),
	(243, 1, 0, -50940, 417, 0, 0, 39, '416'),
	(243, 1, 0, -50940, 418, 0, 0, 39, '417'),
	(243, 1, 0, -50940, 419, 0, 0, 39, '418'),
	(243, 1, 0, -50940, 420, 0, 0, 39, '419'),
	(243, 1, 0, -50940, 421, 0, 0, 39, '420'),
	(243, 1, 0, -50940, 422, 0, 0, 39, '421'),
	(243, 1, 0, -50940, 423, 0, 0, 39, '422'),
	(243, 1, 0, -50940, 424, 0, 0, 39, '423'),
	(243, 1, 0, -50940, 425, 0, 0, 39, '424'),
	(243, 1, 0, -50940, 426, 0, 0, 39, '425'),
	(243, 1, 0, -50940, 427, 0, 0, 39, '426'),
	(243, 1, 0, -50940, 428, 0, 0, 39, '427'),
	(243, 1, 0, -50940, 429, 0, 0, 39, '428'),
	(243, 1, 0, -50940, 430, 0, 0, 39, '429'),
	(243, 1, 0, -50940, 431, 0, 0, 39, '430'),
	(243, 1, 0, -50940, 432, 0, 0, 39, '431'),
	(243, 1, 0, -50940, 433, 0, 0, 39, '432'),
	(243, 1, 0, -50940, 434, 0, 0, 39, '433'),
	(243, 1, 0, -50940, 435, 0, 0, 39, '434'),
	(243, 1, 0, -50940, 436, 0, 0, 39, '435'),
	(243, 1, 0, -50940, 437, 0, 0, 39, '436'),
	(243, 1, 0, -50940, 438, 0, 0, 39, '437'),
	(243, 1, 0, -50940, 439, 0, 0, 39, '438'),
	(243, 1, 0, -50940, 440, 0, 0, 39, '439'),
	(243, 1, 0, -50940, 441, 0, 0, 39, '440'),
	(243, 1, 0, -50940, 442, 0, 0, 39, '441'),
	(243, 1, 0, -50940, 443, 0, 0, 39, '442'),
	(243, 1, 0, -50940, 444, 0, 0, 39, '443'),
	(243, 1, 0, -50940, 445, 0, 0, 39, '444'),
	(243, 1, 0, -50940, 446, 0, 0, 39, '445'),
	(243, 1, 0, -50940, 447, 0, 0, 39, '446'),
	(243, 1, 0, -50940, 448, 0, 0, 39, '447'),
	(243, 1, 0, -50940, 449, 0, 0, 39, '448'),
	(243, 1, 0, -50940, 450, 0, 0, 39, '449'),
	(243, 1, 0, -50940, 451, 0, 0, 39, '450'),
	(243, 1, 0, -50940, 452, 0, 0, 39, '451'),
	(243, 1, 0, -50940, 453, 0, 0, 39, '452'),
	(243, 1, 0, -50940, 454, 0, 0, 39, '453'),
	(243, 1, 0, -50940, 455, 0, 0, 39, '454'),
	(243, 1, 0, -50940, 456, 0, 0, 39, '455'),
	(243, 1, 0, -50940, 457, 0, 0, 39, '456'),
	(243, 1, 0, -50940, 458, 0, 0, 39, '457'),
	(243, 1, 0, -50940, 459, 0, 0, 39, '458'),
	(243, 1, 0, -50940, 460, 0, 0, 39, '459'),
	(243, 1, 0, -50940, 461, 0, 0, 39, '460'),
	(243, 1, 0, -50940, 462, 0, 0, 39, '461'),
	(243, 1, 0, -50940, 463, 0, 0, 39, '462'),
	(243, 1, 0, -50940, 464, 0, 0, 39, '463'),
	(243, 1, 0, -50940, 465, 0, 0, 39, '464'),
	(243, 1, 0, -50940, 466, 0, 0, 39, '465'),
	(243, 1, 0, -50940, 467, 0, 0, 39, '466'),
	(243, 1, 0, -50940, 468, 0, 0, 39, '467'),
	(243, 1, 0, -50940, 469, 0, 0, 39, '468'),
	(243, 1, 0, -50940, 470, 0, 0, 39, '469'),
	(243, 1, 0, -50940, 471, 0, 0, 39, '470'),
	(243, 1, 0, -50940, 472, 0, 0, 39, '471'),
	(243, 1, 0, -50940, 473, 0, 0, 39, '472'),
	(243, 1, 0, -50940, 474, 0, 0, 39, '473'),
	(243, 1, 0, -50940, 475, 0, 0, 39, '474'),
	(243, 1, 0, -50940, 476, 0, 0, 39, '475'),
	(243, 1, 0, -50940, 477, 0, 0, 39, '476'),
	(243, 1, 0, -50940, 478, 0, 0, 39, '477'),
	(243, 1, 0, -50940, 479, 0, 0, 39, '478'),
	(243, 1, 0, -50940, 480, 0, 0, 39, '479'),
	(243, 1, 0, -50940, 481, 0, 0, 39, '480'),
	(243, 1, 0, -50940, 482, 0, 0, 39, '481'),
	(243, 1, 0, -50940, 483, 0, 0, 39, '482'),
	(243, 1, 0, -50940, 484, 0, 0, 39, '483'),
	(243, 1, 0, -50940, 485, 0, 0, 39, '484'),
	(243, 1, 0, -50940, 486, 0, 0, 39, '485'),
	(243, 1, 0, -50940, 487, 0, 0, 39, '486'),
	(243, 1, 0, -50940, 488, 0, 0, 39, '487'),
	(243, 1, 0, -50940, 489, 0, 0, 39, '488'),
	(243, 1, 0, -50940, 490, 0, 0, 39, '489'),
	(243, 1, 0, -50940, 491, 0, 0, 39, '490'),
	(243, 1, 0, -50940, 492, 0, 0, 39, '491'),
	(243, 1, 0, -50940, 493, 0, 0, 39, '492'),
	(243, 1, 0, -50940, 494, 0, 0, 39, '493'),
	(243, 1, 0, -50940, 495, 0, 0, 39, '494'),
	(243, 1, 0, -50940, 496, 0, 0, 39, '495'),
	(243, 1, 0, -50940, 497, 0, 0, 39, '496'),
	(243, 1, 0, -50940, 498, 0, 0, 39, '497'),
	(243, 1, 0, -50940, 499, 0, 0, 39, '498'),
	(243, 1, 0, -50940, 500, 0, 0, 39, '499'),
	(243, 1, 0, -50940, 501, 0, 0, 39, '500'),
	(243, 1, 0, -50940, 502, 0, 0, 39, '501'),
	(243, 1, 0, -50940, 503, 0, 0, 39, '502'),
	(243, 1, 0, -50940, 504, 0, 0, 39, '503'),
	(243, 1, 0, -50940, 505, 0, 0, 39, '504'),
	(243, 1, 0, -50940, 506, 0, 0, 39, '505'),
	(243, 1, 0, -50940, 507, 0, 0, 39, '506'),
	(243, 1, 0, -50940, 508, 0, 0, 39, '507'),
	(243, 1, 0, -50940, 509, 0, 0, 39, '508'),
	(243, 1, 0, -50940, 510, 0, 0, 39, '509'),
	(243, 1, 0, -50940, 511, 0, 0, 39, '510'),
	(243, 1, 0, -50940, 512, 0, 0, 39, '511'),
	(243, 1, 0, -50940, 513, 0, 0, 39, '512'),
	(243, 1, 0, -50940, 514, 0, 0, 39, '513'),
	(243, 1, 0, -50940, 515, 0, 0, 39, '514'),
	(243, 1, 0, -50940, 516, 0, 0, 39, '515'),
	(243, 1, 0, -50940, 517, 0, 0, 39, '516'),
	(243, 1, 0, -50940, 518, 0, 0, 39, '517'),
	(243, 1, 0, -50940, 519, 0, 0, 39, '518'),
	(243, 1, 0, -50940, 520, 0, 0, 39, '519'),
	(243, 1, 0, -50940, 521, 0, 0, 39, '520'),
	(243, 1, 0, -50940, 522, 0, 0, 39, '521'),
	(243, 1, 0, -50940, 523, 0, 0, 39, '522'),
	(243, 1, 0, -50940, 524, 0, 0, 39, '523'),
	(243, 1, 0, -50940, 525, 0, 0, 39, '524'),
	(243, 1, 0, -50940, 526, 0, 0, 39, '525'),
	(243, 1, 0, -50940, 527, 0, 0, 39, '526'),
	(243, 1, 0, -50940, 528, 0, 0, 39, '527'),
	(243, 1, 0, -50940, 529, 0, 0, 39, '528'),
	(243, 1, 0, -50940, 530, 0, 0, 39, '529'),
	(243, 1, 0, -50940, 531, 0, 0, 39, '530'),
	(243, 1, 0, -50940, 532, 0, 0, 39, '531'),
	(243, 1, 0, -50940, 533, 0, 0, 39, '532'),
	(243, 1, 0, -50940, 534, 0, 0, 39, '533'),
	(243, 1, 0, -50940, 535, 0, 0, 39, '534'),
	(243, 1, 0, -50940, 536, 0, 0, 39, '535'),
	(243, 1, 0, -50940, 537, 0, 0, 39, '536'),
	(243, 1, 0, -50940, 538, 0, 0, 39, '537'),
	(243, 1, 0, -50940, 539, 0, 0, 39, '538'),
	(243, 1, 0, -50940, 540, 0, 0, 39, '539'),
	(243, 1, 0, -50940, 541, 0, 0, 39, '540'),
	(243, 1, 0, -50940, 542, 0, 0, 39, '541'),
	(243, 1, 0, -50940, 543, 0, 0, 39, '542'),
	(243, 1, 0, -50940, 544, 0, 0, 39, '543'),
	(243, 1, 0, -50940, 545, 0, 0, 39, '544'),
	(243, 1, 0, -50940, 546, 0, 0, 39, '545'),
	(243, 1, 0, -50940, 547, 0, 0, 39, '546'),
	(243, 1, 0, -50940, 548, 0, 0, 39, '547'),
	(243, 1, 0, -50940, 549, 0, 0, 39, '548'),
	(243, 1, 0, -50940, 550, 0, 0, 39, '549'),
	(243, 1, 0, -50940, 551, 0, 0, 39, '550'),
	(243, 1, 0, -50940, 552, 0, 0, 39, '551'),
	(243, 1, 0, -50940, 553, 0, 0, 39, '552'),
	(243, 1, 0, -50940, 554, 0, 0, 39, '553'),
	(243, 1, 0, -50940, 555, 0, 0, 39, '554'),
	(243, 1, 0, -50940, 556, 0, 0, 39, '555'),
	(243, 1, 0, -50940, 557, 0, 0, 39, '556'),
	(243, 1, 0, -50940, 558, 0, 0, 39, '557'),
	(243, 1, 0, -50940, 559, 0, 0, 39, '558'),
	(243, 1, 0, -50940, 560, 0, 0, 39, '559'),
	(243, 1, 0, -50940, 561, 0, 0, 39, '560'),
	(243, 1, 0, -50940, 562, 0, 0, 39, '561'),
	(243, 1, 0, -50940, 563, 0, 0, 39, '562'),
	(243, 1, 0, -50940, 564, 0, 0, 39, '563'),
	(243, 1, 0, -50940, 565, 0, 0, 39, '564'),
	(243, 1, 0, -50940, 566, 0, 0, 39, '565'),
	(243, 1, 0, -50940, 567, 0, 0, 39, '566'),
	(243, 1, 0, -50940, 568, 0, 0, 39, '567'),
	(243, 1, 0, -50940, 569, 0, 0, 39, '568'),
	(243, 1, 0, -50940, 570, 0, 0, 39, '569'),
	(243, 1, 0, -50940, 571, 0, 0, 39, '570'),
	(243, 1, 0, -50940, 572, 0, 0, 39, '571'),
	(243, 1, 0, -50940, 573, 0, 0, 39, '572'),
	(243, 1, 0, -50940, 574, 0, 0, 39, '573'),
	(243, 1, 0, -50940, 575, 0, 0, 39, '574'),
	(243, 1, 0, -50940, 576, 0, 0, 39, '575'),
	(243, 1, 0, -50940, 577, 0, 0, 39, '576'),
	(243, 1, 0, -50940, 578, 0, 0, 39, '577'),
	(243, 1, 0, -50940, 579, 0, 0, 39, '578'),
	(243, 1, 0, -50940, 580, 0, 0, 39, '579'),
	(243, 1, 0, -50940, 581, 0, 0, 39, '580'),
	(243, 1, 0, -50940, 582, 0, 0, 39, '581'),
	(243, 1, 0, -50940, 583, 0, 0, 39, '582'),
	(243, 1, 0, -50940, 584, 0, 0, 39, '583'),
	(243, 1, 0, -50940, 585, 0, 0, 39, '584'),
	(243, 1, 0, -50940, 586, 0, 0, 39, '585'),
	(243, 1, 0, -50940, 587, 0, 0, 39, '586'),
	(243, 1, 0, -50940, 588, 0, 0, 39, '587'),
	(243, 1, 0, -50940, 589, 0, 0, 39, '588'),
	(243, 1, 0, -50940, 590, 0, 0, 39, '589'),
	(243, 1, 0, -50940, 591, 0, 0, 39, '590'),
	(243, 1, 0, -50940, 592, 0, 0, 39, '591'),
	(243, 1, 0, -50940, 593, 0, 0, 39, '592'),
	(243, 1, 0, -50940, 594, 0, 0, 39, '593'),
	(243, 1, 0, -50940, 595, 0, 0, 39, '594'),
	(243, 1, 0, -50940, 596, 0, 0, 39, '595'),
	(243, 1, 0, -50940, 597, 0, 0, 39, '596'),
	(243, 1, 0, -50940, 598, 0, 0, 39, '597'),
	(243, 1, 0, -50940, 599, 0, 0, 39, '598'),
	(243, 1, 0, -50940, 600, 0, 0, 39, '599'),
	(243, 1, 0, -50940, 601, 0, 0, 39, '600'),
	(243, 1, 0, -50940, 602, 0, 0, 39, '601'),
	(243, 1, 0, -50940, 603, 0, 0, 39, '602'),
	(243, 1, 0, -50940, 604, 0, 0, 39, '603'),
	(243, 1, 0, -50940, 605, 0, 0, 39, '604'),
	(243, 1, 0, -50940, 606, 0, 0, 39, '605'),
	(243, 1, 0, -50940, 607, 0, 0, 39, '606'),
	(243, 1, 0, -50940, 608, 0, 0, 39, '607'),
	(243, 1, 0, -50940, 609, 0, 0, 39, '608'),
	(243, 1, 0, -50940, 610, 0, 0, 39, '609'),
	(243, 1, 0, -50940, 611, 0, 0, 39, '610'),
	(243, 1, 0, -50940, 612, 0, 0, 39, '611'),
	(243, 1, 0, -50940, 613, 0, 0, 39, '612'),
	(243, 1, 0, -50940, 614, 0, 0, 39, '613'),
	(243, 1, 0, -50940, 615, 0, 0, 39, '614'),
	(243, 1, 0, -50940, 616, 0, 0, 39, '615'),
	(243, 1, 0, -50940, 617, 0, 0, 39, '616'),
	(243, 1, 0, -50940, 618, 0, 0, 39, '617'),
	(243, 1, 0, -50940, 619, 0, 0, 39, '618'),
	(243, 1, 0, -50940, 620, 0, 0, 39, '619'),
	(243, 1, 0, -50940, 621, 0, 0, 39, '620'),
	(243, 1, 0, -50940, 622, 0, 0, 39, '621'),
	(243, 1, 0, -50940, 623, 0, 0, 39, '622'),
	(243, 1, 0, -50940, 624, 0, 0, 39, '623'),
	(243, 1, 0, -50940, 625, 0, 0, 39, '624'),
	(243, 1, 0, -50940, 626, 0, 0, 39, '625'),
	(243, 1, 0, -50940, 627, 0, 0, 39, '626'),
	(243, 1, 0, -50940, 628, 0, 0, 39, '627'),
	(243, 1, 0, -50940, 629, 0, 0, 39, '628'),
	(243, 1, 0, -50940, 630, 0, 0, 39, '629'),
	(243, 1, 0, -50940, 631, 0, 0, 39, '630'),
	(243, 1, 0, -50940, 632, 0, 0, 39, '631'),
	(243, 1, 0, -50940, 633, 0, 0, 39, '632'),
	(243, 1, 0, -50940, 634, 0, 0, 39, '633'),
	(243, 1, 0, -50940, 635, 0, 0, 39, '634'),
	(243, 1, 0, -50940, 636, 0, 0, 39, '635'),
	(243, 1, 0, -50940, 637, 0, 0, 39, '636'),
	(243, 1, 0, -50940, 638, 0, 0, 39, '637'),
	(243, 1, 0, -50940, 639, 0, 0, 39, '638'),
	(243, 1, 0, -50940, 640, 0, 0, 39, '639'),
	(243, 1, 0, -50940, 641, 0, 0, 39, '640'),
	(243, 1, 0, -50940, 642, 0, 0, 39, '641'),
	(243, 1, 0, -50940, 643, 0, 0, 39, '642'),
	(243, 1, 0, -50940, 644, 0, 0, 39, '643'),
	(243, 1, 0, -50940, 645, 0, 0, 39, '644'),
	(243, 1, 0, -50940, 646, 0, 0, 39, '645'),
	(243, 1, 0, -50940, 647, 0, 0, 39, '646'),
	(243, 1, 0, -50940, 648, 0, 0, 39, '647'),
	(243, 1, 0, -50940, 649, 0, 0, 39, '648'),
	(243, 1, 0, -50940, 650, 0, 0, 39, '649'),
	(243, 1, 0, -50940, 651, 0, 0, 39, '650'),
	(243, 1, 0, -50940, 652, 0, 0, 39, '651'),
	(243, 1, 0, -50940, 653, 0, 0, 39, '652'),
	(243, 1, 0, -50940, 654, 0, 0, 39, '653'),
	(243, 1, 0, -50940, 655, 0, 0, 39, '654'),
	(243, 1, 0, -50940, 656, 0, 0, 39, '655'),
	(243, 1, 0, -50940, 657, 0, 0, 39, '656'),
	(243, 1, 0, -50940, 658, 0, 0, 39, '657'),
	(243, 1, 0, -50940, 659, 0, 0, 39, '658'),
	(243, 1, 0, -50940, 660, 0, 0, 39, '659'),
	(243, 1, 0, -50940, 661, 0, 0, 39, '660'),
	(243, 1, 0, -50940, 662, 0, 0, 39, '661'),
	(243, 1, 0, -50940, 663, 0, 0, 39, '662'),
	(243, 1, 0, -50940, 664, 0, 0, 39, '663'),
	(243, 1, 0, -50940, 665, 0, 0, 39, '664'),
	(243, 1, 0, -50940, 666, 0, 0, 39, '665'),
	(243, 1, 0, -50940, 667, 0, 0, 39, '666'),
	(243, 1, 0, -50940, 668, 0, 0, 39, '667'),
	(243, 1, 0, -50940, 669, 0, 0, 39, '668'),
	(243, 1, 0, -50940, 670, 0, 0, 39, '669'),
	(243, 1, 0, -50940, 671, 0, 0, 39, '670'),
	(243, 1, 0, -50940, 672, 0, 0, 39, '671'),
	(243, 1, 0, -50940, 673, 0, 0, 39, '672'),
	(243, 1, 0, -50940, 674, 0, 0, 39, '673'),
	(243, 1, 0, -50940, 675, 0, 0, 39, '674'),
	(243, 1, 0, -50940, 676, 0, 0, 39, '675'),
	(243, 1, 0, -50940, 677, 0, 0, 39, '676'),
	(243, 1, 0, -50940, 678, 0, 0, 39, '677'),
	(243, 1, 0, -50940, 679, 0, 0, 39, '678'),
	(243, 1, 0, -50940, 680, 0, 0, 39, '679'),
	(243, 1, 0, -50940, 681, 0, 0, 39, '680'),
	(243, 1, 0, -50940, 682, 0, 0, 39, '681'),
	(243, 1, 0, -50940, 683, 0, 0, 39, '682'),
	(243, 1, 0, -50940, 684, 0, 0, 39, '683'),
	(243, 1, 0, -50940, 685, 0, 0, 39, '684'),
	(243, 1, 0, -50940, 686, 0, 0, 39, '685'),
	(243, 1, 0, -50940, 687, 0, 0, 39, '686'),
	(243, 1, 0, -50940, 688, 0, 0, 39, '687'),
	(243, 1, 0, -50940, 689, 0, 0, 39, '688'),
	(243, 1, 0, -50940, 690, 0, 0, 39, '689'),
	(243, 1, 0, -50940, 691, 0, 0, 39, '690'),
	(243, 1, 0, -50940, 692, 0, 0, 39, '691'),
	(243, 1, 0, -50940, 693, 0, 0, 39, '692'),
	(243, 1, 0, -50940, 694, 0, 0, 39, '693'),
	(243, 1, 0, -50940, 695, 0, 0, 39, '694'),
	(243, 1, 0, -50940, 696, 0, 0, 39, '695'),
	(243, 1, 0, -50940, 697, 0, 0, 39, '696'),
	(243, 1, 0, -50940, 698, 0, 0, 39, '697'),
	(243, 1, 0, -50940, 699, 0, 0, 39, '698'),
	(243, 1, 0, -50940, 700, 0, 0, 39, '699'),
	(243, 1, 0, -50940, 701, 0, 0, 39, '700'),
	(243, 1, 0, -50940, 702, 0, 0, 39, '701'),
	(243, 1, 0, -50940, 703, 0, 0, 39, '702'),
	(243, 1, 0, -50940, 704, 0, 0, 39, '703'),
	(243, 1, 0, -50940, 705, 0, 0, 39, '704'),
	(243, 1, 0, -50940, 706, 0, 0, 39, '705'),
	(243, 1, 0, -50940, 707, 0, 0, 39, '706'),
	(243, 1, 0, -50940, 708, 0, 0, 39, '707'),
	(243, 1, 0, -50940, 709, 0, 0, 39, '708'),
	(243, 1, 0, -50940, 710, 0, 0, 39, '709'),
	(243, 1, 0, -50940, 711, 0, 0, 39, '710'),
	(243, 1, 0, -50940, 712, 0, 0, 39, '711'),
	(243, 1, 0, -50940, 713, 0, 0, 39, '712'),
	(243, 1, 0, -50940, 714, 0, 0, 39, '713'),
	(243, 1, 0, -50940, 715, 0, 0, 39, '714'),
	(243, 1, 0, -50940, 716, 0, 0, 39, '715'),
	(243, 1, 0, -50940, 717, 0, 0, 39, '716'),
	(243, 1, 0, -50940, 718, 0, 0, 39, '717'),
	(243, 1, 0, -50940, 719, 0, 0, 39, '718'),
	(243, 1, 0, -50940, 720, 0, 0, 39, '719'),
	(243, 1, 0, -50940, 721, 0, 0, 39, '720'),
	(243, 1, 0, -50940, 722, 0, 0, 39, '721'),
	(243, 1, 0, -50940, 723, 0, 0, 39, '722'),
	(243, 1, 0, -50940, 724, 0, 0, 39, '723'),
	(243, 1, 0, -50940, 725, 0, 0, 39, '724'),
	(243, 1, 0, -50940, 726, 0, 0, 39, '725'),
	(243, 1, 0, -50940, 727, 0, 0, 39, '726'),
	(243, 1, 0, -50940, 728, 0, 0, 39, '727'),
	(243, 1, 0, -50940, 729, 0, 0, 39, '728'),
	(243, 1, 0, -50940, 730, 0, 0, 39, '729'),
	(243, 1, 0, -50940, 731, 0, 0, 39, '730'),
	(243, 1, 0, -50940, 732, 0, 0, 39, '731'),
	(243, 1, 0, -50940, 733, 0, 0, 39, '732'),
	(243, 1, 0, -50940, 734, 0, 0, 39, '733'),
	(243, 1, 0, -50940, 735, 0, 0, 39, '734'),
	(243, 1, 0, -50940, 736, 0, 0, 39, '735'),
	(243, 1, 0, -50940, 737, 0, 0, 39, '736'),
	(243, 1, 0, -50940, 738, 0, 0, 39, '737'),
	(243, 1, 0, -50940, 739, 0, 0, 39, '738'),
	(243, 1, 0, -50940, 740, 0, 0, 39, '739'),
	(243, 1, 0, -50940, 741, 0, 0, 39, '740'),
	(243, 1, 0, -50940, 742, 0, 0, 39, '741'),
	(243, 1, 0, -50940, 743, 0, 0, 39, '742'),
	(243, 1, 0, -50940, 744, 0, 0, 39, '743'),
	(243, 1, 0, -50940, 745, 0, 0, 39, '744'),
	(243, 1, 0, -50940, 746, 0, 0, 39, '745'),
	(243, 1, 0, -50940, 747, 0, 0, 39, '746'),
	(243, 1, 0, -50940, 748, 0, 0, 39, '747'),
	(243, 1, 0, -50940, 749, 0, 0, 39, '748'),
	(243, 1, 0, -50940, 750, 0, 0, 39, '749'),
	(243, 1, 0, -50940, 751, 0, 0, 39, '750'),
	(243, 1, 0, -50940, 752, 0, 0, 39, '751'),
	(243, 1, 0, -50940, 753, 0, 0, 39, '752'),
	(243, 1, 0, -50940, 754, 0, 0, 39, '753'),
	(243, 1, 0, -50940, 755, 0, 0, 39, '754'),
	(243, 1, 0, -50940, 756, 0, 0, 39, '755'),
	(243, 1, 0, -50940, 757, 0, 0, 39, '756'),
	(243, 1, 0, -50940, 758, 0, 0, 39, '757'),
	(243, 1, 0, -50940, 759, 0, 0, 39, '758'),
	(243, 1, 0, -50940, 760, 0, 0, 39, '759'),
	(243, 1, 0, -50940, 761, 0, 0, 39, '760'),
	(243, 1, 0, -50940, 762, 0, 0, 39, '761'),
	(243, 1, 0, -50940, 763, 0, 0, 39, '762'),
	(243, 1, 0, -50940, 764, 0, 0, 39, '763'),
	(243, 1, 0, -50940, 765, 0, 0, 39, '764'),
	(243, 1, 0, -50940, 766, 0, 0, 39, '765'),
	(243, 1, 0, -50940, 767, 0, 0, 39, '766'),
	(243, 1, 0, -50940, 768, 0, 0, 39, '767'),
	(243, 1, 0, -50940, 769, 0, 0, 39, '768'),
	(243, 1, 0, -50940, 770, 0, 0, 39, '769'),
	(243, 1, 0, -50940, 771, 0, 0, 39, '770'),
	(243, 1, 0, -50940, 772, 0, 0, 39, '771'),
	(243, 1, 0, -50940, 773, 0, 0, 39, '772'),
	(243, 1, 0, -50940, 774, 0, 0, 39, '773'),
	(243, 1, 0, -50940, 775, 0, 0, 39, '774'),
	(243, 1, 0, -50940, 776, 0, 0, 39, '775'),
	(243, 1, 0, -50940, 777, 0, 0, 39, '776'),
	(243, 1, 0, -50940, 778, 0, 0, 39, '777'),
	(243, 1, 0, -50940, 779, 0, 0, 39, '778'),
	(243, 1, 0, -50940, 780, 0, 0, 39, '779'),
	(243, 1, 0, -50940, 781, 0, 0, 39, '780'),
	(243, 1, 0, -50940, 782, 0, 0, 39, '781'),
	(243, 1, 0, -50940, 783, 0, 0, 39, '782'),
	(243, 1, 0, -50940, 784, 0, 0, 39, '783'),
	(243, 1, 0, -50940, 785, 0, 0, 39, '784'),
	(243, 1, 0, -50940, 786, 0, 0, 39, '785'),
	(243, 1, 0, -50940, 787, 0, 0, 39, '786'),
	(243, 1, 0, -50940, 788, 0, 0, 39, '787'),
	(243, 1, 0, -50940, 789, 0, 0, 39, '788'),
	(243, 1, 0, -50940, 790, 0, 0, 39, '789'),
	(243, 1, 0, -50940, 791, 0, 0, 39, '790'),
	(243, 1, 0, -50940, 792, 0, 0, 39, '791'),
	(243, 1, 0, -50940, 793, 0, 0, 39, '792'),
	(243, 1, 0, -50940, 794, 0, 0, 39, '793'),
	(243, 1, 0, -50940, 795, 0, 0, 39, '794'),
	(243, 1, 0, -50940, 796, 0, 0, 39, '795'),
	(243, 1, 0, -50940, 797, 0, 0, 39, '796'),
	(243, 1, 0, -50940, 798, 0, 0, 39, '797'),
	(243, 1, 0, -50940, 799, 0, 0, 39, '798'),
	(243, 1, 0, -50940, 800, 0, 0, 39, '799'),
	(243, 1, 0, -50940, 801, 0, 0, 39, '800'),
	(243, 1, 0, -50940, 802, 0, 0, 39, '801'),
	(243, 1, 0, -50940, 803, 0, 0, 39, '802'),
	(243, 1, 0, -50940, 804, 0, 0, 39, '803'),
	(243, 1, 0, -50940, 805, 0, 0, 39, '804'),
	(243, 1, 0, -50940, 806, 0, 0, 39, '805'),
	(243, 1, 0, -50940, 807, 0, 0, 39, '806'),
	(243, 1, 0, -50940, 808, 0, 0, 39, '807'),
	(243, 1, 0, -50940, 809, 0, 0, 39, '808'),
	(243, 1, 0, -50940, 810, 0, 0, 39, '809'),
	(243, 1, 0, -50940, 811, 0, 0, 39, '810'),
	(243, 1, 0, -50940, 812, 0, 0, 39, '811'),
	(243, 1, 0, -50940, 813, 0, 0, 39, '812'),
	(243, 1, 0, -50940, 814, 0, 0, 39, '813'),
	(243, 1, 0, -50940, 815, 0, 0, 39, '814'),
	(243, 1, 0, -50940, 816, 0, 0, 39, '815'),
	(243, 1, 0, -50940, 817, 0, 0, 39, '816'),
	(243, 1, 0, -50940, 818, 0, 0, 39, '817'),
	(243, 1, 0, -50940, 819, 0, 0, 39, '818'),
	(243, 1, 0, -50940, 820, 0, 0, 39, '819'),
	(243, 1, 0, -50940, 821, 0, 0, 39, '820'),
	(243, 1, 0, -50940, 822, 0, 0, 39, '821'),
	(243, 1, 0, -50940, 823, 0, 0, 39, '822'),
	(243, 1, 0, -50940, 824, 0, 0, 39, '823'),
	(243, 1, 0, -50940, 825, 0, 0, 39, '824'),
	(243, 1, 0, -50940, 826, 0, 0, 39, '825'),
	(243, 1, 0, -50940, 827, 0, 0, 39, '826'),
	(243, 1, 0, -50940, 828, 0, 0, 39, '827'),
	(243, 1, 0, -50940, 829, 0, 0, 39, '828'),
	(243, 1, 0, -50940, 830, 0, 0, 39, '829'),
	(243, 1, 0, -50940, 831, 0, 0, 39, '830'),
	(243, 1, 0, -50940, 832, 0, 0, 39, '831'),
	(243, 1, 0, -50940, 833, 0, 0, 39, '832'),
	(243, 1, 0, -50940, 834, 0, 0, 39, '833'),
	(243, 1, 0, -50940, 835, 0, 0, 39, '834'),
	(243, 1, 0, -50940, 836, 0, 0, 39, '835'),
	(243, 1, 0, -50940, 837, 0, 0, 39, '836'),
	(243, 1, 0, -50940, 838, 0, 0, 39, '837'),
	(243, 1, 0, -50940, 839, 0, 0, 39, '838'),
	(243, 1, 0, -50940, 840, 0, 0, 39, '839'),
	(243, 1, 0, -50940, 841, 0, 0, 39, '840'),
	(243, 1, 0, -50940, 842, 0, 0, 39, '841'),
	(243, 1, 0, -50940, 843, 0, 0, 39, '842'),
	(243, 1, 0, -50940, 844, 0, 0, 39, '843'),
	(243, 1, 0, -50940, 845, 0, 0, 39, '844'),
	(243, 1, 0, -50940, 846, 0, 0, 39, '845'),
	(243, 1, 0, -50940, 847, 0, 0, 39, '846'),
	(243, 1, 0, -50940, 848, 0, 0, 39, '847'),
	(243, 1, 0, -50940, 849, 0, 0, 39, '848'),
	(243, 1, 0, -50940, 850, 0, 0, 39, '849'),
	(243, 1, 0, -50940, 851, 0, 0, 39, '850'),
	(243, 1, 0, -50940, 852, 0, 0, 39, '851'),
	(243, 1, 0, -50940, 853, 0, 0, 39, '852'),
	(243, 1, 0, -50940, 854, 0, 0, 39, '853'),
	(243, 1, 0, -50940, 855, 0, 0, 39, '854'),
	(243, 1, 0, -50940, 856, 0, 0, 39, '855'),
	(243, 1, 0, -50940, 857, 0, 0, 39, '856'),
	(243, 1, 0, -50940, 858, 0, 0, 39, '857'),
	(243, 1, 0, -50940, 859, 0, 0, 39, '858'),
	(243, 1, 0, -50940, 860, 0, 0, 39, '859'),
	(243, 1, 0, -50940, 861, 0, 0, 39, '860'),
	(243, 1, 0, -50940, 862, 0, 0, 39, '861'),
	(243, 1, 0, -50940, 863, 0, 0, 39, '862'),
	(243, 1, 0, -50940, 864, 0, 0, 39, '863'),
	(243, 1, 0, -50940, 865, 0, 0, 39, '864'),
	(243, 1, 0, -50940, 866, 0, 0, 39, '865'),
	(243, 1, 0, -50940, 867, 0, 0, 39, '866'),
	(243, 1, 0, -50940, 868, 0, 0, 39, '867'),
	(243, 1, 0, -50940, 869, 0, 0, 39, '868'),
	(243, 1, 0, -50940, 870, 0, 0, 39, '869'),
	(243, 1, 0, -50940, 871, 0, 0, 39, '870'),
	(243, 1, 0, -50940, 872, 0, 0, 39, '871'),
	(243, 1, 0, -50940, 873, 0, 0, 39, '872'),
	(243, 1, 0, -50940, 874, 0, 0, 39, '873'),
	(243, 1, 0, -50940, 875, 0, 0, 39, '874'),
	(243, 1, 0, -50940, 876, 0, 0, 39, '875'),
	(243, 1, 0, -50940, 877, 0, 0, 39, '876'),
	(243, 1, 0, -50940, 878, 0, 0, 39, '877'),
	(243, 1, 0, -50940, 879, 0, 0, 39, '878'),
	(243, 1, 0, -50940, 880, 0, 0, 39, '879'),
	(243, 1, 0, -50940, 881, 0, 0, 39, '880'),
	(243, 1, 0, -50940, 882, 0, 0, 39, '881'),
	(243, 1, 0, -50940, 883, 0, 0, 39, '882'),
	(243, 1, 0, -50940, 884, 0, 0, 39, '883'),
	(243, 1, 0, -50940, 885, 0, 0, 39, '884'),
	(243, 1, 0, -50940, 886, 0, 0, 39, '885'),
	(243, 1, 0, -50940, 887, 0, 0, 39, '886'),
	(243, 1, 0, -50940, 888, 0, 0, 39, '887'),
	(243, 1, 0, -50940, 889, 0, 0, 39, '888'),
	(243, 1, 0, -50940, 890, 0, 0, 39, '889'),
	(243, 1, 0, -50940, 891, 0, 0, 39, '890'),
	(243, 1, 0, -50940, 892, 0, 0, 39, '891'),
	(243, 1, 0, -50940, 893, 0, 0, 39, '892'),
	(243, 1, 0, -50940, 894, 0, 0, 39, '893'),
	(243, 1, 0, -50940, 895, 0, 0, 39, '894'),
	(243, 1, 0, -50940, 896, 0, 0, 39, '895'),
	(243, 1, 0, -50940, 897, 0, 0, 39, '896'),
	(243, 1, 0, -50940, 898, 0, 0, 39, '897'),
	(243, 1, 0, -50940, 899, 0, 0, 39, '898'),
	(243, 1, 0, -50940, 900, 0, 0, 39, '899'),
	(243, 1, 0, -50940, 901, 0, 0, 39, '900'),
	(243, 1, 0, -50940, 902, 0, 0, 39, '901'),
	(243, 1, 0, -50940, 903, 0, 0, 39, '902'),
	(243, 1, 0, -50940, 904, 0, 0, 39, '903'),
	(243, 1, 0, -50940, 905, 0, 0, 39, '904'),
	(243, 1, 0, -50940, 906, 0, 0, 39, '905'),
	(243, 1, 0, -50940, 907, 0, 0, 39, '906'),
	(243, 1, 0, -50940, 908, 0, 0, 39, '907'),
	(243, 1, 0, -50940, 909, 0, 0, 39, '908'),
	(243, 1, 0, -50940, 910, 0, 0, 39, '909'),
	(243, 1, 0, -50940, 911, 0, 0, 39, '910'),
	(243, 1, 0, -50940, 912, 0, 0, 39, '911'),
	(243, 1, 0, -50940, 913, 0, 0, 39, '912'),
	(243, 1, 0, -50940, 914, 0, 0, 39, '913'),
	(243, 1, 0, -50940, 915, 0, 0, 39, '914'),
	(243, 1, 0, -50940, 916, 0, 0, 39, '915'),
	(243, 1, 0, -50940, 917, 0, 0, 39, '916'),
	(243, 1, 0, -50940, 918, 0, 0, 39, '917'),
	(243, 1, 0, -50940, 919, 0, 0, 39, '918'),
	(243, 1, 0, -50940, 920, 0, 0, 39, '919'),
	(243, 1, 0, -50940, 921, 0, 0, 39, '920'),
	(243, 1, 0, -50940, 922, 0, 0, 39, '921'),
	(243, 1, 0, -50940, 923, 0, 0, 39, '922'),
	(243, 1, 0, -50940, 924, 0, 0, 39, '923'),
	(243, 1, 0, -50940, 925, 0, 0, 39, '924'),
	(243, 1, 0, -50940, 926, 0, 0, 39, '925'),
	(243, 1, 0, -50940, 927, 0, 0, 39, '926'),
	(243, 1, 0, -50940, 928, 0, 0, 39, '927'),
	(243, 1, 0, -50940, 929, 0, 0, 39, '928'),
	(243, 1, 0, -50940, 930, 0, 0, 39, '929'),
	(243, 1, 0, -50940, 931, 0, 0, 39, '930'),
	(243, 1, 0, -50940, 932, 0, 0, 39, '931'),
	(243, 1, 0, -50940, 933, 0, 0, 39, '932'),
	(243, 1, 0, -50940, 934, 0, 0, 39, '933'),
	(243, 1, 0, -50940, 935, 0, 0, 39, '934'),
	(243, 1, 0, -50940, 936, 0, 0, 39, '935'),
	(243, 1, 0, -50940, 937, 0, 0, 39, '936'),
	(243, 1, 0, -50940, 938, 0, 0, 39, '937'),
	(243, 1, 0, -50940, 939, 0, 0, 39, '938'),
	(243, 1, 0, -50940, 940, 0, 0, 39, '939'),
	(243, 1, 0, -50940, 941, 0, 0, 39, '940'),
	(243, 1, 0, -50940, 942, 0, 0, 39, '941'),
	(243, 1, 0, -50940, 943, 0, 0, 39, '942'),
	(243, 1, 0, -50940, 944, 0, 0, 39, '943'),
	(243, 1, 0, -50940, 945, 0, 0, 39, '944'),
	(243, 1, 0, -50940, 946, 0, 0, 39, '945'),
	(243, 1, 0, -50940, 947, 0, 0, 39, '946'),
	(243, 1, 0, -50940, 948, 0, 0, 39, '947'),
	(243, 1, 0, -50940, 949, 0, 0, 39, '948'),
	(243, 1, 0, -50940, 950, 0, 0, 39, '949'),
	(243, 1, 0, -50940, 951, 0, 0, 39, '950'),
	(243, 1, 0, -50940, 952, 0, 0, 39, '951'),
	(243, 1, 0, -50940, 953, 0, 0, 39, '952'),
	(243, 1, 0, -50940, 954, 0, 0, 39, '953'),
	(243, 1, 0, -50940, 955, 0, 0, 39, '954'),
	(243, 1, 0, -50940, 956, 0, 0, 39, '955'),
	(243, 1, 0, -50940, 957, 0, 0, 39, '956'),
	(243, 1, 0, -50940, 958, 0, 0, 39, '957'),
	(243, 1, 0, -50940, 959, 0, 0, 39, '958'),
	(243, 1, 0, -50940, 960, 0, 0, 39, '959'),
	(243, 1, 0, -50940, 961, 0, 0, 39, '960'),
	(243, 1, 0, -50940, 962, 0, 0, 39, '961'),
	(243, 1, 0, -50940, 963, 0, 0, 39, '962'),
	(243, 1, 0, -50940, 964, 0, 0, 39, '963'),
	(243, 1, 0, -50940, 965, 0, 0, 39, '964'),
	(243, 1, 0, -50940, 966, 0, 0, 39, '965'),
	(243, 1, 0, -50940, 967, 0, 0, 39, '966'),
	(243, 1, 0, -50940, 968, 0, 0, 39, '967'),
	(243, 1, 0, -50940, 969, 0, 0, 39, '968'),
	(243, 1, 0, -50940, 970, 0, 0, 39, '969'),
	(243, 1, 0, -50940, 971, 0, 0, 39, '970'),
	(243, 1, 0, -50940, 972, 0, 0, 39, '971'),
	(243, 1, 0, -50940, 973, 0, 0, 39, '972'),
	(243, 1, 0, -50940, 974, 0, 0, 39, '973'),
	(243, 1, 0, -50940, 975, 0, 0, 39, '974'),
	(243, 1, 0, -50940, 976, 0, 0, 39, '975'),
	(243, 1, 0, -50940, 977, 0, 0, 39, '976'),
	(243, 1, 0, -50940, 978, 0, 0, 39, '977'),
	(243, 1, 0, -50940, 979, 0, 0, 39, '978'),
	(243, 1, 0, -50940, 980, 0, 0, 39, '979'),
	(243, 1, 0, -50940, 981, 0, 0, 39, '980'),
	(243, 1, 0, -50940, 982, 0, 0, 39, '981'),
	(243, 1, 0, -50940, 983, 0, 0, 39, '982'),
	(243, 1, 0, -50940, 984, 0, 0, 39, '983'),
	(243, 1, 0, -50940, 985, 0, 0, 39, '984'),
	(243, 1, 0, -50940, 986, 0, 0, 39, '985'),
	(243, 1, 0, -50940, 987, 0, 0, 39, '986'),
	(243, 1, 0, -50940, 988, 0, 0, 39, '987'),
	(243, 1, 0, -50940, 989, 0, 0, 39, '988'),
	(243, 1, 0, -50940, 990, 0, 0, 39, '989'),
	(243, 1, 0, -50940, 991, 0, 0, 39, '990'),
	(243, 1, 0, -50940, 992, 0, 0, 39, '991'),
	(243, 1, 0, -50940, 993, 0, 0, 39, '992'),
	(243, 1, 0, -50940, 994, 0, 0, 39, '993'),
	(243, 1, 0, -50940, 995, 0, 0, 39, '994'),
	(243, 1, 0, -50940, 996, 0, 0, 39, '995'),
	(243, 1, 0, -50940, 997, 0, 0, 39, '996'),
	(243, 1, 0, -50940, 998, 0, 0, 39, '997'),
	(243, 1, 0, -50940, 999, 0, 0, 39, '998'),
	(243, 1, 0, -50940, 1000, 0, 0, 39, '999'),
	(243, 1, 0, -50940, 1001, 0, 0, 39, '1000'),
	(243, 1, 0, -50940, 1002, 0, 0, 39, '1001'),
	(243, 1, 0, -50940, 1003, 0, 0, 39, '1002'),
	(243, 1, 0, -50940, 1004, 0, 0, 39, '1003'),
	(243, 1, 0, -50940, 1005, 0, 0, 39, '1004'),
	(243, 1, 0, -50940, 1006, 0, 0, 39, '1005'),
	(243, 1, 0, -50940, 1007, 0, 0, 39, '1006'),
	(243, 1, 0, -50940, 1008, 0, 0, 39, '1007'),
	(243, 1, 0, -50940, 1009, 0, 0, 39, '1008'),
	(243, 1, 0, -50940, 1010, 0, 0, 39, '1009'),
	(243, 1, 0, -50940, 1011, 0, 0, 39, '1010'),
	(243, 1, 0, -50940, 1012, 0, 0, 39, '1011'),
	(243, 1, 0, -50940, 1013, 0, 0, 39, '1012'),
	(243, 1, 0, -50940, 1014, 0, 0, 39, '1013'),
	(243, 1, 0, -50940, 1015, 0, 0, 39, '1014'),
	(243, 1, 0, -50940, 1016, 0, 0, 39, '1015'),
	(243, 1, 0, -50940, 1017, 0, 0, 39, '1016'),
	(243, 1, 0, -50940, 1018, 0, 0, 39, '1017'),
	(243, 1, 0, -50940, 1019, 0, 0, 39, '1018'),
	(243, 1, 0, -50940, 1020, 0, 0, 39, '1019'),
	(243, 1, 0, -50940, 1021, 0, 0, 39, '1020'),
	(243, 1, 0, -50940, 1022, 0, 0, 39, '1021'),
	(243, 1, 0, -50940, 1023, 0, 0, 39, '1022'),
	(243, 1, 0, -50940, 1024, 0, 0, 39, '1023'),
	(243, 1, 0, -50940, 1025, 0, 0, 39, '1024'),
	(243, 1, 0, -50940, 1026, 0, 0, 39, '1025'),
	(243, 1, 0, -50940, 1027, 0, 0, 39, '1026'),
	(243, 1, 0, -50940, 1028, 0, 0, 39, '1027'),
	(243, 1, 0, -50940, 1029, 0, 0, 39, '1028'),
	(243, 1, 0, -50940, 1030, 0, 0, 39, '1029'),
	(243, 1, 0, -50940, 1031, 0, 0, 39, '1030'),
	(243, 1, 0, -50940, 1032, 0, 0, 39, '1031'),
	(243, 1, 0, -50940, 1033, 0, 0, 39, '1032'),
	(243, 1, 0, -50940, 1034, 0, 0, 39, '1033'),
	(243, 1, 0, -50940, 1035, 0, 0, 39, '1034'),
	(243, 1, 0, -50940, 1036, 0, 0, 39, '1035'),
	(243, 1, 0, -50940, 1037, 0, 0, 39, '1036'),
	(243, 1, 0, -50940, 1038, 0, 0, 39, '1037'),
	(243, 1, 0, -50940, 1039, 0, 0, 39, '1038'),
	(243, 1, 0, -50940, 1040, 0, 0, 39, '1039'),
	(243, 1, 0, -50940, 1041, 0, 0, 39, '1040'),
	(243, 1, 0, -50940, 1042, 0, 0, 39, '1041'),
	(243, 1, 0, -50940, 1043, 0, 0, 39, '1042'),
	(243, 1, 0, -50940, 1044, 0, 0, 39, '1043'),
	(243, 1, 0, -50940, 1045, 0, 0, 39, '1044'),
	(243, 1, 0, -50940, 1046, 0, 0, 39, '1045'),
	(243, 1, 0, -50940, 1047, 0, 0, 39, '1046'),
	(243, 1, 0, -50940, 1048, 0, 0, 39, '1047'),
	(243, 1, 0, -50940, 1049, 0, 0, 39, '1048'),
	(243, 1, 0, -50940, 1050, 0, 0, 39, '1049'),
	(243, 1, 0, -50940, 1051, 0, 0, 39, '1050'),
	(243, 1, 0, -50940, 1052, 0, 0, 39, '1051'),
	(243, 1, 0, -50940, 1053, 0, 0, 39, '1052'),
	(243, 1, 0, -50940, 1054, 0, 0, 39, '1053'),
	(243, 1, 0, -50940, 1055, 0, 0, 39, '1054'),
	(243, 1, 0, -50940, 1056, 0, 0, 39, '1055'),
	(243, 1, 0, -50940, 1057, 0, 0, 39, '1056'),
	(243, 1, 0, -50940, 1058, 0, 0, 39, '1057'),
	(243, 1, 0, -50940, 1059, 0, 0, 39, '1058'),
	(243, 1, 0, -50940, 1060, 0, 0, 39, '1059'),
	(243, 1, 0, -50940, 1061, 0, 0, 39, '1060'),
	(243, 1, 0, -50940, 1062, 0, 0, 39, '1061'),
	(243, 1, 0, -50940, 1063, 0, 0, 39, '1062'),
	(243, 1, 0, -50940, 1064, 0, 0, 39, '1063'),
	(243, 1, 0, -50940, 1065, 0, 0, 39, '1064'),
	(243, 1, 0, -50940, 1066, 0, 0, 39, '1065'),
	(243, 1, 0, -50940, 1067, 0, 0, 39, '1066'),
	(243, 1, 0, -50940, 1068, 0, 0, 39, '1067'),
	(243, 1, 0, -50940, 1069, 0, 0, 39, '1068'),
	(243, 1, 0, -50940, 1070, 0, 0, 39, '1069'),
	(243, 1, 0, -50940, 1071, 0, 0, 39, '1070'),
	(243, 1, 0, -50940, 1072, 0, 0, 39, '1071'),
	(243, 1, 0, -50940, 1073, 0, 0, 39, '1072'),
	(243, 1, 0, -50940, 1074, 0, 0, 39, '1073'),
	(243, 1, 0, -50940, 1075, 0, 0, 39, '1074'),
	(243, 1, 0, -50940, 1076, 0, 0, 39, '1075'),
	(243, 1, 0, -50940, 1077, 0, 0, 39, '1076'),
	(243, 1, 0, -50940, 1078, 0, 0, 39, '1077'),
	(243, 1, 0, -50940, 1079, 0, 0, 39, '1078'),
	(243, 1, 0, -50940, 1080, 0, 0, 39, '1079'),
	(243, 1, 0, -50940, 1081, 0, 0, 39, '1080'),
	(243, 1, 0, -50940, 1082, 0, 0, 39, '1081'),
	(243, 1, 0, -50940, 1083, 0, 0, 39, '1082'),
	(243, 1, 0, -50940, 1084, 0, 0, 39, '1083'),
	(243, 1, 0, -50940, 1085, 0, 0, 39, '1084'),
	(243, 1, 0, -50940, 1086, 0, 0, 39, '1085'),
	(243, 1, 0, -50940, 1087, 0, 0, 39, '1086'),
	(243, 1, 0, -50940, 1088, 0, 0, 39, '1087'),
	(243, 1, 0, -50940, 1089, 0, 0, 39, '1088'),
	(243, 1, 0, -50940, 1090, 0, 0, 39, '1089'),
	(243, 1, 0, -50940, 1091, 0, 0, 39, '1090'),
	(243, 1, 0, -50940, 1092, 0, 0, 39, '1091'),
	(243, 1, 0, -50940, 1093, 0, 0, 39, '1092'),
	(243, 1, 0, -50940, 1094, 0, 0, 39, '1093'),
	(243, 1, 0, -50940, 1095, 0, 0, 39, '1094'),
	(243, 1, 0, -50940, 1096, 0, 0, 39, '1095'),
	(243, 1, 0, -50940, 1097, 0, 0, 39, '1096'),
	(243, 1, 0, -50940, 1098, 0, 0, 39, '1097'),
	(243, 1, 0, -50940, 1099, 0, 0, 39, '1098'),
	(243, 1, 0, -50940, 1100, 0, 0, 39, '1099'),
	(243, 1, 0, -50940, 1101, 0, 0, 39, '1100'),
	(243, 1, 0, -50940, 1102, 0, 0, 39, '1101'),
	(243, 1, 0, -50940, 1103, 0, 0, 39, '1102'),
	(243, 1, 0, -50940, 1104, 0, 0, 39, '1103'),
	(243, 1, 0, -50940, 1105, 0, 0, 39, '1104'),
	(243, 1, 0, -50940, 1106, 0, 0, 39, '1105'),
	(243, 1, 0, -50940, 1107, 0, 0, 39, '1106'),
	(243, 1, 0, -50940, 1108, 0, 0, 39, '1107'),
	(243, 1, 0, -50940, 1109, 0, 0, 39, '1108'),
	(243, 1, 0, -50940, 1110, 0, 0, 39, '1109'),
	(243, 1, 0, -50940, 1111, 0, 0, 39, '1110'),
	(243, 1, 0, -50940, 1112, 0, 0, 39, '1111'),
	(243, 1, 0, -50940, 1113, 0, 0, 39, '1112'),
	(243, 1, 0, -50940, 1114, 0, 0, 39, '1113'),
	(243, 1, 0, -50940, 1115, 0, 0, 39, '1114'),
	(243, 1, 0, -50940, 1116, 0, 0, 39, '1115'),
	(243, 1, 0, -50940, 1117, 0, 0, 39, '1116'),
	(243, 1, 0, -50940, 1118, 0, 0, 39, '1117'),
	(243, 1, 0, -50940, 1119, 0, 0, 39, '1118'),
	(243, 1, 0, -50940, 1120, 0, 0, 39, '1119'),
	(243, 1, 0, -50940, 1121, 0, 0, 39, '1120'),
	(243, 1, 0, -50940, 1122, 0, 0, 39, '1121'),
	(243, 1, 0, -50940, 1123, 0, 0, 39, '1122'),
	(243, 1, 0, -50940, 1124, 0, 0, 39, '1123'),
	(243, 1, 0, -50940, 1125, 0, 0, 39, '1124'),
	(243, 1, 0, -50940, 1126, 0, 0, 39, '1125'),
	(243, 1, 0, -50940, 1127, 0, 0, 39, '1126'),
	(243, 1, 0, -50940, 1128, 0, 0, 39, '1127'),
	(243, 1, 0, -50940, 1129, 0, 0, 39, '1128'),
	(243, 1, 0, -50940, 1130, 0, 0, 39, '1129'),
	(243, 1, 0, -50940, 1131, 0, 0, 39, '1130'),
	(243, 1, 0, -50940, 1132, 0, 0, 39, '1131'),
	(243, 1, 0, -50940, 1133, 0, 0, 39, '1132'),
	(243, 1, 0, -50940, 1134, 0, 0, 39, '1133'),
	(243, 1, 0, -50940, 1135, 0, 0, 39, '1134'),
	(243, 1, 0, -50940, 1136, 0, 0, 39, '1135'),
	(243, 1, 0, -50940, 1137, 0, 0, 39, '1136'),
	(243, 1, 0, -50940, 1138, 0, 0, 39, '1137'),
	(243, 1, 0, -50940, 1139, 0, 0, 39, '1138'),
	(243, 1, 0, -50940, 1140, 0, 0, 39, '1139'),
	(243, 1, 0, -50940, 1141, 0, 0, 39, '1140'),
	(243, 1, 0, -50940, 1142, 0, 0, 39, '1141'),
	(243, 1, 0, -50940, 1143, 0, 0, 39, '1142'),
	(243, 1, 0, -50940, 1144, 0, 0, 39, '1143'),
	(243, 1, 0, -50940, 1145, 0, 0, 39, '1144'),
	(243, 1, 0, -50940, 1146, 0, 0, 39, '1145'),
	(243, 1, 0, -50940, 1147, 0, 0, 39, '1146'),
	(243, 1, 0, -50940, 1148, 0, 0, 39, '1147'),
	(243, 1, 0, -50940, 1149, 0, 0, 39, '1148'),
	(243, 1, 0, -50940, 1150, 0, 0, 39, '1149'),
	(243, 1, 0, -50940, 1151, 0, 0, 39, '1150'),
	(243, 1, 0, -50940, 1152, 0, 0, 39, '1151'),
	(243, 1, 0, -50940, 1153, 0, 0, 39, '1152'),
	(243, 1, 0, -50940, 1154, 0, 0, 39, '1153'),
	(243, 1, 0, -50940, 1155, 0, 0, 39, '1154'),
	(243, 1, 0, -50940, 1156, 0, 0, 39, '1155'),
	(243, 1, 0, -50940, 1157, 0, 0, 39, '1156'),
	(243, 1, 0, -50940, 1158, 0, 0, 39, '1157'),
	(243, 1, 0, -50940, 1159, 0, 0, 39, '1158'),
	(243, 1, 0, -50940, 1160, 0, 0, 39, '1159'),
	(243, 1, 0, -50940, 1161, 0, 0, 39, '1160'),
	(243, 1, 0, -50940, 1162, 0, 0, 39, '1161'),
	(243, 1, 0, -50940, 1163, 0, 0, 39, '1162'),
	(243, 1, 0, -50940, 1164, 0, 0, 39, '1163'),
	(243, 1, 0, -50940, 1165, 0, 0, 39, '1164'),
	(243, 1, 0, -50940, 1166, 0, 0, 39, '1165'),
	(243, 1, 0, -50940, 1167, 0, 0, 39, '1166'),
	(243, 1, 0, -50940, 1168, 0, 0, 39, '1167'),
	(243, 1, 0, -50940, 1169, 0, 0, 39, '1168'),
	(243, 1, 0, -50940, 1170, 0, 0, 39, '1169'),
	(243, 1, 0, -50940, 1171, 0, 0, 39, '1170'),
	(243, 1, 0, -50940, 1172, 0, 0, 39, '1171'),
	(243, 1, 0, -50940, 1173, 0, 0, 39, '1172'),
	(243, 1, 0, -50940, 1174, 0, 0, 39, '1173'),
	(243, 1, 0, -50940, 1175, 0, 0, 39, '1174'),
	(243, 1, 0, -50940, 1176, 0, 0, 39, '1175'),
	(243, 1, 0, -50940, 1177, 0, 0, 39, '1176'),
	(243, 1, 0, -50940, 1178, 0, 0, 39, '1177'),
	(243, 1, 0, -50940, 1179, 0, 0, 39, '1178'),
	(243, 1, 0, -50940, 1180, 0, 0, 39, '1179'),
	(243, 1, 0, -50940, 1181, 0, 0, 39, '1180'),
	(243, 1, 0, -50940, 1182, 0, 0, 39, '1181'),
	(243, 1, 0, -50940, 1183, 0, 0, 39, '1182'),
	(243, 1, 0, -50940, 1184, 0, 0, 39, '1183'),
	(243, 1, 0, -50940, 1185, 0, 0, 39, '1184'),
	(243, 1, 0, -50940, 1186, 0, 0, 39, '1185'),
	(243, 1, 0, -50940, 1187, 0, 0, 39, '1186'),
	(243, 1, 0, -50940, 1188, 0, 0, 39, '1187'),
	(243, 1, 0, -50940, 1189, 0, 0, 39, '1188'),
	(243, 1, 0, -50940, 1190, 0, 0, 39, '1189'),
	(243, 1, 0, -50940, 1191, 0, 0, 39, '1190'),
	(243, 1, 0, -50940, 1192, 0, 0, 39, '1191'),
	(243, 1, 0, -50940, 1193, 0, 0, 39, '1192'),
	(243, 1, 0, -50940, 1194, 0, 0, 39, '1193'),
	(243, 1, 0, -50940, 1195, 0, 0, 39, '1194'),
	(243, 1, 0, -50940, 1196, 0, 0, 39, '1195'),
	(243, 1, 0, -50940, 1197, 0, 0, 39, '1196'),
	(243, 1, 0, -50940, 1198, 0, 0, 39, '1197'),
	(243, 1, 0, -50940, 1199, 0, 0, 39, '1198'),
	(243, 1, 0, -50940, 1200, 0, 0, 39, '1199'),
	(243, 1, 0, -50940, 1201, 0, 0, 39, '1200'),
	(243, 1, 0, -50940, 1202, 0, 0, 39, '1201'),
	(243, 1, 0, -50940, 1203, 0, 0, 39, '1202'),
	(243, 1, 0, -50940, 1204, 0, 0, 39, '1203'),
	(243, 1, 0, -50940, 1205, 0, 0, 39, '1204'),
	(243, 1, 0, -50940, 1206, 0, 0, 39, '1205'),
	(243, 1, 0, -50940, 1207, 0, 0, 39, '1206'),
	(243, 1, 0, -50940, 1208, 0, 0, 39, '1207'),
	(243, 1, 0, -50940, 1209, 0, 0, 39, '1208'),
	(243, 1, 0, -50940, 1210, 0, 0, 39, '1209'),
	(243, 1, 0, -50940, 1211, 0, 0, 39, '1210'),
	(243, 1, 0, -50940, 1212, 0, 0, 39, '1211'),
	(243, 1, 0, -50940, 1213, 0, 0, 39, '1212'),
	(243, 1, 0, -50940, 1214, 0, 0, 39, '1213'),
	(243, 1, 0, -50940, 1215, 0, 0, 39, '1214'),
	(243, 1, 0, -50940, 1216, 0, 0, 39, '1215'),
	(243, 1, 0, -50940, 1217, 0, 0, 39, '1216'),
	(243, 1, 0, -50940, 1218, 0, 0, 39, '1217'),
	(243, 1, 0, -50940, 1219, 0, 0, 39, '1218'),
	(243, 1, 0, -50940, 1220, 0, 0, 39, '1219'),
	(243, 1, 0, -50940, 1221, 0, 0, 39, '1220'),
	(243, 1, 0, -50940, 1222, 0, 0, 39, '1221'),
	(243, 1, 0, -50940, 1223, 0, 0, 39, '1222'),
	(243, 1, 0, -50940, 1224, 0, 0, 39, '1223'),
	(243, 1, 0, -50940, 1225, 0, 0, 39, '1224'),
	(243, 1, 0, -50940, 1226, 0, 0, 39, '1225'),
	(243, 1, 0, -50940, 1227, 0, 0, 39, '1226'),
	(243, 1, 0, -50940, 1228, 0, 0, 39, '1227'),
	(243, 1, 0, -50940, 1229, 0, 0, 39, '1228'),
	(243, 1, 0, -50940, 1230, 0, 0, 39, '1229'),
	(243, 1, 0, -50940, 1231, 0, 0, 39, '1230'),
	(243, 1, 0, -50940, 1232, 0, 0, 39, '1231'),
	(243, 1, 0, -50940, 1233, 0, 0, 39, '1232'),
	(243, 1, 0, -50940, 1234, 0, 0, 39, '1233'),
	(243, 1, 0, -50940, 1235, 0, 0, 39, '1234'),
	(243, 1, 0, -50940, 1236, 0, 0, 39, '1235'),
	(243, 1, 0, -50940, 1237, 0, 0, 39, '1236'),
	(243, 1, 0, -50940, 1238, 0, 0, 39, '1237'),
	(243, 1, 0, -50940, 1239, 0, 0, 39, '1238'),
	(243, 1, 0, -50940, 1240, 0, 0, 39, '1239'),
	(243, 1, 0, -50940, 1241, 0, 0, 39, '1240'),
	(243, 1, 0, -50940, 1242, 0, 0, 39, '1241'),
	(243, 1, 0, -50940, 1243, 0, 0, 39, '1242'),
	(243, 1, 0, -50940, 1244, 0, 0, 39, '1243'),
	(243, 1, 0, -50940, 1245, 0, 0, 39, '1244'),
	(243, 1, 0, -50940, 1246, 0, 0, 39, '1245'),
	(243, 1, 0, -50940, 1247, 0, 0, 39, '1246'),
	(243, 1, 0, -50940, 1248, 0, 0, 39, '1247'),
	(243, 1, 0, -50940, 1249, 0, 0, 39, '1248'),
	(243, 1, 0, -50940, 1250, 0, 0, 39, '1249'),
	(243, 1, 0, -50940, 1251, 0, 0, 39, '1250'),
	(243, 1, 0, -50940, 1252, 0, 0, 39, '1251'),
	(243, 1, 0, -50940, 1253, 0, 0, 39, '1252'),
	(243, 1, 0, -50940, 1254, 0, 0, 39, '1253'),
	(243, 1, 0, -50940, 1255, 0, 0, 39, '1254'),
	(243, 1, 0, -50940, 1256, 0, 0, 39, '1255'),
	(243, 1, 0, -50940, 1257, 0, 0, 39, '1256'),
	(243, 1, 0, -50940, 1258, 0, 0, 39, '1257'),
	(243, 1, 0, -50940, 1259, 0, 0, 39, '1258'),
	(243, 1, 0, -50940, 1260, 0, 0, 39, '1259'),
	(243, 1, 0, -50940, 1261, 0, 0, 39, '1260'),
	(243, 1, 0, -50940, 1262, 0, 0, 39, '1261'),
	(243, 1, 0, -50940, 1263, 0, 0, 39, '1262'),
	(243, 1, 0, -50940, 1264, 0, 0, 39, '1263'),
	(243, 1, 0, -50940, 1265, 0, 0, 39, '1264'),
	(243, 1, 0, -50940, 1266, 0, 0, 39, '1265'),
	(243, 1, 0, -50940, 1267, 0, 0, 39, '1266'),
	(243, 1, 0, -50940, 1268, 0, 0, 39, '1267'),
	(243, 1, 0, -50940, 1269, 0, 0, 39, '1268'),
	(243, 1, 0, -50940, 1270, 0, 0, 39, '1269'),
	(243, 1, 0, -50940, 1271, 0, 0, 39, '1270'),
	(243, 1, 0, -50940, 1272, 0, 0, 39, '1271'),
	(243, 1, 0, -50940, 1273, 0, 0, 39, '1272'),
	(243, 1, 0, -50940, 1274, 0, 0, 39, '1273'),
	(243, 1, 0, -50940, 1275, 0, 0, 39, '1274'),
	(243, 1, 0, -50940, 1276, 0, 0, 39, '1275'),
	(243, 1, 0, -50940, 1277, 0, 0, 39, '1276'),
	(243, 1, 0, -50940, 1278, 0, 0, 39, '1277'),
	(243, 1, 0, -50940, 1279, 0, 0, 39, '1278'),
	(243, 1, 0, -50940, 1280, 0, 0, 39, '1279'),
	(243, 1, 0, -50940, 1281, 0, 0, 39, '1280'),
	(243, 1, 0, -50940, 1282, 0, 0, 39, '1281'),
	(243, 1, 0, -50940, 1283, 0, 0, 39, '1282'),
	(243, 1, 0, -50940, 1284, 0, 0, 39, '1283'),
	(243, 1, 0, -50940, 1285, 0, 0, 39, '1284'),
	(243, 1, 0, -50940, 1286, 0, 0, 39, '1285'),
	(243, 1, 0, -50940, 1287, 0, 0, 39, '1286'),
	(243, 1, 0, -50940, 1288, 0, 0, 39, '1287'),
	(243, 1, 0, -50940, 1289, 0, 0, 39, '1288'),
	(243, 1, 0, -50940, 1290, 0, 0, 39, '1289'),
	(243, 1, 0, -50940, 1291, 0, 0, 39, '1290'),
	(243, 1, 0, -50940, 1292, 0, 0, 39, '1291'),
	(243, 1, 0, -50940, 1293, 0, 0, 39, '1292'),
	(243, 1, 0, -50940, 1294, 0, 0, 39, '1293'),
	(243, 1, 0, -50940, 1295, 0, 0, 39, '1294'),
	(243, 1, 0, -50940, 1296, 0, 0, 39, '1295'),
	(243, 1, 0, -50940, 1297, 0, 0, 39, '1296'),
	(243, 1, 0, -50940, 1298, 0, 0, 39, '1297'),
	(243, 1, 0, -50940, 1299, 0, 0, 39, '1298'),
	(243, 1, 0, -50940, 1300, 0, 0, 39, '1299'),
	(243, 1, 0, -50940, 1301, 0, 0, 39, '1300'),
	(243, 1, 0, -50940, 1302, 0, 0, 39, '1301'),
	(243, 1, 0, -50940, 1303, 0, 0, 39, '1302'),
	(243, 1, 0, -50940, 1304, 0, 0, 39, '1303'),
	(243, 1, 0, -50940, 1305, 0, 0, 39, '1304'),
	(243, 1, 0, -50940, 1306, 0, 0, 39, '1305'),
	(243, 1, 0, -50940, 1307, 0, 0, 39, '1306'),
	(243, 1, 0, -50940, 1308, 0, 0, 39, '1307'),
	(243, 1, 0, -50940, 1309, 0, 0, 39, '1308'),
	(243, 1, 0, -50940, 1310, 0, 0, 39, '1309'),
	(243, 1, 0, -50940, 1311, 0, 0, 39, '1310'),
	(243, 1, 0, -50940, 1312, 0, 0, 39, '1311'),
	(243, 1, 0, -50940, 1313, 0, 0, 39, '1312'),
	(243, 1, 0, -50940, 1314, 0, 0, 39, '1313'),
	(243, 1, 0, -50940, 1315, 0, 0, 39, '1314'),
	(243, 1, 0, -50940, 1316, 0, 0, 39, '1315'),
	(243, 1, 0, -50940, 1317, 0, 0, 39, '1316'),
	(243, 1, 0, -50940, 1318, 0, 0, 39, '1317'),
	(243, 1, 0, -50940, 1319, 0, 0, 39, '1318'),
	(243, 1, 0, -50940, 1320, 0, 0, 39, '1319'),
	(243, 1, 0, -50940, 1321, 0, 0, 39, '1320'),
	(243, 1, 0, -50940, 1322, 0, 0, 39, '1321'),
	(243, 1, 0, -50940, 1323, 0, 0, 39, '1322'),
	(243, 1, 0, -50940, 1324, 0, 0, 39, '1323'),
	(243, 1, 0, -50940, 1325, 0, 0, 39, '1324'),
	(243, 1, 0, -50940, 1326, 0, 0, 39, '1325'),
	(243, 1, 0, -50940, 1327, 0, 0, 39, '1326'),
	(243, 1, 0, -50940, 1328, 0, 0, 39, '1327'),
	(243, 1, 0, -50940, 1329, 0, 0, 39, '1328'),
	(243, 1, 0, -50940, 1330, 0, 0, 39, '1329'),
	(243, 1, 0, -50940, 1331, 0, 0, 39, '1330'),
	(243, 1, 0, -50940, 1332, 0, 0, 39, '1331'),
	(243, 1, 0, -50940, 1333, 0, 0, 39, '1332'),
	(243, 1, 0, -50940, 1334, 0, 0, 39, '1333'),
	(243, 1, 0, -50940, 1335, 0, 0, 39, '1334'),
	(243, 1, 0, -50940, 1336, 0, 0, 39, '1335'),
	(243, 1, 0, -50940, 1337, 0, 0, 39, '1336'),
	(243, 1, 0, -50940, 1338, 0, 0, 39, '1337'),
	(243, 1, 0, -50940, 1339, 0, 0, 39, '1338'),
	(243, 1, 0, -50940, 1340, 0, 0, 39, '1339'),
	(243, 1, 0, -50940, 1341, 0, 0, 39, '1340'),
	(243, 1, 0, -50940, 1342, 0, 0, 39, '1341'),
	(243, 1, 0, -50940, 1343, 0, 0, 39, '1342'),
	(243, 1, 0, -50940, 1344, 0, 0, 39, '1343'),
	(243, 1, 0, -50940, 1345, 0, 0, 39, '1344'),
	(243, 1, 0, -50940, 1346, 0, 0, 39, '1345'),
	(243, 1, 0, -50940, 1347, 0, 0, 39, '1346'),
	(243, 1, 0, -50940, 1348, 0, 0, 39, '1347'),
	(243, 1, 0, -50940, 1349, 0, 0, 39, '1348'),
	(243, 1, 0, -50940, 1350, 0, 0, 39, '1349'),
	(243, 1, 0, -50940, 1351, 0, 0, 39, '1350'),
	(243, 1, 0, -50940, 1352, 0, 0, 39, '1351'),
	(243, 1, 0, -50940, 1353, 0, 0, 39, '1352'),
	(243, 1, 0, -50940, 1354, 0, 0, 39, '1353'),
	(243, 1, 0, -50940, 1355, 0, 0, 39, '1354'),
	(243, 1, 0, -50940, 1356, 0, 0, 39, '1355'),
	(243, 1, 0, -50940, 1357, 0, 0, 39, '1356'),
	(243, 1, 0, -50940, 1358, 0, 0, 39, '1357'),
	(243, 1, 0, -50940, 1359, 0, 0, 39, '1358'),
	(243, 1, 0, -50940, 1360, 0, 0, 39, '1359'),
	(243, 1, 0, -50940, 1361, 0, 0, 39, '1360'),
	(243, 1, 0, -50940, 1362, 0, 0, 39, '1361'),
	(243, 1, 0, -50940, 1363, 0, 0, 39, '1362'),
	(243, 1, 0, -50940, 1364, 0, 0, 39, '1363'),
	(243, 1, 0, -50940, 1365, 0, 0, 39, '1364'),
	(243, 1, 0, -50940, 1366, 0, 0, 39, '1365'),
	(243, 1, 0, -50940, 1367, 0, 0, 39, '1366'),
	(243, 1, 0, -50940, 1368, 0, 0, 39, '1367'),
	(243, 1, 0, -50940, 1369, 0, 0, 39, '1368'),
	(243, 1, 0, -50940, 1370, 0, 0, 39, '1369'),
	(243, 1, 0, -50940, 1371, 0, 0, 39, '1370'),
	(243, 1, 0, -50940, 1372, 0, 0, 39, '1371'),
	(243, 1, 0, -50940, 1373, 0, 0, 39, '1372'),
	(243, 1, 0, -50940, 1374, 0, 0, 39, '1373'),
	(243, 1, 0, -50940, 1375, 0, 0, 39, '1374'),
	(243, 1, 0, -50940, 1376, 0, 0, 39, '1375'),
	(243, 1, 0, -50940, 1377, 0, 0, 39, '1376'),
	(243, 1, 0, -50940, 1378, 0, 0, 39, '1377'),
	(243, 1, 0, -50940, 1379, 0, 0, 39, '1378'),
	(243, 1, 0, -50940, 1380, 0, 0, 39, '1379'),
	(243, 1, 0, -50940, 1381, 0, 0, 39, '1380'),
	(243, 1, 0, -50940, 1382, 0, 0, 39, '1381'),
	(243, 1, 0, -50940, 1383, 0, 0, 39, '1382'),
	(243, 1, 0, -50940, 1384, 0, 0, 39, '1383'),
	(243, 1, 0, -50940, 1385, 0, 0, 39, '1384'),
	(243, 1, 0, -50940, 1386, 0, 0, 39, '1385'),
	(243, 1, 0, -50940, 1387, 0, 0, 39, '1386'),
	(243, 1, 0, -50940, 1388, 0, 0, 39, '1387'),
	(243, 1, 0, -50940, 1389, 0, 0, 39, '1388'),
	(243, 1, 0, -50940, 1390, 0, 0, 39, '1389'),
	(243, 1, 0, -50940, 1391, 0, 0, 39, '1390'),
	(243, 1, 0, -50940, 1392, 0, 0, 39, '1391'),
	(243, 1, 0, -50940, 1393, 0, 0, 39, '1392'),
	(243, 1, 0, -50940, 1394, 0, 0, 39, '1393'),
	(243, 1, 0, -50940, 1395, 0, 0, 39, '1394'),
	(243, 1, 0, -50940, 1396, 0, 0, 39, '1395'),
	(243, 1, 0, -50940, 1397, 0, 0, 39, '1396'),
	(243, 1, 0, -50940, 1398, 0, 0, 39, '1397'),
	(243, 1, 0, -50940, 1399, 0, 0, 39, '1398'),
	(243, 1, 0, -50940, 1400, 0, 0, 39, '1399'),
	(243, 1, 0, -50940, 1401, 0, 0, 39, '1400'),
	(243, 1, 0, -50940, 1402, 0, 0, 39, '1401'),
	(243, 1, 0, -50940, 1403, 0, 0, 39, '1402'),
	(243, 1, 0, -50940, 1404, 0, 0, 39, '1403'),
	(243, 1, 0, -50940, 1405, 0, 0, 39, '1404'),
	(243, 1, 0, -50940, 1406, 0, 0, 39, '1405'),
	(243, 1, 0, -50940, 1407, 0, 0, 39, '1406'),
	(243, 1, 0, -50940, 1408, 0, 0, 39, '1407'),
	(243, 1, 0, -50940, 1409, 0, 0, 39, '1408'),
	(243, 1, 0, -50940, 1410, 0, 0, 39, '1409'),
	(243, 1, 0, -50940, 1411, 0, 0, 39, '1410'),
	(243, 1, 0, -50940, 1412, 0, 0, 39, '1411'),
	(243, 1, 0, -50940, 1413, 0, 0, 39, '1412'),
	(243, 1, 0, -50940, 1414, 0, 0, 39, '1413'),
	(243, 1, 0, -50940, 1415, 0, 0, 39, '1414'),
	(243, 1, 0, -50940, 1416, 0, 0, 39, '1415'),
	(243, 1, 0, -50940, 1417, 0, 0, 39, '1416'),
	(243, 1, 0, -50940, 1418, 0, 0, 39, '1417'),
	(243, 1, 0, -50940, 1419, 0, 0, 39, '1418'),
	(243, 1, 0, -50940, 1420, 0, 0, 39, '1419'),
	(243, 1, 0, -50940, 1421, 0, 0, 39, '1420'),
	(243, 1, 0, -50940, 1422, 0, 0, 39, '1421'),
	(243, 1, 0, -50940, 1423, 0, 0, 39, '1422'),
	(243, 1, 0, -50940, 1424, 0, 0, 39, '1423'),
	(243, 1, 0, -50940, 1425, 0, 0, 39, '1424'),
	(243, 1, 0, -50940, 1426, 0, 0, 39, '1425'),
	(243, 1, 0, -50940, 1427, 0, 0, 39, '1426'),
	(243, 1, 0, -50940, 1428, 0, 0, 39, '1427'),
	(243, 1, 0, -50940, 1429, 0, 0, 39, '1428'),
	(243, 1, 0, -50940, 1430, 0, 0, 39, '1429'),
	(243, 1, 0, -50940, 1431, 0, 0, 39, '1430'),
	(243, 1, 0, -50940, 1432, 0, 0, 39, '1431'),
	(243, 1, 0, -50940, 1433, 0, 0, 39, '1432'),
	(243, 1, 0, -50940, 1434, 0, 0, 39, '1433'),
	(243, 1, 0, -50940, 1435, 0, 0, 39, '1434'),
	(243, 1, 0, -50940, 1436, 0, 0, 39, '1435'),
	(243, 1, 0, -50940, 1437, 0, 0, 39, '1436'),
	(243, 1, 0, -50940, 1438, 0, 0, 39, '1437'),
	(243, 1, 0, -50940, 1439, 0, 0, 39, '1438'),
	(243, 1, 0, -50940, 1440, 0, 0, 39, '1439'),
	(243, 1, 0, -50940, 1441, 0, 0, 39, '1440'),
	(243, 1, 0, -50940, 1442, 0, 0, 39, '1441'),
	(243, 1, 0, -50940, 1443, 0, 0, 39, '1442'),
	(243, 1, 0, -50940, 1444, 0, 0, 39, '1443'),
	(243, 1, 0, -50940, 1445, 0, 0, 39, '1444'),
	(243, 1, 0, -50940, 1446, 0, 0, 39, '1445'),
	(243, 1, 0, -50940, 1447, 0, 0, 39, '1446'),
	(243, 1, 0, -50940, 1448, 0, 0, 39, '1447'),
	(243, 1, 0, -50940, 1449, 0, 0, 39, '1448'),
	(243, 1, 0, -50940, 1450, 0, 0, 39, '1449'),
	(243, 1, 0, -50940, 1451, 0, 0, 39, '1450'),
	(243, 1, 0, -50940, 1452, 0, 0, 39, '1451'),
	(243, 1, 0, -50940, 1453, 0, 0, 39, '1452'),
	(243, 1, 0, -50940, 1454, 0, 0, 39, '1453'),
	(243, 1, 0, -50940, 1455, 0, 0, 39, '1454'),
	(243, 1, 0, -50940, 1456, 0, 0, 39, '1455'),
	(243, 1, 0, -50940, 1457, 0, 0, 39, '1456'),
	(243, 1, 0, -50940, 1458, 0, 0, 39, '1457'),
	(243, 1, 0, -50940, 1459, 0, 0, 39, '1458'),
	(243, 1, 0, -50940, 1460, 0, 0, 39, '1459'),
	(243, 1, 0, -50940, 1461, 0, 0, 39, '1460'),
	(243, 1, 0, -50940, 1462, 0, 0, 39, '1461'),
	(243, 1, 0, -50940, 1463, 0, 0, 39, '1462'),
	(243, 1, 0, -50940, 1464, 0, 0, 39, '1463'),
	(243, 1, 0, -50940, 1465, 0, 0, 39, '1464'),
	(243, 1, 0, -50940, 1466, 0, 0, 39, '1465'),
	(243, 1, 0, -50940, 1467, 0, 0, 39, '1466'),
	(243, 1, 0, -50940, 1468, 0, 0, 39, '1467'),
	(243, 1, 0, -50940, 1469, 0, 0, 39, '1468'),
	(243, 1, 0, -50940, 1470, 0, 0, 39, '1469'),
	(243, 1, 0, -50940, 1471, 0, 0, 39, '1470'),
	(243, 1, 0, -50940, 1472, 0, 0, 39, '1471'),
	(243, 1, 0, -50940, 1473, 0, 0, 39, '1472'),
	(243, 1, 0, -50940, 1474, 0, 0, 39, '1473'),
	(243, 1, 0, -50940, 1475, 0, 0, 39, '1474'),
	(243, 1, 0, -50940, 1476, 0, 0, 39, '1475'),
	(243, 1, 0, -50940, 1477, 0, 0, 39, '1476'),
	(243, 1, 0, -50940, 1478, 0, 0, 39, '1477'),
	(243, 1, 0, -50940, 1479, 0, 0, 39, '1478'),
	(243, 1, 0, -50940, 1480, 0, 0, 39, '1479'),
	(243, 1, 0, -50940, 1481, 0, 0, 39, '1480'),
	(243, 1, 0, -50940, 1482, 0, 0, 39, '1481'),
	(243, 1, 0, -50940, 1483, 0, 0, 39, '1482'),
	(243, 1, 0, -50940, 1484, 0, 0, 39, '1483'),
	(243, 1, 0, -50940, 1485, 0, 0, 39, '1484'),
	(243, 1, 0, -50940, 1486, 0, 0, 39, '1485'),
	(243, 1, 0, -50940, 1487, 0, 0, 39, '1486'),
	(243, 1, 0, -50940, 1488, 0, 0, 39, '1487'),
	(243, 1, 0, -50940, 1489, 0, 0, 39, '1488'),
	(243, 1, 0, -50940, 1490, 0, 0, 39, '1489'),
	(243, 1, 0, -50940, 1491, 0, 0, 39, '1490'),
	(243, 1, 0, -50940, 1492, 0, 0, 39, '1491'),
	(243, 1, 0, -50940, 1493, 0, 0, 39, '1492'),
	(243, 1, 0, -50940, 1494, 0, 0, 39, '1493'),
	(243, 1, 0, -50940, 1495, 0, 0, 39, '1494'),
	(243, 1, 0, -50940, 1496, 0, 0, 39, '1495'),
	(243, 1, 0, -50940, 1497, 0, 0, 39, '1496'),
	(243, 1, 0, -50940, 1498, 0, 0, 39, '1497'),
	(243, 1, 0, -50940, 1499, 0, 0, 39, '1498'),
	(243, 1, 0, -50940, 1500, 0, 0, 39, '1499'),
	(243, 1, 0, -50940, 1501, 0, 0, 39, '1500'),
	(243, 1, 0, -50940, 1502, 0, 0, 39, '1501'),
	(243, 1, 0, -50940, 1503, 0, 0, 39, '1502'),
	(243, 1, 0, -50940, 1504, 0, 0, 39, '1503'),
	(243, 1, 0, -50940, 1505, 0, 0, 39, '1504'),
	(243, 1, 0, -50940, 1506, 0, 0, 39, '1505'),
	(243, 1, 0, -50940, 1507, 0, 0, 39, '1506'),
	(243, 1, 0, -50940, 1508, 0, 0, 39, '1507'),
	(243, 1, 0, -50940, 1509, 0, 0, 39, '1508'),
	(243, 1, 0, -50940, 1510, 0, 0, 39, '1509'),
	(243, 1, 0, -50940, 1511, 0, 0, 39, '1510'),
	(243, 1, 0, -50940, 1512, 0, 0, 39, '1511'),
	(243, 1, 0, -50940, 1513, 0, 0, 39, '1512'),
	(243, 1, 0, -50940, 1514, 0, 0, 39, '1513'),
	(243, 1, 0, -50940, 1515, 0, 0, 39, '1514'),
	(243, 1, 0, -50940, 1516, 0, 0, 39, '1515'),
	(243, 1, 0, -50940, 1517, 0, 0, 39, '1516'),
	(243, 1, 0, -50940, 1518, 0, 0, 39, '1517'),
	(243, 1, 0, -50940, 1519, 0, 0, 39, '1518'),
	(243, 1, 0, -50940, 1520, 0, 0, 39, '1519'),
	(243, 1, 0, -50940, 1521, 0, 0, 39, '1520'),
	(243, 1, 0, -50940, 1522, 0, 0, 39, '1521'),
	(243, 1, 0, -50940, 1523, 0, 0, 39, '1522'),
	(243, 1, 0, -50940, 1524, 0, 0, 39, '1523'),
	(243, 1, 0, -50940, 1525, 0, 0, 39, '1524'),
	(243, 1, 0, -50940, 1526, 0, 0, 39, '1525'),
	(243, 1, 0, -50940, 1527, 0, 0, 39, '1526'),
	(243, 1, 0, -50940, 1528, 0, 0, 39, '1527'),
	(243, 1, 0, -50940, 1529, 0, 0, 39, '1528'),
	(243, 1, 0, -50940, 1530, 0, 0, 39, '1529'),
	(243, 1, 0, -50940, 1531, 0, 0, 39, '1530'),
	(243, 1, 0, -50940, 1532, 0, 0, 39, '1531'),
	(243, 1, 0, -50940, 1533, 0, 0, 39, '1532'),
	(243, 1, 0, -50940, 1534, 0, 0, 39, '1533'),
	(243, 1, 0, -50940, 1535, 0, 0, 39, '1534'),
	(243, 1, 0, -50940, 1536, 0, 0, 39, '1535'),
	(243, 1, 0, -50940, 1537, 0, 0, 39, '1536'),
	(243, 1, 0, -50940, 1538, 0, 0, 39, '1537'),
	(243, 1, 0, -50940, 1539, 0, 0, 39, '1538'),
	(243, 1, 0, -50940, 1540, 0, 0, 39, '1539'),
	(243, 1, 0, -50940, 1541, 0, 0, 39, '1540'),
	(243, 1, 0, -50940, 1542, 0, 0, 39, '1541'),
	(243, 1, 0, -50940, 1543, 0, 0, 39, '1542'),
	(243, 1, 0, -50940, 1544, 0, 0, 39, '1543'),
	(243, 1, 0, -50940, 1545, 0, 0, 39, '1544'),
	(243, 1, 0, -50940, 1546, 0, 0, 39, '1545'),
	(243, 1, 0, -50940, 1547, 0, 0, 39, '1546'),
	(243, 1, 0, -50940, 1548, 0, 0, 39, '1547'),
	(243, 1, 0, -50940, 1549, 0, 0, 39, '1548'),
	(243, 1, 0, -50940, 1550, 0, 0, 39, '1549'),
	(243, 1, 0, -50940, 1551, 0, 0, 39, '1550'),
	(243, 1, 0, -50940, 1552, 0, 0, 39, '1551'),
	(243, 1, 0, -50940, 1553, 0, 0, 39, '1552'),
	(243, 1, 0, -50940, 1554, 0, 0, 39, '1553'),
	(243, 1, 0, -50940, 1555, 0, 0, 39, '1554'),
	(243, 1, 0, -50940, 1556, 0, 0, 39, '1555'),
	(243, 1, 0, -50940, 1557, 0, 0, 39, '1556'),
	(243, 1, 0, -50940, 1558, 0, 0, 39, '1557'),
	(243, 1, 0, -50940, 1559, 0, 0, 39, '1558'),
	(243, 1, 0, -50940, 1560, 0, 0, 39, '1559'),
	(243, 1, 0, -50940, 1561, 0, 0, 39, '1560'),
	(243, 1, 0, -50940, 1562, 0, 0, 39, '1561'),
	(243, 1, 0, -50940, 1563, 0, 0, 39, '1562'),
	(243, 1, 0, -50940, 1564, 0, 0, 39, '1563'),
	(243, 1, 0, -50940, 1565, 0, 0, 39, '1564'),
	(243, 1, 0, -50940, 1566, 0, 0, 39, '1565'),
	(243, 1, 0, -50940, 1567, 0, 0, 39, '1566'),
	(243, 1, 0, -50940, 1568, 0, 0, 39, '1567'),
	(243, 1, 0, -50940, 1569, 0, 0, 39, '1568'),
	(243, 1, 0, -50940, 1570, 0, 0, 39, '1569'),
	(243, 1, 0, -50940, 1571, 0, 0, 39, '1570'),
	(243, 1, 0, -50940, 1572, 0, 0, 39, '1571'),
	(243, 1, 0, -50940, 1573, 0, 0, 39, '1572'),
	(243, 1, 0, -50940, 1574, 0, 0, 39, '1573'),
	(243, 1, 0, -50940, 1575, 0, 0, 39, '1574'),
	(243, 1, 0, -50940, 1576, 0, 0, 39, '1575'),
	(243, 1, 0, -50940, 1577, 0, 0, 39, '1576'),
	(243, 1, 0, -50940, 1578, 0, 0, 39, '1577'),
	(243, 1, 0, -50940, 1579, 0, 0, 39, '1578'),
	(243, 1, 0, -50940, 1580, 0, 0, 39, '1579'),
	(243, 1, 0, -50940, 1581, 0, 0, 39, '1580'),
	(243, 1, 0, -50940, 1582, 0, 0, 39, '1581'),
	(243, 1, 0, -50940, 1583, 0, 0, 39, '1582'),
	(243, 1, 0, -50940, 1584, 0, 0, 39, '1583'),
	(243, 1, 0, -50940, 1585, 0, 0, 39, '1584'),
	(243, 1, 0, -50940, 1586, 0, 0, 39, '1585'),
	(243, 1, 0, -50940, 1587, 0, 0, 39, '1586'),
	(243, 1, 0, -50940, 1588, 0, 0, 39, '1587'),
	(243, 1, 0, -50940, 1589, 0, 0, 39, '1588'),
	(243, 1, 0, -50940, 1590, 0, 0, 39, '1589'),
	(243, 1, 0, -50940, 1591, 0, 0, 39, '1590'),
	(243, 1, 0, -50940, 1592, 0, 0, 39, '1591'),
	(243, 1, 0, -50940, 1593, 0, 0, 39, '1592'),
	(243, 1, 0, -50940, 1594, 0, 0, 39, '1593'),
	(243, 1, 0, -50940, 1595, 0, 0, 39, '1594'),
	(243, 1, 0, -50940, 1596, 0, 0, 39, '1595'),
	(243, 1, 0, -50940, 1597, 0, 0, 39, '1596'),
	(243, 1, 0, -50940, 1598, 0, 0, 39, '1597'),
	(243, 1, 0, -50940, 1599, 0, 0, 39, '1598'),
	(243, 1, 0, -50940, 1600, 0, 0, 39, '1599'),
	(243, 1, 0, -50940, 1601, 0, 0, 39, '1600'),
	(243, 1, 0, -50940, 1602, 0, 0, 39, '1601'),
	(243, 1, 0, -50940, 1603, 0, 0, 39, '1602'),
	(243, 1, 0, -50940, 1604, 0, 0, 39, '1603'),
	(243, 1, 0, -50940, 1605, 0, 0, 39, '1604'),
	(243, 1, 0, -50940, 1606, 0, 0, 39, '1605'),
	(243, 1, 0, -50940, 1607, 0, 0, 39, '1606'),
	(243, 1, 0, -50940, 1608, 0, 0, 39, '1607'),
	(243, 1, 0, -50940, 1609, 0, 0, 39, '1608'),
	(243, 1, 0, -50940, 1610, 0, 0, 39, '1609'),
	(243, 1, 0, -50940, 1611, 0, 0, 39, '1610'),
	(243, 1, 0, -50940, 1612, 0, 0, 39, '1611'),
	(243, 1, 0, -50940, 1613, 0, 0, 39, '1612'),
	(243, 1, 0, -50940, 1614, 0, 0, 39, '1613'),
	(243, 1, 0, -50940, 1615, 0, 0, 39, '1614'),
	(243, 1, 0, -50940, 1616, 0, 0, 39, '1615'),
	(243, 1, 0, -50940, 1617, 0, 0, 39, '1616'),
	(243, 1, 0, -50940, 1618, 0, 0, 39, '1617'),
	(243, 1, 0, -50940, 1619, 0, 0, 39, '1618'),
	(243, 1, 0, -50940, 1620, 0, 0, 39, '1619'),
	(243, 1, 0, -50940, 1621, 0, 0, 39, '1620'),
	(243, 1, 0, -50940, 1622, 0, 0, 39, '1621'),
	(243, 1, 0, -50940, 1623, 0, 0, 39, '1622'),
	(243, 1, 0, -50940, 1624, 0, 0, 39, '1623'),
	(243, 1, 0, -50940, 1625, 0, 0, 39, '1624'),
	(243, 1, 0, -50940, 1626, 0, 0, 39, '1625'),
	(243, 1, 0, -50940, 1627, 0, 0, 39, '1626'),
	(243, 1, 0, -50940, 1628, 0, 0, 39, '1627'),
	(243, 1, 0, -50940, 1629, 0, 0, 39, '1628'),
	(243, 1, 0, -50940, 1630, 0, 0, 39, '1629'),
	(243, 1, 0, -50940, 1631, 0, 0, 39, '1630'),
	(243, 1, 0, -50940, 1632, 0, 0, 39, '1631'),
	(243, 1, 0, -50940, 1633, 0, 0, 39, '1632'),
	(243, 1, 0, -50940, 1634, 0, 0, 39, '1633'),
	(243, 1, 0, -50940, 1635, 0, 0, 39, '1634'),
	(243, 1, 0, -50940, 1636, 0, 0, 39, '1635'),
	(243, 1, 0, -50940, 1637, 0, 0, 39, '1636'),
	(243, 1, 0, -50940, 1638, 0, 0, 39, '1637'),
	(243, 1, 0, -50940, 1639, 0, 0, 39, '1638'),
	(243, 1, 0, -50940, 1640, 0, 0, 39, '1639'),
	(243, 1, 0, -50940, 1641, 0, 0, 39, '1640'),
	(243, 1, 0, -50940, 1642, 0, 0, 39, '1641'),
	(243, 1, 0, -50940, 1643, 0, 0, 39, '1642'),
	(243, 1, 0, -50940, 1644, 0, 0, 39, '1643'),
	(243, 1, 0, -50940, 1645, 0, 0, 39, '1644'),
	(243, 1, 0, -50940, 1646, 0, 0, 39, '1645'),
	(243, 1, 0, -50940, 1647, 0, 0, 39, '1646'),
	(243, 1, 0, -50940, 1648, 0, 0, 39, '1647'),
	(243, 1, 0, -50940, 1649, 0, 0, 39, '1648'),
	(243, 1, 0, -50940, 1650, 0, 0, 39, '1649'),
	(243, 1, 0, -50940, 1651, 0, 0, 39, '1650'),
	(243, 1, 0, -50940, 1652, 0, 0, 39, '1651'),
	(243, 1, 0, -50940, 1653, 0, 0, 39, '1652'),
	(243, 1, 0, -50940, 1654, 0, 0, 39, '1653'),
	(243, 1, 0, -50940, 1655, 0, 0, 39, '1654'),
	(243, 1, 0, -50940, 1656, 0, 0, 39, '1655'),
	(243, 1, 0, -50940, 1657, 0, 0, 39, '1656'),
	(243, 1, 0, -50940, 1658, 0, 0, 39, '1657'),
	(243, 1, 0, -50940, 1659, 0, 0, 39, '1658'),
	(243, 1, 0, -50940, 1660, 0, 0, 39, '1659'),
	(243, 1, 0, -50940, 1661, 0, 0, 39, '1660'),
	(243, 1, 0, -50940, 1662, 0, 0, 39, '1661'),
	(243, 1, 0, -50940, 1663, 0, 0, 39, '1662'),
	(243, 1, 0, -50940, 1664, 0, 0, 39, '1663'),
	(243, 1, 0, -50940, 1665, 0, 0, 39, '1664'),
	(243, 1, 0, -50940, 1666, 0, 0, 39, '1665'),
	(243, 1, 0, -50940, 1667, 0, 0, 39, '1666'),
	(243, 1, 0, -50940, 1668, 0, 0, 39, '1667'),
	(243, 1, 0, -50940, 1669, 0, 0, 39, '1668'),
	(243, 1, 0, -50940, 1670, 0, 0, 39, '1669'),
	(243, 1, 0, -50940, 1671, 0, 0, 39, '1670'),
	(243, 1, 0, -50940, 1672, 0, 0, 39, '1671'),
	(243, 1, 0, -50940, 1673, 0, 0, 39, '1672'),
	(243, 1, 0, -50940, 1674, 0, 0, 39, '1673'),
	(243, 1, 0, -50940, 1675, 0, 0, 39, '1674'),
	(243, 1, 0, -50940, 1676, 0, 0, 39, '1675'),
	(243, 1, 0, -50940, 1677, 0, 0, 39, '1676'),
	(243, 1, 0, -50940, 1678, 0, 0, 39, '1677'),
	(243, 1, 0, -50940, 1679, 0, 0, 39, '1678'),
	(243, 1, 0, -50940, 1680, 0, 0, 39, '1679'),
	(243, 1, 0, -50940, 1681, 0, 0, 39, '1680'),
	(243, 1, 0, -50940, 1682, 0, 0, 39, '1681'),
	(243, 1, 0, -50940, 1683, 0, 0, 39, '1682'),
	(243, 1, 0, -50940, 1684, 0, 0, 39, '1683'),
	(243, 1, 0, -50940, 1685, 0, 0, 39, '1684'),
	(243, 1, 0, -50940, 1686, 0, 0, 39, '1685'),
	(243, 1, 0, -50940, 1687, 0, 0, 39, '1686'),
	(243, 1, 0, -50940, 1688, 0, 0, 39, '1687'),
	(243, 1, 0, -50940, 1689, 0, 0, 39, '1688'),
	(243, 1, 0, -50940, 1690, 0, 0, 39, '1689'),
	(243, 1, 0, -50940, 1691, 0, 0, 39, '1690'),
	(243, 1, 0, -50940, 1692, 0, 0, 39, '1691'),
	(243, 1, 0, -50940, 1693, 0, 0, 39, '1692'),
	(243, 1, 0, -50940, 1694, 0, 0, 39, '1693'),
	(243, 1, 0, -50940, 1695, 0, 0, 39, '1694'),
	(243, 1, 0, -50940, 1696, 0, 0, 39, '1695'),
	(243, 1, 0, -50940, 1697, 0, 0, 39, '1696'),
	(243, 1, 0, -50940, 1698, 0, 0, 39, '1697'),
	(243, 1, 0, -50940, 1699, 0, 0, 39, '1698'),
	(243, 1, 0, -50940, 1700, 0, 0, 39, '1699'),
	(243, 1, 0, -50940, 1701, 0, 0, 39, '1700'),
	(243, 1, 0, -50940, 1702, 0, 0, 39, '1701'),
	(243, 1, 0, -50940, 1703, 0, 0, 39, '1702'),
	(243, 1, 0, -50940, 1704, 0, 0, 39, '1703'),
	(243, 1, 0, -50940, 1705, 0, 0, 39, '1704'),
	(243, 1, 0, -50940, 1706, 0, 0, 39, '1705'),
	(243, 1, 0, -50940, 1707, 0, 0, 39, '1706'),
	(243, 1, 0, -50940, 1708, 0, 0, 39, '1707'),
	(243, 1, 0, -50940, 1709, 0, 0, 39, '1708'),
	(243, 1, 0, -50940, 1710, 0, 0, 39, '1709'),
	(243, 1, 0, -50940, 1711, 0, 0, 39, '1710'),
	(243, 1, 0, -50940, 1712, 0, 0, 39, '1711'),
	(243, 1, 0, -50940, 1713, 0, 0, 39, '1712'),
	(243, 1, 0, -50940, 1714, 0, 0, 39, '1713'),
	(243, 1, 0, -50940, 1715, 0, 0, 39, '1714'),
	(243, 1, 0, -50940, 1716, 0, 0, 39, '1715'),
	(243, 1, 0, -50940, 1717, 0, 0, 39, '1716'),
	(243, 1, 0, -50940, 1718, 0, 0, 39, '1717'),
	(243, 1, 0, -50940, 1719, 0, 0, 39, '1718'),
	(243, 1, 0, -50940, 1720, 0, 0, 39, '1719'),
	(243, 1, 0, -50940, 1721, 0, 0, 39, '1720'),
	(243, 1, 0, -50940, 1722, 0, 0, 39, '1721'),
	(243, 1, 0, -50940, 1723, 0, 0, 39, '1722'),
	(243, 1, 0, -50940, 1724, 0, 0, 39, '1723'),
	(243, 1, 0, -50940, 1725, 0, 0, 39, '1724'),
	(243, 1, 0, -50940, 1726, 0, 0, 39, '1725'),
	(243, 1, 0, -50940, 1727, 0, 0, 39, '1726'),
	(243, 1, 0, -50940, 1728, 0, 0, 39, '1727'),
	(243, 1, 0, -50940, 1729, 0, 0, 39, '1728'),
	(243, 1, 0, -50940, 1730, 0, 0, 39, '1729'),
	(243, 1, 0, -50940, 1731, 0, 0, 39, '1730'),
	(243, 1, 0, -50940, 1732, 0, 0, 39, '1731'),
	(243, 1, 0, -50940, 1733, 0, 0, 39, '1732'),
	(243, 1, 0, -50940, 1734, 0, 0, 39, '1733'),
	(243, 1, 0, -50940, 1735, 0, 0, 39, '1734'),
	(243, 1, 0, -50940, 1736, 0, 0, 39, '1735'),
	(243, 1, 0, -50940, 1737, 0, 0, 39, '1736'),
	(243, 1, 0, -50940, 1738, 0, 0, 39, '1737'),
	(243, 1, 0, -50940, 1739, 0, 0, 39, '1738'),
	(243, 1, 0, -50940, 1740, 0, 0, 39, '1739'),
	(243, 1, 0, -50940, 1741, 0, 0, 39, '1740'),
	(243, 1, 0, -50940, 1742, 0, 0, 39, '1741'),
	(243, 1, 0, -50940, 1743, 0, 0, 39, '1742'),
	(243, 1, 0, -50940, 1744, 0, 0, 39, '1743'),
	(243, 1, 0, -50940, 1745, 0, 0, 39, '1744'),
	(243, 1, 0, -50940, 1746, 0, 0, 39, '1745'),
	(243, 1, 0, -50940, 1747, 0, 0, 39, '1746'),
	(243, 1, 0, -50940, 1748, 0, 0, 39, '1747'),
	(243, 1, 0, -50940, 1749, 0, 0, 39, '1748'),
	(243, 1, 0, -50940, 1750, 0, 0, 39, '1749'),
	(243, 1, 0, -50940, 1751, 0, 0, 39, '1750'),
	(243, 1, 0, -50940, 1752, 0, 0, 39, '1751'),
	(243, 1, 0, -50940, 1753, 0, 0, 39, '1752'),
	(243, 1, 0, -50940, 1754, 0, 0, 39, '1753'),
	(243, 1, 0, -50940, 1755, 0, 0, 39, '1754'),
	(243, 1, 0, -50940, 1756, 0, 0, 39, '1755'),
	(243, 1, 0, -50940, 1757, 0, 0, 39, '1756'),
	(243, 1, 0, -50940, 1758, 0, 0, 39, '1757'),
	(243, 1, 0, -50940, 1759, 0, 0, 39, '1758'),
	(243, 1, 0, -50940, 1760, 0, 0, 39, '1759'),
	(243, 1, 0, -50940, 1761, 0, 0, 39, '1760'),
	(243, 1, 0, -50940, 1762, 0, 0, 39, '1761'),
	(243, 1, 0, -50940, 1763, 0, 0, 39, '1762'),
	(243, 1, 0, -50940, 1764, 0, 0, 39, '1763'),
	(243, 1, 0, -50940, 1765, 0, 0, 39, '1764'),
	(243, 1, 0, -50940, 1766, 0, 0, 39, '1765'),
	(243, 1, 0, -50940, 1767, 0, 0, 39, '1766'),
	(243, 1, 0, -50940, 1768, 0, 0, 39, '1767'),
	(243, 1, 0, -50940, 1769, 0, 0, 39, '1768'),
	(243, 1, 0, -50940, 1770, 0, 0, 39, '1769'),
	(243, 1, 0, -50940, 1771, 0, 0, 39, '1770'),
	(243, 1, 0, -50940, 1772, 0, 0, 39, '1771'),
	(243, 1, 0, -50940, 1773, 0, 0, 39, '1772'),
	(243, 1, 0, -50940, 1774, 0, 0, 39, '1773'),
	(243, 1, 0, -50940, 1775, 0, 0, 39, '1774'),
	(243, 1, 0, -50940, 1776, 0, 0, 39, '1775'),
	(243, 1, 0, -50940, 1777, 0, 0, 39, '1776'),
	(243, 1, 0, -50940, 1778, 0, 0, 39, '1777'),
	(243, 1, 0, -50940, 1779, 0, 0, 39, '1778'),
	(243, 1, 0, -50940, 1780, 0, 0, 39, '1779'),
	(243, 1, 0, -50940, 1781, 0, 0, 39, '1780'),
	(243, 1, 0, -50940, 1782, 0, 0, 39, '1781'),
	(243, 1, 0, -50940, 1783, 0, 0, 39, '1782'),
	(243, 1, 0, -50940, 1784, 0, 0, 39, '1783'),
	(243, 1, 0, -50940, 1785, 0, 0, 39, '1784'),
	(243, 1, 0, -50940, 1786, 0, 0, 39, '1785'),
	(243, 1, 0, -50940, 1787, 0, 0, 39, '1786'),
	(243, 1, 0, -50940, 1788, 0, 0, 39, '1787'),
	(243, 1, 0, -50940, 1789, 0, 0, 39, '1788'),
	(243, 1, 0, -50940, 1790, 0, 0, 39, '1789'),
	(243, 1, 0, -50940, 1791, 0, 0, 39, '1790'),
	(243, 1, 0, -50940, 1792, 0, 0, 39, '1791'),
	(243, 1, 0, -50940, 1793, 0, 0, 39, '1792'),
	(243, 1, 0, -50940, 1794, 0, 0, 39, '1793'),
	(243, 1, 0, -50940, 1795, 0, 0, 39, '1794'),
	(243, 1, 0, -50940, 1796, 0, 0, 39, '1795'),
	(243, 1, 0, -50940, 1797, 0, 0, 39, '1796'),
	(243, 1, 0, -50940, 1798, 0, 0, 39, '1797'),
	(243, 1, 0, -50940, 1799, 0, 0, 39, '1798'),
	(243, 1, 0, -50940, 1800, 0, 0, 39, '1799'),
	(243, 1, 0, -50940, 1801, 0, 0, 39, '1800'),
	(243, 1, 0, -50940, 1802, 0, 0, 39, '1801'),
	(243, 1, 0, -50940, 1803, 0, 0, 39, '1802'),
	(243, 1, 0, -50940, 1804, 0, 0, 39, '1803'),
	(243, 1, 0, -50940, 1805, 0, 0, 39, '1804'),
	(243, 1, 0, -50940, 1806, 0, 0, 39, '1805'),
	(243, 1, 0, -50940, 1807, 0, 0, 39, '1806'),
	(243, 1, 0, -50940, 1808, 0, 0, 39, '1807'),
	(243, 1, 0, -50940, 1809, 0, 0, 39, '1808'),
	(243, 1, 0, -50940, 1810, 0, 0, 39, '1809'),
	(243, 1, 0, -50940, 1811, 0, 0, 39, '1810'),
	(243, 1, 0, -50940, 1812, 0, 0, 39, '1811'),
	(243, 1, 0, -50940, 1813, 0, 0, 39, '1812'),
	(243, 1, 0, -50940, 1814, 0, 0, 39, '1813'),
	(243, 1, 0, -50940, 1815, 0, 0, 39, '1814'),
	(243, 1, 0, -50940, 1816, 0, 0, 39, '1815'),
	(243, 1, 0, -50940, 1817, 0, 0, 39, '1816'),
	(243, 1, 0, -50940, 1818, 0, 0, 39, '1817'),
	(243, 1, 0, -50940, 1819, 0, 0, 39, '1818'),
	(243, 1, 0, -50940, 1820, 0, 0, 39, '1819'),
	(243, 1, 0, -50940, 1821, 0, 0, 39, '1820'),
	(243, 1, 0, -50940, 1822, 0, 0, 39, '1821'),
	(243, 1, 0, -50940, 1823, 0, 0, 39, '1822'),
	(243, 1, 0, -50940, 1824, 0, 0, 39, '1823'),
	(243, 1, 0, -50940, 1825, 0, 0, 39, '1824'),
	(243, 1, 0, -50940, 1826, 0, 0, 39, '1825'),
	(243, 1, 0, -50940, 1827, 0, 0, 39, '1826'),
	(243, 1, 0, -50940, 1828, 0, 0, 39, '1827'),
	(243, 1, 0, -50940, 1829, 0, 0, 39, '1828'),
	(243, 1, 0, -50940, 1830, 0, 0, 39, '1829'),
	(243, 1, 0, -50940, 1831, 0, 0, 39, '1830'),
	(243, 1, 0, -50940, 1832, 0, 0, 39, '1831'),
	(243, 1, 0, -50940, 1833, 0, 0, 39, '1832'),
	(243, 1, 0, -50940, 1834, 0, 0, 39, '1833'),
	(243, 1, 0, -50940, 1835, 0, 0, 39, '1834'),
	(243, 1, 0, -50940, 1836, 0, 0, 39, '1835'),
	(243, 1, 0, -50940, 1837, 0, 0, 39, '1836'),
	(243, 1, 0, -50940, 1838, 0, 0, 39, '1837'),
	(243, 1, 0, -50940, 1839, 0, 0, 39, '1838'),
	(243, 1, 0, -50940, 1840, 0, 0, 39, '1839'),
	(243, 1, 0, -50940, 1841, 0, 0, 39, '1840'),
	(243, 1, 0, -50940, 1842, 0, 0, 39, '1841'),
	(243, 1, 0, -50940, 1843, 0, 0, 39, '1842'),
	(243, 1, 0, -50940, 1844, 0, 0, 39, '1843'),
	(243, 1, 0, -50940, 1845, 0, 0, 39, '1844'),
	(243, 1, 0, -50940, 1846, 0, 0, 39, '1845'),
	(243, 1, 0, -50940, 1847, 0, 0, 39, '1846'),
	(243, 1, 0, -50940, 1848, 0, 0, 39, '1847'),
	(243, 1, 0, -50940, 1849, 0, 0, 39, '1848'),
	(243, 1, 0, -50940, 1850, 0, 0, 39, '1849'),
	(243, 1, 0, -50940, 1851, 0, 0, 39, '1850'),
	(243, 1, 0, -50940, 1852, 0, 0, 39, '1851'),
	(243, 1, 0, -50940, 1853, 0, 0, 39, '1852'),
	(243, 1, 0, -50940, 1854, 0, 0, 39, '1853'),
	(243, 1, 0, -50940, 1855, 0, 0, 39, '1854'),
	(243, 1, 0, -50940, 1856, 0, 0, 39, '1855'),
	(243, 1, 0, -50940, 1857, 0, 0, 39, '1856'),
	(243, 1, 0, -50940, 1858, 0, 0, 39, '1857'),
	(243, 1, 0, -50940, 1859, 0, 0, 39, '1858'),
	(243, 1, 0, -50940, 1860, 0, 0, 39, '1859'),
	(243, 1, 0, -50940, 1861, 0, 0, 39, '1860'),
	(243, 1, 0, -50940, 1862, 0, 0, 39, '1861'),
	(243, 1, 0, -50940, 1863, 0, 0, 39, '1862'),
	(243, 1, 0, -50940, 1864, 0, 0, 39, '1863'),
	(243, 1, 0, -50940, 1865, 0, 0, 39, '1864'),
	(243, 1, 0, -50940, 1866, 0, 0, 39, '1865'),
	(243, 1, 0, -50940, 1867, 0, 0, 39, '1866'),
	(243, 1, 0, -50940, 1868, 0, 0, 39, '1867'),
	(243, 1, 0, -50940, 1869, 0, 0, 39, '1868'),
	(243, 1, 0, -50940, 1870, 0, 0, 39, '1869'),
	(243, 1, 0, -50940, 1871, 0, 0, 39, '1870'),
	(243, 1, 0, -50940, 1872, 0, 0, 39, '1871'),
	(243, 1, 0, -50940, 1873, 0, 0, 39, '1872'),
	(243, 1, 0, -50940, 1874, 0, 0, 39, '1873'),
	(243, 1, 0, -50940, 1875, 0, 0, 39, '1874'),
	(243, 1, 0, -50940, 1876, 0, 0, 39, '1875'),
	(243, 1, 0, -50940, 1877, 0, 0, 39, '1876'),
	(243, 1, 0, -50940, 1878, 0, 0, 39, '1877'),
	(243, 1, 0, -50940, 1879, 0, 0, 39, '1878'),
	(243, 1, 0, -50940, 1880, 0, 0, 39, '1879'),
	(243, 1, 0, -50940, 1881, 0, 0, 39, '1880'),
	(243, 1, 0, -50940, 1882, 0, 0, 39, '1881'),
	(243, 1, 0, -50940, 1883, 0, 0, 39, '1882'),
	(243, 1, 0, -50940, 1884, 0, 0, 39, '1883'),
	(243, 1, 0, -50940, 1885, 0, 0, 39, '1884'),
	(243, 1, 0, -50940, 1886, 0, 0, 39, '1885'),
	(243, 1, 0, -50940, 1887, 0, 0, 39, '1886'),
	(243, 1, 0, -50940, 1888, 0, 0, 39, '1887'),
	(243, 1, 0, -50940, 1889, 0, 0, 39, '1888'),
	(243, 1, 0, -50940, 1890, 0, 0, 39, '1889'),
	(243, 1, 0, -50940, 1891, 0, 0, 39, '1890'),
	(243, 1, 0, -50940, 1892, 0, 0, 39, '1891'),
	(243, 1, 0, -50940, 1893, 0, 0, 39, '1892'),
	(243, 1, 0, -50940, 1894, 0, 0, 39, '1893'),
	(243, 1, 0, -50940, 1895, 0, 0, 39, '1894'),
	(243, 1, 0, -50940, 1896, 0, 0, 39, '1895'),
	(243, 1, 0, -50940, 1897, 0, 0, 39, '1896'),
	(243, 1, 0, -50940, 1898, 0, 0, 39, '1897'),
	(243, 1, 0, -50940, 1899, 0, 0, 39, '1898'),
	(243, 1, 0, -50940, 1900, 0, 0, 39, '1899'),
	(243, 1, 0, -50940, 1901, 0, 0, 39, '1900'),
	(243, 1, 0, -50940, 1902, 0, 0, 39, '1901'),
	(243, 1, 0, -50940, 1903, 0, 0, 39, '1902'),
	(243, 1, 0, -50940, 1904, 0, 0, 39, '1903'),
	(243, 1, 0, -50940, 1905, 0, 0, 39, '1904'),
	(243, 1, 0, -50940, 1906, 0, 0, 39, '1905'),
	(243, 1, 0, -50940, 1907, 0, 0, 39, '1906'),
	(243, 1, 0, -50940, 1908, 0, 0, 39, '1907'),
	(243, 1, 0, -50940, 1909, 0, 0, 39, '1908'),
	(243, 1, 0, -50940, 1910, 0, 0, 39, '1909'),
	(243, 1, 0, -50940, 1911, 0, 0, 39, '1910'),
	(243, 1, 0, -50940, 1912, 0, 0, 39, '1911'),
	(243, 1, 0, -50940, 1913, 0, 0, 39, '1912'),
	(243, 1, 0, -50940, 1914, 0, 0, 39, '1913'),
	(243, 1, 0, -50940, 1915, 0, 0, 39, '1914'),
	(243, 1, 0, -50940, 1916, 0, 0, 39, '1915'),
	(243, 1, 0, -50940, 1917, 0, 0, 39, '1916'),
	(243, 1, 0, -50940, 1918, 0, 0, 39, '1917'),
	(243, 1, 0, -50940, 1919, 0, 0, 39, '1918'),
	(243, 1, 0, -50940, 1920, 0, 0, 39, '1919'),
	(243, 1, 0, -50940, 1921, 0, 0, 39, '1920'),
	(243, 1, 0, -50940, 1922, 0, 0, 39, '1921'),
	(243, 1, 0, -50940, 1923, 0, 0, 39, '1922'),
	(243, 1, 0, -50940, 1924, 0, 0, 39, '1923'),
	(243, 1, 0, -50940, 1925, 0, 0, 39, '1924'),
	(243, 1, 0, -50940, 1926, 0, 0, 39, '1925'),
	(243, 1, 0, -50940, 1927, 0, 0, 39, '1926'),
	(243, 1, 0, -50940, 1928, 0, 0, 39, '1927'),
	(243, 1, 0, -50940, 1929, 0, 0, 39, '1928'),
	(243, 1, 0, -50940, 1930, 0, 0, 39, '1929'),
	(243, 1, 0, -50940, 1931, 0, 0, 39, '1930'),
	(243, 1, 0, -50940, 1932, 0, 0, 39, '1931'),
	(243, 1, 0, -50940, 1933, 0, 0, 39, '1932'),
	(243, 1, 0, -50940, 1934, 0, 0, 39, '1933'),
	(243, 1, 0, -50940, 1935, 0, 0, 39, '1934'),
	(243, 1, 0, -50940, 1936, 0, 0, 39, '1935'),
	(243, 1, 0, -50940, 1937, 0, 0, 39, '1936'),
	(243, 1, 0, -50940, 1938, 0, 0, 39, '1937'),
	(243, 1, 0, -50940, 1939, 0, 0, 39, '1938'),
	(243, 1, 0, -50940, 1940, 0, 0, 39, '1939'),
	(243, 1, 0, -50940, 1941, 0, 0, 39, '1940'),
	(243, 1, 0, -50940, 1942, 0, 0, 39, '1941'),
	(243, 1, 0, -50940, 1943, 0, 0, 39, '1942'),
	(243, 1, 0, -50940, 1944, 0, 0, 39, '1943'),
	(243, 1, 0, -50940, 1945, 0, 0, 39, '1944'),
	(243, 1, 0, -50940, 1946, 0, 0, 39, '1945'),
	(243, 1, 0, -50940, 1947, 0, 0, 39, '1946'),
	(243, 1, 0, -50940, 1948, 0, 0, 39, '1947'),
	(243, 1, 0, -50940, 1949, 0, 0, 39, '1948'),
	(243, 1, 0, -50940, 1950, 0, 0, 39, '1949'),
	(243, 1, 0, -50940, 1951, 0, 0, 39, '1950'),
	(243, 1, 0, -50940, 1952, 0, 0, 39, '1951'),
	(243, 1, 0, -50940, 1953, 0, 0, 39, '1952'),
	(243, 1, 0, -50940, 1954, 0, 0, 39, '1953'),
	(243, 1, 0, -50940, 1955, 0, 0, 39, '1954'),
	(243, 1, 0, -50940, 1956, 0, 0, 39, '1955'),
	(243, 1, 0, -50940, 1957, 0, 0, 39, '1956'),
	(243, 1, 0, -50940, 1958, 0, 0, 39, '1957'),
	(243, 1, 0, -50940, 1959, 0, 0, 39, '1958'),
	(243, 1, 0, -50940, 1960, 0, 0, 39, '1959'),
	(243, 1, 0, -50940, 1961, 0, 0, 39, '1960'),
	(243, 1, 0, -50940, 1962, 0, 0, 39, '1961'),
	(243, 1, 0, -50940, 1963, 0, 0, 39, '1962'),
	(243, 1, 0, -50940, 1964, 0, 0, 39, '1963'),
	(243, 1, 0, -50940, 1965, 0, 0, 39, '1964'),
	(243, 1, 0, -50940, 1966, 0, 0, 39, '1965'),
	(243, 1, 0, -50940, 1967, 0, 0, 39, '1966'),
	(243, 1, 0, -50940, 1968, 0, 0, 39, '1967'),
	(243, 1, 0, -50940, 1969, 0, 0, 39, '1968'),
	(243, 1, 0, -50940, 1970, 0, 0, 39, '1969'),
	(243, 1, 0, -50940, 1971, 0, 0, 39, '1970'),
	(243, 1, 0, -50940, 1972, 0, 0, 39, '1971'),
	(243, 1, 0, -50940, 1973, 0, 0, 39, '1972'),
	(243, 1, 0, -50940, 1974, 0, 0, 39, '1973'),
	(243, 1, 0, -50940, 1975, 0, 0, 39, '1974'),
	(243, 1, 0, -50940, 1976, 0, 0, 39, '1975'),
	(243, 1, 0, -50940, 1977, 0, 0, 39, '1976'),
	(243, 1, 0, -50940, 1978, 0, 0, 39, '1977'),
	(243, 1, 0, -50940, 1979, 0, 0, 39, '1978'),
	(243, 1, 0, -50940, 1980, 0, 0, 39, '1979'),
	(243, 1, 0, -50940, 1981, 0, 0, 39, '1980'),
	(243, 1, 0, -50940, 1982, 0, 0, 39, '1981'),
	(243, 1, 0, -50940, 1983, 0, 0, 39, '1982'),
	(243, 1, 0, -50940, 1984, 0, 0, 39, '1983'),
	(243, 1, 0, -50940, 1985, 0, 0, 39, '1984'),
	(243, 1, 0, -50940, 1986, 0, 0, 39, '1985'),
	(243, 1, 0, -50940, 1987, 0, 0, 39, '1986'),
	(243, 1, 0, -50940, 1988, 0, 0, 39, '1987'),
	(243, 1, 0, -50940, 1989, 0, 0, 39, '1988'),
	(243, 1, 0, -50940, 1990, 0, 0, 39, '1989'),
	(243, 1, 0, -50940, 1991, 0, 0, 39, '1990'),
	(243, 1, 0, -50940, 1992, 0, 0, 39, '1991'),
	(243, 1, 0, -50940, 1993, 0, 0, 39, '1992'),
	(243, 1, 0, -50940, 1994, 0, 0, 39, '1993'),
	(243, 1, 0, -50940, 1995, 0, 0, 39, '1994'),
	(243, 1, 0, -50940, 1996, 0, 0, 39, '1995'),
	(243, 1, 0, -50940, 1997, 0, 0, 39, '1996'),
	(243, 1, 0, -50940, 1998, 0, 0, 39, '1997'),
	(243, 1, 0, -50940, 1999, 0, 0, 39, '1998'),
	(243, 1, 0, -50940, 2000, 0, 0, 39, '1999'),
	(243, 1, 0, -50940, 2001, 0, 0, 39, '2000'),
	(243, 1, 0, -50940, 2002, 0, 0, 39, '2001'),
	(243, 1, 0, -50940, 2003, 0, 0, 39, '2002'),
	(243, 1, 0, -50940, 2004, 0, 0, 39, '2003'),
	(243, 1, 0, -50940, 2005, 0, 0, 39, '2004'),
	(243, 1, 0, -50940, 2006, 0, 0, 39, '2005'),
	(243, 1, 0, -50940, 2007, 0, 0, 39, '2006'),
	(243, 1, 0, -50940, 2008, 0, 0, 39, '2007'),
	(243, 1, 0, -50940, 2009, 0, 0, 39, '2008'),
	(243, 1, 0, -50940, 2010, 0, 0, 39, '2009'),
	(243, 1, 0, -50940, 2011, 0, 0, 39, '2010'),
	(243, 1, 0, -50940, 2012, 0, 0, 39, '2011'),
	(243, 1, 0, -50940, 2013, 0, 0, 39, '2012'),
	(243, 1, 0, -50940, 2014, 0, 0, 39, '2013'),
	(243, 1, 0, -50940, 2015, 0, 0, 39, '2014'),
	(243, 1, 0, -50940, 2016, 0, 0, 39, '2015'),
	(243, 1, 0, -50940, 2017, 0, 0, 39, '2016'),
	(243, 1, 0, -50940, 2018, 0, 0, 39, '2017'),
	(243, 1, 0, -50940, 2019, 0, 0, 39, '2018'),
	(243, 1, 0, -50940, 2020, 0, 0, 39, '2019'),
	(243, 1, 0, -50940, 2021, 0, 0, 39, '2020'),
	(243, 1, 0, -50940, 2022, 0, 0, 39, '2021'),
	(243, 1, 0, -50940, 2023, 0, 0, 39, '2022'),
	(243, 1, 0, -50940, 2024, 0, 0, 39, '2023'),
	(243, 1, 0, -50940, 2025, 0, 0, 39, '2024'),
	(243, 1, 0, -50940, 2026, 0, 0, 39, '2025'),
	(243, 1, 0, -50940, 2027, 0, 0, 39, '2026'),
	(243, 1, 0, -50940, 2028, 0, 0, 39, '2027'),
	(243, 1, 0, -50940, 2029, 0, 0, 39, '2028'),
	(243, 1, 0, -50940, 2030, 0, 0, 39, '2029'),
	(243, 1, 0, -50940, 2031, 0, 0, 39, '2030'),
	(243, 1, 0, -50940, 2032, 0, 0, 39, '2031'),
	(243, 1, 0, -50940, 2033, 0, 0, 39, '2032'),
	(243, 1, 0, -50940, 2034, 0, 0, 39, '2033'),
	(243, 1, 0, -50940, 2035, 0, 0, 39, '2034'),
	(243, 1, 0, -50940, 2036, 0, 0, 39, '2035'),
	(243, 1, 0, -50940, 2037, 0, 0, 39, '2036'),
	(243, 1, 0, -50940, 2038, 0, 0, 39, '2037'),
	(243, 1, 0, -50940, 2039, 0, 0, 39, '2038'),
	(243, 1, 0, -50940, 2040, 0, 0, 39, '2039'),
	(243, 1, 0, -50940, 2041, 0, 0, 39, '2040'),
	(243, 1, 0, -50940, 2042, 0, 0, 39, '2041'),
	(243, 1, 0, -50940, 2043, 0, 0, 39, '2042'),
	(243, 1, 0, -50940, 2044, 0, 0, 39, '2043'),
	(243, 1, 0, -50940, 2045, 0, 0, 39, '2044'),
	(243, 1, 0, -50940, 2046, 0, 0, 39, '2045'),
	(243, 1, 0, -50940, 2047, 0, 0, 39, '2046'),
	(243, 1, 0, -50940, 2048, 0, 0, 39, '2047'),
	(243, 1, 0, -50939, 1, 0, 0, 39, '0'),
	(243, 1, 0, -50939, 2, 0, 0, 39, '1'),
	(243, 1, 0, -50939, 3, 0, 0, 39, '2'),
	(243, 1, 0, -50939, 4, 0, 0, 39, '3'),
	(243, 1, 0, -50939, 5, 0, 0, 39, '4'),
	(243, 1, 0, -50939, 6, 0, 0, 39, '5'),
	(243, 1, 0, -50939, 7, 0, 0, 39, '6'),
	(243, 1, 0, -50939, 8, 0, 0, 39, '7'),
	(243, 1, 0, -50939, 9, 0, 0, 39, '8'),
	(243, 1, 0, -50939, 10, 0, 0, 39, '9'),
	(243, 1, 0, -50939, 11, 0, 0, 39, '10'),
	(243, 1, 0, -50939, 12, 0, 0, 39, '11'),
	(243, 1, 0, -50939, 13, 0, 0, 39, '12'),
	(243, 1, 0, -50939, 14, 0, 0, 39, '13'),
	(243, 1, 0, -50939, 15, 0, 0, 39, '14'),
	(243, 1, 0, -50939, 16, 0, 0, 39, '15'),
	(243, 1, 0, -50939, 17, 0, 0, 39, '16'),
	(243, 1, 0, -50939, 18, 0, 0, 39, '17'),
	(243, 1, 0, -50939, 19, 0, 0, 39, '18'),
	(243, 1, 0, -50939, 20, 0, 0, 39, '19'),
	(243, 1, 0, -50939, 21, 0, 0, 39, '20'),
	(243, 1, 0, -50939, 22, 0, 0, 39, '21'),
	(243, 1, 0, -50939, 23, 0, 0, 39, '22'),
	(243, 1, 0, -50939, 24, 0, 0, 39, '23'),
	(243, 1, 0, -50939, 25, 0, 0, 39, '24'),
	(243, 1, 0, -50939, 26, 0, 0, 39, '25'),
	(243, 1, 0, -50939, 27, 0, 0, 39, '26'),
	(243, 1, 0, -50939, 28, 0, 0, 39, '27'),
	(243, 1, 0, -50939, 29, 0, 0, 39, '28'),
	(243, 1, 0, -50939, 30, 0, 0, 39, '29'),
	(243, 1, 0, -50939, 31, 0, 0, 39, '30'),
	(243, 1, 0, -50939, 32, 0, 0, 39, '31'),
	(243, 1, 0, -50939, 33, 0, 0, 39, '32'),
	(243, 1, 0, -50939, 34, 0, 0, 39, '33'),
	(243, 1, 0, -50939, 35, 0, 0, 39, '34'),
	(243, 1, 0, -50939, 36, 0, 0, 39, '35'),
	(243, 1, 0, -50939, 37, 0, 0, 39, '36'),
	(243, 1, 0, -50939, 38, 0, 0, 39, '37'),
	(243, 1, 0, -50939, 39, 0, 0, 39, '38'),
	(243, 1, 0, -50939, 40, 0, 0, 39, '39'),
	(243, 1, 0, -50939, 41, 0, 0, 39, '40'),
	(243, 1, 0, -50939, 42, 0, 0, 39, '41'),
	(243, 1, 0, -50939, 43, 0, 0, 39, '42'),
	(243, 1, 0, -50939, 44, 0, 0, 39, '43'),
	(243, 1, 0, -50939, 45, 0, 0, 39, '44'),
	(243, 1, 0, -50939, 46, 0, 0, 39, '45'),
	(243, 1, 0, -50939, 47, 0, 0, 39, '46'),
	(243, 1, 0, -50939, 48, 0, 0, 39, '47'),
	(243, 1, 0, -50939, 49, 0, 0, 39, '48'),
	(243, 1, 0, -50939, 50, 0, 0, 39, '49'),
	(243, 1, 0, -50939, 51, 0, 0, 39, '50'),
	(243, 1, 0, -50939, 52, 0, 0, 39, '51'),
	(243, 1, 0, -50939, 53, 0, 0, 39, '52'),
	(243, 1, 0, -50939, 54, 0, 0, 39, '53'),
	(243, 1, 0, -50939, 55, 0, 0, 39, '54'),
	(243, 1, 0, -50939, 56, 0, 0, 39, '55'),
	(243, 1, 0, -50939, 57, 0, 0, 39, '56'),
	(243, 1, 0, -50939, 58, 0, 0, 39, '57'),
	(243, 1, 0, -50939, 59, 0, 0, 39, '58'),
	(243, 1, 0, -50939, 60, 0, 0, 39, '59'),
	(243, 1, 0, -50939, 61, 0, 0, 39, '60'),
	(243, 1, 0, -50939, 62, 0, 0, 39, '61'),
	(243, 1, 0, -50939, 63, 0, 0, 39, '62'),
	(243, 1, 0, -50939, 64, 0, 0, 39, '63'),
	(243, 1, 0, -50939, 65, 0, 0, 39, '64'),
	(243, 1, 0, -50939, 66, 0, 0, 39, '65'),
	(243, 1, 0, -50939, 67, 0, 0, 39, '66'),
	(243, 1, 0, -50939, 68, 0, 0, 39, '67'),
	(243, 1, 0, -50939, 69, 0, 0, 39, '68'),
	(243, 1, 0, -50939, 70, 0, 0, 39, '69'),
	(243, 1, 0, -50939, 71, 0, 0, 39, '70'),
	(243, 1, 0, -50939, 72, 0, 0, 39, '71'),
	(243, 1, 0, -50939, 73, 0, 0, 39, '72'),
	(243, 1, 0, -50939, 74, 0, 0, 39, '73'),
	(243, 1, 0, -50939, 75, 0, 0, 39, '74'),
	(243, 1, 0, -50939, 76, 0, 0, 39, '75'),
	(243, 1, 0, -50939, 77, 0, 0, 39, '76'),
	(243, 1, 0, -50939, 78, 0, 0, 39, '77'),
	(243, 1, 0, -50939, 79, 0, 0, 39, '78'),
	(243, 1, 0, -50939, 80, 0, 0, 39, '79'),
	(243, 1, 0, -50939, 81, 0, 0, 39, '80'),
	(243, 1, 0, -50939, 82, 0, 0, 39, '81'),
	(243, 1, 0, -50939, 83, 0, 0, 39, '82'),
	(243, 1, 0, -50939, 84, 0, 0, 39, '83'),
	(243, 1, 0, -50939, 85, 0, 0, 39, '84'),
	(243, 1, 0, -50939, 86, 0, 0, 39, '85'),
	(243, 1, 0, -50939, 87, 0, 0, 39, '86'),
	(243, 1, 0, -50939, 88, 0, 0, 39, '87'),
	(243, 1, 0, -50939, 89, 0, 0, 39, '88'),
	(243, 1, 0, -50939, 90, 0, 0, 39, '89'),
	(243, 1, 0, -50939, 91, 0, 0, 39, '90'),
	(243, 1, 0, -50939, 92, 0, 0, 39, '91'),
	(243, 1, 0, -50939, 93, 0, 0, 39, '92'),
	(243, 1, 0, -50939, 94, 0, 0, 39, '93'),
	(243, 1, 0, -50939, 95, 0, 0, 39, '94'),
	(243, 1, 0, -50939, 96, 0, 0, 39, '95'),
	(243, 1, 0, -50939, 97, 0, 0, 39, '96'),
	(243, 1, 0, -50939, 98, 0, 0, 39, '97'),
	(243, 1, 0, -50939, 99, 0, 0, 39, '98'),
	(243, 1, 0, -50939, 100, 0, 0, 39, '99'),
	(243, 1, 0, -50939, 101, 0, 0, 39, '100'),
	(243, 1, 0, -50939, 102, 0, 0, 39, '101'),
	(243, 1, 0, -50939, 103, 0, 0, 39, '102'),
	(243, 1, 0, -50939, 104, 0, 0, 39, '103'),
	(243, 1, 0, -50939, 105, 0, 0, 39, '104'),
	(243, 1, 0, -50939, 106, 0, 0, 39, '105'),
	(243, 1, 0, -50939, 107, 0, 0, 39, '106'),
	(243, 1, 0, -50939, 108, 0, 0, 39, '107'),
	(243, 1, 0, -50939, 109, 0, 0, 39, '108'),
	(243, 1, 0, -50939, 110, 0, 0, 39, '109'),
	(243, 1, 0, -50939, 111, 0, 0, 39, '110'),
	(243, 1, 0, -50939, 112, 0, 0, 39, '111'),
	(243, 1, 0, -50939, 113, 0, 0, 39, '112'),
	(243, 1, 0, -50939, 114, 0, 0, 39, '113'),
	(243, 1, 0, -50939, 115, 0, 0, 39, '114'),
	(243, 1, 0, -50939, 116, 0, 0, 39, '115'),
	(243, 1, 0, -50939, 117, 0, 0, 39, '116'),
	(243, 1, 0, -50939, 118, 0, 0, 39, '117'),
	(243, 1, 0, -50939, 119, 0, 0, 39, '118'),
	(243, 1, 0, -50939, 120, 0, 0, 39, '119'),
	(243, 1, 0, -50939, 121, 0, 0, 39, '120'),
	(243, 1, 0, -50939, 122, 0, 0, 39, '121'),
	(243, 1, 0, -50939, 123, 0, 0, 39, '122'),
	(243, 1, 0, -50939, 124, 0, 0, 39, '123'),
	(243, 1, 0, -50939, 125, 0, 0, 39, '124'),
	(243, 1, 0, -50939, 126, 0, 0, 39, '125'),
	(243, 1, 0, -50939, 127, 0, 0, 39, '126'),
	(243, 1, 0, -50939, 128, 0, 0, 39, '127'),
	(243, 1, 0, -50939, 129, 0, 0, 39, '128'),
	(243, 1, 0, -50939, 130, 0, 0, 39, '129'),
	(243, 1, 0, -50939, 131, 0, 0, 39, '130'),
	(243, 1, 0, -50939, 132, 0, 0, 39, '131'),
	(243, 1, 0, -50939, 133, 0, 0, 39, '132'),
	(243, 1, 0, -50939, 134, 0, 0, 39, '133'),
	(243, 1, 0, -50939, 135, 0, 0, 39, '134'),
	(243, 1, 0, -50939, 136, 0, 0, 39, '135'),
	(243, 1, 0, -50939, 137, 0, 0, 39, '136'),
	(243, 1, 0, -50939, 138, 0, 0, 39, '137'),
	(243, 1, 0, -50939, 139, 0, 0, 39, '138'),
	(243, 1, 0, -50939, 140, 0, 0, 39, '139'),
	(243, 1, 0, -50939, 141, 0, 0, 39, '140'),
	(243, 1, 0, -50939, 142, 0, 0, 39, '141'),
	(243, 1, 0, -50939, 143, 0, 0, 39, '142'),
	(243, 1, 0, -50939, 144, 0, 0, 39, '143'),
	(243, 1, 0, -50939, 145, 0, 0, 39, '144'),
	(243, 1, 0, -50939, 146, 0, 0, 39, '145'),
	(243, 1, 0, -50939, 147, 0, 0, 39, '146'),
	(243, 1, 0, -50939, 148, 0, 0, 39, '147'),
	(243, 1, 0, -50939, 149, 0, 0, 39, '148'),
	(243, 1, 0, -50939, 150, 0, 0, 39, '149'),
	(243, 1, 0, -50939, 151, 0, 0, 39, '150'),
	(243, 1, 0, -50939, 152, 0, 0, 39, '151'),
	(243, 1, 0, -50939, 153, 0, 0, 39, '152'),
	(243, 1, 0, -50939, 154, 0, 0, 39, '153'),
	(243, 1, 0, -50939, 155, 0, 0, 39, '154'),
	(243, 1, 0, -50939, 156, 0, 0, 39, '155'),
	(243, 1, 0, -50939, 157, 0, 0, 39, '156'),
	(243, 1, 0, -50939, 158, 0, 0, 39, '157'),
	(243, 1, 0, -50939, 159, 0, 0, 39, '158'),
	(243, 1, 0, -50939, 160, 0, 0, 39, '159'),
	(243, 1, 0, -50939, 161, 0, 0, 39, '160'),
	(243, 1, 0, -50939, 162, 0, 0, 39, '161'),
	(243, 1, 0, -50939, 163, 0, 0, 39, '162'),
	(243, 1, 0, -50939, 164, 0, 0, 39, '163'),
	(243, 1, 0, -50939, 165, 0, 0, 39, '164'),
	(243, 1, 0, -50939, 166, 0, 0, 39, '165'),
	(243, 1, 0, -50939, 167, 0, 0, 39, '166'),
	(243, 1, 0, -50939, 168, 0, 0, 39, '167'),
	(243, 1, 0, -50939, 169, 0, 0, 39, '168'),
	(243, 1, 0, -50939, 170, 0, 0, 39, '169'),
	(243, 1, 0, -50939, 171, 0, 0, 39, '170'),
	(243, 1, 0, -50939, 172, 0, 0, 39, '171'),
	(243, 1, 0, -50939, 173, 0, 0, 39, '172'),
	(243, 1, 0, -50939, 174, 0, 0, 39, '173'),
	(243, 1, 0, -50939, 175, 0, 0, 39, '174'),
	(243, 1, 0, -50939, 176, 0, 0, 39, '175'),
	(243, 1, 0, -50939, 177, 0, 0, 39, '176'),
	(243, 1, 0, -50939, 178, 0, 0, 39, '177'),
	(243, 1, 0, -50939, 179, 0, 0, 39, '178'),
	(243, 1, 0, -50939, 180, 0, 0, 39, '179'),
	(243, 1, 0, -50939, 181, 0, 0, 39, '180'),
	(243, 1, 0, -50939, 182, 0, 0, 39, '181'),
	(243, 1, 0, -50939, 183, 0, 0, 39, '182'),
	(243, 1, 0, -50939, 184, 0, 0, 39, '183'),
	(243, 1, 0, -50939, 185, 0, 0, 39, '184'),
	(243, 1, 0, -50939, 186, 0, 0, 39, '185'),
	(243, 1, 0, -50939, 187, 0, 0, 39, '186'),
	(243, 1, 0, -50939, 188, 0, 0, 39, '187'),
	(243, 1, 0, -50939, 189, 0, 0, 39, '188'),
	(243, 1, 0, -50939, 190, 0, 0, 39, '189'),
	(243, 1, 0, -50939, 191, 0, 0, 39, '190'),
	(243, 1, 0, -50939, 192, 0, 0, 39, '191'),
	(243, 1, 0, -50939, 193, 0, 0, 39, '192'),
	(243, 1, 0, -50939, 194, 0, 0, 39, '193'),
	(243, 1, 0, -50939, 195, 0, 0, 39, '194'),
	(243, 1, 0, -50939, 196, 0, 0, 39, '195'),
	(243, 1, 0, -50939, 197, 0, 0, 39, '196'),
	(243, 1, 0, -50939, 198, 0, 0, 39, '197'),
	(243, 1, 0, -50939, 199, 0, 0, 39, '198'),
	(243, 1, 0, -50939, 200, 0, 0, 39, '199'),
	(243, 1, 0, -50939, 201, 0, 0, 39, '200'),
	(243, 1, 0, -50939, 202, 0, 0, 39, '201'),
	(243, 1, 0, -50939, 203, 0, 0, 39, '202'),
	(243, 1, 0, -50939, 204, 0, 0, 39, '203'),
	(243, 1, 0, -50939, 205, 0, 0, 39, '204'),
	(243, 1, 0, -50939, 206, 0, 0, 39, '205'),
	(243, 1, 0, -50939, 207, 0, 0, 39, '206'),
	(243, 1, 0, -50939, 208, 0, 0, 39, '207'),
	(243, 1, 0, -50939, 209, 0, 0, 39, '208'),
	(243, 1, 0, -50939, 210, 0, 0, 39, '209'),
	(243, 1, 0, -50939, 211, 0, 0, 39, '210'),
	(243, 1, 0, -50939, 212, 0, 0, 39, '211'),
	(243, 1, 0, -50939, 213, 0, 0, 39, '212'),
	(243, 1, 0, -50939, 214, 0, 0, 39, '213'),
	(243, 1, 0, -50939, 215, 0, 0, 39, '214'),
	(243, 1, 0, -50939, 216, 0, 0, 39, '215'),
	(243, 1, 0, -50939, 217, 0, 0, 39, '216'),
	(243, 1, 0, -50939, 218, 0, 0, 39, '217'),
	(243, 1, 0, -50939, 219, 0, 0, 39, '218'),
	(243, 1, 0, -50939, 220, 0, 0, 39, '219'),
	(243, 1, 0, -50939, 221, 0, 0, 39, '220'),
	(243, 1, 0, -50939, 222, 0, 0, 39, '221'),
	(243, 1, 0, -50939, 223, 0, 0, 39, '222'),
	(243, 1, 0, -50939, 224, 0, 0, 39, '223'),
	(243, 1, 0, -50939, 225, 0, 0, 39, '224'),
	(243, 1, 0, -50939, 226, 0, 0, 39, '225'),
	(243, 1, 0, -50939, 227, 0, 0, 39, '226'),
	(243, 1, 0, -50939, 228, 0, 0, 39, '227'),
	(243, 1, 0, -50939, 229, 0, 0, 39, '228'),
	(243, 1, 0, -50939, 230, 0, 0, 39, '229'),
	(243, 1, 0, -50939, 231, 0, 0, 39, '230'),
	(243, 1, 0, -50939, 232, 0, 0, 39, '231'),
	(243, 1, 0, -50939, 233, 0, 0, 39, '232'),
	(243, 1, 0, -50939, 234, 0, 0, 39, '233'),
	(243, 1, 0, -50939, 235, 0, 0, 39, '234'),
	(243, 1, 0, -50939, 236, 0, 0, 39, '235'),
	(243, 1, 0, -50939, 237, 0, 0, 39, '236'),
	(243, 1, 0, -50939, 238, 0, 0, 39, '237'),
	(243, 1, 0, -50939, 239, 0, 0, 39, '238'),
	(243, 1, 0, -50939, 240, 0, 0, 39, '239'),
	(243, 1, 0, -50939, 241, 0, 0, 39, '240'),
	(243, 1, 0, -50939, 242, 0, 0, 39, '241'),
	(243, 1, 0, -50939, 243, 0, 0, 39, '242'),
	(243, 1, 0, -50939, 244, 0, 0, 39, '243'),
	(243, 1, 0, -50939, 245, 0, 0, 39, '244'),
	(243, 1, 0, -50939, 246, 0, 0, 39, '245'),
	(243, 1, 0, -50939, 247, 0, 0, 39, '246'),
	(243, 1, 0, -50939, 248, 0, 0, 39, '247'),
	(243, 1, 0, -50939, 249, 0, 0, 39, '248'),
	(243, 1, 0, -50939, 250, 0, 0, 39, '249'),
	(243, 1, 0, -50939, 251, 0, 0, 39, '250'),
	(243, 1, 0, -50939, 252, 0, 0, 39, '251'),
	(243, 1, 0, -50939, 253, 0, 0, 39, '252'),
	(243, 1, 0, -50939, 254, 0, 0, 39, '253'),
	(243, 1, 0, -50939, 255, 0, 0, 39, '254'),
	(243, 1, 0, -50939, 256, 0, 0, 39, '255'),
	(243, 1, 0, -50939, 257, 0, 0, 39, '256'),
	(243, 1, 0, -50939, 258, 0, 0, 39, '257'),
	(243, 1, 0, -50939, 259, 0, 0, 39, '258'),
	(243, 1, 0, -50939, 260, 0, 0, 39, '259'),
	(243, 1, 0, -50939, 261, 0, 0, 39, '260'),
	(243, 1, 0, -50939, 262, 0, 0, 39, '261'),
	(243, 1, 0, -50939, 263, 0, 0, 39, '262'),
	(243, 1, 0, -50939, 264, 0, 0, 39, '263'),
	(243, 1, 0, -50939, 265, 0, 0, 39, '264'),
	(243, 1, 0, -50939, 266, 0, 0, 39, '265'),
	(243, 1, 0, -50939, 267, 0, 0, 39, '266'),
	(243, 1, 0, -50939, 268, 0, 0, 39, '267'),
	(243, 1, 0, -50939, 269, 0, 0, 39, '268'),
	(243, 1, 0, -50939, 270, 0, 0, 39, '269'),
	(243, 1, 0, -50939, 271, 0, 0, 39, '270'),
	(243, 1, 0, -50939, 272, 0, 0, 39, '271'),
	(243, 1, 0, -50939, 273, 0, 0, 39, '272'),
	(243, 1, 0, -50939, 274, 0, 0, 39, '273'),
	(243, 1, 0, -50939, 275, 0, 0, 39, '274'),
	(243, 1, 0, -50939, 276, 0, 0, 39, '275'),
	(243, 1, 0, -50939, 277, 0, 0, 39, '276'),
	(243, 1, 0, -50939, 278, 0, 0, 39, '277'),
	(243, 1, 0, -50939, 279, 0, 0, 39, '278'),
	(243, 1, 0, -50939, 280, 0, 0, 39, '279'),
	(243, 1, 0, -50939, 281, 0, 0, 39, '280'),
	(243, 1, 0, -50939, 282, 0, 0, 39, '281'),
	(243, 1, 0, -50939, 283, 0, 0, 39, '282'),
	(243, 1, 0, -50939, 284, 0, 0, 39, '283'),
	(243, 1, 0, -50939, 285, 0, 0, 39, '284'),
	(243, 1, 0, -50939, 286, 0, 0, 39, '285'),
	(243, 1, 0, -50939, 287, 0, 0, 39, '286'),
	(243, 1, 0, -50939, 288, 0, 0, 39, '287'),
	(243, 1, 0, -50939, 289, 0, 0, 39, '288'),
	(243, 1, 0, -50939, 290, 0, 0, 39, '289'),
	(243, 1, 0, -50939, 291, 0, 0, 39, '290'),
	(243, 1, 0, -50939, 292, 0, 0, 39, '291'),
	(243, 1, 0, -50939, 293, 0, 0, 39, '292'),
	(243, 1, 0, -50939, 294, 0, 0, 39, '293'),
	(243, 1, 0, -50939, 295, 0, 0, 39, '294'),
	(243, 1, 0, -50939, 296, 0, 0, 39, '295'),
	(243, 1, 0, -50939, 297, 0, 0, 39, '296'),
	(243, 1, 0, -50939, 298, 0, 0, 39, '297'),
	(243, 1, 0, -50939, 299, 0, 0, 39, '298'),
	(243, 1, 0, -50939, 300, 0, 0, 39, '299'),
	(243, 1, 0, -50939, 301, 0, 0, 39, '300'),
	(243, 1, 0, -50939, 302, 0, 0, 39, '301'),
	(243, 1, 0, -50939, 303, 0, 0, 39, '302'),
	(243, 1, 0, -50939, 304, 0, 0, 39, '303'),
	(243, 1, 0, -50939, 305, 0, 0, 39, '304'),
	(243, 1, 0, -50939, 306, 0, 0, 39, '305'),
	(243, 1, 0, -50939, 307, 0, 0, 39, '306'),
	(243, 1, 0, -50939, 308, 0, 0, 39, '307'),
	(243, 1, 0, -50939, 309, 0, 0, 39, '308'),
	(243, 1, 0, -50939, 310, 0, 0, 39, '309'),
	(243, 1, 0, -50939, 311, 0, 0, 39, '310'),
	(243, 1, 0, -50939, 312, 0, 0, 39, '311'),
	(243, 1, 0, -50939, 313, 0, 0, 39, '312'),
	(243, 1, 0, -50939, 314, 0, 0, 39, '313'),
	(243, 1, 0, -50939, 315, 0, 0, 39, '314'),
	(243, 1, 0, -50939, 316, 0, 0, 39, '315'),
	(243, 1, 0, -50939, 317, 0, 0, 39, '316'),
	(243, 1, 0, -50939, 318, 0, 0, 39, '317'),
	(243, 1, 0, -50939, 319, 0, 0, 39, '318'),
	(243, 1, 0, -50939, 320, 0, 0, 39, '319'),
	(243, 1, 0, -50939, 321, 0, 0, 39, '320'),
	(243, 1, 0, -50939, 322, 0, 0, 39, '321'),
	(243, 1, 0, -50939, 323, 0, 0, 39, '322'),
	(243, 1, 0, -50939, 324, 0, 0, 39, '323'),
	(243, 1, 0, -50939, 325, 0, 0, 39, '324'),
	(243, 1, 0, -50939, 326, 0, 0, 39, '325'),
	(243, 1, 0, -50939, 327, 0, 0, 39, '326'),
	(243, 1, 0, -50939, 328, 0, 0, 39, '327'),
	(243, 1, 0, -50939, 329, 0, 0, 39, '328'),
	(243, 1, 0, -50939, 330, 0, 0, 39, '329'),
	(243, 1, 0, -50939, 331, 0, 0, 39, '330'),
	(243, 1, 0, -50939, 332, 0, 0, 39, '331'),
	(243, 1, 0, -50939, 333, 0, 0, 39, '332'),
	(243, 1, 0, -50939, 334, 0, 0, 39, '333'),
	(243, 1, 0, -50939, 335, 0, 0, 39, '334'),
	(243, 1, 0, -50939, 336, 0, 0, 39, '335'),
	(243, 1, 0, -50939, 337, 0, 0, 39, '336'),
	(243, 1, 0, -50939, 338, 0, 0, 39, '337'),
	(243, 1, 0, -50939, 339, 0, 0, 39, '338'),
	(243, 1, 0, -50939, 340, 0, 0, 39, '339'),
	(243, 1, 0, -50939, 341, 0, 0, 39, '340'),
	(243, 1, 0, -50939, 342, 0, 0, 39, '341'),
	(243, 1, 0, -50939, 343, 0, 0, 39, '342'),
	(243, 1, 0, -50939, 344, 0, 0, 39, '343'),
	(243, 1, 0, -50939, 345, 0, 0, 39, '344'),
	(243, 1, 0, -50939, 346, 0, 0, 39, '345'),
	(243, 1, 0, -50939, 347, 0, 0, 39, '346'),
	(243, 1, 0, -50939, 348, 0, 0, 39, '347'),
	(243, 1, 0, -50939, 349, 0, 0, 39, '348'),
	(243, 1, 0, -50939, 350, 0, 0, 39, '349'),
	(243, 1, 0, -50939, 351, 0, 0, 39, '350'),
	(243, 1, 0, -50939, 352, 0, 0, 39, '351'),
	(243, 1, 0, -50939, 353, 0, 0, 39, '352'),
	(243, 1, 0, -50939, 354, 0, 0, 39, '353'),
	(243, 1, 0, -50939, 355, 0, 0, 39, '354'),
	(243, 1, 0, -50939, 356, 0, 0, 39, '355'),
	(243, 1, 0, -50939, 357, 0, 0, 39, '356'),
	(243, 1, 0, -50939, 358, 0, 0, 39, '357'),
	(243, 1, 0, -50939, 359, 0, 0, 39, '358'),
	(243, 1, 0, -50939, 360, 0, 0, 39, '359'),
	(243, 1, 0, -50939, 361, 0, 0, 39, '360'),
	(243, 1, 0, -50939, 362, 0, 0, 39, '361'),
	(243, 1, 0, -50939, 363, 0, 0, 39, '362'),
	(243, 1, 0, -50939, 364, 0, 0, 39, '363'),
	(243, 1, 0, -50939, 365, 0, 0, 39, '364'),
	(243, 1, 0, -50939, 366, 0, 0, 39, '365'),
	(243, 1, 0, -50939, 367, 0, 0, 39, '366'),
	(243, 1, 0, -50939, 368, 0, 0, 39, '367'),
	(243, 1, 0, -50939, 369, 0, 0, 39, '368'),
	(243, 1, 0, -50939, 370, 0, 0, 39, '369'),
	(243, 1, 0, -50939, 371, 0, 0, 39, '370'),
	(243, 1, 0, -50939, 372, 0, 0, 39, '371'),
	(243, 1, 0, -50939, 373, 0, 0, 39, '372'),
	(243, 1, 0, -50939, 374, 0, 0, 39, '373'),
	(243, 1, 0, -50939, 375, 0, 0, 39, '374'),
	(243, 1, 0, -50939, 376, 0, 0, 39, '375'),
	(243, 1, 0, -50939, 377, 0, 0, 39, '376'),
	(243, 1, 0, -50939, 378, 0, 0, 39, '377'),
	(243, 1, 0, -50939, 379, 0, 0, 39, '378'),
	(243, 1, 0, -50939, 380, 0, 0, 39, '379'),
	(243, 1, 0, -50939, 381, 0, 0, 39, '380'),
	(243, 1, 0, -50939, 382, 0, 0, 39, '381'),
	(243, 1, 0, -50939, 383, 0, 0, 39, '382'),
	(243, 1, 0, -50939, 384, 0, 0, 39, '383'),
	(243, 1, 0, -50939, 385, 0, 0, 39, '384'),
	(243, 1, 0, -50939, 386, 0, 0, 39, '385'),
	(243, 1, 0, -50939, 387, 0, 0, 39, '386'),
	(243, 1, 0, -50939, 388, 0, 0, 39, '387'),
	(243, 1, 0, -50939, 389, 0, 0, 39, '388'),
	(243, 1, 0, -50939, 390, 0, 0, 39, '389'),
	(243, 1, 0, -50939, 391, 0, 0, 39, '390'),
	(243, 1, 0, -50939, 392, 0, 0, 39, '391'),
	(243, 1, 0, -50939, 393, 0, 0, 39, '392'),
	(243, 1, 0, -50939, 394, 0, 0, 39, '393'),
	(243, 1, 0, -50939, 395, 0, 0, 39, '394'),
	(243, 1, 0, -50939, 396, 0, 0, 39, '395'),
	(243, 1, 0, -50939, 397, 0, 0, 39, '396'),
	(243, 1, 0, -50939, 398, 0, 0, 39, '397'),
	(243, 1, 0, -50939, 399, 0, 0, 39, '398'),
	(243, 1, 0, -50939, 400, 0, 0, 39, '399'),
	(243, 1, 0, -50939, 401, 0, 0, 39, '400'),
	(243, 1, 0, -50939, 402, 0, 0, 39, '401'),
	(243, 1, 0, -50939, 403, 0, 0, 39, '402'),
	(243, 1, 0, -50939, 404, 0, 0, 39, '403'),
	(243, 1, 0, -50939, 405, 0, 0, 39, '404'),
	(243, 1, 0, -50939, 406, 0, 0, 39, '405'),
	(243, 1, 0, -50939, 407, 0, 0, 39, '406'),
	(243, 1, 0, -50939, 408, 0, 0, 39, '407'),
	(243, 1, 0, -50939, 409, 0, 0, 39, '408'),
	(243, 1, 0, -50939, 410, 0, 0, 39, '409'),
	(243, 1, 0, -50939, 411, 0, 0, 39, '410'),
	(243, 1, 0, -50939, 412, 0, 0, 39, '411'),
	(243, 1, 0, -50939, 413, 0, 0, 39, '412'),
	(243, 1, 0, -50939, 414, 0, 0, 39, '413'),
	(243, 1, 0, -50939, 415, 0, 0, 39, '414'),
	(243, 1, 0, -50939, 416, 0, 0, 39, '415'),
	(243, 1, 0, -50939, 417, 0, 0, 39, '416'),
	(243, 1, 0, -50939, 418, 0, 0, 39, '417'),
	(243, 1, 0, -50939, 419, 0, 0, 39, '418'),
	(243, 1, 0, -50939, 420, 0, 0, 39, '419'),
	(243, 1, 0, -50939, 421, 0, 0, 39, '420'),
	(243, 1, 0, -50939, 422, 0, 0, 39, '421'),
	(243, 1, 0, -50939, 423, 0, 0, 39, '422'),
	(243, 1, 0, -50939, 424, 0, 0, 39, '423'),
	(243, 1, 0, -50939, 425, 0, 0, 39, '424'),
	(243, 1, 0, -50939, 426, 0, 0, 39, '425'),
	(243, 1, 0, -50939, 427, 0, 0, 39, '426'),
	(243, 1, 0, -50939, 428, 0, 0, 39, '427'),
	(243, 1, 0, -50939, 429, 0, 0, 39, '428'),
	(243, 1, 0, -50939, 430, 0, 0, 39, '429'),
	(243, 1, 0, -50939, 431, 0, 0, 39, '430'),
	(243, 1, 0, -50939, 432, 0, 0, 39, '431'),
	(243, 1, 0, -50939, 433, 0, 0, 39, '432'),
	(243, 1, 0, -50939, 434, 0, 0, 39, '433'),
	(243, 1, 0, -50939, 435, 0, 0, 39, '434'),
	(243, 1, 0, -50939, 436, 0, 0, 39, '435'),
	(243, 1, 0, -50939, 437, 0, 0, 39, '436'),
	(243, 1, 0, -50939, 438, 0, 0, 39, '437'),
	(243, 1, 0, -50939, 439, 0, 0, 39, '438'),
	(243, 1, 0, -50939, 440, 0, 0, 39, '439'),
	(243, 1, 0, -50939, 441, 0, 0, 39, '440'),
	(243, 1, 0, -50939, 442, 0, 0, 39, '441'),
	(243, 1, 0, -50939, 443, 0, 0, 39, '442'),
	(243, 1, 0, -50939, 444, 0, 0, 39, '443'),
	(243, 1, 0, -50939, 445, 0, 0, 39, '444'),
	(243, 1, 0, -50939, 446, 0, 0, 39, '445'),
	(243, 1, 0, -50939, 447, 0, 0, 39, '446'),
	(243, 1, 0, -50939, 448, 0, 0, 39, '447'),
	(243, 1, 0, -50939, 449, 0, 0, 39, '448'),
	(243, 1, 0, -50939, 450, 0, 0, 39, '449'),
	(243, 1, 0, -50939, 451, 0, 0, 39, '450'),
	(243, 1, 0, -50939, 452, 0, 0, 39, '451'),
	(243, 1, 0, -50939, 453, 0, 0, 39, '452'),
	(243, 1, 0, -50939, 454, 0, 0, 39, '453'),
	(243, 1, 0, -50939, 455, 0, 0, 39, '454'),
	(243, 1, 0, -50939, 456, 0, 0, 39, '455'),
	(243, 1, 0, -50939, 457, 0, 0, 39, '456'),
	(243, 1, 0, -50939, 458, 0, 0, 39, '457'),
	(243, 1, 0, -50939, 459, 0, 0, 39, '458'),
	(243, 1, 0, -50939, 460, 0, 0, 39, '459'),
	(243, 1, 0, -50939, 461, 0, 0, 39, '460'),
	(243, 1, 0, -50939, 462, 0, 0, 39, '461'),
	(243, 1, 0, -50939, 463, 0, 0, 39, '462'),
	(243, 1, 0, -50939, 464, 0, 0, 39, '463'),
	(243, 1, 0, -50939, 465, 0, 0, 39, '464'),
	(243, 1, 0, -50939, 466, 0, 0, 39, '465'),
	(243, 1, 0, -50939, 467, 0, 0, 39, '466'),
	(243, 1, 0, -50939, 468, 0, 0, 39, '467'),
	(243, 1, 0, -50939, 469, 0, 0, 39, '468'),
	(243, 1, 0, -50939, 470, 0, 0, 39, '469'),
	(243, 1, 0, -50939, 471, 0, 0, 39, '470'),
	(243, 1, 0, -50939, 472, 0, 0, 39, '471'),
	(243, 1, 0, -50939, 473, 0, 0, 39, '472'),
	(243, 1, 0, -50939, 474, 0, 0, 39, '473'),
	(243, 1, 0, -50939, 475, 0, 0, 39, '474'),
	(243, 1, 0, -50939, 476, 0, 0, 39, '475'),
	(243, 1, 0, -50939, 477, 0, 0, 39, '476'),
	(243, 1, 0, -50939, 478, 0, 0, 39, '477'),
	(243, 1, 0, -50939, 479, 0, 0, 39, '478'),
	(243, 1, 0, -50939, 480, 0, 0, 39, '479'),
	(243, 1, 0, -50939, 481, 0, 0, 39, '480'),
	(243, 1, 0, -50939, 482, 0, 0, 39, '481'),
	(243, 1, 0, -50939, 483, 0, 0, 39, '482'),
	(243, 1, 0, -50939, 484, 0, 0, 39, '483'),
	(243, 1, 0, -50939, 485, 0, 0, 39, '484'),
	(243, 1, 0, -50939, 486, 0, 0, 39, '485'),
	(243, 1, 0, -50939, 487, 0, 0, 39, '486'),
	(243, 1, 0, -50939, 488, 0, 0, 39, '487'),
	(243, 1, 0, -50939, 489, 0, 0, 39, '488'),
	(243, 1, 0, -50939, 490, 0, 0, 39, '489'),
	(243, 1, 0, -50939, 491, 0, 0, 39, '490'),
	(243, 1, 0, -50939, 492, 0, 0, 39, '491'),
	(243, 1, 0, -50939, 493, 0, 0, 39, '492'),
	(243, 1, 0, -50939, 494, 0, 0, 39, '493'),
	(243, 1, 0, -50939, 495, 0, 0, 39, '494'),
	(243, 1, 0, -50939, 496, 0, 0, 39, '495'),
	(243, 1, 0, -50939, 497, 0, 0, 39, '496'),
	(243, 1, 0, -50939, 498, 0, 0, 39, '497'),
	(243, 1, 0, -50939, 499, 0, 0, 39, '498'),
	(243, 1, 0, -50939, 500, 0, 0, 39, '499'),
	(243, 1, 0, -50939, 501, 0, 0, 39, '500'),
	(243, 1, 0, -50939, 502, 0, 0, 39, '501'),
	(243, 1, 0, -50939, 503, 0, 0, 39, '502'),
	(243, 1, 0, -50939, 504, 0, 0, 39, '503'),
	(243, 1, 0, -50939, 505, 0, 0, 39, '504'),
	(243, 1, 0, -50939, 506, 0, 0, 39, '505'),
	(243, 1, 0, -50939, 507, 0, 0, 39, '506'),
	(243, 1, 0, -50939, 508, 0, 0, 39, '507'),
	(243, 1, 0, -50939, 509, 0, 0, 39, '508'),
	(243, 1, 0, -50939, 510, 0, 0, 39, '509'),
	(243, 1, 0, -50939, 511, 0, 0, 39, '510'),
	(243, 1, 0, -50939, 512, 0, 0, 39, '511'),
	(243, 1, 0, -50939, 513, 0, 0, 39, '512'),
	(243, 1, 0, -50939, 514, 0, 0, 39, '513'),
	(243, 1, 0, -50939, 515, 0, 0, 39, '514'),
	(243, 1, 0, -50939, 516, 0, 0, 39, '515'),
	(243, 1, 0, -50939, 517, 0, 0, 39, '516'),
	(243, 1, 0, -50939, 518, 0, 0, 39, '517'),
	(243, 1, 0, -50939, 519, 0, 0, 39, '518'),
	(243, 1, 0, -50939, 520, 0, 0, 39, '519'),
	(243, 1, 0, -50939, 521, 0, 0, 39, '520'),
	(243, 1, 0, -50939, 522, 0, 0, 39, '521'),
	(243, 1, 0, -50939, 523, 0, 0, 39, '522'),
	(243, 1, 0, -50939, 524, 0, 0, 39, '523'),
	(243, 1, 0, -50939, 525, 0, 0, 39, '524'),
	(243, 1, 0, -50939, 526, 0, 0, 39, '525'),
	(243, 1, 0, -50939, 527, 0, 0, 39, '526'),
	(243, 1, 0, -50939, 528, 0, 0, 39, '527'),
	(243, 1, 0, -50939, 529, 0, 0, 39, '528'),
	(243, 1, 0, -50939, 530, 0, 0, 39, '529'),
	(243, 1, 0, -50939, 531, 0, 0, 39, '530'),
	(243, 1, 0, -50939, 532, 0, 0, 39, '531'),
	(243, 1, 0, -50939, 533, 0, 0, 39, '532'),
	(243, 1, 0, -50939, 534, 0, 0, 39, '533'),
	(243, 1, 0, -50939, 535, 0, 0, 39, '534'),
	(243, 1, 0, -50939, 536, 0, 0, 39, '535'),
	(243, 1, 0, -50939, 537, 0, 0, 39, '536'),
	(243, 1, 0, -50939, 538, 0, 0, 39, '537'),
	(243, 1, 0, -50939, 539, 0, 0, 39, '538'),
	(243, 1, 0, -50939, 540, 0, 0, 39, '539'),
	(243, 1, 0, -50939, 541, 0, 0, 39, '540'),
	(243, 1, 0, -50939, 542, 0, 0, 39, '541'),
	(243, 1, 0, -50939, 543, 0, 0, 39, '542'),
	(243, 1, 0, -50939, 544, 0, 0, 39, '543'),
	(243, 1, 0, -50939, 545, 0, 0, 39, '544'),
	(243, 1, 0, -50939, 546, 0, 0, 39, '545'),
	(243, 1, 0, -50939, 547, 0, 0, 39, '546'),
	(243, 1, 0, -50939, 548, 0, 0, 39, '547'),
	(243, 1, 0, -50939, 549, 0, 0, 39, '548'),
	(243, 1, 0, -50939, 550, 0, 0, 39, '549'),
	(243, 1, 0, -50939, 551, 0, 0, 39, '550'),
	(243, 1, 0, -50939, 552, 0, 0, 39, '551'),
	(243, 1, 0, -50939, 553, 0, 0, 39, '552'),
	(243, 1, 0, -50939, 554, 0, 0, 39, '553'),
	(243, 1, 0, -50939, 555, 0, 0, 39, '554'),
	(243, 1, 0, -50939, 556, 0, 0, 39, '555'),
	(243, 1, 0, -50939, 557, 0, 0, 39, '556'),
	(243, 1, 0, -50939, 558, 0, 0, 39, '557'),
	(243, 1, 0, -50939, 559, 0, 0, 39, '558'),
	(243, 1, 0, -50939, 560, 0, 0, 39, '559'),
	(243, 1, 0, -50939, 561, 0, 0, 39, '560'),
	(243, 1, 0, -50939, 562, 0, 0, 39, '561'),
	(243, 1, 0, -50939, 563, 0, 0, 39, '562'),
	(243, 1, 0, -50939, 564, 0, 0, 39, '563'),
	(243, 1, 0, -50939, 565, 0, 0, 39, '564'),
	(243, 1, 0, -50939, 566, 0, 0, 39, '565'),
	(243, 1, 0, -50939, 567, 0, 0, 39, '566'),
	(243, 1, 0, -50939, 568, 0, 0, 39, '567'),
	(243, 1, 0, -50939, 569, 0, 0, 39, '568'),
	(243, 1, 0, -50939, 570, 0, 0, 39, '569'),
	(243, 1, 0, -50939, 571, 0, 0, 39, '570'),
	(243, 1, 0, -50939, 572, 0, 0, 39, '571'),
	(243, 1, 0, -50939, 573, 0, 0, 39, '572'),
	(243, 1, 0, -50939, 574, 0, 0, 39, '573'),
	(243, 1, 0, -50939, 575, 0, 0, 39, '574'),
	(243, 1, 0, -50939, 576, 0, 0, 39, '575'),
	(243, 1, 0, -50939, 577, 0, 0, 39, '576'),
	(243, 1, 0, -50939, 578, 0, 0, 39, '577'),
	(243, 1, 0, -50939, 579, 0, 0, 39, '578'),
	(243, 1, 0, -50939, 580, 0, 0, 39, '579'),
	(243, 1, 0, -50939, 581, 0, 0, 39, '580'),
	(243, 1, 0, -50939, 582, 0, 0, 39, '581'),
	(243, 1, 0, -50939, 583, 0, 0, 39, '582'),
	(243, 1, 0, -50939, 584, 0, 0, 39, '583'),
	(243, 1, 0, -50939, 585, 0, 0, 39, '584'),
	(243, 1, 0, -50939, 586, 0, 0, 39, '585'),
	(243, 1, 0, -50939, 587, 0, 0, 39, '586'),
	(243, 1, 0, -50939, 588, 0, 0, 39, '587'),
	(243, 1, 0, -50939, 589, 0, 0, 39, '588'),
	(243, 1, 0, -50939, 590, 0, 0, 39, '589'),
	(243, 1, 0, -50939, 591, 0, 0, 39, '590'),
	(243, 1, 0, -50939, 592, 0, 0, 39, '591'),
	(243, 1, 0, -50939, 593, 0, 0, 39, '592'),
	(243, 1, 0, -50939, 594, 0, 0, 39, '593'),
	(243, 1, 0, -50939, 595, 0, 0, 39, '594'),
	(243, 1, 0, -50939, 596, 0, 0, 39, '595'),
	(243, 1, 0, -50939, 597, 0, 0, 39, '596'),
	(243, 1, 0, -50939, 598, 0, 0, 39, '597'),
	(243, 1, 0, -50939, 599, 0, 0, 39, '598'),
	(243, 1, 0, -50939, 600, 0, 0, 39, '599'),
	(243, 1, 0, -50939, 601, 0, 0, 39, '600'),
	(243, 1, 0, -50939, 602, 0, 0, 39, '601'),
	(243, 1, 0, -50939, 603, 0, 0, 39, '602'),
	(243, 1, 0, -50939, 604, 0, 0, 39, '603'),
	(243, 1, 0, -50939, 605, 0, 0, 39, '604'),
	(243, 1, 0, -50939, 606, 0, 0, 39, '605'),
	(243, 1, 0, -50939, 607, 0, 0, 39, '606'),
	(243, 1, 0, -50939, 608, 0, 0, 39, '607'),
	(243, 1, 0, -50939, 609, 0, 0, 39, '608'),
	(243, 1, 0, -50939, 610, 0, 0, 39, '609'),
	(243, 1, 0, -50939, 611, 0, 0, 39, '610'),
	(243, 1, 0, -50939, 612, 0, 0, 39, '611'),
	(243, 1, 0, -50939, 613, 0, 0, 39, '612'),
	(243, 1, 0, -50939, 614, 0, 0, 39, '613'),
	(243, 1, 0, -50939, 615, 0, 0, 39, '614'),
	(243, 1, 0, -50939, 616, 0, 0, 39, '615'),
	(243, 1, 0, -50939, 617, 0, 0, 39, '616'),
	(243, 1, 0, -50939, 618, 0, 0, 39, '617'),
	(243, 1, 0, -50939, 619, 0, 0, 39, '618'),
	(243, 1, 0, -50939, 620, 0, 0, 39, '619'),
	(243, 1, 0, -50939, 621, 0, 0, 39, '620'),
	(243, 1, 0, -50939, 622, 0, 0, 39, '621'),
	(243, 1, 0, -50939, 623, 0, 0, 39, '622'),
	(243, 1, 0, -50939, 624, 0, 0, 39, '623'),
	(243, 1, 0, -50939, 625, 0, 0, 39, '624'),
	(243, 1, 0, -50939, 626, 0, 0, 39, '625'),
	(243, 1, 0, -50939, 627, 0, 0, 39, '626'),
	(243, 1, 0, -50939, 628, 0, 0, 39, '627'),
	(243, 1, 0, -50939, 629, 0, 0, 39, '628'),
	(243, 1, 0, -50939, 630, 0, 0, 39, '629'),
	(243, 1, 0, -50939, 631, 0, 0, 39, '630'),
	(243, 1, 0, -50939, 632, 0, 0, 39, '631'),
	(243, 1, 0, -50939, 633, 0, 0, 39, '632'),
	(243, 1, 0, -50939, 634, 0, 0, 39, '633'),
	(243, 1, 0, -50939, 635, 0, 0, 39, '634'),
	(243, 1, 0, -50939, 636, 0, 0, 39, '635'),
	(243, 1, 0, -50939, 637, 0, 0, 39, '636'),
	(243, 1, 0, -50939, 638, 0, 0, 39, '637'),
	(243, 1, 0, -50939, 639, 0, 0, 39, '638'),
	(243, 1, 0, -50939, 640, 0, 0, 39, '639'),
	(243, 1, 0, -50939, 641, 0, 0, 39, '640'),
	(243, 1, 0, -50939, 642, 0, 0, 39, '641'),
	(243, 1, 0, -50939, 643, 0, 0, 39, '642'),
	(243, 1, 0, -50939, 644, 0, 0, 39, '643'),
	(243, 1, 0, -50939, 645, 0, 0, 39, '644'),
	(243, 1, 0, -50939, 646, 0, 0, 39, '645'),
	(243, 1, 0, -50939, 647, 0, 0, 39, '646'),
	(243, 1, 0, -50939, 648, 0, 0, 39, '647'),
	(243, 1, 0, -50939, 649, 0, 0, 39, '648'),
	(243, 1, 0, -50939, 650, 0, 0, 39, '649'),
	(243, 1, 0, -50939, 651, 0, 0, 39, '650'),
	(243, 1, 0, -50939, 652, 0, 0, 39, '651'),
	(243, 1, 0, -50939, 653, 0, 0, 39, '652'),
	(243, 1, 0, -50939, 654, 0, 0, 39, '653'),
	(243, 1, 0, -50939, 655, 0, 0, 39, '654'),
	(243, 1, 0, -50939, 656, 0, 0, 39, '655'),
	(243, 1, 0, -50939, 657, 0, 0, 39, '656'),
	(243, 1, 0, -50939, 658, 0, 0, 39, '657'),
	(243, 1, 0, -50939, 659, 0, 0, 39, '658'),
	(243, 1, 0, -50939, 660, 0, 0, 39, '659'),
	(243, 1, 0, -50939, 661, 0, 0, 39, '660'),
	(243, 1, 0, -50939, 662, 0, 0, 39, '661'),
	(243, 1, 0, -50939, 663, 0, 0, 39, '662'),
	(243, 1, 0, -50939, 664, 0, 0, 39, '663'),
	(243, 1, 0, -50939, 665, 0, 0, 39, '664'),
	(243, 1, 0, -50939, 666, 0, 0, 39, '665'),
	(243, 1, 0, -50939, 667, 0, 0, 39, '666'),
	(243, 1, 0, -50939, 668, 0, 0, 39, '667'),
	(243, 1, 0, -50939, 669, 0, 0, 39, '668'),
	(243, 1, 0, -50939, 670, 0, 0, 39, '669'),
	(243, 1, 0, -50939, 671, 0, 0, 39, '670'),
	(243, 1, 0, -50939, 672, 0, 0, 39, '671'),
	(243, 1, 0, -50939, 673, 0, 0, 39, '672'),
	(243, 1, 0, -50939, 674, 0, 0, 39, '673'),
	(243, 1, 0, -50939, 675, 0, 0, 39, '674'),
	(243, 1, 0, -50939, 676, 0, 0, 39, '675'),
	(243, 1, 0, -50939, 677, 0, 0, 39, '676'),
	(243, 1, 0, -50939, 678, 0, 0, 39, '677'),
	(243, 1, 0, -50939, 679, 0, 0, 39, '678'),
	(243, 1, 0, -50939, 680, 0, 0, 39, '679'),
	(243, 1, 0, -50939, 681, 0, 0, 39, '680'),
	(243, 1, 0, -50939, 682, 0, 0, 39, '681'),
	(243, 1, 0, -50939, 683, 0, 0, 39, '682'),
	(243, 1, 0, -50939, 684, 0, 0, 39, '683'),
	(243, 1, 0, -50939, 685, 0, 0, 39, '684'),
	(243, 1, 0, -50939, 686, 0, 0, 39, '685'),
	(243, 1, 0, -50939, 687, 0, 0, 39, '686'),
	(243, 1, 0, -50939, 688, 0, 0, 39, '687'),
	(243, 1, 0, -50939, 689, 0, 0, 39, '688'),
	(243, 1, 0, -50939, 690, 0, 0, 39, '689'),
	(243, 1, 0, -50939, 691, 0, 0, 39, '690'),
	(243, 1, 0, -50939, 692, 0, 0, 39, '691'),
	(243, 1, 0, -50939, 693, 0, 0, 39, '692'),
	(243, 1, 0, -50939, 694, 0, 0, 39, '693'),
	(243, 1, 0, -50939, 695, 0, 0, 39, '694'),
	(243, 1, 0, -50939, 696, 0, 0, 39, '695'),
	(243, 1, 0, -50939, 697, 0, 0, 39, '696'),
	(243, 1, 0, -50939, 698, 0, 0, 39, '697'),
	(243, 1, 0, -50939, 699, 0, 0, 39, '698'),
	(243, 1, 0, -50939, 700, 0, 0, 39, '699'),
	(243, 1, 0, -50939, 701, 0, 0, 39, '700'),
	(243, 1, 0, -50939, 702, 0, 0, 39, '701'),
	(243, 1, 0, -50939, 703, 0, 0, 39, '702'),
	(243, 1, 0, -50939, 704, 0, 0, 39, '703'),
	(243, 1, 0, -50939, 705, 0, 0, 39, '704'),
	(243, 1, 0, -50939, 706, 0, 0, 39, '705'),
	(243, 1, 0, -50939, 707, 0, 0, 39, '706'),
	(243, 1, 0, -50939, 708, 0, 0, 39, '707'),
	(243, 1, 0, -50939, 709, 0, 0, 39, '708'),
	(243, 1, 0, -50939, 710, 0, 0, 39, '709'),
	(243, 1, 0, -50939, 711, 0, 0, 39, '710'),
	(243, 1, 0, -50939, 712, 0, 0, 39, '711'),
	(243, 1, 0, -50939, 713, 0, 0, 39, '712'),
	(243, 1, 0, -50939, 714, 0, 0, 39, '713'),
	(243, 1, 0, -50939, 715, 0, 0, 39, '714'),
	(243, 1, 0, -50939, 716, 0, 0, 39, '715'),
	(243, 1, 0, -50939, 717, 0, 0, 39, '716'),
	(243, 1, 0, -50939, 718, 0, 0, 39, '717'),
	(243, 1, 0, -50939, 719, 0, 0, 39, '718'),
	(243, 1, 0, -50939, 720, 0, 0, 39, '719'),
	(243, 1, 0, -50939, 721, 0, 0, 39, '720'),
	(243, 1, 0, -50939, 722, 0, 0, 39, '721'),
	(243, 1, 0, -50939, 723, 0, 0, 39, '722'),
	(243, 1, 0, -50939, 724, 0, 0, 39, '723'),
	(243, 1, 0, -50939, 725, 0, 0, 39, '724'),
	(243, 1, 0, -50939, 726, 0, 0, 39, '725'),
	(243, 1, 0, -50939, 727, 0, 0, 39, '726'),
	(243, 1, 0, -50939, 728, 0, 0, 39, '727'),
	(243, 1, 0, -50939, 729, 0, 0, 39, '728'),
	(243, 1, 0, -50939, 730, 0, 0, 39, '729'),
	(243, 1, 0, -50939, 731, 0, 0, 39, '730'),
	(243, 1, 0, -50939, 732, 0, 0, 39, '731'),
	(243, 1, 0, -50939, 733, 0, 0, 39, '732'),
	(243, 1, 0, -50939, 734, 0, 0, 39, '733'),
	(243, 1, 0, -50939, 735, 0, 0, 39, '734'),
	(243, 1, 0, -50939, 736, 0, 0, 39, '735'),
	(243, 1, 0, -50939, 737, 0, 0, 39, '736'),
	(243, 1, 0, -50939, 738, 0, 0, 39, '737'),
	(243, 1, 0, -50939, 739, 0, 0, 39, '738'),
	(243, 1, 0, -50939, 740, 0, 0, 39, '739'),
	(243, 1, 0, -50939, 741, 0, 0, 39, '740'),
	(243, 1, 0, -50939, 742, 0, 0, 39, '741'),
	(243, 1, 0, -50939, 743, 0, 0, 39, '742'),
	(243, 1, 0, -50939, 744, 0, 0, 39, '743'),
	(243, 1, 0, -50939, 745, 0, 0, 39, '744'),
	(243, 1, 0, -50939, 746, 0, 0, 39, '745'),
	(243, 1, 0, -50939, 747, 0, 0, 39, '746'),
	(243, 1, 0, -50939, 748, 0, 0, 39, '747'),
	(243, 1, 0, -50939, 749, 0, 0, 39, '748'),
	(243, 1, 0, -50939, 750, 0, 0, 39, '749'),
	(243, 1, 0, -50939, 751, 0, 0, 39, '750'),
	(243, 1, 0, -50939, 752, 0, 0, 39, '751'),
	(243, 1, 0, -50939, 753, 0, 0, 39, '752'),
	(243, 1, 0, -50939, 754, 0, 0, 39, '753'),
	(243, 1, 0, -50939, 755, 0, 0, 39, '754'),
	(243, 1, 0, -50939, 756, 0, 0, 39, '755'),
	(243, 1, 0, -50939, 757, 0, 0, 39, '756'),
	(243, 1, 0, -50939, 758, 0, 0, 39, '757'),
	(243, 1, 0, -50939, 759, 0, 0, 39, '758'),
	(243, 1, 0, -50939, 760, 0, 0, 39, '759'),
	(243, 1, 0, -50939, 761, 0, 0, 39, '760'),
	(243, 1, 0, -50939, 762, 0, 0, 39, '761'),
	(243, 1, 0, -50939, 763, 0, 0, 39, '762'),
	(243, 1, 0, -50939, 764, 0, 0, 39, '763'),
	(243, 1, 0, -50939, 765, 0, 0, 39, '764'),
	(243, 1, 0, -50939, 766, 0, 0, 39, '765'),
	(243, 1, 0, -50939, 767, 0, 0, 39, '766'),
	(243, 1, 0, -50939, 768, 0, 0, 39, '767'),
	(243, 1, 0, -50939, 769, 0, 0, 39, '768'),
	(243, 1, 0, -50939, 770, 0, 0, 39, '769'),
	(243, 1, 0, -50939, 771, 0, 0, 39, '770'),
	(243, 1, 0, -50939, 772, 0, 0, 39, '771'),
	(243, 1, 0, -50939, 773, 0, 0, 39, '772'),
	(243, 1, 0, -50939, 774, 0, 0, 39, '773'),
	(243, 1, 0, -50939, 775, 0, 0, 39, '774'),
	(243, 1, 0, -50939, 776, 0, 0, 39, '775'),
	(243, 1, 0, -50939, 777, 0, 0, 39, '776'),
	(243, 1, 0, -50939, 778, 0, 0, 39, '777'),
	(243, 1, 0, -50939, 779, 0, 0, 39, '778'),
	(243, 1, 0, -50939, 780, 0, 0, 39, '779'),
	(243, 1, 0, -50939, 781, 0, 0, 39, '780'),
	(243, 1, 0, -50939, 782, 0, 0, 39, '781'),
	(243, 1, 0, -50939, 783, 0, 0, 39, '782'),
	(243, 1, 0, -50939, 784, 0, 0, 39, '783'),
	(243, 1, 0, -50939, 785, 0, 0, 39, '784'),
	(243, 1, 0, -50939, 786, 0, 0, 39, '785'),
	(243, 1, 0, -50939, 787, 0, 0, 39, '786'),
	(243, 1, 0, -50939, 788, 0, 0, 39, '787'),
	(243, 1, 0, -50939, 789, 0, 0, 39, '788'),
	(243, 1, 0, -50939, 790, 0, 0, 39, '789'),
	(243, 1, 0, -50939, 791, 0, 0, 39, '790'),
	(243, 1, 0, -50939, 792, 0, 0, 39, '791'),
	(243, 1, 0, -50939, 793, 0, 0, 39, '792'),
	(243, 1, 0, -50939, 794, 0, 0, 39, '793'),
	(243, 1, 0, -50939, 795, 0, 0, 39, '794'),
	(243, 1, 0, -50939, 796, 0, 0, 39, '795'),
	(243, 1, 0, -50939, 797, 0, 0, 39, '796'),
	(243, 1, 0, -50939, 798, 0, 0, 39, '797'),
	(243, 1, 0, -50939, 799, 0, 0, 39, '798'),
	(243, 1, 0, -50939, 800, 0, 0, 39, '799'),
	(243, 1, 0, -50939, 801, 0, 0, 39, '800'),
	(243, 1, 0, -50939, 802, 0, 0, 39, '801'),
	(243, 1, 0, -50939, 803, 0, 0, 39, '802'),
	(243, 1, 0, -50939, 804, 0, 0, 39, '803'),
	(243, 1, 0, -50939, 805, 0, 0, 39, '804'),
	(243, 1, 0, -50939, 806, 0, 0, 39, '805'),
	(243, 1, 0, -50939, 807, 0, 0, 39, '806'),
	(243, 1, 0, -50939, 808, 0, 0, 39, '807'),
	(243, 1, 0, -50939, 809, 0, 0, 39, '808'),
	(243, 1, 0, -50939, 810, 0, 0, 39, '809'),
	(243, 1, 0, -50939, 811, 0, 0, 39, '810'),
	(243, 1, 0, -50939, 812, 0, 0, 39, '811'),
	(243, 1, 0, -50939, 813, 0, 0, 39, '812'),
	(243, 1, 0, -50939, 814, 0, 0, 39, '813'),
	(243, 1, 0, -50939, 815, 0, 0, 39, '814'),
	(243, 1, 0, -50939, 816, 0, 0, 39, '815'),
	(243, 1, 0, -50939, 817, 0, 0, 39, '816'),
	(243, 1, 0, -50939, 818, 0, 0, 39, '817'),
	(243, 1, 0, -50939, 819, 0, 0, 39, '818'),
	(243, 1, 0, -50939, 820, 0, 0, 39, '819'),
	(243, 1, 0, -50939, 821, 0, 0, 39, '820'),
	(243, 1, 0, -50939, 822, 0, 0, 39, '821'),
	(243, 1, 0, -50939, 823, 0, 0, 39, '822'),
	(243, 1, 0, -50939, 824, 0, 0, 39, '823'),
	(243, 1, 0, -50939, 825, 0, 0, 39, '824'),
	(243, 1, 0, -50939, 826, 0, 0, 39, '825'),
	(243, 1, 0, -50939, 827, 0, 0, 39, '826'),
	(243, 1, 0, -50939, 828, 0, 0, 39, '827'),
	(243, 1, 0, -50939, 829, 0, 0, 39, '828'),
	(243, 1, 0, -50939, 830, 0, 0, 39, '829'),
	(243, 1, 0, -50939, 831, 0, 0, 39, '830'),
	(243, 1, 0, -50939, 832, 0, 0, 39, '831'),
	(243, 1, 0, -50939, 833, 0, 0, 39, '832'),
	(243, 1, 0, -50939, 834, 0, 0, 39, '833'),
	(243, 1, 0, -50939, 835, 0, 0, 39, '834'),
	(243, 1, 0, -50939, 836, 0, 0, 39, '835'),
	(243, 1, 0, -50939, 837, 0, 0, 39, '836'),
	(243, 1, 0, -50939, 838, 0, 0, 39, '837'),
	(243, 1, 0, -50939, 839, 0, 0, 39, '838'),
	(243, 1, 0, -50939, 840, 0, 0, 39, '839'),
	(243, 1, 0, -50939, 841, 0, 0, 39, '840'),
	(243, 1, 0, -50939, 842, 0, 0, 39, '841'),
	(243, 1, 0, -50939, 843, 0, 0, 39, '842'),
	(243, 1, 0, -50939, 844, 0, 0, 39, '843'),
	(243, 1, 0, -50939, 845, 0, 0, 39, '844'),
	(243, 1, 0, -50939, 846, 0, 0, 39, '845'),
	(243, 1, 0, -50939, 847, 0, 0, 39, '846'),
	(243, 1, 0, -50939, 848, 0, 0, 39, '847'),
	(243, 1, 0, -50939, 849, 0, 0, 39, '848'),
	(243, 1, 0, -50939, 850, 0, 0, 39, '849'),
	(243, 1, 0, -50939, 851, 0, 0, 39, '850'),
	(243, 1, 0, -50939, 852, 0, 0, 39, '851'),
	(243, 1, 0, -50939, 853, 0, 0, 39, '852'),
	(243, 1, 0, -50939, 854, 0, 0, 39, '853'),
	(243, 1, 0, -50939, 855, 0, 0, 39, '854'),
	(243, 1, 0, -50939, 856, 0, 0, 39, '855'),
	(243, 1, 0, -50939, 857, 0, 0, 39, '856'),
	(243, 1, 0, -50939, 858, 0, 0, 39, '857'),
	(243, 1, 0, -50939, 859, 0, 0, 39, '858'),
	(243, 1, 0, -50939, 860, 0, 0, 39, '859'),
	(243, 1, 0, -50939, 861, 0, 0, 39, '860'),
	(243, 1, 0, -50939, 862, 0, 0, 39, '861'),
	(243, 1, 0, -50939, 863, 0, 0, 39, '862'),
	(243, 1, 0, -50939, 864, 0, 0, 39, '863'),
	(243, 1, 0, -50939, 865, 0, 0, 39, '864'),
	(243, 1, 0, -50939, 866, 0, 0, 39, '865'),
	(243, 1, 0, -50939, 867, 0, 0, 39, '866'),
	(243, 1, 0, -50939, 868, 0, 0, 39, '867'),
	(243, 1, 0, -50939, 869, 0, 0, 39, '868'),
	(243, 1, 0, -50939, 870, 0, 0, 39, '869'),
	(243, 1, 0, -50939, 871, 0, 0, 39, '870'),
	(243, 1, 0, -50939, 872, 0, 0, 39, '871'),
	(243, 1, 0, -50939, 873, 0, 0, 39, '872'),
	(243, 1, 0, -50939, 874, 0, 0, 39, '873'),
	(243, 1, 0, -50939, 875, 0, 0, 39, '874'),
	(243, 1, 0, -50939, 876, 0, 0, 39, '875'),
	(243, 1, 0, -50939, 877, 0, 0, 39, '876'),
	(243, 1, 0, -50939, 878, 0, 0, 39, '877'),
	(243, 1, 0, -50939, 879, 0, 0, 39, '878'),
	(243, 1, 0, -50939, 880, 0, 0, 39, '879'),
	(243, 1, 0, -50939, 881, 0, 0, 39, '880'),
	(243, 1, 0, -50939, 882, 0, 0, 39, '881'),
	(243, 1, 0, -50939, 883, 0, 0, 39, '882'),
	(243, 1, 0, -50939, 884, 0, 0, 39, '883'),
	(243, 1, 0, -50939, 885, 0, 0, 39, '884'),
	(243, 1, 0, -50939, 886, 0, 0, 39, '885'),
	(243, 1, 0, -50939, 887, 0, 0, 39, '886'),
	(243, 1, 0, -50939, 888, 0, 0, 39, '887'),
	(243, 1, 0, -50939, 889, 0, 0, 39, '888'),
	(243, 1, 0, -50939, 890, 0, 0, 39, '889'),
	(243, 1, 0, -50939, 891, 0, 0, 39, '890'),
	(243, 1, 0, -50939, 892, 0, 0, 39, '891'),
	(243, 1, 0, -50939, 893, 0, 0, 39, '892'),
	(243, 1, 0, -50939, 894, 0, 0, 39, '893'),
	(243, 1, 0, -50939, 895, 0, 0, 39, '894'),
	(243, 1, 0, -50939, 896, 0, 0, 39, '895'),
	(243, 1, 0, -50939, 897, 0, 0, 39, '896'),
	(243, 1, 0, -50939, 898, 0, 0, 39, '897'),
	(243, 1, 0, -50939, 899, 0, 0, 39, '898'),
	(243, 1, 0, -50939, 900, 0, 0, 39, '899'),
	(243, 1, 0, -50939, 901, 0, 0, 39, '900'),
	(243, 1, 0, -50939, 902, 0, 0, 39, '901'),
	(243, 1, 0, -50939, 903, 0, 0, 39, '902'),
	(243, 1, 0, -50939, 904, 0, 0, 39, '903'),
	(243, 1, 0, -50939, 905, 0, 0, 39, '904'),
	(243, 1, 0, -50939, 906, 0, 0, 39, '905'),
	(243, 1, 0, -50939, 907, 0, 0, 39, '906'),
	(243, 1, 0, -50939, 908, 0, 0, 39, '907'),
	(243, 1, 0, -50939, 909, 0, 0, 39, '908'),
	(243, 1, 0, -50939, 910, 0, 0, 39, '909'),
	(243, 1, 0, -50939, 911, 0, 0, 39, '910'),
	(243, 1, 0, -50939, 912, 0, 0, 39, '911'),
	(243, 1, 0, -50939, 913, 0, 0, 39, '912'),
	(243, 1, 0, -50939, 914, 0, 0, 39, '913'),
	(243, 1, 0, -50939, 915, 0, 0, 39, '914'),
	(243, 1, 0, -50939, 916, 0, 0, 39, '915'),
	(243, 1, 0, -50939, 917, 0, 0, 39, '916'),
	(243, 1, 0, -50939, 918, 0, 0, 39, '917'),
	(243, 1, 0, -50939, 919, 0, 0, 39, '918'),
	(243, 1, 0, -50939, 920, 0, 0, 39, '919'),
	(243, 1, 0, -50939, 921, 0, 0, 39, '920'),
	(243, 1, 0, -50939, 922, 0, 0, 39, '921'),
	(243, 1, 0, -50939, 923, 0, 0, 39, '922'),
	(243, 1, 0, -50939, 924, 0, 0, 39, '923'),
	(243, 1, 0, -50939, 925, 0, 0, 39, '924'),
	(243, 1, 0, -50939, 926, 0, 0, 39, '925'),
	(243, 1, 0, -50939, 927, 0, 0, 39, '926'),
	(243, 1, 0, -50939, 928, 0, 0, 39, '927'),
	(243, 1, 0, -50939, 929, 0, 0, 39, '928'),
	(243, 1, 0, -50939, 930, 0, 0, 39, '929'),
	(243, 1, 0, -50939, 931, 0, 0, 39, '930'),
	(243, 1, 0, -50939, 932, 0, 0, 39, '931'),
	(243, 1, 0, -50939, 933, 0, 0, 39, '932'),
	(243, 1, 0, -50939, 934, 0, 0, 39, '933'),
	(243, 1, 0, -50939, 935, 0, 0, 39, '934'),
	(243, 1, 0, -50939, 936, 0, 0, 39, '935'),
	(243, 1, 0, -50939, 937, 0, 0, 39, '936'),
	(243, 1, 0, -50939, 938, 0, 0, 39, '937'),
	(243, 1, 0, -50939, 939, 0, 0, 39, '938'),
	(243, 1, 0, -50939, 940, 0, 0, 39, '939'),
	(243, 1, 0, -50939, 941, 0, 0, 39, '940'),
	(243, 1, 0, -50939, 942, 0, 0, 39, '941'),
	(243, 1, 0, -50939, 943, 0, 0, 39, '942'),
	(243, 1, 0, -50939, 944, 0, 0, 39, '943'),
	(243, 1, 0, -50939, 945, 0, 0, 39, '944'),
	(243, 1, 0, -50939, 946, 0, 0, 39, '945'),
	(243, 1, 0, -50939, 947, 0, 0, 39, '946'),
	(243, 1, 0, -50939, 948, 0, 0, 39, '947'),
	(243, 1, 0, -50939, 949, 0, 0, 39, '948'),
	(243, 1, 0, -50939, 950, 0, 0, 39, '949'),
	(243, 1, 0, -50939, 951, 0, 0, 39, '950'),
	(243, 1, 0, -50939, 952, 0, 0, 39, '951'),
	(243, 1, 0, -50939, 953, 0, 0, 39, '952'),
	(243, 1, 0, -50939, 954, 0, 0, 39, '953'),
	(243, 1, 0, -50939, 955, 0, 0, 39, '954'),
	(243, 1, 0, -50939, 956, 0, 0, 39, '955'),
	(243, 1, 0, -50939, 957, 0, 0, 39, '956'),
	(243, 1, 0, -50939, 958, 0, 0, 39, '957'),
	(243, 1, 0, -50939, 959, 0, 0, 39, '958'),
	(243, 1, 0, -50939, 960, 0, 0, 39, '959'),
	(243, 1, 0, -50939, 961, 0, 0, 39, '960'),
	(243, 1, 0, -50939, 962, 0, 0, 39, '961'),
	(243, 1, 0, -50939, 963, 0, 0, 39, '962'),
	(243, 1, 0, -50939, 964, 0, 0, 39, '963'),
	(243, 1, 0, -50939, 965, 0, 0, 39, '964'),
	(243, 1, 0, -50939, 966, 0, 0, 39, '965'),
	(243, 1, 0, -50939, 967, 0, 0, 39, '966'),
	(243, 1, 0, -50939, 968, 0, 0, 39, '967'),
	(243, 1, 0, -50939, 969, 0, 0, 39, '968'),
	(243, 1, 0, -50939, 970, 0, 0, 39, '969'),
	(243, 1, 0, -50939, 971, 0, 0, 39, '970'),
	(243, 1, 0, -50939, 972, 0, 0, 39, '971'),
	(243, 1, 0, -50939, 973, 0, 0, 39, '972'),
	(243, 1, 0, -50939, 974, 0, 0, 39, '973'),
	(243, 1, 0, -50939, 975, 0, 0, 39, '974'),
	(243, 1, 0, -50939, 976, 0, 0, 39, '975'),
	(243, 1, 0, -50939, 977, 0, 0, 39, '976'),
	(243, 1, 0, -50939, 978, 0, 0, 39, '977'),
	(243, 1, 0, -50939, 979, 0, 0, 39, '978'),
	(243, 1, 0, -50939, 980, 0, 0, 39, '979'),
	(243, 1, 0, -50939, 981, 0, 0, 39, '980'),
	(243, 1, 0, -50939, 982, 0, 0, 39, '981'),
	(243, 1, 0, -50939, 983, 0, 0, 39, '982'),
	(243, 1, 0, -50939, 984, 0, 0, 39, '983'),
	(243, 1, 0, -50939, 985, 0, 0, 39, '984'),
	(243, 1, 0, -50939, 986, 0, 0, 39, '985'),
	(243, 1, 0, -50939, 987, 0, 0, 39, '986'),
	(243, 1, 0, -50939, 988, 0, 0, 39, '987'),
	(243, 1, 0, -50939, 989, 0, 0, 39, '988'),
	(243, 1, 0, -50939, 990, 0, 0, 39, '989'),
	(243, 1, 0, -50939, 991, 0, 0, 39, '990'),
	(243, 1, 0, -50939, 992, 0, 0, 39, '991'),
	(243, 1, 0, -50939, 993, 0, 0, 39, '992'),
	(243, 1, 0, -50939, 994, 0, 0, 39, '993'),
	(243, 1, 0, -50939, 995, 0, 0, 39, '994'),
	(243, 1, 0, -50939, 996, 0, 0, 39, '995'),
	(243, 1, 0, -50939, 997, 0, 0, 39, '996'),
	(243, 1, 0, -50939, 998, 0, 0, 39, '997'),
	(243, 1, 0, -50939, 999, 0, 0, 39, '998'),
	(243, 1, 0, -50939, 1000, 0, 0, 39, '999'),
	(243, 1, 0, -50939, 1001, 0, 0, 39, '1000'),
	(243, 1, 0, -50939, 1002, 0, 0, 39, '1001'),
	(243, 1, 0, -50939, 1003, 0, 0, 39, '1002'),
	(243, 1, 0, -50939, 1004, 0, 0, 39, '1003'),
	(243, 1, 0, -50939, 1005, 0, 0, 39, '1004'),
	(243, 1, 0, -50939, 1006, 0, 0, 39, '1005'),
	(243, 1, 0, -50939, 1007, 0, 0, 39, '1006'),
	(243, 1, 0, -50939, 1008, 0, 0, 39, '1007'),
	(243, 1, 0, -50939, 1009, 0, 0, 39, '1008'),
	(243, 1, 0, -50939, 1010, 0, 0, 39, '1009'),
	(243, 1, 0, -50939, 1011, 0, 0, 39, '1010'),
	(243, 1, 0, -50939, 1012, 0, 0, 39, '1011'),
	(243, 1, 0, -50939, 1013, 0, 0, 39, '1012'),
	(243, 1, 0, -50939, 1014, 0, 0, 39, '1013'),
	(243, 1, 0, -50939, 1015, 0, 0, 39, '1014'),
	(243, 1, 0, -50939, 1016, 0, 0, 39, '1015'),
	(243, 1, 0, -50939, 1017, 0, 0, 39, '1016'),
	(243, 1, 0, -50939, 1018, 0, 0, 39, '1017'),
	(243, 1, 0, -50939, 1019, 0, 0, 39, '1018'),
	(243, 1, 0, -50939, 1020, 0, 0, 39, '1019'),
	(243, 1, 0, -50939, 1021, 0, 0, 39, '1020'),
	(243, 1, 0, -50939, 1022, 0, 0, 39, '1021'),
	(243, 1, 0, -50939, 1023, 0, 0, 39, '1022'),
	(243, 1, 0, -50939, 1024, 0, 0, 39, '1023'),
	(243, 1, 0, -50939, 1025, 0, 0, 39, '1024'),
	(243, 1, 0, -50939, 1026, 0, 0, 39, '1025'),
	(243, 1, 0, -50939, 1027, 0, 0, 39, '1026'),
	(243, 1, 0, -50939, 1028, 0, 0, 39, '1027'),
	(243, 1, 0, -50939, 1029, 0, 0, 39, '1028'),
	(243, 1, 0, -50939, 1030, 0, 0, 39, '1029'),
	(243, 1, 0, -50939, 1031, 0, 0, 39, '1030'),
	(243, 1, 0, -50939, 1032, 0, 0, 39, '1031'),
	(243, 1, 0, -50939, 1033, 0, 0, 39, '1032'),
	(243, 1, 0, -50939, 1034, 0, 0, 39, '1033'),
	(243, 1, 0, -50939, 1035, 0, 0, 39, '1034'),
	(243, 1, 0, -50939, 1036, 0, 0, 39, '1035'),
	(243, 1, 0, -50939, 1037, 0, 0, 39, '1036'),
	(243, 1, 0, -50939, 1038, 0, 0, 39, '1037'),
	(243, 1, 0, -50939, 1039, 0, 0, 39, '1038'),
	(243, 1, 0, -50939, 1040, 0, 0, 39, '1039'),
	(243, 1, 0, -50939, 1041, 0, 0, 39, '1040'),
	(243, 1, 0, -50939, 1042, 0, 0, 39, '1041'),
	(243, 1, 0, -50939, 1043, 0, 0, 39, '1042'),
	(243, 1, 0, -50939, 1044, 0, 0, 39, '1043'),
	(243, 1, 0, -50939, 1045, 0, 0, 39, '1044'),
	(243, 1, 0, -50939, 1046, 0, 0, 39, '1045'),
	(243, 1, 0, -50939, 1047, 0, 0, 39, '1046'),
	(243, 1, 0, -50939, 1048, 0, 0, 39, '1047'),
	(243, 1, 0, -50939, 1049, 0, 0, 39, '1048'),
	(243, 1, 0, -50939, 1050, 0, 0, 39, '1049'),
	(243, 1, 0, -50939, 1051, 0, 0, 39, '1050'),
	(243, 1, 0, -50939, 1052, 0, 0, 39, '1051'),
	(243, 1, 0, -50939, 1053, 0, 0, 39, '1052'),
	(243, 1, 0, -50939, 1054, 0, 0, 39, '1053'),
	(243, 1, 0, -50939, 1055, 0, 0, 39, '1054'),
	(243, 1, 0, -50939, 1056, 0, 0, 39, '1055'),
	(243, 1, 0, -50939, 1057, 0, 0, 39, '1056'),
	(243, 1, 0, -50939, 1058, 0, 0, 39, '1057'),
	(243, 1, 0, -50939, 1059, 0, 0, 39, '1058'),
	(243, 1, 0, -50939, 1060, 0, 0, 39, '1059'),
	(243, 1, 0, -50939, 1061, 0, 0, 39, '1060'),
	(243, 1, 0, -50939, 1062, 0, 0, 39, '1061'),
	(243, 1, 0, -50939, 1063, 0, 0, 39, '1062'),
	(243, 1, 0, -50939, 1064, 0, 0, 39, '1063'),
	(243, 1, 0, -50939, 1065, 0, 0, 39, '1064'),
	(243, 1, 0, -50939, 1066, 0, 0, 39, '1065'),
	(243, 1, 0, -50939, 1067, 0, 0, 39, '1066'),
	(243, 1, 0, -50939, 1068, 0, 0, 39, '1067'),
	(243, 1, 0, -50939, 1069, 0, 0, 39, '1068'),
	(243, 1, 0, -50939, 1070, 0, 0, 39, '1069'),
	(243, 1, 0, -50939, 1071, 0, 0, 39, '1070'),
	(243, 1, 0, -50939, 1072, 0, 0, 39, '1071'),
	(243, 1, 0, -50939, 1073, 0, 0, 39, '1072'),
	(243, 1, 0, -50939, 1074, 0, 0, 39, '1073'),
	(243, 1, 0, -50939, 1075, 0, 0, 39, '1074'),
	(243, 1, 0, -50939, 1076, 0, 0, 39, '1075'),
	(243, 1, 0, -50939, 1077, 0, 0, 39, '1076'),
	(243, 1, 0, -50939, 1078, 0, 0, 39, '1077'),
	(243, 1, 0, -50939, 1079, 0, 0, 39, '1078'),
	(243, 1, 0, -50939, 1080, 0, 0, 39, '1079'),
	(243, 1, 0, -50939, 1081, 0, 0, 39, '1080'),
	(243, 1, 0, -50939, 1082, 0, 0, 39, '1081'),
	(243, 1, 0, -50939, 1083, 0, 0, 39, '1082'),
	(243, 1, 0, -50939, 1084, 0, 0, 39, '1083'),
	(243, 1, 0, -50939, 1085, 0, 0, 39, '1084'),
	(243, 1, 0, -50939, 1086, 0, 0, 39, '1085'),
	(243, 1, 0, -50939, 1087, 0, 0, 39, '1086'),
	(243, 1, 0, -50939, 1088, 0, 0, 39, '1087'),
	(243, 1, 0, -50939, 1089, 0, 0, 39, '1088'),
	(243, 1, 0, -50939, 1090, 0, 0, 39, '1089'),
	(243, 1, 0, -50939, 1091, 0, 0, 39, '1090'),
	(243, 1, 0, -50939, 1092, 0, 0, 39, '1091'),
	(243, 1, 0, -50939, 1093, 0, 0, 39, '1092'),
	(243, 1, 0, -50939, 1094, 0, 0, 39, '1093'),
	(243, 1, 0, -50939, 1095, 0, 0, 39, '1094'),
	(243, 1, 0, -50939, 1096, 0, 0, 39, '1095'),
	(243, 1, 0, -50939, 1097, 0, 0, 39, '1096'),
	(243, 1, 0, -50939, 1098, 0, 0, 39, '1097'),
	(243, 1, 0, -50939, 1099, 0, 0, 39, '1098'),
	(243, 1, 0, -50939, 1100, 0, 0, 39, '1099'),
	(243, 1, 0, -50939, 1101, 0, 0, 39, '1100'),
	(243, 1, 0, -50939, 1102, 0, 0, 39, '1101'),
	(243, 1, 0, -50939, 1103, 0, 0, 39, '1102'),
	(243, 1, 0, -50939, 1104, 0, 0, 39, '1103'),
	(243, 1, 0, -50939, 1105, 0, 0, 39, '1104'),
	(243, 1, 0, -50939, 1106, 0, 0, 39, '1105'),
	(243, 1, 0, -50939, 1107, 0, 0, 39, '1106'),
	(243, 1, 0, -50939, 1108, 0, 0, 39, '1107'),
	(243, 1, 0, -50939, 1109, 0, 0, 39, '1108'),
	(243, 1, 0, -50939, 1110, 0, 0, 39, '1109'),
	(243, 1, 0, -50939, 1111, 0, 0, 39, '1110'),
	(243, 1, 0, -50939, 1112, 0, 0, 39, '1111'),
	(243, 1, 0, -50939, 1113, 0, 0, 39, '1112'),
	(243, 1, 0, -50939, 1114, 0, 0, 39, '1113'),
	(243, 1, 0, -50939, 1115, 0, 0, 39, '1114'),
	(243, 1, 0, -50939, 1116, 0, 0, 39, '1115'),
	(243, 1, 0, -50939, 1117, 0, 0, 39, '1116'),
	(243, 1, 0, -50939, 1118, 0, 0, 39, '1117'),
	(243, 1, 0, -50939, 1119, 0, 0, 39, '1118'),
	(243, 1, 0, -50939, 1120, 0, 0, 39, '1119'),
	(243, 1, 0, -50939, 1121, 0, 0, 39, '1120'),
	(243, 1, 0, -50939, 1122, 0, 0, 39, '1121'),
	(243, 1, 0, -50939, 1123, 0, 0, 39, '1122'),
	(243, 1, 0, -50939, 1124, 0, 0, 39, '1123'),
	(243, 1, 0, -50939, 1125, 0, 0, 39, '1124'),
	(243, 1, 0, -50939, 1126, 0, 0, 39, '1125'),
	(243, 1, 0, -50939, 1127, 0, 0, 39, '1126'),
	(243, 1, 0, -50939, 1128, 0, 0, 39, '1127'),
	(243, 1, 0, -50939, 1129, 0, 0, 39, '1128'),
	(243, 1, 0, -50939, 1130, 0, 0, 39, '1129'),
	(243, 1, 0, -50939, 1131, 0, 0, 39, '1130'),
	(243, 1, 0, -50939, 1132, 0, 0, 39, '1131'),
	(243, 1, 0, -50939, 1133, 0, 0, 39, '1132'),
	(243, 1, 0, -50939, 1134, 0, 0, 39, '1133'),
	(243, 1, 0, -50939, 1135, 0, 0, 39, '1134'),
	(243, 1, 0, -50939, 1136, 0, 0, 39, '1135'),
	(243, 1, 0, -50939, 1137, 0, 0, 39, '1136'),
	(243, 1, 0, -50939, 1138, 0, 0, 39, '1137'),
	(243, 1, 0, -50939, 1139, 0, 0, 39, '1138'),
	(243, 1, 0, -50939, 1140, 0, 0, 39, '1139'),
	(243, 1, 0, -50939, 1141, 0, 0, 39, '1140'),
	(243, 1, 0, -50939, 1142, 0, 0, 39, '1141'),
	(243, 1, 0, -50939, 1143, 0, 0, 39, '1142'),
	(243, 1, 0, -50939, 1144, 0, 0, 39, '1143'),
	(243, 1, 0, -50939, 1145, 0, 0, 39, '1144'),
	(243, 1, 0, -50939, 1146, 0, 0, 39, '1145'),
	(243, 1, 0, -50939, 1147, 0, 0, 39, '1146'),
	(243, 1, 0, -50939, 1148, 0, 0, 39, '1147'),
	(243, 1, 0, -50939, 1149, 0, 0, 39, '1148'),
	(243, 1, 0, -50939, 1150, 0, 0, 39, '1149'),
	(243, 1, 0, -50939, 1151, 0, 0, 39, '1150'),
	(243, 1, 0, -50939, 1152, 0, 0, 39, '1151'),
	(243, 1, 0, -50939, 1153, 0, 0, 39, '1152'),
	(243, 1, 0, -50939, 1154, 0, 0, 39, '1153'),
	(243, 1, 0, -50939, 1155, 0, 0, 39, '1154'),
	(243, 1, 0, -50939, 1156, 0, 0, 39, '1155'),
	(243, 1, 0, -50939, 1157, 0, 0, 39, '1156'),
	(243, 1, 0, -50939, 1158, 0, 0, 39, '1157'),
	(243, 1, 0, -50939, 1159, 0, 0, 39, '1158'),
	(243, 1, 0, -50939, 1160, 0, 0, 39, '1159'),
	(243, 1, 0, -50939, 1161, 0, 0, 39, '1160'),
	(243, 1, 0, -50939, 1162, 0, 0, 39, '1161'),
	(243, 1, 0, -50939, 1163, 0, 0, 39, '1162'),
	(243, 1, 0, -50939, 1164, 0, 0, 39, '1163'),
	(243, 1, 0, -50939, 1165, 0, 0, 39, '1164'),
	(243, 1, 0, -50939, 1166, 0, 0, 39, '1165'),
	(243, 1, 0, -50939, 1167, 0, 0, 39, '1166'),
	(243, 1, 0, -50939, 1168, 0, 0, 39, '1167'),
	(243, 1, 0, -50939, 1169, 0, 0, 39, '1168'),
	(243, 1, 0, -50939, 1170, 0, 0, 39, '1169'),
	(243, 1, 0, -50939, 1171, 0, 0, 39, '1170'),
	(243, 1, 0, -50939, 1172, 0, 0, 39, '1171'),
	(243, 1, 0, -50939, 1173, 0, 0, 39, '1172'),
	(243, 1, 0, -50939, 1174, 0, 0, 39, '1173'),
	(243, 1, 0, -50939, 1175, 0, 0, 39, '1174'),
	(243, 1, 0, -50939, 1176, 0, 0, 39, '1175'),
	(243, 1, 0, -50939, 1177, 0, 0, 39, '1176'),
	(243, 1, 0, -50939, 1178, 0, 0, 39, '1177'),
	(243, 1, 0, -50939, 1179, 0, 0, 39, '1178'),
	(243, 1, 0, -50939, 1180, 0, 0, 39, '1179'),
	(243, 1, 0, -50939, 1181, 0, 0, 39, '1180'),
	(243, 1, 0, -50939, 1182, 0, 0, 39, '1181'),
	(243, 1, 0, -50939, 1183, 0, 0, 39, '1182'),
	(243, 1, 0, -50939, 1184, 0, 0, 39, '1183'),
	(243, 1, 0, -50939, 1185, 0, 0, 39, '1184'),
	(243, 1, 0, -50939, 1186, 0, 0, 39, '1185'),
	(243, 1, 0, -50939, 1187, 0, 0, 39, '1186'),
	(243, 1, 0, -50939, 1188, 0, 0, 39, '1187'),
	(243, 1, 0, -50939, 1189, 0, 0, 39, '1188'),
	(243, 1, 0, -50939, 1190, 0, 0, 39, '1189'),
	(243, 1, 0, -50939, 1191, 0, 0, 39, '1190'),
	(243, 1, 0, -50939, 1192, 0, 0, 39, '1191'),
	(243, 1, 0, -50939, 1193, 0, 0, 39, '1192'),
	(243, 1, 0, -50939, 1194, 0, 0, 39, '1193'),
	(243, 1, 0, -50939, 1195, 0, 0, 39, '1194'),
	(243, 1, 0, -50939, 1196, 0, 0, 39, '1195'),
	(243, 1, 0, -50939, 1197, 0, 0, 39, '1196'),
	(243, 1, 0, -50939, 1198, 0, 0, 39, '1197'),
	(243, 1, 0, -50939, 1199, 0, 0, 39, '1198'),
	(243, 1, 0, -50939, 1200, 0, 0, 39, '1199'),
	(243, 1, 0, -50939, 1201, 0, 0, 39, '1200'),
	(243, 1, 0, -50939, 1202, 0, 0, 39, '1201'),
	(243, 1, 0, -50939, 1203, 0, 0, 39, '1202'),
	(243, 1, 0, -50939, 1204, 0, 0, 39, '1203'),
	(243, 1, 0, -50939, 1205, 0, 0, 39, '1204'),
	(243, 1, 0, -50939, 1206, 0, 0, 39, '1205'),
	(243, 1, 0, -50939, 1207, 0, 0, 39, '1206'),
	(243, 1, 0, -50939, 1208, 0, 0, 39, '1207'),
	(243, 1, 0, -50939, 1209, 0, 0, 39, '1208'),
	(243, 1, 0, -50939, 1210, 0, 0, 39, '1209'),
	(243, 1, 0, -50939, 1211, 0, 0, 39, '1210'),
	(243, 1, 0, -50939, 1212, 0, 0, 39, '1211'),
	(243, 1, 0, -50939, 1213, 0, 0, 39, '1212'),
	(243, 1, 0, -50939, 1214, 0, 0, 39, '1213'),
	(243, 1, 0, -50939, 1215, 0, 0, 39, '1214'),
	(243, 1, 0, -50939, 1216, 0, 0, 39, '1215'),
	(243, 1, 0, -50939, 1217, 0, 0, 39, '1216'),
	(243, 1, 0, -50939, 1218, 0, 0, 39, '1217'),
	(243, 1, 0, -50939, 1219, 0, 0, 39, '1218'),
	(243, 1, 0, -50939, 1220, 0, 0, 39, '1219'),
	(243, 1, 0, -50939, 1221, 0, 0, 39, '1220'),
	(243, 1, 0, -50939, 1222, 0, 0, 39, '1221'),
	(243, 1, 0, -50939, 1223, 0, 0, 39, '1222'),
	(243, 1, 0, -50939, 1224, 0, 0, 39, '1223'),
	(243, 1, 0, -50939, 1225, 0, 0, 39, '1224'),
	(243, 1, 0, -50939, 1226, 0, 0, 39, '1225'),
	(243, 1, 0, -50939, 1227, 0, 0, 39, '1226'),
	(243, 1, 0, -50939, 1228, 0, 0, 39, '1227'),
	(243, 1, 0, -50939, 1229, 0, 0, 39, '1228'),
	(243, 1, 0, -50939, 1230, 0, 0, 39, '1229'),
	(243, 1, 0, -50939, 1231, 0, 0, 39, '1230'),
	(243, 1, 0, -50939, 1232, 0, 0, 39, '1231'),
	(243, 1, 0, -50939, 1233, 0, 0, 39, '1232'),
	(243, 1, 0, -50939, 1234, 0, 0, 39, '1233'),
	(243, 1, 0, -50939, 1235, 0, 0, 39, '1234'),
	(243, 1, 0, -50939, 1236, 0, 0, 39, '1235'),
	(243, 1, 0, -50939, 1237, 0, 0, 39, '1236'),
	(243, 1, 0, -50939, 1238, 0, 0, 39, '1237'),
	(243, 1, 0, -50939, 1239, 0, 0, 39, '1238'),
	(243, 1, 0, -50939, 1240, 0, 0, 39, '1239'),
	(243, 1, 0, -50939, 1241, 0, 0, 39, '1240'),
	(243, 1, 0, -50939, 1242, 0, 0, 39, '1241'),
	(243, 1, 0, -50939, 1243, 0, 0, 39, '1242'),
	(243, 1, 0, -50939, 1244, 0, 0, 39, '1243'),
	(243, 1, 0, -50939, 1245, 0, 0, 39, '1244'),
	(243, 1, 0, -50939, 1246, 0, 0, 39, '1245'),
	(243, 1, 0, -50939, 1247, 0, 0, 39, '1246'),
	(243, 1, 0, -50939, 1248, 0, 0, 39, '1247'),
	(243, 1, 0, -50939, 1249, 0, 0, 39, '1248'),
	(243, 1, 0, -50939, 1250, 0, 0, 39, '1249'),
	(243, 1, 0, -50939, 1251, 0, 0, 39, '1250'),
	(243, 1, 0, -50939, 1252, 0, 0, 39, '1251'),
	(243, 1, 0, -50939, 1253, 0, 0, 39, '1252'),
	(243, 1, 0, -50939, 1254, 0, 0, 39, '1253'),
	(243, 1, 0, -50939, 1255, 0, 0, 39, '1254'),
	(243, 1, 0, -50939, 1256, 0, 0, 39, '1255'),
	(243, 1, 0, -50939, 1257, 0, 0, 39, '1256'),
	(243, 1, 0, -50939, 1258, 0, 0, 39, '1257'),
	(243, 1, 0, -50939, 1259, 0, 0, 39, '1258'),
	(243, 1, 0, -50939, 1260, 0, 0, 39, '1259'),
	(243, 1, 0, -50939, 1261, 0, 0, 39, '1260'),
	(243, 1, 0, -50939, 1262, 0, 0, 39, '1261'),
	(243, 1, 0, -50939, 1263, 0, 0, 39, '1262'),
	(243, 1, 0, -50939, 1264, 0, 0, 39, '1263'),
	(243, 1, 0, -50939, 1265, 0, 0, 39, '1264'),
	(243, 1, 0, -50939, 1266, 0, 0, 39, '1265'),
	(243, 1, 0, -50939, 1267, 0, 0, 39, '1266'),
	(243, 1, 0, -50939, 1268, 0, 0, 39, '1267'),
	(243, 1, 0, -50939, 1269, 0, 0, 39, '1268'),
	(243, 1, 0, -50939, 1270, 0, 0, 39, '1269'),
	(243, 1, 0, -50939, 1271, 0, 0, 39, '1270'),
	(243, 1, 0, -50939, 1272, 0, 0, 39, '1271'),
	(243, 1, 0, -50939, 1273, 0, 0, 39, '1272'),
	(243, 1, 0, -50939, 1274, 0, 0, 39, '1273'),
	(243, 1, 0, -50939, 1275, 0, 0, 39, '1274'),
	(243, 1, 0, -50939, 1276, 0, 0, 39, '1275'),
	(243, 1, 0, -50939, 1277, 0, 0, 39, '1276'),
	(243, 1, 0, -50939, 1278, 0, 0, 39, '1277'),
	(243, 1, 0, -50939, 1279, 0, 0, 39, '1278'),
	(243, 1, 0, -50939, 1280, 0, 0, 39, '1279'),
	(243, 1, 0, -50939, 1281, 0, 0, 39, '1280'),
	(243, 1, 0, -50939, 1282, 0, 0, 39, '1281'),
	(243, 1, 0, -50939, 1283, 0, 0, 39, '1282'),
	(243, 1, 0, -50939, 1284, 0, 0, 39, '1283'),
	(243, 1, 0, -50939, 1285, 0, 0, 39, '1284'),
	(243, 1, 0, -50939, 1286, 0, 0, 39, '1285'),
	(243, 1, 0, -50939, 1287, 0, 0, 39, '1286'),
	(243, 1, 0, -50939, 1288, 0, 0, 39, '1287'),
	(243, 1, 0, -50939, 1289, 0, 0, 39, '1288'),
	(243, 1, 0, -50939, 1290, 0, 0, 39, '1289'),
	(243, 1, 0, -50939, 1291, 0, 0, 39, '1290'),
	(243, 1, 0, -50939, 1292, 0, 0, 39, '1291'),
	(243, 1, 0, -50939, 1293, 0, 0, 39, '1292'),
	(243, 1, 0, -50939, 1294, 0, 0, 39, '1293'),
	(243, 1, 0, -50939, 1295, 0, 0, 39, '1294'),
	(243, 1, 0, -50939, 1296, 0, 0, 39, '1295'),
	(243, 1, 0, -50939, 1297, 0, 0, 39, '1296'),
	(243, 1, 0, -50939, 1298, 0, 0, 39, '1297'),
	(243, 1, 0, -50939, 1299, 0, 0, 39, '1298'),
	(243, 1, 0, -50939, 1300, 0, 0, 39, '1299'),
	(243, 1, 0, -50939, 1301, 0, 0, 39, '1300'),
	(243, 1, 0, -50939, 1302, 0, 0, 39, '1301'),
	(243, 1, 0, -50939, 1303, 0, 0, 39, '1302'),
	(243, 1, 0, -50939, 1304, 0, 0, 39, '1303'),
	(243, 1, 0, -50939, 1305, 0, 0, 39, '1304'),
	(243, 1, 0, -50939, 1306, 0, 0, 39, '1305'),
	(243, 1, 0, -50939, 1307, 0, 0, 39, '1306'),
	(243, 1, 0, -50939, 1308, 0, 0, 39, '1307'),
	(243, 1, 0, -50939, 1309, 0, 0, 39, '1308'),
	(243, 1, 0, -50939, 1310, 0, 0, 39, '1309'),
	(243, 1, 0, -50939, 1311, 0, 0, 39, '1310'),
	(243, 1, 0, -50939, 1312, 0, 0, 39, '1311'),
	(243, 1, 0, -50939, 1313, 0, 0, 39, '1312'),
	(243, 1, 0, -50939, 1314, 0, 0, 39, '1313'),
	(243, 1, 0, -50939, 1315, 0, 0, 39, '1314'),
	(243, 1, 0, -50939, 1316, 0, 0, 39, '1315'),
	(243, 1, 0, -50939, 1317, 0, 0, 39, '1316'),
	(243, 1, 0, -50939, 1318, 0, 0, 39, '1317'),
	(243, 1, 0, -50939, 1319, 0, 0, 39, '1318'),
	(243, 1, 0, -50939, 1320, 0, 0, 39, '1319'),
	(243, 1, 0, -50939, 1321, 0, 0, 39, '1320'),
	(243, 1, 0, -50939, 1322, 0, 0, 39, '1321'),
	(243, 1, 0, -50939, 1323, 0, 0, 39, '1322'),
	(243, 1, 0, -50939, 1324, 0, 0, 39, '1323'),
	(243, 1, 0, -50939, 1325, 0, 0, 39, '1324'),
	(243, 1, 0, -50939, 1326, 0, 0, 39, '1325'),
	(243, 1, 0, -50939, 1327, 0, 0, 39, '1326'),
	(243, 1, 0, -50939, 1328, 0, 0, 39, '1327'),
	(243, 1, 0, -50939, 1329, 0, 0, 39, '1328'),
	(243, 1, 0, -50939, 1330, 0, 0, 39, '1329'),
	(243, 1, 0, -50939, 1331, 0, 0, 39, '1330'),
	(243, 1, 0, -50939, 1332, 0, 0, 39, '1331'),
	(243, 1, 0, -50939, 1333, 0, 0, 39, '1332'),
	(243, 1, 0, -50939, 1334, 0, 0, 39, '1333'),
	(243, 1, 0, -50939, 1335, 0, 0, 39, '1334'),
	(243, 1, 0, -50939, 1336, 0, 0, 39, '1335'),
	(243, 1, 0, -50939, 1337, 0, 0, 39, '1336'),
	(243, 1, 0, -50939, 1338, 0, 0, 39, '1337'),
	(243, 1, 0, -50939, 1339, 0, 0, 39, '1338'),
	(243, 1, 0, -50939, 1340, 0, 0, 39, '1339'),
	(243, 1, 0, -50939, 1341, 0, 0, 39, '1340'),
	(243, 1, 0, -50939, 1342, 0, 0, 39, '1341'),
	(243, 1, 0, -50939, 1343, 0, 0, 39, '1342'),
	(243, 1, 0, -50939, 1344, 0, 0, 39, '1343'),
	(243, 1, 0, -50939, 1345, 0, 0, 39, '1344'),
	(243, 1, 0, -50939, 1346, 0, 0, 39, '1345'),
	(243, 1, 0, -50939, 1347, 0, 0, 39, '1346'),
	(243, 1, 0, -50939, 1348, 0, 0, 39, '1347'),
	(243, 1, 0, -50939, 1349, 0, 0, 39, '1348'),
	(243, 1, 0, -50939, 1350, 0, 0, 39, '1349'),
	(243, 1, 0, -50939, 1351, 0, 0, 39, '1350'),
	(243, 1, 0, -50939, 1352, 0, 0, 39, '1351'),
	(243, 1, 0, -50939, 1353, 0, 0, 39, '1352'),
	(243, 1, 0, -50939, 1354, 0, 0, 39, '1353'),
	(243, 1, 0, -50939, 1355, 0, 0, 39, '1354'),
	(243, 1, 0, -50939, 1356, 0, 0, 39, '1355'),
	(243, 1, 0, -50939, 1357, 0, 0, 39, '1356'),
	(243, 1, 0, -50939, 1358, 0, 0, 39, '1357'),
	(243, 1, 0, -50939, 1359, 0, 0, 39, '1358'),
	(243, 1, 0, -50939, 1360, 0, 0, 39, '1359'),
	(243, 1, 0, -50939, 1361, 0, 0, 39, '1360'),
	(243, 1, 0, -50939, 1362, 0, 0, 39, '1361'),
	(243, 1, 0, -50939, 1363, 0, 0, 39, '1362'),
	(243, 1, 0, -50939, 1364, 0, 0, 39, '1363'),
	(243, 1, 0, -50939, 1365, 0, 0, 39, '1364'),
	(243, 1, 0, -50939, 1366, 0, 0, 39, '1365'),
	(243, 1, 0, -50939, 1367, 0, 0, 39, '1366'),
	(243, 1, 0, -50939, 1368, 0, 0, 39, '1367'),
	(243, 1, 0, -50939, 1369, 0, 0, 39, '1368'),
	(243, 1, 0, -50939, 1370, 0, 0, 39, '1369'),
	(243, 1, 0, -50939, 1371, 0, 0, 39, '1370'),
	(243, 1, 0, -50939, 1372, 0, 0, 39, '1371'),
	(243, 1, 0, -50939, 1373, 0, 0, 39, '1372'),
	(243, 1, 0, -50939, 1374, 0, 0, 39, '1373'),
	(243, 1, 0, -50939, 1375, 0, 0, 39, '1374'),
	(243, 1, 0, -50939, 1376, 0, 0, 39, '1375'),
	(243, 1, 0, -50939, 1377, 0, 0, 39, '1376'),
	(243, 1, 0, -50939, 1378, 0, 0, 39, '1377'),
	(243, 1, 0, -50939, 1379, 0, 0, 39, '1378'),
	(243, 1, 0, -50939, 1380, 0, 0, 39, '1379'),
	(243, 1, 0, -50939, 1381, 0, 0, 39, '1380'),
	(243, 1, 0, -50939, 1382, 0, 0, 39, '1381'),
	(243, 1, 0, -50939, 1383, 0, 0, 39, '1382'),
	(243, 1, 0, -50939, 1384, 0, 0, 39, '1383'),
	(243, 1, 0, -50939, 1385, 0, 0, 39, '1384'),
	(243, 1, 0, -50939, 1386, 0, 0, 39, '1385'),
	(243, 1, 0, -50939, 1387, 0, 0, 39, '1386'),
	(243, 1, 0, -50939, 1388, 0, 0, 39, '1387'),
	(243, 1, 0, -50939, 1389, 0, 0, 39, '1388'),
	(243, 1, 0, -50939, 1390, 0, 0, 39, '1389'),
	(243, 1, 0, -50939, 1391, 0, 0, 39, '1390'),
	(243, 1, 0, -50939, 1392, 0, 0, 39, '1391'),
	(243, 1, 0, -50939, 1393, 0, 0, 39, '1392'),
	(243, 1, 0, -50939, 1394, 0, 0, 39, '1393'),
	(243, 1, 0, -50939, 1395, 0, 0, 39, '1394'),
	(243, 1, 0, -50939, 1396, 0, 0, 39, '1395'),
	(243, 1, 0, -50939, 1397, 0, 0, 39, '1396'),
	(243, 1, 0, -50939, 1398, 0, 0, 39, '1397'),
	(243, 1, 0, -50939, 1399, 0, 0, 39, '1398'),
	(243, 1, 0, -50939, 1400, 0, 0, 39, '1399'),
	(243, 1, 0, -50939, 1401, 0, 0, 39, '1400'),
	(243, 1, 0, -50939, 1402, 0, 0, 39, '1401'),
	(243, 1, 0, -50939, 1403, 0, 0, 39, '1402'),
	(243, 1, 0, -50939, 1404, 0, 0, 39, '1403'),
	(243, 1, 0, -50939, 1405, 0, 0, 39, '1404'),
	(243, 1, 0, -50939, 1406, 0, 0, 39, '1405'),
	(243, 1, 0, -50939, 1407, 0, 0, 39, '1406'),
	(243, 1, 0, -50939, 1408, 0, 0, 39, '1407'),
	(243, 1, 0, -50939, 1409, 0, 0, 39, '1408'),
	(243, 1, 0, -50939, 1410, 0, 0, 39, '1409'),
	(243, 1, 0, -50939, 1411, 0, 0, 39, '1410'),
	(243, 1, 0, -50939, 1412, 0, 0, 39, '1411'),
	(243, 1, 0, -50939, 1413, 0, 0, 39, '1412'),
	(243, 1, 0, -50939, 1414, 0, 0, 39, '1413'),
	(243, 1, 0, -50939, 1415, 0, 0, 39, '1414'),
	(243, 1, 0, -50939, 1416, 0, 0, 39, '1415'),
	(243, 1, 0, -50939, 1417, 0, 0, 39, '1416'),
	(243, 1, 0, -50939, 1418, 0, 0, 39, '1417'),
	(243, 1, 0, -50939, 1419, 0, 0, 39, '1418'),
	(243, 1, 0, -50939, 1420, 0, 0, 39, '1419'),
	(243, 1, 0, -50939, 1421, 0, 0, 39, '1420'),
	(243, 1, 0, -50939, 1422, 0, 0, 39, '1421'),
	(243, 1, 0, -50939, 1423, 0, 0, 39, '1422'),
	(243, 1, 0, -50939, 1424, 0, 0, 39, '1423'),
	(243, 1, 0, -50939, 1425, 0, 0, 39, '1424'),
	(243, 1, 0, -50939, 1426, 0, 0, 39, '1425'),
	(243, 1, 0, -50939, 1427, 0, 0, 39, '1426'),
	(243, 1, 0, -50939, 1428, 0, 0, 39, '1427'),
	(243, 1, 0, -50939, 1429, 0, 0, 39, '1428'),
	(243, 1, 0, -50939, 1430, 0, 0, 39, '1429'),
	(243, 1, 0, -50939, 1431, 0, 0, 39, '1430'),
	(243, 1, 0, -50939, 1432, 0, 0, 39, '1431'),
	(243, 1, 0, -50939, 1433, 0, 0, 39, '1432'),
	(243, 1, 0, -50939, 1434, 0, 0, 39, '1433'),
	(243, 1, 0, -50939, 1435, 0, 0, 39, '1434'),
	(243, 1, 0, -50939, 1436, 0, 0, 39, '1435'),
	(243, 1, 0, -50939, 1437, 0, 0, 39, '1436'),
	(243, 1, 0, -50939, 1438, 0, 0, 39, '1437'),
	(243, 1, 0, -50939, 1439, 0, 0, 39, '1438'),
	(243, 1, 0, -50939, 1440, 0, 0, 39, '1439'),
	(243, 1, 0, -50939, 1441, 0, 0, 39, '1440'),
	(243, 1, 0, -50939, 1442, 0, 0, 39, '1441'),
	(243, 1, 0, -50939, 1443, 0, 0, 39, '1442'),
	(243, 1, 0, -50939, 1444, 0, 0, 39, '1443'),
	(243, 1, 0, -50939, 1445, 0, 0, 39, '1444'),
	(243, 1, 0, -50939, 1446, 0, 0, 39, '1445'),
	(243, 1, 0, -50939, 1447, 0, 0, 39, '1446'),
	(243, 1, 0, -50939, 1448, 0, 0, 39, '1447'),
	(243, 1, 0, -50939, 1449, 0, 0, 39, '1448'),
	(243, 1, 0, -50939, 1450, 0, 0, 39, '1449'),
	(243, 1, 0, -50939, 1451, 0, 0, 39, '1450'),
	(243, 1, 0, -50939, 1452, 0, 0, 39, '1451'),
	(243, 1, 0, -50939, 1453, 0, 0, 39, '1452'),
	(243, 1, 0, -50939, 1454, 0, 0, 39, '1453'),
	(243, 1, 0, -50939, 1455, 0, 0, 39, '1454'),
	(243, 1, 0, -50939, 1456, 0, 0, 39, '1455'),
	(243, 1, 0, -50939, 1457, 0, 0, 39, '1456'),
	(243, 1, 0, -50939, 1458, 0, 0, 39, '1457'),
	(243, 1, 0, -50939, 1459, 0, 0, 39, '1458'),
	(243, 1, 0, -50939, 1460, 0, 0, 39, '1459'),
	(243, 1, 0, -50939, 1461, 0, 0, 39, '1460'),
	(243, 1, 0, -50939, 1462, 0, 0, 39, '1461'),
	(243, 1, 0, -50939, 1463, 0, 0, 39, '1462'),
	(243, 1, 0, -50939, 1464, 0, 0, 39, '1463'),
	(243, 1, 0, -50939, 1465, 0, 0, 39, '1464'),
	(243, 1, 0, -50939, 1466, 0, 0, 39, '1465'),
	(243, 1, 0, -50939, 1467, 0, 0, 39, '1466'),
	(243, 1, 0, -50939, 1468, 0, 0, 39, '1467'),
	(243, 1, 0, -50939, 1469, 0, 0, 39, '1468'),
	(243, 1, 0, -50939, 1470, 0, 0, 39, '1469'),
	(243, 1, 0, -50939, 1471, 0, 0, 39, '1470'),
	(243, 1, 0, -50939, 1472, 0, 0, 39, '1471'),
	(243, 1, 0, -50939, 1473, 0, 0, 39, '1472'),
	(243, 1, 0, -50939, 1474, 0, 0, 39, '1473'),
	(243, 1, 0, -50939, 1475, 0, 0, 39, '1474'),
	(243, 1, 0, -50939, 1476, 0, 0, 39, '1475'),
	(243, 1, 0, -50939, 1477, 0, 0, 39, '1476'),
	(243, 1, 0, -50939, 1478, 0, 0, 39, '1477'),
	(243, 1, 0, -50939, 1479, 0, 0, 39, '1478'),
	(243, 1, 0, -50939, 1480, 0, 0, 39, '1479'),
	(243, 1, 0, -50939, 1481, 0, 0, 39, '1480'),
	(243, 1, 0, -50939, 1482, 0, 0, 39, '1481'),
	(243, 1, 0, -50939, 1483, 0, 0, 39, '1482'),
	(243, 1, 0, -50939, 1484, 0, 0, 39, '1483'),
	(243, 1, 0, -50939, 1485, 0, 0, 39, '1484'),
	(243, 1, 0, -50939, 1486, 0, 0, 39, '1485'),
	(243, 1, 0, -50939, 1487, 0, 0, 39, '1486'),
	(243, 1, 0, -50939, 1488, 0, 0, 39, '1487'),
	(243, 1, 0, -50939, 1489, 0, 0, 39, '1488'),
	(243, 1, 0, -50939, 1490, 0, 0, 39, '1489'),
	(243, 1, 0, -50939, 1491, 0, 0, 39, '1490'),
	(243, 1, 0, -50939, 1492, 0, 0, 39, '1491'),
	(243, 1, 0, -50939, 1493, 0, 0, 39, '1492'),
	(243, 1, 0, -50939, 1494, 0, 0, 39, '1493'),
	(243, 1, 0, -50939, 1495, 0, 0, 39, '1494'),
	(243, 1, 0, -50939, 1496, 0, 0, 39, '1495'),
	(243, 1, 0, -50939, 1497, 0, 0, 39, '1496'),
	(243, 1, 0, -50939, 1498, 0, 0, 39, '1497'),
	(243, 1, 0, -50939, 1499, 0, 0, 39, '1498'),
	(243, 1, 0, -50939, 1500, 0, 0, 39, '1499'),
	(243, 1, 0, -50939, 1501, 0, 0, 39, '1500'),
	(243, 1, 0, -50939, 1502, 0, 0, 39, '1501'),
	(243, 1, 0, -50939, 1503, 0, 0, 39, '1502'),
	(243, 1, 0, -50939, 1504, 0, 0, 39, '1503'),
	(243, 1, 0, -50939, 1505, 0, 0, 39, '1504'),
	(243, 1, 0, -50939, 1506, 0, 0, 39, '1505'),
	(243, 1, 0, -50939, 1507, 0, 0, 39, '1506'),
	(243, 1, 0, -50939, 1508, 0, 0, 39, '1507'),
	(243, 1, 0, -50939, 1509, 0, 0, 39, '1508'),
	(243, 1, 0, -50939, 1510, 0, 0, 39, '1509'),
	(243, 1, 0, -50939, 1511, 0, 0, 39, '1510'),
	(243, 1, 0, -50939, 1512, 0, 0, 39, '1511'),
	(243, 1, 0, -50939, 1513, 0, 0, 39, '1512'),
	(243, 1, 0, -50939, 1514, 0, 0, 39, '1513'),
	(243, 1, 0, -50939, 1515, 0, 0, 39, '1514'),
	(243, 1, 0, -50939, 1516, 0, 0, 39, '1515'),
	(243, 1, 0, -50939, 1517, 0, 0, 39, '1516'),
	(243, 1, 0, -50939, 1518, 0, 0, 39, '1517'),
	(243, 1, 0, -50939, 1519, 0, 0, 39, '1518'),
	(243, 1, 0, -50939, 1520, 0, 0, 39, '1519'),
	(243, 1, 0, -50939, 1521, 0, 0, 39, '1520'),
	(243, 1, 0, -50939, 1522, 0, 0, 39, '1521'),
	(243, 1, 0, -50939, 1523, 0, 0, 39, '1522'),
	(243, 1, 0, -50939, 1524, 0, 0, 39, '1523'),
	(243, 1, 0, -50939, 1525, 0, 0, 39, '1524'),
	(243, 1, 0, -50939, 1526, 0, 0, 39, '1525'),
	(243, 1, 0, -50939, 1527, 0, 0, 39, '1526'),
	(243, 1, 0, -50939, 1528, 0, 0, 39, '1527'),
	(243, 1, 0, -50939, 1529, 0, 0, 39, '1528'),
	(243, 1, 0, -50939, 1530, 0, 0, 39, '1529'),
	(243, 1, 0, -50939, 1531, 0, 0, 39, '1530'),
	(243, 1, 0, -50939, 1532, 0, 0, 39, '1531'),
	(243, 1, 0, -50939, 1533, 0, 0, 39, '1532'),
	(243, 1, 0, -50939, 1534, 0, 0, 39, '1533'),
	(243, 1, 0, -50939, 1535, 0, 0, 39, '1534'),
	(243, 1, 0, -50939, 1536, 0, 0, 39, '1535'),
	(243, 1, 0, -50939, 1537, 0, 0, 39, '1536'),
	(243, 1, 0, -50939, 1538, 0, 0, 39, '1537'),
	(243, 1, 0, -50939, 1539, 0, 0, 39, '1538'),
	(243, 1, 0, -50939, 1540, 0, 0, 39, '1539'),
	(243, 1, 0, -50939, 1541, 0, 0, 39, '1540'),
	(243, 1, 0, -50939, 1542, 0, 0, 39, '1541'),
	(243, 1, 0, -50939, 1543, 0, 0, 39, '1542'),
	(243, 1, 0, -50939, 1544, 0, 0, 39, '1543'),
	(243, 1, 0, -50939, 1545, 0, 0, 39, '1544'),
	(243, 1, 0, -50939, 1546, 0, 0, 39, '1545'),
	(243, 1, 0, -50939, 1547, 0, 0, 39, '1546'),
	(243, 1, 0, -50939, 1548, 0, 0, 39, '1547'),
	(243, 1, 0, -50939, 1549, 0, 0, 39, '1548'),
	(243, 1, 0, -50939, 1550, 0, 0, 39, '1549'),
	(243, 1, 0, -50939, 1551, 0, 0, 39, '1550'),
	(243, 1, 0, -50939, 1552, 0, 0, 39, '1551'),
	(243, 1, 0, -50939, 1553, 0, 0, 39, '1552'),
	(243, 1, 0, -50939, 1554, 0, 0, 39, '1553'),
	(243, 1, 0, -50939, 1555, 0, 0, 39, '1554'),
	(243, 1, 0, -50939, 1556, 0, 0, 39, '1555'),
	(243, 1, 0, -50939, 1557, 0, 0, 39, '1556'),
	(243, 1, 0, -50939, 1558, 0, 0, 39, '1557'),
	(243, 1, 0, -50939, 1559, 0, 0, 39, '1558'),
	(243, 1, 0, -50939, 1560, 0, 0, 39, '1559'),
	(243, 1, 0, -50939, 1561, 0, 0, 39, '1560'),
	(243, 1, 0, -50939, 1562, 0, 0, 39, '1561'),
	(243, 1, 0, -50939, 1563, 0, 0, 39, '1562'),
	(243, 1, 0, -50939, 1564, 0, 0, 39, '1563'),
	(243, 1, 0, -50939, 1565, 0, 0, 39, '1564'),
	(243, 1, 0, -50939, 1566, 0, 0, 39, '1565'),
	(243, 1, 0, -50939, 1567, 0, 0, 39, '1566'),
	(243, 1, 0, -50939, 1568, 0, 0, 39, '1567'),
	(243, 1, 0, -50939, 1569, 0, 0, 39, '1568'),
	(243, 1, 0, -50939, 1570, 0, 0, 39, '1569'),
	(243, 1, 0, -50939, 1571, 0, 0, 39, '1570'),
	(243, 1, 0, -50939, 1572, 0, 0, 39, '1571'),
	(243, 1, 0, -50939, 1573, 0, 0, 39, '1572'),
	(243, 1, 0, -50939, 1574, 0, 0, 39, '1573'),
	(243, 1, 0, -50939, 1575, 0, 0, 39, '1574'),
	(243, 1, 0, -50939, 1576, 0, 0, 39, '1575'),
	(243, 1, 0, -50939, 1577, 0, 0, 39, '1576'),
	(243, 1, 0, -50939, 1578, 0, 0, 39, '1577'),
	(243, 1, 0, -50939, 1579, 0, 0, 39, '1578'),
	(243, 1, 0, -50939, 1580, 0, 0, 39, '1579'),
	(243, 1, 0, -50939, 1581, 0, 0, 39, '1580'),
	(243, 1, 0, -50939, 1582, 0, 0, 39, '1581'),
	(243, 1, 0, -50939, 1583, 0, 0, 39, '1582'),
	(243, 1, 0, -50939, 1584, 0, 0, 39, '1583'),
	(243, 1, 0, -50939, 1585, 0, 0, 39, '1584'),
	(243, 1, 0, -50939, 1586, 0, 0, 39, '1585'),
	(243, 1, 0, -50939, 1587, 0, 0, 39, '1586'),
	(243, 1, 0, -50939, 1588, 0, 0, 39, '1587'),
	(243, 1, 0, -50939, 1589, 0, 0, 39, '1588'),
	(243, 1, 0, -50939, 1590, 0, 0, 39, '1589'),
	(243, 1, 0, -50939, 1591, 0, 0, 39, '1590'),
	(243, 1, 0, -50939, 1592, 0, 0, 39, '1591'),
	(243, 1, 0, -50939, 1593, 0, 0, 39, '1592'),
	(243, 1, 0, -50939, 1594, 0, 0, 39, '1593'),
	(243, 1, 0, -50939, 1595, 0, 0, 39, '1594'),
	(243, 1, 0, -50939, 1596, 0, 0, 39, '1595'),
	(243, 1, 0, -50939, 1597, 0, 0, 39, '1596'),
	(243, 1, 0, -50939, 1598, 0, 0, 39, '1597'),
	(243, 1, 0, -50939, 1599, 0, 0, 39, '1598'),
	(243, 1, 0, -50939, 1600, 0, 0, 39, '1599'),
	(243, 1, 0, -50939, 1601, 0, 0, 39, '1600'),
	(243, 1, 0, -50939, 1602, 0, 0, 39, '1601'),
	(243, 1, 0, -50939, 1603, 0, 0, 39, '1602'),
	(243, 1, 0, -50939, 1604, 0, 0, 39, '1603'),
	(243, 1, 0, -50939, 1605, 0, 0, 39, '1604'),
	(243, 1, 0, -50939, 1606, 0, 0, 39, '1605'),
	(243, 1, 0, -50939, 1607, 0, 0, 39, '1606'),
	(243, 1, 0, -50939, 1608, 0, 0, 39, '1607'),
	(243, 1, 0, -50939, 1609, 0, 0, 39, '1608'),
	(243, 1, 0, -50939, 1610, 0, 0, 39, '1609'),
	(243, 1, 0, -50939, 1611, 0, 0, 39, '1610'),
	(243, 1, 0, -50939, 1612, 0, 0, 39, '1611'),
	(243, 1, 0, -50939, 1613, 0, 0, 39, '1612'),
	(243, 1, 0, -50939, 1614, 0, 0, 39, '1613'),
	(243, 1, 0, -50939, 1615, 0, 0, 39, '1614'),
	(243, 1, 0, -50939, 1616, 0, 0, 39, '1615'),
	(243, 1, 0, -50939, 1617, 0, 0, 39, '1616'),
	(243, 1, 0, -50939, 1618, 0, 0, 39, '1617'),
	(243, 1, 0, -50939, 1619, 0, 0, 39, '1618'),
	(243, 1, 0, -50939, 1620, 0, 0, 39, '1619'),
	(243, 1, 0, -50939, 1621, 0, 0, 39, '1620'),
	(243, 1, 0, -50939, 1622, 0, 0, 39, '1621'),
	(243, 1, 0, -50939, 1623, 0, 0, 39, '1622'),
	(243, 1, 0, -50939, 1624, 0, 0, 39, '1623'),
	(243, 1, 0, -50939, 1625, 0, 0, 39, '1624'),
	(243, 1, 0, -50939, 1626, 0, 0, 39, '1625'),
	(243, 1, 0, -50939, 1627, 0, 0, 39, '1626'),
	(243, 1, 0, -50939, 1628, 0, 0, 39, '1627'),
	(243, 1, 0, -50939, 1629, 0, 0, 39, '1628'),
	(243, 1, 0, -50939, 1630, 0, 0, 39, '1629'),
	(243, 1, 0, -50939, 1631, 0, 0, 39, '1630'),
	(243, 1, 0, -50939, 1632, 0, 0, 39, '1631'),
	(243, 1, 0, -50939, 1633, 0, 0, 39, '1632'),
	(243, 1, 0, -50939, 1634, 0, 0, 39, '1633'),
	(243, 1, 0, -50939, 1635, 0, 0, 39, '1634'),
	(243, 1, 0, -50939, 1636, 0, 0, 39, '1635'),
	(243, 1, 0, -50939, 1637, 0, 0, 39, '1636'),
	(243, 1, 0, -50939, 1638, 0, 0, 39, '1637'),
	(243, 1, 0, -50939, 1639, 0, 0, 39, '1638'),
	(243, 1, 0, -50939, 1640, 0, 0, 39, '1639'),
	(243, 1, 0, -50939, 1641, 0, 0, 39, '1640'),
	(243, 1, 0, -50939, 1642, 0, 0, 39, '1641'),
	(243, 1, 0, -50939, 1643, 0, 0, 39, '1642'),
	(243, 1, 0, -50939, 1644, 0, 0, 39, '1643'),
	(243, 1, 0, -50939, 1645, 0, 0, 39, '1644'),
	(243, 1, 0, -50939, 1646, 0, 0, 39, '1645'),
	(243, 1, 0, -50939, 1647, 0, 0, 39, '1646'),
	(243, 1, 0, -50939, 1648, 0, 0, 39, '1647'),
	(243, 1, 0, -50939, 1649, 0, 0, 39, '1648'),
	(243, 1, 0, -50939, 1650, 0, 0, 39, '1649'),
	(243, 1, 0, -50939, 1651, 0, 0, 39, '1650'),
	(243, 1, 0, -50939, 1652, 0, 0, 39, '1651'),
	(243, 1, 0, -50939, 1653, 0, 0, 39, '1652'),
	(243, 1, 0, -50939, 1654, 0, 0, 39, '1653'),
	(243, 1, 0, -50939, 1655, 0, 0, 39, '1654'),
	(243, 1, 0, -50939, 1656, 0, 0, 39, '1655'),
	(243, 1, 0, -50939, 1657, 0, 0, 39, '1656'),
	(243, 1, 0, -50939, 1658, 0, 0, 39, '1657'),
	(243, 1, 0, -50939, 1659, 0, 0, 39, '1658'),
	(243, 1, 0, -50939, 1660, 0, 0, 39, '1659'),
	(243, 1, 0, -50939, 1661, 0, 0, 39, '1660'),
	(243, 1, 0, -50939, 1662, 0, 0, 39, '1661'),
	(243, 1, 0, -50939, 1663, 0, 0, 39, '1662'),
	(243, 1, 0, -50939, 1664, 0, 0, 39, '1663'),
	(243, 1, 0, -50939, 1665, 0, 0, 39, '1664'),
	(243, 1, 0, -50939, 1666, 0, 0, 39, '1665'),
	(243, 1, 0, -50939, 1667, 0, 0, 39, '1666'),
	(243, 1, 0, -50939, 1668, 0, 0, 39, '1667'),
	(243, 1, 0, -50939, 1669, 0, 0, 39, '1668'),
	(243, 1, 0, -50939, 1670, 0, 0, 39, '1669'),
	(243, 1, 0, -50939, 1671, 0, 0, 39, '1670'),
	(243, 1, 0, -50939, 1672, 0, 0, 39, '1671'),
	(243, 1, 0, -50939, 1673, 0, 0, 39, '1672'),
	(243, 1, 0, -50939, 1674, 0, 0, 39, '1673'),
	(243, 1, 0, -50939, 1675, 0, 0, 39, '1674'),
	(243, 1, 0, -50939, 1676, 0, 0, 39, '1675'),
	(243, 1, 0, -50939, 1677, 0, 0, 39, '1676'),
	(243, 1, 0, -50939, 1678, 0, 0, 39, '1677'),
	(243, 1, 0, -50939, 1679, 0, 0, 39, '1678'),
	(243, 1, 0, -50939, 1680, 0, 0, 39, '1679'),
	(243, 1, 0, -50939, 1681, 0, 0, 39, '1680'),
	(243, 1, 0, -50939, 1682, 0, 0, 39, '1681'),
	(243, 1, 0, -50939, 1683, 0, 0, 39, '1682'),
	(243, 1, 0, -50939, 1684, 0, 0, 39, '1683'),
	(243, 1, 0, -50939, 1685, 0, 0, 39, '1684'),
	(243, 1, 0, -50939, 1686, 0, 0, 39, '1685'),
	(243, 1, 0, -50939, 1687, 0, 0, 39, '1686'),
	(243, 1, 0, -50939, 1688, 0, 0, 39, '1687'),
	(243, 1, 0, -50939, 1689, 0, 0, 39, '1688'),
	(243, 1, 0, -50939, 1690, 0, 0, 39, '1689'),
	(243, 1, 0, -50939, 1691, 0, 0, 39, '1690'),
	(243, 1, 0, -50939, 1692, 0, 0, 39, '1691'),
	(243, 1, 0, -50939, 1693, 0, 0, 39, '1692'),
	(243, 1, 0, -50939, 1694, 0, 0, 39, '1693'),
	(243, 1, 0, -50939, 1695, 0, 0, 39, '1694'),
	(243, 1, 0, -50939, 1696, 0, 0, 39, '1695'),
	(243, 1, 0, -50939, 1697, 0, 0, 39, '1696'),
	(243, 1, 0, -50939, 1698, 0, 0, 39, '1697'),
	(243, 1, 0, -50939, 1699, 0, 0, 39, '1698'),
	(243, 1, 0, -50939, 1700, 0, 0, 39, '1699'),
	(243, 1, 0, -50939, 1701, 0, 0, 39, '1700'),
	(243, 1, 0, -50939, 1702, 0, 0, 39, '1701'),
	(243, 1, 0, -50939, 1703, 0, 0, 39, '1702'),
	(243, 1, 0, -50939, 1704, 0, 0, 39, '1703'),
	(243, 1, 0, -50939, 1705, 0, 0, 39, '1704'),
	(243, 1, 0, -50939, 1706, 0, 0, 39, '1705'),
	(243, 1, 0, -50939, 1707, 0, 0, 39, '1706'),
	(243, 1, 0, -50939, 1708, 0, 0, 39, '1707'),
	(243, 1, 0, -50939, 1709, 0, 0, 39, '1708'),
	(243, 1, 0, -50939, 1710, 0, 0, 39, '1709'),
	(243, 1, 0, -50939, 1711, 0, 0, 39, '1710'),
	(243, 1, 0, -50939, 1712, 0, 0, 39, '1711'),
	(243, 1, 0, -50939, 1713, 0, 0, 39, '1712'),
	(243, 1, 0, -50939, 1714, 0, 0, 39, '1713'),
	(243, 1, 0, -50939, 1715, 0, 0, 39, '1714'),
	(243, 1, 0, -50939, 1716, 0, 0, 39, '1715'),
	(243, 1, 0, -50939, 1717, 0, 0, 39, '1716'),
	(243, 1, 0, -50939, 1718, 0, 0, 39, '1717'),
	(243, 1, 0, -50939, 1719, 0, 0, 39, '1718'),
	(243, 1, 0, -50939, 1720, 0, 0, 39, '1719'),
	(243, 1, 0, -50939, 1721, 0, 0, 39, '1720'),
	(243, 1, 0, -50939, 1722, 0, 0, 39, '1721'),
	(243, 1, 0, -50939, 1723, 0, 0, 39, '1722'),
	(243, 1, 0, -50939, 1724, 0, 0, 39, '1723'),
	(243, 1, 0, -50939, 1725, 0, 0, 39, '1724'),
	(243, 1, 0, -50939, 1726, 0, 0, 39, '1725'),
	(243, 1, 0, -50939, 1727, 0, 0, 39, '1726'),
	(243, 1, 0, -50939, 1728, 0, 0, 39, '1727'),
	(243, 1, 0, -50939, 1729, 0, 0, 39, '1728'),
	(243, 1, 0, -50939, 1730, 0, 0, 39, '1729'),
	(243, 1, 0, -50939, 1731, 0, 0, 39, '1730'),
	(243, 1, 0, -50939, 1732, 0, 0, 39, '1731'),
	(243, 1, 0, -50939, 1733, 0, 0, 39, '1732'),
	(243, 1, 0, -50939, 1734, 0, 0, 39, '1733'),
	(243, 1, 0, -50939, 1735, 0, 0, 39, '1734'),
	(243, 1, 0, -50939, 1736, 0, 0, 39, '1735'),
	(243, 1, 0, -50939, 1737, 0, 0, 39, '1736'),
	(243, 1, 0, -50939, 1738, 0, 0, 39, '1737'),
	(243, 1, 0, -50939, 1739, 0, 0, 39, '1738'),
	(243, 1, 0, -50939, 1740, 0, 0, 39, '1739'),
	(243, 1, 0, -50939, 1741, 0, 0, 39, '1740'),
	(243, 1, 0, -50939, 1742, 0, 0, 39, '1741'),
	(243, 1, 0, -50939, 1743, 0, 0, 39, '1742'),
	(243, 1, 0, -50939, 1744, 0, 0, 39, '1743'),
	(243, 1, 0, -50939, 1745, 0, 0, 39, '1744'),
	(243, 1, 0, -50939, 1746, 0, 0, 39, '1745'),
	(243, 1, 0, -50939, 1747, 0, 0, 39, '1746'),
	(243, 1, 0, -50939, 1748, 0, 0, 39, '1747'),
	(243, 1, 0, -50939, 1749, 0, 0, 39, '1748'),
	(243, 1, 0, -50939, 1750, 0, 0, 39, '1749'),
	(243, 1, 0, -50939, 1751, 0, 0, 39, '1750'),
	(243, 1, 0, -50939, 1752, 0, 0, 39, '1751'),
	(243, 1, 0, -50939, 1753, 0, 0, 39, '1752'),
	(243, 1, 0, -50939, 1754, 0, 0, 39, '1753'),
	(243, 1, 0, -50939, 1755, 0, 0, 39, '1754'),
	(243, 1, 0, -50939, 1756, 0, 0, 39, '1755'),
	(243, 1, 0, -50939, 1757, 0, 0, 39, '1756'),
	(243, 1, 0, -50939, 1758, 0, 0, 39, '1757'),
	(243, 1, 0, -50939, 1759, 0, 0, 39, '1758'),
	(243, 1, 0, -50939, 1760, 0, 0, 39, '1759'),
	(243, 1, 0, -50939, 1761, 0, 0, 39, '1760'),
	(243, 1, 0, -50939, 1762, 0, 0, 39, '1761'),
	(243, 1, 0, -50939, 1763, 0, 0, 39, '1762'),
	(243, 1, 0, -50939, 1764, 0, 0, 39, '1763'),
	(243, 1, 0, -50939, 1765, 0, 0, 39, '1764'),
	(243, 1, 0, -50939, 1766, 0, 0, 39, '1765'),
	(243, 1, 0, -50939, 1767, 0, 0, 39, '1766'),
	(243, 1, 0, -50939, 1768, 0, 0, 39, '1767'),
	(243, 1, 0, -50939, 1769, 0, 0, 39, '1768'),
	(243, 1, 0, -50939, 1770, 0, 0, 39, '1769'),
	(243, 1, 0, -50939, 1771, 0, 0, 39, '1770'),
	(243, 1, 0, -50939, 1772, 0, 0, 39, '1771'),
	(243, 1, 0, -50939, 1773, 0, 0, 39, '1772'),
	(243, 1, 0, -50939, 1774, 0, 0, 39, '1773'),
	(243, 1, 0, -50939, 1775, 0, 0, 39, '1774'),
	(243, 1, 0, -50939, 1776, 0, 0, 39, '1775'),
	(243, 1, 0, -50939, 1777, 0, 0, 39, '1776'),
	(243, 1, 0, -50939, 1778, 0, 0, 39, '1777'),
	(243, 1, 0, -50939, 1779, 0, 0, 39, '1778'),
	(243, 1, 0, -50939, 1780, 0, 0, 39, '1779'),
	(243, 1, 0, -50939, 1781, 0, 0, 39, '1780'),
	(243, 1, 0, -50939, 1782, 0, 0, 39, '1781'),
	(243, 1, 0, -50939, 1783, 0, 0, 39, '1782'),
	(243, 1, 0, -50939, 1784, 0, 0, 39, '1783'),
	(243, 1, 0, -50939, 1785, 0, 0, 39, '1784'),
	(243, 1, 0, -50939, 1786, 0, 0, 39, '1785'),
	(243, 1, 0, -50939, 1787, 0, 0, 39, '1786'),
	(243, 1, 0, -50939, 1788, 0, 0, 39, '1787'),
	(243, 1, 0, -50939, 1789, 0, 0, 39, '1788'),
	(243, 1, 0, -50939, 1790, 0, 0, 39, '1789'),
	(243, 1, 0, -50939, 1791, 0, 0, 39, '1790'),
	(243, 1, 0, -50939, 1792, 0, 0, 39, '1791'),
	(243, 1, 0, -50939, 1793, 0, 0, 39, '1792'),
	(243, 1, 0, -50939, 1794, 0, 0, 39, '1793'),
	(243, 1, 0, -50939, 1795, 0, 0, 39, '1794'),
	(243, 1, 0, -50939, 1796, 0, 0, 39, '1795'),
	(243, 1, 0, -50939, 1797, 0, 0, 39, '1796'),
	(243, 1, 0, -50939, 1798, 0, 0, 39, '1797'),
	(243, 1, 0, -50939, 1799, 0, 0, 39, '1798'),
	(243, 1, 0, -50939, 1800, 0, 0, 39, '1799'),
	(243, 1, 0, -50939, 1801, 0, 0, 39, '1800'),
	(243, 1, 0, -50939, 1802, 0, 0, 39, '1801'),
	(243, 1, 0, -50939, 1803, 0, 0, 39, '1802'),
	(243, 1, 0, -50939, 1804, 0, 0, 39, '1803'),
	(243, 1, 0, -50939, 1805, 0, 0, 39, '1804'),
	(243, 1, 0, -50939, 1806, 0, 0, 39, '1805'),
	(243, 1, 0, -50939, 1807, 0, 0, 39, '1806'),
	(243, 1, 0, -50939, 1808, 0, 0, 39, '1807'),
	(243, 1, 0, -50939, 1809, 0, 0, 39, '1808'),
	(243, 1, 0, -50939, 1810, 0, 0, 39, '1809'),
	(243, 1, 0, -50939, 1811, 0, 0, 39, '1810'),
	(243, 1, 0, -50939, 1812, 0, 0, 39, '1811'),
	(243, 1, 0, -50939, 1813, 0, 0, 39, '1812'),
	(243, 1, 0, -50939, 1814, 0, 0, 39, '1813'),
	(243, 1, 0, -50939, 1815, 0, 0, 39, '1814'),
	(243, 1, 0, -50939, 1816, 0, 0, 39, '1815'),
	(243, 1, 0, -50939, 1817, 0, 0, 39, '1816'),
	(243, 1, 0, -50939, 1818, 0, 0, 39, '1817'),
	(243, 1, 0, -50939, 1819, 0, 0, 39, '1818'),
	(243, 1, 0, -50939, 1820, 0, 0, 39, '1819'),
	(243, 1, 0, -50939, 1821, 0, 0, 39, '1820'),
	(243, 1, 0, -50939, 1822, 0, 0, 39, '1821'),
	(243, 1, 0, -50939, 1823, 0, 0, 39, '1822'),
	(243, 1, 0, -50939, 1824, 0, 0, 39, '1823'),
	(243, 1, 0, -50939, 1825, 0, 0, 39, '1824'),
	(243, 1, 0, -50939, 1826, 0, 0, 39, '1825'),
	(243, 1, 0, -50939, 1827, 0, 0, 39, '1826'),
	(243, 1, 0, -50939, 1828, 0, 0, 39, '1827'),
	(243, 1, 0, -50939, 1829, 0, 0, 39, '1828'),
	(243, 1, 0, -50939, 1830, 0, 0, 39, '1829'),
	(243, 1, 0, -50939, 1831, 0, 0, 39, '1830'),
	(243, 1, 0, -50939, 1832, 0, 0, 39, '1831'),
	(243, 1, 0, -50939, 1833, 0, 0, 39, '1832'),
	(243, 1, 0, -50939, 1834, 0, 0, 39, '1833'),
	(243, 1, 0, -50939, 1835, 0, 0, 39, '1834'),
	(243, 1, 0, -50939, 1836, 0, 0, 39, '1835'),
	(243, 1, 0, -50939, 1837, 0, 0, 39, '1836'),
	(243, 1, 0, -50939, 1838, 0, 0, 39, '1837'),
	(243, 1, 0, -50939, 1839, 0, 0, 39, '1838'),
	(243, 1, 0, -50939, 1840, 0, 0, 39, '1839'),
	(243, 1, 0, -50939, 1841, 0, 0, 39, '1840'),
	(243, 1, 0, -50939, 1842, 0, 0, 39, '1841'),
	(243, 1, 0, -50939, 1843, 0, 0, 39, '1842'),
	(243, 1, 0, -50939, 1844, 0, 0, 39, '1843'),
	(243, 1, 0, -50939, 1845, 0, 0, 39, '1844'),
	(243, 1, 0, -50939, 1846, 0, 0, 39, '1845'),
	(243, 1, 0, -50939, 1847, 0, 0, 39, '1846'),
	(243, 1, 0, -50939, 1848, 0, 0, 39, '1847'),
	(243, 1, 0, -50939, 1849, 0, 0, 39, '1848'),
	(243, 1, 0, -50939, 1850, 0, 0, 39, '1849'),
	(243, 1, 0, -50939, 1851, 0, 0, 39, '1850'),
	(243, 1, 0, -50939, 1852, 0, 0, 39, '1851'),
	(243, 1, 0, -50939, 1853, 0, 0, 39, '1852'),
	(243, 1, 0, -50939, 1854, 0, 0, 39, '1853'),
	(243, 1, 0, -50939, 1855, 0, 0, 39, '1854'),
	(243, 1, 0, -50939, 1856, 0, 0, 39, '1855'),
	(243, 1, 0, -50939, 1857, 0, 0, 39, '1856'),
	(243, 1, 0, -50939, 1858, 0, 0, 39, '1857'),
	(243, 1, 0, -50939, 1859, 0, 0, 39, '1858'),
	(243, 1, 0, -50939, 1860, 0, 0, 39, '1859'),
	(243, 1, 0, -50939, 1861, 0, 0, 39, '1860'),
	(243, 1, 0, -50939, 1862, 0, 0, 39, '1861'),
	(243, 1, 0, -50939, 1863, 0, 0, 39, '1862'),
	(243, 1, 0, -50939, 1864, 0, 0, 39, '1863'),
	(243, 1, 0, -50939, 1865, 0, 0, 39, '1864'),
	(243, 1, 0, -50939, 1866, 0, 0, 39, '1865'),
	(243, 1, 0, -50939, 1867, 0, 0, 39, '1866'),
	(243, 1, 0, -50939, 1868, 0, 0, 39, '1867'),
	(243, 1, 0, -50939, 1869, 0, 0, 39, '1868'),
	(243, 1, 0, -50939, 1870, 0, 0, 39, '1869'),
	(243, 1, 0, -50939, 1871, 0, 0, 39, '1870'),
	(243, 1, 0, -50939, 1872, 0, 0, 39, '1871'),
	(243, 1, 0, -50939, 1873, 0, 0, 39, '1872'),
	(243, 1, 0, -50939, 1874, 0, 0, 39, '1873'),
	(243, 1, 0, -50939, 1875, 0, 0, 39, '1874'),
	(243, 1, 0, -50939, 1876, 0, 0, 39, '1875'),
	(243, 1, 0, -50939, 1877, 0, 0, 39, '1876'),
	(243, 1, 0, -50939, 1878, 0, 0, 39, '1877'),
	(243, 1, 0, -50939, 1879, 0, 0, 39, '1878'),
	(243, 1, 0, -50939, 1880, 0, 0, 39, '1879'),
	(243, 1, 0, -50939, 1881, 0, 0, 39, '1880'),
	(243, 1, 0, -50939, 1882, 0, 0, 39, '1881'),
	(243, 1, 0, -50939, 1883, 0, 0, 39, '1882'),
	(243, 1, 0, -50939, 1884, 0, 0, 39, '1883'),
	(243, 1, 0, -50939, 1885, 0, 0, 39, '1884'),
	(243, 1, 0, -50939, 1886, 0, 0, 39, '1885'),
	(243, 1, 0, -50939, 1887, 0, 0, 39, '1886'),
	(243, 1, 0, -50939, 1888, 0, 0, 39, '1887'),
	(243, 1, 0, -50939, 1889, 0, 0, 39, '1888'),
	(243, 1, 0, -50939, 1890, 0, 0, 39, '1889'),
	(243, 1, 0, -50939, 1891, 0, 0, 39, '1890'),
	(243, 1, 0, -50939, 1892, 0, 0, 39, '1891'),
	(243, 1, 0, -50939, 1893, 0, 0, 39, '1892'),
	(243, 1, 0, -50939, 1894, 0, 0, 39, '1893'),
	(243, 1, 0, -50939, 1895, 0, 0, 39, '1894'),
	(243, 1, 0, -50939, 1896, 0, 0, 39, '1895'),
	(243, 1, 0, -50939, 1897, 0, 0, 39, '1896'),
	(243, 1, 0, -50939, 1898, 0, 0, 39, '1897'),
	(243, 1, 0, -50939, 1899, 0, 0, 39, '1898'),
	(243, 1, 0, -50939, 1900, 0, 0, 39, '1899'),
	(243, 1, 0, -50939, 1901, 0, 0, 39, '1900'),
	(243, 1, 0, -50939, 1902, 0, 0, 39, '1901'),
	(243, 1, 0, -50939, 1903, 0, 0, 39, '1902'),
	(243, 1, 0, -50939, 1904, 0, 0, 39, '1903'),
	(243, 1, 0, -50939, 1905, 0, 0, 39, '1904'),
	(243, 1, 0, -50939, 1906, 0, 0, 39, '1905'),
	(243, 1, 0, -50939, 1907, 0, 0, 39, '1906'),
	(243, 1, 0, -50939, 1908, 0, 0, 39, '1907'),
	(243, 1, 0, -50939, 1909, 0, 0, 39, '1908'),
	(243, 1, 0, -50939, 1910, 0, 0, 39, '1909'),
	(243, 1, 0, -50939, 1911, 0, 0, 39, '1910'),
	(243, 1, 0, -50939, 1912, 0, 0, 39, '1911'),
	(243, 1, 0, -50939, 1913, 0, 0, 39, '1912'),
	(243, 1, 0, -50939, 1914, 0, 0, 39, '1913'),
	(243, 1, 0, -50939, 1915, 0, 0, 39, '1914'),
	(243, 1, 0, -50939, 1916, 0, 0, 39, '1915'),
	(243, 1, 0, -50939, 1917, 0, 0, 39, '1916'),
	(243, 1, 0, -50939, 1918, 0, 0, 39, '1917'),
	(243, 1, 0, -50939, 1919, 0, 0, 39, '1918'),
	(243, 1, 0, -50939, 1920, 0, 0, 39, '1919'),
	(243, 1, 0, -50939, 1921, 0, 0, 39, '1920'),
	(243, 1, 0, -50939, 1922, 0, 0, 39, '1921'),
	(243, 1, 0, -50939, 1923, 0, 0, 39, '1922'),
	(243, 1, 0, -50939, 1924, 0, 0, 39, '1923'),
	(243, 1, 0, -50939, 1925, 0, 0, 39, '1924'),
	(243, 1, 0, -50939, 1926, 0, 0, 39, '1925'),
	(243, 1, 0, -50939, 1927, 0, 0, 39, '1926'),
	(243, 1, 0, -50939, 1928, 0, 0, 39, '1927'),
	(243, 1, 0, -50939, 1929, 0, 0, 39, '1928'),
	(243, 1, 0, -50939, 1930, 0, 0, 39, '1929'),
	(243, 1, 0, -50939, 1931, 0, 0, 39, '1930'),
	(243, 1, 0, -50939, 1932, 0, 0, 39, '1931'),
	(243, 1, 0, -50939, 1933, 0, 0, 39, '1932'),
	(243, 1, 0, -50939, 1934, 0, 0, 39, '1933'),
	(243, 1, 0, -50939, 1935, 0, 0, 39, '1934'),
	(243, 1, 0, -50939, 1936, 0, 0, 39, '1935'),
	(243, 1, 0, -50939, 1937, 0, 0, 39, '1936'),
	(243, 1, 0, -50939, 1938, 0, 0, 39, '1937'),
	(243, 1, 0, -50939, 1939, 0, 0, 39, '1938'),
	(243, 1, 0, -50939, 1940, 0, 0, 39, '1939'),
	(243, 1, 0, -50939, 1941, 0, 0, 39, '1940'),
	(243, 1, 0, -50939, 1942, 0, 0, 39, '1941'),
	(243, 1, 0, -50939, 1943, 0, 0, 39, '1942'),
	(243, 1, 0, -50939, 1944, 0, 0, 39, '1943'),
	(243, 1, 0, -50939, 1945, 0, 0, 39, '1944'),
	(243, 1, 0, -50939, 1946, 0, 0, 39, '1945'),
	(243, 1, 0, -50939, 1947, 0, 0, 39, '1946'),
	(243, 1, 0, -50939, 1948, 0, 0, 39, '1947'),
	(243, 1, 0, -50939, 1949, 0, 0, 39, '1948'),
	(243, 1, 0, -50939, 1950, 0, 0, 39, '1949'),
	(243, 1, 0, -50939, 1951, 0, 0, 39, '1950'),
	(243, 1, 0, -50939, 1952, 0, 0, 39, '1951'),
	(243, 1, 0, -50939, 1953, 0, 0, 39, '1952'),
	(243, 1, 0, -50939, 1954, 0, 0, 39, '1953'),
	(243, 1, 0, -50939, 1955, 0, 0, 39, '1954'),
	(243, 1, 0, -50939, 1956, 0, 0, 39, '1955'),
	(243, 1, 0, -50939, 1957, 0, 0, 39, '1956'),
	(243, 1, 0, -50939, 1958, 0, 0, 39, '1957'),
	(243, 1, 0, -50939, 1959, 0, 0, 39, '1958'),
	(243, 1, 0, -50939, 1960, 0, 0, 39, '1959'),
	(243, 1, 0, -50939, 1961, 0, 0, 39, '1960'),
	(243, 1, 0, -50939, 1962, 0, 0, 39, '1961'),
	(243, 1, 0, -50939, 1963, 0, 0, 39, '1962'),
	(243, 1, 0, -50939, 1964, 0, 0, 39, '1963'),
	(243, 1, 0, -50939, 1965, 0, 0, 39, '1964'),
	(243, 1, 0, -50939, 1966, 0, 0, 39, '1965'),
	(243, 1, 0, -50939, 1967, 0, 0, 39, '1966'),
	(243, 1, 0, -50939, 1968, 0, 0, 39, '1967'),
	(243, 1, 0, -50939, 1969, 0, 0, 39, '1968'),
	(243, 1, 0, -50939, 1970, 0, 0, 39, '1969'),
	(243, 1, 0, -50939, 1971, 0, 0, 39, '1970'),
	(243, 1, 0, -50939, 1972, 0, 0, 39, '1971'),
	(243, 1, 0, -50939, 1973, 0, 0, 39, '1972'),
	(243, 1, 0, -50939, 1974, 0, 0, 39, '1973'),
	(243, 1, 0, -50939, 1975, 0, 0, 39, '1974'),
	(243, 1, 0, -50939, 1976, 0, 0, 39, '1975'),
	(243, 1, 0, -50939, 1977, 0, 0, 39, '1976'),
	(243, 1, 0, -50939, 1978, 0, 0, 39, '1977'),
	(243, 1, 0, -50939, 1979, 0, 0, 39, '1978'),
	(243, 1, 0, -50939, 1980, 0, 0, 39, '1979'),
	(243, 1, 0, -50939, 1981, 0, 0, 39, '1980'),
	(243, 1, 0, -50939, 1982, 0, 0, 39, '1981'),
	(243, 1, 0, -50939, 1983, 0, 0, 39, '1982'),
	(243, 1, 0, -50939, 1984, 0, 0, 39, '1983'),
	(243, 1, 0, -50939, 1985, 0, 0, 39, '1984'),
	(243, 1, 0, -50939, 1986, 0, 0, 39, '1985'),
	(243, 1, 0, -50939, 1987, 0, 0, 39, '1986'),
	(243, 1, 0, -50939, 1988, 0, 0, 39, '1987'),
	(243, 1, 0, -50939, 1989, 0, 0, 39, '1988'),
	(243, 1, 0, -50939, 1990, 0, 0, 39, '1989'),
	(243, 1, 0, -50939, 1991, 0, 0, 39, '1990'),
	(243, 1, 0, -50939, 1992, 0, 0, 39, '1991'),
	(243, 1, 0, -50939, 1993, 0, 0, 39, '1992'),
	(243, 1, 0, -50939, 1994, 0, 0, 39, '1993'),
	(243, 1, 0, -50939, 1995, 0, 0, 39, '1994'),
	(243, 1, 0, -50939, 1996, 0, 0, 39, '1995'),
	(243, 1, 0, -50939, 1997, 0, 0, 39, '1996'),
	(243, 1, 0, -50939, 1998, 0, 0, 39, '1997'),
	(243, 1, 0, -50939, 1999, 0, 0, 39, '1998'),
	(243, 1, 0, -50939, 2000, 0, 0, 39, '1999'),
	(243, 1, 0, -50939, 2001, 0, 0, 39, '2000'),
	(243, 1, 0, -50939, 2002, 0, 0, 39, '2001'),
	(243, 1, 0, -50939, 2003, 0, 0, 39, '2002'),
	(243, 1, 0, -50939, 2004, 0, 0, 39, '2003'),
	(243, 1, 0, -50939, 2005, 0, 0, 39, '2004'),
	(243, 1, 0, -50939, 2006, 0, 0, 39, '2005'),
	(243, 1, 0, -50939, 2007, 0, 0, 39, '2006'),
	(243, 1, 0, -50939, 2008, 0, 0, 39, '2007'),
	(243, 1, 0, -50939, 2009, 0, 0, 39, '2008'),
	(243, 1, 0, -50939, 2010, 0, 0, 39, '2009'),
	(243, 1, 0, -50939, 2011, 0, 0, 39, '2010'),
	(243, 1, 0, -50939, 2012, 0, 0, 39, '2011'),
	(243, 1, 0, -50939, 2013, 0, 0, 39, '2012'),
	(243, 1, 0, -50939, 2014, 0, 0, 39, '2013'),
	(243, 1, 0, -50939, 2015, 0, 0, 39, '2014'),
	(243, 1, 0, -50939, 2016, 0, 0, 39, '2015'),
	(243, 1, 0, -50939, 2017, 0, 0, 39, '2016'),
	(243, 1, 0, -50939, 2018, 0, 0, 39, '2017'),
	(243, 1, 0, -50939, 2019, 0, 0, 39, '2018'),
	(243, 1, 0, -50939, 2020, 0, 0, 39, '2019'),
	(243, 1, 0, -50939, 2021, 0, 0, 39, '2020'),
	(243, 1, 0, -50939, 2022, 0, 0, 39, '2021'),
	(243, 1, 0, -50939, 2023, 0, 0, 39, '2022'),
	(243, 1, 0, -50939, 2024, 0, 0, 39, '2023'),
	(243, 1, 0, -50939, 2025, 0, 0, 39, '2024'),
	(243, 1, 0, -50939, 2026, 0, 0, 39, '2025'),
	(243, 1, 0, -50939, 2027, 0, 0, 39, '2026'),
	(243, 1, 0, -50939, 2028, 0, 0, 39, '2027'),
	(243, 1, 0, -50939, 2029, 0, 0, 39, '2028'),
	(243, 1, 0, -50939, 2030, 0, 0, 39, '2029'),
	(243, 1, 0, -50939, 2031, 0, 0, 39, '2030'),
	(243, 1, 0, -50939, 2032, 0, 0, 39, '2031'),
	(243, 1, 0, -50939, 2033, 0, 0, 39, '2032'),
	(243, 1, 0, -50939, 2034, 0, 0, 39, '2033'),
	(243, 1, 0, -50939, 2035, 0, 0, 39, '2034'),
	(243, 1, 0, -50939, 2036, 0, 0, 39, '2035'),
	(243, 1, 0, -50939, 2037, 0, 0, 39, '2036'),
	(243, 1, 0, -50939, 2038, 0, 0, 39, '2037'),
	(243, 1, 0, -50939, 2039, 0, 0, 39, '2038'),
	(243, 1, 0, -50939, 2040, 0, 0, 39, '2039'),
	(243, 1, 0, -50939, 2041, 0, 0, 39, '2040'),
	(243, 1, 0, -50939, 2042, 0, 0, 39, '2041'),
	(243, 1, 0, -50939, 2043, 0, 0, 39, '2042'),
	(243, 1, 0, -50939, 2044, 0, 0, 39, '2043'),
	(243, 1, 0, -50939, 2045, 0, 0, 39, '2044'),
	(243, 1, 0, -50939, 2046, 0, 0, 39, '2045'),
	(243, 1, 0, -50939, 2047, 0, 0, 39, '2046'),
	(243, 1, 0, -50939, 2048, 0, 0, 39, '2047'),
	(243, 1, 0, -50938, 1, 0, 0, 39, '0'),
	(243, 1, 0, -50938, 2, 0, 0, 39, '1'),
	(243, 1, 0, -50938, 3, 0, 0, 39, '2'),
	(243, 1, 0, -50938, 4, 0, 0, 39, '3'),
	(243, 1, 0, -50938, 5, 0, 0, 39, '4'),
	(243, 1, 0, -50938, 6, 0, 0, 39, '5'),
	(243, 1, 0, -50938, 7, 0, 0, 39, '6'),
	(243, 1, 0, -50938, 8, 0, 0, 39, '7'),
	(243, 1, 0, -50938, 9, 0, 0, 39, '8'),
	(243, 1, 0, -50938, 10, 0, 0, 39, '9'),
	(243, 1, 0, -50938, 11, 0, 0, 39, '10'),
	(243, 1, 0, -50938, 12, 0, 0, 39, '11'),
	(243, 1, 0, -50938, 13, 0, 0, 39, '12'),
	(243, 1, 0, -50938, 14, 0, 0, 39, '13'),
	(243, 1, 0, -50938, 15, 0, 0, 39, '14'),
	(243, 1, 0, -50938, 16, 0, 0, 39, '15'),
	(243, 1, 0, -50938, 17, 0, 0, 39, '16'),
	(243, 1, 0, -50938, 18, 0, 0, 39, '17'),
	(243, 1, 0, -50938, 19, 0, 0, 39, '18'),
	(243, 1, 0, -50938, 20, 0, 0, 39, '19'),
	(243, 1, 0, -50938, 21, 0, 0, 39, '20'),
	(243, 1, 0, -50938, 22, 0, 0, 39, '21'),
	(243, 1, 0, -50938, 23, 0, 0, 39, '22'),
	(243, 1, 0, -50938, 24, 0, 0, 39, '23'),
	(243, 1, 0, -50938, 25, 0, 0, 39, '24'),
	(243, 1, 0, -50938, 26, 0, 0, 39, '25'),
	(243, 1, 0, -50938, 27, 0, 0, 39, '26'),
	(243, 1, 0, -50938, 28, 0, 0, 39, '27'),
	(243, 1, 0, -50938, 29, 0, 0, 39, '28'),
	(243, 1, 0, -50938, 30, 0, 0, 39, '29'),
	(243, 1, 0, -50938, 31, 0, 0, 39, '30'),
	(243, 1, 0, -50938, 32, 0, 0, 39, '31'),
	(243, 1, 0, -50938, 33, 0, 0, 39, '32'),
	(243, 1, 0, -50938, 34, 0, 0, 39, '33'),
	(243, 1, 0, -50938, 35, 0, 0, 39, '34'),
	(243, 1, 0, -50938, 36, 0, 0, 39, '35'),
	(243, 1, 0, -50938, 37, 0, 0, 39, '36'),
	(243, 1, 0, -50938, 38, 0, 0, 39, '37'),
	(243, 1, 0, -50938, 39, 0, 0, 39, '38'),
	(243, 1, 0, -50938, 40, 0, 0, 39, '39'),
	(243, 1, 0, -50938, 41, 0, 0, 39, '40'),
	(243, 1, 0, -50938, 42, 0, 0, 39, '41'),
	(243, 1, 0, -50938, 43, 0, 0, 39, '42'),
	(243, 1, 0, -50938, 44, 0, 0, 39, '43'),
	(243, 1, 0, -50938, 45, 0, 0, 39, '44'),
	(243, 1, 0, -50938, 46, 0, 0, 39, '45'),
	(243, 1, 0, -50938, 47, 0, 0, 39, '46'),
	(243, 1, 0, -50938, 48, 0, 0, 39, '47'),
	(243, 1, 0, -50938, 49, 0, 0, 39, '48'),
	(243, 1, 0, -50938, 50, 0, 0, 39, '49'),
	(243, 1, 0, -50938, 51, 0, 0, 39, '50'),
	(243, 1, 0, -50938, 52, 0, 0, 39, '51'),
	(243, 1, 0, -50938, 53, 0, 0, 39, '52'),
	(243, 1, 0, -50938, 54, 0, 0, 39, '53'),
	(243, 1, 0, -50938, 55, 0, 0, 39, '54'),
	(243, 1, 0, -50938, 56, 0, 0, 39, '55'),
	(243, 1, 0, -50938, 57, 0, 0, 39, '56'),
	(243, 1, 0, -50938, 58, 0, 0, 39, '57'),
	(243, 1, 0, -50938, 59, 0, 0, 39, '58'),
	(243, 1, 0, -50938, 60, 0, 0, 39, '59'),
	(243, 1, 0, -50938, 61, 0, 0, 39, '60'),
	(243, 1, 0, -50938, 62, 0, 0, 39, '61'),
	(243, 1, 0, -50938, 63, 0, 0, 39, '62'),
	(243, 1, 0, -50938, 64, 0, 0, 39, '63'),
	(243, 1, 0, -50938, 65, 0, 0, 39, '64'),
	(243, 1, 0, -50938, 66, 0, 0, 39, '65'),
	(243, 1, 0, -50938, 67, 0, 0, 39, '66'),
	(243, 1, 0, -50938, 68, 0, 0, 39, '67'),
	(243, 1, 0, -50938, 69, 0, 0, 39, '68'),
	(243, 1, 0, -50938, 70, 0, 0, 39, '69'),
	(243, 1, 0, -50938, 71, 0, 0, 39, '70'),
	(243, 1, 0, -50938, 72, 0, 0, 39, '71'),
	(243, 1, 0, -50938, 73, 0, 0, 39, '72'),
	(243, 1, 0, -50938, 74, 0, 0, 39, '73'),
	(243, 1, 0, -50938, 75, 0, 0, 39, '74'),
	(243, 1, 0, -50938, 76, 0, 0, 39, '75'),
	(243, 1, 0, -50938, 77, 0, 0, 39, '76'),
	(243, 1, 0, -50938, 78, 0, 0, 39, '77'),
	(243, 1, 0, -50938, 79, 0, 0, 39, '78'),
	(243, 1, 0, -50938, 80, 0, 0, 39, '79'),
	(243, 1, 0, -50938, 81, 0, 0, 39, '80'),
	(243, 1, 0, -50938, 82, 0, 0, 39, '81'),
	(243, 1, 0, -50938, 83, 0, 0, 39, '82'),
	(243, 1, 0, -50938, 84, 0, 0, 39, '83'),
	(243, 1, 0, -50938, 85, 0, 0, 39, '84'),
	(243, 1, 0, -50938, 86, 0, 0, 39, '85'),
	(243, 1, 0, -50938, 87, 0, 0, 39, '86'),
	(243, 1, 0, -50938, 88, 0, 0, 39, '87'),
	(243, 1, 0, -50938, 89, 0, 0, 39, '88'),
	(243, 1, 0, -50938, 90, 0, 0, 39, '89'),
	(243, 1, 0, -50938, 91, 0, 0, 39, '90'),
	(243, 1, 0, -50938, 92, 0, 0, 39, '91'),
	(243, 1, 0, -50938, 93, 0, 0, 39, '92'),
	(243, 1, 0, -50938, 94, 0, 0, 39, '93'),
	(243, 1, 0, -50938, 95, 0, 0, 39, '94'),
	(243, 1, 0, -50938, 96, 0, 0, 39, '95'),
	(243, 1, 0, -50938, 97, 0, 0, 39, '96'),
	(243, 1, 0, -50938, 98, 0, 0, 39, '97'),
	(243, 1, 0, -50938, 99, 0, 0, 39, '98'),
	(243, 1, 0, -50938, 100, 0, 0, 39, '99'),
	(243, 1, 0, -50938, 101, 0, 0, 39, '100'),
	(243, 1, 0, -50938, 102, 0, 0, 39, '101'),
	(243, 1, 0, -50938, 103, 0, 0, 39, '102'),
	(243, 1, 0, -50938, 104, 0, 0, 39, '103'),
	(243, 1, 0, -50938, 105, 0, 0, 39, '104'),
	(243, 1, 0, -50938, 106, 0, 0, 39, '105'),
	(243, 1, 0, -50938, 107, 0, 0, 39, '106'),
	(243, 1, 0, -50938, 108, 0, 0, 39, '107'),
	(243, 1, 0, -50938, 109, 0, 0, 39, '108'),
	(243, 1, 0, -50938, 110, 0, 0, 39, '109'),
	(243, 1, 0, -50938, 111, 0, 0, 39, '110'),
	(243, 1, 0, -50938, 112, 0, 0, 39, '111'),
	(243, 1, 0, -50938, 113, 0, 0, 39, '112'),
	(243, 1, 0, -50938, 114, 0, 0, 39, '113'),
	(243, 1, 0, -50938, 115, 0, 0, 39, '114'),
	(243, 1, 0, -50938, 116, 0, 0, 39, '115'),
	(243, 1, 0, -50938, 117, 0, 0, 39, '116'),
	(243, 1, 0, -50938, 118, 0, 0, 39, '117'),
	(243, 1, 0, -50938, 119, 0, 0, 39, '118'),
	(243, 1, 0, -50938, 120, 0, 0, 39, '119'),
	(243, 1, 0, -50938, 121, 0, 0, 39, '120'),
	(243, 1, 0, -50938, 122, 0, 0, 39, '121'),
	(243, 1, 0, -50938, 123, 0, 0, 39, '122'),
	(243, 1, 0, -50938, 124, 0, 0, 39, '123'),
	(243, 1, 0, -50938, 125, 0, 0, 39, '124'),
	(243, 1, 0, -50938, 126, 0, 0, 39, '125'),
	(243, 1, 0, -50938, 127, 0, 0, 39, '126'),
	(243, 1, 0, -50938, 128, 0, 0, 39, '127'),
	(243, 1, 0, -50938, 129, 0, 0, 39, '128'),
	(243, 1, 0, -50938, 130, 0, 0, 39, '129'),
	(243, 1, 0, -50938, 131, 0, 0, 39, '130'),
	(243, 1, 0, -50938, 132, 0, 0, 39, '131'),
	(243, 1, 0, -50938, 133, 0, 0, 39, '132'),
	(243, 1, 0, -50938, 134, 0, 0, 39, '133'),
	(243, 1, 0, -50938, 135, 0, 0, 39, '134'),
	(243, 1, 0, -50938, 136, 0, 0, 39, '135'),
	(243, 1, 0, -50938, 137, 0, 0, 39, '136'),
	(243, 1, 0, -50938, 138, 0, 0, 39, '137'),
	(243, 1, 0, -50938, 139, 0, 0, 39, '138'),
	(243, 1, 0, -50938, 140, 0, 0, 39, '139'),
	(243, 1, 0, -50938, 141, 0, 0, 39, '140'),
	(243, 1, 0, -50938, 142, 0, 0, 39, '141'),
	(243, 1, 0, -50938, 143, 0, 0, 39, '142'),
	(243, 1, 0, -50938, 144, 0, 0, 39, '143'),
	(243, 1, 0, -50938, 145, 0, 0, 39, '144'),
	(243, 1, 0, -50938, 146, 0, 0, 39, '145'),
	(243, 1, 0, -50938, 147, 0, 0, 39, '146'),
	(243, 1, 0, -50938, 148, 0, 0, 39, '147'),
	(243, 1, 0, -50938, 149, 0, 0, 39, '148'),
	(243, 1, 0, -50938, 150, 0, 0, 39, '149'),
	(243, 1, 0, -50938, 151, 0, 0, 39, '150'),
	(243, 1, 0, -50938, 152, 0, 0, 39, '151'),
	(243, 1, 0, -50938, 153, 0, 0, 39, '152'),
	(243, 1, 0, -50938, 154, 0, 0, 39, '153'),
	(243, 1, 0, -50938, 155, 0, 0, 39, '154'),
	(243, 1, 0, -50938, 156, 0, 0, 39, '155'),
	(243, 1, 0, -50938, 157, 0, 0, 39, '156'),
	(243, 1, 0, -50938, 158, 0, 0, 39, '157'),
	(243, 1, 0, -50938, 159, 0, 0, 39, '158'),
	(243, 1, 0, -50938, 160, 0, 0, 39, '159'),
	(243, 1, 0, -50938, 161, 0, 0, 39, '160'),
	(243, 1, 0, -50938, 162, 0, 0, 39, '161'),
	(243, 1, 0, -50938, 163, 0, 0, 39, '162'),
	(243, 1, 0, -50938, 164, 0, 0, 39, '163'),
	(243, 1, 0, -50938, 165, 0, 0, 39, '164'),
	(243, 1, 0, -50938, 166, 0, 0, 39, '165'),
	(243, 1, 0, -50938, 167, 0, 0, 39, '166'),
	(243, 1, 0, -50938, 168, 0, 0, 39, '167'),
	(243, 1, 0, -50938, 169, 0, 0, 39, '168'),
	(243, 1, 0, -50938, 170, 0, 0, 39, '169'),
	(243, 1, 0, -50938, 171, 0, 0, 39, '170'),
	(243, 1, 0, -50938, 172, 0, 0, 39, '171'),
	(243, 1, 0, -50938, 173, 0, 0, 39, '172'),
	(243, 1, 0, -50938, 174, 0, 0, 39, '173'),
	(243, 1, 0, -50938, 175, 0, 0, 39, '174'),
	(243, 1, 0, -50938, 176, 0, 0, 39, '175'),
	(243, 1, 0, -50938, 177, 0, 0, 39, '176'),
	(243, 1, 0, -50938, 178, 0, 0, 39, '177'),
	(243, 1, 0, -50938, 179, 0, 0, 39, '178'),
	(243, 1, 0, -50938, 180, 0, 0, 39, '179'),
	(243, 1, 0, -50938, 181, 0, 0, 39, '180'),
	(243, 1, 0, -50938, 182, 0, 0, 39, '181'),
	(243, 1, 0, -50938, 183, 0, 0, 39, '182'),
	(243, 1, 0, -50938, 184, 0, 0, 39, '183'),
	(243, 1, 0, -50938, 185, 0, 0, 39, '184'),
	(243, 1, 0, -50938, 186, 0, 0, 39, '185'),
	(243, 1, 0, -50938, 187, 0, 0, 39, '186'),
	(243, 1, 0, -50938, 188, 0, 0, 39, '187'),
	(243, 1, 0, -50938, 189, 0, 0, 39, '188'),
	(243, 1, 0, -50938, 190, 0, 0, 39, '189'),
	(243, 1, 0, -50938, 191, 0, 0, 39, '190'),
	(243, 1, 0, -50938, 192, 0, 0, 39, '191'),
	(243, 1, 0, -50938, 193, 0, 0, 39, '192'),
	(243, 1, 0, -50938, 194, 0, 0, 39, '193'),
	(243, 1, 0, -50938, 195, 0, 0, 39, '194'),
	(243, 1, 0, -50938, 196, 0, 0, 39, '195'),
	(243, 1, 0, -50938, 197, 0, 0, 39, '196'),
	(243, 1, 0, -50938, 198, 0, 0, 39, '197'),
	(243, 1, 0, -50938, 199, 0, 0, 39, '198'),
	(243, 1, 0, -50938, 200, 0, 0, 39, '199'),
	(243, 1, 0, -50938, 201, 0, 0, 39, '200'),
	(243, 1, 0, -50938, 202, 0, 0, 39, '201'),
	(243, 1, 0, -50938, 203, 0, 0, 39, '202'),
	(243, 1, 0, -50938, 204, 0, 0, 39, '203'),
	(243, 1, 0, -50938, 205, 0, 0, 39, '204'),
	(243, 1, 0, -50938, 206, 0, 0, 39, '205'),
	(243, 1, 0, -50938, 207, 0, 0, 39, '206'),
	(243, 1, 0, -50938, 208, 0, 0, 39, '207'),
	(243, 1, 0, -50938, 209, 0, 0, 39, '208'),
	(243, 1, 0, -50938, 210, 0, 0, 39, '209'),
	(243, 1, 0, -50938, 211, 0, 0, 39, '210'),
	(243, 1, 0, -50938, 212, 0, 0, 39, '211'),
	(243, 1, 0, -50938, 213, 0, 0, 39, '212'),
	(243, 1, 0, -50938, 214, 0, 0, 39, '213'),
	(243, 1, 0, -50938, 215, 0, 0, 39, '214'),
	(243, 1, 0, -50938, 216, 0, 0, 39, '215'),
	(243, 1, 0, -50938, 217, 0, 0, 39, '216'),
	(243, 1, 0, -50938, 218, 0, 0, 39, '217'),
	(243, 1, 0, -50938, 219, 0, 0, 39, '218'),
	(243, 1, 0, -50938, 220, 0, 0, 39, '219'),
	(243, 1, 0, -50938, 221, 0, 0, 39, '220'),
	(243, 1, 0, -50938, 222, 0, 0, 39, '221'),
	(243, 1, 0, -50938, 223, 0, 0, 39, '222'),
	(243, 1, 0, -50938, 224, 0, 0, 39, '223'),
	(243, 1, 0, -50938, 225, 0, 0, 39, '224'),
	(243, 1, 0, -50938, 226, 0, 0, 39, '225'),
	(243, 1, 0, -50938, 227, 0, 0, 39, '226'),
	(243, 1, 0, -50938, 228, 0, 0, 39, '227'),
	(243, 1, 0, -50938, 229, 0, 0, 39, '228'),
	(243, 1, 0, -50938, 230, 0, 0, 39, '229'),
	(243, 1, 0, -50938, 231, 0, 0, 39, '230'),
	(243, 1, 0, -50938, 232, 0, 0, 39, '231'),
	(243, 1, 0, -50938, 233, 0, 0, 39, '232'),
	(243, 1, 0, -50938, 234, 0, 0, 39, '233'),
	(243, 1, 0, -50938, 235, 0, 0, 39, '234'),
	(243, 1, 0, -50938, 236, 0, 0, 39, '235'),
	(243, 1, 0, -50938, 237, 0, 0, 39, '236'),
	(243, 1, 0, -50938, 238, 0, 0, 39, '237'),
	(243, 1, 0, -50938, 239, 0, 0, 39, '238'),
	(243, 1, 0, -50938, 240, 0, 0, 39, '239'),
	(243, 1, 0, -50938, 241, 0, 0, 39, '240'),
	(243, 1, 0, -50938, 242, 0, 0, 39, '241'),
	(243, 1, 0, -50938, 243, 0, 0, 39, '242'),
	(243, 1, 0, -50938, 244, 0, 0, 39, '243'),
	(243, 1, 0, -50938, 245, 0, 0, 39, '244'),
	(243, 1, 0, -50938, 246, 0, 0, 39, '245'),
	(243, 1, 0, -50938, 247, 0, 0, 39, '246'),
	(243, 1, 0, -50938, 248, 0, 0, 39, '247'),
	(243, 1, 0, -50938, 249, 0, 0, 39, '248'),
	(243, 1, 0, -50938, 250, 0, 0, 39, '249'),
	(243, 1, 0, -50938, 251, 0, 0, 39, '250'),
	(243, 1, 0, -50938, 252, 0, 0, 39, '251'),
	(243, 1, 0, -50938, 253, 0, 0, 39, '252'),
	(243, 1, 0, -50938, 254, 0, 0, 39, '253'),
	(243, 1, 0, -50938, 255, 0, 0, 39, '254'),
	(243, 1, 0, -50938, 256, 0, 0, 39, '255'),
	(243, 1, 0, -50938, 257, 0, 0, 39, '256'),
	(243, 1, 0, -50938, 258, 0, 0, 39, '257'),
	(243, 1, 0, -50938, 259, 0, 0, 39, '258'),
	(243, 1, 0, -50938, 260, 0, 0, 39, '259'),
	(243, 1, 0, -50938, 261, 0, 0, 39, '260'),
	(243, 1, 0, -50938, 262, 0, 0, 39, '261'),
	(243, 1, 0, -50938, 263, 0, 0, 39, '262'),
	(243, 1, 0, -50938, 264, 0, 0, 39, '263'),
	(243, 1, 0, -50938, 265, 0, 0, 39, '264'),
	(243, 1, 0, -50938, 266, 0, 0, 39, '265'),
	(243, 1, 0, -50938, 267, 0, 0, 39, '266'),
	(243, 1, 0, -50938, 268, 0, 0, 39, '267'),
	(243, 1, 0, -50938, 269, 0, 0, 39, '268'),
	(243, 1, 0, -50938, 270, 0, 0, 39, '269'),
	(243, 1, 0, -50938, 271, 0, 0, 39, '270'),
	(243, 1, 0, -50938, 272, 0, 0, 39, '271'),
	(243, 1, 0, -50938, 273, 0, 0, 39, '272'),
	(243, 1, 0, -50938, 274, 0, 0, 39, '273'),
	(243, 1, 0, -50938, 275, 0, 0, 39, '274'),
	(243, 1, 0, -50938, 276, 0, 0, 39, '275'),
	(243, 1, 0, -50938, 277, 0, 0, 39, '276'),
	(243, 1, 0, -50938, 278, 0, 0, 39, '277'),
	(243, 1, 0, -50938, 279, 0, 0, 39, '278'),
	(243, 1, 0, -50938, 280, 0, 0, 39, '279'),
	(243, 1, 0, -50938, 281, 0, 0, 39, '280'),
	(243, 1, 0, -50938, 282, 0, 0, 39, '281'),
	(243, 1, 0, -50938, 283, 0, 0, 39, '282'),
	(243, 1, 0, -50938, 284, 0, 0, 39, '283'),
	(243, 1, 0, -50938, 285, 0, 0, 39, '284'),
	(243, 1, 0, -50938, 286, 0, 0, 39, '285'),
	(243, 1, 0, -50938, 287, 0, 0, 39, '286'),
	(243, 1, 0, -50938, 288, 0, 0, 39, '287'),
	(243, 1, 0, -50938, 289, 0, 0, 39, '288'),
	(243, 1, 0, -50938, 290, 0, 0, 39, '289'),
	(243, 1, 0, -50938, 291, 0, 0, 39, '290'),
	(243, 1, 0, -50938, 292, 0, 0, 39, '291'),
	(243, 1, 0, -50938, 293, 0, 0, 39, '292'),
	(243, 1, 0, -50938, 294, 0, 0, 39, '293'),
	(243, 1, 0, -50938, 295, 0, 0, 39, '294'),
	(243, 1, 0, -50938, 296, 0, 0, 39, '295'),
	(243, 1, 0, -50938, 297, 0, 0, 39, '296'),
	(243, 1, 0, -50938, 298, 0, 0, 39, '297'),
	(243, 1, 0, -50938, 299, 0, 0, 39, '298'),
	(243, 1, 0, -50938, 300, 0, 0, 39, '299'),
	(243, 1, 0, -50938, 301, 0, 0, 39, '300'),
	(243, 1, 0, -50938, 302, 0, 0, 39, '301'),
	(243, 1, 0, -50938, 303, 0, 0, 39, '302'),
	(243, 1, 0, -50938, 304, 0, 0, 39, '303'),
	(243, 1, 0, -50938, 305, 0, 0, 39, '304'),
	(243, 1, 0, -50938, 306, 0, 0, 39, '305'),
	(243, 1, 0, -50938, 307, 0, 0, 39, '306'),
	(243, 1, 0, -50938, 308, 0, 0, 39, '307'),
	(243, 1, 0, -50938, 309, 0, 0, 39, '308'),
	(243, 1, 0, -50938, 310, 0, 0, 39, '309'),
	(243, 1, 0, -50938, 311, 0, 0, 39, '310'),
	(243, 1, 0, -50938, 312, 0, 0, 39, '311'),
	(243, 1, 0, -50938, 313, 0, 0, 39, '312'),
	(243, 1, 0, -50938, 314, 0, 0, 39, '313'),
	(243, 1, 0, -50938, 315, 0, 0, 39, '314'),
	(243, 1, 0, -50938, 316, 0, 0, 39, '315'),
	(243, 1, 0, -50938, 317, 0, 0, 39, '316'),
	(243, 1, 0, -50938, 318, 0, 0, 39, '317'),
	(243, 1, 0, -50938, 319, 0, 0, 39, '318'),
	(243, 1, 0, -50938, 320, 0, 0, 39, '319'),
	(243, 1, 0, -50938, 321, 0, 0, 39, '320'),
	(243, 1, 0, -50938, 322, 0, 0, 39, '321'),
	(243, 1, 0, -50938, 323, 0, 0, 39, '322'),
	(243, 1, 0, -50938, 324, 0, 0, 39, '323'),
	(243, 1, 0, -50938, 325, 0, 0, 39, '324'),
	(243, 1, 0, -50938, 326, 0, 0, 39, '325'),
	(243, 1, 0, -50938, 327, 0, 0, 39, '326'),
	(243, 1, 0, -50938, 328, 0, 0, 39, '327'),
	(243, 1, 0, -50938, 329, 0, 0, 39, '328'),
	(243, 1, 0, -50938, 330, 0, 0, 39, '329'),
	(243, 1, 0, -50938, 331, 0, 0, 39, '330'),
	(243, 1, 0, -50938, 332, 0, 0, 39, '331'),
	(243, 1, 0, -50938, 333, 0, 0, 39, '332'),
	(243, 1, 0, -50938, 334, 0, 0, 39, '333'),
	(243, 1, 0, -50938, 335, 0, 0, 39, '334'),
	(243, 1, 0, -50938, 336, 0, 0, 39, '335'),
	(243, 1, 0, -50938, 337, 0, 0, 39, '336'),
	(243, 1, 0, -50938, 338, 0, 0, 39, '337'),
	(243, 1, 0, -50938, 339, 0, 0, 39, '338'),
	(243, 1, 0, -50938, 340, 0, 0, 39, '339'),
	(243, 1, 0, -50938, 341, 0, 0, 39, '340'),
	(243, 1, 0, -50938, 342, 0, 0, 39, '341'),
	(243, 1, 0, -50938, 343, 0, 0, 39, '342'),
	(243, 1, 0, -50938, 344, 0, 0, 39, '343'),
	(243, 1, 0, -50938, 345, 0, 0, 39, '344'),
	(243, 1, 0, -50938, 346, 0, 0, 39, '345'),
	(243, 1, 0, -50938, 347, 0, 0, 39, '346'),
	(243, 1, 0, -50938, 348, 0, 0, 39, '347'),
	(243, 1, 0, -50938, 349, 0, 0, 39, '348'),
	(243, 1, 0, -50938, 350, 0, 0, 39, '349'),
	(243, 1, 0, -50938, 351, 0, 0, 39, '350'),
	(243, 1, 0, -50938, 352, 0, 0, 39, '351'),
	(243, 1, 0, -50938, 353, 0, 0, 39, '352'),
	(243, 1, 0, -50938, 354, 0, 0, 39, '353'),
	(243, 1, 0, -50938, 355, 0, 0, 39, '354'),
	(243, 1, 0, -50938, 356, 0, 0, 39, '355'),
	(243, 1, 0, -50938, 357, 0, 0, 39, '356'),
	(243, 1, 0, -50938, 358, 0, 0, 39, '357'),
	(243, 1, 0, -50938, 359, 0, 0, 39, '358'),
	(243, 1, 0, -50938, 360, 0, 0, 39, '359'),
	(243, 1, 0, -50938, 361, 0, 0, 39, '360'),
	(243, 1, 0, -50938, 362, 0, 0, 39, '361'),
	(243, 1, 0, -50938, 363, 0, 0, 39, '362'),
	(243, 1, 0, -50938, 364, 0, 0, 39, '363'),
	(243, 1, 0, -50938, 365, 0, 0, 39, '364'),
	(243, 1, 0, -50938, 366, 0, 0, 39, '365'),
	(243, 1, 0, -50938, 367, 0, 0, 39, '366'),
	(243, 1, 0, -50938, 368, 0, 0, 39, '367'),
	(243, 1, 0, -50938, 369, 0, 0, 39, '368'),
	(243, 1, 0, -50938, 370, 0, 0, 39, '369'),
	(243, 1, 0, -50938, 371, 0, 0, 39, '370'),
	(243, 1, 0, -50938, 372, 0, 0, 39, '371'),
	(243, 1, 0, -50938, 373, 0, 0, 39, '372'),
	(243, 1, 0, -50938, 374, 0, 0, 39, '373'),
	(243, 1, 0, -50938, 375, 0, 0, 39, '374'),
	(243, 1, 0, -50938, 376, 0, 0, 39, '375'),
	(243, 1, 0, -50938, 377, 0, 0, 39, '376'),
	(243, 1, 0, -50938, 378, 0, 0, 39, '377'),
	(243, 1, 0, -50938, 379, 0, 0, 39, '378'),
	(243, 1, 0, -50938, 380, 0, 0, 39, '379'),
	(243, 1, 0, -50938, 381, 0, 0, 39, '380'),
	(243, 1, 0, -50938, 382, 0, 0, 39, '381'),
	(243, 1, 0, -50938, 383, 0, 0, 39, '382'),
	(243, 1, 0, -50938, 384, 0, 0, 39, '383'),
	(243, 1, 0, -50938, 385, 0, 0, 39, '384'),
	(243, 1, 0, -50938, 386, 0, 0, 39, '385'),
	(243, 1, 0, -50938, 387, 0, 0, 39, '386'),
	(243, 1, 0, -50938, 388, 0, 0, 39, '387'),
	(243, 1, 0, -50938, 389, 0, 0, 39, '388'),
	(243, 1, 0, -50938, 390, 0, 0, 39, '389'),
	(243, 1, 0, -50938, 391, 0, 0, 39, '390'),
	(243, 1, 0, -50938, 392, 0, 0, 39, '391'),
	(243, 1, 0, -50938, 393, 0, 0, 39, '392'),
	(243, 1, 0, -50938, 394, 0, 0, 39, '393'),
	(243, 1, 0, -50938, 395, 0, 0, 39, '394'),
	(243, 1, 0, -50938, 396, 0, 0, 39, '395'),
	(243, 1, 0, -50938, 397, 0, 0, 39, '396'),
	(243, 1, 0, -50938, 398, 0, 0, 39, '397'),
	(243, 1, 0, -50938, 399, 0, 0, 39, '398'),
	(243, 1, 0, -50938, 400, 0, 0, 39, '399'),
	(243, 1, 0, -50938, 401, 0, 0, 39, '400'),
	(243, 1, 0, -50938, 402, 0, 0, 39, '401'),
	(243, 1, 0, -50938, 403, 0, 0, 39, '402'),
	(243, 1, 0, -50938, 404, 0, 0, 39, '403'),
	(243, 1, 0, -50938, 405, 0, 0, 39, '404'),
	(243, 1, 0, -50938, 406, 0, 0, 39, '405'),
	(243, 1, 0, -50938, 407, 0, 0, 39, '406'),
	(243, 1, 0, -50938, 408, 0, 0, 39, '407'),
	(243, 1, 0, -50938, 409, 0, 0, 39, '408'),
	(243, 1, 0, -50938, 410, 0, 0, 39, '409'),
	(243, 1, 0, -50938, 411, 0, 0, 39, '410'),
	(243, 1, 0, -50938, 412, 0, 0, 39, '411'),
	(243, 1, 0, -50938, 413, 0, 0, 39, '412'),
	(243, 1, 0, -50938, 414, 0, 0, 39, '413'),
	(243, 1, 0, -50938, 415, 0, 0, 39, '414'),
	(243, 1, 0, -50938, 416, 0, 0, 39, '415'),
	(243, 1, 0, -50938, 417, 0, 0, 39, '416'),
	(243, 1, 0, -50938, 418, 0, 0, 39, '417'),
	(243, 1, 0, -50938, 419, 0, 0, 39, '418'),
	(243, 1, 0, -50938, 420, 0, 0, 39, '419'),
	(243, 1, 0, -50938, 421, 0, 0, 39, '420'),
	(243, 1, 0, -50938, 422, 0, 0, 39, '421'),
	(243, 1, 0, -50938, 423, 0, 0, 39, '422'),
	(243, 1, 0, -50938, 424, 0, 0, 39, '423'),
	(243, 1, 0, -50938, 425, 0, 0, 39, '424'),
	(243, 1, 0, -50938, 426, 0, 0, 39, '425'),
	(243, 1, 0, -50938, 427, 0, 0, 39, '426'),
	(243, 1, 0, -50938, 428, 0, 0, 39, '427'),
	(243, 1, 0, -50938, 429, 0, 0, 39, '428'),
	(243, 1, 0, -50938, 430, 0, 0, 39, '429'),
	(243, 1, 0, -50938, 431, 0, 0, 39, '430'),
	(243, 1, 0, -50938, 432, 0, 0, 39, '431'),
	(243, 1, 0, -50938, 433, 0, 0, 39, '432'),
	(243, 1, 0, -50938, 434, 0, 0, 39, '433'),
	(243, 1, 0, -50938, 435, 0, 0, 39, '434'),
	(243, 1, 0, -50938, 436, 0, 0, 39, '435'),
	(243, 1, 0, -50938, 437, 0, 0, 39, '436'),
	(243, 1, 0, -50938, 438, 0, 0, 39, '437'),
	(243, 1, 0, -50938, 439, 0, 0, 39, '438'),
	(243, 1, 0, -50938, 440, 0, 0, 39, '439'),
	(243, 1, 0, -50938, 441, 0, 0, 39, '440'),
	(243, 1, 0, -50938, 442, 0, 0, 39, '441'),
	(243, 1, 0, -50938, 443, 0, 0, 39, '442'),
	(243, 1, 0, -50938, 444, 0, 0, 39, '443'),
	(243, 1, 0, -50938, 445, 0, 0, 39, '444'),
	(243, 1, 0, -50938, 446, 0, 0, 39, '445'),
	(243, 1, 0, -50938, 447, 0, 0, 39, '446'),
	(243, 1, 0, -50938, 448, 0, 0, 39, '447'),
	(243, 1, 0, -50938, 449, 0, 0, 39, '448'),
	(243, 1, 0, -50938, 450, 0, 0, 39, '449'),
	(243, 1, 0, -50938, 451, 0, 0, 39, '450'),
	(243, 1, 0, -50938, 452, 0, 0, 39, '451'),
	(243, 1, 0, -50938, 453, 0, 0, 39, '452'),
	(243, 1, 0, -50938, 454, 0, 0, 39, '453'),
	(243, 1, 0, -50938, 455, 0, 0, 39, '454'),
	(243, 1, 0, -50938, 456, 0, 0, 39, '455'),
	(243, 1, 0, -50938, 457, 0, 0, 39, '456'),
	(243, 1, 0, -50938, 458, 0, 0, 39, '457'),
	(243, 1, 0, -50938, 459, 0, 0, 39, '458'),
	(243, 1, 0, -50938, 460, 0, 0, 39, '459'),
	(243, 1, 0, -50938, 461, 0, 0, 39, '460'),
	(243, 1, 0, -50938, 462, 0, 0, 39, '461'),
	(243, 1, 0, -50938, 463, 0, 0, 39, '462'),
	(243, 1, 0, -50938, 464, 0, 0, 39, '463'),
	(243, 1, 0, -50938, 465, 0, 0, 39, '464'),
	(243, 1, 0, -50938, 466, 0, 0, 39, '465'),
	(243, 1, 0, -50938, 467, 0, 0, 39, '466'),
	(243, 1, 0, -50938, 468, 0, 0, 39, '467'),
	(243, 1, 0, -50938, 469, 0, 0, 39, '468'),
	(243, 1, 0, -50938, 470, 0, 0, 39, '469'),
	(243, 1, 0, -50938, 471, 0, 0, 39, '470'),
	(243, 1, 0, -50938, 472, 0, 0, 39, '471'),
	(243, 1, 0, -50938, 473, 0, 0, 39, '472'),
	(243, 1, 0, -50938, 474, 0, 0, 39, '473'),
	(243, 1, 0, -50938, 475, 0, 0, 39, '474'),
	(243, 1, 0, -50938, 476, 0, 0, 39, '475'),
	(243, 1, 0, -50938, 477, 0, 0, 39, '476'),
	(243, 1, 0, -50938, 478, 0, 0, 39, '477'),
	(243, 1, 0, -50938, 479, 0, 0, 39, '478'),
	(243, 1, 0, -50938, 480, 0, 0, 39, '479'),
	(243, 1, 0, -50938, 481, 0, 0, 39, '480'),
	(243, 1, 0, -50938, 482, 0, 0, 39, '481'),
	(243, 1, 0, -50938, 483, 0, 0, 39, '482'),
	(243, 1, 0, -50938, 484, 0, 0, 39, '483'),
	(243, 1, 0, -50938, 485, 0, 0, 39, '484'),
	(243, 1, 0, -50938, 486, 0, 0, 39, '485'),
	(243, 1, 0, -50938, 487, 0, 0, 39, '486'),
	(243, 1, 0, -50938, 488, 0, 0, 39, '487'),
	(243, 1, 0, -50938, 489, 0, 0, 39, '488'),
	(243, 1, 0, -50938, 490, 0, 0, 39, '489'),
	(243, 1, 0, -50938, 491, 0, 0, 39, '490'),
	(243, 1, 0, -50938, 492, 0, 0, 39, '491'),
	(243, 1, 0, -50938, 493, 0, 0, 39, '492'),
	(243, 1, 0, -50938, 494, 0, 0, 39, '493'),
	(243, 1, 0, -50938, 495, 0, 0, 39, '494'),
	(243, 1, 0, -50938, 496, 0, 0, 39, '495'),
	(243, 1, 0, -50938, 497, 0, 0, 39, '496'),
	(243, 1, 0, -50938, 498, 0, 0, 39, '497'),
	(243, 1, 0, -50938, 499, 0, 0, 39, '498'),
	(243, 1, 0, -50938, 500, 0, 0, 39, '499'),
	(243, 1, 0, -50938, 501, 0, 0, 39, '500'),
	(243, 1, 0, -50938, 502, 0, 0, 39, '501'),
	(243, 1, 0, -50938, 503, 0, 0, 39, '502'),
	(243, 1, 0, -50938, 504, 0, 0, 39, '503'),
	(243, 1, 0, -50938, 505, 0, 0, 39, '504'),
	(243, 1, 0, -50938, 506, 0, 0, 39, '505'),
	(243, 1, 0, -50938, 507, 0, 0, 39, '506'),
	(243, 1, 0, -50938, 508, 0, 0, 39, '507'),
	(243, 1, 0, -50938, 509, 0, 0, 39, '508'),
	(243, 1, 0, -50938, 510, 0, 0, 39, '509'),
	(243, 1, 0, -50938, 511, 0, 0, 39, '510'),
	(243, 1, 0, -50938, 512, 0, 0, 39, '511'),
	(243, 1, 0, -50938, 513, 0, 0, 39, '512'),
	(243, 1, 0, -50938, 514, 0, 0, 39, '513'),
	(243, 1, 0, -50938, 515, 0, 0, 39, '514'),
	(243, 1, 0, -50938, 516, 0, 0, 39, '515'),
	(243, 1, 0, -50938, 517, 0, 0, 39, '516'),
	(243, 1, 0, -50938, 518, 0, 0, 39, '517'),
	(243, 1, 0, -50938, 519, 0, 0, 39, '518'),
	(243, 1, 0, -50938, 520, 0, 0, 39, '519'),
	(243, 1, 0, -50938, 521, 0, 0, 39, '520'),
	(243, 1, 0, -50938, 522, 0, 0, 39, '521'),
	(243, 1, 0, -50938, 523, 0, 0, 39, '522'),
	(243, 1, 0, -50938, 524, 0, 0, 39, '523'),
	(243, 1, 0, -50938, 525, 0, 0, 39, '524'),
	(243, 1, 0, -50938, 526, 0, 0, 39, '525'),
	(243, 1, 0, -50938, 527, 0, 0, 39, '526'),
	(243, 1, 0, -50938, 528, 0, 0, 39, '527'),
	(243, 1, 0, -50938, 529, 0, 0, 39, '528'),
	(243, 1, 0, -50938, 530, 0, 0, 39, '529'),
	(243, 1, 0, -50938, 531, 0, 0, 39, '530'),
	(243, 1, 0, -50938, 532, 0, 0, 39, '531'),
	(243, 1, 0, -50938, 533, 0, 0, 39, '532'),
	(243, 1, 0, -50938, 534, 0, 0, 39, '533'),
	(243, 1, 0, -50938, 535, 0, 0, 39, '534'),
	(243, 1, 0, -50938, 536, 0, 0, 39, '535'),
	(243, 1, 0, -50938, 537, 0, 0, 39, '536'),
	(243, 1, 0, -50938, 538, 0, 0, 39, '537'),
	(243, 1, 0, -50938, 539, 0, 0, 39, '538'),
	(243, 1, 0, -50938, 540, 0, 0, 39, '539'),
	(243, 1, 0, -50938, 541, 0, 0, 39, '540'),
	(243, 1, 0, -50938, 542, 0, 0, 39, '541'),
	(243, 1, 0, -50938, 543, 0, 0, 39, '542'),
	(243, 1, 0, -50938, 544, 0, 0, 39, '543'),
	(243, 1, 0, -50938, 545, 0, 0, 39, '544'),
	(243, 1, 0, -50938, 546, 0, 0, 39, '545'),
	(243, 1, 0, -50938, 547, 0, 0, 39, '546'),
	(243, 1, 0, -50938, 548, 0, 0, 39, '547'),
	(243, 1, 0, -50938, 549, 0, 0, 39, '548'),
	(243, 1, 0, -50938, 550, 0, 0, 39, '549'),
	(243, 1, 0, -50938, 551, 0, 0, 39, '550'),
	(243, 1, 0, -50938, 552, 0, 0, 39, '551'),
	(243, 1, 0, -50938, 553, 0, 0, 39, '552'),
	(243, 1, 0, -50938, 554, 0, 0, 39, '553'),
	(243, 1, 0, -50938, 555, 0, 0, 39, '554'),
	(243, 1, 0, -50938, 556, 0, 0, 39, '555'),
	(243, 1, 0, -50938, 557, 0, 0, 39, '556'),
	(243, 1, 0, -50938, 558, 0, 0, 39, '557'),
	(243, 1, 0, -50938, 559, 0, 0, 39, '558'),
	(243, 1, 0, -50938, 560, 0, 0, 39, '559'),
	(243, 1, 0, -50938, 561, 0, 0, 39, '560'),
	(243, 1, 0, -50938, 562, 0, 0, 39, '561'),
	(243, 1, 0, -50938, 563, 0, 0, 39, '562'),
	(243, 1, 0, -50938, 564, 0, 0, 39, '563'),
	(243, 1, 0, -50938, 565, 0, 0, 39, '564'),
	(243, 1, 0, -50938, 566, 0, 0, 39, '565'),
	(243, 1, 0, -50938, 567, 0, 0, 39, '566'),
	(243, 1, 0, -50938, 568, 0, 0, 39, '567'),
	(243, 1, 0, -50938, 569, 0, 0, 39, '568'),
	(243, 1, 0, -50938, 570, 0, 0, 39, '569'),
	(243, 1, 0, -50938, 571, 0, 0, 39, '570'),
	(243, 1, 0, -50938, 572, 0, 0, 39, '571'),
	(243, 1, 0, -50938, 573, 0, 0, 39, '572'),
	(243, 1, 0, -50938, 574, 0, 0, 39, '573'),
	(243, 1, 0, -50938, 575, 0, 0, 39, '574'),
	(243, 1, 0, -50938, 576, 0, 0, 39, '575'),
	(243, 1, 0, -50938, 577, 0, 0, 39, '576'),
	(243, 1, 0, -50938, 578, 0, 0, 39, '577'),
	(243, 1, 0, -50938, 579, 0, 0, 39, '578'),
	(243, 1, 0, -50938, 580, 0, 0, 39, '579'),
	(243, 1, 0, -50938, 581, 0, 0, 39, '580'),
	(243, 1, 0, -50938, 582, 0, 0, 39, '581'),
	(243, 1, 0, -50938, 583, 0, 0, 39, '582'),
	(243, 1, 0, -50938, 584, 0, 0, 39, '583'),
	(243, 1, 0, -50938, 585, 0, 0, 39, '584'),
	(243, 1, 0, -50938, 586, 0, 0, 39, '585'),
	(243, 1, 0, -50938, 587, 0, 0, 39, '586'),
	(243, 1, 0, -50938, 588, 0, 0, 39, '587'),
	(243, 1, 0, -50938, 589, 0, 0, 39, '588'),
	(243, 1, 0, -50938, 590, 0, 0, 39, '589'),
	(243, 1, 0, -50938, 591, 0, 0, 39, '590'),
	(243, 1, 0, -50938, 592, 0, 0, 39, '591'),
	(243, 1, 0, -50938, 593, 0, 0, 39, '592'),
	(243, 1, 0, -50938, 594, 0, 0, 39, '593'),
	(243, 1, 0, -50938, 595, 0, 0, 39, '594'),
	(243, 1, 0, -50938, 596, 0, 0, 39, '595'),
	(243, 1, 0, -50938, 597, 0, 0, 39, '596'),
	(243, 1, 0, -50938, 598, 0, 0, 39, '597'),
	(243, 1, 0, -50938, 599, 0, 0, 39, '598'),
	(243, 1, 0, -50938, 600, 0, 0, 39, '599'),
	(243, 1, 0, -50938, 601, 0, 0, 39, '600'),
	(243, 1, 0, -50938, 602, 0, 0, 39, '601'),
	(243, 1, 0, -50938, 603, 0, 0, 39, '602'),
	(243, 1, 0, -50938, 604, 0, 0, 39, '603'),
	(243, 1, 0, -50938, 605, 0, 0, 39, '604'),
	(243, 1, 0, -50938, 606, 0, 0, 39, '605'),
	(243, 1, 0, -50938, 607, 0, 0, 39, '606'),
	(243, 1, 0, -50938, 608, 0, 0, 39, '607'),
	(243, 1, 0, -50938, 609, 0, 0, 39, '608'),
	(243, 1, 0, -50938, 610, 0, 0, 39, '609'),
	(243, 1, 0, -50938, 611, 0, 0, 39, '610'),
	(243, 1, 0, -50938, 612, 0, 0, 39, '611'),
	(243, 1, 0, -50938, 613, 0, 0, 39, '612'),
	(243, 1, 0, -50938, 614, 0, 0, 39, '613'),
	(243, 1, 0, -50938, 615, 0, 0, 39, '614'),
	(243, 1, 0, -50938, 616, 0, 0, 39, '615'),
	(243, 1, 0, -50938, 617, 0, 0, 39, '616'),
	(243, 1, 0, -50938, 618, 0, 0, 39, '617'),
	(243, 1, 0, -50938, 619, 0, 0, 39, '618'),
	(243, 1, 0, -50938, 620, 0, 0, 39, '619'),
	(243, 1, 0, -50938, 621, 0, 0, 39, '620'),
	(243, 1, 0, -50938, 622, 0, 0, 39, '621'),
	(243, 1, 0, -50938, 623, 0, 0, 39, '622'),
	(243, 1, 0, -50938, 624, 0, 0, 39, '623'),
	(243, 1, 0, -50938, 625, 0, 0, 39, '624'),
	(243, 1, 0, -50938, 626, 0, 0, 39, '625'),
	(243, 1, 0, -50938, 627, 0, 0, 39, '626'),
	(243, 1, 0, -50938, 628, 0, 0, 39, '627'),
	(243, 1, 0, -50938, 629, 0, 0, 39, '628'),
	(243, 1, 0, -50938, 630, 0, 0, 39, '629'),
	(243, 1, 0, -50938, 631, 0, 0, 39, '630'),
	(243, 1, 0, -50938, 632, 0, 0, 39, '631'),
	(243, 1, 0, -50938, 633, 0, 0, 39, '632'),
	(243, 1, 0, -50938, 634, 0, 0, 39, '633'),
	(243, 1, 0, -50938, 635, 0, 0, 39, '634'),
	(243, 1, 0, -50938, 636, 0, 0, 39, '635'),
	(243, 1, 0, -50938, 637, 0, 0, 39, '636'),
	(243, 1, 0, -50938, 638, 0, 0, 39, '637'),
	(243, 1, 0, -50938, 639, 0, 0, 39, '638'),
	(243, 1, 0, -50938, 640, 0, 0, 39, '639'),
	(243, 1, 0, -50938, 641, 0, 0, 39, '640'),
	(243, 1, 0, -50938, 642, 0, 0, 39, '641'),
	(243, 1, 0, -50938, 643, 0, 0, 39, '642'),
	(243, 1, 0, -50938, 644, 0, 0, 39, '643'),
	(243, 1, 0, -50938, 645, 0, 0, 39, '644'),
	(243, 1, 0, -50938, 646, 0, 0, 39, '645'),
	(243, 1, 0, -50938, 647, 0, 0, 39, '646'),
	(243, 1, 0, -50938, 648, 0, 0, 39, '647'),
	(243, 1, 0, -50938, 649, 0, 0, 39, '648'),
	(243, 1, 0, -50938, 650, 0, 0, 39, '649'),
	(243, 1, 0, -50938, 651, 0, 0, 39, '650'),
	(243, 1, 0, -50938, 652, 0, 0, 39, '651'),
	(243, 1, 0, -50938, 653, 0, 0, 39, '652'),
	(243, 1, 0, -50938, 654, 0, 0, 39, '653'),
	(243, 1, 0, -50938, 655, 0, 0, 39, '654'),
	(243, 1, 0, -50938, 656, 0, 0, 39, '655'),
	(243, 1, 0, -50938, 657, 0, 0, 39, '656'),
	(243, 1, 0, -50938, 658, 0, 0, 39, '657'),
	(243, 1, 0, -50938, 659, 0, 0, 39, '658'),
	(243, 1, 0, -50938, 660, 0, 0, 39, '659'),
	(243, 1, 0, -50938, 661, 0, 0, 39, '660'),
	(243, 1, 0, -50938, 662, 0, 0, 39, '661'),
	(243, 1, 0, -50938, 663, 0, 0, 39, '662'),
	(243, 1, 0, -50938, 664, 0, 0, 39, '663'),
	(243, 1, 0, -50938, 665, 0, 0, 39, '664'),
	(243, 1, 0, -50938, 666, 0, 0, 39, '665'),
	(243, 1, 0, -50938, 667, 0, 0, 39, '666'),
	(243, 1, 0, -50938, 668, 0, 0, 39, '667'),
	(243, 1, 0, -50938, 669, 0, 0, 39, '668'),
	(243, 1, 0, -50938, 670, 0, 0, 39, '669'),
	(243, 1, 0, -50938, 671, 0, 0, 39, '670'),
	(243, 1, 0, -50938, 672, 0, 0, 39, '671'),
	(243, 1, 0, -50938, 673, 0, 0, 39, '672'),
	(243, 1, 0, -50938, 674, 0, 0, 39, '673'),
	(243, 1, 0, -50938, 675, 0, 0, 39, '674'),
	(243, 1, 0, -50938, 676, 0, 0, 39, '675'),
	(243, 1, 0, -50938, 677, 0, 0, 39, '676'),
	(243, 1, 0, -50938, 678, 0, 0, 39, '677'),
	(243, 1, 0, -50938, 679, 0, 0, 39, '678'),
	(243, 1, 0, -50938, 680, 0, 0, 39, '679'),
	(243, 1, 0, -50938, 681, 0, 0, 39, '680'),
	(243, 1, 0, -50938, 682, 0, 0, 39, '681'),
	(243, 1, 0, -50938, 683, 0, 0, 39, '682'),
	(243, 1, 0, -50938, 684, 0, 0, 39, '683'),
	(243, 1, 0, -50938, 685, 0, 0, 39, '684'),
	(243, 1, 0, -50938, 686, 0, 0, 39, '685'),
	(243, 1, 0, -50938, 687, 0, 0, 39, '686'),
	(243, 1, 0, -50938, 688, 0, 0, 39, '687'),
	(243, 1, 0, -50938, 689, 0, 0, 39, '688'),
	(243, 1, 0, -50938, 690, 0, 0, 39, '689'),
	(243, 1, 0, -50938, 691, 0, 0, 39, '690'),
	(243, 1, 0, -50938, 692, 0, 0, 39, '691'),
	(243, 1, 0, -50938, 693, 0, 0, 39, '692'),
	(243, 1, 0, -50938, 694, 0, 0, 39, '693'),
	(243, 1, 0, -50938, 695, 0, 0, 39, '694'),
	(243, 1, 0, -50938, 696, 0, 0, 39, '695'),
	(243, 1, 0, -50938, 697, 0, 0, 39, '696'),
	(243, 1, 0, -50938, 698, 0, 0, 39, '697'),
	(243, 1, 0, -50938, 699, 0, 0, 39, '698'),
	(243, 1, 0, -50938, 700, 0, 0, 39, '699'),
	(243, 1, 0, -50938, 701, 0, 0, 39, '700'),
	(243, 1, 0, -50938, 702, 0, 0, 39, '701'),
	(243, 1, 0, -50938, 703, 0, 0, 39, '702'),
	(243, 1, 0, -50938, 704, 0, 0, 39, '703'),
	(243, 1, 0, -50938, 705, 0, 0, 39, '704'),
	(243, 1, 0, -50938, 706, 0, 0, 39, '705'),
	(243, 1, 0, -50938, 707, 0, 0, 39, '706'),
	(243, 1, 0, -50938, 708, 0, 0, 39, '707'),
	(243, 1, 0, -50938, 709, 0, 0, 39, '708'),
	(243, 1, 0, -50938, 710, 0, 0, 39, '709'),
	(243, 1, 0, -50938, 711, 0, 0, 39, '710'),
	(243, 1, 0, -50938, 712, 0, 0, 39, '711'),
	(243, 1, 0, -50938, 713, 0, 0, 39, '712'),
	(243, 1, 0, -50938, 714, 0, 0, 39, '713'),
	(243, 1, 0, -50938, 715, 0, 0, 39, '714'),
	(243, 1, 0, -50938, 716, 0, 0, 39, '715'),
	(243, 1, 0, -50938, 717, 0, 0, 39, '716'),
	(243, 1, 0, -50938, 718, 0, 0, 39, '717'),
	(243, 1, 0, -50938, 719, 0, 0, 39, '718'),
	(243, 1, 0, -50938, 720, 0, 0, 39, '719'),
	(243, 1, 0, -50938, 721, 0, 0, 39, '720'),
	(243, 1, 0, -50938, 722, 0, 0, 39, '721'),
	(243, 1, 0, -50938, 723, 0, 0, 39, '722'),
	(243, 1, 0, -50938, 724, 0, 0, 39, '723'),
	(243, 1, 0, -50938, 725, 0, 0, 39, '724'),
	(243, 1, 0, -50938, 726, 0, 0, 39, '725'),
	(243, 1, 0, -50938, 727, 0, 0, 39, '726'),
	(243, 1, 0, -50938, 728, 0, 0, 39, '727'),
	(243, 1, 0, -50938, 729, 0, 0, 39, '728'),
	(243, 1, 0, -50938, 730, 0, 0, 39, '729'),
	(243, 1, 0, -50938, 731, 0, 0, 39, '730'),
	(243, 1, 0, -50938, 732, 0, 0, 39, '731'),
	(243, 1, 0, -50938, 733, 0, 0, 39, '732'),
	(243, 1, 0, -50938, 734, 0, 0, 39, '733'),
	(243, 1, 0, -50938, 735, 0, 0, 39, '734'),
	(243, 1, 0, -50938, 736, 0, 0, 39, '735'),
	(243, 1, 0, -50938, 737, 0, 0, 39, '736'),
	(243, 1, 0, -50938, 738, 0, 0, 39, '737'),
	(243, 1, 0, -50938, 739, 0, 0, 39, '738'),
	(243, 1, 0, -50938, 740, 0, 0, 39, '739'),
	(243, 1, 0, -50938, 741, 0, 0, 39, '740'),
	(243, 1, 0, -50938, 742, 0, 0, 39, '741'),
	(243, 1, 0, -50938, 743, 0, 0, 39, '742'),
	(243, 1, 0, -50938, 744, 0, 0, 39, '743'),
	(243, 1, 0, -50938, 745, 0, 0, 39, '744'),
	(243, 1, 0, -50938, 746, 0, 0, 39, '745'),
	(243, 1, 0, -50938, 747, 0, 0, 39, '746'),
	(243, 1, 0, -50938, 748, 0, 0, 39, '747'),
	(243, 1, 0, -50938, 749, 0, 0, 39, '748'),
	(243, 1, 0, -50938, 750, 0, 0, 39, '749'),
	(243, 1, 0, -50938, 751, 0, 0, 39, '750'),
	(243, 1, 0, -50938, 752, 0, 0, 39, '751'),
	(243, 1, 0, -50938, 753, 0, 0, 39, '752'),
	(243, 1, 0, -50938, 754, 0, 0, 39, '753'),
	(243, 1, 0, -50938, 755, 0, 0, 39, '754'),
	(243, 1, 0, -50938, 756, 0, 0, 39, '755'),
	(243, 1, 0, -50938, 757, 0, 0, 39, '756'),
	(243, 1, 0, -50938, 758, 0, 0, 39, '757'),
	(243, 1, 0, -50938, 759, 0, 0, 39, '758'),
	(243, 1, 0, -50938, 760, 0, 0, 39, '759'),
	(243, 1, 0, -50938, 761, 0, 0, 39, '760'),
	(243, 1, 0, -50938, 762, 0, 0, 39, '761'),
	(243, 1, 0, -50938, 763, 0, 0, 39, '762'),
	(243, 1, 0, -50938, 764, 0, 0, 39, '763'),
	(243, 1, 0, -50938, 765, 0, 0, 39, '764'),
	(243, 1, 0, -50938, 766, 0, 0, 39, '765'),
	(243, 1, 0, -50938, 767, 0, 0, 39, '766'),
	(243, 1, 0, -50938, 768, 0, 0, 39, '767'),
	(243, 1, 0, -50938, 769, 0, 0, 39, '768'),
	(243, 1, 0, -50938, 770, 0, 0, 39, '769'),
	(243, 1, 0, -50938, 771, 0, 0, 39, '770'),
	(243, 1, 0, -50938, 772, 0, 0, 39, '771'),
	(243, 1, 0, -50938, 773, 0, 0, 39, '772'),
	(243, 1, 0, -50938, 774, 0, 0, 39, '773'),
	(243, 1, 0, -50938, 775, 0, 0, 39, '774'),
	(243, 1, 0, -50938, 776, 0, 0, 39, '775'),
	(243, 1, 0, -50938, 777, 0, 0, 39, '776'),
	(243, 1, 0, -50938, 778, 0, 0, 39, '777'),
	(243, 1, 0, -50938, 779, 0, 0, 39, '778'),
	(243, 1, 0, -50938, 780, 0, 0, 39, '779'),
	(243, 1, 0, -50938, 781, 0, 0, 39, '780'),
	(243, 1, 0, -50938, 782, 0, 0, 39, '781'),
	(243, 1, 0, -50938, 783, 0, 0, 39, '782'),
	(243, 1, 0, -50938, 784, 0, 0, 39, '783'),
	(243, 1, 0, -50938, 785, 0, 0, 39, '784'),
	(243, 1, 0, -50938, 786, 0, 0, 39, '785'),
	(243, 1, 0, -50938, 787, 0, 0, 39, '786'),
	(243, 1, 0, -50938, 788, 0, 0, 39, '787'),
	(243, 1, 0, -50938, 789, 0, 0, 39, '788'),
	(243, 1, 0, -50938, 790, 0, 0, 39, '789'),
	(243, 1, 0, -50938, 791, 0, 0, 39, '790'),
	(243, 1, 0, -50938, 792, 0, 0, 39, '791'),
	(243, 1, 0, -50938, 793, 0, 0, 39, '792'),
	(243, 1, 0, -50938, 794, 0, 0, 39, '793'),
	(243, 1, 0, -50938, 795, 0, 0, 39, '794'),
	(243, 1, 0, -50938, 796, 0, 0, 39, '795'),
	(243, 1, 0, -50938, 797, 0, 0, 39, '796'),
	(243, 1, 0, -50938, 798, 0, 0, 39, '797'),
	(243, 1, 0, -50938, 799, 0, 0, 39, '798'),
	(243, 1, 0, -50938, 800, 0, 0, 39, '799'),
	(243, 1, 0, -50938, 801, 0, 0, 39, '800'),
	(243, 1, 0, -50938, 802, 0, 0, 39, '801'),
	(243, 1, 0, -50938, 803, 0, 0, 39, '802'),
	(243, 1, 0, -50938, 804, 0, 0, 39, '803'),
	(243, 1, 0, -50938, 805, 0, 0, 39, '804'),
	(243, 1, 0, -50938, 806, 0, 0, 39, '805'),
	(243, 1, 0, -50938, 807, 0, 0, 39, '806'),
	(243, 1, 0, -50938, 808, 0, 0, 39, '807'),
	(243, 1, 0, -50938, 809, 0, 0, 39, '808'),
	(243, 1, 0, -50938, 810, 0, 0, 39, '809'),
	(243, 1, 0, -50938, 811, 0, 0, 39, '810'),
	(243, 1, 0, -50938, 812, 0, 0, 39, '811'),
	(243, 1, 0, -50938, 813, 0, 0, 39, '812'),
	(243, 1, 0, -50938, 814, 0, 0, 39, '813'),
	(243, 1, 0, -50938, 815, 0, 0, 39, '814'),
	(243, 1, 0, -50938, 816, 0, 0, 39, '815'),
	(243, 1, 0, -50938, 817, 0, 0, 39, '816'),
	(243, 1, 0, -50938, 818, 0, 0, 39, '817'),
	(243, 1, 0, -50938, 819, 0, 0, 39, '818'),
	(243, 1, 0, -50938, 820, 0, 0, 39, '819'),
	(243, 1, 0, -50938, 821, 0, 0, 39, '820'),
	(243, 1, 0, -50938, 822, 0, 0, 39, '821'),
	(243, 1, 0, -50938, 823, 0, 0, 39, '822'),
	(243, 1, 0, -50938, 824, 0, 0, 39, '823'),
	(243, 1, 0, -50938, 825, 0, 0, 39, '824'),
	(243, 1, 0, -50938, 826, 0, 0, 39, '825'),
	(243, 1, 0, -50938, 827, 0, 0, 39, '826'),
	(243, 1, 0, -50938, 828, 0, 0, 39, '827'),
	(243, 1, 0, -50938, 829, 0, 0, 39, '828'),
	(243, 1, 0, -50938, 830, 0, 0, 39, '829'),
	(243, 1, 0, -50938, 831, 0, 0, 39, '830'),
	(243, 1, 0, -50938, 832, 0, 0, 39, '831'),
	(243, 1, 0, -50938, 833, 0, 0, 39, '832'),
	(243, 1, 0, -50938, 834, 0, 0, 39, '833'),
	(243, 1, 0, -50938, 835, 0, 0, 39, '834'),
	(243, 1, 0, -50938, 836, 0, 0, 39, '835'),
	(243, 1, 0, -50938, 837, 0, 0, 39, '836'),
	(243, 1, 0, -50938, 838, 0, 0, 39, '837'),
	(243, 1, 0, -50938, 839, 0, 0, 39, '838'),
	(243, 1, 0, -50938, 840, 0, 0, 39, '839'),
	(243, 1, 0, -50938, 841, 0, 0, 39, '840'),
	(243, 1, 0, -50938, 842, 0, 0, 39, '841'),
	(243, 1, 0, -50938, 843, 0, 0, 39, '842'),
	(243, 1, 0, -50938, 844, 0, 0, 39, '843'),
	(243, 1, 0, -50938, 845, 0, 0, 39, '844'),
	(243, 1, 0, -50938, 846, 0, 0, 39, '845'),
	(243, 1, 0, -50938, 847, 0, 0, 39, '846'),
	(243, 1, 0, -50938, 848, 0, 0, 39, '847'),
	(243, 1, 0, -50938, 849, 0, 0, 39, '848'),
	(243, 1, 0, -50938, 850, 0, 0, 39, '849'),
	(243, 1, 0, -50938, 851, 0, 0, 39, '850'),
	(243, 1, 0, -50938, 852, 0, 0, 39, '851'),
	(243, 1, 0, -50938, 853, 0, 0, 39, '852'),
	(243, 1, 0, -50938, 854, 0, 0, 39, '853'),
	(243, 1, 0, -50938, 855, 0, 0, 39, '854'),
	(243, 1, 0, -50938, 856, 0, 0, 39, '855'),
	(243, 1, 0, -50938, 857, 0, 0, 39, '856'),
	(243, 1, 0, -50938, 858, 0, 0, 39, '857'),
	(243, 1, 0, -50938, 859, 0, 0, 39, '858'),
	(243, 1, 0, -50938, 860, 0, 0, 39, '859'),
	(243, 1, 0, -50938, 861, 0, 0, 39, '860'),
	(243, 1, 0, -50938, 862, 0, 0, 39, '861'),
	(243, 1, 0, -50938, 863, 0, 0, 39, '862'),
	(243, 1, 0, -50938, 864, 0, 0, 39, '863'),
	(243, 1, 0, -50938, 865, 0, 0, 39, '864'),
	(243, 1, 0, -50938, 866, 0, 0, 39, '865'),
	(243, 1, 0, -50938, 867, 0, 0, 39, '866'),
	(243, 1, 0, -50938, 868, 0, 0, 39, '867'),
	(243, 1, 0, -50938, 869, 0, 0, 39, '868'),
	(243, 1, 0, -50938, 870, 0, 0, 39, '869'),
	(243, 1, 0, -50938, 871, 0, 0, 39, '870'),
	(243, 1, 0, -50938, 872, 0, 0, 39, '871'),
	(243, 1, 0, -50938, 873, 0, 0, 39, '872'),
	(243, 1, 0, -50938, 874, 0, 0, 39, '873'),
	(243, 1, 0, -50938, 875, 0, 0, 39, '874'),
	(243, 1, 0, -50938, 876, 0, 0, 39, '875'),
	(243, 1, 0, -50938, 877, 0, 0, 39, '876'),
	(243, 1, 0, -50938, 878, 0, 0, 39, '877'),
	(243, 1, 0, -50938, 879, 0, 0, 39, '878'),
	(243, 1, 0, -50938, 880, 0, 0, 39, '879'),
	(243, 1, 0, -50938, 881, 0, 0, 39, '880'),
	(243, 1, 0, -50938, 882, 0, 0, 39, '881'),
	(243, 1, 0, -50938, 883, 0, 0, 39, '882'),
	(243, 1, 0, -50938, 884, 0, 0, 39, '883'),
	(243, 1, 0, -50938, 885, 0, 0, 39, '884'),
	(243, 1, 0, -50938, 886, 0, 0, 39, '885'),
	(243, 1, 0, -50938, 887, 0, 0, 39, '886'),
	(243, 1, 0, -50938, 888, 0, 0, 39, '887'),
	(243, 1, 0, -50938, 889, 0, 0, 39, '888'),
	(243, 1, 0, -50938, 890, 0, 0, 39, '889'),
	(243, 1, 0, -50938, 891, 0, 0, 39, '890'),
	(243, 1, 0, -50938, 892, 0, 0, 39, '891'),
	(243, 1, 0, -50938, 893, 0, 0, 39, '892'),
	(243, 1, 0, -50938, 894, 0, 0, 39, '893'),
	(243, 1, 0, -50938, 895, 0, 0, 39, '894'),
	(243, 1, 0, -50938, 896, 0, 0, 39, '895'),
	(243, 1, 0, -50938, 897, 0, 0, 39, '896'),
	(243, 1, 0, -50938, 898, 0, 0, 39, '897'),
	(243, 1, 0, -50938, 899, 0, 0, 39, '898'),
	(243, 1, 0, -50938, 900, 0, 0, 39, '899'),
	(243, 1, 0, -50938, 901, 0, 0, 39, '900'),
	(243, 1, 0, -50938, 902, 0, 0, 39, '901'),
	(243, 1, 0, -50938, 903, 0, 0, 39, '902'),
	(243, 1, 0, -50938, 904, 0, 0, 39, '903'),
	(243, 1, 0, -50938, 905, 0, 0, 39, '904'),
	(243, 1, 0, -50938, 906, 0, 0, 39, '905'),
	(243, 1, 0, -50938, 907, 0, 0, 39, '906'),
	(243, 1, 0, -50938, 908, 0, 0, 39, '907'),
	(243, 1, 0, -50938, 909, 0, 0, 39, '908'),
	(243, 1, 0, -50938, 910, 0, 0, 39, '909'),
	(243, 1, 0, -50938, 911, 0, 0, 39, '910'),
	(243, 1, 0, -50938, 912, 0, 0, 39, '911'),
	(243, 1, 0, -50938, 913, 0, 0, 39, '912'),
	(243, 1, 0, -50938, 914, 0, 0, 39, '913'),
	(243, 1, 0, -50938, 915, 0, 0, 39, '914'),
	(243, 1, 0, -50938, 916, 0, 0, 39, '915'),
	(243, 1, 0, -50938, 917, 0, 0, 39, '916'),
	(243, 1, 0, -50938, 918, 0, 0, 39, '917'),
	(243, 1, 0, -50938, 919, 0, 0, 39, '918'),
	(243, 1, 0, -50938, 920, 0, 0, 39, '919'),
	(243, 1, 0, -50938, 921, 0, 0, 39, '920'),
	(243, 1, 0, -50938, 922, 0, 0, 39, '921'),
	(243, 1, 0, -50938, 923, 0, 0, 39, '922'),
	(243, 1, 0, -50938, 924, 0, 0, 39, '923'),
	(243, 1, 0, -50938, 925, 0, 0, 39, '924'),
	(243, 1, 0, -50938, 926, 0, 0, 39, '925'),
	(243, 1, 0, -50938, 927, 0, 0, 39, '926'),
	(243, 1, 0, -50938, 928, 0, 0, 39, '927'),
	(243, 1, 0, -50938, 929, 0, 0, 39, '928'),
	(243, 1, 0, -50938, 930, 0, 0, 39, '929'),
	(243, 1, 0, -50938, 931, 0, 0, 39, '930'),
	(243, 1, 0, -50938, 932, 0, 0, 39, '931'),
	(243, 1, 0, -50938, 933, 0, 0, 39, '932'),
	(243, 1, 0, -50938, 934, 0, 0, 39, '933'),
	(243, 1, 0, -50938, 935, 0, 0, 39, '934'),
	(243, 1, 0, -50938, 936, 0, 0, 39, '935'),
	(243, 1, 0, -50938, 937, 0, 0, 39, '936'),
	(243, 1, 0, -50938, 938, 0, 0, 39, '937'),
	(243, 1, 0, -50938, 939, 0, 0, 39, '938'),
	(243, 1, 0, -50938, 940, 0, 0, 39, '939'),
	(243, 1, 0, -50938, 941, 0, 0, 39, '940'),
	(243, 1, 0, -50938, 942, 0, 0, 39, '941'),
	(243, 1, 0, -50938, 943, 0, 0, 39, '942'),
	(243, 1, 0, -50938, 944, 0, 0, 39, '943'),
	(243, 1, 0, -50938, 945, 0, 0, 39, '944'),
	(243, 1, 0, -50938, 946, 0, 0, 39, '945'),
	(243, 1, 0, -50938, 947, 0, 0, 39, '946'),
	(243, 1, 0, -50938, 948, 0, 0, 39, '947'),
	(243, 1, 0, -50938, 949, 0, 0, 39, '948'),
	(243, 1, 0, -50938, 950, 0, 0, 39, '949'),
	(243, 1, 0, -50938, 951, 0, 0, 39, '950'),
	(243, 1, 0, -50938, 952, 0, 0, 39, '951'),
	(243, 1, 0, -50938, 953, 0, 0, 39, '952'),
	(243, 1, 0, -50938, 954, 0, 0, 39, '953'),
	(243, 1, 0, -50938, 955, 0, 0, 39, '954'),
	(243, 1, 0, -50938, 956, 0, 0, 39, '955'),
	(243, 1, 0, -50938, 957, 0, 0, 39, '956'),
	(243, 1, 0, -50938, 958, 0, 0, 39, '957'),
	(243, 1, 0, -50938, 959, 0, 0, 39, '958'),
	(243, 1, 0, -50938, 960, 0, 0, 39, '959'),
	(243, 1, 0, -50938, 961, 0, 0, 39, '960'),
	(243, 1, 0, -50938, 962, 0, 0, 39, '961'),
	(243, 1, 0, -50938, 963, 0, 0, 39, '962'),
	(243, 1, 0, -50938, 964, 0, 0, 39, '963'),
	(243, 1, 0, -50938, 965, 0, 0, 39, '964'),
	(243, 1, 0, -50938, 966, 0, 0, 39, '965'),
	(243, 1, 0, -50938, 967, 0, 0, 39, '966'),
	(243, 1, 0, -50938, 968, 0, 0, 39, '967'),
	(243, 1, 0, -50938, 969, 0, 0, 39, '968'),
	(243, 1, 0, -50938, 970, 0, 0, 39, '969'),
	(243, 1, 0, -50938, 971, 0, 0, 39, '970'),
	(243, 1, 0, -50938, 972, 0, 0, 39, '971'),
	(243, 1, 0, -50938, 973, 0, 0, 39, '972'),
	(243, 1, 0, -50938, 974, 0, 0, 39, '973'),
	(243, 1, 0, -50938, 975, 0, 0, 39, '974'),
	(243, 1, 0, -50938, 976, 0, 0, 39, '975'),
	(243, 1, 0, -50938, 977, 0, 0, 39, '976'),
	(243, 1, 0, -50938, 978, 0, 0, 39, '977'),
	(243, 1, 0, -50938, 979, 0, 0, 39, '978'),
	(243, 1, 0, -50938, 980, 0, 0, 39, '979'),
	(243, 1, 0, -50938, 981, 0, 0, 39, '980'),
	(243, 1, 0, -50938, 982, 0, 0, 39, '981'),
	(243, 1, 0, -50938, 983, 0, 0, 39, '982'),
	(243, 1, 0, -50938, 984, 0, 0, 39, '983'),
	(243, 1, 0, -50938, 985, 0, 0, 39, '984'),
	(243, 1, 0, -50938, 986, 0, 0, 39, '985'),
	(243, 1, 0, -50938, 987, 0, 0, 39, '986'),
	(243, 1, 0, -50938, 988, 0, 0, 39, '987'),
	(243, 1, 0, -50938, 989, 0, 0, 39, '988'),
	(243, 1, 0, -50938, 990, 0, 0, 39, '989'),
	(243, 1, 0, -50938, 991, 0, 0, 39, '990'),
	(243, 1, 0, -50938, 992, 0, 0, 39, '991'),
	(243, 1, 0, -50938, 993, 0, 0, 39, '992'),
	(243, 1, 0, -50938, 994, 0, 0, 39, '993'),
	(243, 1, 0, -50938, 995, 0, 0, 39, '994'),
	(243, 1, 0, -50938, 996, 0, 0, 39, '995'),
	(243, 1, 0, -50938, 997, 0, 0, 39, '996'),
	(243, 1, 0, -50938, 998, 0, 0, 39, '997'),
	(243, 1, 0, -50938, 999, 0, 0, 39, '998'),
	(243, 1, 0, -50938, 1000, 0, 0, 39, '999'),
	(243, 1, 0, -50938, 1001, 0, 0, 39, '1000'),
	(243, 1, 0, -50938, 1002, 0, 0, 39, '1001'),
	(243, 1, 0, -50938, 1003, 0, 0, 39, '1002'),
	(243, 1, 0, -50938, 1004, 0, 0, 39, '1003'),
	(243, 1, 0, -50938, 1005, 0, 0, 39, '1004'),
	(243, 1, 0, -50938, 1006, 0, 0, 39, '1005'),
	(243, 1, 0, -50938, 1007, 0, 0, 39, '1006'),
	(243, 1, 0, -50938, 1008, 0, 0, 39, '1007'),
	(243, 1, 0, -50938, 1009, 0, 0, 39, '1008'),
	(243, 1, 0, -50938, 1010, 0, 0, 39, '1009'),
	(243, 1, 0, -50938, 1011, 0, 0, 39, '1010'),
	(243, 1, 0, -50938, 1012, 0, 0, 39, '1011'),
	(243, 1, 0, -50938, 1013, 0, 0, 39, '1012'),
	(243, 1, 0, -50938, 1014, 0, 0, 39, '1013'),
	(243, 1, 0, -50938, 1015, 0, 0, 39, '1014'),
	(243, 1, 0, -50938, 1016, 0, 0, 39, '1015'),
	(243, 1, 0, -50938, 1017, 0, 0, 39, '1016'),
	(243, 1, 0, -50938, 1018, 0, 0, 39, '1017'),
	(243, 1, 0, -50938, 1019, 0, 0, 39, '1018'),
	(243, 1, 0, -50938, 1020, 0, 0, 39, '1019'),
	(243, 1, 0, -50938, 1021, 0, 0, 39, '1020'),
	(243, 1, 0, -50938, 1022, 0, 0, 39, '1021'),
	(243, 1, 0, -50938, 1023, 0, 0, 39, '1022'),
	(243, 1, 0, -50938, 1024, 0, 0, 39, '1023'),
	(243, 1, 0, -50938, 1025, 0, 0, 39, '1024'),
	(243, 1, 0, -50938, 1026, 0, 0, 39, '1025'),
	(243, 1, 0, -50938, 1027, 0, 0, 39, '1026'),
	(243, 1, 0, -50938, 1028, 0, 0, 39, '1027'),
	(243, 1, 0, -50938, 1029, 0, 0, 39, '1028'),
	(243, 1, 0, -50938, 1030, 0, 0, 39, '1029'),
	(243, 1, 0, -50938, 1031, 0, 0, 39, '1030'),
	(243, 1, 0, -50938, 1032, 0, 0, 39, '1031'),
	(243, 1, 0, -50938, 1033, 0, 0, 39, '1032'),
	(243, 1, 0, -50938, 1034, 0, 0, 39, '1033'),
	(243, 1, 0, -50938, 1035, 0, 0, 39, '1034'),
	(243, 1, 0, -50938, 1036, 0, 0, 39, '1035'),
	(243, 1, 0, -50938, 1037, 0, 0, 39, '1036'),
	(243, 1, 0, -50938, 1038, 0, 0, 39, '1037'),
	(243, 1, 0, -50938, 1039, 0, 0, 39, '1038'),
	(243, 1, 0, -50938, 1040, 0, 0, 39, '1039'),
	(243, 1, 0, -50938, 1041, 0, 0, 39, '1040'),
	(243, 1, 0, -50938, 1042, 0, 0, 39, '1041'),
	(243, 1, 0, -50938, 1043, 0, 0, 39, '1042'),
	(243, 1, 0, -50938, 1044, 0, 0, 39, '1043'),
	(243, 1, 0, -50938, 1045, 0, 0, 39, '1044'),
	(243, 1, 0, -50938, 1046, 0, 0, 39, '1045'),
	(243, 1, 0, -50938, 1047, 0, 0, 39, '1046'),
	(243, 1, 0, -50938, 1048, 0, 0, 39, '1047'),
	(243, 1, 0, -50938, 1049, 0, 0, 39, '1048'),
	(243, 1, 0, -50938, 1050, 0, 0, 39, '1049'),
	(243, 1, 0, -50938, 1051, 0, 0, 39, '1050'),
	(243, 1, 0, -50938, 1052, 0, 0, 39, '1051'),
	(243, 1, 0, -50938, 1053, 0, 0, 39, '1052'),
	(243, 1, 0, -50938, 1054, 0, 0, 39, '1053'),
	(243, 1, 0, -50938, 1055, 0, 0, 39, '1054'),
	(243, 1, 0, -50938, 1056, 0, 0, 39, '1055'),
	(243, 1, 0, -50938, 1057, 0, 0, 39, '1056'),
	(243, 1, 0, -50938, 1058, 0, 0, 39, '1057'),
	(243, 1, 0, -50938, 1059, 0, 0, 39, '1058'),
	(243, 1, 0, -50938, 1060, 0, 0, 39, '1059'),
	(243, 1, 0, -50938, 1061, 0, 0, 39, '1060'),
	(243, 1, 0, -50938, 1062, 0, 0, 39, '1061'),
	(243, 1, 0, -50938, 1063, 0, 0, 39, '1062'),
	(243, 1, 0, -50938, 1064, 0, 0, 39, '1063'),
	(243, 1, 0, -50938, 1065, 0, 0, 39, '1064'),
	(243, 1, 0, -50938, 1066, 0, 0, 39, '1065'),
	(243, 1, 0, -50938, 1067, 0, 0, 39, '1066'),
	(243, 1, 0, -50938, 1068, 0, 0, 39, '1067'),
	(243, 1, 0, -50938, 1069, 0, 0, 39, '1068'),
	(243, 1, 0, -50938, 1070, 0, 0, 39, '1069'),
	(243, 1, 0, -50938, 1071, 0, 0, 39, '1070'),
	(243, 1, 0, -50938, 1072, 0, 0, 39, '1071'),
	(243, 1, 0, -50938, 1073, 0, 0, 39, '1072'),
	(243, 1, 0, -50938, 1074, 0, 0, 39, '1073'),
	(243, 1, 0, -50938, 1075, 0, 0, 39, '1074'),
	(243, 1, 0, -50938, 1076, 0, 0, 39, '1075'),
	(243, 1, 0, -50938, 1077, 0, 0, 39, '1076'),
	(243, 1, 0, -50938, 1078, 0, 0, 39, '1077'),
	(243, 1, 0, -50938, 1079, 0, 0, 39, '1078'),
	(243, 1, 0, -50938, 1080, 0, 0, 39, '1079'),
	(243, 1, 0, -50938, 1081, 0, 0, 39, '1080'),
	(243, 1, 0, -50938, 1082, 0, 0, 39, '1081'),
	(243, 1, 0, -50938, 1083, 0, 0, 39, '1082'),
	(243, 1, 0, -50938, 1084, 0, 0, 39, '1083'),
	(243, 1, 0, -50938, 1085, 0, 0, 39, '1084'),
	(243, 1, 0, -50938, 1086, 0, 0, 39, '1085'),
	(243, 1, 0, -50938, 1087, 0, 0, 39, '1086'),
	(243, 1, 0, -50938, 1088, 0, 0, 39, '1087'),
	(243, 1, 0, -50938, 1089, 0, 0, 39, '1088'),
	(243, 1, 0, -50938, 1090, 0, 0, 39, '1089'),
	(243, 1, 0, -50938, 1091, 0, 0, 39, '1090'),
	(243, 1, 0, -50938, 1092, 0, 0, 39, '1091'),
	(243, 1, 0, -50938, 1093, 0, 0, 39, '1092'),
	(243, 1, 0, -50938, 1094, 0, 0, 39, '1093'),
	(243, 1, 0, -50938, 1095, 0, 0, 39, '1094'),
	(243, 1, 0, -50938, 1096, 0, 0, 39, '1095'),
	(243, 1, 0, -50938, 1097, 0, 0, 39, '1096'),
	(243, 1, 0, -50938, 1098, 0, 0, 39, '1097'),
	(243, 1, 0, -50938, 1099, 0, 0, 39, '1098'),
	(243, 1, 0, -50938, 1100, 0, 0, 39, '1099'),
	(243, 1, 0, -50938, 1101, 0, 0, 39, '1100'),
	(243, 1, 0, -50938, 1102, 0, 0, 39, '1101'),
	(243, 1, 0, -50938, 1103, 0, 0, 39, '1102'),
	(243, 1, 0, -50938, 1104, 0, 0, 39, '1103'),
	(243, 1, 0, -50938, 1105, 0, 0, 39, '1104'),
	(243, 1, 0, -50938, 1106, 0, 0, 39, '1105'),
	(243, 1, 0, -50938, 1107, 0, 0, 39, '1106'),
	(243, 1, 0, -50938, 1108, 0, 0, 39, '1107'),
	(243, 1, 0, -50938, 1109, 0, 0, 39, '1108'),
	(243, 1, 0, -50938, 1110, 0, 0, 39, '1109'),
	(243, 1, 0, -50938, 1111, 0, 0, 39, '1110'),
	(243, 1, 0, -50938, 1112, 0, 0, 39, '1111'),
	(243, 1, 0, -50938, 1113, 0, 0, 39, '1112'),
	(243, 1, 0, -50938, 1114, 0, 0, 39, '1113'),
	(243, 1, 0, -50938, 1115, 0, 0, 39, '1114'),
	(243, 1, 0, -50938, 1116, 0, 0, 39, '1115'),
	(243, 1, 0, -50938, 1117, 0, 0, 39, '1116'),
	(243, 1, 0, -50938, 1118, 0, 0, 39, '1117'),
	(243, 1, 0, -50938, 1119, 0, 0, 39, '1118'),
	(243, 1, 0, -50938, 1120, 0, 0, 39, '1119'),
	(243, 1, 0, -50938, 1121, 0, 0, 39, '1120'),
	(243, 1, 0, -50938, 1122, 0, 0, 39, '1121'),
	(243, 1, 0, -50938, 1123, 0, 0, 39, '1122'),
	(243, 1, 0, -50938, 1124, 0, 0, 39, '1123'),
	(243, 1, 0, -50938, 1125, 0, 0, 39, '1124'),
	(243, 1, 0, -50938, 1126, 0, 0, 39, '1125'),
	(243, 1, 0, -50938, 1127, 0, 0, 39, '1126'),
	(243, 1, 0, -50938, 1128, 0, 0, 39, '1127'),
	(243, 1, 0, -50938, 1129, 0, 0, 39, '1128'),
	(243, 1, 0, -50938, 1130, 0, 0, 39, '1129'),
	(243, 1, 0, -50938, 1131, 0, 0, 39, '1130'),
	(243, 1, 0, -50938, 1132, 0, 0, 39, '1131'),
	(243, 1, 0, -50938, 1133, 0, 0, 39, '1132'),
	(243, 1, 0, -50938, 1134, 0, 0, 39, '1133'),
	(243, 1, 0, -50938, 1135, 0, 0, 39, '1134'),
	(243, 1, 0, -50938, 1136, 0, 0, 39, '1135'),
	(243, 1, 0, -50938, 1137, 0, 0, 39, '1136'),
	(243, 1, 0, -50938, 1138, 0, 0, 39, '1137'),
	(243, 1, 0, -50938, 1139, 0, 0, 39, '1138'),
	(243, 1, 0, -50938, 1140, 0, 0, 39, '1139'),
	(243, 1, 0, -50938, 1141, 0, 0, 39, '1140'),
	(243, 1, 0, -50938, 1142, 0, 0, 39, '1141'),
	(243, 1, 0, -50938, 1143, 0, 0, 39, '1142'),
	(243, 1, 0, -50938, 1144, 0, 0, 39, '1143'),
	(243, 1, 0, -50938, 1145, 0, 0, 39, '1144'),
	(243, 1, 0, -50938, 1146, 0, 0, 39, '1145'),
	(243, 1, 0, -50938, 1147, 0, 0, 39, '1146'),
	(243, 1, 0, -50938, 1148, 0, 0, 39, '1147'),
	(243, 1, 0, -50938, 1149, 0, 0, 39, '1148'),
	(243, 1, 0, -50938, 1150, 0, 0, 39, '1149'),
	(243, 1, 0, -50938, 1151, 0, 0, 39, '1150'),
	(243, 1, 0, -50938, 1152, 0, 0, 39, '1151'),
	(243, 1, 0, -50938, 1153, 0, 0, 39, '1152'),
	(243, 1, 0, -50938, 1154, 0, 0, 39, '1153'),
	(243, 1, 0, -50938, 1155, 0, 0, 39, '1154'),
	(243, 1, 0, -50938, 1156, 0, 0, 39, '1155'),
	(243, 1, 0, -50938, 1157, 0, 0, 39, '1156'),
	(243, 1, 0, -50938, 1158, 0, 0, 39, '1157'),
	(243, 1, 0, -50938, 1159, 0, 0, 39, '1158'),
	(243, 1, 0, -50938, 1160, 0, 0, 39, '1159'),
	(243, 1, 0, -50938, 1161, 0, 0, 39, '1160'),
	(243, 1, 0, -50938, 1162, 0, 0, 39, '1161'),
	(243, 1, 0, -50938, 1163, 0, 0, 39, '1162'),
	(243, 1, 0, -50938, 1164, 0, 0, 39, '1163'),
	(243, 1, 0, -50938, 1165, 0, 0, 39, '1164'),
	(243, 1, 0, -50938, 1166, 0, 0, 39, '1165'),
	(243, 1, 0, -50938, 1167, 0, 0, 39, '1166'),
	(243, 1, 0, -50938, 1168, 0, 0, 39, '1167'),
	(243, 1, 0, -50938, 1169, 0, 0, 39, '1168'),
	(243, 1, 0, -50938, 1170, 0, 0, 39, '1169'),
	(243, 1, 0, -50938, 1171, 0, 0, 39, '1170'),
	(243, 1, 0, -50938, 1172, 0, 0, 39, '1171'),
	(243, 1, 0, -50938, 1173, 0, 0, 39, '1172'),
	(243, 1, 0, -50938, 1174, 0, 0, 39, '1173'),
	(243, 1, 0, -50938, 1175, 0, 0, 39, '1174'),
	(243, 1, 0, -50938, 1176, 0, 0, 39, '1175'),
	(243, 1, 0, -50938, 1177, 0, 0, 39, '1176'),
	(243, 1, 0, -50938, 1178, 0, 0, 39, '1177'),
	(243, 1, 0, -50938, 1179, 0, 0, 39, '1178'),
	(243, 1, 0, -50938, 1180, 0, 0, 39, '1179'),
	(243, 1, 0, -50938, 1181, 0, 0, 39, '1180'),
	(243, 1, 0, -50938, 1182, 0, 0, 39, '1181'),
	(243, 1, 0, -50938, 1183, 0, 0, 39, '1182'),
	(243, 1, 0, -50938, 1184, 0, 0, 39, '1183'),
	(243, 1, 0, -50938, 1185, 0, 0, 39, '1184'),
	(243, 1, 0, -50938, 1186, 0, 0, 39, '1185'),
	(243, 1, 0, -50938, 1187, 0, 0, 39, '1186'),
	(243, 1, 0, -50938, 1188, 0, 0, 39, '1187'),
	(243, 1, 0, -50938, 1189, 0, 0, 39, '1188'),
	(243, 1, 0, -50938, 1190, 0, 0, 39, '1189'),
	(243, 1, 0, -50938, 1191, 0, 0, 39, '1190'),
	(243, 1, 0, -50938, 1192, 0, 0, 39, '1191'),
	(243, 1, 0, -50938, 1193, 0, 0, 39, '1192'),
	(243, 1, 0, -50938, 1194, 0, 0, 39, '1193'),
	(243, 1, 0, -50938, 1195, 0, 0, 39, '1194'),
	(243, 1, 0, -50938, 1196, 0, 0, 39, '1195'),
	(243, 1, 0, -50938, 1197, 0, 0, 39, '1196'),
	(243, 1, 0, -50938, 1198, 0, 0, 39, '1197'),
	(243, 1, 0, -50938, 1199, 0, 0, 39, '1198'),
	(243, 1, 0, -50938, 1200, 0, 0, 39, '1199'),
	(243, 1, 0, -50938, 1201, 0, 0, 39, '1200'),
	(243, 1, 0, -50938, 1202, 0, 0, 39, '1201'),
	(243, 1, 0, -50938, 1203, 0, 0, 39, '1202'),
	(243, 1, 0, -50938, 1204, 0, 0, 39, '1203'),
	(243, 1, 0, -50938, 1205, 0, 0, 39, '1204'),
	(243, 1, 0, -50938, 1206, 0, 0, 39, '1205'),
	(243, 1, 0, -50938, 1207, 0, 0, 39, '1206'),
	(243, 1, 0, -50938, 1208, 0, 0, 39, '1207'),
	(243, 1, 0, -50938, 1209, 0, 0, 39, '1208'),
	(243, 1, 0, -50938, 1210, 0, 0, 39, '1209'),
	(243, 1, 0, -50938, 1211, 0, 0, 39, '1210'),
	(243, 1, 0, -50938, 1212, 0, 0, 39, '1211'),
	(243, 1, 0, -50938, 1213, 0, 0, 39, '1212'),
	(243, 1, 0, -50938, 1214, 0, 0, 39, '1213'),
	(243, 1, 0, -50938, 1215, 0, 0, 39, '1214'),
	(243, 1, 0, -50938, 1216, 0, 0, 39, '1215'),
	(243, 1, 0, -50938, 1217, 0, 0, 39, '1216'),
	(243, 1, 0, -50938, 1218, 0, 0, 39, '1217'),
	(243, 1, 0, -50938, 1219, 0, 0, 39, '1218'),
	(243, 1, 0, -50938, 1220, 0, 0, 39, '1219'),
	(243, 1, 0, -50938, 1221, 0, 0, 39, '1220'),
	(243, 1, 0, -50938, 1222, 0, 0, 39, '1221'),
	(243, 1, 0, -50938, 1223, 0, 0, 39, '1222'),
	(243, 1, 0, -50938, 1224, 0, 0, 39, '1223'),
	(243, 1, 0, -50938, 1225, 0, 0, 39, '1224'),
	(243, 1, 0, -50938, 1226, 0, 0, 39, '1225'),
	(243, 1, 0, -50938, 1227, 0, 0, 39, '1226'),
	(243, 1, 0, -50938, 1228, 0, 0, 39, '1227'),
	(243, 1, 0, -50938, 1229, 0, 0, 39, '1228'),
	(243, 1, 0, -50938, 1230, 0, 0, 39, '1229'),
	(243, 1, 0, -50938, 1231, 0, 0, 39, '1230'),
	(243, 1, 0, -50938, 1232, 0, 0, 39, '1231'),
	(243, 1, 0, -50938, 1233, 0, 0, 39, '1232'),
	(243, 1, 0, -50938, 1234, 0, 0, 39, '1233'),
	(243, 1, 0, -50938, 1235, 0, 0, 39, '1234'),
	(243, 1, 0, -50938, 1236, 0, 0, 39, '1235'),
	(243, 1, 0, -50938, 1237, 0, 0, 39, '1236'),
	(243, 1, 0, -50938, 1238, 0, 0, 39, '1237'),
	(243, 1, 0, -50938, 1239, 0, 0, 39, '1238'),
	(243, 1, 0, -50938, 1240, 0, 0, 39, '1239'),
	(243, 1, 0, -50938, 1241, 0, 0, 39, '1240'),
	(243, 1, 0, -50938, 1242, 0, 0, 39, '1241'),
	(243, 1, 0, -50938, 1243, 0, 0, 39, '1242'),
	(243, 1, 0, -50938, 1244, 0, 0, 39, '1243'),
	(243, 1, 0, -50938, 1245, 0, 0, 39, '1244'),
	(243, 1, 0, -50938, 1246, 0, 0, 39, '1245'),
	(243, 1, 0, -50938, 1247, 0, 0, 39, '1246'),
	(243, 1, 0, -50938, 1248, 0, 0, 39, '1247'),
	(243, 1, 0, -50938, 1249, 0, 0, 39, '1248'),
	(243, 1, 0, -50938, 1250, 0, 0, 39, '1249'),
	(243, 1, 0, -50938, 1251, 0, 0, 39, '1250'),
	(243, 1, 0, -50938, 1252, 0, 0, 39, '1251'),
	(243, 1, 0, -50938, 1253, 0, 0, 39, '1252'),
	(243, 1, 0, -50938, 1254, 0, 0, 39, '1253'),
	(243, 1, 0, -50938, 1255, 0, 0, 39, '1254'),
	(243, 1, 0, -50938, 1256, 0, 0, 39, '1255'),
	(243, 1, 0, -50938, 1257, 0, 0, 39, '1256'),
	(243, 1, 0, -50938, 1258, 0, 0, 39, '1257'),
	(243, 1, 0, -50938, 1259, 0, 0, 39, '1258'),
	(243, 1, 0, -50938, 1260, 0, 0, 39, '1259'),
	(243, 1, 0, -50938, 1261, 0, 0, 39, '1260'),
	(243, 1, 0, -50938, 1262, 0, 0, 39, '1261'),
	(243, 1, 0, -50938, 1263, 0, 0, 39, '1262'),
	(243, 1, 0, -50938, 1264, 0, 0, 39, '1263'),
	(243, 1, 0, -50938, 1265, 0, 0, 39, '1264'),
	(243, 1, 0, -50938, 1266, 0, 0, 39, '1265'),
	(243, 1, 0, -50938, 1267, 0, 0, 39, '1266'),
	(243, 1, 0, -50938, 1268, 0, 0, 39, '1267'),
	(243, 1, 0, -50938, 1269, 0, 0, 39, '1268'),
	(243, 1, 0, -50938, 1270, 0, 0, 39, '1269'),
	(243, 1, 0, -50938, 1271, 0, 0, 39, '1270'),
	(243, 1, 0, -50938, 1272, 0, 0, 39, '1271'),
	(243, 1, 0, -50938, 1273, 0, 0, 39, '1272'),
	(243, 1, 0, -50938, 1274, 0, 0, 39, '1273'),
	(243, 1, 0, -50938, 1275, 0, 0, 39, '1274'),
	(243, 1, 0, -50938, 1276, 0, 0, 39, '1275'),
	(243, 1, 0, -50938, 1277, 0, 0, 39, '1276'),
	(243, 1, 0, -50938, 1278, 0, 0, 39, '1277'),
	(243, 1, 0, -50938, 1279, 0, 0, 39, '1278'),
	(243, 1, 0, -50938, 1280, 0, 0, 39, '1279'),
	(243, 1, 0, -50938, 1281, 0, 0, 39, '1280'),
	(243, 1, 0, -50938, 1282, 0, 0, 39, '1281'),
	(243, 1, 0, -50938, 1283, 0, 0, 39, '1282'),
	(243, 1, 0, -50938, 1284, 0, 0, 39, '1283'),
	(243, 1, 0, -50938, 1285, 0, 0, 39, '1284'),
	(243, 1, 0, -50938, 1286, 0, 0, 39, '1285'),
	(243, 1, 0, -50938, 1287, 0, 0, 39, '1286'),
	(243, 1, 0, -50938, 1288, 0, 0, 39, '1287'),
	(243, 1, 0, -50938, 1289, 0, 0, 39, '1288'),
	(243, 1, 0, -50938, 1290, 0, 0, 39, '1289'),
	(243, 1, 0, -50938, 1291, 0, 0, 39, '1290'),
	(243, 1, 0, -50938, 1292, 0, 0, 39, '1291'),
	(243, 1, 0, -50938, 1293, 0, 0, 39, '1292'),
	(243, 1, 0, -50938, 1294, 0, 0, 39, '1293'),
	(243, 1, 0, -50938, 1295, 0, 0, 39, '1294'),
	(243, 1, 0, -50938, 1296, 0, 0, 39, '1295'),
	(243, 1, 0, -50938, 1297, 0, 0, 39, '1296'),
	(243, 1, 0, -50938, 1298, 0, 0, 39, '1297'),
	(243, 1, 0, -50938, 1299, 0, 0, 39, '1298'),
	(243, 1, 0, -50938, 1300, 0, 0, 39, '1299'),
	(243, 1, 0, -50938, 1301, 0, 0, 39, '1300'),
	(243, 1, 0, -50938, 1302, 0, 0, 39, '1301'),
	(243, 1, 0, -50938, 1303, 0, 0, 39, '1302'),
	(243, 1, 0, -50938, 1304, 0, 0, 39, '1303'),
	(243, 1, 0, -50938, 1305, 0, 0, 39, '1304'),
	(243, 1, 0, -50938, 1306, 0, 0, 39, '1305'),
	(243, 1, 0, -50938, 1307, 0, 0, 39, '1306'),
	(243, 1, 0, -50938, 1308, 0, 0, 39, '1307'),
	(243, 1, 0, -50938, 1309, 0, 0, 39, '1308'),
	(243, 1, 0, -50938, 1310, 0, 0, 39, '1309'),
	(243, 1, 0, -50938, 1311, 0, 0, 39, '1310'),
	(243, 1, 0, -50938, 1312, 0, 0, 39, '1311'),
	(243, 1, 0, -50938, 1313, 0, 0, 39, '1312'),
	(243, 1, 0, -50938, 1314, 0, 0, 39, '1313'),
	(243, 1, 0, -50938, 1315, 0, 0, 39, '1314'),
	(243, 1, 0, -50938, 1316, 0, 0, 39, '1315'),
	(243, 1, 0, -50938, 1317, 0, 0, 39, '1316'),
	(243, 1, 0, -50938, 1318, 0, 0, 39, '1317'),
	(243, 1, 0, -50938, 1319, 0, 0, 39, '1318'),
	(243, 1, 0, -50938, 1320, 0, 0, 39, '1319'),
	(243, 1, 0, -50938, 1321, 0, 0, 39, '1320'),
	(243, 1, 0, -50938, 1322, 0, 0, 39, '1321'),
	(243, 1, 0, -50938, 1323, 0, 0, 39, '1322'),
	(243, 1, 0, -50938, 1324, 0, 0, 39, '1323'),
	(243, 1, 0, -50938, 1325, 0, 0, 39, '1324'),
	(243, 1, 0, -50938, 1326, 0, 0, 39, '1325'),
	(243, 1, 0, -50938, 1327, 0, 0, 39, '1326'),
	(243, 1, 0, -50938, 1328, 0, 0, 39, '1327'),
	(243, 1, 0, -50938, 1329, 0, 0, 39, '1328'),
	(243, 1, 0, -50938, 1330, 0, 0, 39, '1329'),
	(243, 1, 0, -50938, 1331, 0, 0, 39, '1330'),
	(243, 1, 0, -50938, 1332, 0, 0, 39, '1331'),
	(243, 1, 0, -50938, 1333, 0, 0, 39, '1332'),
	(243, 1, 0, -50938, 1334, 0, 0, 39, '1333'),
	(243, 1, 0, -50938, 1335, 0, 0, 39, '1334'),
	(243, 1, 0, -50938, 1336, 0, 0, 39, '1335'),
	(243, 1, 0, -50938, 1337, 0, 0, 39, '1336'),
	(243, 1, 0, -50938, 1338, 0, 0, 39, '1337'),
	(243, 1, 0, -50938, 1339, 0, 0, 39, '1338'),
	(243, 1, 0, -50938, 1340, 0, 0, 39, '1339'),
	(243, 1, 0, -50938, 1341, 0, 0, 39, '1340'),
	(243, 1, 0, -50938, 1342, 0, 0, 39, '1341'),
	(243, 1, 0, -50938, 1343, 0, 0, 39, '1342'),
	(243, 1, 0, -50938, 1344, 0, 0, 39, '1343'),
	(243, 1, 0, -50938, 1345, 0, 0, 39, '1344'),
	(243, 1, 0, -50938, 1346, 0, 0, 39, '1345'),
	(243, 1, 0, -50938, 1347, 0, 0, 39, '1346'),
	(243, 1, 0, -50938, 1348, 0, 0, 39, '1347'),
	(243, 1, 0, -50938, 1349, 0, 0, 39, '1348'),
	(243, 1, 0, -50938, 1350, 0, 0, 39, '1349'),
	(243, 1, 0, -50938, 1351, 0, 0, 39, '1350'),
	(243, 1, 0, -50938, 1352, 0, 0, 39, '1351'),
	(243, 1, 0, -50938, 1353, 0, 0, 39, '1352'),
	(243, 1, 0, -50938, 1354, 0, 0, 39, '1353'),
	(243, 1, 0, -50938, 1355, 0, 0, 39, '1354'),
	(243, 1, 0, -50938, 1356, 0, 0, 39, '1355'),
	(243, 1, 0, -50938, 1357, 0, 0, 39, '1356'),
	(243, 1, 0, -50938, 1358, 0, 0, 39, '1357'),
	(243, 1, 0, -50938, 1359, 0, 0, 39, '1358'),
	(243, 1, 0, -50938, 1360, 0, 0, 39, '1359'),
	(243, 1, 0, -50938, 1361, 0, 0, 39, '1360'),
	(243, 1, 0, -50938, 1362, 0, 0, 39, '1361'),
	(243, 1, 0, -50938, 1363, 0, 0, 39, '1362'),
	(243, 1, 0, -50938, 1364, 0, 0, 39, '1363'),
	(243, 1, 0, -50938, 1365, 0, 0, 39, '1364'),
	(243, 1, 0, -50938, 1366, 0, 0, 39, '1365'),
	(243, 1, 0, -50938, 1367, 0, 0, 39, '1366'),
	(243, 1, 0, -50938, 1368, 0, 0, 39, '1367'),
	(243, 1, 0, -50938, 1369, 0, 0, 39, '1368'),
	(243, 1, 0, -50938, 1370, 0, 0, 39, '1369'),
	(243, 1, 0, -50938, 1371, 0, 0, 39, '1370'),
	(243, 1, 0, -50938, 1372, 0, 0, 39, '1371'),
	(243, 1, 0, -50938, 1373, 0, 0, 39, '1372'),
	(243, 1, 0, -50938, 1374, 0, 0, 39, '1373'),
	(243, 1, 0, -50938, 1375, 0, 0, 39, '1374'),
	(243, 1, 0, -50938, 1376, 0, 0, 39, '1375'),
	(243, 1, 0, -50938, 1377, 0, 0, 39, '1376'),
	(243, 1, 0, -50938, 1378, 0, 0, 39, '1377'),
	(243, 1, 0, -50938, 1379, 0, 0, 39, '1378'),
	(243, 1, 0, -50938, 1380, 0, 0, 39, '1379'),
	(243, 1, 0, -50938, 1381, 0, 0, 39, '1380'),
	(243, 1, 0, -50938, 1382, 0, 0, 39, '1381'),
	(243, 1, 0, -50938, 1383, 0, 0, 39, '1382'),
	(243, 1, 0, -50938, 1384, 0, 0, 39, '1383'),
	(243, 1, 0, -50938, 1385, 0, 0, 39, '1384'),
	(243, 1, 0, -50938, 1386, 0, 0, 39, '1385'),
	(243, 1, 0, -50938, 1387, 0, 0, 39, '1386'),
	(243, 1, 0, -50938, 1388, 0, 0, 39, '1387'),
	(243, 1, 0, -50938, 1389, 0, 0, 39, '1388'),
	(243, 1, 0, -50938, 1390, 0, 0, 39, '1389'),
	(243, 1, 0, -50938, 1391, 0, 0, 39, '1390'),
	(243, 1, 0, -50938, 1392, 0, 0, 39, '1391'),
	(243, 1, 0, -50938, 1393, 0, 0, 39, '1392'),
	(243, 1, 0, -50938, 1394, 0, 0, 39, '1393'),
	(243, 1, 0, -50938, 1395, 0, 0, 39, '1394'),
	(243, 1, 0, -50938, 1396, 0, 0, 39, '1395'),
	(243, 1, 0, -50938, 1397, 0, 0, 39, '1396'),
	(243, 1, 0, -50938, 1398, 0, 0, 39, '1397'),
	(243, 1, 0, -50938, 1399, 0, 0, 39, '1398'),
	(243, 1, 0, -50938, 1400, 0, 0, 39, '1399'),
	(243, 1, 0, -50938, 1401, 0, 0, 39, '1400'),
	(243, 1, 0, -50938, 1402, 0, 0, 39, '1401'),
	(243, 1, 0, -50938, 1403, 0, 0, 39, '1402'),
	(243, 1, 0, -50938, 1404, 0, 0, 39, '1403'),
	(243, 1, 0, -50938, 1405, 0, 0, 39, '1404'),
	(243, 1, 0, -50938, 1406, 0, 0, 39, '1405'),
	(243, 1, 0, -50938, 1407, 0, 0, 39, '1406'),
	(243, 1, 0, -50938, 1408, 0, 0, 39, '1407'),
	(243, 1, 0, -50938, 1409, 0, 0, 39, '1408'),
	(243, 1, 0, -50938, 1410, 0, 0, 39, '1409'),
	(243, 1, 0, -50938, 1411, 0, 0, 39, '1410'),
	(243, 1, 0, -50938, 1412, 0, 0, 39, '1411'),
	(243, 1, 0, -50938, 1413, 0, 0, 39, '1412'),
	(243, 1, 0, -50938, 1414, 0, 0, 39, '1413'),
	(243, 1, 0, -50938, 1415, 0, 0, 39, '1414'),
	(243, 1, 0, -50938, 1416, 0, 0, 39, '1415'),
	(243, 1, 0, -50938, 1417, 0, 0, 39, '1416'),
	(243, 1, 0, -50938, 1418, 0, 0, 39, '1417'),
	(243, 1, 0, -50938, 1419, 0, 0, 39, '1418'),
	(243, 1, 0, -50938, 1420, 0, 0, 39, '1419'),
	(243, 1, 0, -50938, 1421, 0, 0, 39, '1420'),
	(243, 1, 0, -50938, 1422, 0, 0, 39, '1421'),
	(243, 1, 0, -50938, 1423, 0, 0, 39, '1422'),
	(243, 1, 0, -50938, 1424, 0, 0, 39, '1423'),
	(243, 1, 0, -50938, 1425, 0, 0, 39, '1424'),
	(243, 1, 0, -50938, 1426, 0, 0, 39, '1425'),
	(243, 1, 0, -50938, 1427, 0, 0, 39, '1426'),
	(243, 1, 0, -50938, 1428, 0, 0, 39, '1427'),
	(243, 1, 0, -50938, 1429, 0, 0, 39, '1428'),
	(243, 1, 0, -50938, 1430, 0, 0, 39, '1429'),
	(243, 1, 0, -50938, 1431, 0, 0, 39, '1430'),
	(243, 1, 0, -50938, 1432, 0, 0, 39, '1431'),
	(243, 1, 0, -50938, 1433, 0, 0, 39, '1432'),
	(243, 1, 0, -50938, 1434, 0, 0, 39, '1433'),
	(243, 1, 0, -50938, 1435, 0, 0, 39, '1434'),
	(243, 1, 0, -50938, 1436, 0, 0, 39, '1435'),
	(243, 1, 0, -50938, 1437, 0, 0, 39, '1436'),
	(243, 1, 0, -50938, 1438, 0, 0, 39, '1437'),
	(243, 1, 0, -50938, 1439, 0, 0, 39, '1438'),
	(243, 1, 0, -50938, 1440, 0, 0, 39, '1439'),
	(243, 1, 0, -50938, 1441, 0, 0, 39, '1440'),
	(243, 1, 0, -50938, 1442, 0, 0, 39, '1441'),
	(243, 1, 0, -50938, 1443, 0, 0, 39, '1442'),
	(243, 1, 0, -50938, 1444, 0, 0, 39, '1443'),
	(243, 1, 0, -50938, 1445, 0, 0, 39, '1444'),
	(243, 1, 0, -50938, 1446, 0, 0, 39, '1445'),
	(243, 1, 0, -50938, 1447, 0, 0, 39, '1446'),
	(243, 1, 0, -50938, 1448, 0, 0, 39, '1447'),
	(243, 1, 0, -50938, 1449, 0, 0, 39, '1448'),
	(243, 1, 0, -50938, 1450, 0, 0, 39, '1449'),
	(243, 1, 0, -50938, 1451, 0, 0, 39, '1450'),
	(243, 1, 0, -50938, 1452, 0, 0, 39, '1451'),
	(243, 1, 0, -50938, 1453, 0, 0, 39, '1452'),
	(243, 1, 0, -50938, 1454, 0, 0, 39, '1453'),
	(243, 1, 0, -50938, 1455, 0, 0, 39, '1454'),
	(243, 1, 0, -50938, 1456, 0, 0, 39, '1455'),
	(243, 1, 0, -50938, 1457, 0, 0, 39, '1456'),
	(243, 1, 0, -50938, 1458, 0, 0, 39, '1457'),
	(243, 1, 0, -50938, 1459, 0, 0, 39, '1458'),
	(243, 1, 0, -50938, 1460, 0, 0, 39, '1459'),
	(243, 1, 0, -50938, 1461, 0, 0, 39, '1460'),
	(243, 1, 0, -50938, 1462, 0, 0, 39, '1461'),
	(243, 1, 0, -50938, 1463, 0, 0, 39, '1462'),
	(243, 1, 0, -50938, 1464, 0, 0, 39, '1463'),
	(243, 1, 0, -50938, 1465, 0, 0, 39, '1464'),
	(243, 1, 0, -50938, 1466, 0, 0, 39, '1465'),
	(243, 1, 0, -50938, 1467, 0, 0, 39, '1466'),
	(243, 1, 0, -50938, 1468, 0, 0, 39, '1467'),
	(243, 1, 0, -50938, 1469, 0, 0, 39, '1468'),
	(243, 1, 0, -50938, 1470, 0, 0, 39, '1469'),
	(243, 1, 0, -50938, 1471, 0, 0, 39, '1470'),
	(243, 1, 0, -50938, 1472, 0, 0, 39, '1471'),
	(243, 1, 0, -50938, 1473, 0, 0, 39, '1472'),
	(243, 1, 0, -50938, 1474, 0, 0, 39, '1473'),
	(243, 1, 0, -50938, 1475, 0, 0, 39, '1474'),
	(243, 1, 0, -50938, 1476, 0, 0, 39, '1475'),
	(243, 1, 0, -50938, 1477, 0, 0, 39, '1476'),
	(243, 1, 0, -50938, 1478, 0, 0, 39, '1477'),
	(243, 1, 0, -50938, 1479, 0, 0, 39, '1478'),
	(243, 1, 0, -50938, 1480, 0, 0, 39, '1479'),
	(243, 1, 0, -50938, 1481, 0, 0, 39, '1480'),
	(243, 1, 0, -50938, 1482, 0, 0, 39, '1481'),
	(243, 1, 0, -50938, 1483, 0, 0, 39, '1482'),
	(243, 1, 0, -50938, 1484, 0, 0, 39, '1483'),
	(243, 1, 0, -50938, 1485, 0, 0, 39, '1484'),
	(243, 1, 0, -50938, 1486, 0, 0, 39, '1485'),
	(243, 1, 0, -50938, 1487, 0, 0, 39, '1486'),
	(243, 1, 0, -50938, 1488, 0, 0, 39, '1487'),
	(243, 1, 0, -50938, 1489, 0, 0, 39, '1488'),
	(243, 1, 0, -50938, 1490, 0, 0, 39, '1489'),
	(243, 1, 0, -50938, 1491, 0, 0, 39, '1490'),
	(243, 1, 0, -50938, 1492, 0, 0, 39, '1491'),
	(243, 1, 0, -50938, 1493, 0, 0, 39, '1492'),
	(243, 1, 0, -50938, 1494, 0, 0, 39, '1493'),
	(243, 1, 0, -50938, 1495, 0, 0, 39, '1494'),
	(243, 1, 0, -50938, 1496, 0, 0, 39, '1495'),
	(243, 1, 0, -50938, 1497, 0, 0, 39, '1496'),
	(243, 1, 0, -50938, 1498, 0, 0, 39, '1497'),
	(243, 1, 0, -50938, 1499, 0, 0, 39, '1498'),
	(243, 1, 0, -50938, 1500, 0, 0, 39, '1499'),
	(243, 1, 0, -50938, 1501, 0, 0, 39, '1500'),
	(243, 1, 0, -50938, 1502, 0, 0, 39, '1501'),
	(243, 1, 0, -50938, 1503, 0, 0, 39, '1502'),
	(243, 1, 0, -50938, 1504, 0, 0, 39, '1503'),
	(243, 1, 0, -50938, 1505, 0, 0, 39, '1504'),
	(243, 1, 0, -50938, 1506, 0, 0, 39, '1505'),
	(243, 1, 0, -50938, 1507, 0, 0, 39, '1506'),
	(243, 1, 0, -50938, 1508, 0, 0, 39, '1507'),
	(243, 1, 0, -50938, 1509, 0, 0, 39, '1508'),
	(243, 1, 0, -50938, 1510, 0, 0, 39, '1509'),
	(243, 1, 0, -50938, 1511, 0, 0, 39, '1510'),
	(243, 1, 0, -50938, 1512, 0, 0, 39, '1511'),
	(243, 1, 0, -50938, 1513, 0, 0, 39, '1512'),
	(243, 1, 0, -50938, 1514, 0, 0, 39, '1513'),
	(243, 1, 0, -50938, 1515, 0, 0, 39, '1514'),
	(243, 1, 0, -50938, 1516, 0, 0, 39, '1515'),
	(243, 1, 0, -50938, 1517, 0, 0, 39, '1516'),
	(243, 1, 0, -50938, 1518, 0, 0, 39, '1517'),
	(243, 1, 0, -50938, 1519, 0, 0, 39, '1518'),
	(243, 1, 0, -50938, 1520, 0, 0, 39, '1519'),
	(243, 1, 0, -50938, 1521, 0, 0, 39, '1520'),
	(243, 1, 0, -50938, 1522, 0, 0, 39, '1521'),
	(243, 1, 0, -50938, 1523, 0, 0, 39, '1522'),
	(243, 1, 0, -50938, 1524, 0, 0, 39, '1523'),
	(243, 1, 0, -50938, 1525, 0, 0, 39, '1524'),
	(243, 1, 0, -50938, 1526, 0, 0, 39, '1525'),
	(243, 1, 0, -50938, 1527, 0, 0, 39, '1526'),
	(243, 1, 0, -50938, 1528, 0, 0, 39, '1527'),
	(243, 1, 0, -50938, 1529, 0, 0, 39, '1528'),
	(243, 1, 0, -50938, 1530, 0, 0, 39, '1529'),
	(243, 1, 0, -50938, 1531, 0, 0, 39, '1530'),
	(243, 1, 0, -50938, 1532, 0, 0, 39, '1531'),
	(243, 1, 0, -50938, 1533, 0, 0, 39, '1532'),
	(243, 1, 0, -50938, 1534, 0, 0, 39, '1533'),
	(243, 1, 0, -50938, 1535, 0, 0, 39, '1534'),
	(243, 1, 0, -50938, 1536, 0, 0, 39, '1535'),
	(243, 1, 0, -50938, 1537, 0, 0, 39, '1536'),
	(243, 1, 0, -50938, 1538, 0, 0, 39, '1537'),
	(243, 1, 0, -50938, 1539, 0, 0, 39, '1538'),
	(243, 1, 0, -50938, 1540, 0, 0, 39, '1539'),
	(243, 1, 0, -50938, 1541, 0, 0, 39, '1540'),
	(243, 1, 0, -50938, 1542, 0, 0, 39, '1541'),
	(243, 1, 0, -50938, 1543, 0, 0, 39, '1542'),
	(243, 1, 0, -50938, 1544, 0, 0, 39, '1543'),
	(243, 1, 0, -50938, 1545, 0, 0, 39, '1544'),
	(243, 1, 0, -50938, 1546, 0, 0, 39, '1545'),
	(243, 1, 0, -50938, 1547, 0, 0, 39, '1546'),
	(243, 1, 0, -50938, 1548, 0, 0, 39, '1547'),
	(243, 1, 0, -50938, 1549, 0, 0, 39, '1548'),
	(243, 1, 0, -50938, 1550, 0, 0, 39, '1549'),
	(243, 1, 0, -50938, 1551, 0, 0, 39, '1550'),
	(243, 1, 0, -50938, 1552, 0, 0, 39, '1551'),
	(243, 1, 0, -50938, 1553, 0, 0, 39, '1552'),
	(243, 1, 0, -50938, 1554, 0, 0, 39, '1553'),
	(243, 1, 0, -50938, 1555, 0, 0, 39, '1554'),
	(243, 1, 0, -50938, 1556, 0, 0, 39, '1555'),
	(243, 1, 0, -50938, 1557, 0, 0, 39, '1556'),
	(243, 1, 0, -50938, 1558, 0, 0, 39, '1557'),
	(243, 1, 0, -50938, 1559, 0, 0, 39, '1558'),
	(243, 1, 0, -50938, 1560, 0, 0, 39, '1559'),
	(243, 1, 0, -50938, 1561, 0, 0, 39, '1560'),
	(243, 1, 0, -50938, 1562, 0, 0, 39, '1561'),
	(243, 1, 0, -50938, 1563, 0, 0, 39, '1562'),
	(243, 1, 0, -50938, 1564, 0, 0, 39, '1563'),
	(243, 1, 0, -50938, 1565, 0, 0, 39, '1564'),
	(243, 1, 0, -50938, 1566, 0, 0, 39, '1565'),
	(243, 1, 0, -50938, 1567, 0, 0, 39, '1566'),
	(243, 1, 0, -50938, 1568, 0, 0, 39, '1567'),
	(243, 1, 0, -50938, 1569, 0, 0, 39, '1568'),
	(243, 1, 0, -50938, 1570, 0, 0, 39, '1569'),
	(243, 1, 0, -50938, 1571, 0, 0, 39, '1570'),
	(243, 1, 0, -50938, 1572, 0, 0, 39, '1571'),
	(243, 1, 0, -50938, 1573, 0, 0, 39, '1572'),
	(243, 1, 0, -50938, 1574, 0, 0, 39, '1573'),
	(243, 1, 0, -50938, 1575, 0, 0, 39, '1574'),
	(243, 1, 0, -50938, 1576, 0, 0, 39, '1575'),
	(243, 1, 0, -50938, 1577, 0, 0, 39, '1576'),
	(243, 1, 0, -50938, 1578, 0, 0, 39, '1577'),
	(243, 1, 0, -50938, 1579, 0, 0, 39, '1578'),
	(243, 1, 0, -50938, 1580, 0, 0, 39, '1579'),
	(243, 1, 0, -50938, 1581, 0, 0, 39, '1580'),
	(243, 1, 0, -50938, 1582, 0, 0, 39, '1581'),
	(243, 1, 0, -50938, 1583, 0, 0, 39, '1582'),
	(243, 1, 0, -50938, 1584, 0, 0, 39, '1583'),
	(243, 1, 0, -50938, 1585, 0, 0, 39, '1584'),
	(243, 1, 0, -50938, 1586, 0, 0, 39, '1585'),
	(243, 1, 0, -50938, 1587, 0, 0, 39, '1586'),
	(243, 1, 0, -50938, 1588, 0, 0, 39, '1587'),
	(243, 1, 0, -50938, 1589, 0, 0, 39, '1588'),
	(243, 1, 0, -50938, 1590, 0, 0, 39, '1589'),
	(243, 1, 0, -50938, 1591, 0, 0, 39, '1590'),
	(243, 1, 0, -50938, 1592, 0, 0, 39, '1591'),
	(243, 1, 0, -50938, 1593, 0, 0, 39, '1592'),
	(243, 1, 0, -50938, 1594, 0, 0, 39, '1593'),
	(243, 1, 0, -50938, 1595, 0, 0, 39, '1594'),
	(243, 1, 0, -50938, 1596, 0, 0, 39, '1595'),
	(243, 1, 0, -50938, 1597, 0, 0, 39, '1596'),
	(243, 1, 0, -50938, 1598, 0, 0, 39, '1597'),
	(243, 1, 0, -50938, 1599, 0, 0, 39, '1598'),
	(243, 1, 0, -50938, 1600, 0, 0, 39, '1599'),
	(243, 1, 0, -50938, 1601, 0, 0, 39, '1600'),
	(243, 1, 0, -50938, 1602, 0, 0, 39, '1601'),
	(243, 1, 0, -50938, 1603, 0, 0, 39, '1602'),
	(243, 1, 0, -50938, 1604, 0, 0, 39, '1603'),
	(243, 1, 0, -50938, 1605, 0, 0, 39, '1604'),
	(243, 1, 0, -50938, 1606, 0, 0, 39, '1605'),
	(243, 1, 0, -50938, 1607, 0, 0, 39, '1606'),
	(243, 1, 0, -50938, 1608, 0, 0, 39, '1607'),
	(243, 1, 0, -50938, 1609, 0, 0, 39, '1608'),
	(243, 1, 0, -50938, 1610, 0, 0, 39, '1609'),
	(243, 1, 0, -50938, 1611, 0, 0, 39, '1610'),
	(243, 1, 0, -50938, 1612, 0, 0, 39, '1611'),
	(243, 1, 0, -50938, 1613, 0, 0, 39, '1612'),
	(243, 1, 0, -50938, 1614, 0, 0, 39, '1613'),
	(243, 1, 0, -50938, 1615, 0, 0, 39, '1614'),
	(243, 1, 0, -50938, 1616, 0, 0, 39, '1615'),
	(243, 1, 0, -50938, 1617, 0, 0, 39, '1616'),
	(243, 1, 0, -50938, 1618, 0, 0, 39, '1617'),
	(243, 1, 0, -50938, 1619, 0, 0, 39, '1618'),
	(243, 1, 0, -50938, 1620, 0, 0, 39, '1619'),
	(243, 1, 0, -50938, 1621, 0, 0, 39, '1620'),
	(243, 1, 0, -50938, 1622, 0, 0, 39, '1621'),
	(243, 1, 0, -50938, 1623, 0, 0, 39, '1622'),
	(243, 1, 0, -50938, 1624, 0, 0, 39, '1623'),
	(243, 1, 0, -50938, 1625, 0, 0, 39, '1624'),
	(243, 1, 0, -50938, 1626, 0, 0, 39, '1625'),
	(243, 1, 0, -50938, 1627, 0, 0, 39, '1626'),
	(243, 1, 0, -50938, 1628, 0, 0, 39, '1627'),
	(243, 1, 0, -50938, 1629, 0, 0, 39, '1628'),
	(243, 1, 0, -50938, 1630, 0, 0, 39, '1629'),
	(243, 1, 0, -50938, 1631, 0, 0, 39, '1630'),
	(243, 1, 0, -50938, 1632, 0, 0, 39, '1631'),
	(243, 1, 0, -50938, 1633, 0, 0, 39, '1632'),
	(243, 1, 0, -50938, 1634, 0, 0, 39, '1633'),
	(243, 1, 0, -50938, 1635, 0, 0, 39, '1634'),
	(243, 1, 0, -50938, 1636, 0, 0, 39, '1635'),
	(243, 1, 0, -50938, 1637, 0, 0, 39, '1636'),
	(243, 1, 0, -50938, 1638, 0, 0, 39, '1637'),
	(243, 1, 0, -50938, 1639, 0, 0, 39, '1638'),
	(243, 1, 0, -50938, 1640, 0, 0, 39, '1639'),
	(243, 1, 0, -50938, 1641, 0, 0, 39, '1640'),
	(243, 1, 0, -50938, 1642, 0, 0, 39, '1641'),
	(243, 1, 0, -50938, 1643, 0, 0, 39, '1642'),
	(243, 1, 0, -50938, 1644, 0, 0, 39, '1643'),
	(243, 1, 0, -50938, 1645, 0, 0, 39, '1644'),
	(243, 1, 0, -50938, 1646, 0, 0, 39, '1645'),
	(243, 1, 0, -50938, 1647, 0, 0, 39, '1646'),
	(243, 1, 0, -50938, 1648, 0, 0, 39, '1647'),
	(243, 1, 0, -50938, 1649, 0, 0, 39, '1648'),
	(243, 1, 0, -50938, 1650, 0, 0, 39, '1649'),
	(243, 1, 0, -50938, 1651, 0, 0, 39, '1650'),
	(243, 1, 0, -50938, 1652, 0, 0, 39, '1651'),
	(243, 1, 0, -50938, 1653, 0, 0, 39, '1652'),
	(243, 1, 0, -50938, 1654, 0, 0, 39, '1653'),
	(243, 1, 0, -50938, 1655, 0, 0, 39, '1654'),
	(243, 1, 0, -50938, 1656, 0, 0, 39, '1655'),
	(243, 1, 0, -50938, 1657, 0, 0, 39, '1656'),
	(243, 1, 0, -50938, 1658, 0, 0, 39, '1657'),
	(243, 1, 0, -50938, 1659, 0, 0, 39, '1658'),
	(243, 1, 0, -50938, 1660, 0, 0, 39, '1659'),
	(243, 1, 0, -50938, 1661, 0, 0, 39, '1660'),
	(243, 1, 0, -50938, 1662, 0, 0, 39, '1661'),
	(243, 1, 0, -50938, 1663, 0, 0, 39, '1662'),
	(243, 1, 0, -50938, 1664, 0, 0, 39, '1663'),
	(243, 1, 0, -50938, 1665, 0, 0, 39, '1664'),
	(243, 1, 0, -50938, 1666, 0, 0, 39, '1665'),
	(243, 1, 0, -50938, 1667, 0, 0, 39, '1666'),
	(243, 1, 0, -50938, 1668, 0, 0, 39, '1667'),
	(243, 1, 0, -50938, 1669, 0, 0, 39, '1668'),
	(243, 1, 0, -50938, 1670, 0, 0, 39, '1669'),
	(243, 1, 0, -50938, 1671, 0, 0, 39, '1670'),
	(243, 1, 0, -50938, 1672, 0, 0, 39, '1671'),
	(243, 1, 0, -50938, 1673, 0, 0, 39, '1672'),
	(243, 1, 0, -50938, 1674, 0, 0, 39, '1673'),
	(243, 1, 0, -50938, 1675, 0, 0, 39, '1674'),
	(243, 1, 0, -50938, 1676, 0, 0, 39, '1675'),
	(243, 1, 0, -50938, 1677, 0, 0, 39, '1676'),
	(243, 1, 0, -50938, 1678, 0, 0, 39, '1677'),
	(243, 1, 0, -50938, 1679, 0, 0, 39, '1678'),
	(243, 1, 0, -50938, 1680, 0, 0, 39, '1679'),
	(243, 1, 0, -50938, 1681, 0, 0, 39, '1680'),
	(243, 1, 0, -50938, 1682, 0, 0, 39, '1681'),
	(243, 1, 0, -50938, 1683, 0, 0, 39, '1682'),
	(243, 1, 0, -50938, 1684, 0, 0, 39, '1683'),
	(243, 1, 0, -50938, 1685, 0, 0, 39, '1684'),
	(243, 1, 0, -50938, 1686, 0, 0, 39, '1685'),
	(243, 1, 0, -50938, 1687, 0, 0, 39, '1686'),
	(243, 1, 0, -50938, 1688, 0, 0, 39, '1687'),
	(243, 1, 0, -50938, 1689, 0, 0, 39, '1688'),
	(243, 1, 0, -50938, 1690, 0, 0, 39, '1689'),
	(243, 1, 0, -50938, 1691, 0, 0, 39, '1690'),
	(243, 1, 0, -50938, 1692, 0, 0, 39, '1691'),
	(243, 1, 0, -50938, 1693, 0, 0, 39, '1692'),
	(243, 1, 0, -50938, 1694, 0, 0, 39, '1693'),
	(243, 1, 0, -50938, 1695, 0, 0, 39, '1694'),
	(243, 1, 0, -50938, 1696, 0, 0, 39, '1695'),
	(243, 1, 0, -50938, 1697, 0, 0, 39, '1696'),
	(243, 1, 0, -50938, 1698, 0, 0, 39, '1697'),
	(243, 1, 0, -50938, 1699, 0, 0, 39, '1698'),
	(243, 1, 0, -50938, 1700, 0, 0, 39, '1699'),
	(243, 1, 0, -50938, 1701, 0, 0, 39, '1700'),
	(243, 1, 0, -50938, 1702, 0, 0, 39, '1701'),
	(243, 1, 0, -50938, 1703, 0, 0, 39, '1702'),
	(243, 1, 0, -50938, 1704, 0, 0, 39, '1703'),
	(243, 1, 0, -50938, 1705, 0, 0, 39, '1704'),
	(243, 1, 0, -50938, 1706, 0, 0, 39, '1705'),
	(243, 1, 0, -50938, 1707, 0, 0, 39, '1706'),
	(243, 1, 0, -50938, 1708, 0, 0, 39, '1707'),
	(243, 1, 0, -50938, 1709, 0, 0, 39, '1708'),
	(243, 1, 0, -50938, 1710, 0, 0, 39, '1709'),
	(243, 1, 0, -50938, 1711, 0, 0, 39, '1710'),
	(243, 1, 0, -50938, 1712, 0, 0, 39, '1711'),
	(243, 1, 0, -50938, 1713, 0, 0, 39, '1712'),
	(243, 1, 0, -50938, 1714, 0, 0, 39, '1713'),
	(243, 1, 0, -50938, 1715, 0, 0, 39, '1714'),
	(243, 1, 0, -50938, 1716, 0, 0, 39, '1715'),
	(243, 1, 0, -50938, 1717, 0, 0, 39, '1716'),
	(243, 1, 0, -50938, 1718, 0, 0, 39, '1717'),
	(243, 1, 0, -50938, 1719, 0, 0, 39, '1718'),
	(243, 1, 0, -50938, 1720, 0, 0, 39, '1719'),
	(243, 1, 0, -50938, 1721, 0, 0, 39, '1720'),
	(243, 1, 0, -50938, 1722, 0, 0, 39, '1721'),
	(243, 1, 0, -50938, 1723, 0, 0, 39, '1722'),
	(243, 1, 0, -50938, 1724, 0, 0, 39, '1723'),
	(243, 1, 0, -50938, 1725, 0, 0, 39, '1724'),
	(243, 1, 0, -50938, 1726, 0, 0, 39, '1725'),
	(243, 1, 0, -50938, 1727, 0, 0, 39, '1726'),
	(243, 1, 0, -50938, 1728, 0, 0, 39, '1727'),
	(243, 1, 0, -50938, 1729, 0, 0, 39, '1728'),
	(243, 1, 0, -50938, 1730, 0, 0, 39, '1729'),
	(243, 1, 0, -50938, 1731, 0, 0, 39, '1730'),
	(243, 1, 0, -50938, 1732, 0, 0, 39, '1731'),
	(243, 1, 0, -50938, 1733, 0, 0, 39, '1732'),
	(243, 1, 0, -50938, 1734, 0, 0, 39, '1733'),
	(243, 1, 0, -50938, 1735, 0, 0, 39, '1734'),
	(243, 1, 0, -50938, 1736, 0, 0, 39, '1735'),
	(243, 1, 0, -50938, 1737, 0, 0, 39, '1736'),
	(243, 1, 0, -50938, 1738, 0, 0, 39, '1737'),
	(243, 1, 0, -50938, 1739, 0, 0, 39, '1738'),
	(243, 1, 0, -50938, 1740, 0, 0, 39, '1739'),
	(243, 1, 0, -50938, 1741, 0, 0, 39, '1740'),
	(243, 1, 0, -50938, 1742, 0, 0, 39, '1741'),
	(243, 1, 0, -50938, 1743, 0, 0, 39, '1742'),
	(243, 1, 0, -50938, 1744, 0, 0, 39, '1743'),
	(243, 1, 0, -50938, 1745, 0, 0, 39, '1744'),
	(243, 1, 0, -50938, 1746, 0, 0, 39, '1745'),
	(243, 1, 0, -50938, 1747, 0, 0, 39, '1746'),
	(243, 1, 0, -50938, 1748, 0, 0, 39, '1747'),
	(243, 1, 0, -50938, 1749, 0, 0, 39, '1748'),
	(243, 1, 0, -50938, 1750, 0, 0, 39, '1749'),
	(243, 1, 0, -50938, 1751, 0, 0, 39, '1750'),
	(243, 1, 0, -50938, 1752, 0, 0, 39, '1751'),
	(243, 1, 0, -50938, 1753, 0, 0, 39, '1752'),
	(243, 1, 0, -50938, 1754, 0, 0, 39, '1753'),
	(243, 1, 0, -50938, 1755, 0, 0, 39, '1754'),
	(243, 1, 0, -50938, 1756, 0, 0, 39, '1755'),
	(243, 1, 0, -50938, 1757, 0, 0, 39, '1756'),
	(243, 1, 0, -50938, 1758, 0, 0, 39, '1757'),
	(243, 1, 0, -50938, 1759, 0, 0, 39, '1758'),
	(243, 1, 0, -50938, 1760, 0, 0, 39, '1759'),
	(243, 1, 0, -50938, 1761, 0, 0, 39, '1760'),
	(243, 1, 0, -50938, 1762, 0, 0, 39, '1761'),
	(243, 1, 0, -50938, 1763, 0, 0, 39, '1762'),
	(243, 1, 0, -50938, 1764, 0, 0, 39, '1763'),
	(243, 1, 0, -50938, 1765, 0, 0, 39, '1764'),
	(243, 1, 0, -50938, 1766, 0, 0, 39, '1765'),
	(243, 1, 0, -50938, 1767, 0, 0, 39, '1766'),
	(243, 1, 0, -50938, 1768, 0, 0, 39, '1767'),
	(243, 1, 0, -50938, 1769, 0, 0, 39, '1768'),
	(243, 1, 0, -50938, 1770, 0, 0, 39, '1769'),
	(243, 1, 0, -50938, 1771, 0, 0, 39, '1770'),
	(243, 1, 0, -50938, 1772, 0, 0, 39, '1771'),
	(243, 1, 0, -50938, 1773, 0, 0, 39, '1772'),
	(243, 1, 0, -50938, 1774, 0, 0, 39, '1773'),
	(243, 1, 0, -50938, 1775, 0, 0, 39, '1774'),
	(243, 1, 0, -50938, 1776, 0, 0, 39, '1775'),
	(243, 1, 0, -50938, 1777, 0, 0, 39, '1776'),
	(243, 1, 0, -50938, 1778, 0, 0, 39, '1777'),
	(243, 1, 0, -50938, 1779, 0, 0, 39, '1778'),
	(243, 1, 0, -50938, 1780, 0, 0, 39, '1779'),
	(243, 1, 0, -50938, 1781, 0, 0, 39, '1780'),
	(243, 1, 0, -50938, 1782, 0, 0, 39, '1781'),
	(243, 1, 0, -50938, 1783, 0, 0, 39, '1782'),
	(243, 1, 0, -50938, 1784, 0, 0, 39, '1783'),
	(243, 1, 0, -50938, 1785, 0, 0, 39, '1784'),
	(243, 1, 0, -50938, 1786, 0, 0, 39, '1785'),
	(243, 1, 0, -50938, 1787, 0, 0, 39, '1786'),
	(243, 1, 0, -50938, 1788, 0, 0, 39, '1787'),
	(243, 1, 0, -50938, 1789, 0, 0, 39, '1788'),
	(243, 1, 0, -50938, 1790, 0, 0, 39, '1789'),
	(243, 1, 0, -50938, 1791, 0, 0, 39, '1790'),
	(243, 1, 0, -50938, 1792, 0, 0, 39, '1791'),
	(243, 1, 0, -50938, 1793, 0, 0, 39, '1792'),
	(243, 1, 0, -50938, 1794, 0, 0, 39, '1793'),
	(243, 1, 0, -50938, 1795, 0, 0, 39, '1794'),
	(243, 1, 0, -50938, 1796, 0, 0, 39, '1795'),
	(243, 1, 0, -50938, 1797, 0, 0, 39, '1796'),
	(243, 1, 0, -50938, 1798, 0, 0, 39, '1797'),
	(243, 1, 0, -50938, 1799, 0, 0, 39, '1798'),
	(243, 1, 0, -50938, 1800, 0, 0, 39, '1799'),
	(243, 1, 0, -50938, 1801, 0, 0, 39, '1800'),
	(243, 1, 0, -50938, 1802, 0, 0, 39, '1801'),
	(243, 1, 0, -50938, 1803, 0, 0, 39, '1802'),
	(243, 1, 0, -50938, 1804, 0, 0, 39, '1803'),
	(243, 1, 0, -50938, 1805, 0, 0, 39, '1804'),
	(243, 1, 0, -50938, 1806, 0, 0, 39, '1805'),
	(243, 1, 0, -50938, 1807, 0, 0, 39, '1806'),
	(243, 1, 0, -50938, 1808, 0, 0, 39, '1807'),
	(243, 1, 0, -50938, 1809, 0, 0, 39, '1808'),
	(243, 1, 0, -50938, 1810, 0, 0, 39, '1809'),
	(243, 1, 0, -50938, 1811, 0, 0, 39, '1810'),
	(243, 1, 0, -50938, 1812, 0, 0, 39, '1811'),
	(243, 1, 0, -50938, 1813, 0, 0, 39, '1812'),
	(243, 1, 0, -50938, 1814, 0, 0, 39, '1813'),
	(243, 1, 0, -50938, 1815, 0, 0, 39, '1814'),
	(243, 1, 0, -50938, 1816, 0, 0, 39, '1815'),
	(243, 1, 0, -50938, 1817, 0, 0, 39, '1816'),
	(243, 1, 0, -50938, 1818, 0, 0, 39, '1817'),
	(243, 1, 0, -50938, 1819, 0, 0, 39, '1818'),
	(243, 1, 0, -50938, 1820, 0, 0, 39, '1819'),
	(243, 1, 0, -50938, 1821, 0, 0, 39, '1820'),
	(243, 1, 0, -50938, 1822, 0, 0, 39, '1821'),
	(243, 1, 0, -50938, 1823, 0, 0, 39, '1822'),
	(243, 1, 0, -50938, 1824, 0, 0, 39, '1823'),
	(243, 1, 0, -50938, 1825, 0, 0, 39, '1824'),
	(243, 1, 0, -50938, 1826, 0, 0, 39, '1825'),
	(243, 1, 0, -50938, 1827, 0, 0, 39, '1826'),
	(243, 1, 0, -50938, 1828, 0, 0, 39, '1827'),
	(243, 1, 0, -50938, 1829, 0, 0, 39, '1828'),
	(243, 1, 0, -50938, 1830, 0, 0, 39, '1829'),
	(243, 1, 0, -50938, 1831, 0, 0, 39, '1830'),
	(243, 1, 0, -50938, 1832, 0, 0, 39, '1831'),
	(243, 1, 0, -50938, 1833, 0, 0, 39, '1832'),
	(243, 1, 0, -50938, 1834, 0, 0, 39, '1833'),
	(243, 1, 0, -50938, 1835, 0, 0, 39, '1834'),
	(243, 1, 0, -50938, 1836, 0, 0, 39, '1835'),
	(243, 1, 0, -50938, 1837, 0, 0, 39, '1836'),
	(243, 1, 0, -50938, 1838, 0, 0, 39, '1837'),
	(243, 1, 0, -50938, 1839, 0, 0, 39, '1838'),
	(243, 1, 0, -50938, 1840, 0, 0, 39, '1839'),
	(243, 1, 0, -50938, 1841, 0, 0, 39, '1840'),
	(243, 1, 0, -50938, 1842, 0, 0, 39, '1841'),
	(243, 1, 0, -50938, 1843, 0, 0, 39, '1842'),
	(243, 1, 0, -50938, 1844, 0, 0, 39, '1843'),
	(243, 1, 0, -50938, 1845, 0, 0, 39, '1844'),
	(243, 1, 0, -50938, 1846, 0, 0, 39, '1845'),
	(243, 1, 0, -50938, 1847, 0, 0, 39, '1846'),
	(243, 1, 0, -50938, 1848, 0, 0, 39, '1847'),
	(243, 1, 0, -50938, 1849, 0, 0, 39, '1848'),
	(243, 1, 0, -50938, 1850, 0, 0, 39, '1849'),
	(243, 1, 0, -50938, 1851, 0, 0, 39, '1850'),
	(243, 1, 0, -50938, 1852, 0, 0, 39, '1851'),
	(243, 1, 0, -50938, 1853, 0, 0, 39, '1852'),
	(243, 1, 0, -50938, 1854, 0, 0, 39, '1853'),
	(243, 1, 0, -50938, 1855, 0, 0, 39, '1854'),
	(243, 1, 0, -50938, 1856, 0, 0, 39, '1855'),
	(243, 1, 0, -50938, 1857, 0, 0, 39, '1856'),
	(243, 1, 0, -50938, 1858, 0, 0, 39, '1857'),
	(243, 1, 0, -50938, 1859, 0, 0, 39, '1858'),
	(243, 1, 0, -50938, 1860, 0, 0, 39, '1859'),
	(243, 1, 0, -50938, 1861, 0, 0, 39, '1860'),
	(243, 1, 0, -50938, 1862, 0, 0, 39, '1861'),
	(243, 1, 0, -50938, 1863, 0, 0, 39, '1862'),
	(243, 1, 0, -50938, 1864, 0, 0, 39, '1863'),
	(243, 1, 0, -50938, 1865, 0, 0, 39, '1864'),
	(243, 1, 0, -50938, 1866, 0, 0, 39, '1865'),
	(243, 1, 0, -50938, 1867, 0, 0, 39, '1866'),
	(243, 1, 0, -50938, 1868, 0, 0, 39, '1867'),
	(243, 1, 0, -50938, 1869, 0, 0, 39, '1868'),
	(243, 1, 0, -50938, 1870, 0, 0, 39, '1869'),
	(243, 1, 0, -50938, 1871, 0, 0, 39, '1870'),
	(243, 1, 0, -50938, 1872, 0, 0, 39, '1871'),
	(243, 1, 0, -50938, 1873, 0, 0, 39, '1872'),
	(243, 1, 0, -50938, 1874, 0, 0, 39, '1873'),
	(243, 1, 0, -50938, 1875, 0, 0, 39, '1874'),
	(243, 1, 0, -50938, 1876, 0, 0, 39, '1875'),
	(243, 1, 0, -50938, 1877, 0, 0, 39, '1876'),
	(243, 1, 0, -50938, 1878, 0, 0, 39, '1877'),
	(243, 1, 0, -50938, 1879, 0, 0, 39, '1878'),
	(243, 1, 0, -50938, 1880, 0, 0, 39, '1879'),
	(243, 1, 0, -50938, 1881, 0, 0, 39, '1880'),
	(243, 1, 0, -50938, 1882, 0, 0, 39, '1881'),
	(243, 1, 0, -50938, 1883, 0, 0, 39, '1882'),
	(243, 1, 0, -50938, 1884, 0, 0, 39, '1883'),
	(243, 1, 0, -50938, 1885, 0, 0, 39, '1884'),
	(243, 1, 0, -50938, 1886, 0, 0, 39, '1885'),
	(243, 1, 0, -50938, 1887, 0, 0, 39, '1886'),
	(243, 1, 0, -50938, 1888, 0, 0, 39, '1887'),
	(243, 1, 0, -50938, 1889, 0, 0, 39, '1888'),
	(243, 1, 0, -50938, 1890, 0, 0, 39, '1889'),
	(243, 1, 0, -50938, 1891, 0, 0, 39, '1890'),
	(243, 1, 0, -50938, 1892, 0, 0, 39, '1891'),
	(243, 1, 0, -50938, 1893, 0, 0, 39, '1892'),
	(243, 1, 0, -50938, 1894, 0, 0, 39, '1893'),
	(243, 1, 0, -50938, 1895, 0, 0, 39, '1894'),
	(243, 1, 0, -50938, 1896, 0, 0, 39, '1895'),
	(243, 1, 0, -50938, 1897, 0, 0, 39, '1896'),
	(243, 1, 0, -50938, 1898, 0, 0, 39, '1897'),
	(243, 1, 0, -50938, 1899, 0, 0, 39, '1898'),
	(243, 1, 0, -50938, 1900, 0, 0, 39, '1899'),
	(243, 1, 0, -50938, 1901, 0, 0, 39, '1900'),
	(243, 1, 0, -50938, 1902, 0, 0, 39, '1901'),
	(243, 1, 0, -50938, 1903, 0, 0, 39, '1902'),
	(243, 1, 0, -50938, 1904, 0, 0, 39, '1903'),
	(243, 1, 0, -50938, 1905, 0, 0, 39, '1904'),
	(243, 1, 0, -50938, 1906, 0, 0, 39, '1905'),
	(243, 1, 0, -50938, 1907, 0, 0, 39, '1906'),
	(243, 1, 0, -50938, 1908, 0, 0, 39, '1907'),
	(243, 1, 0, -50938, 1909, 0, 0, 39, '1908'),
	(243, 1, 0, -50938, 1910, 0, 0, 39, '1909'),
	(243, 1, 0, -50938, 1911, 0, 0, 39, '1910'),
	(243, 1, 0, -50938, 1912, 0, 0, 39, '1911'),
	(243, 1, 0, -50938, 1913, 0, 0, 39, '1912'),
	(243, 1, 0, -50938, 1914, 0, 0, 39, '1913'),
	(243, 1, 0, -50938, 1915, 0, 0, 39, '1914'),
	(243, 1, 0, -50938, 1916, 0, 0, 39, '1915'),
	(243, 1, 0, -50938, 1917, 0, 0, 39, '1916'),
	(243, 1, 0, -50938, 1918, 0, 0, 39, '1917'),
	(243, 1, 0, -50938, 1919, 0, 0, 39, '1918'),
	(243, 1, 0, -50938, 1920, 0, 0, 39, '1919'),
	(243, 1, 0, -50938, 1921, 0, 0, 39, '1920'),
	(243, 1, 0, -50938, 1922, 0, 0, 39, '1921'),
	(243, 1, 0, -50938, 1923, 0, 0, 39, '1922'),
	(243, 1, 0, -50938, 1924, 0, 0, 39, '1923'),
	(243, 1, 0, -50938, 1925, 0, 0, 39, '1924'),
	(243, 1, 0, -50938, 1926, 0, 0, 39, '1925'),
	(243, 1, 0, -50938, 1927, 0, 0, 39, '1926'),
	(243, 1, 0, -50938, 1928, 0, 0, 39, '1927'),
	(243, 1, 0, -50938, 1929, 0, 0, 39, '1928'),
	(243, 1, 0, -50938, 1930, 0, 0, 39, '1929'),
	(243, 1, 0, -50938, 1931, 0, 0, 39, '1930'),
	(243, 1, 0, -50938, 1932, 0, 0, 39, '1931'),
	(243, 1, 0, -50938, 1933, 0, 0, 39, '1932'),
	(243, 1, 0, -50938, 1934, 0, 0, 39, '1933'),
	(243, 1, 0, -50938, 1935, 0, 0, 39, '1934'),
	(243, 1, 0, -50938, 1936, 0, 0, 39, '1935'),
	(243, 1, 0, -50938, 1937, 0, 0, 39, '1936'),
	(243, 1, 0, -50938, 1938, 0, 0, 39, '1937'),
	(243, 1, 0, -50938, 1939, 0, 0, 39, '1938'),
	(243, 1, 0, -50938, 1940, 0, 0, 39, '1939'),
	(243, 1, 0, -50938, 1941, 0, 0, 39, '1940'),
	(243, 1, 0, -50938, 1942, 0, 0, 39, '1941'),
	(243, 1, 0, -50938, 1943, 0, 0, 39, '1942'),
	(243, 1, 0, -50938, 1944, 0, 0, 39, '1943'),
	(243, 1, 0, -50938, 1945, 0, 0, 39, '1944'),
	(243, 1, 0, -50938, 1946, 0, 0, 39, '1945'),
	(243, 1, 0, -50938, 1947, 0, 0, 39, '1946'),
	(243, 1, 0, -50938, 1948, 0, 0, 39, '1947'),
	(243, 1, 0, -50938, 1949, 0, 0, 39, '1948'),
	(243, 1, 0, -50938, 1950, 0, 0, 39, '1949'),
	(243, 1, 0, -50938, 1951, 0, 0, 39, '1950'),
	(243, 1, 0, -50938, 1952, 0, 0, 39, '1951'),
	(243, 1, 0, -50938, 1953, 0, 0, 39, '1952'),
	(243, 1, 0, -50938, 1954, 0, 0, 39, '1953'),
	(243, 1, 0, -50938, 1955, 0, 0, 39, '1954'),
	(243, 1, 0, -50938, 1956, 0, 0, 39, '1955'),
	(243, 1, 0, -50938, 1957, 0, 0, 39, '1956'),
	(243, 1, 0, -50938, 1958, 0, 0, 39, '1957'),
	(243, 1, 0, -50938, 1959, 0, 0, 39, '1958'),
	(243, 1, 0, -50938, 1960, 0, 0, 39, '1959'),
	(243, 1, 0, -50938, 1961, 0, 0, 39, '1960'),
	(243, 1, 0, -50938, 1962, 0, 0, 39, '1961'),
	(243, 1, 0, -50938, 1963, 0, 0, 39, '1962'),
	(243, 1, 0, -50938, 1964, 0, 0, 39, '1963'),
	(243, 1, 0, -50938, 1965, 0, 0, 39, '1964'),
	(243, 1, 0, -50938, 1966, 0, 0, 39, '1965'),
	(243, 1, 0, -50938, 1967, 0, 0, 39, '1966'),
	(243, 1, 0, -50938, 1968, 0, 0, 39, '1967'),
	(243, 1, 0, -50938, 1969, 0, 0, 39, '1968'),
	(243, 1, 0, -50938, 1970, 0, 0, 39, '1969'),
	(243, 1, 0, -50938, 1971, 0, 0, 39, '1970'),
	(243, 1, 0, -50938, 1972, 0, 0, 39, '1971'),
	(243, 1, 0, -50938, 1973, 0, 0, 39, '1972'),
	(243, 1, 0, -50938, 1974, 0, 0, 39, '1973'),
	(243, 1, 0, -50938, 1975, 0, 0, 39, '1974'),
	(243, 1, 0, -50938, 1976, 0, 0, 39, '1975'),
	(243, 1, 0, -50938, 1977, 0, 0, 39, '1976'),
	(243, 1, 0, -50938, 1978, 0, 0, 39, '1977'),
	(243, 1, 0, -50938, 1979, 0, 0, 39, '1978'),
	(243, 1, 0, -50938, 1980, 0, 0, 39, '1979'),
	(243, 1, 0, -50938, 1981, 0, 0, 39, '1980'),
	(243, 1, 0, -50938, 1982, 0, 0, 39, '1981'),
	(243, 1, 0, -50938, 1983, 0, 0, 39, '1982'),
	(243, 1, 0, -50938, 1984, 0, 0, 39, '1983'),
	(243, 1, 0, -50938, 1985, 0, 0, 39, '1984'),
	(243, 1, 0, -50938, 1986, 0, 0, 39, '1985'),
	(243, 1, 0, -50938, 1987, 0, 0, 39, '1986'),
	(243, 1, 0, -50938, 1988, 0, 0, 39, '1987'),
	(243, 1, 0, -50938, 1989, 0, 0, 39, '1988'),
	(243, 1, 0, -50938, 1990, 0, 0, 39, '1989'),
	(243, 1, 0, -50938, 1991, 0, 0, 39, '1990'),
	(243, 1, 0, -50938, 1992, 0, 0, 39, '1991'),
	(243, 1, 0, -50938, 1993, 0, 0, 39, '1992'),
	(243, 1, 0, -50938, 1994, 0, 0, 39, '1993'),
	(243, 1, 0, -50938, 1995, 0, 0, 39, '1994'),
	(243, 1, 0, -50938, 1996, 0, 0, 39, '1995'),
	(243, 1, 0, -50938, 1997, 0, 0, 39, '1996'),
	(243, 1, 0, -50938, 1998, 0, 0, 39, '1997'),
	(243, 1, 0, -50938, 1999, 0, 0, 39, '1998'),
	(243, 1, 0, -50938, 2000, 0, 0, 39, '1999'),
	(243, 1, 0, -50938, 2001, 0, 0, 39, '2000'),
	(243, 1, 0, -50938, 2002, 0, 0, 39, '2001'),
	(243, 1, 0, -50938, 2003, 0, 0, 39, '2002'),
	(243, 1, 0, -50938, 2004, 0, 0, 39, '2003'),
	(243, 1, 0, -50938, 2005, 0, 0, 39, '2004'),
	(243, 1, 0, -50938, 2006, 0, 0, 39, '2005'),
	(243, 1, 0, -50938, 2007, 0, 0, 39, '2006'),
	(243, 1, 0, -50938, 2008, 0, 0, 39, '2007'),
	(243, 1, 0, -50938, 2009, 0, 0, 39, '2008'),
	(243, 1, 0, -50938, 2010, 0, 0, 39, '2009'),
	(243, 1, 0, -50938, 2011, 0, 0, 39, '2010'),
	(243, 1, 0, -50938, 2012, 0, 0, 39, '2011'),
	(243, 1, 0, -50938, 2013, 0, 0, 39, '2012'),
	(243, 1, 0, -50938, 2014, 0, 0, 39, '2013'),
	(243, 1, 0, -50938, 2015, 0, 0, 39, '2014'),
	(243, 1, 0, -50938, 2016, 0, 0, 39, '2015'),
	(243, 1, 0, -50938, 2017, 0, 0, 39, '2016'),
	(243, 1, 0, -50938, 2018, 0, 0, 39, '2017'),
	(243, 1, 0, -50938, 2019, 0, 0, 39, '2018'),
	(243, 1, 0, -50938, 2020, 0, 0, 39, '2019'),
	(243, 1, 0, -50938, 2021, 0, 0, 39, '2020'),
	(243, 1, 0, -50938, 2022, 0, 0, 39, '2021'),
	(243, 1, 0, -50938, 2023, 0, 0, 39, '2022'),
	(243, 1, 0, -50938, 2024, 0, 0, 39, '2023'),
	(243, 1, 0, -50938, 2025, 0, 0, 39, '2024'),
	(243, 1, 0, -50938, 2026, 0, 0, 39, '2025'),
	(243, 1, 0, -50938, 2027, 0, 0, 39, '2026'),
	(243, 1, 0, -50938, 2028, 0, 0, 39, '2027'),
	(243, 1, 0, -50938, 2029, 0, 0, 39, '2028'),
	(243, 1, 0, -50938, 2030, 0, 0, 39, '2029'),
	(243, 1, 0, -50938, 2031, 0, 0, 39, '2030'),
	(243, 1, 0, -50938, 2032, 0, 0, 39, '2031'),
	(243, 1, 0, -50938, 2033, 0, 0, 39, '2032'),
	(243, 1, 0, -50938, 2034, 0, 0, 39, '2033'),
	(243, 1, 0, -50938, 2035, 0, 0, 39, '2034'),
	(243, 1, 0, -50938, 2036, 0, 0, 39, '2035'),
	(243, 1, 0, -50938, 2037, 0, 0, 39, '2036'),
	(243, 1, 0, -50938, 2038, 0, 0, 39, '2037'),
	(243, 1, 0, -50938, 2039, 0, 0, 39, '2038'),
	(243, 1, 0, -50938, 2040, 0, 0, 39, '2039'),
	(243, 1, 0, -50938, 2041, 0, 0, 39, '2040'),
	(243, 1, 0, -50938, 2042, 0, 0, 39, '2041'),
	(243, 1, 0, -50938, 2043, 0, 0, 39, '2042'),
	(243, 1, 0, -50938, 2044, 0, 0, 39, '2043'),
	(243, 1, 0, -50938, 2045, 0, 0, 39, '2044'),
	(243, 1, 0, -50938, 2046, 0, 0, 39, '2045'),
	(243, 1, 0, -50938, 2047, 0, 0, 39, '2046'),
	(243, 1, 0, -50938, 2048, 0, 0, 39, '2047'),
	(243, 1, 0, -50937, 1, 0, 0, 39, '0'),
	(243, 1, 0, -50937, 2, 0, 0, 39, '1'),
	(243, 1, 0, -50937, 3, 0, 0, 39, '2'),
	(243, 1, 0, -50937, 4, 0, 0, 39, '3'),
	(243, 1, 0, -50937, 5, 0, 0, 39, '4'),
	(243, 1, 0, -50937, 6, 0, 0, 39, '5'),
	(243, 1, 0, -50937, 7, 0, 0, 39, '6'),
	(243, 1, 0, -50937, 8, 0, 0, 39, '7'),
	(243, 1, 0, -50937, 9, 0, 0, 39, '8'),
	(243, 1, 0, -50937, 10, 0, 0, 39, '9'),
	(243, 1, 0, -50937, 11, 0, 0, 39, '10'),
	(243, 1, 0, -50937, 12, 0, 0, 39, '11'),
	(243, 1, 0, -50937, 13, 0, 0, 39, '12'),
	(243, 1, 0, -50937, 14, 0, 0, 39, '13'),
	(243, 1, 0, -50937, 15, 0, 0, 39, '14'),
	(243, 1, 0, -50937, 16, 0, 0, 39, '15'),
	(243, 1, 0, -50937, 17, 0, 0, 39, '16'),
	(243, 1, 0, -50937, 18, 0, 0, 39, '17'),
	(243, 1, 0, -50937, 19, 0, 0, 39, '18'),
	(243, 1, 0, -50937, 20, 0, 0, 39, '19'),
	(243, 1, 0, -50937, 21, 0, 0, 39, '20'),
	(243, 1, 0, -50937, 22, 0, 0, 39, '21'),
	(243, 1, 0, -50937, 23, 0, 0, 39, '22'),
	(243, 1, 0, -50937, 24, 0, 0, 39, '23'),
	(243, 1, 0, -50937, 25, 0, 0, 39, '24'),
	(243, 1, 0, -50937, 26, 0, 0, 39, '25'),
	(243, 1, 0, -50937, 27, 0, 0, 39, '26'),
	(243, 1, 0, -50937, 28, 0, 0, 39, '27'),
	(243, 1, 0, -50937, 29, 0, 0, 39, '28'),
	(243, 1, 0, -50937, 30, 0, 0, 39, '29'),
	(243, 1, 0, -50937, 31, 0, 0, 39, '30'),
	(243, 1, 0, -50937, 32, 0, 0, 39, '31'),
	(243, 1, 0, -50937, 33, 0, 0, 39, '32'),
	(243, 1, 0, -50937, 34, 0, 0, 39, '33'),
	(243, 1, 0, -50937, 35, 0, 0, 39, '34'),
	(243, 1, 0, -50937, 36, 0, 0, 39, '35'),
	(243, 1, 0, -50937, 37, 0, 0, 39, '36'),
	(243, 1, 0, -50937, 38, 0, 0, 39, '37'),
	(243, 1, 0, -50937, 39, 0, 0, 39, '38'),
	(243, 1, 0, -50937, 40, 0, 0, 39, '39'),
	(243, 1, 0, -50937, 41, 0, 0, 39, '40'),
	(243, 1, 0, -50937, 42, 0, 0, 39, '41'),
	(243, 1, 0, -50937, 43, 0, 0, 39, '42'),
	(243, 1, 0, -50937, 44, 0, 0, 39, '43'),
	(243, 1, 0, -50937, 45, 0, 0, 39, '44'),
	(243, 1, 0, -50937, 46, 0, 0, 39, '45'),
	(243, 1, 0, -50937, 47, 0, 0, 39, '46'),
	(243, 1, 0, -50937, 48, 0, 0, 39, '47'),
	(243, 1, 0, -50937, 49, 0, 0, 39, '48'),
	(243, 1, 0, -50937, 50, 0, 0, 39, '49'),
	(243, 1, 0, -50937, 51, 0, 0, 39, '50'),
	(243, 1, 0, -50937, 52, 0, 0, 39, '51'),
	(243, 1, 0, -50937, 53, 0, 0, 39, '52'),
	(243, 1, 0, -50937, 54, 0, 0, 39, '53'),
	(243, 1, 0, -50937, 55, 0, 0, 39, '54'),
	(243, 1, 0, -50937, 56, 0, 0, 39, '55'),
	(243, 1, 0, -50937, 57, 0, 0, 39, '56'),
	(243, 1, 0, -50937, 58, 0, 0, 39, '57'),
	(243, 1, 0, -50937, 59, 0, 0, 39, '58'),
	(243, 1, 0, -50937, 60, 0, 0, 39, '59'),
	(243, 1, 0, -50937, 61, 0, 0, 39, '60'),
	(243, 1, 0, -50937, 62, 0, 0, 39, '61'),
	(243, 1, 0, -50937, 63, 0, 0, 39, '62'),
	(243, 1, 0, -50937, 64, 0, 0, 39, '63'),
	(243, 1, 0, -50937, 65, 0, 0, 39, '64'),
	(243, 1, 0, -50937, 66, 0, 0, 39, '65'),
	(243, 1, 0, -50937, 67, 0, 0, 39, '66'),
	(243, 1, 0, -50937, 68, 0, 0, 39, '67'),
	(243, 1, 0, -50937, 69, 0, 0, 39, '68'),
	(243, 1, 0, -50937, 70, 0, 0, 39, '69'),
	(243, 1, 0, -50937, 71, 0, 0, 39, '70'),
	(243, 1, 0, -50937, 72, 0, 0, 39, '71'),
	(243, 1, 0, -50937, 73, 0, 0, 39, '72'),
	(243, 1, 0, -50937, 74, 0, 0, 39, '73'),
	(243, 1, 0, -50937, 75, 0, 0, 39, '74'),
	(243, 1, 0, -50937, 76, 0, 0, 39, '75'),
	(243, 1, 0, -50937, 77, 0, 0, 39, '76'),
	(243, 1, 0, -50937, 78, 0, 0, 39, '77'),
	(243, 1, 0, -50937, 79, 0, 0, 39, '78'),
	(243, 1, 0, -50937, 80, 0, 0, 39, '79'),
	(243, 1, 0, -50937, 81, 0, 0, 39, '80'),
	(243, 1, 0, -50937, 82, 0, 0, 39, '81'),
	(243, 1, 0, -50937, 83, 0, 0, 39, '82'),
	(243, 1, 0, -50937, 84, 0, 0, 39, '83'),
	(243, 1, 0, -50937, 85, 0, 0, 39, '84'),
	(243, 1, 0, -50937, 86, 0, 0, 39, '85'),
	(243, 1, 0, -50937, 87, 0, 0, 39, '86'),
	(243, 1, 0, -50937, 88, 0, 0, 39, '87'),
	(243, 1, 0, -50937, 89, 0, 0, 39, '88'),
	(243, 1, 0, -50937, 90, 0, 0, 39, '89'),
	(243, 1, 0, -50937, 91, 0, 0, 39, '90'),
	(243, 1, 0, -50937, 92, 0, 0, 39, '91'),
	(243, 1, 0, -50937, 93, 0, 0, 39, '92'),
	(243, 1, 0, -50937, 94, 0, 0, 39, '93'),
	(243, 1, 0, -50937, 95, 0, 0, 39, '94'),
	(243, 1, 0, -50937, 96, 0, 0, 39, '95'),
	(243, 1, 0, -50937, 97, 0, 0, 39, '96'),
	(243, 1, 0, -50937, 98, 0, 0, 39, '97'),
	(243, 1, 0, -50937, 99, 0, 0, 39, '98'),
	(243, 1, 0, -50937, 100, 0, 0, 39, '99'),
	(243, 1, 0, -50937, 101, 0, 0, 39, '100'),
	(243, 1, 0, -50937, 102, 0, 0, 39, '101'),
	(243, 1, 0, -50937, 103, 0, 0, 39, '102'),
	(243, 1, 0, -50937, 104, 0, 0, 39, '103'),
	(243, 1, 0, -50937, 105, 0, 0, 39, '104'),
	(243, 1, 0, -50937, 106, 0, 0, 39, '105'),
	(243, 1, 0, -50937, 107, 0, 0, 39, '106'),
	(243, 1, 0, -50937, 108, 0, 0, 39, '107'),
	(243, 1, 0, -50937, 109, 0, 0, 39, '108'),
	(243, 1, 0, -50937, 110, 0, 0, 39, '109'),
	(243, 1, 0, -50937, 111, 0, 0, 39, '110'),
	(243, 1, 0, -50937, 112, 0, 0, 39, '111'),
	(243, 1, 0, -50937, 113, 0, 0, 39, '112'),
	(243, 1, 0, -50937, 114, 0, 0, 39, '113'),
	(243, 1, 0, -50937, 115, 0, 0, 39, '114'),
	(243, 1, 0, -50937, 116, 0, 0, 39, '115'),
	(243, 1, 0, -50937, 117, 0, 0, 39, '116'),
	(243, 1, 0, -50937, 118, 0, 0, 39, '117'),
	(243, 1, 0, -50937, 119, 0, 0, 39, '118'),
	(243, 1, 0, -50937, 120, 0, 0, 39, '119'),
	(243, 1, 0, -50937, 121, 0, 0, 39, '120'),
	(243, 1, 0, -50937, 122, 0, 0, 39, '121'),
	(243, 1, 0, -50937, 123, 0, 0, 39, '122'),
	(243, 1, 0, -50937, 124, 0, 0, 39, '123'),
	(243, 1, 0, -50937, 125, 0, 0, 39, '124'),
	(243, 1, 0, -50937, 126, 0, 0, 39, '125'),
	(243, 1, 0, -50937, 127, 0, 0, 39, '126'),
	(243, 1, 0, -50937, 128, 0, 0, 39, '127'),
	(243, 1, 0, -50937, 129, 0, 0, 39, '128'),
	(243, 1, 0, -50937, 130, 0, 0, 39, '129'),
	(243, 1, 0, -50937, 131, 0, 0, 39, '130'),
	(243, 1, 0, -50937, 132, 0, 0, 39, '131'),
	(243, 1, 0, -50937, 133, 0, 0, 39, '132'),
	(243, 1, 0, -50937, 134, 0, 0, 39, '133'),
	(243, 1, 0, -50937, 135, 0, 0, 39, '134'),
	(243, 1, 0, -50937, 136, 0, 0, 39, '135'),
	(243, 1, 0, -50937, 137, 0, 0, 39, '136'),
	(243, 1, 0, -50937, 138, 0, 0, 39, '137'),
	(243, 1, 0, -50937, 139, 0, 0, 39, '138'),
	(243, 1, 0, -50937, 140, 0, 0, 39, '139'),
	(243, 1, 0, -50937, 141, 0, 0, 39, '140'),
	(243, 1, 0, -50937, 142, 0, 0, 39, '141'),
	(243, 1, 0, -50937, 143, 0, 0, 39, '142'),
	(243, 1, 0, -50937, 144, 0, 0, 39, '143'),
	(243, 1, 0, -50937, 145, 0, 0, 39, '144'),
	(243, 1, 0, -50937, 146, 0, 0, 39, '145'),
	(243, 1, 0, -50937, 147, 0, 0, 39, '146'),
	(243, 1, 0, -50937, 148, 0, 0, 39, '147'),
	(243, 1, 0, -50937, 149, 0, 0, 39, '148'),
	(243, 1, 0, -50937, 150, 0, 0, 39, '149'),
	(243, 1, 0, -50937, 151, 0, 0, 39, '150'),
	(243, 1, 0, -50937, 152, 0, 0, 39, '151'),
	(243, 1, 0, -50937, 153, 0, 0, 39, '152'),
	(243, 1, 0, -50937, 154, 0, 0, 39, '153'),
	(243, 1, 0, -50937, 155, 0, 0, 39, '154'),
	(243, 1, 0, -50937, 156, 0, 0, 39, '155'),
	(243, 1, 0, -50937, 157, 0, 0, 39, '156'),
	(243, 1, 0, -50937, 158, 0, 0, 39, '157'),
	(243, 1, 0, -50937, 159, 0, 0, 39, '158'),
	(243, 1, 0, -50937, 160, 0, 0, 39, '159'),
	(243, 1, 0, -50937, 161, 0, 0, 39, '160'),
	(243, 1, 0, -50937, 162, 0, 0, 39, '161'),
	(243, 1, 0, -50937, 163, 0, 0, 39, '162'),
	(243, 1, 0, -50937, 164, 0, 0, 39, '163'),
	(243, 1, 0, -50937, 165, 0, 0, 39, '164'),
	(243, 1, 0, -50937, 166, 0, 0, 39, '165'),
	(243, 1, 0, -50937, 167, 0, 0, 39, '166'),
	(243, 1, 0, -50937, 168, 0, 0, 39, '167'),
	(243, 1, 0, -50937, 169, 0, 0, 39, '168'),
	(243, 1, 0, -50937, 170, 0, 0, 39, '169'),
	(243, 1, 0, -50937, 171, 0, 0, 39, '170'),
	(243, 1, 0, -50937, 172, 0, 0, 39, '171'),
	(243, 1, 0, -50937, 173, 0, 0, 39, '172'),
	(243, 1, 0, -50937, 174, 0, 0, 39, '173'),
	(243, 1, 0, -50937, 175, 0, 0, 39, '174'),
	(243, 1, 0, -50937, 176, 0, 0, 39, '175'),
	(243, 1, 0, -50937, 177, 0, 0, 39, '176'),
	(243, 1, 0, -50937, 178, 0, 0, 39, '177'),
	(243, 1, 0, -50937, 179, 0, 0, 39, '178'),
	(243, 1, 0, -50937, 180, 0, 0, 39, '179'),
	(243, 1, 0, -50937, 181, 0, 0, 39, '180'),
	(243, 1, 0, -50937, 182, 0, 0, 39, '181'),
	(243, 1, 0, -50937, 183, 0, 0, 39, '182'),
	(243, 1, 0, -50937, 184, 0, 0, 39, '183'),
	(243, 1, 0, -50937, 185, 0, 0, 39, '184'),
	(243, 1, 0, -50937, 186, 0, 0, 39, '185'),
	(243, 1, 0, -50937, 187, 0, 0, 39, '186'),
	(243, 1, 0, -50937, 188, 0, 0, 39, '187'),
	(243, 1, 0, -50937, 189, 0, 0, 39, '188'),
	(243, 1, 0, -50937, 190, 0, 0, 39, '189'),
	(243, 1, 0, -50937, 191, 0, 0, 39, '190'),
	(243, 1, 0, -50937, 192, 0, 0, 39, '191'),
	(243, 1, 0, -50937, 193, 0, 0, 39, '192'),
	(243, 1, 0, -50937, 194, 0, 0, 39, '193'),
	(243, 1, 0, -50937, 195, 0, 0, 39, '194'),
	(243, 1, 0, -50937, 196, 0, 0, 39, '195'),
	(243, 1, 0, -50937, 197, 0, 0, 39, '196'),
	(243, 1, 0, -50937, 198, 0, 0, 39, '197'),
	(243, 1, 0, -50937, 199, 0, 0, 39, '198'),
	(243, 1, 0, -50937, 200, 0, 0, 39, '199'),
	(243, 1, 0, -50937, 201, 0, 0, 39, '200'),
	(243, 1, 0, -50937, 202, 0, 0, 39, '201'),
	(243, 1, 0, -50937, 203, 0, 0, 39, '202'),
	(243, 1, 0, -50937, 204, 0, 0, 39, '203'),
	(243, 1, 0, -50937, 205, 0, 0, 39, '204'),
	(243, 1, 0, -50937, 206, 0, 0, 39, '205'),
	(243, 1, 0, -50937, 207, 0, 0, 39, '206'),
	(243, 1, 0, -50937, 208, 0, 0, 39, '207'),
	(243, 1, 0, -50937, 209, 0, 0, 39, '208'),
	(243, 1, 0, -50937, 210, 0, 0, 39, '209'),
	(243, 1, 0, -50937, 211, 0, 0, 39, '210'),
	(243, 1, 0, -50937, 212, 0, 0, 39, '211'),
	(243, 1, 0, -50937, 213, 0, 0, 39, '212'),
	(243, 1, 0, -50937, 214, 0, 0, 39, '213'),
	(243, 1, 0, -50937, 215, 0, 0, 39, '214'),
	(243, 1, 0, -50937, 216, 0, 0, 39, '215'),
	(243, 1, 0, -50937, 217, 0, 0, 39, '216'),
	(243, 1, 0, -50937, 218, 0, 0, 39, '217'),
	(243, 1, 0, -50937, 219, 0, 0, 39, '218'),
	(243, 1, 0, -50937, 220, 0, 0, 39, '219'),
	(243, 1, 0, -50937, 221, 0, 0, 39, '220'),
	(243, 1, 0, -50937, 222, 0, 0, 39, '221'),
	(243, 1, 0, -50937, 223, 0, 0, 39, '222'),
	(243, 1, 0, -50937, 224, 0, 0, 39, '223'),
	(243, 1, 0, -50937, 225, 0, 0, 39, '224'),
	(243, 1, 0, -50937, 226, 0, 0, 39, '225'),
	(243, 1, 0, -50937, 227, 0, 0, 39, '226'),
	(243, 1, 0, -50937, 228, 0, 0, 39, '227'),
	(243, 1, 0, -50937, 229, 0, 0, 39, '228'),
	(243, 1, 0, -50937, 230, 0, 0, 39, '229'),
	(243, 1, 0, -50937, 231, 0, 0, 39, '230'),
	(243, 1, 0, -50937, 232, 0, 0, 39, '231'),
	(243, 1, 0, -50937, 233, 0, 0, 39, '232'),
	(243, 1, 0, -50937, 234, 0, 0, 39, '233'),
	(243, 1, 0, -50937, 235, 0, 0, 39, '234'),
	(243, 1, 0, -50937, 236, 0, 0, 39, '235'),
	(243, 1, 0, -50937, 237, 0, 0, 39, '236'),
	(243, 1, 0, -50937, 238, 0, 0, 39, '237'),
	(243, 1, 0, -50937, 239, 0, 0, 39, '238'),
	(243, 1, 0, -50937, 240, 0, 0, 39, '239'),
	(243, 1, 0, -50937, 241, 0, 0, 39, '240'),
	(243, 1, 0, -50937, 242, 0, 0, 39, '241'),
	(243, 1, 0, -50937, 243, 0, 0, 39, '242'),
	(243, 1, 0, -50937, 244, 0, 0, 39, '243'),
	(243, 1, 0, -50937, 245, 0, 0, 39, '244'),
	(243, 1, 0, -50937, 246, 0, 0, 39, '245'),
	(243, 1, 0, -50937, 247, 0, 0, 39, '246'),
	(243, 1, 0, -50937, 248, 0, 0, 39, '247'),
	(243, 1, 0, -50937, 249, 0, 0, 39, '248'),
	(243, 1, 0, -50937, 250, 0, 0, 39, '249'),
	(243, 1, 0, -50937, 251, 0, 0, 39, '250'),
	(243, 1, 0, -50937, 252, 0, 0, 39, '251'),
	(243, 1, 0, -50937, 253, 0, 0, 39, '252'),
	(243, 1, 0, -50937, 254, 0, 0, 39, '253'),
	(243, 1, 0, -50937, 255, 0, 0, 39, '254'),
	(243, 1, 0, -50937, 256, 0, 0, 39, '255'),
	(243, 1, 0, -50937, 257, 0, 0, 39, '256'),
	(243, 1, 0, -50937, 258, 0, 0, 39, '257'),
	(243, 1, 0, -50937, 259, 0, 0, 39, '258'),
	(243, 1, 0, -50937, 260, 0, 0, 39, '259'),
	(243, 1, 0, -50937, 261, 0, 0, 39, '260'),
	(243, 1, 0, -50937, 262, 0, 0, 39, '261'),
	(243, 1, 0, -50937, 263, 0, 0, 39, '262'),
	(243, 1, 0, -50937, 264, 0, 0, 39, '263'),
	(243, 1, 0, -50937, 265, 0, 0, 39, '264'),
	(243, 1, 0, -50937, 266, 0, 0, 39, '265'),
	(243, 1, 0, -50937, 267, 0, 0, 39, '266'),
	(243, 1, 0, -50937, 268, 0, 0, 39, '267'),
	(243, 1, 0, -50937, 269, 0, 0, 39, '268'),
	(243, 1, 0, -50937, 270, 0, 0, 39, '269'),
	(243, 1, 0, -50937, 271, 0, 0, 39, '270'),
	(243, 1, 0, -50937, 272, 0, 0, 39, '271'),
	(243, 1, 0, -50937, 273, 0, 0, 39, '272'),
	(243, 1, 0, -50937, 274, 0, 0, 39, '273'),
	(243, 1, 0, -50937, 275, 0, 0, 39, '274'),
	(243, 1, 0, -50937, 276, 0, 0, 39, '275'),
	(243, 1, 0, -50937, 277, 0, 0, 39, '276'),
	(243, 1, 0, -50937, 278, 0, 0, 39, '277'),
	(243, 1, 0, -50937, 279, 0, 0, 39, '278'),
	(243, 1, 0, -50937, 280, 0, 0, 39, '279'),
	(243, 1, 0, -50937, 281, 0, 0, 39, '280'),
	(243, 1, 0, -50937, 282, 0, 0, 39, '281'),
	(243, 1, 0, -50937, 283, 0, 0, 39, '282'),
	(243, 1, 0, -50937, 284, 0, 0, 39, '283'),
	(243, 1, 0, -50937, 285, 0, 0, 39, '284'),
	(243, 1, 0, -50937, 286, 0, 0, 39, '285'),
	(243, 1, 0, -50937, 287, 0, 0, 39, '286'),
	(243, 1, 0, -50937, 288, 0, 0, 39, '287'),
	(243, 1, 0, -50937, 289, 0, 0, 39, '288'),
	(243, 1, 0, -50937, 290, 0, 0, 39, '289'),
	(243, 1, 0, -50937, 291, 0, 0, 39, '290'),
	(243, 1, 0, -50937, 292, 0, 0, 39, '291'),
	(243, 1, 0, -50937, 293, 0, 0, 39, '292'),
	(243, 1, 0, -50937, 294, 0, 0, 39, '293'),
	(243, 1, 0, -50937, 295, 0, 0, 39, '294'),
	(243, 1, 0, -50937, 296, 0, 0, 39, '295'),
	(243, 1, 0, -50937, 297, 0, 0, 39, '296'),
	(243, 1, 0, -50937, 298, 0, 0, 39, '297'),
	(243, 1, 0, -50937, 299, 0, 0, 39, '298'),
	(243, 1, 0, -50937, 300, 0, 0, 39, '299'),
	(243, 1, 0, -50937, 301, 0, 0, 39, '300'),
	(243, 1, 0, -50937, 302, 0, 0, 39, '301'),
	(243, 1, 0, -50937, 303, 0, 0, 39, '302'),
	(243, 1, 0, -50937, 304, 0, 0, 39, '303'),
	(243, 1, 0, -50937, 305, 0, 0, 39, '304'),
	(243, 1, 0, -50937, 306, 0, 0, 39, '305'),
	(243, 1, 0, -50937, 307, 0, 0, 39, '306'),
	(243, 1, 0, -50937, 308, 0, 0, 39, '307'),
	(243, 1, 0, -50937, 309, 0, 0, 39, '308'),
	(243, 1, 0, -50937, 310, 0, 0, 39, '309'),
	(243, 1, 0, -50937, 311, 0, 0, 39, '310'),
	(243, 1, 0, -50937, 312, 0, 0, 39, '311'),
	(243, 1, 0, -50937, 313, 0, 0, 39, '312'),
	(243, 1, 0, -50937, 314, 0, 0, 39, '313'),
	(243, 1, 0, -50937, 315, 0, 0, 39, '314'),
	(243, 1, 0, -50937, 316, 0, 0, 39, '315'),
	(243, 1, 0, -50937, 317, 0, 0, 39, '316'),
	(243, 1, 0, -50937, 318, 0, 0, 39, '317'),
	(243, 1, 0, -50937, 319, 0, 0, 39, '318'),
	(243, 1, 0, -50937, 320, 0, 0, 39, '319'),
	(243, 1, 0, -50937, 321, 0, 0, 39, '320'),
	(243, 1, 0, -50937, 322, 0, 0, 39, '321'),
	(243, 1, 0, -50937, 323, 0, 0, 39, '322'),
	(243, 1, 0, -50937, 324, 0, 0, 39, '323'),
	(243, 1, 0, -50937, 325, 0, 0, 39, '324'),
	(243, 1, 0, -50937, 326, 0, 0, 39, '325'),
	(243, 1, 0, -50937, 327, 0, 0, 39, '326'),
	(243, 1, 0, -50937, 328, 0, 0, 39, '327'),
	(243, 1, 0, -50937, 329, 0, 0, 39, '328'),
	(243, 1, 0, -50937, 330, 0, 0, 39, '329'),
	(243, 1, 0, -50937, 331, 0, 0, 39, '330'),
	(243, 1, 0, -50937, 332, 0, 0, 39, '331'),
	(243, 1, 0, -50937, 333, 0, 0, 39, '332'),
	(243, 1, 0, -50937, 334, 0, 0, 39, '333'),
	(243, 1, 0, -50937, 335, 0, 0, 39, '334'),
	(243, 1, 0, -50937, 336, 0, 0, 39, '335'),
	(243, 1, 0, -50937, 337, 0, 0, 39, '336'),
	(243, 1, 0, -50937, 338, 0, 0, 39, '337'),
	(243, 1, 0, -50937, 339, 0, 0, 39, '338'),
	(243, 1, 0, -50937, 340, 0, 0, 39, '339'),
	(243, 1, 0, -50937, 341, 0, 0, 39, '340'),
	(243, 1, 0, -50937, 342, 0, 0, 39, '341'),
	(243, 1, 0, -50937, 343, 0, 0, 39, '342'),
	(243, 1, 0, -50937, 344, 0, 0, 39, '343'),
	(243, 1, 0, -50937, 345, 0, 0, 39, '344'),
	(243, 1, 0, -50937, 346, 0, 0, 39, '345'),
	(243, 1, 0, -50937, 347, 0, 0, 39, '346'),
	(243, 1, 0, -50937, 348, 0, 0, 39, '347'),
	(243, 1, 0, -50937, 349, 0, 0, 39, '348'),
	(243, 1, 0, -50937, 350, 0, 0, 39, '349'),
	(243, 1, 0, -50937, 351, 0, 0, 39, '350'),
	(243, 1, 0, -50937, 352, 0, 0, 39, '351'),
	(243, 1, 0, -50937, 353, 0, 0, 39, '352'),
	(243, 1, 0, -50937, 354, 0, 0, 39, '353'),
	(243, 1, 0, -50937, 355, 0, 0, 39, '354'),
	(243, 1, 0, -50937, 356, 0, 0, 39, '355'),
	(243, 1, 0, -50937, 357, 0, 0, 39, '356'),
	(243, 1, 0, -50937, 358, 0, 0, 39, '357'),
	(243, 1, 0, -50937, 359, 0, 0, 39, '358'),
	(243, 1, 0, -50937, 360, 0, 0, 39, '359'),
	(243, 1, 0, -50937, 361, 0, 0, 39, '360'),
	(243, 1, 0, -50937, 362, 0, 0, 39, '361'),
	(243, 1, 0, -50937, 363, 0, 0, 39, '362'),
	(243, 1, 0, -50937, 364, 0, 0, 39, '363'),
	(243, 1, 0, -50937, 365, 0, 0, 39, '364'),
	(243, 1, 0, -50937, 366, 0, 0, 39, '365'),
	(243, 1, 0, -50937, 367, 0, 0, 39, '366'),
	(243, 1, 0, -50937, 368, 0, 0, 39, '367'),
	(243, 1, 0, -50937, 369, 0, 0, 39, '368'),
	(243, 1, 0, -50937, 370, 0, 0, 39, '369'),
	(243, 1, 0, -50937, 371, 0, 0, 39, '370'),
	(243, 1, 0, -50937, 372, 0, 0, 39, '371'),
	(243, 1, 0, -50937, 373, 0, 0, 39, '372'),
	(243, 1, 0, -50937, 374, 0, 0, 39, '373'),
	(243, 1, 0, -50937, 375, 0, 0, 39, '374'),
	(243, 1, 0, -50937, 376, 0, 0, 39, '375'),
	(243, 1, 0, -50937, 377, 0, 0, 39, '376'),
	(243, 1, 0, -50937, 378, 0, 0, 39, '377'),
	(243, 1, 0, -50937, 379, 0, 0, 39, '378'),
	(243, 1, 0, -50937, 380, 0, 0, 39, '379'),
	(243, 1, 0, -50937, 381, 0, 0, 39, '380'),
	(243, 1, 0, -50937, 382, 0, 0, 39, '381'),
	(243, 1, 0, -50937, 383, 0, 0, 39, '382'),
	(243, 1, 0, -50937, 384, 0, 0, 39, '383'),
	(243, 1, 0, -50937, 385, 0, 0, 39, '384'),
	(243, 1, 0, -50937, 386, 0, 0, 39, '385'),
	(243, 1, 0, -50937, 387, 0, 0, 39, '386'),
	(243, 1, 0, -50937, 388, 0, 0, 39, '387'),
	(243, 1, 0, -50937, 389, 0, 0, 39, '388'),
	(243, 1, 0, -50937, 390, 0, 0, 39, '389'),
	(243, 1, 0, -50937, 391, 0, 0, 39, '390'),
	(243, 1, 0, -50937, 392, 0, 0, 39, '391'),
	(243, 1, 0, -50937, 393, 0, 0, 39, '392'),
	(243, 1, 0, -50937, 394, 0, 0, 39, '393'),
	(243, 1, 0, -50937, 395, 0, 0, 39, '394'),
	(243, 1, 0, -50937, 396, 0, 0, 39, '395'),
	(243, 1, 0, -50937, 397, 0, 0, 39, '396'),
	(243, 1, 0, -50937, 398, 0, 0, 39, '397'),
	(243, 1, 0, -50937, 399, 0, 0, 39, '398'),
	(243, 1, 0, -50937, 400, 0, 0, 39, '399'),
	(243, 1, 0, -50937, 401, 0, 0, 39, '400'),
	(243, 1, 0, -50937, 402, 0, 0, 39, '401'),
	(243, 1, 0, -50937, 403, 0, 0, 39, '402'),
	(243, 1, 0, -50937, 404, 0, 0, 39, '403'),
	(243, 1, 0, -50937, 405, 0, 0, 39, '404'),
	(243, 1, 0, -50937, 406, 0, 0, 39, '405'),
	(243, 1, 0, -50937, 407, 0, 0, 39, '406'),
	(243, 1, 0, -50937, 408, 0, 0, 39, '407'),
	(243, 1, 0, -50937, 409, 0, 0, 39, '408'),
	(243, 1, 0, -50937, 410, 0, 0, 39, '409'),
	(243, 1, 0, -50937, 411, 0, 0, 39, '410'),
	(243, 1, 0, -50937, 412, 0, 0, 39, '411'),
	(243, 1, 0, -50937, 413, 0, 0, 39, '412'),
	(243, 1, 0, -50937, 414, 0, 0, 39, '413'),
	(243, 1, 0, -50937, 415, 0, 0, 39, '414'),
	(243, 1, 0, -50937, 416, 0, 0, 39, '415'),
	(243, 1, 0, -50937, 417, 0, 0, 39, '416'),
	(243, 1, 0, -50937, 418, 0, 0, 39, '417'),
	(243, 1, 0, -50937, 419, 0, 0, 39, '418'),
	(243, 1, 0, -50937, 420, 0, 0, 39, '419'),
	(243, 1, 0, -50937, 421, 0, 0, 39, '420'),
	(243, 1, 0, -50937, 422, 0, 0, 39, '421'),
	(243, 1, 0, -50937, 423, 0, 0, 39, '422'),
	(243, 1, 0, -50937, 424, 0, 0, 39, '423'),
	(243, 1, 0, -50937, 425, 0, 0, 39, '424'),
	(243, 1, 0, -50937, 426, 0, 0, 39, '425'),
	(243, 1, 0, -50937, 427, 0, 0, 39, '426'),
	(243, 1, 0, -50937, 428, 0, 0, 39, '427'),
	(243, 1, 0, -50937, 429, 0, 0, 39, '428'),
	(243, 1, 0, -50937, 430, 0, 0, 39, '429'),
	(243, 1, 0, -50937, 431, 0, 0, 39, '430'),
	(243, 1, 0, -50937, 432, 0, 0, 39, '431'),
	(243, 1, 0, -50937, 433, 0, 0, 39, '432'),
	(243, 1, 0, -50937, 434, 0, 0, 39, '433'),
	(243, 1, 0, -50937, 435, 0, 0, 39, '434'),
	(243, 1, 0, -50937, 436, 0, 0, 39, '435'),
	(243, 1, 0, -50937, 437, 0, 0, 39, '436'),
	(243, 1, 0, -50937, 438, 0, 0, 39, '437'),
	(243, 1, 0, -50937, 439, 0, 0, 39, '438'),
	(243, 1, 0, -50937, 440, 0, 0, 39, '439'),
	(243, 1, 0, -50937, 441, 0, 0, 39, '440'),
	(243, 1, 0, -50937, 442, 0, 0, 39, '441'),
	(243, 1, 0, -50937, 443, 0, 0, 39, '442'),
	(243, 1, 0, -50937, 444, 0, 0, 39, '443'),
	(243, 1, 0, -50937, 445, 0, 0, 39, '444'),
	(243, 1, 0, -50937, 446, 0, 0, 39, '445'),
	(243, 1, 0, -50937, 447, 0, 0, 39, '446'),
	(243, 1, 0, -50937, 448, 0, 0, 39, '447'),
	(243, 1, 0, -50937, 449, 0, 0, 39, '448'),
	(243, 1, 0, -50937, 450, 0, 0, 39, '449'),
	(243, 1, 0, -50937, 451, 0, 0, 39, '450'),
	(243, 1, 0, -50937, 452, 0, 0, 39, '451'),
	(243, 1, 0, -50937, 453, 0, 0, 39, '452'),
	(243, 1, 0, -50937, 454, 0, 0, 39, '453'),
	(243, 1, 0, -50937, 455, 0, 0, 39, '454'),
	(243, 1, 0, -50937, 456, 0, 0, 39, '455'),
	(243, 1, 0, -50937, 457, 0, 0, 39, '456'),
	(243, 1, 0, -50937, 458, 0, 0, 39, '457'),
	(243, 1, 0, -50937, 459, 0, 0, 39, '458'),
	(243, 1, 0, -50937, 460, 0, 0, 39, '459'),
	(243, 1, 0, -50937, 461, 0, 0, 39, '460'),
	(243, 1, 0, -50937, 462, 0, 0, 39, '461'),
	(243, 1, 0, -50937, 463, 0, 0, 39, '462'),
	(243, 1, 0, -50937, 464, 0, 0, 39, '463'),
	(243, 1, 0, -50937, 465, 0, 0, 39, '464'),
	(243, 1, 0, -50937, 466, 0, 0, 39, '465'),
	(243, 1, 0, -50937, 467, 0, 0, 39, '466'),
	(243, 1, 0, -50937, 468, 0, 0, 39, '467'),
	(243, 1, 0, -50937, 469, 0, 0, 39, '468'),
	(243, 1, 0, -50937, 470, 0, 0, 39, '469'),
	(243, 1, 0, -50937, 471, 0, 0, 39, '470'),
	(243, 1, 0, -50937, 472, 0, 0, 39, '471'),
	(243, 1, 0, -50937, 473, 0, 0, 39, '472'),
	(243, 1, 0, -50937, 474, 0, 0, 39, '473'),
	(243, 1, 0, -50937, 475, 0, 0, 39, '474'),
	(243, 1, 0, -50937, 476, 0, 0, 39, '475'),
	(243, 1, 0, -50937, 477, 0, 0, 39, '476'),
	(243, 1, 0, -50937, 478, 0, 0, 39, '477'),
	(243, 1, 0, -50937, 479, 0, 0, 39, '478'),
	(243, 1, 0, -50937, 480, 0, 0, 39, '479'),
	(243, 1, 0, -50937, 481, 0, 0, 39, '480'),
	(243, 1, 0, -50937, 482, 0, 0, 39, '481'),
	(243, 1, 0, -50937, 483, 0, 0, 39, '482'),
	(243, 1, 0, -50937, 484, 0, 0, 39, '483'),
	(243, 1, 0, -50937, 485, 0, 0, 39, '484'),
	(243, 1, 0, -50937, 486, 0, 0, 39, '485'),
	(243, 1, 0, -50937, 487, 0, 0, 39, '486'),
	(243, 1, 0, -50937, 488, 0, 0, 39, '487'),
	(243, 1, 0, -50937, 489, 0, 0, 39, '488'),
	(243, 1, 0, -50937, 490, 0, 0, 39, '489'),
	(243, 1, 0, -50937, 491, 0, 0, 39, '490'),
	(243, 1, 0, -50937, 492, 0, 0, 39, '491'),
	(243, 1, 0, -50937, 493, 0, 0, 39, '492'),
	(243, 1, 0, -50937, 494, 0, 0, 39, '493'),
	(243, 1, 0, -50937, 495, 0, 0, 39, '494'),
	(243, 1, 0, -50937, 496, 0, 0, 39, '495'),
	(243, 1, 0, -50937, 497, 0, 0, 39, '496'),
	(243, 1, 0, -50937, 498, 0, 0, 39, '497'),
	(243, 1, 0, -50937, 499, 0, 0, 39, '498'),
	(243, 1, 0, -50937, 500, 0, 0, 39, '499'),
	(243, 1, 0, -50937, 501, 0, 0, 39, '500'),
	(243, 1, 0, -50937, 502, 0, 0, 39, '501'),
	(243, 1, 0, -50937, 503, 0, 0, 39, '502'),
	(243, 1, 0, -50937, 504, 0, 0, 39, '503'),
	(243, 1, 0, -50937, 505, 0, 0, 39, '504'),
	(243, 1, 0, -50937, 506, 0, 0, 39, '505'),
	(243, 1, 0, -50937, 507, 0, 0, 39, '506'),
	(243, 1, 0, -50937, 508, 0, 0, 39, '507'),
	(243, 1, 0, -50937, 509, 0, 0, 39, '508'),
	(243, 1, 0, -50937, 510, 0, 0, 39, '509'),
	(243, 1, 0, -50937, 511, 0, 0, 39, '510'),
	(243, 1, 0, -50937, 512, 0, 0, 39, '511'),
	(243, 1, 0, -50937, 513, 0, 0, 39, '512'),
	(243, 1, 0, -50937, 514, 0, 0, 39, '513'),
	(243, 1, 0, -50937, 515, 0, 0, 39, '514'),
	(243, 1, 0, -50937, 516, 0, 0, 39, '515'),
	(243, 1, 0, -50937, 517, 0, 0, 39, '516'),
	(243, 1, 0, -50937, 518, 0, 0, 39, '517'),
	(243, 1, 0, -50937, 519, 0, 0, 39, '518'),
	(243, 1, 0, -50937, 520, 0, 0, 39, '519'),
	(243, 1, 0, -50937, 521, 0, 0, 39, '520'),
	(243, 1, 0, -50937, 522, 0, 0, 39, '521'),
	(243, 1, 0, -50937, 523, 0, 0, 39, '522'),
	(243, 1, 0, -50937, 524, 0, 0, 39, '523'),
	(243, 1, 0, -50937, 525, 0, 0, 39, '524'),
	(243, 1, 0, -50937, 526, 0, 0, 39, '525'),
	(243, 1, 0, -50937, 527, 0, 0, 39, '526'),
	(243, 1, 0, -50937, 528, 0, 0, 39, '527'),
	(243, 1, 0, -50937, 529, 0, 0, 39, '528'),
	(243, 1, 0, -50937, 530, 0, 0, 39, '529'),
	(243, 1, 0, -50937, 531, 0, 0, 39, '530'),
	(243, 1, 0, -50937, 532, 0, 0, 39, '531'),
	(243, 1, 0, -50937, 533, 0, 0, 39, '532'),
	(243, 1, 0, -50937, 534, 0, 0, 39, '533'),
	(243, 1, 0, -50937, 535, 0, 0, 39, '534'),
	(243, 1, 0, -50937, 536, 0, 0, 39, '535'),
	(243, 1, 0, -50937, 537, 0, 0, 39, '536'),
	(243, 1, 0, -50937, 538, 0, 0, 39, '537'),
	(243, 1, 0, -50937, 539, 0, 0, 39, '538'),
	(243, 1, 0, -50937, 540, 0, 0, 39, '539'),
	(243, 1, 0, -50937, 541, 0, 0, 39, '540'),
	(243, 1, 0, -50937, 542, 0, 0, 39, '541'),
	(243, 1, 0, -50937, 543, 0, 0, 39, '542'),
	(243, 1, 0, -50937, 544, 0, 0, 39, '543'),
	(243, 1, 0, -50937, 545, 0, 0, 39, '544'),
	(243, 1, 0, -50937, 546, 0, 0, 39, '545'),
	(243, 1, 0, -50937, 547, 0, 0, 39, '546'),
	(243, 1, 0, -50937, 548, 0, 0, 39, '547'),
	(243, 1, 0, -50937, 549, 0, 0, 39, '548'),
	(243, 1, 0, -50937, 550, 0, 0, 39, '549'),
	(243, 1, 0, -50937, 551, 0, 0, 39, '550'),
	(243, 1, 0, -50937, 552, 0, 0, 39, '551'),
	(243, 1, 0, -50937, 553, 0, 0, 39, '552'),
	(243, 1, 0, -50937, 554, 0, 0, 39, '553'),
	(243, 1, 0, -50937, 555, 0, 0, 39, '554'),
	(243, 1, 0, -50937, 556, 0, 0, 39, '555'),
	(243, 1, 0, -50937, 557, 0, 0, 39, '556'),
	(243, 1, 0, -50937, 558, 0, 0, 39, '557'),
	(243, 1, 0, -50937, 559, 0, 0, 39, '558'),
	(243, 1, 0, -50937, 560, 0, 0, 39, '559'),
	(243, 1, 0, -50937, 561, 0, 0, 39, '560'),
	(243, 1, 0, -50937, 562, 0, 0, 39, '561'),
	(243, 1, 0, -50937, 563, 0, 0, 39, '562'),
	(243, 1, 0, -50937, 564, 0, 0, 39, '563'),
	(243, 1, 0, -50937, 565, 0, 0, 39, '564'),
	(243, 1, 0, -50937, 566, 0, 0, 39, '565'),
	(243, 1, 0, -50937, 567, 0, 0, 39, '566'),
	(243, 1, 0, -50937, 568, 0, 0, 39, '567'),
	(243, 1, 0, -50937, 569, 0, 0, 39, '568'),
	(243, 1, 0, -50937, 570, 0, 0, 39, '569'),
	(243, 1, 0, -50937, 571, 0, 0, 39, '570'),
	(243, 1, 0, -50937, 572, 0, 0, 39, '571'),
	(243, 1, 0, -50937, 573, 0, 0, 39, '572'),
	(243, 1, 0, -50937, 574, 0, 0, 39, '573'),
	(243, 1, 0, -50937, 575, 0, 0, 39, '574'),
	(243, 1, 0, -50937, 576, 0, 0, 39, '575'),
	(243, 1, 0, -50937, 577, 0, 0, 39, '576'),
	(243, 1, 0, -50937, 578, 0, 0, 39, '577'),
	(243, 1, 0, -50937, 579, 0, 0, 39, '578'),
	(243, 1, 0, -50937, 580, 0, 0, 39, '579'),
	(243, 1, 0, -50937, 581, 0, 0, 39, '580'),
	(243, 1, 0, -50937, 582, 0, 0, 39, '581'),
	(243, 1, 0, -50937, 583, 0, 0, 39, '582'),
	(243, 1, 0, -50937, 584, 0, 0, 39, '583'),
	(243, 1, 0, -50937, 585, 0, 0, 39, '584'),
	(243, 1, 0, -50937, 586, 0, 0, 39, '585'),
	(243, 1, 0, -50937, 587, 0, 0, 39, '586'),
	(243, 1, 0, -50937, 588, 0, 0, 39, '587'),
	(243, 1, 0, -50937, 589, 0, 0, 39, '588'),
	(243, 1, 0, -50937, 590, 0, 0, 39, '589'),
	(243, 1, 0, -50937, 591, 0, 0, 39, '590'),
	(243, 1, 0, -50937, 592, 0, 0, 39, '591'),
	(243, 1, 0, -50937, 593, 0, 0, 39, '592'),
	(243, 1, 0, -50937, 594, 0, 0, 39, '593'),
	(243, 1, 0, -50937, 595, 0, 0, 39, '594'),
	(243, 1, 0, -50937, 596, 0, 0, 39, '595'),
	(243, 1, 0, -50937, 597, 0, 0, 39, '596'),
	(243, 1, 0, -50937, 598, 0, 0, 39, '597'),
	(243, 1, 0, -50937, 599, 0, 0, 39, '598'),
	(243, 1, 0, -50937, 600, 0, 0, 39, '599'),
	(243, 1, 0, -50937, 601, 0, 0, 39, '600'),
	(243, 1, 0, -50937, 602, 0, 0, 39, '601'),
	(243, 1, 0, -50937, 603, 0, 0, 39, '602'),
	(243, 1, 0, -50937, 604, 0, 0, 39, '603'),
	(243, 1, 0, -50937, 605, 0, 0, 39, '604'),
	(243, 1, 0, -50937, 606, 0, 0, 39, '605'),
	(243, 1, 0, -50937, 607, 0, 0, 39, '606'),
	(243, 1, 0, -50937, 608, 0, 0, 39, '607'),
	(243, 1, 0, -50937, 609, 0, 0, 39, '608'),
	(243, 1, 0, -50937, 610, 0, 0, 39, '609'),
	(243, 1, 0, -50937, 611, 0, 0, 39, '610'),
	(243, 1, 0, -50937, 612, 0, 0, 39, '611'),
	(243, 1, 0, -50937, 613, 0, 0, 39, '612'),
	(243, 1, 0, -50937, 614, 0, 0, 39, '613'),
	(243, 1, 0, -50937, 615, 0, 0, 39, '614'),
	(243, 1, 0, -50937, 616, 0, 0, 39, '615'),
	(243, 1, 0, -50937, 617, 0, 0, 39, '616'),
	(243, 1, 0, -50937, 618, 0, 0, 39, '617'),
	(243, 1, 0, -50937, 619, 0, 0, 39, '618'),
	(243, 1, 0, -50937, 620, 0, 0, 39, '619'),
	(243, 1, 0, -50937, 621, 0, 0, 39, '620'),
	(243, 1, 0, -50937, 622, 0, 0, 39, '621'),
	(243, 1, 0, -50937, 623, 0, 0, 39, '622'),
	(243, 1, 0, -50937, 624, 0, 0, 39, '623'),
	(243, 1, 0, -50937, 625, 0, 0, 39, '624'),
	(243, 1, 0, -50937, 626, 0, 0, 39, '625'),
	(243, 1, 0, -50937, 627, 0, 0, 39, '626'),
	(243, 1, 0, -50937, 628, 0, 0, 39, '627'),
	(243, 1, 0, -50937, 629, 0, 0, 39, '628'),
	(243, 1, 0, -50937, 630, 0, 0, 39, '629'),
	(243, 1, 0, -50937, 631, 0, 0, 39, '630'),
	(243, 1, 0, -50937, 632, 0, 0, 39, '631'),
	(243, 1, 0, -50937, 633, 0, 0, 39, '632'),
	(243, 1, 0, -50937, 634, 0, 0, 39, '633'),
	(243, 1, 0, -50937, 635, 0, 0, 39, '634'),
	(243, 1, 0, -50937, 636, 0, 0, 39, '635'),
	(243, 1, 0, -50937, 637, 0, 0, 39, '636'),
	(243, 1, 0, -50937, 638, 0, 0, 39, '637'),
	(243, 1, 0, -50937, 639, 0, 0, 39, '638'),
	(243, 1, 0, -50937, 640, 0, 0, 39, '639'),
	(243, 1, 0, -50937, 641, 0, 0, 39, '640'),
	(243, 1, 0, -50937, 642, 0, 0, 39, '641'),
	(243, 1, 0, -50937, 643, 0, 0, 39, '642'),
	(243, 1, 0, -50937, 644, 0, 0, 39, '643'),
	(243, 1, 0, -50937, 645, 0, 0, 39, '644'),
	(243, 1, 0, -50937, 646, 0, 0, 39, '645'),
	(243, 1, 0, -50937, 647, 0, 0, 39, '646'),
	(243, 1, 0, -50937, 648, 0, 0, 39, '647'),
	(243, 1, 0, -50937, 649, 0, 0, 39, '648'),
	(243, 1, 0, -50937, 650, 0, 0, 39, '649'),
	(243, 1, 0, -50937, 651, 0, 0, 39, '650'),
	(243, 1, 0, -50937, 652, 0, 0, 39, '651'),
	(243, 1, 0, -50937, 653, 0, 0, 39, '652'),
	(243, 1, 0, -50937, 654, 0, 0, 39, '653'),
	(243, 1, 0, -50937, 655, 0, 0, 39, '654'),
	(243, 1, 0, -50937, 656, 0, 0, 39, '655'),
	(243, 1, 0, -50937, 657, 0, 0, 39, '656'),
	(243, 1, 0, -50937, 658, 0, 0, 39, '657'),
	(243, 1, 0, -50937, 659, 0, 0, 39, '658'),
	(243, 1, 0, -50937, 660, 0, 0, 39, '659'),
	(243, 1, 0, -50937, 661, 0, 0, 39, '660'),
	(243, 1, 0, -50937, 662, 0, 0, 39, '661'),
	(243, 1, 0, -50937, 663, 0, 0, 39, '662'),
	(243, 1, 0, -50937, 664, 0, 0, 39, '663'),
	(243, 1, 0, -50937, 665, 0, 0, 39, '664'),
	(243, 1, 0, -50937, 666, 0, 0, 39, '665'),
	(243, 1, 0, -50937, 667, 0, 0, 39, '666'),
	(243, 1, 0, -50937, 668, 0, 0, 39, '667'),
	(243, 1, 0, -50937, 669, 0, 0, 39, '668'),
	(243, 1, 0, -50937, 670, 0, 0, 39, '669'),
	(243, 1, 0, -50937, 671, 0, 0, 39, '670'),
	(243, 1, 0, -50937, 672, 0, 0, 39, '671'),
	(243, 1, 0, -50937, 673, 0, 0, 39, '672'),
	(243, 1, 0, -50937, 674, 0, 0, 39, '673'),
	(243, 1, 0, -50937, 675, 0, 0, 39, '674'),
	(243, 1, 0, -50937, 676, 0, 0, 39, '675'),
	(243, 1, 0, -50937, 677, 0, 0, 39, '676'),
	(243, 1, 0, -50937, 678, 0, 0, 39, '677'),
	(243, 1, 0, -50937, 679, 0, 0, 39, '678'),
	(243, 1, 0, -50937, 680, 0, 0, 39, '679'),
	(243, 1, 0, -50937, 681, 0, 0, 39, '680'),
	(243, 1, 0, -50937, 682, 0, 0, 39, '681'),
	(243, 1, 0, -50937, 683, 0, 0, 39, '682'),
	(243, 1, 0, -50937, 684, 0, 0, 39, '683'),
	(243, 1, 0, -50937, 685, 0, 0, 39, '684'),
	(243, 1, 0, -50937, 686, 0, 0, 39, '685'),
	(243, 1, 0, -50937, 687, 0, 0, 39, '686'),
	(243, 1, 0, -50937, 688, 0, 0, 39, '687'),
	(243, 1, 0, -50937, 689, 0, 0, 39, '688'),
	(243, 1, 0, -50937, 690, 0, 0, 39, '689'),
	(243, 1, 0, -50937, 691, 0, 0, 39, '690'),
	(243, 1, 0, -50937, 692, 0, 0, 39, '691'),
	(243, 1, 0, -50937, 693, 0, 0, 39, '692'),
	(243, 1, 0, -50937, 694, 0, 0, 39, '693'),
	(243, 1, 0, -50937, 695, 0, 0, 39, '694'),
	(243, 1, 0, -50937, 696, 0, 0, 39, '695'),
	(243, 1, 0, -50937, 697, 0, 0, 39, '696'),
	(243, 1, 0, -50937, 698, 0, 0, 39, '697'),
	(243, 1, 0, -50937, 699, 0, 0, 39, '698'),
	(243, 1, 0, -50937, 700, 0, 0, 39, '699'),
	(243, 1, 0, -50937, 701, 0, 0, 39, '700'),
	(243, 1, 0, -50937, 702, 0, 0, 39, '701'),
	(243, 1, 0, -50937, 703, 0, 0, 39, '702'),
	(243, 1, 0, -50937, 704, 0, 0, 39, '703'),
	(243, 1, 0, -50937, 705, 0, 0, 39, '704'),
	(243, 1, 0, -50937, 706, 0, 0, 39, '705'),
	(243, 1, 0, -50937, 707, 0, 0, 39, '706'),
	(243, 1, 0, -50937, 708, 0, 0, 39, '707'),
	(243, 1, 0, -50937, 709, 0, 0, 39, '708'),
	(243, 1, 0, -50937, 710, 0, 0, 39, '709'),
	(243, 1, 0, -50937, 711, 0, 0, 39, '710'),
	(243, 1, 0, -50937, 712, 0, 0, 39, '711'),
	(243, 1, 0, -50937, 713, 0, 0, 39, '712'),
	(243, 1, 0, -50937, 714, 0, 0, 39, '713'),
	(243, 1, 0, -50937, 715, 0, 0, 39, '714'),
	(243, 1, 0, -50937, 716, 0, 0, 39, '715'),
	(243, 1, 0, -50937, 717, 0, 0, 39, '716'),
	(243, 1, 0, -50937, 718, 0, 0, 39, '717'),
	(243, 1, 0, -50937, 719, 0, 0, 39, '718'),
	(243, 1, 0, -50937, 720, 0, 0, 39, '719'),
	(243, 1, 0, -50937, 721, 0, 0, 39, '720'),
	(243, 1, 0, -50937, 722, 0, 0, 39, '721'),
	(243, 1, 0, -50937, 723, 0, 0, 39, '722'),
	(243, 1, 0, -50937, 724, 0, 0, 39, '723'),
	(243, 1, 0, -50937, 725, 0, 0, 39, '724'),
	(243, 1, 0, -50937, 726, 0, 0, 39, '725'),
	(243, 1, 0, -50937, 727, 0, 0, 39, '726'),
	(243, 1, 0, -50937, 728, 0, 0, 39, '727'),
	(243, 1, 0, -50937, 729, 0, 0, 39, '728'),
	(243, 1, 0, -50937, 730, 0, 0, 39, '729'),
	(243, 1, 0, -50937, 731, 0, 0, 39, '730'),
	(243, 1, 0, -50937, 732, 0, 0, 39, '731'),
	(243, 1, 0, -50937, 733, 0, 0, 39, '732'),
	(243, 1, 0, -50937, 734, 0, 0, 39, '733'),
	(243, 1, 0, -50937, 735, 0, 0, 39, '734'),
	(243, 1, 0, -50937, 736, 0, 0, 39, '735'),
	(243, 1, 0, -50937, 737, 0, 0, 39, '736'),
	(243, 1, 0, -50937, 738, 0, 0, 39, '737'),
	(243, 1, 0, -50937, 739, 0, 0, 39, '738'),
	(243, 1, 0, -50937, 740, 0, 0, 39, '739'),
	(243, 1, 0, -50937, 741, 0, 0, 39, '740'),
	(243, 1, 0, -50937, 742, 0, 0, 39, '741'),
	(243, 1, 0, -50937, 743, 0, 0, 39, '742'),
	(243, 1, 0, -50937, 744, 0, 0, 39, '743'),
	(243, 1, 0, -50937, 745, 0, 0, 39, '744'),
	(243, 1, 0, -50937, 746, 0, 0, 39, '745'),
	(243, 1, 0, -50937, 747, 0, 0, 39, '746'),
	(243, 1, 0, -50937, 748, 0, 0, 39, '747'),
	(243, 1, 0, -50937, 749, 0, 0, 39, '748'),
	(243, 1, 0, -50937, 750, 0, 0, 39, '749'),
	(243, 1, 0, -50937, 751, 0, 0, 39, '750'),
	(243, 1, 0, -50937, 752, 0, 0, 39, '751'),
	(243, 1, 0, -50937, 753, 0, 0, 39, '752'),
	(243, 1, 0, -50937, 754, 0, 0, 39, '753'),
	(243, 1, 0, -50937, 755, 0, 0, 39, '754'),
	(243, 1, 0, -50937, 756, 0, 0, 39, '755'),
	(243, 1, 0, -50937, 757, 0, 0, 39, '756'),
	(243, 1, 0, -50937, 758, 0, 0, 39, '757'),
	(243, 1, 0, -50937, 759, 0, 0, 39, '758'),
	(243, 1, 0, -50937, 760, 0, 0, 39, '759'),
	(243, 1, 0, -50937, 761, 0, 0, 39, '760'),
	(243, 1, 0, -50937, 762, 0, 0, 39, '761'),
	(243, 1, 0, -50937, 763, 0, 0, 39, '762'),
	(243, 1, 0, -50937, 764, 0, 0, 39, '763'),
	(243, 1, 0, -50937, 765, 0, 0, 39, '764'),
	(243, 1, 0, -50937, 766, 0, 0, 39, '765'),
	(243, 1, 0, -50937, 767, 0, 0, 39, '766'),
	(243, 1, 0, -50937, 768, 0, 0, 39, '767'),
	(243, 1, 0, -50937, 769, 0, 0, 39, '768'),
	(243, 1, 0, -50937, 770, 0, 0, 39, '769'),
	(243, 1, 0, -50937, 771, 0, 0, 39, '770'),
	(243, 1, 0, -50937, 772, 0, 0, 39, '771'),
	(243, 1, 0, -50937, 773, 0, 0, 39, '772'),
	(243, 1, 0, -50937, 774, 0, 0, 39, '773'),
	(243, 1, 0, -50937, 775, 0, 0, 39, '774'),
	(243, 1, 0, -50937, 776, 0, 0, 39, '775'),
	(243, 1, 0, -50937, 777, 0, 0, 39, '776'),
	(243, 1, 0, -50937, 778, 0, 0, 39, '777'),
	(243, 1, 0, -50937, 779, 0, 0, 39, '778'),
	(243, 1, 0, -50937, 780, 0, 0, 39, '779'),
	(243, 1, 0, -50937, 781, 0, 0, 39, '780'),
	(243, 1, 0, -50937, 782, 0, 0, 39, '781'),
	(243, 1, 0, -50937, 783, 0, 0, 39, '782'),
	(243, 1, 0, -50937, 784, 0, 0, 39, '783'),
	(243, 1, 0, -50937, 785, 0, 0, 39, '784'),
	(243, 1, 0, -50937, 786, 0, 0, 39, '785'),
	(243, 1, 0, -50937, 787, 0, 0, 39, '786'),
	(243, 1, 0, -50937, 788, 0, 0, 39, '787'),
	(243, 1, 0, -50937, 789, 0, 0, 39, '788'),
	(243, 1, 0, -50937, 790, 0, 0, 39, '789'),
	(243, 1, 0, -50937, 791, 0, 0, 39, '790'),
	(243, 1, 0, -50937, 792, 0, 0, 39, '791'),
	(243, 1, 0, -50937, 793, 0, 0, 39, '792'),
	(243, 1, 0, -50937, 794, 0, 0, 39, '793'),
	(243, 1, 0, -50937, 795, 0, 0, 39, '794'),
	(243, 1, 0, -50937, 796, 0, 0, 39, '795'),
	(243, 1, 0, -50937, 797, 0, 0, 39, '796'),
	(243, 1, 0, -50937, 798, 0, 0, 39, '797'),
	(243, 1, 0, -50937, 799, 0, 0, 39, '798'),
	(243, 1, 0, -50937, 800, 0, 0, 39, '799'),
	(243, 1, 0, -50937, 801, 0, 0, 39, '800'),
	(243, 1, 0, -50937, 802, 0, 0, 39, '801'),
	(243, 1, 0, -50937, 803, 0, 0, 39, '802'),
	(243, 1, 0, -50937, 804, 0, 0, 39, '803'),
	(243, 1, 0, -50937, 805, 0, 0, 39, '804'),
	(243, 1, 0, -50937, 806, 0, 0, 39, '805'),
	(243, 1, 0, -50937, 807, 0, 0, 39, '806'),
	(243, 1, 0, -50937, 808, 0, 0, 39, '807'),
	(243, 1, 0, -50937, 809, 0, 0, 39, '808'),
	(243, 1, 0, -50937, 810, 0, 0, 39, '809'),
	(243, 1, 0, -50937, 811, 0, 0, 39, '810'),
	(243, 1, 0, -50937, 812, 0, 0, 39, '811'),
	(243, 1, 0, -50937, 813, 0, 0, 39, '812'),
	(243, 1, 0, -50937, 814, 0, 0, 39, '813'),
	(243, 1, 0, -50937, 815, 0, 0, 39, '814'),
	(243, 1, 0, -50937, 816, 0, 0, 39, '815'),
	(243, 1, 0, -50937, 817, 0, 0, 39, '816'),
	(243, 1, 0, -50937, 818, 0, 0, 39, '817'),
	(243, 1, 0, -50937, 819, 0, 0, 39, '818'),
	(243, 1, 0, -50937, 820, 0, 0, 39, '819'),
	(243, 1, 0, -50937, 821, 0, 0, 39, '820'),
	(243, 1, 0, -50937, 822, 0, 0, 39, '821'),
	(243, 1, 0, -50937, 823, 0, 0, 39, '822'),
	(243, 1, 0, -50937, 824, 0, 0, 39, '823'),
	(243, 1, 0, -50937, 825, 0, 0, 39, '824'),
	(243, 1, 0, -50937, 826, 0, 0, 39, '825'),
	(243, 1, 0, -50937, 827, 0, 0, 39, '826'),
	(243, 1, 0, -50937, 828, 0, 0, 39, '827'),
	(243, 1, 0, -50937, 829, 0, 0, 39, '828'),
	(243, 1, 0, -50937, 830, 0, 0, 39, '829'),
	(243, 1, 0, -50937, 831, 0, 0, 39, '830'),
	(243, 1, 0, -50937, 832, 0, 0, 39, '831'),
	(243, 1, 0, -50937, 833, 0, 0, 39, '832'),
	(243, 1, 0, -50937, 834, 0, 0, 39, '833'),
	(243, 1, 0, -50937, 835, 0, 0, 39, '834'),
	(243, 1, 0, -50937, 836, 0, 0, 39, '835'),
	(243, 1, 0, -50937, 837, 0, 0, 39, '836'),
	(243, 1, 0, -50937, 838, 0, 0, 39, '837'),
	(243, 1, 0, -50937, 839, 0, 0, 39, '838'),
	(243, 1, 0, -50937, 840, 0, 0, 39, '839'),
	(243, 1, 0, -50937, 841, 0, 0, 39, '840'),
	(243, 1, 0, -50937, 842, 0, 0, 39, '841'),
	(243, 1, 0, -50937, 843, 0, 0, 39, '842'),
	(243, 1, 0, -50937, 844, 0, 0, 39, '843'),
	(243, 1, 0, -50937, 845, 0, 0, 39, '844'),
	(243, 1, 0, -50937, 846, 0, 0, 39, '845'),
	(243, 1, 0, -50937, 847, 0, 0, 39, '846'),
	(243, 1, 0, -50937, 848, 0, 0, 39, '847'),
	(243, 1, 0, -50937, 849, 0, 0, 39, '848'),
	(243, 1, 0, -50937, 850, 0, 0, 39, '849'),
	(243, 1, 0, -50937, 851, 0, 0, 39, '850'),
	(243, 1, 0, -50937, 852, 0, 0, 39, '851'),
	(243, 1, 0, -50937, 853, 0, 0, 39, '852'),
	(243, 1, 0, -50937, 854, 0, 0, 39, '853'),
	(243, 1, 0, -50937, 855, 0, 0, 39, '854'),
	(243, 1, 0, -50937, 856, 0, 0, 39, '855'),
	(243, 1, 0, -50937, 857, 0, 0, 39, '856'),
	(243, 1, 0, -50937, 858, 0, 0, 39, '857'),
	(243, 1, 0, -50937, 859, 0, 0, 39, '858'),
	(243, 1, 0, -50937, 860, 0, 0, 39, '859'),
	(243, 1, 0, -50937, 861, 0, 0, 39, '860'),
	(243, 1, 0, -50937, 862, 0, 0, 39, '861'),
	(243, 1, 0, -50937, 863, 0, 0, 39, '862'),
	(243, 1, 0, -50937, 864, 0, 0, 39, '863'),
	(243, 1, 0, -50937, 865, 0, 0, 39, '864'),
	(243, 1, 0, -50937, 866, 0, 0, 39, '865'),
	(243, 1, 0, -50937, 867, 0, 0, 39, '866'),
	(243, 1, 0, -50937, 868, 0, 0, 39, '867'),
	(243, 1, 0, -50937, 869, 0, 0, 39, '868'),
	(243, 1, 0, -50937, 870, 0, 0, 39, '869'),
	(243, 1, 0, -50937, 871, 0, 0, 39, '870'),
	(243, 1, 0, -50937, 872, 0, 0, 39, '871'),
	(243, 1, 0, -50937, 873, 0, 0, 39, '872'),
	(243, 1, 0, -50937, 874, 0, 0, 39, '873'),
	(243, 1, 0, -50937, 875, 0, 0, 39, '874'),
	(243, 1, 0, -50937, 876, 0, 0, 39, '875'),
	(243, 1, 0, -50937, 877, 0, 0, 39, '876'),
	(243, 1, 0, -50937, 878, 0, 0, 39, '877'),
	(243, 1, 0, -50937, 879, 0, 0, 39, '878'),
	(243, 1, 0, -50937, 880, 0, 0, 39, '879'),
	(243, 1, 0, -50937, 881, 0, 0, 39, '880'),
	(243, 1, 0, -50937, 882, 0, 0, 39, '881'),
	(243, 1, 0, -50937, 883, 0, 0, 39, '882'),
	(243, 1, 0, -50937, 884, 0, 0, 39, '883'),
	(243, 1, 0, -50937, 885, 0, 0, 39, '884'),
	(243, 1, 0, -50937, 886, 0, 0, 39, '885'),
	(243, 1, 0, -50937, 887, 0, 0, 39, '886'),
	(243, 1, 0, -50937, 888, 0, 0, 39, '887'),
	(243, 1, 0, -50937, 889, 0, 0, 39, '888'),
	(243, 1, 0, -50937, 890, 0, 0, 39, '889'),
	(243, 1, 0, -50937, 891, 0, 0, 39, '890'),
	(243, 1, 0, -50937, 892, 0, 0, 39, '891'),
	(243, 1, 0, -50937, 893, 0, 0, 39, '892'),
	(243, 1, 0, -50937, 894, 0, 0, 39, '893'),
	(243, 1, 0, -50937, 895, 0, 0, 39, '894'),
	(243, 1, 0, -50937, 896, 0, 0, 39, '895'),
	(243, 1, 0, -50937, 897, 0, 0, 39, '896'),
	(243, 1, 0, -50937, 898, 0, 0, 39, '897'),
	(243, 1, 0, -50937, 899, 0, 0, 39, '898'),
	(243, 1, 0, -50937, 900, 0, 0, 39, '899'),
	(243, 1, 0, -50937, 901, 0, 0, 39, '900'),
	(243, 1, 0, -50937, 902, 0, 0, 39, '901'),
	(243, 1, 0, -50937, 903, 0, 0, 39, '902'),
	(243, 1, 0, -50937, 904, 0, 0, 39, '903'),
	(243, 1, 0, -50937, 905, 0, 0, 39, '904'),
	(243, 1, 0, -50937, 906, 0, 0, 39, '905'),
	(243, 1, 0, -50937, 907, 0, 0, 39, '906'),
	(243, 1, 0, -50937, 908, 0, 0, 39, '907'),
	(243, 1, 0, -50937, 909, 0, 0, 39, '908'),
	(243, 1, 0, -50937, 910, 0, 0, 39, '909'),
	(243, 1, 0, -50937, 911, 0, 0, 39, '910'),
	(243, 1, 0, -50937, 912, 0, 0, 39, '911'),
	(243, 1, 0, -50937, 913, 0, 0, 39, '912'),
	(243, 1, 0, -50937, 914, 0, 0, 39, '913'),
	(243, 1, 0, -50937, 915, 0, 0, 39, '914'),
	(243, 1, 0, -50937, 916, 0, 0, 39, '915'),
	(243, 1, 0, -50937, 917, 0, 0, 39, '916'),
	(243, 1, 0, -50937, 918, 0, 0, 39, '917'),
	(243, 1, 0, -50937, 919, 0, 0, 39, '918'),
	(243, 1, 0, -50937, 920, 0, 0, 39, '919'),
	(243, 1, 0, -50937, 921, 0, 0, 39, '920'),
	(243, 1, 0, -50937, 922, 0, 0, 39, '921'),
	(243, 1, 0, -50937, 923, 0, 0, 39, '922'),
	(243, 1, 0, -50937, 924, 0, 0, 39, '923'),
	(243, 1, 0, -50937, 925, 0, 0, 39, '924'),
	(243, 1, 0, -50937, 926, 0, 0, 39, '925'),
	(243, 1, 0, -50937, 927, 0, 0, 39, '926'),
	(243, 1, 0, -50937, 928, 0, 0, 39, '927'),
	(243, 1, 0, -50937, 929, 0, 0, 39, '928'),
	(243, 1, 0, -50937, 930, 0, 0, 39, '929'),
	(243, 1, 0, -50937, 931, 0, 0, 39, '930'),
	(243, 1, 0, -50937, 932, 0, 0, 39, '931'),
	(243, 1, 0, -50937, 933, 0, 0, 39, '932'),
	(243, 1, 0, -50937, 934, 0, 0, 39, '933'),
	(243, 1, 0, -50937, 935, 0, 0, 39, '934'),
	(243, 1, 0, -50937, 936, 0, 0, 39, '935'),
	(243, 1, 0, -50937, 937, 0, 0, 39, '936'),
	(243, 1, 0, -50937, 938, 0, 0, 39, '937'),
	(243, 1, 0, -50937, 939, 0, 0, 39, '938'),
	(243, 1, 0, -50937, 940, 0, 0, 39, '939'),
	(243, 1, 0, -50937, 941, 0, 0, 39, '940'),
	(243, 1, 0, -50937, 942, 0, 0, 39, '941'),
	(243, 1, 0, -50937, 943, 0, 0, 39, '942'),
	(243, 1, 0, -50937, 944, 0, 0, 39, '943'),
	(243, 1, 0, -50937, 945, 0, 0, 39, '944'),
	(243, 1, 0, -50937, 946, 0, 0, 39, '945'),
	(243, 1, 0, -50937, 947, 0, 0, 39, '946'),
	(243, 1, 0, -50937, 948, 0, 0, 39, '947'),
	(243, 1, 0, -50937, 949, 0, 0, 39, '948'),
	(243, 1, 0, -50937, 950, 0, 0, 39, '949'),
	(243, 1, 0, -50937, 951, 0, 0, 39, '950'),
	(243, 1, 0, -50937, 952, 0, 0, 39, '951'),
	(243, 1, 0, -50937, 953, 0, 0, 39, '952'),
	(243, 1, 0, -50937, 954, 0, 0, 39, '953'),
	(243, 1, 0, -50937, 955, 0, 0, 39, '954'),
	(243, 1, 0, -50937, 956, 0, 0, 39, '955'),
	(243, 1, 0, -50937, 957, 0, 0, 39, '956'),
	(243, 1, 0, -50937, 958, 0, 0, 39, '957'),
	(243, 1, 0, -50937, 959, 0, 0, 39, '958'),
	(243, 1, 0, -50937, 960, 0, 0, 39, '959'),
	(243, 1, 0, -50937, 961, 0, 0, 39, '960'),
	(243, 1, 0, -50937, 962, 0, 0, 39, '961'),
	(243, 1, 0, -50937, 963, 0, 0, 39, '962'),
	(243, 1, 0, -50937, 964, 0, 0, 39, '963'),
	(243, 1, 0, -50937, 965, 0, 0, 39, '964'),
	(243, 1, 0, -50937, 966, 0, 0, 39, '965'),
	(243, 1, 0, -50937, 967, 0, 0, 39, '966'),
	(243, 1, 0, -50937, 968, 0, 0, 39, '967'),
	(243, 1, 0, -50937, 969, 0, 0, 39, '968'),
	(243, 1, 0, -50937, 970, 0, 0, 39, '969'),
	(243, 1, 0, -50937, 971, 0, 0, 39, '970'),
	(243, 1, 0, -50937, 972, 0, 0, 39, '971'),
	(243, 1, 0, -50937, 973, 0, 0, 39, '972'),
	(243, 1, 0, -50937, 974, 0, 0, 39, '973'),
	(243, 1, 0, -50937, 975, 0, 0, 39, '974'),
	(243, 1, 0, -50937, 976, 0, 0, 39, '975'),
	(243, 1, 0, -50937, 977, 0, 0, 39, '976'),
	(243, 1, 0, -50937, 978, 0, 0, 39, '977'),
	(243, 1, 0, -50937, 979, 0, 0, 39, '978'),
	(243, 1, 0, -50937, 980, 0, 0, 39, '979'),
	(243, 1, 0, -50937, 981, 0, 0, 39, '980'),
	(243, 1, 0, -50937, 982, 0, 0, 39, '981'),
	(243, 1, 0, -50937, 983, 0, 0, 39, '982'),
	(243, 1, 0, -50937, 984, 0, 0, 39, '983'),
	(243, 1, 0, -50937, 985, 0, 0, 39, '984'),
	(243, 1, 0, -50937, 986, 0, 0, 39, '985'),
	(243, 1, 0, -50937, 987, 0, 0, 39, '986'),
	(243, 1, 0, -50937, 988, 0, 0, 39, '987'),
	(243, 1, 0, -50937, 989, 0, 0, 39, '988'),
	(243, 1, 0, -50937, 990, 0, 0, 39, '989'),
	(243, 1, 0, -50937, 991, 0, 0, 39, '990'),
	(243, 1, 0, -50937, 992, 0, 0, 39, '991'),
	(243, 1, 0, -50937, 993, 0, 0, 39, '992'),
	(243, 1, 0, -50937, 994, 0, 0, 39, '993'),
	(243, 1, 0, -50937, 995, 0, 0, 39, '994'),
	(243, 1, 0, -50937, 996, 0, 0, 39, '995'),
	(243, 1, 0, -50937, 997, 0, 0, 39, '996'),
	(243, 1, 0, -50937, 998, 0, 0, 39, '997'),
	(243, 1, 0, -50937, 999, 0, 0, 39, '998'),
	(243, 1, 0, -50937, 1000, 0, 0, 39, '999'),
	(243, 1, 0, -50937, 1001, 0, 0, 39, '1000'),
	(243, 1, 0, -50937, 1002, 0, 0, 39, '1001'),
	(243, 1, 0, -50937, 1003, 0, 0, 39, '1002'),
	(243, 1, 0, -50937, 1004, 0, 0, 39, '1003'),
	(243, 1, 0, -50937, 1005, 0, 0, 39, '1004'),
	(243, 1, 0, -50937, 1006, 0, 0, 39, '1005'),
	(243, 1, 0, -50937, 1007, 0, 0, 39, '1006'),
	(243, 1, 0, -50937, 1008, 0, 0, 39, '1007'),
	(243, 1, 0, -50937, 1009, 0, 0, 39, '1008'),
	(243, 1, 0, -50937, 1010, 0, 0, 39, '1009'),
	(243, 1, 0, -50937, 1011, 0, 0, 39, '1010'),
	(243, 1, 0, -50937, 1012, 0, 0, 39, '1011'),
	(243, 1, 0, -50937, 1013, 0, 0, 39, '1012'),
	(243, 1, 0, -50937, 1014, 0, 0, 39, '1013'),
	(243, 1, 0, -50937, 1015, 0, 0, 39, '1014'),
	(243, 1, 0, -50937, 1016, 0, 0, 39, '1015'),
	(243, 1, 0, -50937, 1017, 0, 0, 39, '1016'),
	(243, 1, 0, -50937, 1018, 0, 0, 39, '1017'),
	(243, 1, 0, -50937, 1019, 0, 0, 39, '1018'),
	(243, 1, 0, -50937, 1020, 0, 0, 39, '1019'),
	(243, 1, 0, -50937, 1021, 0, 0, 39, '1020'),
	(243, 1, 0, -50937, 1022, 0, 0, 39, '1021'),
	(243, 1, 0, -50937, 1023, 0, 0, 39, '1022'),
	(243, 1, 0, -50937, 1024, 0, 0, 39, '1023'),
	(243, 1, 0, -50937, 1025, 0, 0, 39, '1024'),
	(243, 1, 0, -50937, 1026, 0, 0, 39, '1025'),
	(243, 1, 0, -50937, 1027, 0, 0, 39, '1026'),
	(243, 1, 0, -50937, 1028, 0, 0, 39, '1027'),
	(243, 1, 0, -50937, 1029, 0, 0, 39, '1028'),
	(243, 1, 0, -50937, 1030, 0, 0, 39, '1029'),
	(243, 1, 0, -50937, 1031, 0, 0, 39, '1030'),
	(243, 1, 0, -50937, 1032, 0, 0, 39, '1031'),
	(243, 1, 0, -50937, 1033, 0, 0, 39, '1032'),
	(243, 1, 0, -50937, 1034, 0, 0, 39, '1033'),
	(243, 1, 0, -50937, 1035, 0, 0, 39, '1034'),
	(243, 1, 0, -50937, 1036, 0, 0, 39, '1035'),
	(243, 1, 0, -50937, 1037, 0, 0, 39, '1036'),
	(243, 1, 0, -50937, 1038, 0, 0, 39, '1037'),
	(243, 1, 0, -50937, 1039, 0, 0, 39, '1038'),
	(243, 1, 0, -50937, 1040, 0, 0, 39, '1039'),
	(243, 1, 0, -50937, 1041, 0, 0, 39, '1040'),
	(243, 1, 0, -50937, 1042, 0, 0, 39, '1041'),
	(243, 1, 0, -50937, 1043, 0, 0, 39, '1042'),
	(243, 1, 0, -50937, 1044, 0, 0, 39, '1043'),
	(243, 1, 0, -50937, 1045, 0, 0, 39, '1044'),
	(243, 1, 0, -50937, 1046, 0, 0, 39, '1045'),
	(243, 1, 0, -50937, 1047, 0, 0, 39, '1046'),
	(243, 1, 0, -50937, 1048, 0, 0, 39, '1047'),
	(243, 1, 0, -50937, 1049, 0, 0, 39, '1048'),
	(243, 1, 0, -50937, 1050, 0, 0, 39, '1049'),
	(243, 1, 0, -50937, 1051, 0, 0, 39, '1050'),
	(243, 1, 0, -50937, 1052, 0, 0, 39, '1051'),
	(243, 1, 0, -50937, 1053, 0, 0, 39, '1052'),
	(243, 1, 0, -50937, 1054, 0, 0, 39, '1053'),
	(243, 1, 0, -50937, 1055, 0, 0, 39, '1054'),
	(243, 1, 0, -50937, 1056, 0, 0, 39, '1055'),
	(243, 1, 0, -50937, 1057, 0, 0, 39, '1056'),
	(243, 1, 0, -50937, 1058, 0, 0, 39, '1057'),
	(243, 1, 0, -50937, 1059, 0, 0, 39, '1058'),
	(243, 1, 0, -50937, 1060, 0, 0, 39, '1059'),
	(243, 1, 0, -50937, 1061, 0, 0, 39, '1060'),
	(243, 1, 0, -50937, 1062, 0, 0, 39, '1061'),
	(243, 1, 0, -50937, 1063, 0, 0, 39, '1062'),
	(243, 1, 0, -50937, 1064, 0, 0, 39, '1063'),
	(243, 1, 0, -50937, 1065, 0, 0, 39, '1064'),
	(243, 1, 0, -50937, 1066, 0, 0, 39, '1065'),
	(243, 1, 0, -50937, 1067, 0, 0, 39, '1066'),
	(243, 1, 0, -50937, 1068, 0, 0, 39, '1067'),
	(243, 1, 0, -50937, 1069, 0, 0, 39, '1068'),
	(243, 1, 0, -50937, 1070, 0, 0, 39, '1069'),
	(243, 1, 0, -50937, 1071, 0, 0, 39, '1070'),
	(243, 1, 0, -50937, 1072, 0, 0, 39, '1071'),
	(243, 1, 0, -50937, 1073, 0, 0, 39, '1072'),
	(243, 1, 0, -50937, 1074, 0, 0, 39, '1073'),
	(243, 1, 0, -50937, 1075, 0, 0, 39, '1074'),
	(243, 1, 0, -50937, 1076, 0, 0, 39, '1075'),
	(243, 1, 0, -50937, 1077, 0, 0, 39, '1076'),
	(243, 1, 0, -50937, 1078, 0, 0, 39, '1077'),
	(243, 1, 0, -50937, 1079, 0, 0, 39, '1078'),
	(243, 1, 0, -50937, 1080, 0, 0, 39, '1079'),
	(243, 1, 0, -50937, 1081, 0, 0, 39, '1080'),
	(243, 1, 0, -50937, 1082, 0, 0, 39, '1081'),
	(243, 1, 0, -50937, 1083, 0, 0, 39, '1082'),
	(243, 1, 0, -50937, 1084, 0, 0, 39, '1083'),
	(243, 1, 0, -50937, 1085, 0, 0, 39, '1084'),
	(243, 1, 0, -50937, 1086, 0, 0, 39, '1085'),
	(243, 1, 0, -50937, 1087, 0, 0, 39, '1086'),
	(243, 1, 0, -50937, 1088, 0, 0, 39, '1087'),
	(243, 1, 0, -50937, 1089, 0, 0, 39, '1088'),
	(243, 1, 0, -50937, 1090, 0, 0, 39, '1089'),
	(243, 1, 0, -50937, 1091, 0, 0, 39, '1090'),
	(243, 1, 0, -50937, 1092, 0, 0, 39, '1091'),
	(243, 1, 0, -50937, 1093, 0, 0, 39, '1092'),
	(243, 1, 0, -50937, 1094, 0, 0, 39, '1093'),
	(243, 1, 0, -50937, 1095, 0, 0, 39, '1094'),
	(243, 1, 0, -50937, 1096, 0, 0, 39, '1095'),
	(243, 1, 0, -50937, 1097, 0, 0, 39, '1096'),
	(243, 1, 0, -50937, 1098, 0, 0, 39, '1097'),
	(243, 1, 0, -50937, 1099, 0, 0, 39, '1098'),
	(243, 1, 0, -50937, 1100, 0, 0, 39, '1099'),
	(243, 1, 0, -50937, 1101, 0, 0, 39, '1100'),
	(243, 1, 0, -50937, 1102, 0, 0, 39, '1101'),
	(243, 1, 0, -50937, 1103, 0, 0, 39, '1102'),
	(243, 1, 0, -50937, 1104, 0, 0, 39, '1103'),
	(243, 1, 0, -50937, 1105, 0, 0, 39, '1104'),
	(243, 1, 0, -50937, 1106, 0, 0, 39, '1105'),
	(243, 1, 0, -50937, 1107, 0, 0, 39, '1106'),
	(243, 1, 0, -50937, 1108, 0, 0, 39, '1107'),
	(243, 1, 0, -50937, 1109, 0, 0, 39, '1108'),
	(243, 1, 0, -50937, 1110, 0, 0, 39, '1109'),
	(243, 1, 0, -50937, 1111, 0, 0, 39, '1110'),
	(243, 1, 0, -50937, 1112, 0, 0, 39, '1111'),
	(243, 1, 0, -50937, 1113, 0, 0, 39, '1112'),
	(243, 1, 0, -50937, 1114, 0, 0, 39, '1113'),
	(243, 1, 0, -50937, 1115, 0, 0, 39, '1114'),
	(243, 1, 0, -50937, 1116, 0, 0, 39, '1115'),
	(243, 1, 0, -50937, 1117, 0, 0, 39, '1116'),
	(243, 1, 0, -50937, 1118, 0, 0, 39, '1117'),
	(243, 1, 0, -50937, 1119, 0, 0, 39, '1118'),
	(243, 1, 0, -50937, 1120, 0, 0, 39, '1119'),
	(243, 1, 0, -50937, 1121, 0, 0, 39, '1120'),
	(243, 1, 0, -50937, 1122, 0, 0, 39, '1121'),
	(243, 1, 0, -50937, 1123, 0, 0, 39, '1122'),
	(243, 1, 0, -50937, 1124, 0, 0, 39, '1123'),
	(243, 1, 0, -50937, 1125, 0, 0, 39, '1124'),
	(243, 1, 0, -50937, 1126, 0, 0, 39, '1125'),
	(243, 1, 0, -50937, 1127, 0, 0, 39, '1126'),
	(243, 1, 0, -50937, 1128, 0, 0, 39, '1127'),
	(243, 1, 0, -50937, 1129, 0, 0, 39, '1128'),
	(243, 1, 0, -50937, 1130, 0, 0, 39, '1129'),
	(243, 1, 0, -50937, 1131, 0, 0, 39, '1130'),
	(243, 1, 0, -50937, 1132, 0, 0, 39, '1131'),
	(243, 1, 0, -50937, 1133, 0, 0, 39, '1132'),
	(243, 1, 0, -50937, 1134, 0, 0, 39, '1133'),
	(243, 1, 0, -50937, 1135, 0, 0, 39, '1134'),
	(243, 1, 0, -50937, 1136, 0, 0, 39, '1135'),
	(243, 1, 0, -50937, 1137, 0, 0, 39, '1136'),
	(243, 1, 0, -50937, 1138, 0, 0, 39, '1137'),
	(243, 1, 0, -50937, 1139, 0, 0, 39, '1138'),
	(243, 1, 0, -50937, 1140, 0, 0, 39, '1139'),
	(243, 1, 0, -50937, 1141, 0, 0, 39, '1140'),
	(243, 1, 0, -50937, 1142, 0, 0, 39, '1141'),
	(243, 1, 0, -50937, 1143, 0, 0, 39, '1142'),
	(243, 1, 0, -50937, 1144, 0, 0, 39, '1143'),
	(243, 1, 0, -50937, 1145, 0, 0, 39, '1144'),
	(243, 1, 0, -50937, 1146, 0, 0, 39, '1145'),
	(243, 1, 0, -50937, 1147, 0, 0, 39, '1146'),
	(243, 1, 0, -50937, 1148, 0, 0, 39, '1147'),
	(243, 1, 0, -50937, 1149, 0, 0, 39, '1148'),
	(243, 1, 0, -50937, 1150, 0, 0, 39, '1149'),
	(243, 1, 0, -50937, 1151, 0, 0, 39, '1150'),
	(243, 1, 0, -50937, 1152, 0, 0, 39, '1151'),
	(243, 1, 0, -50937, 1153, 0, 0, 39, '1152'),
	(243, 1, 0, -50937, 1154, 0, 0, 39, '1153'),
	(243, 1, 0, -50937, 1155, 0, 0, 39, '1154'),
	(243, 1, 0, -50937, 1156, 0, 0, 39, '1155'),
	(243, 1, 0, -50937, 1157, 0, 0, 39, '1156'),
	(243, 1, 0, -50937, 1158, 0, 0, 39, '1157'),
	(243, 1, 0, -50937, 1159, 0, 0, 39, '1158'),
	(243, 1, 0, -50937, 1160, 0, 0, 39, '1159'),
	(243, 1, 0, -50937, 1161, 0, 0, 39, '1160'),
	(243, 1, 0, -50937, 1162, 0, 0, 39, '1161'),
	(243, 1, 0, -50937, 1163, 0, 0, 39, '1162'),
	(243, 1, 0, -50937, 1164, 0, 0, 39, '1163'),
	(243, 1, 0, -50937, 1165, 0, 0, 39, '1164'),
	(243, 1, 0, -50937, 1166, 0, 0, 39, '1165'),
	(243, 1, 0, -50937, 1167, 0, 0, 39, '1166'),
	(243, 1, 0, -50937, 1168, 0, 0, 39, '1167'),
	(243, 1, 0, -50937, 1169, 0, 0, 39, '1168'),
	(243, 1, 0, -50937, 1170, 0, 0, 39, '1169'),
	(243, 1, 0, -50937, 1171, 0, 0, 39, '1170'),
	(243, 1, 0, -50937, 1172, 0, 0, 39, '1171'),
	(243, 1, 0, -50937, 1173, 0, 0, 39, '1172'),
	(243, 1, 0, -50937, 1174, 0, 0, 39, '1173'),
	(243, 1, 0, -50937, 1175, 0, 0, 39, '1174'),
	(243, 1, 0, -50937, 1176, 0, 0, 39, '1175'),
	(243, 1, 0, -50937, 1177, 0, 0, 39, '1176'),
	(243, 1, 0, -50937, 1178, 0, 0, 39, '1177'),
	(243, 1, 0, -50937, 1179, 0, 0, 39, '1178'),
	(243, 1, 0, -50937, 1180, 0, 0, 39, '1179'),
	(243, 1, 0, -50937, 1181, 0, 0, 39, '1180'),
	(243, 1, 0, -50937, 1182, 0, 0, 39, '1181'),
	(243, 1, 0, -50937, 1183, 0, 0, 39, '1182'),
	(243, 1, 0, -50937, 1184, 0, 0, 39, '1183'),
	(243, 1, 0, -50937, 1185, 0, 0, 39, '1184'),
	(243, 1, 0, -50937, 1186, 0, 0, 39, '1185'),
	(243, 1, 0, -50937, 1187, 0, 0, 39, '1186'),
	(243, 1, 0, -50937, 1188, 0, 0, 39, '1187'),
	(243, 1, 0, -50937, 1189, 0, 0, 39, '1188'),
	(243, 1, 0, -50937, 1190, 0, 0, 39, '1189'),
	(243, 1, 0, -50937, 1191, 0, 0, 39, '1190'),
	(243, 1, 0, -50937, 1192, 0, 0, 39, '1191'),
	(243, 1, 0, -50937, 1193, 0, 0, 39, '1192'),
	(243, 1, 0, -50937, 1194, 0, 0, 39, '1193'),
	(243, 1, 0, -50937, 1195, 0, 0, 39, '1194'),
	(243, 1, 0, -50937, 1196, 0, 0, 39, '1195'),
	(243, 1, 0, -50937, 1197, 0, 0, 39, '1196'),
	(243, 1, 0, -50937, 1198, 0, 0, 39, '1197'),
	(243, 1, 0, -50937, 1199, 0, 0, 39, '1198'),
	(243, 1, 0, -50937, 1200, 0, 0, 39, '1199'),
	(243, 1, 0, -50937, 1201, 0, 0, 39, '1200'),
	(243, 1, 0, -50937, 1202, 0, 0, 39, '1201'),
	(243, 1, 0, -50937, 1203, 0, 0, 39, '1202'),
	(243, 1, 0, -50937, 1204, 0, 0, 39, '1203'),
	(243, 1, 0, -50937, 1205, 0, 0, 39, '1204'),
	(243, 1, 0, -50937, 1206, 0, 0, 39, '1205'),
	(243, 1, 0, -50937, 1207, 0, 0, 39, '1206'),
	(243, 1, 0, -50937, 1208, 0, 0, 39, '1207'),
	(243, 1, 0, -50937, 1209, 0, 0, 39, '1208'),
	(243, 1, 0, -50937, 1210, 0, 0, 39, '1209'),
	(243, 1, 0, -50937, 1211, 0, 0, 39, '1210'),
	(243, 1, 0, -50937, 1212, 0, 0, 39, '1211'),
	(243, 1, 0, -50937, 1213, 0, 0, 39, '1212'),
	(243, 1, 0, -50937, 1214, 0, 0, 39, '1213'),
	(243, 1, 0, -50937, 1215, 0, 0, 39, '1214'),
	(243, 1, 0, -50937, 1216, 0, 0, 39, '1215'),
	(243, 1, 0, -50937, 1217, 0, 0, 39, '1216'),
	(243, 1, 0, -50937, 1218, 0, 0, 39, '1217'),
	(243, 1, 0, -50937, 1219, 0, 0, 39, '1218'),
	(243, 1, 0, -50937, 1220, 0, 0, 39, '1219'),
	(243, 1, 0, -50937, 1221, 0, 0, 39, '1220'),
	(243, 1, 0, -50937, 1222, 0, 0, 39, '1221'),
	(243, 1, 0, -50937, 1223, 0, 0, 39, '1222'),
	(243, 1, 0, -50937, 1224, 0, 0, 39, '1223'),
	(243, 1, 0, -50937, 1225, 0, 0, 39, '1224'),
	(243, 1, 0, -50937, 1226, 0, 0, 39, '1225'),
	(243, 1, 0, -50937, 1227, 0, 0, 39, '1226'),
	(243, 1, 0, -50937, 1228, 0, 0, 39, '1227'),
	(243, 1, 0, -50937, 1229, 0, 0, 39, '1228'),
	(243, 1, 0, -50937, 1230, 0, 0, 39, '1229'),
	(243, 1, 0, -50937, 1231, 0, 0, 39, '1230'),
	(243, 1, 0, -50937, 1232, 0, 0, 39, '1231'),
	(243, 1, 0, -50937, 1233, 0, 0, 39, '1232'),
	(243, 1, 0, -50937, 1234, 0, 0, 39, '1233'),
	(243, 1, 0, -50937, 1235, 0, 0, 39, '1234'),
	(243, 1, 0, -50937, 1236, 0, 0, 39, '1235'),
	(243, 1, 0, -50937, 1237, 0, 0, 39, '1236'),
	(243, 1, 0, -50937, 1238, 0, 0, 39, '1237'),
	(243, 1, 0, -50937, 1239, 0, 0, 39, '1238'),
	(243, 1, 0, -50937, 1240, 0, 0, 39, '1239'),
	(243, 1, 0, -50937, 1241, 0, 0, 39, '1240'),
	(243, 1, 0, -50937, 1242, 0, 0, 39, '1241'),
	(243, 1, 0, -50937, 1243, 0, 0, 39, '1242'),
	(243, 1, 0, -50937, 1244, 0, 0, 39, '1243'),
	(243, 1, 0, -50937, 1245, 0, 0, 39, '1244'),
	(243, 1, 0, -50937, 1246, 0, 0, 39, '1245'),
	(243, 1, 0, -50937, 1247, 0, 0, 39, '1246'),
	(243, 1, 0, -50937, 1248, 0, 0, 39, '1247'),
	(243, 1, 0, -50937, 1249, 0, 0, 39, '1248'),
	(243, 1, 0, -50937, 1250, 0, 0, 39, '1249'),
	(243, 1, 0, -50937, 1251, 0, 0, 39, '1250'),
	(243, 1, 0, -50937, 1252, 0, 0, 39, '1251'),
	(243, 1, 0, -50937, 1253, 0, 0, 39, '1252'),
	(243, 1, 0, -50937, 1254, 0, 0, 39, '1253'),
	(243, 1, 0, -50937, 1255, 0, 0, 39, '1254'),
	(243, 1, 0, -50937, 1256, 0, 0, 39, '1255'),
	(243, 1, 0, -50937, 1257, 0, 0, 39, '1256'),
	(243, 1, 0, -50937, 1258, 0, 0, 39, '1257'),
	(243, 1, 0, -50937, 1259, 0, 0, 39, '1258'),
	(243, 1, 0, -50937, 1260, 0, 0, 39, '1259'),
	(243, 1, 0, -50937, 1261, 0, 0, 39, '1260'),
	(243, 1, 0, -50937, 1262, 0, 0, 39, '1261'),
	(243, 1, 0, -50937, 1263, 0, 0, 39, '1262'),
	(243, 1, 0, -50937, 1264, 0, 0, 39, '1263'),
	(243, 1, 0, -50937, 1265, 0, 0, 39, '1264'),
	(243, 1, 0, -50937, 1266, 0, 0, 39, '1265'),
	(243, 1, 0, -50937, 1267, 0, 0, 39, '1266'),
	(243, 1, 0, -50937, 1268, 0, 0, 39, '1267'),
	(243, 1, 0, -50937, 1269, 0, 0, 39, '1268'),
	(243, 1, 0, -50937, 1270, 0, 0, 39, '1269'),
	(243, 1, 0, -50937, 1271, 0, 0, 39, '1270'),
	(243, 1, 0, -50937, 1272, 0, 0, 39, '1271'),
	(243, 1, 0, -50937, 1273, 0, 0, 39, '1272'),
	(243, 1, 0, -50937, 1274, 0, 0, 39, '1273'),
	(243, 1, 0, -50937, 1275, 0, 0, 39, '1274'),
	(243, 1, 0, -50937, 1276, 0, 0, 39, '1275'),
	(243, 1, 0, -50937, 1277, 0, 0, 39, '1276'),
	(243, 1, 0, -50937, 1278, 0, 0, 39, '1277'),
	(243, 1, 0, -50937, 1279, 0, 0, 39, '1278'),
	(243, 1, 0, -50937, 1280, 0, 0, 39, '1279'),
	(243, 1, 0, -50937, 1281, 0, 0, 39, '1280'),
	(243, 1, 0, -50937, 1282, 0, 0, 39, '1281'),
	(243, 1, 0, -50937, 1283, 0, 0, 39, '1282'),
	(243, 1, 0, -50937, 1284, 0, 0, 39, '1283'),
	(243, 1, 0, -50937, 1285, 0, 0, 39, '1284'),
	(243, 1, 0, -50937, 1286, 0, 0, 39, '1285'),
	(243, 1, 0, -50937, 1287, 0, 0, 39, '1286'),
	(243, 1, 0, -50937, 1288, 0, 0, 39, '1287'),
	(243, 1, 0, -50937, 1289, 0, 0, 39, '1288'),
	(243, 1, 0, -50937, 1290, 0, 0, 39, '1289'),
	(243, 1, 0, -50937, 1291, 0, 0, 39, '1290'),
	(243, 1, 0, -50937, 1292, 0, 0, 39, '1291'),
	(243, 1, 0, -50937, 1293, 0, 0, 39, '1292'),
	(243, 1, 0, -50937, 1294, 0, 0, 39, '1293'),
	(243, 1, 0, -50937, 1295, 0, 0, 39, '1294'),
	(243, 1, 0, -50937, 1296, 0, 0, 39, '1295'),
	(243, 1, 0, -50937, 1297, 0, 0, 39, '1296'),
	(243, 1, 0, -50937, 1298, 0, 0, 39, '1297'),
	(243, 1, 0, -50937, 1299, 0, 0, 39, '1298'),
	(243, 1, 0, -50937, 1300, 0, 0, 39, '1299'),
	(243, 1, 0, -50937, 1301, 0, 0, 39, '1300'),
	(243, 1, 0, -50937, 1302, 0, 0, 39, '1301'),
	(243, 1, 0, -50937, 1303, 0, 0, 39, '1302'),
	(243, 1, 0, -50937, 1304, 0, 0, 39, '1303'),
	(243, 1, 0, -50937, 1305, 0, 0, 39, '1304'),
	(243, 1, 0, -50937, 1306, 0, 0, 39, '1305'),
	(243, 1, 0, -50937, 1307, 0, 0, 39, '1306'),
	(243, 1, 0, -50937, 1308, 0, 0, 39, '1307'),
	(243, 1, 0, -50937, 1309, 0, 0, 39, '1308'),
	(243, 1, 0, -50937, 1310, 0, 0, 39, '1309'),
	(243, 1, 0, -50937, 1311, 0, 0, 39, '1310'),
	(243, 1, 0, -50937, 1312, 0, 0, 39, '1311'),
	(243, 1, 0, -50937, 1313, 0, 0, 39, '1312'),
	(243, 1, 0, -50937, 1314, 0, 0, 39, '1313'),
	(243, 1, 0, -50937, 1315, 0, 0, 39, '1314'),
	(243, 1, 0, -50937, 1316, 0, 0, 39, '1315'),
	(243, 1, 0, -50937, 1317, 0, 0, 39, '1316'),
	(243, 1, 0, -50937, 1318, 0, 0, 39, '1317'),
	(243, 1, 0, -50937, 1319, 0, 0, 39, '1318'),
	(243, 1, 0, -50937, 1320, 0, 0, 39, '1319'),
	(243, 1, 0, -50937, 1321, 0, 0, 39, '1320'),
	(243, 1, 0, -50937, 1322, 0, 0, 39, '1321'),
	(243, 1, 0, -50937, 1323, 0, 0, 39, '1322'),
	(243, 1, 0, -50937, 1324, 0, 0, 39, '1323'),
	(243, 1, 0, -50937, 1325, 0, 0, 39, '1324'),
	(243, 1, 0, -50937, 1326, 0, 0, 39, '1325'),
	(243, 1, 0, -50937, 1327, 0, 0, 39, '1326'),
	(243, 1, 0, -50937, 1328, 0, 0, 39, '1327'),
	(243, 1, 0, -50937, 1329, 0, 0, 39, '1328'),
	(243, 1, 0, -50937, 1330, 0, 0, 39, '1329'),
	(243, 1, 0, -50937, 1331, 0, 0, 39, '1330'),
	(243, 1, 0, -50937, 1332, 0, 0, 39, '1331'),
	(243, 1, 0, -50937, 1333, 0, 0, 39, '1332'),
	(243, 1, 0, -50937, 1334, 0, 0, 39, '1333'),
	(243, 1, 0, -50937, 1335, 0, 0, 39, '1334'),
	(243, 1, 0, -50937, 1336, 0, 0, 39, '1335'),
	(243, 1, 0, -50937, 1337, 0, 0, 39, '1336'),
	(243, 1, 0, -50937, 1338, 0, 0, 39, '1337'),
	(243, 1, 0, -50937, 1339, 0, 0, 39, '1338'),
	(243, 1, 0, -50937, 1340, 0, 0, 39, '1339'),
	(243, 1, 0, -50937, 1341, 0, 0, 39, '1340'),
	(243, 1, 0, -50937, 1342, 0, 0, 39, '1341'),
	(243, 1, 0, -50937, 1343, 0, 0, 39, '1342'),
	(243, 1, 0, -50937, 1344, 0, 0, 39, '1343'),
	(243, 1, 0, -50937, 1345, 0, 0, 39, '1344'),
	(243, 1, 0, -50937, 1346, 0, 0, 39, '1345'),
	(243, 1, 0, -50937, 1347, 0, 0, 39, '1346'),
	(243, 1, 0, -50937, 1348, 0, 0, 39, '1347'),
	(243, 1, 0, -50937, 1349, 0, 0, 39, '1348'),
	(243, 1, 0, -50937, 1350, 0, 0, 39, '1349'),
	(243, 1, 0, -50937, 1351, 0, 0, 39, '1350'),
	(243, 1, 0, -50937, 1352, 0, 0, 39, '1351'),
	(243, 1, 0, -50937, 1353, 0, 0, 39, '1352'),
	(243, 1, 0, -50937, 1354, 0, 0, 39, '1353'),
	(243, 1, 0, -50937, 1355, 0, 0, 39, '1354'),
	(243, 1, 0, -50937, 1356, 0, 0, 39, '1355'),
	(243, 1, 0, -50937, 1357, 0, 0, 39, '1356'),
	(243, 1, 0, -50937, 1358, 0, 0, 39, '1357'),
	(243, 1, 0, -50937, 1359, 0, 0, 39, '1358'),
	(243, 1, 0, -50937, 1360, 0, 0, 39, '1359'),
	(243, 1, 0, -50937, 1361, 0, 0, 39, '1360'),
	(243, 1, 0, -50937, 1362, 0, 0, 39, '1361'),
	(243, 1, 0, -50937, 1363, 0, 0, 39, '1362'),
	(243, 1, 0, -50937, 1364, 0, 0, 39, '1363'),
	(243, 1, 0, -50937, 1365, 0, 0, 39, '1364'),
	(243, 1, 0, -50937, 1366, 0, 0, 39, '1365'),
	(243, 1, 0, -50937, 1367, 0, 0, 39, '1366'),
	(243, 1, 0, -50937, 1368, 0, 0, 39, '1367'),
	(243, 1, 0, -50937, 1369, 0, 0, 39, '1368'),
	(243, 1, 0, -50937, 1370, 0, 0, 39, '1369'),
	(243, 1, 0, -50937, 1371, 0, 0, 39, '1370'),
	(243, 1, 0, -50937, 1372, 0, 0, 39, '1371'),
	(243, 1, 0, -50937, 1373, 0, 0, 39, '1372'),
	(243, 1, 0, -50937, 1374, 0, 0, 39, '1373'),
	(243, 1, 0, -50937, 1375, 0, 0, 39, '1374'),
	(243, 1, 0, -50937, 1376, 0, 0, 39, '1375'),
	(243, 1, 0, -50937, 1377, 0, 0, 39, '1376'),
	(243, 1, 0, -50937, 1378, 0, 0, 39, '1377'),
	(243, 1, 0, -50937, 1379, 0, 0, 39, '1378'),
	(243, 1, 0, -50937, 1380, 0, 0, 39, '1379'),
	(243, 1, 0, -50937, 1381, 0, 0, 39, '1380'),
	(243, 1, 0, -50937, 1382, 0, 0, 39, '1381'),
	(243, 1, 0, -50937, 1383, 0, 0, 39, '1382'),
	(243, 1, 0, -50937, 1384, 0, 0, 39, '1383'),
	(243, 1, 0, -50937, 1385, 0, 0, 39, '1384'),
	(243, 1, 0, -50937, 1386, 0, 0, 39, '1385'),
	(243, 1, 0, -50937, 1387, 0, 0, 39, '1386'),
	(243, 1, 0, -50937, 1388, 0, 0, 39, '1387'),
	(243, 1, 0, -50937, 1389, 0, 0, 39, '1388'),
	(243, 1, 0, -50937, 1390, 0, 0, 39, '1389'),
	(243, 1, 0, -50937, 1391, 0, 0, 39, '1390'),
	(243, 1, 0, -50937, 1392, 0, 0, 39, '1391'),
	(243, 1, 0, -50937, 1393, 0, 0, 39, '1392'),
	(243, 1, 0, -50937, 1394, 0, 0, 39, '1393'),
	(243, 1, 0, -50937, 1395, 0, 0, 39, '1394'),
	(243, 1, 0, -50937, 1396, 0, 0, 39, '1395'),
	(243, 1, 0, -50937, 1397, 0, 0, 39, '1396'),
	(243, 1, 0, -50937, 1398, 0, 0, 39, '1397'),
	(243, 1, 0, -50937, 1399, 0, 0, 39, '1398'),
	(243, 1, 0, -50937, 1400, 0, 0, 39, '1399'),
	(243, 1, 0, -50937, 1401, 0, 0, 39, '1400'),
	(243, 1, 0, -50937, 1402, 0, 0, 39, '1401'),
	(243, 1, 0, -50937, 1403, 0, 0, 39, '1402'),
	(243, 1, 0, -50937, 1404, 0, 0, 39, '1403'),
	(243, 1, 0, -50937, 1405, 0, 0, 39, '1404'),
	(243, 1, 0, -50937, 1406, 0, 0, 39, '1405'),
	(243, 1, 0, -50937, 1407, 0, 0, 39, '1406'),
	(243, 1, 0, -50937, 1408, 0, 0, 39, '1407'),
	(243, 1, 0, -50937, 1409, 0, 0, 39, '1408'),
	(243, 1, 0, -50937, 1410, 0, 0, 39, '1409'),
	(243, 1, 0, -50937, 1411, 0, 0, 39, '1410'),
	(243, 1, 0, -50937, 1412, 0, 0, 39, '1411'),
	(243, 1, 0, -50937, 1413, 0, 0, 39, '1412'),
	(243, 1, 0, -50937, 1414, 0, 0, 39, '1413'),
	(243, 1, 0, -50937, 1415, 0, 0, 39, '1414'),
	(243, 1, 0, -50937, 1416, 0, 0, 39, '1415'),
	(243, 1, 0, -50937, 1417, 0, 0, 39, '1416'),
	(243, 1, 0, -50937, 1418, 0, 0, 39, '1417'),
	(243, 1, 0, -50937, 1419, 0, 0, 39, '1418'),
	(243, 1, 0, -50937, 1420, 0, 0, 39, '1419'),
	(243, 1, 0, -50937, 1421, 0, 0, 39, '1420'),
	(243, 1, 0, -50937, 1422, 0, 0, 39, '1421'),
	(243, 1, 0, -50937, 1423, 0, 0, 39, '1422'),
	(243, 1, 0, -50937, 1424, 0, 0, 39, '1423'),
	(243, 1, 0, -50937, 1425, 0, 0, 39, '1424'),
	(243, 1, 0, -50937, 1426, 0, 0, 39, '1425'),
	(243, 1, 0, -50937, 1427, 0, 0, 39, '1426'),
	(243, 1, 0, -50937, 1428, 0, 0, 39, '1427'),
	(243, 1, 0, -50937, 1429, 0, 0, 39, '1428'),
	(243, 1, 0, -50937, 1430, 0, 0, 39, '1429'),
	(243, 1, 0, -50937, 1431, 0, 0, 39, '1430'),
	(243, 1, 0, -50937, 1432, 0, 0, 39, '1431'),
	(243, 1, 0, -50937, 1433, 0, 0, 39, '1432'),
	(243, 1, 0, -50937, 1434, 0, 0, 39, '1433'),
	(243, 1, 0, -50937, 1435, 0, 0, 39, '1434'),
	(243, 1, 0, -50937, 1436, 0, 0, 39, '1435'),
	(243, 1, 0, -50937, 1437, 0, 0, 39, '1436'),
	(243, 1, 0, -50937, 1438, 0, 0, 39, '1437'),
	(243, 1, 0, -50937, 1439, 0, 0, 39, '1438'),
	(243, 1, 0, -50937, 1440, 0, 0, 39, '1439'),
	(243, 1, 0, -50937, 1441, 0, 0, 39, '1440'),
	(243, 1, 0, -50937, 1442, 0, 0, 39, '1441'),
	(243, 1, 0, -50937, 1443, 0, 0, 39, '1442'),
	(243, 1, 0, -50937, 1444, 0, 0, 39, '1443'),
	(243, 1, 0, -50937, 1445, 0, 0, 39, '1444'),
	(243, 1, 0, -50937, 1446, 0, 0, 39, '1445'),
	(243, 1, 0, -50937, 1447, 0, 0, 39, '1446'),
	(243, 1, 0, -50937, 1448, 0, 0, 39, '1447'),
	(243, 1, 0, -50937, 1449, 0, 0, 39, '1448'),
	(243, 1, 0, -50937, 1450, 0, 0, 39, '1449'),
	(243, 1, 0, -50937, 1451, 0, 0, 39, '1450'),
	(243, 1, 0, -50937, 1452, 0, 0, 39, '1451'),
	(243, 1, 0, -50937, 1453, 0, 0, 39, '1452'),
	(243, 1, 0, -50937, 1454, 0, 0, 39, '1453'),
	(243, 1, 0, -50937, 1455, 0, 0, 39, '1454'),
	(243, 1, 0, -50937, 1456, 0, 0, 39, '1455'),
	(243, 1, 0, -50937, 1457, 0, 0, 39, '1456'),
	(243, 1, 0, -50937, 1458, 0, 0, 39, '1457'),
	(243, 1, 0, -50937, 1459, 0, 0, 39, '1458'),
	(243, 1, 0, -50937, 1460, 0, 0, 39, '1459'),
	(243, 1, 0, -50937, 1461, 0, 0, 39, '1460'),
	(243, 1, 0, -50937, 1462, 0, 0, 39, '1461'),
	(243, 1, 0, -50937, 1463, 0, 0, 39, '1462'),
	(243, 1, 0, -50937, 1464, 0, 0, 39, '1463'),
	(243, 1, 0, -50937, 1465, 0, 0, 39, '1464'),
	(243, 1, 0, -50937, 1466, 0, 0, 39, '1465'),
	(243, 1, 0, -50937, 1467, 0, 0, 39, '1466'),
	(243, 1, 0, -50937, 1468, 0, 0, 39, '1467'),
	(243, 1, 0, -50937, 1469, 0, 0, 39, '1468'),
	(243, 1, 0, -50937, 1470, 0, 0, 39, '1469'),
	(243, 1, 0, -50937, 1471, 0, 0, 39, '1470'),
	(243, 1, 0, -50937, 1472, 0, 0, 39, '1471'),
	(243, 1, 0, -50937, 1473, 0, 0, 39, '1472'),
	(243, 1, 0, -50937, 1474, 0, 0, 39, '1473'),
	(243, 1, 0, -50937, 1475, 0, 0, 39, '1474'),
	(243, 1, 0, -50937, 1476, 0, 0, 39, '1475'),
	(243, 1, 0, -50937, 1477, 0, 0, 39, '1476'),
	(243, 1, 0, -50937, 1478, 0, 0, 39, '1477'),
	(243, 1, 0, -50937, 1479, 0, 0, 39, '1478'),
	(243, 1, 0, -50937, 1480, 0, 0, 39, '1479'),
	(243, 1, 0, -50937, 1481, 0, 0, 39, '1480'),
	(243, 1, 0, -50937, 1482, 0, 0, 39, '1481'),
	(243, 1, 0, -50937, 1483, 0, 0, 39, '1482'),
	(243, 1, 0, -50937, 1484, 0, 0, 39, '1483'),
	(243, 1, 0, -50937, 1485, 0, 0, 39, '1484'),
	(243, 1, 0, -50937, 1486, 0, 0, 39, '1485'),
	(243, 1, 0, -50937, 1487, 0, 0, 39, '1486'),
	(243, 1, 0, -50937, 1488, 0, 0, 39, '1487'),
	(243, 1, 0, -50937, 1489, 0, 0, 39, '1488'),
	(243, 1, 0, -50937, 1490, 0, 0, 39, '1489'),
	(243, 1, 0, -50937, 1491, 0, 0, 39, '1490'),
	(243, 1, 0, -50937, 1492, 0, 0, 39, '1491'),
	(243, 1, 0, -50937, 1493, 0, 0, 39, '1492'),
	(243, 1, 0, -50937, 1494, 0, 0, 39, '1493'),
	(243, 1, 0, -50937, 1495, 0, 0, 39, '1494'),
	(243, 1, 0, -50937, 1496, 0, 0, 39, '1495'),
	(243, 1, 0, -50937, 1497, 0, 0, 39, '1496'),
	(243, 1, 0, -50937, 1498, 0, 0, 39, '1497'),
	(243, 1, 0, -50937, 1499, 0, 0, 39, '1498'),
	(243, 1, 0, -50937, 1500, 0, 0, 39, '1499'),
	(243, 1, 0, -50937, 1501, 0, 0, 39, '1500'),
	(243, 1, 0, -50937, 1502, 0, 0, 39, '1501'),
	(243, 1, 0, -50937, 1503, 0, 0, 39, '1502'),
	(243, 1, 0, -50937, 1504, 0, 0, 39, '1503'),
	(243, 1, 0, -50937, 1505, 0, 0, 39, '1504'),
	(243, 1, 0, -50937, 1506, 0, 0, 39, '1505'),
	(243, 1, 0, -50937, 1507, 0, 0, 39, '1506'),
	(243, 1, 0, -50937, 1508, 0, 0, 39, '1507'),
	(243, 1, 0, -50937, 1509, 0, 0, 39, '1508'),
	(243, 1, 0, -50937, 1510, 0, 0, 39, '1509'),
	(243, 1, 0, -50937, 1511, 0, 0, 39, '1510'),
	(243, 1, 0, -50937, 1512, 0, 0, 39, '1511'),
	(243, 1, 0, -50937, 1513, 0, 0, 39, '1512'),
	(243, 1, 0, -50937, 1514, 0, 0, 39, '1513'),
	(243, 1, 0, -50937, 1515, 0, 0, 39, '1514'),
	(243, 1, 0, -50937, 1516, 0, 0, 39, '1515'),
	(243, 1, 0, -50937, 1517, 0, 0, 39, '1516'),
	(243, 1, 0, -50937, 1518, 0, 0, 39, '1517'),
	(243, 1, 0, -50937, 1519, 0, 0, 39, '1518'),
	(243, 1, 0, -50937, 1520, 0, 0, 39, '1519'),
	(243, 1, 0, -50937, 1521, 0, 0, 39, '1520'),
	(243, 1, 0, -50937, 1522, 0, 0, 39, '1521'),
	(243, 1, 0, -50937, 1523, 0, 0, 39, '1522'),
	(243, 1, 0, -50937, 1524, 0, 0, 39, '1523'),
	(243, 1, 0, -50937, 1525, 0, 0, 39, '1524'),
	(243, 1, 0, -50937, 1526, 0, 0, 39, '1525'),
	(243, 1, 0, -50937, 1527, 0, 0, 39, '1526'),
	(243, 1, 0, -50937, 1528, 0, 0, 39, '1527'),
	(243, 1, 0, -50937, 1529, 0, 0, 39, '1528'),
	(243, 1, 0, -50937, 1530, 0, 0, 39, '1529'),
	(243, 1, 0, -50937, 1531, 0, 0, 39, '1530'),
	(243, 1, 0, -50937, 1532, 0, 0, 39, '1531'),
	(243, 1, 0, -50937, 1533, 0, 0, 39, '1532'),
	(243, 1, 0, -50937, 1534, 0, 0, 39, '1533'),
	(243, 1, 0, -50937, 1535, 0, 0, 39, '1534'),
	(243, 1, 0, -50937, 1536, 0, 0, 39, '1535'),
	(243, 1, 0, -50937, 1537, 0, 0, 39, '1536'),
	(243, 1, 0, -50937, 1538, 0, 0, 39, '1537'),
	(243, 1, 0, -50937, 1539, 0, 0, 39, '1538'),
	(243, 1, 0, -50937, 1540, 0, 0, 39, '1539'),
	(243, 1, 0, -50937, 1541, 0, 0, 39, '1540'),
	(243, 1, 0, -50937, 1542, 0, 0, 39, '1541'),
	(243, 1, 0, -50937, 1543, 0, 0, 39, '1542'),
	(243, 1, 0, -50937, 1544, 0, 0, 39, '1543'),
	(243, 1, 0, -50937, 1545, 0, 0, 39, '1544'),
	(243, 1, 0, -50937, 1546, 0, 0, 39, '1545'),
	(243, 1, 0, -50937, 1547, 0, 0, 39, '1546'),
	(243, 1, 0, -50937, 1548, 0, 0, 39, '1547'),
	(243, 1, 0, -50937, 1549, 0, 0, 39, '1548'),
	(243, 1, 0, -50937, 1550, 0, 0, 39, '1549'),
	(243, 1, 0, -50937, 1551, 0, 0, 39, '1550'),
	(243, 1, 0, -50937, 1552, 0, 0, 39, '1551'),
	(243, 1, 0, -50937, 1553, 0, 0, 39, '1552'),
	(243, 1, 0, -50937, 1554, 0, 0, 39, '1553'),
	(243, 1, 0, -50937, 1555, 0, 0, 39, '1554'),
	(243, 1, 0, -50937, 1556, 0, 0, 39, '1555'),
	(243, 1, 0, -50937, 1557, 0, 0, 39, '1556'),
	(243, 1, 0, -50937, 1558, 0, 0, 39, '1557'),
	(243, 1, 0, -50937, 1559, 0, 0, 39, '1558'),
	(243, 1, 0, -50937, 1560, 0, 0, 39, '1559'),
	(243, 1, 0, -50937, 1561, 0, 0, 39, '1560'),
	(243, 1, 0, -50937, 1562, 0, 0, 39, '1561'),
	(243, 1, 0, -50937, 1563, 0, 0, 39, '1562'),
	(243, 1, 0, -50937, 1564, 0, 0, 39, '1563'),
	(243, 1, 0, -50937, 1565, 0, 0, 39, '1564'),
	(243, 1, 0, -50937, 1566, 0, 0, 39, '1565'),
	(243, 1, 0, -50937, 1567, 0, 0, 39, '1566'),
	(243, 1, 0, -50937, 1568, 0, 0, 39, '1567'),
	(243, 1, 0, -50937, 1569, 0, 0, 39, '1568'),
	(243, 1, 0, -50937, 1570, 0, 0, 39, '1569'),
	(243, 1, 0, -50937, 1571, 0, 0, 39, '1570'),
	(243, 1, 0, -50937, 1572, 0, 0, 39, '1571'),
	(243, 1, 0, -50937, 1573, 0, 0, 39, '1572'),
	(243, 1, 0, -50937, 1574, 0, 0, 39, '1573'),
	(243, 1, 0, -50937, 1575, 0, 0, 39, '1574'),
	(243, 1, 0, -50937, 1576, 0, 0, 39, '1575'),
	(243, 1, 0, -50937, 1577, 0, 0, 39, '1576'),
	(243, 1, 0, -50937, 1578, 0, 0, 39, '1577'),
	(243, 1, 0, -50937, 1579, 0, 0, 39, '1578'),
	(243, 1, 0, -50937, 1580, 0, 0, 39, '1579'),
	(243, 1, 0, -50937, 1581, 0, 0, 39, '1580'),
	(243, 1, 0, -50937, 1582, 0, 0, 39, '1581'),
	(243, 1, 0, -50937, 1583, 0, 0, 39, '1582'),
	(243, 1, 0, -50937, 1584, 0, 0, 39, '1583'),
	(243, 1, 0, -50937, 1585, 0, 0, 39, '1584'),
	(243, 1, 0, -50937, 1586, 0, 0, 39, '1585'),
	(243, 1, 0, -50937, 1587, 0, 0, 39, '1586'),
	(243, 1, 0, -50937, 1588, 0, 0, 39, '1587'),
	(243, 1, 0, -50937, 1589, 0, 0, 39, '1588'),
	(243, 1, 0, -50937, 1590, 0, 0, 39, '1589'),
	(243, 1, 0, -50937, 1591, 0, 0, 39, '1590'),
	(243, 1, 0, -50937, 1592, 0, 0, 39, '1591'),
	(243, 1, 0, -50937, 1593, 0, 0, 39, '1592'),
	(243, 1, 0, -50937, 1594, 0, 0, 39, '1593'),
	(243, 1, 0, -50937, 1595, 0, 0, 39, '1594'),
	(243, 1, 0, -50937, 1596, 0, 0, 39, '1595'),
	(243, 1, 0, -50937, 1597, 0, 0, 39, '1596'),
	(243, 1, 0, -50937, 1598, 0, 0, 39, '1597'),
	(243, 1, 0, -50937, 1599, 0, 0, 39, '1598'),
	(243, 1, 0, -50937, 1600, 0, 0, 39, '1599'),
	(243, 1, 0, -50937, 1601, 0, 0, 39, '1600'),
	(243, 1, 0, -50937, 1602, 0, 0, 39, '1601'),
	(243, 1, 0, -50937, 1603, 0, 0, 39, '1602'),
	(243, 1, 0, -50937, 1604, 0, 0, 39, '1603'),
	(243, 1, 0, -50937, 1605, 0, 0, 39, '1604'),
	(243, 1, 0, -50937, 1606, 0, 0, 39, '1605'),
	(243, 1, 0, -50937, 1607, 0, 0, 39, '1606'),
	(243, 1, 0, -50937, 1608, 0, 0, 39, '1607'),
	(243, 1, 0, -50937, 1609, 0, 0, 39, '1608'),
	(243, 1, 0, -50937, 1610, 0, 0, 39, '1609'),
	(243, 1, 0, -50937, 1611, 0, 0, 39, '1610'),
	(243, 1, 0, -50937, 1612, 0, 0, 39, '1611'),
	(243, 1, 0, -50937, 1613, 0, 0, 39, '1612'),
	(243, 1, 0, -50937, 1614, 0, 0, 39, '1613'),
	(243, 1, 0, -50937, 1615, 0, 0, 39, '1614'),
	(243, 1, 0, -50937, 1616, 0, 0, 39, '1615'),
	(243, 1, 0, -50937, 1617, 0, 0, 39, '1616'),
	(243, 1, 0, -50937, 1618, 0, 0, 39, '1617'),
	(243, 1, 0, -50937, 1619, 0, 0, 39, '1618'),
	(243, 1, 0, -50937, 1620, 0, 0, 39, '1619'),
	(243, 1, 0, -50937, 1621, 0, 0, 39, '1620'),
	(243, 1, 0, -50937, 1622, 0, 0, 39, '1621'),
	(243, 1, 0, -50937, 1623, 0, 0, 39, '1622'),
	(243, 1, 0, -50937, 1624, 0, 0, 39, '1623'),
	(243, 1, 0, -50937, 1625, 0, 0, 39, '1624'),
	(243, 1, 0, -50937, 1626, 0, 0, 39, '1625'),
	(243, 1, 0, -50937, 1627, 0, 0, 39, '1626'),
	(243, 1, 0, -50937, 1628, 0, 0, 39, '1627'),
	(243, 1, 0, -50937, 1629, 0, 0, 39, '1628'),
	(243, 1, 0, -50937, 1630, 0, 0, 39, '1629'),
	(243, 1, 0, -50937, 1631, 0, 0, 39, '1630'),
	(243, 1, 0, -50937, 1632, 0, 0, 39, '1631'),
	(243, 1, 0, -50937, 1633, 0, 0, 39, '1632'),
	(243, 1, 0, -50937, 1634, 0, 0, 39, '1633'),
	(243, 1, 0, -50937, 1635, 0, 0, 39, '1634'),
	(243, 1, 0, -50937, 1636, 0, 0, 39, '1635'),
	(243, 1, 0, -50937, 1637, 0, 0, 39, '1636'),
	(243, 1, 0, -50937, 1638, 0, 0, 39, '1637'),
	(243, 1, 0, -50937, 1639, 0, 0, 39, '1638'),
	(243, 1, 0, -50937, 1640, 0, 0, 39, '1639'),
	(243, 1, 0, -50937, 1641, 0, 0, 39, '1640'),
	(243, 1, 0, -50937, 1642, 0, 0, 39, '1641'),
	(243, 1, 0, -50937, 1643, 0, 0, 39, '1642'),
	(243, 1, 0, -50937, 1644, 0, 0, 39, '1643'),
	(243, 1, 0, -50937, 1645, 0, 0, 39, '1644'),
	(243, 1, 0, -50937, 1646, 0, 0, 39, '1645'),
	(243, 1, 0, -50937, 1647, 0, 0, 39, '1646'),
	(243, 1, 0, -50937, 1648, 0, 0, 39, '1647'),
	(243, 1, 0, -50937, 1649, 0, 0, 39, '1648'),
	(243, 1, 0, -50937, 1650, 0, 0, 39, '1649'),
	(243, 1, 0, -50937, 1651, 0, 0, 39, '1650'),
	(243, 1, 0, -50937, 1652, 0, 0, 39, '1651'),
	(243, 1, 0, -50937, 1653, 0, 0, 39, '1652'),
	(243, 1, 0, -50937, 1654, 0, 0, 39, '1653'),
	(243, 1, 0, -50937, 1655, 0, 0, 39, '1654'),
	(243, 1, 0, -50937, 1656, 0, 0, 39, '1655'),
	(243, 1, 0, -50937, 1657, 0, 0, 39, '1656'),
	(243, 1, 0, -50937, 1658, 0, 0, 39, '1657'),
	(243, 1, 0, -50937, 1659, 0, 0, 39, '1658'),
	(243, 1, 0, -50937, 1660, 0, 0, 39, '1659'),
	(243, 1, 0, -50937, 1661, 0, 0, 39, '1660'),
	(243, 1, 0, -50937, 1662, 0, 0, 39, '1661'),
	(243, 1, 0, -50937, 1663, 0, 0, 39, '1662'),
	(243, 1, 0, -50937, 1664, 0, 0, 39, '1663'),
	(243, 1, 0, -50937, 1665, 0, 0, 39, '1664'),
	(243, 1, 0, -50937, 1666, 0, 0, 39, '1665'),
	(243, 1, 0, -50937, 1667, 0, 0, 39, '1666'),
	(243, 1, 0, -50937, 1668, 0, 0, 39, '1667'),
	(243, 1, 0, -50937, 1669, 0, 0, 39, '1668'),
	(243, 1, 0, -50937, 1670, 0, 0, 39, '1669'),
	(243, 1, 0, -50937, 1671, 0, 0, 39, '1670'),
	(243, 1, 0, -50937, 1672, 0, 0, 39, '1671'),
	(243, 1, 0, -50937, 1673, 0, 0, 39, '1672'),
	(243, 1, 0, -50937, 1674, 0, 0, 39, '1673'),
	(243, 1, 0, -50937, 1675, 0, 0, 39, '1674'),
	(243, 1, 0, -50937, 1676, 0, 0, 39, '1675'),
	(243, 1, 0, -50937, 1677, 0, 0, 39, '1676'),
	(243, 1, 0, -50937, 1678, 0, 0, 39, '1677'),
	(243, 1, 0, -50937, 1679, 0, 0, 39, '1678'),
	(243, 1, 0, -50937, 1680, 0, 0, 39, '1679'),
	(243, 1, 0, -50937, 1681, 0, 0, 39, '1680'),
	(243, 1, 0, -50937, 1682, 0, 0, 39, '1681'),
	(243, 1, 0, -50937, 1683, 0, 0, 39, '1682'),
	(243, 1, 0, -50937, 1684, 0, 0, 39, '1683'),
	(243, 1, 0, -50937, 1685, 0, 0, 39, '1684'),
	(243, 1, 0, -50937, 1686, 0, 0, 39, '1685'),
	(243, 1, 0, -50937, 1687, 0, 0, 39, '1686'),
	(243, 1, 0, -50937, 1688, 0, 0, 39, '1687'),
	(243, 1, 0, -50937, 1689, 0, 0, 39, '1688'),
	(243, 1, 0, -50937, 1690, 0, 0, 39, '1689'),
	(243, 1, 0, -50937, 1691, 0, 0, 39, '1690'),
	(243, 1, 0, -50937, 1692, 0, 0, 39, '1691'),
	(243, 1, 0, -50937, 1693, 0, 0, 39, '1692'),
	(243, 1, 0, -50937, 1694, 0, 0, 39, '1693'),
	(243, 1, 0, -50937, 1695, 0, 0, 39, '1694'),
	(243, 1, 0, -50937, 1696, 0, 0, 39, '1695'),
	(243, 1, 0, -50937, 1697, 0, 0, 39, '1696'),
	(243, 1, 0, -50937, 1698, 0, 0, 39, '1697'),
	(243, 1, 0, -50937, 1699, 0, 0, 39, '1698'),
	(243, 1, 0, -50937, 1700, 0, 0, 39, '1699'),
	(243, 1, 0, -50937, 1701, 0, 0, 39, '1700'),
	(243, 1, 0, -50937, 1702, 0, 0, 39, '1701'),
	(243, 1, 0, -50937, 1703, 0, 0, 39, '1702'),
	(243, 1, 0, -50937, 1704, 0, 0, 39, '1703'),
	(243, 1, 0, -50937, 1705, 0, 0, 39, '1704'),
	(243, 1, 0, -50937, 1706, 0, 0, 39, '1705'),
	(243, 1, 0, -50937, 1707, 0, 0, 39, '1706'),
	(243, 1, 0, -50937, 1708, 0, 0, 39, '1707'),
	(243, 1, 0, -50937, 1709, 0, 0, 39, '1708'),
	(243, 1, 0, -50937, 1710, 0, 0, 39, '1709'),
	(243, 1, 0, -50937, 1711, 0, 0, 39, '1710'),
	(243, 1, 0, -50937, 1712, 0, 0, 39, '1711'),
	(243, 1, 0, -50937, 1713, 0, 0, 39, '1712'),
	(243, 1, 0, -50937, 1714, 0, 0, 39, '1713'),
	(243, 1, 0, -50937, 1715, 0, 0, 39, '1714'),
	(243, 1, 0, -50937, 1716, 0, 0, 39, '1715'),
	(243, 1, 0, -50937, 1717, 0, 0, 39, '1716'),
	(243, 1, 0, -50937, 1718, 0, 0, 39, '1717'),
	(243, 1, 0, -50937, 1719, 0, 0, 39, '1718'),
	(243, 1, 0, -50937, 1720, 0, 0, 39, '1719'),
	(243, 1, 0, -50937, 1721, 0, 0, 39, '1720'),
	(243, 1, 0, -50937, 1722, 0, 0, 39, '1721'),
	(243, 1, 0, -50937, 1723, 0, 0, 39, '1722'),
	(243, 1, 0, -50937, 1724, 0, 0, 39, '1723'),
	(243, 1, 0, -50937, 1725, 0, 0, 39, '1724'),
	(243, 1, 0, -50937, 1726, 0, 0, 39, '1725'),
	(243, 1, 0, -50937, 1727, 0, 0, 39, '1726'),
	(243, 1, 0, -50937, 1728, 0, 0, 39, '1727'),
	(243, 1, 0, -50937, 1729, 0, 0, 39, '1728'),
	(243, 1, 0, -50937, 1730, 0, 0, 39, '1729'),
	(243, 1, 0, -50937, 1731, 0, 0, 39, '1730'),
	(243, 1, 0, -50937, 1732, 0, 0, 39, '1731'),
	(243, 1, 0, -50937, 1733, 0, 0, 39, '1732'),
	(243, 1, 0, -50937, 1734, 0, 0, 39, '1733'),
	(243, 1, 0, -50937, 1735, 0, 0, 39, '1734'),
	(243, 1, 0, -50937, 1736, 0, 0, 39, '1735'),
	(243, 1, 0, -50937, 1737, 0, 0, 39, '1736'),
	(243, 1, 0, -50937, 1738, 0, 0, 39, '1737'),
	(243, 1, 0, -50937, 1739, 0, 0, 39, '1738'),
	(243, 1, 0, -50937, 1740, 0, 0, 39, '1739'),
	(243, 1, 0, -50937, 1741, 0, 0, 39, '1740'),
	(243, 1, 0, -50937, 1742, 0, 0, 39, '1741'),
	(243, 1, 0, -50937, 1743, 0, 0, 39, '1742'),
	(243, 1, 0, -50937, 1744, 0, 0, 39, '1743'),
	(243, 1, 0, -50937, 1745, 0, 0, 39, '1744'),
	(243, 1, 0, -50937, 1746, 0, 0, 39, '1745'),
	(243, 1, 0, -50937, 1747, 0, 0, 39, '1746'),
	(243, 1, 0, -50937, 1748, 0, 0, 39, '1747'),
	(243, 1, 0, -50937, 1749, 0, 0, 39, '1748'),
	(243, 1, 0, -50937, 1750, 0, 0, 39, '1749'),
	(243, 1, 0, -50937, 1751, 0, 0, 39, '1750'),
	(243, 1, 0, -50937, 1752, 0, 0, 39, '1751'),
	(243, 1, 0, -50937, 1753, 0, 0, 39, '1752'),
	(243, 1, 0, -50937, 1754, 0, 0, 39, '1753'),
	(243, 1, 0, -50937, 1755, 0, 0, 39, '1754'),
	(243, 1, 0, -50937, 1756, 0, 0, 39, '1755'),
	(243, 1, 0, -50937, 1757, 0, 0, 39, '1756'),
	(243, 1, 0, -50937, 1758, 0, 0, 39, '1757'),
	(243, 1, 0, -50937, 1759, 0, 0, 39, '1758'),
	(243, 1, 0, -50937, 1760, 0, 0, 39, '1759'),
	(243, 1, 0, -50937, 1761, 0, 0, 39, '1760'),
	(243, 1, 0, -50937, 1762, 0, 0, 39, '1761'),
	(243, 1, 0, -50937, 1763, 0, 0, 39, '1762'),
	(243, 1, 0, -50937, 1764, 0, 0, 39, '1763'),
	(243, 1, 0, -50937, 1765, 0, 0, 39, '1764'),
	(243, 1, 0, -50937, 1766, 0, 0, 39, '1765'),
	(243, 1, 0, -50937, 1767, 0, 0, 39, '1766'),
	(243, 1, 0, -50937, 1768, 0, 0, 39, '1767'),
	(243, 1, 0, -50937, 1769, 0, 0, 39, '1768'),
	(243, 1, 0, -50937, 1770, 0, 0, 39, '1769'),
	(243, 1, 0, -50937, 1771, 0, 0, 39, '1770'),
	(243, 1, 0, -50937, 1772, 0, 0, 39, '1771'),
	(243, 1, 0, -50937, 1773, 0, 0, 39, '1772'),
	(243, 1, 0, -50937, 1774, 0, 0, 39, '1773'),
	(243, 1, 0, -50937, 1775, 0, 0, 39, '1774'),
	(243, 1, 0, -50937, 1776, 0, 0, 39, '1775'),
	(243, 1, 0, -50937, 1777, 0, 0, 39, '1776'),
	(243, 1, 0, -50937, 1778, 0, 0, 39, '1777'),
	(243, 1, 0, -50937, 1779, 0, 0, 39, '1778'),
	(243, 1, 0, -50937, 1780, 0, 0, 39, '1779'),
	(243, 1, 0, -50937, 1781, 0, 0, 39, '1780'),
	(243, 1, 0, -50937, 1782, 0, 0, 39, '1781'),
	(243, 1, 0, -50937, 1783, 0, 0, 39, '1782'),
	(243, 1, 0, -50937, 1784, 0, 0, 39, '1783'),
	(243, 1, 0, -50937, 1785, 0, 0, 39, '1784'),
	(243, 1, 0, -50937, 1786, 0, 0, 39, '1785'),
	(243, 1, 0, -50937, 1787, 0, 0, 39, '1786'),
	(243, 1, 0, -50937, 1788, 0, 0, 39, '1787'),
	(243, 1, 0, -50937, 1789, 0, 0, 39, '1788'),
	(243, 1, 0, -50937, 1790, 0, 0, 39, '1789'),
	(243, 1, 0, -50937, 1791, 0, 0, 39, '1790'),
	(243, 1, 0, -50937, 1792, 0, 0, 39, '1791'),
	(243, 1, 0, -50937, 1793, 0, 0, 39, '1792'),
	(243, 1, 0, -50937, 1794, 0, 0, 39, '1793'),
	(243, 1, 0, -50937, 1795, 0, 0, 39, '1794'),
	(243, 1, 0, -50937, 1796, 0, 0, 39, '1795'),
	(243, 1, 0, -50937, 1797, 0, 0, 39, '1796'),
	(243, 1, 0, -50937, 1798, 0, 0, 39, '1797'),
	(243, 1, 0, -50937, 1799, 0, 0, 39, '1798'),
	(243, 1, 0, -50937, 1800, 0, 0, 39, '1799'),
	(243, 1, 0, -50937, 1801, 0, 0, 39, '1800'),
	(243, 1, 0, -50937, 1802, 0, 0, 39, '1801'),
	(243, 1, 0, -50937, 1803, 0, 0, 39, '1802'),
	(243, 1, 0, -50937, 1804, 0, 0, 39, '1803'),
	(243, 1, 0, -50937, 1805, 0, 0, 39, '1804'),
	(243, 1, 0, -50937, 1806, 0, 0, 39, '1805'),
	(243, 1, 0, -50937, 1807, 0, 0, 39, '1806'),
	(243, 1, 0, -50937, 1808, 0, 0, 39, '1807'),
	(243, 1, 0, -50937, 1809, 0, 0, 39, '1808'),
	(243, 1, 0, -50937, 1810, 0, 0, 39, '1809'),
	(243, 1, 0, -50937, 1811, 0, 0, 39, '1810'),
	(243, 1, 0, -50937, 1812, 0, 0, 39, '1811'),
	(243, 1, 0, -50937, 1813, 0, 0, 39, '1812'),
	(243, 1, 0, -50937, 1814, 0, 0, 39, '1813'),
	(243, 1, 0, -50937, 1815, 0, 0, 39, '1814'),
	(243, 1, 0, -50937, 1816, 0, 0, 39, '1815'),
	(243, 1, 0, -50937, 1817, 0, 0, 39, '1816'),
	(243, 1, 0, -50937, 1818, 0, 0, 39, '1817'),
	(243, 1, 0, -50937, 1819, 0, 0, 39, '1818'),
	(243, 1, 0, -50937, 1820, 0, 0, 39, '1819'),
	(243, 1, 0, -50937, 1821, 0, 0, 39, '1820'),
	(243, 1, 0, -50937, 1822, 0, 0, 39, '1821'),
	(243, 1, 0, -50937, 1823, 0, 0, 39, '1822'),
	(243, 1, 0, -50937, 1824, 0, 0, 39, '1823'),
	(243, 1, 0, -50937, 1825, 0, 0, 39, '1824'),
	(243, 1, 0, -50937, 1826, 0, 0, 39, '1825'),
	(243, 1, 0, -50937, 1827, 0, 0, 39, '1826'),
	(243, 1, 0, -50937, 1828, 0, 0, 39, '1827'),
	(243, 1, 0, -50937, 1829, 0, 0, 39, '1828'),
	(243, 1, 0, -50937, 1830, 0, 0, 39, '1829'),
	(243, 1, 0, -50937, 1831, 0, 0, 39, '1830'),
	(243, 1, 0, -50937, 1832, 0, 0, 39, '1831'),
	(243, 1, 0, -50937, 1833, 0, 0, 39, '1832'),
	(243, 1, 0, -50937, 1834, 0, 0, 39, '1833'),
	(243, 1, 0, -50937, 1835, 0, 0, 39, '1834'),
	(243, 1, 0, -50937, 1836, 0, 0, 39, '1835'),
	(243, 1, 0, -50937, 1837, 0, 0, 39, '1836'),
	(243, 1, 0, -50937, 1838, 0, 0, 39, '1837'),
	(243, 1, 0, -50937, 1839, 0, 0, 39, '1838'),
	(243, 1, 0, -50937, 1840, 0, 0, 39, '1839'),
	(243, 1, 0, -50937, 1841, 0, 0, 39, '1840'),
	(243, 1, 0, -50937, 1842, 0, 0, 39, '1841'),
	(243, 1, 0, -50937, 1843, 0, 0, 39, '1842'),
	(243, 1, 0, -50937, 1844, 0, 0, 39, '1843'),
	(243, 1, 0, -50937, 1845, 0, 0, 39, '1844'),
	(243, 1, 0, -50937, 1846, 0, 0, 39, '1845'),
	(243, 1, 0, -50937, 1847, 0, 0, 39, '1846'),
	(243, 1, 0, -50937, 1848, 0, 0, 39, '1847'),
	(243, 1, 0, -50937, 1849, 0, 0, 39, '1848'),
	(243, 1, 0, -50937, 1850, 0, 0, 39, '1849'),
	(243, 1, 0, -50937, 1851, 0, 0, 39, '1850'),
	(243, 1, 0, -50937, 1852, 0, 0, 39, '1851'),
	(243, 1, 0, -50937, 1853, 0, 0, 39, '1852'),
	(243, 1, 0, -50937, 1854, 0, 0, 39, '1853'),
	(243, 1, 0, -50937, 1855, 0, 0, 39, '1854'),
	(243, 1, 0, -50937, 1856, 0, 0, 39, '1855'),
	(243, 1, 0, -50937, 1857, 0, 0, 39, '1856'),
	(243, 1, 0, -50937, 1858, 0, 0, 39, '1857'),
	(243, 1, 0, -50937, 1859, 0, 0, 39, '1858'),
	(243, 1, 0, -50937, 1860, 0, 0, 39, '1859'),
	(243, 1, 0, -50937, 1861, 0, 0, 39, '1860'),
	(243, 1, 0, -50937, 1862, 0, 0, 39, '1861'),
	(243, 1, 0, -50937, 1863, 0, 0, 39, '1862'),
	(243, 1, 0, -50937, 1864, 0, 0, 39, '1863'),
	(243, 1, 0, -50937, 1865, 0, 0, 39, '1864'),
	(243, 1, 0, -50937, 1866, 0, 0, 39, '1865'),
	(243, 1, 0, -50937, 1867, 0, 0, 39, '1866'),
	(243, 1, 0, -50937, 1868, 0, 0, 39, '1867'),
	(243, 1, 0, -50937, 1869, 0, 0, 39, '1868'),
	(243, 1, 0, -50937, 1870, 0, 0, 39, '1869'),
	(243, 1, 0, -50937, 1871, 0, 0, 39, '1870'),
	(243, 1, 0, -50937, 1872, 0, 0, 39, '1871'),
	(243, 1, 0, -50937, 1873, 0, 0, 39, '1872'),
	(243, 1, 0, -50937, 1874, 0, 0, 39, '1873'),
	(243, 1, 0, -50937, 1875, 0, 0, 39, '1874'),
	(243, 1, 0, -50937, 1876, 0, 0, 39, '1875'),
	(243, 1, 0, -50937, 1877, 0, 0, 39, '1876'),
	(243, 1, 0, -50937, 1878, 0, 0, 39, '1877'),
	(243, 1, 0, -50937, 1879, 0, 0, 39, '1878'),
	(243, 1, 0, -50937, 1880, 0, 0, 39, '1879'),
	(243, 1, 0, -50937, 1881, 0, 0, 39, '1880'),
	(243, 1, 0, -50937, 1882, 0, 0, 39, '1881'),
	(243, 1, 0, -50937, 1883, 0, 0, 39, '1882'),
	(243, 1, 0, -50937, 1884, 0, 0, 39, '1883'),
	(243, 1, 0, -50937, 1885, 0, 0, 39, '1884'),
	(243, 1, 0, -50937, 1886, 0, 0, 39, '1885'),
	(243, 1, 0, -50937, 1887, 0, 0, 39, '1886'),
	(243, 1, 0, -50937, 1888, 0, 0, 39, '1887'),
	(243, 1, 0, -50937, 1889, 0, 0, 39, '1888'),
	(243, 1, 0, -50937, 1890, 0, 0, 39, '1889'),
	(243, 1, 0, -50937, 1891, 0, 0, 39, '1890'),
	(243, 1, 0, -50937, 1892, 0, 0, 39, '1891'),
	(243, 1, 0, -50937, 1893, 0, 0, 39, '1892'),
	(243, 1, 0, -50937, 1894, 0, 0, 39, '1893'),
	(243, 1, 0, -50937, 1895, 0, 0, 39, '1894'),
	(243, 1, 0, -50937, 1896, 0, 0, 39, '1895'),
	(243, 1, 0, -50937, 1897, 0, 0, 39, '1896'),
	(243, 1, 0, -50937, 1898, 0, 0, 39, '1897'),
	(243, 1, 0, -50937, 1899, 0, 0, 39, '1898'),
	(243, 1, 0, -50937, 1900, 0, 0, 39, '1899'),
	(243, 1, 0, -50937, 1901, 0, 0, 39, '1900'),
	(243, 1, 0, -50937, 1902, 0, 0, 39, '1901'),
	(243, 1, 0, -50937, 1903, 0, 0, 39, '1902'),
	(243, 1, 0, -50937, 1904, 0, 0, 39, '1903'),
	(243, 1, 0, -50937, 1905, 0, 0, 39, '1904'),
	(243, 1, 0, -50937, 1906, 0, 0, 39, '1905'),
	(243, 1, 0, -50937, 1907, 0, 0, 39, '1906'),
	(243, 1, 0, -50937, 1908, 0, 0, 39, '1907'),
	(243, 1, 0, -50937, 1909, 0, 0, 39, '1908'),
	(243, 1, 0, -50937, 1910, 0, 0, 39, '1909'),
	(243, 1, 0, -50937, 1911, 0, 0, 39, '1910'),
	(243, 1, 0, -50937, 1912, 0, 0, 39, '1911'),
	(243, 1, 0, -50937, 1913, 0, 0, 39, '1912'),
	(243, 1, 0, -50937, 1914, 0, 0, 39, '1913'),
	(243, 1, 0, -50937, 1915, 0, 0, 39, '1914'),
	(243, 1, 0, -50937, 1916, 0, 0, 39, '1915'),
	(243, 1, 0, -50937, 1917, 0, 0, 39, '1916'),
	(243, 1, 0, -50937, 1918, 0, 0, 39, '1917'),
	(243, 1, 0, -50937, 1919, 0, 0, 39, '1918'),
	(243, 1, 0, -50937, 1920, 0, 0, 39, '1919'),
	(243, 1, 0, -50937, 1921, 0, 0, 39, '1920'),
	(243, 1, 0, -50937, 1922, 0, 0, 39, '1921'),
	(243, 1, 0, -50937, 1923, 0, 0, 39, '1922'),
	(243, 1, 0, -50937, 1924, 0, 0, 39, '1923'),
	(243, 1, 0, -50937, 1925, 0, 0, 39, '1924'),
	(243, 1, 0, -50937, 1926, 0, 0, 39, '1925'),
	(243, 1, 0, -50937, 1927, 0, 0, 39, '1926'),
	(243, 1, 0, -50937, 1928, 0, 0, 39, '1927'),
	(243, 1, 0, -50937, 1929, 0, 0, 39, '1928'),
	(243, 1, 0, -50937, 1930, 0, 0, 39, '1929'),
	(243, 1, 0, -50937, 1931, 0, 0, 39, '1930'),
	(243, 1, 0, -50937, 1932, 0, 0, 39, '1931'),
	(243, 1, 0, -50937, 1933, 0, 0, 39, '1932'),
	(243, 1, 0, -50937, 1934, 0, 0, 39, '1933'),
	(243, 1, 0, -50937, 1935, 0, 0, 39, '1934'),
	(243, 1, 0, -50937, 1936, 0, 0, 39, '1935'),
	(243, 1, 0, -50937, 1937, 0, 0, 39, '1936'),
	(243, 1, 0, -50937, 1938, 0, 0, 39, '1937'),
	(243, 1, 0, -50937, 1939, 0, 0, 39, '1938'),
	(243, 1, 0, -50937, 1940, 0, 0, 39, '1939'),
	(243, 1, 0, -50937, 1941, 0, 0, 39, '1940'),
	(243, 1, 0, -50937, 1942, 0, 0, 39, '1941'),
	(243, 1, 0, -50937, 1943, 0, 0, 39, '1942'),
	(243, 1, 0, -50937, 1944, 0, 0, 39, '1943'),
	(243, 1, 0, -50937, 1945, 0, 0, 39, '1944'),
	(243, 1, 0, -50937, 1946, 0, 0, 39, '1945'),
	(243, 1, 0, -50937, 1947, 0, 0, 39, '1946'),
	(243, 1, 0, -50937, 1948, 0, 0, 39, '1947'),
	(243, 1, 0, -50937, 1949, 0, 0, 39, '1948'),
	(243, 1, 0, -50937, 1950, 0, 0, 39, '1949'),
	(243, 1, 0, -50937, 1951, 0, 0, 39, '1950'),
	(243, 1, 0, -50937, 1952, 0, 0, 39, '1951'),
	(243, 1, 0, -50937, 1953, 0, 0, 39, '1952'),
	(243, 1, 0, -50937, 1954, 0, 0, 39, '1953'),
	(243, 1, 0, -50937, 1955, 0, 0, 39, '1954'),
	(243, 1, 0, -50937, 1956, 0, 0, 39, '1955'),
	(243, 1, 0, -50937, 1957, 0, 0, 39, '1956'),
	(243, 1, 0, -50937, 1958, 0, 0, 39, '1957'),
	(243, 1, 0, -50937, 1959, 0, 0, 39, '1958'),
	(243, 1, 0, -50937, 1960, 0, 0, 39, '1959'),
	(243, 1, 0, -50937, 1961, 0, 0, 39, '1960'),
	(243, 1, 0, -50937, 1962, 0, 0, 39, '1961'),
	(243, 1, 0, -50937, 1963, 0, 0, 39, '1962'),
	(243, 1, 0, -50937, 1964, 0, 0, 39, '1963'),
	(243, 1, 0, -50937, 1965, 0, 0, 39, '1964'),
	(243, 1, 0, -50937, 1966, 0, 0, 39, '1965'),
	(243, 1, 0, -50937, 1967, 0, 0, 39, '1966'),
	(243, 1, 0, -50937, 1968, 0, 0, 39, '1967'),
	(243, 1, 0, -50937, 1969, 0, 0, 39, '1968'),
	(243, 1, 0, -50937, 1970, 0, 0, 39, '1969'),
	(243, 1, 0, -50937, 1971, 0, 0, 39, '1970'),
	(243, 1, 0, -50937, 1972, 0, 0, 39, '1971'),
	(243, 1, 0, -50937, 1973, 0, 0, 39, '1972'),
	(243, 1, 0, -50937, 1974, 0, 0, 39, '1973'),
	(243, 1, 0, -50937, 1975, 0, 0, 39, '1974'),
	(243, 1, 0, -50937, 1976, 0, 0, 39, '1975'),
	(243, 1, 0, -50937, 1977, 0, 0, 39, '1976'),
	(243, 1, 0, -50937, 1978, 0, 0, 39, '1977'),
	(243, 1, 0, -50937, 1979, 0, 0, 39, '1978'),
	(243, 1, 0, -50937, 1980, 0, 0, 39, '1979'),
	(243, 1, 0, -50937, 1981, 0, 0, 39, '1980'),
	(243, 1, 0, -50937, 1982, 0, 0, 39, '1981'),
	(243, 1, 0, -50937, 1983, 0, 0, 39, '1982'),
	(243, 1, 0, -50937, 1984, 0, 0, 39, '1983'),
	(243, 1, 0, -50937, 1985, 0, 0, 39, '1984'),
	(243, 1, 0, -50937, 1986, 0, 0, 39, '1985'),
	(243, 1, 0, -50937, 1987, 0, 0, 39, '1986'),
	(243, 1, 0, -50937, 1988, 0, 0, 39, '1987'),
	(243, 1, 0, -50937, 1989, 0, 0, 39, '1988'),
	(243, 1, 0, -50937, 1990, 0, 0, 39, '1989'),
	(243, 1, 0, -50937, 1991, 0, 0, 39, '1990'),
	(243, 1, 0, -50937, 1992, 0, 0, 39, '1991'),
	(243, 1, 0, -50937, 1993, 0, 0, 39, '1992'),
	(243, 1, 0, -50937, 1994, 0, 0, 39, '1993'),
	(243, 1, 0, -50937, 1995, 0, 0, 39, '1994'),
	(243, 1, 0, -50937, 1996, 0, 0, 39, '1995'),
	(243, 1, 0, -50937, 1997, 0, 0, 39, '1996'),
	(243, 1, 0, -50937, 1998, 0, 0, 39, '1997'),
	(243, 1, 0, -50937, 1999, 0, 0, 39, '1998'),
	(243, 1, 0, -50937, 2000, 0, 0, 39, '1999'),
	(243, 1, 0, -50937, 2001, 0, 0, 39, '2000'),
	(243, 1, 0, -50937, 2002, 0, 0, 39, '2001'),
	(243, 1, 0, -50937, 2003, 0, 0, 39, '2002'),
	(243, 1, 0, -50937, 2004, 0, 0, 39, '2003'),
	(243, 1, 0, -50937, 2005, 0, 0, 39, '2004'),
	(243, 1, 0, -50937, 2006, 0, 0, 39, '2005'),
	(243, 1, 0, -50937, 2007, 0, 0, 39, '2006'),
	(243, 1, 0, -50937, 2008, 0, 0, 39, '2007'),
	(243, 1, 0, -50937, 2009, 0, 0, 39, '2008'),
	(243, 1, 0, -50937, 2010, 0, 0, 39, '2009'),
	(243, 1, 0, -50937, 2011, 0, 0, 39, '2010'),
	(243, 1, 0, -50937, 2012, 0, 0, 39, '2011'),
	(243, 1, 0, -50937, 2013, 0, 0, 39, '2012'),
	(243, 1, 0, -50937, 2014, 0, 0, 39, '2013'),
	(243, 1, 0, -50937, 2015, 0, 0, 39, '2014'),
	(243, 1, 0, -50937, 2016, 0, 0, 39, '2015'),
	(243, 1, 0, -50937, 2017, 0, 0, 39, '2016'),
	(243, 1, 0, -50937, 2018, 0, 0, 39, '2017'),
	(243, 1, 0, -50937, 2019, 0, 0, 39, '2018'),
	(243, 1, 0, -50937, 2020, 0, 0, 39, '2019'),
	(243, 1, 0, -50937, 2021, 0, 0, 39, '2020'),
	(243, 1, 0, -50937, 2022, 0, 0, 39, '2021'),
	(243, 1, 0, -50937, 2023, 0, 0, 39, '2022'),
	(243, 1, 0, -50937, 2024, 0, 0, 39, '2023'),
	(243, 1, 0, -50937, 2025, 0, 0, 39, '2024'),
	(243, 1, 0, -50937, 2026, 0, 0, 39, '2025'),
	(243, 1, 0, -50937, 2027, 0, 0, 39, '2026'),
	(243, 1, 0, -50937, 2028, 0, 0, 39, '2027'),
	(243, 1, 0, -50937, 2029, 0, 0, 39, '2028'),
	(243, 1, 0, -50937, 2030, 0, 0, 39, '2029'),
	(243, 1, 0, -50937, 2031, 0, 0, 39, '2030'),
	(243, 1, 0, -50937, 2032, 0, 0, 39, '2031'),
	(243, 1, 0, -50937, 2033, 0, 0, 39, '2032'),
	(243, 1, 0, -50937, 2034, 0, 0, 39, '2033'),
	(243, 1, 0, -50937, 2035, 0, 0, 39, '2034'),
	(243, 1, 0, -50937, 2036, 0, 0, 39, '2035'),
	(243, 1, 0, -50937, 2037, 0, 0, 39, '2036'),
	(243, 1, 0, -50937, 2038, 0, 0, 39, '2037'),
	(243, 1, 0, -50937, 2039, 0, 0, 39, '2038'),
	(243, 1, 0, -50937, 2040, 0, 0, 39, '2039'),
	(243, 1, 0, -50937, 2041, 0, 0, 39, '2040'),
	(243, 1, 0, -50937, 2042, 0, 0, 39, '2041'),
	(243, 1, 0, -50937, 2043, 0, 0, 39, '2042'),
	(243, 1, 0, -50937, 2044, 0, 0, 39, '2043'),
	(243, 1, 0, -50937, 2045, 0, 0, 39, '2044'),
	(243, 1, 0, -50937, 2046, 0, 0, 39, '2045'),
	(243, 1, 0, -50937, 2047, 0, 0, 39, '2046'),
	(243, 1, 0, -50937, 2048, 0, 0, 39, '2047'),
	(243, 1, 0, -50934, 1, 0, 0, 37, '12'),
	(243, 1, 0, -50934, 2, 0, 0, 37, '13'),
	(243, 1, 0, -50934, 3, 0, 0, 37, '14'),
	(243, 1, 0, -50934, 4, 0, 0, 37, '15'),
	(243, 1, 0, -50933, 1, 0, 0, 37, '12'),
	(243, 1, 0, -50933, 2, 0, 0, 37, '13'),
	(243, 1, 0, -50933, 3, 0, 0, 37, '14'),
	(243, 1, 0, -50933, 4, 0, 0, 37, '15'),
	(243, 1, 0, -50932, 1, 0, 0, 37, '12'),
	(243, 1, 0, -50932, 2, 0, 0, 37, '13'),
	(243, 1, 0, -50932, 3, 0, 0, 37, '14'),
	(243, 1, 0, -50932, 4, 0, 0, 37, '15'),
	(243, 1, 0, -50931, 1, 0, 0, 37, '12'),
	(243, 1, 0, -50931, 2, 0, 0, 37, '13'),
	(243, 1, 0, -50931, 3, 0, 0, 37, '14'),
	(243, 1, 0, -50931, 4, 0, 0, 37, '15'),
	(243, 1, 0, -50930, 1, 0, 0, 37, '12'),
	(243, 1, 0, -50930, 2, 0, 0, 37, '13'),
	(243, 1, 0, -50930, 3, 0, 0, 37, '14'),
	(243, 1, 0, -50930, 4, 0, 0, 37, '15'),
	(243, 1, 0, -50929, 1, 0, 0, 37, '12'),
	(243, 1, 0, -50929, 2, 0, 0, 37, '13'),
	(243, 1, 0, -50929, 3, 0, 0, 37, '14'),
	(243, 1, 0, -50929, 4, 0, 0, 37, '15'),
	(243, 1, 0, -50928, 1, 0, 0, 37, '12'),
	(243, 1, 0, -50928, 2, 0, 0, 37, '13'),
	(243, 1, 0, -50928, 3, 0, 0, 37, '14'),
	(243, 1, 0, -50928, 4, 0, 0, 37, '15'),
	(243, 1, 0, -50927, 1, 0, 0, 37, '12'),
	(243, 1, 0, -50927, 2, 0, 0, 37, '13'),
	(243, 1, 0, -50927, 3, 0, 0, 37, '14'),
	(243, 1, 0, -50927, 4, 0, 0, 37, '15'),
	(243, 1, 0, -50926, 1, 0, 0, 37, '12'),
	(243, 1, 0, -50926, 2, 0, 0, 37, '13'),
	(243, 1, 0, -50926, 3, 0, 0, 37, '14'),
	(243, 1, 0, -50926, 4, 0, 0, 37, '15'),
	(243, 1, 0, -50924, 1, 0, 0, 39, '0'),
	(243, 1, 0, -50924, 2, 0, 0, 39, '1'),
	(243, 1, 0, -50924, 3, 0, 0, 39, '2'),
	(243, 1, 0, -50924, 4, 0, 0, 39, '3'),
	(243, 1, 0, -50924, 5, 0, 0, 39, '4'),
	(243, 1, 0, -50924, 6, 0, 0, 39, '5'),
	(243, 1, 0, -50924, 7, 0, 0, 39, '6'),
	(243, 1, 0, -50924, 8, 0, 0, 39, '7'),
	(243, 1, 0, -50924, 9, 0, 0, 39, '8'),
	(243, 1, 0, -50924, 10, 0, 0, 39, '9'),
	(243, 1, 0, -50924, 11, 0, 0, 39, '10'),
	(243, 1, 0, -50924, 12, 0, 0, 39, '11'),
	(243, 1, 0, -50924, 13, 0, 0, 39, '12'),
	(243, 1, 0, -50924, 14, 0, 0, 39, '13'),
	(243, 1, 0, -50924, 15, 0, 0, 39, '14'),
	(243, 1, 0, -50924, 16, 0, 0, 39, '15'),
	(243, 1, 0, -50924, 17, 0, 0, 39, '16'),
	(243, 1, 0, -50924, 18, 0, 0, 39, '17'),
	(243, 1, 0, -50924, 19, 0, 0, 39, '18'),
	(243, 1, 0, -50924, 20, 0, 0, 39, '19'),
	(243, 1, 0, -50924, 21, 0, 0, 39, '20'),
	(243, 1, 0, -50924, 22, 0, 0, 39, '21'),
	(243, 1, 0, -50924, 23, 0, 0, 39, '22'),
	(243, 1, 0, -50924, 24, 0, 0, 39, '23'),
	(243, 1, 0, -50924, 25, 0, 0, 39, '24'),
	(243, 1, 0, -50924, 26, 0, 0, 39, '25'),
	(243, 1, 0, -50924, 27, 0, 0, 39, '26'),
	(243, 1, 0, -50924, 28, 0, 0, 39, '27'),
	(243, 1, 0, -50924, 29, 0, 0, 39, '28'),
	(243, 1, 0, -50924, 30, 0, 0, 39, '29'),
	(243, 1, 0, -50924, 31, 0, 0, 39, '30'),
	(243, 1, 0, -50924, 32, 0, 0, 39, '31'),
	(243, 1, 0, -50924, 33, 0, 0, 39, '32'),
	(243, 1, 0, -50924, 34, 0, 0, 39, '33'),
	(243, 1, 0, -50924, 35, 0, 0, 39, '34'),
	(243, 1, 0, -50924, 36, 0, 0, 39, '35'),
	(243, 1, 0, -50924, 37, 0, 0, 39, '36'),
	(243, 1, 0, -50924, 38, 0, 0, 39, '37'),
	(243, 1, 0, -50924, 39, 0, 0, 39, '38'),
	(243, 1, 0, -50924, 40, 0, 0, 39, '39'),
	(243, 1, 0, -50924, 41, 0, 0, 39, '40'),
	(243, 1, 0, -50924, 42, 0, 0, 39, '41'),
	(243, 1, 0, -50924, 43, 0, 0, 39, '42'),
	(243, 1, 0, -50924, 44, 0, 0, 39, '43'),
	(243, 1, 0, -50924, 45, 0, 0, 39, '44'),
	(243, 1, 0, -50924, 46, 0, 0, 39, '45'),
	(243, 1, 0, -50924, 47, 0, 0, 39, '46'),
	(243, 1, 0, -50924, 48, 0, 0, 39, '47'),
	(243, 1, 0, -50924, 49, 0, 0, 39, '48'),
	(243, 1, 0, -50924, 50, 0, 0, 39, '49'),
	(243, 1, 0, -50924, 51, 0, 0, 39, '50'),
	(243, 1, 0, -50924, 52, 0, 0, 39, '51'),
	(243, 1, 0, -50924, 53, 0, 0, 39, '52'),
	(243, 1, 0, -50924, 54, 0, 0, 39, '53'),
	(243, 1, 0, -50924, 55, 0, 0, 39, '54'),
	(243, 1, 0, -50924, 56, 0, 0, 39, '55'),
	(243, 1, 0, -50924, 57, 0, 0, 39, '56'),
	(243, 1, 0, -50924, 58, 0, 0, 39, '57'),
	(243, 1, 0, -50924, 59, 0, 0, 39, '58'),
	(243, 1, 0, -50924, 60, 0, 0, 39, '59'),
	(243, 1, 0, -50924, 61, 0, 0, 39, '60'),
	(243, 1, 0, -50924, 62, 0, 0, 39, '61'),
	(243, 1, 0, -50924, 63, 0, 0, 39, '62'),
	(243, 1, 0, -50924, 64, 0, 0, 39, '63'),
	(243, 1, 0, -50924, 65, 0, 0, 39, '64'),
	(243, 1, 0, -50924, 66, 0, 0, 39, '65'),
	(243, 1, 0, -50924, 67, 0, 0, 39, '66'),
	(243, 1, 0, -50924, 68, 0, 0, 39, '67'),
	(243, 1, 0, -50924, 69, 0, 0, 39, '68'),
	(243, 1, 0, -50924, 70, 0, 0, 39, '69'),
	(243, 1, 0, -50924, 71, 0, 0, 39, '70'),
	(243, 1, 0, -50924, 72, 0, 0, 39, '71'),
	(243, 1, 0, -50924, 73, 0, 0, 39, '72'),
	(243, 1, 0, -50924, 74, 0, 0, 39, '73'),
	(243, 1, 0, -50924, 75, 0, 0, 39, '74'),
	(243, 1, 0, -50924, 76, 0, 0, 39, '75'),
	(243, 1, 0, -50924, 77, 0, 0, 39, '76'),
	(243, 1, 0, -50924, 78, 0, 0, 39, '77'),
	(243, 1, 0, -50924, 79, 0, 0, 39, '78'),
	(243, 1, 0, -50924, 80, 0, 0, 39, '79'),
	(243, 1, 0, -50924, 81, 0, 0, 39, '80'),
	(243, 1, 0, -50924, 82, 0, 0, 39, '81'),
	(243, 1, 0, -50924, 83, 0, 0, 39, '82'),
	(243, 1, 0, -50924, 84, 0, 0, 39, '83'),
	(243, 1, 0, -50924, 85, 0, 0, 39, '84'),
	(243, 1, 0, -50924, 86, 0, 0, 39, '85'),
	(243, 1, 0, -50924, 87, 0, 0, 39, '86'),
	(243, 1, 0, -50924, 88, 0, 0, 39, '87'),
	(243, 1, 0, -50924, 89, 0, 0, 39, '88'),
	(243, 1, 0, -50924, 90, 0, 0, 39, '89'),
	(243, 1, 0, -50924, 91, 0, 0, 39, '90'),
	(243, 1, 0, -50924, 92, 0, 0, 39, '91'),
	(243, 1, 0, -50924, 93, 0, 0, 39, '92'),
	(243, 1, 0, -50924, 94, 0, 0, 39, '93'),
	(243, 1, 0, -50924, 95, 0, 0, 39, '94'),
	(243, 1, 0, -50924, 96, 0, 0, 39, '95'),
	(243, 1, 0, -50924, 97, 0, 0, 39, '96'),
	(243, 1, 0, -50924, 98, 0, 0, 39, '97'),
	(243, 1, 0, -50924, 99, 0, 0, 39, '98'),
	(243, 1, 0, -50924, 100, 0, 0, 39, '99'),
	(243, 1, 0, -50924, 101, 0, 0, 39, '100'),
	(243, 1, 0, -50924, 102, 0, 0, 39, '101'),
	(243, 1, 0, -50924, 103, 0, 0, 39, '102'),
	(243, 1, 0, -50924, 104, 0, 0, 39, '103'),
	(243, 1, 0, -50924, 105, 0, 0, 39, '104'),
	(243, 1, 0, -50924, 106, 0, 0, 39, '105'),
	(243, 1, 0, -50924, 107, 0, 0, 39, '106'),
	(243, 1, 0, -50924, 108, 0, 0, 39, '107'),
	(243, 1, 0, -50924, 109, 0, 0, 39, '108'),
	(243, 1, 0, -50924, 110, 0, 0, 39, '109'),
	(243, 1, 0, -50924, 111, 0, 0, 39, '110'),
	(243, 1, 0, -50924, 112, 0, 0, 39, '111'),
	(243, 1, 0, -50924, 113, 0, 0, 39, '112'),
	(243, 1, 0, -50924, 114, 0, 0, 39, '113'),
	(243, 1, 0, -50924, 115, 0, 0, 39, '114'),
	(243, 1, 0, -50924, 116, 0, 0, 39, '115'),
	(243, 1, 0, -50924, 117, 0, 0, 39, '116'),
	(243, 1, 0, -50924, 118, 0, 0, 39, '117'),
	(243, 1, 0, -50924, 119, 0, 0, 39, '118'),
	(243, 1, 0, -50924, 120, 0, 0, 39, '119'),
	(243, 1, 0, -50924, 121, 0, 0, 39, '120'),
	(243, 1, 0, -50924, 122, 0, 0, 39, '121'),
	(243, 1, 0, -50924, 123, 0, 0, 39, '122'),
	(243, 1, 0, -50924, 124, 0, 0, 39, '123'),
	(243, 1, 0, -50924, 125, 0, 0, 39, '124'),
	(243, 1, 0, -50924, 126, 0, 0, 39, '125'),
	(243, 1, 0, -50924, 127, 0, 0, 39, '126'),
	(243, 1, 0, -50924, 128, 0, 0, 39, '127'),
	(243, 1, 0, -50924, 129, 0, 0, 39, '128'),
	(243, 1, 0, -50924, 130, 0, 0, 39, '129'),
	(243, 1, 0, -50924, 131, 0, 0, 39, '130'),
	(243, 1, 0, -50924, 132, 0, 0, 39, '131'),
	(243, 1, 0, -50924, 133, 0, 0, 39, '132'),
	(243, 1, 0, -50924, 134, 0, 0, 39, '133'),
	(243, 1, 0, -50924, 135, 0, 0, 39, '134'),
	(243, 1, 0, -50924, 136, 0, 0, 39, '135'),
	(243, 1, 0, -50924, 137, 0, 0, 39, '136'),
	(243, 1, 0, -50924, 138, 0, 0, 39, '137'),
	(243, 1, 0, -50924, 139, 0, 0, 39, '138'),
	(243, 1, 0, -50924, 140, 0, 0, 39, '139'),
	(243, 1, 0, -50924, 141, 0, 0, 39, '140'),
	(243, 1, 0, -50924, 142, 0, 0, 39, '141'),
	(243, 1, 0, -50924, 143, 0, 0, 39, '142'),
	(243, 1, 0, -50924, 144, 0, 0, 39, '143'),
	(243, 1, 0, -50924, 145, 0, 0, 39, '144'),
	(243, 1, 0, -50924, 146, 0, 0, 39, '145'),
	(243, 1, 0, -50924, 147, 0, 0, 39, '146'),
	(243, 1, 0, -50924, 148, 0, 0, 39, '147'),
	(243, 1, 0, -50924, 149, 0, 0, 39, '148'),
	(243, 1, 0, -50924, 150, 0, 0, 39, '149'),
	(243, 1, 0, -50924, 151, 0, 0, 39, '150'),
	(243, 1, 0, -50924, 152, 0, 0, 39, '151'),
	(243, 1, 0, -50924, 153, 0, 0, 39, '152'),
	(243, 1, 0, -50924, 154, 0, 0, 39, '153'),
	(243, 1, 0, -50924, 155, 0, 0, 39, '154'),
	(243, 1, 0, -50924, 156, 0, 0, 39, '155'),
	(243, 1, 0, -50924, 157, 0, 0, 39, '156'),
	(243, 1, 0, -50924, 158, 0, 0, 39, '157'),
	(243, 1, 0, -50924, 159, 0, 0, 39, '158'),
	(243, 1, 0, -50924, 160, 0, 0, 39, '159'),
	(243, 1, 0, -50924, 161, 0, 0, 39, '160'),
	(243, 1, 0, -50924, 162, 0, 0, 39, '161'),
	(243, 1, 0, -50924, 163, 0, 0, 39, '162'),
	(243, 1, 0, -50924, 164, 0, 0, 39, '163'),
	(243, 1, 0, -50924, 165, 0, 0, 39, '164'),
	(243, 1, 0, -50924, 166, 0, 0, 39, '165'),
	(243, 1, 0, -50924, 167, 0, 0, 39, '166'),
	(243, 1, 0, -50924, 168, 0, 0, 39, '167'),
	(243, 1, 0, -50924, 169, 0, 0, 39, '168'),
	(243, 1, 0, -50924, 170, 0, 0, 39, '169'),
	(243, 1, 0, -50924, 171, 0, 0, 39, '170'),
	(243, 1, 0, -50924, 172, 0, 0, 39, '171'),
	(243, 1, 0, -50924, 173, 0, 0, 39, '172'),
	(243, 1, 0, -50924, 174, 0, 0, 39, '173'),
	(243, 1, 0, -50924, 175, 0, 0, 39, '174'),
	(243, 1, 0, -50924, 176, 0, 0, 39, '175'),
	(243, 1, 0, -50924, 177, 0, 0, 39, '176'),
	(243, 1, 0, -50924, 178, 0, 0, 39, '177'),
	(243, 1, 0, -50924, 179, 0, 0, 39, '178'),
	(243, 1, 0, -50924, 180, 0, 0, 39, '179'),
	(243, 1, 0, -50924, 181, 0, 0, 39, '180'),
	(243, 1, 0, -50924, 182, 0, 0, 39, '181'),
	(243, 1, 0, -50924, 183, 0, 0, 39, '182'),
	(243, 1, 0, -50924, 184, 0, 0, 39, '183'),
	(243, 1, 0, -50924, 185, 0, 0, 39, '184'),
	(243, 1, 0, -50924, 186, 0, 0, 39, '185'),
	(243, 1, 0, -50924, 187, 0, 0, 39, '186'),
	(243, 1, 0, -50924, 188, 0, 0, 39, '187'),
	(243, 1, 0, -50924, 189, 0, 0, 39, '188'),
	(243, 1, 0, -50924, 190, 0, 0, 39, '189'),
	(243, 1, 0, -50924, 191, 0, 0, 39, '190'),
	(243, 1, 0, -50924, 192, 0, 0, 39, '191'),
	(243, 1, 0, -50924, 193, 0, 0, 39, '192'),
	(243, 1, 0, -50924, 194, 0, 0, 39, '193'),
	(243, 1, 0, -50924, 195, 0, 0, 39, '194'),
	(243, 1, 0, -50924, 196, 0, 0, 39, '195'),
	(243, 1, 0, -50924, 197, 0, 0, 39, '196'),
	(243, 1, 0, -50924, 198, 0, 0, 39, '197'),
	(243, 1, 0, -50924, 199, 0, 0, 39, '198'),
	(243, 1, 0, -50924, 200, 0, 0, 39, '199'),
	(243, 1, 0, -50924, 201, 0, 0, 39, '200'),
	(243, 1, 0, -50924, 202, 0, 0, 39, '201'),
	(243, 1, 0, -50924, 203, 0, 0, 39, '202'),
	(243, 1, 0, -50924, 204, 0, 0, 39, '203'),
	(243, 1, 0, -50924, 205, 0, 0, 39, '204'),
	(243, 1, 0, -50924, 206, 0, 0, 39, '205'),
	(243, 1, 0, -50924, 207, 0, 0, 39, '206'),
	(243, 1, 0, -50924, 208, 0, 0, 39, '207'),
	(243, 1, 0, -50924, 209, 0, 0, 39, '208'),
	(243, 1, 0, -50924, 210, 0, 0, 39, '209'),
	(243, 1, 0, -50924, 211, 0, 0, 39, '210'),
	(243, 1, 0, -50924, 212, 0, 0, 39, '211'),
	(243, 1, 0, -50924, 213, 0, 0, 39, '212'),
	(243, 1, 0, -50924, 214, 0, 0, 39, '213'),
	(243, 1, 0, -50924, 215, 0, 0, 39, '214'),
	(243, 1, 0, -50924, 216, 0, 0, 39, '215'),
	(243, 1, 0, -50924, 217, 0, 0, 39, '216'),
	(243, 1, 0, -50924, 218, 0, 0, 39, '217'),
	(243, 1, 0, -50924, 219, 0, 0, 39, '218'),
	(243, 1, 0, -50924, 220, 0, 0, 39, '219'),
	(243, 1, 0, -50924, 221, 0, 0, 39, '220'),
	(243, 1, 0, -50924, 222, 0, 0, 39, '221'),
	(243, 1, 0, -50924, 223, 0, 0, 39, '222'),
	(243, 1, 0, -50924, 224, 0, 0, 39, '223'),
	(243, 1, 0, -50924, 225, 0, 0, 39, '224'),
	(243, 1, 0, -50924, 226, 0, 0, 39, '225'),
	(243, 1, 0, -50924, 227, 0, 0, 39, '226'),
	(243, 1, 0, -50924, 228, 0, 0, 39, '227'),
	(243, 1, 0, -50924, 229, 0, 0, 39, '228'),
	(243, 1, 0, -50924, 230, 0, 0, 39, '229'),
	(243, 1, 0, -50924, 231, 0, 0, 39, '230'),
	(243, 1, 0, -50924, 232, 0, 0, 39, '231'),
	(243, 1, 0, -50924, 233, 0, 0, 39, '232'),
	(243, 1, 0, -50924, 234, 0, 0, 39, '233'),
	(243, 1, 0, -50924, 235, 0, 0, 39, '234'),
	(243, 1, 0, -50924, 236, 0, 0, 39, '235'),
	(243, 1, 0, -50924, 237, 0, 0, 39, '236'),
	(243, 1, 0, -50924, 238, 0, 0, 39, '237'),
	(243, 1, 0, -50924, 239, 0, 0, 39, '238'),
	(243, 1, 0, -50924, 240, 0, 0, 39, '239'),
	(243, 1, 0, -50924, 241, 0, 0, 39, '240'),
	(243, 1, 0, -50924, 242, 0, 0, 39, '241'),
	(243, 1, 0, -50924, 243, 0, 0, 39, '242'),
	(243, 1, 0, -50924, 244, 0, 0, 39, '243'),
	(243, 1, 0, -50924, 245, 0, 0, 39, '244'),
	(243, 1, 0, -50924, 246, 0, 0, 39, '245'),
	(243, 1, 0, -50924, 247, 0, 0, 39, '246'),
	(243, 1, 0, -50924, 248, 0, 0, 39, '247'),
	(243, 1, 0, -50924, 249, 0, 0, 39, '248'),
	(243, 1, 0, -50924, 250, 0, 0, 39, '249'),
	(243, 1, 0, -50924, 251, 0, 0, 39, '250'),
	(243, 1, 0, -50924, 252, 0, 0, 39, '251'),
	(243, 1, 0, -50924, 253, 0, 0, 39, '252'),
	(243, 1, 0, -50924, 254, 0, 0, 39, '253'),
	(243, 1, 0, -50924, 255, 0, 0, 39, '254'),
	(243, 1, 0, -50924, 256, 0, 0, 39, '255'),
	(243, 1, 0, -50924, 257, 0, 0, 39, '256'),
	(243, 1, 0, -50924, 258, 0, 0, 39, '257'),
	(243, 1, 0, -50924, 259, 0, 0, 39, '258'),
	(243, 1, 0, -50924, 260, 0, 0, 39, '259'),
	(243, 1, 0, -50924, 261, 0, 0, 39, '260'),
	(243, 1, 0, -50924, 262, 0, 0, 39, '261'),
	(243, 1, 0, -50924, 263, 0, 0, 39, '262'),
	(243, 1, 0, -50924, 264, 0, 0, 39, '263'),
	(243, 1, 0, -50924, 265, 0, 0, 39, '264'),
	(243, 1, 0, -50924, 266, 0, 0, 39, '265'),
	(243, 1, 0, -50924, 267, 0, 0, 39, '266'),
	(243, 1, 0, -50924, 268, 0, 0, 39, '267'),
	(243, 1, 0, -50924, 269, 0, 0, 39, '268'),
	(243, 1, 0, -50924, 270, 0, 0, 39, '269'),
	(243, 1, 0, -50924, 271, 0, 0, 39, '270'),
	(243, 1, 0, -50924, 272, 0, 0, 39, '271'),
	(243, 1, 0, -50924, 273, 0, 0, 39, '272'),
	(243, 1, 0, -50924, 274, 0, 0, 39, '273'),
	(243, 1, 0, -50924, 275, 0, 0, 39, '274'),
	(243, 1, 0, -50924, 276, 0, 0, 39, '275'),
	(243, 1, 0, -50924, 277, 0, 0, 39, '276'),
	(243, 1, 0, -50924, 278, 0, 0, 39, '277'),
	(243, 1, 0, -50924, 279, 0, 0, 39, '278'),
	(243, 1, 0, -50924, 280, 0, 0, 39, '279'),
	(243, 1, 0, -50924, 281, 0, 0, 39, '280'),
	(243, 1, 0, -50924, 282, 0, 0, 39, '281'),
	(243, 1, 0, -50924, 283, 0, 0, 39, '282'),
	(243, 1, 0, -50924, 284, 0, 0, 39, '283'),
	(243, 1, 0, -50924, 285, 0, 0, 39, '284'),
	(243, 1, 0, -50924, 286, 0, 0, 39, '285'),
	(243, 1, 0, -50924, 287, 0, 0, 39, '286'),
	(243, 1, 0, -50924, 288, 0, 0, 39, '287'),
	(243, 1, 0, -50924, 289, 0, 0, 39, '288'),
	(243, 1, 0, -50924, 290, 0, 0, 39, '289'),
	(243, 1, 0, -50924, 291, 0, 0, 39, '290'),
	(243, 1, 0, -50924, 292, 0, 0, 39, '291'),
	(243, 1, 0, -50924, 293, 0, 0, 39, '292'),
	(243, 1, 0, -50924, 294, 0, 0, 39, '293'),
	(243, 1, 0, -50924, 295, 0, 0, 39, '294'),
	(243, 1, 0, -50924, 296, 0, 0, 39, '295'),
	(243, 1, 0, -50924, 297, 0, 0, 39, '296'),
	(243, 1, 0, -50924, 298, 0, 0, 39, '297'),
	(243, 1, 0, -50924, 299, 0, 0, 39, '298'),
	(243, 1, 0, -50924, 300, 0, 0, 39, '299'),
	(243, 1, 0, -50924, 301, 0, 0, 39, '300'),
	(243, 1, 0, -50924, 302, 0, 0, 39, '301'),
	(243, 1, 0, -50924, 303, 0, 0, 39, '302'),
	(243, 1, 0, -50924, 304, 0, 0, 39, '303'),
	(243, 1, 0, -50924, 305, 0, 0, 39, '304'),
	(243, 1, 0, -50924, 306, 0, 0, 39, '305'),
	(243, 1, 0, -50924, 307, 0, 0, 39, '306'),
	(243, 1, 0, -50924, 308, 0, 0, 39, '307'),
	(243, 1, 0, -50924, 309, 0, 0, 39, '308'),
	(243, 1, 0, -50924, 310, 0, 0, 39, '309'),
	(243, 1, 0, -50924, 311, 0, 0, 39, '310'),
	(243, 1, 0, -50924, 312, 0, 0, 39, '311'),
	(243, 1, 0, -50924, 313, 0, 0, 39, '312'),
	(243, 1, 0, -50924, 314, 0, 0, 39, '313'),
	(243, 1, 0, -50924, 315, 0, 0, 39, '314'),
	(243, 1, 0, -50924, 316, 0, 0, 39, '315'),
	(243, 1, 0, -50924, 317, 0, 0, 39, '316'),
	(243, 1, 0, -50924, 318, 0, 0, 39, '317'),
	(243, 1, 0, -50924, 319, 0, 0, 39, '318'),
	(243, 1, 0, -50924, 320, 0, 0, 39, '319'),
	(243, 1, 0, -50924, 321, 0, 0, 39, '320'),
	(243, 1, 0, -50924, 322, 0, 0, 39, '321'),
	(243, 1, 0, -50924, 323, 0, 0, 39, '322'),
	(243, 1, 0, -50924, 324, 0, 0, 39, '323'),
	(243, 1, 0, -50924, 325, 0, 0, 39, '324'),
	(243, 1, 0, -50924, 326, 0, 0, 39, '325'),
	(243, 1, 0, -50924, 327, 0, 0, 39, '326'),
	(243, 1, 0, -50924, 328, 0, 0, 39, '327'),
	(243, 1, 0, -50924, 329, 0, 0, 39, '328'),
	(243, 1, 0, -50924, 330, 0, 0, 39, '329'),
	(243, 1, 0, -50924, 331, 0, 0, 39, '330'),
	(243, 1, 0, -50924, 332, 0, 0, 39, '331'),
	(243, 1, 0, -50924, 333, 0, 0, 39, '332'),
	(243, 1, 0, -50924, 334, 0, 0, 39, '333'),
	(243, 1, 0, -50924, 335, 0, 0, 39, '334'),
	(243, 1, 0, -50924, 336, 0, 0, 39, '335'),
	(243, 1, 0, -50924, 337, 0, 0, 39, '336'),
	(243, 1, 0, -50924, 338, 0, 0, 39, '337'),
	(243, 1, 0, -50924, 339, 0, 0, 39, '338'),
	(243, 1, 0, -50924, 340, 0, 0, 39, '339'),
	(243, 1, 0, -50924, 341, 0, 0, 39, '340'),
	(243, 1, 0, -50924, 342, 0, 0, 39, '341'),
	(243, 1, 0, -50924, 343, 0, 0, 39, '342'),
	(243, 1, 0, -50924, 344, 0, 0, 39, '343'),
	(243, 1, 0, -50924, 345, 0, 0, 39, '344'),
	(243, 1, 0, -50924, 346, 0, 0, 39, '345'),
	(243, 1, 0, -50924, 347, 0, 0, 39, '346'),
	(243, 1, 0, -50924, 348, 0, 0, 39, '347'),
	(243, 1, 0, -50924, 349, 0, 0, 39, '348'),
	(243, 1, 0, -50924, 350, 0, 0, 39, '349'),
	(243, 1, 0, -50924, 351, 0, 0, 39, '350'),
	(243, 1, 0, -50924, 352, 0, 0, 39, '351'),
	(243, 1, 0, -50924, 353, 0, 0, 39, '352'),
	(243, 1, 0, -50924, 354, 0, 0, 39, '353'),
	(243, 1, 0, -50924, 355, 0, 0, 39, '354'),
	(243, 1, 0, -50924, 356, 0, 0, 39, '355'),
	(243, 1, 0, -50924, 357, 0, 0, 39, '356'),
	(243, 1, 0, -50924, 358, 0, 0, 39, '357'),
	(243, 1, 0, -50924, 359, 0, 0, 39, '358'),
	(243, 1, 0, -50924, 360, 0, 0, 39, '359'),
	(243, 1, 0, -50924, 361, 0, 0, 39, '360'),
	(243, 1, 0, -50924, 362, 0, 0, 39, '361'),
	(243, 1, 0, -50924, 363, 0, 0, 39, '362'),
	(243, 1, 0, -50924, 364, 0, 0, 39, '363'),
	(243, 1, 0, -50924, 365, 0, 0, 39, '364'),
	(243, 1, 0, -50924, 366, 0, 0, 39, '365'),
	(243, 1, 0, -50924, 367, 0, 0, 39, '366'),
	(243, 1, 0, -50924, 368, 0, 0, 39, '367'),
	(243, 1, 0, -50924, 369, 0, 0, 39, '368'),
	(243, 1, 0, -50924, 370, 0, 0, 39, '369'),
	(243, 1, 0, -50924, 371, 0, 0, 39, '370'),
	(243, 1, 0, -50924, 372, 0, 0, 39, '371'),
	(243, 1, 0, -50924, 373, 0, 0, 39, '372'),
	(243, 1, 0, -50924, 374, 0, 0, 39, '373'),
	(243, 1, 0, -50924, 375, 0, 0, 39, '374'),
	(243, 1, 0, -50924, 376, 0, 0, 39, '375'),
	(243, 1, 0, -50924, 377, 0, 0, 39, '376'),
	(243, 1, 0, -50924, 378, 0, 0, 39, '377'),
	(243, 1, 0, -50924, 379, 0, 0, 39, '378'),
	(243, 1, 0, -50924, 380, 0, 0, 39, '379'),
	(243, 1, 0, -50924, 381, 0, 0, 39, '380'),
	(243, 1, 0, -50924, 382, 0, 0, 39, '381'),
	(243, 1, 0, -50924, 383, 0, 0, 39, '382'),
	(243, 1, 0, -50924, 384, 0, 0, 39, '383'),
	(243, 1, 0, -50924, 385, 0, 0, 39, '384'),
	(243, 1, 0, -50924, 386, 0, 0, 39, '385'),
	(243, 1, 0, -50924, 387, 0, 0, 39, '386'),
	(243, 1, 0, -50924, 388, 0, 0, 39, '387'),
	(243, 1, 0, -50924, 389, 0, 0, 39, '388'),
	(243, 1, 0, -50924, 390, 0, 0, 39, '389'),
	(243, 1, 0, -50924, 391, 0, 0, 39, '390'),
	(243, 1, 0, -50924, 392, 0, 0, 39, '391'),
	(243, 1, 0, -50924, 393, 0, 0, 39, '392'),
	(243, 1, 0, -50924, 394, 0, 0, 39, '393'),
	(243, 1, 0, -50924, 395, 0, 0, 39, '394'),
	(243, 1, 0, -50924, 396, 0, 0, 39, '395'),
	(243, 1, 0, -50924, 397, 0, 0, 39, '396'),
	(243, 1, 0, -50924, 398, 0, 0, 39, '397'),
	(243, 1, 0, -50924, 399, 0, 0, 39, '398'),
	(243, 1, 0, -50924, 400, 0, 0, 39, '399'),
	(243, 1, 0, -50924, 401, 0, 0, 39, '400'),
	(243, 1, 0, -50924, 402, 0, 0, 39, '401'),
	(243, 1, 0, -50924, 403, 0, 0, 39, '402'),
	(243, 1, 0, -50924, 404, 0, 0, 39, '403'),
	(243, 1, 0, -50924, 405, 0, 0, 39, '404'),
	(243, 1, 0, -50924, 406, 0, 0, 39, '405'),
	(243, 1, 0, -50924, 407, 0, 0, 39, '406'),
	(243, 1, 0, -50924, 408, 0, 0, 39, '407'),
	(243, 1, 0, -50924, 409, 0, 0, 39, '408'),
	(243, 1, 0, -50924, 410, 0, 0, 39, '409'),
	(243, 1, 0, -50924, 411, 0, 0, 39, '410'),
	(243, 1, 0, -50924, 412, 0, 0, 39, '411'),
	(243, 1, 0, -50924, 413, 0, 0, 39, '412'),
	(243, 1, 0, -50924, 414, 0, 0, 39, '413'),
	(243, 1, 0, -50924, 415, 0, 0, 39, '414'),
	(243, 1, 0, -50924, 416, 0, 0, 39, '415'),
	(243, 1, 0, -50924, 417, 0, 0, 39, '416'),
	(243, 1, 0, -50924, 418, 0, 0, 39, '417'),
	(243, 1, 0, -50924, 419, 0, 0, 39, '418'),
	(243, 1, 0, -50924, 420, 0, 0, 39, '419'),
	(243, 1, 0, -50924, 421, 0, 0, 39, '420'),
	(243, 1, 0, -50924, 422, 0, 0, 39, '421'),
	(243, 1, 0, -50924, 423, 0, 0, 39, '422'),
	(243, 1, 0, -50924, 424, 0, 0, 39, '423'),
	(243, 1, 0, -50924, 425, 0, 0, 39, '424'),
	(243, 1, 0, -50924, 426, 0, 0, 39, '425'),
	(243, 1, 0, -50924, 427, 0, 0, 39, '426'),
	(243, 1, 0, -50924, 428, 0, 0, 39, '427'),
	(243, 1, 0, -50924, 429, 0, 0, 39, '428'),
	(243, 1, 0, -50924, 430, 0, 0, 39, '429'),
	(243, 1, 0, -50924, 431, 0, 0, 39, '430'),
	(243, 1, 0, -50924, 432, 0, 0, 39, '431'),
	(243, 1, 0, -50924, 433, 0, 0, 39, '432'),
	(243, 1, 0, -50924, 434, 0, 0, 39, '433'),
	(243, 1, 0, -50924, 435, 0, 0, 39, '434'),
	(243, 1, 0, -50924, 436, 0, 0, 39, '435'),
	(243, 1, 0, -50924, 437, 0, 0, 39, '436'),
	(243, 1, 0, -50924, 438, 0, 0, 39, '437'),
	(243, 1, 0, -50924, 439, 0, 0, 39, '438'),
	(243, 1, 0, -50924, 440, 0, 0, 39, '439'),
	(243, 1, 0, -50924, 441, 0, 0, 39, '440'),
	(243, 1, 0, -50924, 442, 0, 0, 39, '441'),
	(243, 1, 0, -50924, 443, 0, 0, 39, '442'),
	(243, 1, 0, -50924, 444, 0, 0, 39, '443'),
	(243, 1, 0, -50924, 445, 0, 0, 39, '444'),
	(243, 1, 0, -50924, 446, 0, 0, 39, '445'),
	(243, 1, 0, -50924, 447, 0, 0, 39, '446'),
	(243, 1, 0, -50924, 448, 0, 0, 39, '447'),
	(243, 1, 0, -50924, 449, 0, 0, 39, '448'),
	(243, 1, 0, -50924, 450, 0, 0, 39, '449'),
	(243, 1, 0, -50924, 451, 0, 0, 39, '450'),
	(243, 1, 0, -50924, 452, 0, 0, 39, '451'),
	(243, 1, 0, -50924, 453, 0, 0, 39, '452'),
	(243, 1, 0, -50924, 454, 0, 0, 39, '453'),
	(243, 1, 0, -50924, 455, 0, 0, 39, '454'),
	(243, 1, 0, -50924, 456, 0, 0, 39, '455'),
	(243, 1, 0, -50924, 457, 0, 0, 39, '456'),
	(243, 1, 0, -50924, 458, 0, 0, 39, '457'),
	(243, 1, 0, -50924, 459, 0, 0, 39, '458'),
	(243, 1, 0, -50924, 460, 0, 0, 39, '459'),
	(243, 1, 0, -50924, 461, 0, 0, 39, '460'),
	(243, 1, 0, -50924, 462, 0, 0, 39, '461'),
	(243, 1, 0, -50924, 463, 0, 0, 39, '462'),
	(243, 1, 0, -50924, 464, 0, 0, 39, '463'),
	(243, 1, 0, -50924, 465, 0, 0, 39, '464'),
	(243, 1, 0, -50924, 466, 0, 0, 39, '465'),
	(243, 1, 0, -50924, 467, 0, 0, 39, '466'),
	(243, 1, 0, -50924, 468, 0, 0, 39, '467'),
	(243, 1, 0, -50924, 469, 0, 0, 39, '468'),
	(243, 1, 0, -50924, 470, 0, 0, 39, '469'),
	(243, 1, 0, -50924, 471, 0, 0, 39, '470'),
	(243, 1, 0, -50924, 472, 0, 0, 39, '471'),
	(243, 1, 0, -50924, 473, 0, 0, 39, '472'),
	(243, 1, 0, -50924, 474, 0, 0, 39, '473'),
	(243, 1, 0, -50924, 475, 0, 0, 39, '474'),
	(243, 1, 0, -50924, 476, 0, 0, 39, '475'),
	(243, 1, 0, -50924, 477, 0, 0, 39, '476'),
	(243, 1, 0, -50924, 478, 0, 0, 39, '477'),
	(243, 1, 0, -50924, 479, 0, 0, 39, '478'),
	(243, 1, 0, -50924, 480, 0, 0, 39, '479'),
	(243, 1, 0, -50924, 481, 0, 0, 39, '480'),
	(243, 1, 0, -50924, 482, 0, 0, 39, '481'),
	(243, 1, 0, -50924, 483, 0, 0, 39, '482'),
	(243, 1, 0, -50924, 484, 0, 0, 39, '483'),
	(243, 1, 0, -50924, 485, 0, 0, 39, '484'),
	(243, 1, 0, -50924, 486, 0, 0, 39, '485'),
	(243, 1, 0, -50924, 487, 0, 0, 39, '486'),
	(243, 1, 0, -50924, 488, 0, 0, 39, '487'),
	(243, 1, 0, -50924, 489, 0, 0, 39, '488'),
	(243, 1, 0, -50924, 490, 0, 0, 39, '489'),
	(243, 1, 0, -50924, 491, 0, 0, 39, '490'),
	(243, 1, 0, -50924, 492, 0, 0, 39, '491'),
	(243, 1, 0, -50924, 493, 0, 0, 39, '492'),
	(243, 1, 0, -50924, 494, 0, 0, 39, '493'),
	(243, 1, 0, -50924, 495, 0, 0, 39, '494'),
	(243, 1, 0, -50924, 496, 0, 0, 39, '495'),
	(243, 1, 0, -50924, 497, 0, 0, 39, '496'),
	(243, 1, 0, -50924, 498, 0, 0, 39, '497'),
	(243, 1, 0, -50924, 499, 0, 0, 39, '498'),
	(243, 1, 0, -50924, 500, 0, 0, 39, '499'),
	(243, 1, 0, -50924, 501, 0, 0, 39, '500'),
	(243, 1, 0, -50924, 502, 0, 0, 39, '501'),
	(243, 1, 0, -50924, 503, 0, 0, 39, '502'),
	(243, 1, 0, -50924, 504, 0, 0, 39, '503'),
	(243, 1, 0, -50924, 505, 0, 0, 39, '504'),
	(243, 1, 0, -50924, 506, 0, 0, 39, '505'),
	(243, 1, 0, -50924, 507, 0, 0, 39, '506'),
	(243, 1, 0, -50924, 508, 0, 0, 39, '507'),
	(243, 1, 0, -50924, 509, 0, 0, 39, '508'),
	(243, 1, 0, -50924, 510, 0, 0, 39, '509'),
	(243, 1, 0, -50924, 511, 0, 0, 39, '510'),
	(243, 1, 0, -50924, 512, 0, 0, 39, '511'),
	(243, 1, 0, -50924, 513, 0, 0, 39, '512'),
	(243, 1, 0, -50924, 514, 0, 0, 39, '513'),
	(243, 1, 0, -50924, 515, 0, 0, 39, '514'),
	(243, 1, 0, -50924, 516, 0, 0, 39, '515'),
	(243, 1, 0, -50924, 517, 0, 0, 39, '516'),
	(243, 1, 0, -50924, 518, 0, 0, 39, '517'),
	(243, 1, 0, -50924, 519, 0, 0, 39, '518'),
	(243, 1, 0, -50924, 520, 0, 0, 39, '519'),
	(243, 1, 0, -50924, 521, 0, 0, 39, '520'),
	(243, 1, 0, -50924, 522, 0, 0, 39, '521'),
	(243, 1, 0, -50924, 523, 0, 0, 39, '522'),
	(243, 1, 0, -50924, 524, 0, 0, 39, '523'),
	(243, 1, 0, -50924, 525, 0, 0, 39, '524'),
	(243, 1, 0, -50924, 526, 0, 0, 39, '525'),
	(243, 1, 0, -50924, 527, 0, 0, 39, '526'),
	(243, 1, 0, -50924, 528, 0, 0, 39, '527'),
	(243, 1, 0, -50924, 529, 0, 0, 39, '528'),
	(243, 1, 0, -50924, 530, 0, 0, 39, '529'),
	(243, 1, 0, -50924, 531, 0, 0, 39, '530'),
	(243, 1, 0, -50924, 532, 0, 0, 39, '531'),
	(243, 1, 0, -50924, 533, 0, 0, 39, '532'),
	(243, 1, 0, -50924, 534, 0, 0, 39, '533'),
	(243, 1, 0, -50924, 535, 0, 0, 39, '534'),
	(243, 1, 0, -50924, 536, 0, 0, 39, '535'),
	(243, 1, 0, -50924, 537, 0, 0, 39, '536'),
	(243, 1, 0, -50924, 538, 0, 0, 39, '537'),
	(243, 1, 0, -50924, 539, 0, 0, 39, '538'),
	(243, 1, 0, -50924, 540, 0, 0, 39, '539'),
	(243, 1, 0, -50924, 541, 0, 0, 39, '540'),
	(243, 1, 0, -50924, 542, 0, 0, 39, '541'),
	(243, 1, 0, -50924, 543, 0, 0, 39, '542'),
	(243, 1, 0, -50924, 544, 0, 0, 39, '543'),
	(243, 1, 0, -50924, 545, 0, 0, 39, '544'),
	(243, 1, 0, -50924, 546, 0, 0, 39, '545'),
	(243, 1, 0, -50924, 547, 0, 0, 39, '546'),
	(243, 1, 0, -50924, 548, 0, 0, 39, '547'),
	(243, 1, 0, -50924, 549, 0, 0, 39, '548'),
	(243, 1, 0, -50924, 550, 0, 0, 39, '549'),
	(243, 1, 0, -50924, 551, 0, 0, 39, '550'),
	(243, 1, 0, -50924, 552, 0, 0, 39, '551'),
	(243, 1, 0, -50924, 553, 0, 0, 39, '552'),
	(243, 1, 0, -50924, 554, 0, 0, 39, '553'),
	(243, 1, 0, -50924, 555, 0, 0, 39, '554'),
	(243, 1, 0, -50924, 556, 0, 0, 39, '555'),
	(243, 1, 0, -50924, 557, 0, 0, 39, '556'),
	(243, 1, 0, -50924, 558, 0, 0, 39, '557'),
	(243, 1, 0, -50924, 559, 0, 0, 39, '558'),
	(243, 1, 0, -50924, 560, 0, 0, 39, '559'),
	(243, 1, 0, -50924, 561, 0, 0, 39, '560'),
	(243, 1, 0, -50924, 562, 0, 0, 39, '561'),
	(243, 1, 0, -50924, 563, 0, 0, 39, '562'),
	(243, 1, 0, -50924, 564, 0, 0, 39, '563'),
	(243, 1, 0, -50924, 565, 0, 0, 39, '564'),
	(243, 1, 0, -50924, 566, 0, 0, 39, '565'),
	(243, 1, 0, -50924, 567, 0, 0, 39, '566'),
	(243, 1, 0, -50924, 568, 0, 0, 39, '567'),
	(243, 1, 0, -50924, 569, 0, 0, 39, '568'),
	(243, 1, 0, -50924, 570, 0, 0, 39, '569'),
	(243, 1, 0, -50924, 571, 0, 0, 39, '570'),
	(243, 1, 0, -50924, 572, 0, 0, 39, '571'),
	(243, 1, 0, -50924, 573, 0, 0, 39, '572'),
	(243, 1, 0, -50924, 574, 0, 0, 39, '573'),
	(243, 1, 0, -50924, 575, 0, 0, 39, '574'),
	(243, 1, 0, -50924, 576, 0, 0, 39, '575'),
	(243, 1, 0, -50924, 577, 0, 0, 39, '576'),
	(243, 1, 0, -50924, 578, 0, 0, 39, '577'),
	(243, 1, 0, -50924, 579, 0, 0, 39, '578'),
	(243, 1, 0, -50924, 580, 0, 0, 39, '579'),
	(243, 1, 0, -50924, 581, 0, 0, 39, '580'),
	(243, 1, 0, -50924, 582, 0, 0, 39, '581'),
	(243, 1, 0, -50924, 583, 0, 0, 39, '582'),
	(243, 1, 0, -50924, 584, 0, 0, 39, '583'),
	(243, 1, 0, -50924, 585, 0, 0, 39, '584'),
	(243, 1, 0, -50924, 586, 0, 0, 39, '585'),
	(243, 1, 0, -50924, 587, 0, 0, 39, '586'),
	(243, 1, 0, -50924, 588, 0, 0, 39, '587'),
	(243, 1, 0, -50924, 589, 0, 0, 39, '588'),
	(243, 1, 0, -50924, 590, 0, 0, 39, '589'),
	(243, 1, 0, -50924, 591, 0, 0, 39, '590'),
	(243, 1, 0, -50924, 592, 0, 0, 39, '591'),
	(243, 1, 0, -50924, 593, 0, 0, 39, '592'),
	(243, 1, 0, -50924, 594, 0, 0, 39, '593'),
	(243, 1, 0, -50924, 595, 0, 0, 39, '594'),
	(243, 1, 0, -50924, 596, 0, 0, 39, '595'),
	(243, 1, 0, -50924, 597, 0, 0, 39, '596'),
	(243, 1, 0, -50924, 598, 0, 0, 39, '597'),
	(243, 1, 0, -50924, 599, 0, 0, 39, '598'),
	(243, 1, 0, -50924, 600, 0, 0, 39, '599'),
	(243, 1, 0, -50924, 601, 0, 0, 39, '600'),
	(243, 1, 0, -50924, 602, 0, 0, 39, '601'),
	(243, 1, 0, -50924, 603, 0, 0, 39, '602'),
	(243, 1, 0, -50924, 604, 0, 0, 39, '603'),
	(243, 1, 0, -50924, 605, 0, 0, 39, '604'),
	(243, 1, 0, -50924, 606, 0, 0, 39, '605'),
	(243, 1, 0, -50924, 607, 0, 0, 39, '606'),
	(243, 1, 0, -50924, 608, 0, 0, 39, '607'),
	(243, 1, 0, -50924, 609, 0, 0, 39, '608'),
	(243, 1, 0, -50924, 610, 0, 0, 39, '609'),
	(243, 1, 0, -50924, 611, 0, 0, 39, '610'),
	(243, 1, 0, -50924, 612, 0, 0, 39, '611'),
	(243, 1, 0, -50924, 613, 0, 0, 39, '612'),
	(243, 1, 0, -50924, 614, 0, 0, 39, '613'),
	(243, 1, 0, -50924, 615, 0, 0, 39, '614'),
	(243, 1, 0, -50924, 616, 0, 0, 39, '615'),
	(243, 1, 0, -50924, 617, 0, 0, 39, '616'),
	(243, 1, 0, -50924, 618, 0, 0, 39, '617'),
	(243, 1, 0, -50924, 619, 0, 0, 39, '618'),
	(243, 1, 0, -50924, 620, 0, 0, 39, '619'),
	(243, 1, 0, -50924, 621, 0, 0, 39, '620'),
	(243, 1, 0, -50924, 622, 0, 0, 39, '621'),
	(243, 1, 0, -50924, 623, 0, 0, 39, '622'),
	(243, 1, 0, -50924, 624, 0, 0, 39, '623'),
	(243, 1, 0, -50924, 625, 0, 0, 39, '624'),
	(243, 1, 0, -50924, 626, 0, 0, 39, '625'),
	(243, 1, 0, -50924, 627, 0, 0, 39, '626'),
	(243, 1, 0, -50924, 628, 0, 0, 39, '627'),
	(243, 1, 0, -50924, 629, 0, 0, 39, '628'),
	(243, 1, 0, -50924, 630, 0, 0, 39, '629'),
	(243, 1, 0, -50924, 631, 0, 0, 39, '630'),
	(243, 1, 0, -50924, 632, 0, 0, 39, '631'),
	(243, 1, 0, -50924, 633, 0, 0, 39, '632'),
	(243, 1, 0, -50924, 634, 0, 0, 39, '633'),
	(243, 1, 0, -50924, 635, 0, 0, 39, '634'),
	(243, 1, 0, -50924, 636, 0, 0, 39, '635'),
	(243, 1, 0, -50924, 637, 0, 0, 39, '636'),
	(243, 1, 0, -50924, 638, 0, 0, 39, '637'),
	(243, 1, 0, -50924, 639, 0, 0, 39, '638'),
	(243, 1, 0, -50924, 640, 0, 0, 39, '639'),
	(243, 1, 0, -50924, 641, 0, 0, 39, '640'),
	(243, 1, 0, -50924, 642, 0, 0, 39, '641'),
	(243, 1, 0, -50924, 643, 0, 0, 39, '642'),
	(243, 1, 0, -50924, 644, 0, 0, 39, '643'),
	(243, 1, 0, -50924, 645, 0, 0, 39, '644'),
	(243, 1, 0, -50924, 646, 0, 0, 39, '645'),
	(243, 1, 0, -50924, 647, 0, 0, 39, '646'),
	(243, 1, 0, -50924, 648, 0, 0, 39, '647'),
	(243, 1, 0, -50924, 649, 0, 0, 39, '648'),
	(243, 1, 0, -50924, 650, 0, 0, 39, '649'),
	(243, 1, 0, -50924, 651, 0, 0, 39, '650'),
	(243, 1, 0, -50924, 652, 0, 0, 39, '651'),
	(243, 1, 0, -50924, 653, 0, 0, 39, '652'),
	(243, 1, 0, -50924, 654, 0, 0, 39, '653'),
	(243, 1, 0, -50924, 655, 0, 0, 39, '654'),
	(243, 1, 0, -50924, 656, 0, 0, 39, '655'),
	(243, 1, 0, -50924, 657, 0, 0, 39, '656'),
	(243, 1, 0, -50924, 658, 0, 0, 39, '657'),
	(243, 1, 0, -50924, 659, 0, 0, 39, '658'),
	(243, 1, 0, -50924, 660, 0, 0, 39, '659'),
	(243, 1, 0, -50924, 661, 0, 0, 39, '660'),
	(243, 1, 0, -50924, 662, 0, 0, 39, '661'),
	(243, 1, 0, -50924, 663, 0, 0, 39, '662'),
	(243, 1, 0, -50924, 664, 0, 0, 39, '663'),
	(243, 1, 0, -50924, 665, 0, 0, 39, '664'),
	(243, 1, 0, -50924, 666, 0, 0, 39, '665'),
	(243, 1, 0, -50924, 667, 0, 0, 39, '666'),
	(243, 1, 0, -50924, 668, 0, 0, 39, '667'),
	(243, 1, 0, -50924, 669, 0, 0, 39, '668'),
	(243, 1, 0, -50924, 670, 0, 0, 39, '669'),
	(243, 1, 0, -50924, 671, 0, 0, 39, '670'),
	(243, 1, 0, -50924, 672, 0, 0, 39, '671'),
	(243, 1, 0, -50924, 673, 0, 0, 39, '672'),
	(243, 1, 0, -50924, 674, 0, 0, 39, '673'),
	(243, 1, 0, -50924, 675, 0, 0, 39, '674'),
	(243, 1, 0, -50924, 676, 0, 0, 39, '675'),
	(243, 1, 0, -50924, 677, 0, 0, 39, '676'),
	(243, 1, 0, -50924, 678, 0, 0, 39, '677'),
	(243, 1, 0, -50924, 679, 0, 0, 39, '678'),
	(243, 1, 0, -50924, 680, 0, 0, 39, '679'),
	(243, 1, 0, -50924, 681, 0, 0, 39, '680'),
	(243, 1, 0, -50924, 682, 0, 0, 39, '681'),
	(243, 1, 0, -50924, 683, 0, 0, 39, '682'),
	(243, 1, 0, -50924, 684, 0, 0, 39, '683'),
	(243, 1, 0, -50924, 685, 0, 0, 39, '684'),
	(243, 1, 0, -50924, 686, 0, 0, 39, '685'),
	(243, 1, 0, -50924, 687, 0, 0, 39, '686'),
	(243, 1, 0, -50924, 688, 0, 0, 39, '687'),
	(243, 1, 0, -50924, 689, 0, 0, 39, '688'),
	(243, 1, 0, -50924, 690, 0, 0, 39, '689'),
	(243, 1, 0, -50924, 691, 0, 0, 39, '690'),
	(243, 1, 0, -50924, 692, 0, 0, 39, '691'),
	(243, 1, 0, -50924, 693, 0, 0, 39, '692'),
	(243, 1, 0, -50924, 694, 0, 0, 39, '693'),
	(243, 1, 0, -50924, 695, 0, 0, 39, '694'),
	(243, 1, 0, -50924, 696, 0, 0, 39, '695'),
	(243, 1, 0, -50924, 697, 0, 0, 39, '696'),
	(243, 1, 0, -50924, 698, 0, 0, 39, '697'),
	(243, 1, 0, -50924, 699, 0, 0, 39, '698'),
	(243, 1, 0, -50924, 700, 0, 0, 39, '699'),
	(243, 1, 0, -50924, 701, 0, 0, 39, '700'),
	(243, 1, 0, -50924, 702, 0, 0, 39, '701'),
	(243, 1, 0, -50924, 703, 0, 0, 39, '702'),
	(243, 1, 0, -50924, 704, 0, 0, 39, '703'),
	(243, 1, 0, -50924, 705, 0, 0, 39, '704'),
	(243, 1, 0, -50924, 706, 0, 0, 39, '705'),
	(243, 1, 0, -50924, 707, 0, 0, 39, '706'),
	(243, 1, 0, -50924, 708, 0, 0, 39, '707'),
	(243, 1, 0, -50924, 709, 0, 0, 39, '708'),
	(243, 1, 0, -50924, 710, 0, 0, 39, '709'),
	(243, 1, 0, -50924, 711, 0, 0, 39, '710'),
	(243, 1, 0, -50924, 712, 0, 0, 39, '711'),
	(243, 1, 0, -50924, 713, 0, 0, 39, '712'),
	(243, 1, 0, -50924, 714, 0, 0, 39, '713'),
	(243, 1, 0, -50924, 715, 0, 0, 39, '714'),
	(243, 1, 0, -50924, 716, 0, 0, 39, '715'),
	(243, 1, 0, -50924, 717, 0, 0, 39, '716'),
	(243, 1, 0, -50924, 718, 0, 0, 39, '717'),
	(243, 1, 0, -50924, 719, 0, 0, 39, '718'),
	(243, 1, 0, -50924, 720, 0, 0, 39, '719'),
	(243, 1, 0, -50924, 721, 0, 0, 39, '720'),
	(243, 1, 0, -50924, 722, 0, 0, 39, '721'),
	(243, 1, 0, -50924, 723, 0, 0, 39, '722'),
	(243, 1, 0, -50924, 724, 0, 0, 39, '723'),
	(243, 1, 0, -50924, 725, 0, 0, 39, '724'),
	(243, 1, 0, -50924, 726, 0, 0, 39, '725'),
	(243, 1, 0, -50924, 727, 0, 0, 39, '726'),
	(243, 1, 0, -50924, 728, 0, 0, 39, '727'),
	(243, 1, 0, -50924, 729, 0, 0, 39, '728'),
	(243, 1, 0, -50924, 730, 0, 0, 39, '729'),
	(243, 1, 0, -50924, 731, 0, 0, 39, '730'),
	(243, 1, 0, -50924, 732, 0, 0, 39, '731'),
	(243, 1, 0, -50924, 733, 0, 0, 39, '732'),
	(243, 1, 0, -50924, 734, 0, 0, 39, '733'),
	(243, 1, 0, -50924, 735, 0, 0, 39, '734'),
	(243, 1, 0, -50924, 736, 0, 0, 39, '735'),
	(243, 1, 0, -50924, 737, 0, 0, 39, '736'),
	(243, 1, 0, -50924, 738, 0, 0, 39, '737'),
	(243, 1, 0, -50924, 739, 0, 0, 39, '738'),
	(243, 1, 0, -50924, 740, 0, 0, 39, '739'),
	(243, 1, 0, -50924, 741, 0, 0, 39, '740'),
	(243, 1, 0, -50924, 742, 0, 0, 39, '741'),
	(243, 1, 0, -50924, 743, 0, 0, 39, '742'),
	(243, 1, 0, -50924, 744, 0, 0, 39, '743'),
	(243, 1, 0, -50924, 745, 0, 0, 39, '744'),
	(243, 1, 0, -50924, 746, 0, 0, 39, '745'),
	(243, 1, 0, -50924, 747, 0, 0, 39, '746'),
	(243, 1, 0, -50924, 748, 0, 0, 39, '747'),
	(243, 1, 0, -50924, 749, 0, 0, 39, '748'),
	(243, 1, 0, -50924, 750, 0, 0, 39, '749'),
	(243, 1, 0, -50924, 751, 0, 0, 39, '750'),
	(243, 1, 0, -50924, 752, 0, 0, 39, '751'),
	(243, 1, 0, -50924, 753, 0, 0, 39, '752'),
	(243, 1, 0, -50924, 754, 0, 0, 39, '753'),
	(243, 1, 0, -50924, 755, 0, 0, 39, '754'),
	(243, 1, 0, -50924, 756, 0, 0, 39, '755'),
	(243, 1, 0, -50924, 757, 0, 0, 39, '756'),
	(243, 1, 0, -50924, 758, 0, 0, 39, '757'),
	(243, 1, 0, -50924, 759, 0, 0, 39, '758'),
	(243, 1, 0, -50924, 760, 0, 0, 39, '759'),
	(243, 1, 0, -50924, 761, 0, 0, 39, '760'),
	(243, 1, 0, -50924, 762, 0, 0, 39, '761'),
	(243, 1, 0, -50924, 763, 0, 0, 39, '762'),
	(243, 1, 0, -50924, 764, 0, 0, 39, '763'),
	(243, 1, 0, -50924, 765, 0, 0, 39, '764'),
	(243, 1, 0, -50924, 766, 0, 0, 39, '765'),
	(243, 1, 0, -50924, 767, 0, 0, 39, '766'),
	(243, 1, 0, -50924, 768, 0, 0, 39, '767'),
	(243, 1, 0, -50924, 769, 0, 0, 39, '768'),
	(243, 1, 0, -50924, 770, 0, 0, 39, '769'),
	(243, 1, 0, -50924, 771, 0, 0, 39, '770'),
	(243, 1, 0, -50924, 772, 0, 0, 39, '771'),
	(243, 1, 0, -50924, 773, 0, 0, 39, '772'),
	(243, 1, 0, -50924, 774, 0, 0, 39, '773'),
	(243, 1, 0, -50924, 775, 0, 0, 39, '774'),
	(243, 1, 0, -50924, 776, 0, 0, 39, '775'),
	(243, 1, 0, -50924, 777, 0, 0, 39, '776'),
	(243, 1, 0, -50924, 778, 0, 0, 39, '777'),
	(243, 1, 0, -50924, 779, 0, 0, 39, '778'),
	(243, 1, 0, -50924, 780, 0, 0, 39, '779'),
	(243, 1, 0, -50924, 781, 0, 0, 39, '780'),
	(243, 1, 0, -50924, 782, 0, 0, 39, '781'),
	(243, 1, 0, -50924, 783, 0, 0, 39, '782'),
	(243, 1, 0, -50924, 784, 0, 0, 39, '783'),
	(243, 1, 0, -50924, 785, 0, 0, 39, '784'),
	(243, 1, 0, -50924, 786, 0, 0, 39, '785'),
	(243, 1, 0, -50924, 787, 0, 0, 39, '786'),
	(243, 1, 0, -50924, 788, 0, 0, 39, '787'),
	(243, 1, 0, -50924, 789, 0, 0, 39, '788'),
	(243, 1, 0, -50924, 790, 0, 0, 39, '789'),
	(243, 1, 0, -50924, 791, 0, 0, 39, '790'),
	(243, 1, 0, -50924, 792, 0, 0, 39, '791'),
	(243, 1, 0, -50924, 793, 0, 0, 39, '792'),
	(243, 1, 0, -50924, 794, 0, 0, 39, '793'),
	(243, 1, 0, -50924, 795, 0, 0, 39, '794'),
	(243, 1, 0, -50924, 796, 0, 0, 39, '795'),
	(243, 1, 0, -50924, 797, 0, 0, 39, '796'),
	(243, 1, 0, -50924, 798, 0, 0, 39, '797'),
	(243, 1, 0, -50924, 799, 0, 0, 39, '798'),
	(243, 1, 0, -50924, 800, 0, 0, 39, '799'),
	(243, 1, 0, -50924, 801, 0, 0, 39, '800'),
	(243, 1, 0, -50924, 802, 0, 0, 39, '801'),
	(243, 1, 0, -50924, 803, 0, 0, 39, '802'),
	(243, 1, 0, -50924, 804, 0, 0, 39, '803'),
	(243, 1, 0, -50924, 805, 0, 0, 39, '804'),
	(243, 1, 0, -50924, 806, 0, 0, 39, '805'),
	(243, 1, 0, -50924, 807, 0, 0, 39, '806'),
	(243, 1, 0, -50924, 808, 0, 0, 39, '807'),
	(243, 1, 0, -50924, 809, 0, 0, 39, '808'),
	(243, 1, 0, -50924, 810, 0, 0, 39, '809'),
	(243, 1, 0, -50924, 811, 0, 0, 39, '810'),
	(243, 1, 0, -50924, 812, 0, 0, 39, '811'),
	(243, 1, 0, -50924, 813, 0, 0, 39, '812'),
	(243, 1, 0, -50924, 814, 0, 0, 39, '813'),
	(243, 1, 0, -50924, 815, 0, 0, 39, '814'),
	(243, 1, 0, -50924, 816, 0, 0, 39, '815'),
	(243, 1, 0, -50924, 817, 0, 0, 39, '816'),
	(243, 1, 0, -50924, 818, 0, 0, 39, '817'),
	(243, 1, 0, -50924, 819, 0, 0, 39, '818'),
	(243, 1, 0, -50924, 820, 0, 0, 39, '819'),
	(243, 1, 0, -50924, 821, 0, 0, 39, '820'),
	(243, 1, 0, -50924, 822, 0, 0, 39, '821'),
	(243, 1, 0, -50924, 823, 0, 0, 39, '822'),
	(243, 1, 0, -50924, 824, 0, 0, 39, '823'),
	(243, 1, 0, -50924, 825, 0, 0, 39, '824'),
	(243, 1, 0, -50924, 826, 0, 0, 39, '825'),
	(243, 1, 0, -50924, 827, 0, 0, 39, '826'),
	(243, 1, 0, -50924, 828, 0, 0, 39, '827'),
	(243, 1, 0, -50924, 829, 0, 0, 39, '828'),
	(243, 1, 0, -50924, 830, 0, 0, 39, '829'),
	(243, 1, 0, -50924, 831, 0, 0, 39, '830'),
	(243, 1, 0, -50924, 832, 0, 0, 39, '831'),
	(243, 1, 0, -50924, 833, 0, 0, 39, '832'),
	(243, 1, 0, -50924, 834, 0, 0, 39, '833'),
	(243, 1, 0, -50924, 835, 0, 0, 39, '834'),
	(243, 1, 0, -50924, 836, 0, 0, 39, '835'),
	(243, 1, 0, -50924, 837, 0, 0, 39, '836'),
	(243, 1, 0, -50924, 838, 0, 0, 39, '837'),
	(243, 1, 0, -50924, 839, 0, 0, 39, '838'),
	(243, 1, 0, -50924, 840, 0, 0, 39, '839'),
	(243, 1, 0, -50924, 841, 0, 0, 39, '840'),
	(243, 1, 0, -50924, 842, 0, 0, 39, '841'),
	(243, 1, 0, -50924, 843, 0, 0, 39, '842'),
	(243, 1, 0, -50924, 844, 0, 0, 39, '843'),
	(243, 1, 0, -50924, 845, 0, 0, 39, '844'),
	(243, 1, 0, -50924, 846, 0, 0, 39, '845'),
	(243, 1, 0, -50924, 847, 0, 0, 39, '846'),
	(243, 1, 0, -50924, 848, 0, 0, 39, '847'),
	(243, 1, 0, -50924, 849, 0, 0, 39, '848'),
	(243, 1, 0, -50924, 850, 0, 0, 39, '849'),
	(243, 1, 0, -50924, 851, 0, 0, 39, '850'),
	(243, 1, 0, -50924, 852, 0, 0, 39, '851'),
	(243, 1, 0, -50924, 853, 0, 0, 39, '852'),
	(243, 1, 0, -50924, 854, 0, 0, 39, '853'),
	(243, 1, 0, -50924, 855, 0, 0, 39, '854'),
	(243, 1, 0, -50924, 856, 0, 0, 39, '855'),
	(243, 1, 0, -50924, 857, 0, 0, 39, '856'),
	(243, 1, 0, -50924, 858, 0, 0, 39, '857'),
	(243, 1, 0, -50924, 859, 0, 0, 39, '858'),
	(243, 1, 0, -50924, 860, 0, 0, 39, '859'),
	(243, 1, 0, -50924, 861, 0, 0, 39, '860'),
	(243, 1, 0, -50924, 862, 0, 0, 39, '861'),
	(243, 1, 0, -50924, 863, 0, 0, 39, '862'),
	(243, 1, 0, -50924, 864, 0, 0, 39, '863'),
	(243, 1, 0, -50924, 865, 0, 0, 39, '864'),
	(243, 1, 0, -50924, 866, 0, 0, 39, '865'),
	(243, 1, 0, -50924, 867, 0, 0, 39, '866'),
	(243, 1, 0, -50924, 868, 0, 0, 39, '867'),
	(243, 1, 0, -50924, 869, 0, 0, 39, '868'),
	(243, 1, 0, -50924, 870, 0, 0, 39, '869'),
	(243, 1, 0, -50924, 871, 0, 0, 39, '870'),
	(243, 1, 0, -50924, 872, 0, 0, 39, '871'),
	(243, 1, 0, -50924, 873, 0, 0, 39, '872'),
	(243, 1, 0, -50924, 874, 0, 0, 39, '873'),
	(243, 1, 0, -50924, 875, 0, 0, 39, '874'),
	(243, 1, 0, -50924, 876, 0, 0, 39, '875'),
	(243, 1, 0, -50924, 877, 0, 0, 39, '876'),
	(243, 1, 0, -50924, 878, 0, 0, 39, '877'),
	(243, 1, 0, -50924, 879, 0, 0, 39, '878'),
	(243, 1, 0, -50924, 880, 0, 0, 39, '879'),
	(243, 1, 0, -50924, 881, 0, 0, 39, '880'),
	(243, 1, 0, -50924, 882, 0, 0, 39, '881'),
	(243, 1, 0, -50924, 883, 0, 0, 39, '882'),
	(243, 1, 0, -50924, 884, 0, 0, 39, '883'),
	(243, 1, 0, -50924, 885, 0, 0, 39, '884'),
	(243, 1, 0, -50924, 886, 0, 0, 39, '885'),
	(243, 1, 0, -50924, 887, 0, 0, 39, '886'),
	(243, 1, 0, -50924, 888, 0, 0, 39, '887'),
	(243, 1, 0, -50924, 889, 0, 0, 39, '888'),
	(243, 1, 0, -50924, 890, 0, 0, 39, '889'),
	(243, 1, 0, -50924, 891, 0, 0, 39, '890'),
	(243, 1, 0, -50924, 892, 0, 0, 39, '891'),
	(243, 1, 0, -50924, 893, 0, 0, 39, '892'),
	(243, 1, 0, -50924, 894, 0, 0, 39, '893'),
	(243, 1, 0, -50924, 895, 0, 0, 39, '894'),
	(243, 1, 0, -50924, 896, 0, 0, 39, '895'),
	(243, 1, 0, -50924, 897, 0, 0, 39, '896'),
	(243, 1, 0, -50924, 898, 0, 0, 39, '897'),
	(243, 1, 0, -50924, 899, 0, 0, 39, '898'),
	(243, 1, 0, -50924, 900, 0, 0, 39, '899'),
	(243, 1, 0, -50924, 901, 0, 0, 39, '900'),
	(243, 1, 0, -50924, 902, 0, 0, 39, '901'),
	(243, 1, 0, -50924, 903, 0, 0, 39, '902'),
	(243, 1, 0, -50924, 904, 0, 0, 39, '903'),
	(243, 1, 0, -50924, 905, 0, 0, 39, '904'),
	(243, 1, 0, -50924, 906, 0, 0, 39, '905'),
	(243, 1, 0, -50924, 907, 0, 0, 39, '906'),
	(243, 1, 0, -50924, 908, 0, 0, 39, '907'),
	(243, 1, 0, -50924, 909, 0, 0, 39, '908'),
	(243, 1, 0, -50924, 910, 0, 0, 39, '909'),
	(243, 1, 0, -50924, 911, 0, 0, 39, '910'),
	(243, 1, 0, -50924, 912, 0, 0, 39, '911'),
	(243, 1, 0, -50924, 913, 0, 0, 39, '912'),
	(243, 1, 0, -50924, 914, 0, 0, 39, '913'),
	(243, 1, 0, -50924, 915, 0, 0, 39, '914'),
	(243, 1, 0, -50924, 916, 0, 0, 39, '915'),
	(243, 1, 0, -50924, 917, 0, 0, 39, '916'),
	(243, 1, 0, -50924, 918, 0, 0, 39, '917'),
	(243, 1, 0, -50924, 919, 0, 0, 39, '918'),
	(243, 1, 0, -50924, 920, 0, 0, 39, '919'),
	(243, 1, 0, -50924, 921, 0, 0, 39, '920'),
	(243, 1, 0, -50924, 922, 0, 0, 39, '921'),
	(243, 1, 0, -50924, 923, 0, 0, 39, '922'),
	(243, 1, 0, -50924, 924, 0, 0, 39, '923'),
	(243, 1, 0, -50924, 925, 0, 0, 39, '924'),
	(243, 1, 0, -50924, 926, 0, 0, 39, '925'),
	(243, 1, 0, -50924, 927, 0, 0, 39, '926'),
	(243, 1, 0, -50924, 928, 0, 0, 39, '927'),
	(243, 1, 0, -50924, 929, 0, 0, 39, '928'),
	(243, 1, 0, -50924, 930, 0, 0, 39, '929'),
	(243, 1, 0, -50924, 931, 0, 0, 39, '930'),
	(243, 1, 0, -50924, 932, 0, 0, 39, '931'),
	(243, 1, 0, -50924, 933, 0, 0, 39, '932'),
	(243, 1, 0, -50924, 934, 0, 0, 39, '933'),
	(243, 1, 0, -50924, 935, 0, 0, 39, '934'),
	(243, 1, 0, -50924, 936, 0, 0, 39, '935'),
	(243, 1, 0, -50924, 937, 0, 0, 39, '936'),
	(243, 1, 0, -50924, 938, 0, 0, 39, '937'),
	(243, 1, 0, -50924, 939, 0, 0, 39, '938'),
	(243, 1, 0, -50924, 940, 0, 0, 39, '939'),
	(243, 1, 0, -50924, 941, 0, 0, 39, '940'),
	(243, 1, 0, -50924, 942, 0, 0, 39, '941'),
	(243, 1, 0, -50924, 943, 0, 0, 39, '942'),
	(243, 1, 0, -50924, 944, 0, 0, 39, '943'),
	(243, 1, 0, -50924, 945, 0, 0, 39, '944'),
	(243, 1, 0, -50924, 946, 0, 0, 39, '945'),
	(243, 1, 0, -50924, 947, 0, 0, 39, '946'),
	(243, 1, 0, -50924, 948, 0, 0, 39, '947'),
	(243, 1, 0, -50924, 949, 0, 0, 39, '948'),
	(243, 1, 0, -50924, 950, 0, 0, 39, '949'),
	(243, 1, 0, -50924, 951, 0, 0, 39, '950'),
	(243, 1, 0, -50924, 952, 0, 0, 39, '951'),
	(243, 1, 0, -50924, 953, 0, 0, 39, '952'),
	(243, 1, 0, -50924, 954, 0, 0, 39, '953'),
	(243, 1, 0, -50924, 955, 0, 0, 39, '954'),
	(243, 1, 0, -50924, 956, 0, 0, 39, '955'),
	(243, 1, 0, -50924, 957, 0, 0, 39, '956'),
	(243, 1, 0, -50924, 958, 0, 0, 39, '957'),
	(243, 1, 0, -50924, 959, 0, 0, 39, '958'),
	(243, 1, 0, -50924, 960, 0, 0, 39, '959'),
	(243, 1, 0, -50924, 961, 0, 0, 39, '960'),
	(243, 1, 0, -50924, 962, 0, 0, 39, '961'),
	(243, 1, 0, -50924, 963, 0, 0, 39, '962'),
	(243, 1, 0, -50924, 964, 0, 0, 39, '963'),
	(243, 1, 0, -50924, 965, 0, 0, 39, '964'),
	(243, 1, 0, -50924, 966, 0, 0, 39, '965'),
	(243, 1, 0, -50924, 967, 0, 0, 39, '966'),
	(243, 1, 0, -50924, 968, 0, 0, 39, '967'),
	(243, 1, 0, -50924, 969, 0, 0, 39, '968'),
	(243, 1, 0, -50924, 970, 0, 0, 39, '969'),
	(243, 1, 0, -50924, 971, 0, 0, 39, '970'),
	(243, 1, 0, -50924, 972, 0, 0, 39, '971'),
	(243, 1, 0, -50924, 973, 0, 0, 39, '972'),
	(243, 1, 0, -50924, 974, 0, 0, 39, '973'),
	(243, 1, 0, -50924, 975, 0, 0, 39, '974'),
	(243, 1, 0, -50924, 976, 0, 0, 39, '975'),
	(243, 1, 0, -50924, 977, 0, 0, 39, '976'),
	(243, 1, 0, -50924, 978, 0, 0, 39, '977'),
	(243, 1, 0, -50924, 979, 0, 0, 39, '978'),
	(243, 1, 0, -50924, 980, 0, 0, 39, '979'),
	(243, 1, 0, -50924, 981, 0, 0, 39, '980'),
	(243, 1, 0, -50924, 982, 0, 0, 39, '981'),
	(243, 1, 0, -50924, 983, 0, 0, 39, '982'),
	(243, 1, 0, -50924, 984, 0, 0, 39, '983'),
	(243, 1, 0, -50924, 985, 0, 0, 39, '984'),
	(243, 1, 0, -50924, 986, 0, 0, 39, '985'),
	(243, 1, 0, -50924, 987, 0, 0, 39, '986'),
	(243, 1, 0, -50924, 988, 0, 0, 39, '987'),
	(243, 1, 0, -50924, 989, 0, 0, 39, '988'),
	(243, 1, 0, -50924, 990, 0, 0, 39, '989'),
	(243, 1, 0, -50924, 991, 0, 0, 39, '990'),
	(243, 1, 0, -50924, 992, 0, 0, 39, '991'),
	(243, 1, 0, -50924, 993, 0, 0, 39, '992'),
	(243, 1, 0, -50924, 994, 0, 0, 39, '993'),
	(243, 1, 0, -50924, 995, 0, 0, 39, '994'),
	(243, 1, 0, -50924, 996, 0, 0, 39, '995'),
	(243, 1, 0, -50924, 997, 0, 0, 39, '996'),
	(243, 1, 0, -50924, 998, 0, 0, 39, '997'),
	(243, 1, 0, -50924, 999, 0, 0, 39, '998'),
	(243, 1, 0, -50924, 1000, 0, 0, 39, '999'),
	(243, 1, 0, -50924, 1001, 0, 0, 39, '1000'),
	(243, 1, 0, -50924, 1002, 0, 0, 39, '1001'),
	(243, 1, 0, -50924, 1003, 0, 0, 39, '1002'),
	(243, 1, 0, -50924, 1004, 0, 0, 39, '1003'),
	(243, 1, 0, -50924, 1005, 0, 0, 39, '1004'),
	(243, 1, 0, -50924, 1006, 0, 0, 39, '1005'),
	(243, 1, 0, -50924, 1007, 0, 0, 39, '1006'),
	(243, 1, 0, -50924, 1008, 0, 0, 39, '1007'),
	(243, 1, 0, -50924, 1009, 0, 0, 39, '1008'),
	(243, 1, 0, -50924, 1010, 0, 0, 39, '1009'),
	(243, 1, 0, -50924, 1011, 0, 0, 39, '1010'),
	(243, 1, 0, -50924, 1012, 0, 0, 39, '1011'),
	(243, 1, 0, -50924, 1013, 0, 0, 39, '1012'),
	(243, 1, 0, -50924, 1014, 0, 0, 39, '1013'),
	(243, 1, 0, -50924, 1015, 0, 0, 39, '1014'),
	(243, 1, 0, -50924, 1016, 0, 0, 39, '1015'),
	(243, 1, 0, -50924, 1017, 0, 0, 39, '1016'),
	(243, 1, 0, -50924, 1018, 0, 0, 39, '1017'),
	(243, 1, 0, -50924, 1019, 0, 0, 39, '1018'),
	(243, 1, 0, -50924, 1020, 0, 0, 39, '1019'),
	(243, 1, 0, -50924, 1021, 0, 0, 39, '1020'),
	(243, 1, 0, -50924, 1022, 0, 0, 39, '1021'),
	(243, 1, 0, -50924, 1023, 0, 0, 39, '1022'),
	(243, 1, 0, -50924, 1024, 0, 0, 39, '1023'),
	(243, 1, 0, -50924, 1025, 0, 0, 39, '1024'),
	(243, 1, 0, -50924, 1026, 0, 0, 39, '1025'),
	(243, 1, 0, -50924, 1027, 0, 0, 39, '1026'),
	(243, 1, 0, -50924, 1028, 0, 0, 39, '1027'),
	(243, 1, 0, -50924, 1029, 0, 0, 39, '1028'),
	(243, 1, 0, -50924, 1030, 0, 0, 39, '1029'),
	(243, 1, 0, -50924, 1031, 0, 0, 39, '1030'),
	(243, 1, 0, -50924, 1032, 0, 0, 39, '1031'),
	(243, 1, 0, -50924, 1033, 0, 0, 39, '1032'),
	(243, 1, 0, -50924, 1034, 0, 0, 39, '1033'),
	(243, 1, 0, -50924, 1035, 0, 0, 39, '1034'),
	(243, 1, 0, -50924, 1036, 0, 0, 39, '1035'),
	(243, 1, 0, -50924, 1037, 0, 0, 39, '1036'),
	(243, 1, 0, -50924, 1038, 0, 0, 39, '1037'),
	(243, 1, 0, -50924, 1039, 0, 0, 39, '1038'),
	(243, 1, 0, -50924, 1040, 0, 0, 39, '1039'),
	(243, 1, 0, -50924, 1041, 0, 0, 39, '1040'),
	(243, 1, 0, -50924, 1042, 0, 0, 39, '1041'),
	(243, 1, 0, -50924, 1043, 0, 0, 39, '1042'),
	(243, 1, 0, -50924, 1044, 0, 0, 39, '1043'),
	(243, 1, 0, -50924, 1045, 0, 0, 39, '1044'),
	(243, 1, 0, -50924, 1046, 0, 0, 39, '1045'),
	(243, 1, 0, -50924, 1047, 0, 0, 39, '1046'),
	(243, 1, 0, -50924, 1048, 0, 0, 39, '1047'),
	(243, 1, 0, -50924, 1049, 0, 0, 39, '1048'),
	(243, 1, 0, -50924, 1050, 0, 0, 39, '1049'),
	(243, 1, 0, -50924, 1051, 0, 0, 39, '1050'),
	(243, 1, 0, -50924, 1052, 0, 0, 39, '1051'),
	(243, 1, 0, -50924, 1053, 0, 0, 39, '1052'),
	(243, 1, 0, -50924, 1054, 0, 0, 39, '1053'),
	(243, 1, 0, -50924, 1055, 0, 0, 39, '1054'),
	(243, 1, 0, -50924, 1056, 0, 0, 39, '1055'),
	(243, 1, 0, -50924, 1057, 0, 0, 39, '1056'),
	(243, 1, 0, -50924, 1058, 0, 0, 39, '1057'),
	(243, 1, 0, -50924, 1059, 0, 0, 39, '1058'),
	(243, 1, 0, -50924, 1060, 0, 0, 39, '1059'),
	(243, 1, 0, -50924, 1061, 0, 0, 39, '1060'),
	(243, 1, 0, -50924, 1062, 0, 0, 39, '1061'),
	(243, 1, 0, -50924, 1063, 0, 0, 39, '1062'),
	(243, 1, 0, -50924, 1064, 0, 0, 39, '1063'),
	(243, 1, 0, -50924, 1065, 0, 0, 39, '1064'),
	(243, 1, 0, -50924, 1066, 0, 0, 39, '1065'),
	(243, 1, 0, -50924, 1067, 0, 0, 39, '1066'),
	(243, 1, 0, -50924, 1068, 0, 0, 39, '1067'),
	(243, 1, 0, -50924, 1069, 0, 0, 39, '1068'),
	(243, 1, 0, -50924, 1070, 0, 0, 39, '1069'),
	(243, 1, 0, -50924, 1071, 0, 0, 39, '1070'),
	(243, 1, 0, -50924, 1072, 0, 0, 39, '1071'),
	(243, 1, 0, -50924, 1073, 0, 0, 39, '1072'),
	(243, 1, 0, -50924, 1074, 0, 0, 39, '1073'),
	(243, 1, 0, -50924, 1075, 0, 0, 39, '1074'),
	(243, 1, 0, -50924, 1076, 0, 0, 39, '1075'),
	(243, 1, 0, -50924, 1077, 0, 0, 39, '1076'),
	(243, 1, 0, -50924, 1078, 0, 0, 39, '1077'),
	(243, 1, 0, -50924, 1079, 0, 0, 39, '1078'),
	(243, 1, 0, -50924, 1080, 0, 0, 39, '1079'),
	(243, 1, 0, -50924, 1081, 0, 0, 39, '1080'),
	(243, 1, 0, -50924, 1082, 0, 0, 39, '1081'),
	(243, 1, 0, -50924, 1083, 0, 0, 39, '1082'),
	(243, 1, 0, -50924, 1084, 0, 0, 39, '1083'),
	(243, 1, 0, -50924, 1085, 0, 0, 39, '1084'),
	(243, 1, 0, -50924, 1086, 0, 0, 39, '1085'),
	(243, 1, 0, -50924, 1087, 0, 0, 39, '1086'),
	(243, 1, 0, -50924, 1088, 0, 0, 39, '1087'),
	(243, 1, 0, -50924, 1089, 0, 0, 39, '1088'),
	(243, 1, 0, -50924, 1090, 0, 0, 39, '1089'),
	(243, 1, 0, -50924, 1091, 0, 0, 39, '1090'),
	(243, 1, 0, -50924, 1092, 0, 0, 39, '1091'),
	(243, 1, 0, -50924, 1093, 0, 0, 39, '1092'),
	(243, 1, 0, -50924, 1094, 0, 0, 39, '1093'),
	(243, 1, 0, -50924, 1095, 0, 0, 39, '1094'),
	(243, 1, 0, -50924, 1096, 0, 0, 39, '1095'),
	(243, 1, 0, -50924, 1097, 0, 0, 39, '1096'),
	(243, 1, 0, -50924, 1098, 0, 0, 39, '1097'),
	(243, 1, 0, -50924, 1099, 0, 0, 39, '1098'),
	(243, 1, 0, -50924, 1100, 0, 0, 39, '1099'),
	(243, 1, 0, -50924, 1101, 0, 0, 39, '1100'),
	(243, 1, 0, -50924, 1102, 0, 0, 39, '1101'),
	(243, 1, 0, -50924, 1103, 0, 0, 39, '1102'),
	(243, 1, 0, -50924, 1104, 0, 0, 39, '1103'),
	(243, 1, 0, -50924, 1105, 0, 0, 39, '1104'),
	(243, 1, 0, -50924, 1106, 0, 0, 39, '1105'),
	(243, 1, 0, -50924, 1107, 0, 0, 39, '1106'),
	(243, 1, 0, -50924, 1108, 0, 0, 39, '1107'),
	(243, 1, 0, -50924, 1109, 0, 0, 39, '1108'),
	(243, 1, 0, -50924, 1110, 0, 0, 39, '1109'),
	(243, 1, 0, -50924, 1111, 0, 0, 39, '1110'),
	(243, 1, 0, -50924, 1112, 0, 0, 39, '1111'),
	(243, 1, 0, -50924, 1113, 0, 0, 39, '1112'),
	(243, 1, 0, -50924, 1114, 0, 0, 39, '1113'),
	(243, 1, 0, -50924, 1115, 0, 0, 39, '1114'),
	(243, 1, 0, -50924, 1116, 0, 0, 39, '1115'),
	(243, 1, 0, -50924, 1117, 0, 0, 39, '1116'),
	(243, 1, 0, -50924, 1118, 0, 0, 39, '1117'),
	(243, 1, 0, -50924, 1119, 0, 0, 39, '1118'),
	(243, 1, 0, -50924, 1120, 0, 0, 39, '1119'),
	(243, 1, 0, -50924, 1121, 0, 0, 39, '1120'),
	(243, 1, 0, -50924, 1122, 0, 0, 39, '1121'),
	(243, 1, 0, -50924, 1123, 0, 0, 39, '1122'),
	(243, 1, 0, -50924, 1124, 0, 0, 39, '1123'),
	(243, 1, 0, -50924, 1125, 0, 0, 39, '1124'),
	(243, 1, 0, -50924, 1126, 0, 0, 39, '1125'),
	(243, 1, 0, -50924, 1127, 0, 0, 39, '1126'),
	(243, 1, 0, -50924, 1128, 0, 0, 39, '1127'),
	(243, 1, 0, -50924, 1129, 0, 0, 39, '1128'),
	(243, 1, 0, -50924, 1130, 0, 0, 39, '1129'),
	(243, 1, 0, -50924, 1131, 0, 0, 39, '1130'),
	(243, 1, 0, -50924, 1132, 0, 0, 39, '1131'),
	(243, 1, 0, -50924, 1133, 0, 0, 39, '1132'),
	(243, 1, 0, -50924, 1134, 0, 0, 39, '1133'),
	(243, 1, 0, -50924, 1135, 0, 0, 39, '1134'),
	(243, 1, 0, -50924, 1136, 0, 0, 39, '1135'),
	(243, 1, 0, -50924, 1137, 0, 0, 39, '1136'),
	(243, 1, 0, -50924, 1138, 0, 0, 39, '1137'),
	(243, 1, 0, -50924, 1139, 0, 0, 39, '1138'),
	(243, 1, 0, -50924, 1140, 0, 0, 39, '1139'),
	(243, 1, 0, -50924, 1141, 0, 0, 39, '1140'),
	(243, 1, 0, -50924, 1142, 0, 0, 39, '1141'),
	(243, 1, 0, -50924, 1143, 0, 0, 39, '1142'),
	(243, 1, 0, -50924, 1144, 0, 0, 39, '1143'),
	(243, 1, 0, -50924, 1145, 0, 0, 39, '1144'),
	(243, 1, 0, -50924, 1146, 0, 0, 39, '1145'),
	(243, 1, 0, -50924, 1147, 0, 0, 39, '1146'),
	(243, 1, 0, -50924, 1148, 0, 0, 39, '1147'),
	(243, 1, 0, -50924, 1149, 0, 0, 39, '1148'),
	(243, 1, 0, -50924, 1150, 0, 0, 39, '1149'),
	(243, 1, 0, -50924, 1151, 0, 0, 39, '1150'),
	(243, 1, 0, -50924, 1152, 0, 0, 39, '1151'),
	(243, 1, 0, -50924, 1153, 0, 0, 39, '1152'),
	(243, 1, 0, -50924, 1154, 0, 0, 39, '1153'),
	(243, 1, 0, -50924, 1155, 0, 0, 39, '1154'),
	(243, 1, 0, -50924, 1156, 0, 0, 39, '1155'),
	(243, 1, 0, -50924, 1157, 0, 0, 39, '1156'),
	(243, 1, 0, -50924, 1158, 0, 0, 39, '1157'),
	(243, 1, 0, -50924, 1159, 0, 0, 39, '1158'),
	(243, 1, 0, -50924, 1160, 0, 0, 39, '1159'),
	(243, 1, 0, -50924, 1161, 0, 0, 39, '1160'),
	(243, 1, 0, -50924, 1162, 0, 0, 39, '1161'),
	(243, 1, 0, -50924, 1163, 0, 0, 39, '1162'),
	(243, 1, 0, -50924, 1164, 0, 0, 39, '1163'),
	(243, 1, 0, -50924, 1165, 0, 0, 39, '1164'),
	(243, 1, 0, -50924, 1166, 0, 0, 39, '1165'),
	(243, 1, 0, -50924, 1167, 0, 0, 39, '1166'),
	(243, 1, 0, -50924, 1168, 0, 0, 39, '1167'),
	(243, 1, 0, -50924, 1169, 0, 0, 39, '1168'),
	(243, 1, 0, -50924, 1170, 0, 0, 39, '1169'),
	(243, 1, 0, -50924, 1171, 0, 0, 39, '1170'),
	(243, 1, 0, -50924, 1172, 0, 0, 39, '1171'),
	(243, 1, 0, -50924, 1173, 0, 0, 39, '1172'),
	(243, 1, 0, -50924, 1174, 0, 0, 39, '1173'),
	(243, 1, 0, -50924, 1175, 0, 0, 39, '1174'),
	(243, 1, 0, -50924, 1176, 0, 0, 39, '1175'),
	(243, 1, 0, -50924, 1177, 0, 0, 39, '1176'),
	(243, 1, 0, -50924, 1178, 0, 0, 39, '1177'),
	(243, 1, 0, -50924, 1179, 0, 0, 39, '1178'),
	(243, 1, 0, -50924, 1180, 0, 0, 39, '1179'),
	(243, 1, 0, -50924, 1181, 0, 0, 39, '1180'),
	(243, 1, 0, -50924, 1182, 0, 0, 39, '1181'),
	(243, 1, 0, -50924, 1183, 0, 0, 39, '1182'),
	(243, 1, 0, -50924, 1184, 0, 0, 39, '1183'),
	(243, 1, 0, -50924, 1185, 0, 0, 39, '1184'),
	(243, 1, 0, -50924, 1186, 0, 0, 39, '1185'),
	(243, 1, 0, -50924, 1187, 0, 0, 39, '1186'),
	(243, 1, 0, -50924, 1188, 0, 0, 39, '1187'),
	(243, 1, 0, -50924, 1189, 0, 0, 39, '1188'),
	(243, 1, 0, -50924, 1190, 0, 0, 39, '1189'),
	(243, 1, 0, -50924, 1191, 0, 0, 39, '1190'),
	(243, 1, 0, -50924, 1192, 0, 0, 39, '1191'),
	(243, 1, 0, -50924, 1193, 0, 0, 39, '1192'),
	(243, 1, 0, -50924, 1194, 0, 0, 39, '1193'),
	(243, 1, 0, -50924, 1195, 0, 0, 39, '1194'),
	(243, 1, 0, -50924, 1196, 0, 0, 39, '1195'),
	(243, 1, 0, -50924, 1197, 0, 0, 39, '1196'),
	(243, 1, 0, -50924, 1198, 0, 0, 39, '1197'),
	(243, 1, 0, -50924, 1199, 0, 0, 39, '1198'),
	(243, 1, 0, -50924, 1200, 0, 0, 39, '1199'),
	(243, 1, 0, -50924, 1201, 0, 0, 39, '1200'),
	(243, 1, 0, -50924, 1202, 0, 0, 39, '1201'),
	(243, 1, 0, -50924, 1203, 0, 0, 39, '1202'),
	(243, 1, 0, -50924, 1204, 0, 0, 39, '1203'),
	(243, 1, 0, -50924, 1205, 0, 0, 39, '1204'),
	(243, 1, 0, -50924, 1206, 0, 0, 39, '1205'),
	(243, 1, 0, -50924, 1207, 0, 0, 39, '1206'),
	(243, 1, 0, -50924, 1208, 0, 0, 39, '1207'),
	(243, 1, 0, -50924, 1209, 0, 0, 39, '1208'),
	(243, 1, 0, -50924, 1210, 0, 0, 39, '1209'),
	(243, 1, 0, -50924, 1211, 0, 0, 39, '1210'),
	(243, 1, 0, -50924, 1212, 0, 0, 39, '1211'),
	(243, 1, 0, -50924, 1213, 0, 0, 39, '1212'),
	(243, 1, 0, -50924, 1214, 0, 0, 39, '1213'),
	(243, 1, 0, -50924, 1215, 0, 0, 39, '1214'),
	(243, 1, 0, -50924, 1216, 0, 0, 39, '1215'),
	(243, 1, 0, -50924, 1217, 0, 0, 39, '1216'),
	(243, 1, 0, -50924, 1218, 0, 0, 39, '1217'),
	(243, 1, 0, -50924, 1219, 0, 0, 39, '1218'),
	(243, 1, 0, -50924, 1220, 0, 0, 39, '1219'),
	(243, 1, 0, -50924, 1221, 0, 0, 39, '1220'),
	(243, 1, 0, -50924, 1222, 0, 0, 39, '1221'),
	(243, 1, 0, -50924, 1223, 0, 0, 39, '1222'),
	(243, 1, 0, -50924, 1224, 0, 0, 39, '1223'),
	(243, 1, 0, -50924, 1225, 0, 0, 39, '1224'),
	(243, 1, 0, -50924, 1226, 0, 0, 39, '1225'),
	(243, 1, 0, -50924, 1227, 0, 0, 39, '1226'),
	(243, 1, 0, -50924, 1228, 0, 0, 39, '1227'),
	(243, 1, 0, -50924, 1229, 0, 0, 39, '1228'),
	(243, 1, 0, -50924, 1230, 0, 0, 39, '1229'),
	(243, 1, 0, -50924, 1231, 0, 0, 39, '1230'),
	(243, 1, 0, -50924, 1232, 0, 0, 39, '1231'),
	(243, 1, 0, -50924, 1233, 0, 0, 39, '1232'),
	(243, 1, 0, -50924, 1234, 0, 0, 39, '1233'),
	(243, 1, 0, -50924, 1235, 0, 0, 39, '1234'),
	(243, 1, 0, -50924, 1236, 0, 0, 39, '1235'),
	(243, 1, 0, -50924, 1237, 0, 0, 39, '1236'),
	(243, 1, 0, -50924, 1238, 0, 0, 39, '1237'),
	(243, 1, 0, -50924, 1239, 0, 0, 39, '1238'),
	(243, 1, 0, -50924, 1240, 0, 0, 39, '1239'),
	(243, 1, 0, -50924, 1241, 0, 0, 39, '1240'),
	(243, 1, 0, -50924, 1242, 0, 0, 39, '1241'),
	(243, 1, 0, -50924, 1243, 0, 0, 39, '1242'),
	(243, 1, 0, -50924, 1244, 0, 0, 39, '1243'),
	(243, 1, 0, -50924, 1245, 0, 0, 39, '1244'),
	(243, 1, 0, -50924, 1246, 0, 0, 39, '1245'),
	(243, 1, 0, -50924, 1247, 0, 0, 39, '1246'),
	(243, 1, 0, -50924, 1248, 0, 0, 39, '1247'),
	(243, 1, 0, -50924, 1249, 0, 0, 39, '1248'),
	(243, 1, 0, -50924, 1250, 0, 0, 39, '1249'),
	(243, 1, 0, -50924, 1251, 0, 0, 39, '1250'),
	(243, 1, 0, -50924, 1252, 0, 0, 39, '1251'),
	(243, 1, 0, -50924, 1253, 0, 0, 39, '1252'),
	(243, 1, 0, -50924, 1254, 0, 0, 39, '1253'),
	(243, 1, 0, -50924, 1255, 0, 0, 39, '1254'),
	(243, 1, 0, -50924, 1256, 0, 0, 39, '1255'),
	(243, 1, 0, -50924, 1257, 0, 0, 39, '1256'),
	(243, 1, 0, -50924, 1258, 0, 0, 39, '1257'),
	(243, 1, 0, -50924, 1259, 0, 0, 39, '1258'),
	(243, 1, 0, -50924, 1260, 0, 0, 39, '1259'),
	(243, 1, 0, -50924, 1261, 0, 0, 39, '1260'),
	(243, 1, 0, -50924, 1262, 0, 0, 39, '1261'),
	(243, 1, 0, -50924, 1263, 0, 0, 39, '1262'),
	(243, 1, 0, -50924, 1264, 0, 0, 39, '1263'),
	(243, 1, 0, -50924, 1265, 0, 0, 39, '1264'),
	(243, 1, 0, -50924, 1266, 0, 0, 39, '1265'),
	(243, 1, 0, -50924, 1267, 0, 0, 39, '1266'),
	(243, 1, 0, -50924, 1268, 0, 0, 39, '1267'),
	(243, 1, 0, -50924, 1269, 0, 0, 39, '1268'),
	(243, 1, 0, -50924, 1270, 0, 0, 39, '1269'),
	(243, 1, 0, -50924, 1271, 0, 0, 39, '1270'),
	(243, 1, 0, -50924, 1272, 0, 0, 39, '1271'),
	(243, 1, 0, -50924, 1273, 0, 0, 39, '1272'),
	(243, 1, 0, -50924, 1274, 0, 0, 39, '1273'),
	(243, 1, 0, -50924, 1275, 0, 0, 39, '1274'),
	(243, 1, 0, -50924, 1276, 0, 0, 39, '1275'),
	(243, 1, 0, -50924, 1277, 0, 0, 39, '1276'),
	(243, 1, 0, -50924, 1278, 0, 0, 39, '1277'),
	(243, 1, 0, -50924, 1279, 0, 0, 39, '1278'),
	(243, 1, 0, -50924, 1280, 0, 0, 39, '1279'),
	(243, 1, 0, -50924, 1281, 0, 0, 39, '1280'),
	(243, 1, 0, -50924, 1282, 0, 0, 39, '1281'),
	(243, 1, 0, -50924, 1283, 0, 0, 39, '1282'),
	(243, 1, 0, -50924, 1284, 0, 0, 39, '1283'),
	(243, 1, 0, -50924, 1285, 0, 0, 39, '1284'),
	(243, 1, 0, -50924, 1286, 0, 0, 39, '1285'),
	(243, 1, 0, -50924, 1287, 0, 0, 39, '1286'),
	(243, 1, 0, -50924, 1288, 0, 0, 39, '1287'),
	(243, 1, 0, -50924, 1289, 0, 0, 39, '1288'),
	(243, 1, 0, -50924, 1290, 0, 0, 39, '1289'),
	(243, 1, 0, -50924, 1291, 0, 0, 39, '1290'),
	(243, 1, 0, -50924, 1292, 0, 0, 39, '1291'),
	(243, 1, 0, -50924, 1293, 0, 0, 39, '1292'),
	(243, 1, 0, -50924, 1294, 0, 0, 39, '1293'),
	(243, 1, 0, -50924, 1295, 0, 0, 39, '1294'),
	(243, 1, 0, -50924, 1296, 0, 0, 39, '1295'),
	(243, 1, 0, -50924, 1297, 0, 0, 39, '1296'),
	(243, 1, 0, -50924, 1298, 0, 0, 39, '1297'),
	(243, 1, 0, -50924, 1299, 0, 0, 39, '1298'),
	(243, 1, 0, -50924, 1300, 0, 0, 39, '1299'),
	(243, 1, 0, -50924, 1301, 0, 0, 39, '1300'),
	(243, 1, 0, -50924, 1302, 0, 0, 39, '1301'),
	(243, 1, 0, -50924, 1303, 0, 0, 39, '1302'),
	(243, 1, 0, -50924, 1304, 0, 0, 39, '1303'),
	(243, 1, 0, -50924, 1305, 0, 0, 39, '1304'),
	(243, 1, 0, -50924, 1306, 0, 0, 39, '1305'),
	(243, 1, 0, -50924, 1307, 0, 0, 39, '1306'),
	(243, 1, 0, -50924, 1308, 0, 0, 39, '1307'),
	(243, 1, 0, -50924, 1309, 0, 0, 39, '1308'),
	(243, 1, 0, -50924, 1310, 0, 0, 39, '1309'),
	(243, 1, 0, -50924, 1311, 0, 0, 39, '1310'),
	(243, 1, 0, -50924, 1312, 0, 0, 39, '1311'),
	(243, 1, 0, -50924, 1313, 0, 0, 39, '1312'),
	(243, 1, 0, -50924, 1314, 0, 0, 39, '1313'),
	(243, 1, 0, -50924, 1315, 0, 0, 39, '1314'),
	(243, 1, 0, -50924, 1316, 0, 0, 39, '1315'),
	(243, 1, 0, -50924, 1317, 0, 0, 39, '1316'),
	(243, 1, 0, -50924, 1318, 0, 0, 39, '1317'),
	(243, 1, 0, -50924, 1319, 0, 0, 39, '1318'),
	(243, 1, 0, -50924, 1320, 0, 0, 39, '1319'),
	(243, 1, 0, -50924, 1321, 0, 0, 39, '1320'),
	(243, 1, 0, -50924, 1322, 0, 0, 39, '1321'),
	(243, 1, 0, -50924, 1323, 0, 0, 39, '1322'),
	(243, 1, 0, -50924, 1324, 0, 0, 39, '1323'),
	(243, 1, 0, -50924, 1325, 0, 0, 39, '1324'),
	(243, 1, 0, -50924, 1326, 0, 0, 39, '1325'),
	(243, 1, 0, -50924, 1327, 0, 0, 39, '1326'),
	(243, 1, 0, -50924, 1328, 0, 0, 39, '1327'),
	(243, 1, 0, -50924, 1329, 0, 0, 39, '1328'),
	(243, 1, 0, -50924, 1330, 0, 0, 39, '1329'),
	(243, 1, 0, -50924, 1331, 0, 0, 39, '1330'),
	(243, 1, 0, -50924, 1332, 0, 0, 39, '1331'),
	(243, 1, 0, -50924, 1333, 0, 0, 39, '1332'),
	(243, 1, 0, -50924, 1334, 0, 0, 39, '1333'),
	(243, 1, 0, -50924, 1335, 0, 0, 39, '1334'),
	(243, 1, 0, -50924, 1336, 0, 0, 39, '1335'),
	(243, 1, 0, -50924, 1337, 0, 0, 39, '1336'),
	(243, 1, 0, -50924, 1338, 0, 0, 39, '1337'),
	(243, 1, 0, -50924, 1339, 0, 0, 39, '1338'),
	(243, 1, 0, -50924, 1340, 0, 0, 39, '1339'),
	(243, 1, 0, -50924, 1341, 0, 0, 39, '1340'),
	(243, 1, 0, -50924, 1342, 0, 0, 39, '1341'),
	(243, 1, 0, -50924, 1343, 0, 0, 39, '1342'),
	(243, 1, 0, -50924, 1344, 0, 0, 39, '1343'),
	(243, 1, 0, -50924, 1345, 0, 0, 39, '1344'),
	(243, 1, 0, -50924, 1346, 0, 0, 39, '1345'),
	(243, 1, 0, -50924, 1347, 0, 0, 39, '1346'),
	(243, 1, 0, -50924, 1348, 0, 0, 39, '1347'),
	(243, 1, 0, -50924, 1349, 0, 0, 39, '1348'),
	(243, 1, 0, -50924, 1350, 0, 0, 39, '1349'),
	(243, 1, 0, -50924, 1351, 0, 0, 39, '1350'),
	(243, 1, 0, -50924, 1352, 0, 0, 39, '1351'),
	(243, 1, 0, -50924, 1353, 0, 0, 39, '1352'),
	(243, 1, 0, -50924, 1354, 0, 0, 39, '1353'),
	(243, 1, 0, -50924, 1355, 0, 0, 39, '1354'),
	(243, 1, 0, -50924, 1356, 0, 0, 39, '1355'),
	(243, 1, 0, -50924, 1357, 0, 0, 39, '1356'),
	(243, 1, 0, -50924, 1358, 0, 0, 39, '1357'),
	(243, 1, 0, -50924, 1359, 0, 0, 39, '1358'),
	(243, 1, 0, -50924, 1360, 0, 0, 39, '1359'),
	(243, 1, 0, -50924, 1361, 0, 0, 39, '1360'),
	(243, 1, 0, -50924, 1362, 0, 0, 39, '1361'),
	(243, 1, 0, -50924, 1363, 0, 0, 39, '1362'),
	(243, 1, 0, -50924, 1364, 0, 0, 39, '1363'),
	(243, 1, 0, -50924, 1365, 0, 0, 39, '1364'),
	(243, 1, 0, -50924, 1366, 0, 0, 39, '1365'),
	(243, 1, 0, -50924, 1367, 0, 0, 39, '1366'),
	(243, 1, 0, -50924, 1368, 0, 0, 39, '1367'),
	(243, 1, 0, -50924, 1369, 0, 0, 39, '1368'),
	(243, 1, 0, -50924, 1370, 0, 0, 39, '1369'),
	(243, 1, 0, -50924, 1371, 0, 0, 39, '1370'),
	(243, 1, 0, -50924, 1372, 0, 0, 39, '1371'),
	(243, 1, 0, -50924, 1373, 0, 0, 39, '1372'),
	(243, 1, 0, -50924, 1374, 0, 0, 39, '1373'),
	(243, 1, 0, -50924, 1375, 0, 0, 39, '1374'),
	(243, 1, 0, -50924, 1376, 0, 0, 39, '1375'),
	(243, 1, 0, -50924, 1377, 0, 0, 39, '1376'),
	(243, 1, 0, -50924, 1378, 0, 0, 39, '1377'),
	(243, 1, 0, -50924, 1379, 0, 0, 39, '1378'),
	(243, 1, 0, -50924, 1380, 0, 0, 39, '1379'),
	(243, 1, 0, -50924, 1381, 0, 0, 39, '1380'),
	(243, 1, 0, -50924, 1382, 0, 0, 39, '1381'),
	(243, 1, 0, -50924, 1383, 0, 0, 39, '1382'),
	(243, 1, 0, -50924, 1384, 0, 0, 39, '1383'),
	(243, 1, 0, -50924, 1385, 0, 0, 39, '1384'),
	(243, 1, 0, -50924, 1386, 0, 0, 39, '1385'),
	(243, 1, 0, -50924, 1387, 0, 0, 39, '1386'),
	(243, 1, 0, -50924, 1388, 0, 0, 39, '1387'),
	(243, 1, 0, -50924, 1389, 0, 0, 39, '1388'),
	(243, 1, 0, -50924, 1390, 0, 0, 39, '1389'),
	(243, 1, 0, -50924, 1391, 0, 0, 39, '1390'),
	(243, 1, 0, -50924, 1392, 0, 0, 39, '1391'),
	(243, 1, 0, -50924, 1393, 0, 0, 39, '1392'),
	(243, 1, 0, -50924, 1394, 0, 0, 39, '1393'),
	(243, 1, 0, -50924, 1395, 0, 0, 39, '1394'),
	(243, 1, 0, -50924, 1396, 0, 0, 39, '1395'),
	(243, 1, 0, -50924, 1397, 0, 0, 39, '1396'),
	(243, 1, 0, -50924, 1398, 0, 0, 39, '1397'),
	(243, 1, 0, -50924, 1399, 0, 0, 39, '1398'),
	(243, 1, 0, -50924, 1400, 0, 0, 39, '1399'),
	(243, 1, 0, -50924, 1401, 0, 0, 39, '1400'),
	(243, 1, 0, -50924, 1402, 0, 0, 39, '1401'),
	(243, 1, 0, -50924, 1403, 0, 0, 39, '1402'),
	(243, 1, 0, -50924, 1404, 0, 0, 39, '1403'),
	(243, 1, 0, -50924, 1405, 0, 0, 39, '1404'),
	(243, 1, 0, -50924, 1406, 0, 0, 39, '1405'),
	(243, 1, 0, -50924, 1407, 0, 0, 39, '1406'),
	(243, 1, 0, -50924, 1408, 0, 0, 39, '1407'),
	(243, 1, 0, -50924, 1409, 0, 0, 39, '1408'),
	(243, 1, 0, -50924, 1410, 0, 0, 39, '1409'),
	(243, 1, 0, -50924, 1411, 0, 0, 39, '1410'),
	(243, 1, 0, -50924, 1412, 0, 0, 39, '1411'),
	(243, 1, 0, -50924, 1413, 0, 0, 39, '1412'),
	(243, 1, 0, -50924, 1414, 0, 0, 39, '1413'),
	(243, 1, 0, -50924, 1415, 0, 0, 39, '1414'),
	(243, 1, 0, -50924, 1416, 0, 0, 39, '1415'),
	(243, 1, 0, -50924, 1417, 0, 0, 39, '1416'),
	(243, 1, 0, -50924, 1418, 0, 0, 39, '1417'),
	(243, 1, 0, -50924, 1419, 0, 0, 39, '1418'),
	(243, 1, 0, -50924, 1420, 0, 0, 39, '1419'),
	(243, 1, 0, -50924, 1421, 0, 0, 39, '1420'),
	(243, 1, 0, -50924, 1422, 0, 0, 39, '1421'),
	(243, 1, 0, -50924, 1423, 0, 0, 39, '1422'),
	(243, 1, 0, -50924, 1424, 0, 0, 39, '1423'),
	(243, 1, 0, -50924, 1425, 0, 0, 39, '1424'),
	(243, 1, 0, -50924, 1426, 0, 0, 39, '1425'),
	(243, 1, 0, -50924, 1427, 0, 0, 39, '1426'),
	(243, 1, 0, -50924, 1428, 0, 0, 39, '1427'),
	(243, 1, 0, -50924, 1429, 0, 0, 39, '1428'),
	(243, 1, 0, -50924, 1430, 0, 0, 39, '1429'),
	(243, 1, 0, -50924, 1431, 0, 0, 39, '1430'),
	(243, 1, 0, -50924, 1432, 0, 0, 39, '1431'),
	(243, 1, 0, -50924, 1433, 0, 0, 39, '1432'),
	(243, 1, 0, -50924, 1434, 0, 0, 39, '1433'),
	(243, 1, 0, -50924, 1435, 0, 0, 39, '1434'),
	(243, 1, 0, -50924, 1436, 0, 0, 39, '1435'),
	(243, 1, 0, -50924, 1437, 0, 0, 39, '1436'),
	(243, 1, 0, -50924, 1438, 0, 0, 39, '1437'),
	(243, 1, 0, -50924, 1439, 0, 0, 39, '1438'),
	(243, 1, 0, -50924, 1440, 0, 0, 39, '1439'),
	(243, 1, 0, -50924, 1441, 0, 0, 39, '1440'),
	(243, 1, 0, -50924, 1442, 0, 0, 39, '1441'),
	(243, 1, 0, -50924, 1443, 0, 0, 39, '1442'),
	(243, 1, 0, -50924, 1444, 0, 0, 39, '1443'),
	(243, 1, 0, -50924, 1445, 0, 0, 39, '1444'),
	(243, 1, 0, -50924, 1446, 0, 0, 39, '1445'),
	(243, 1, 0, -50924, 1447, 0, 0, 39, '1446'),
	(243, 1, 0, -50924, 1448, 0, 0, 39, '1447'),
	(243, 1, 0, -50924, 1449, 0, 0, 39, '1448'),
	(243, 1, 0, -50924, 1450, 0, 0, 39, '1449'),
	(243, 1, 0, -50924, 1451, 0, 0, 39, '1450'),
	(243, 1, 0, -50924, 1452, 0, 0, 39, '1451'),
	(243, 1, 0, -50924, 1453, 0, 0, 39, '1452'),
	(243, 1, 0, -50924, 1454, 0, 0, 39, '1453'),
	(243, 1, 0, -50924, 1455, 0, 0, 39, '1454'),
	(243, 1, 0, -50924, 1456, 0, 0, 39, '1455'),
	(243, 1, 0, -50924, 1457, 0, 0, 39, '1456'),
	(243, 1, 0, -50924, 1458, 0, 0, 39, '1457'),
	(243, 1, 0, -50924, 1459, 0, 0, 39, '1458'),
	(243, 1, 0, -50924, 1460, 0, 0, 39, '1459'),
	(243, 1, 0, -50924, 1461, 0, 0, 39, '1460'),
	(243, 1, 0, -50924, 1462, 0, 0, 39, '1461'),
	(243, 1, 0, -50924, 1463, 0, 0, 39, '1462'),
	(243, 1, 0, -50924, 1464, 0, 0, 39, '1463'),
	(243, 1, 0, -50924, 1465, 0, 0, 39, '1464'),
	(243, 1, 0, -50924, 1466, 0, 0, 39, '1465'),
	(243, 1, 0, -50924, 1467, 0, 0, 39, '1466'),
	(243, 1, 0, -50924, 1468, 0, 0, 39, '1467'),
	(243, 1, 0, -50924, 1469, 0, 0, 39, '1468'),
	(243, 1, 0, -50924, 1470, 0, 0, 39, '1469'),
	(243, 1, 0, -50924, 1471, 0, 0, 39, '1470'),
	(243, 1, 0, -50924, 1472, 0, 0, 39, '1471'),
	(243, 1, 0, -50924, 1473, 0, 0, 39, '1472'),
	(243, 1, 0, -50924, 1474, 0, 0, 39, '1473'),
	(243, 1, 0, -50924, 1475, 0, 0, 39, '1474'),
	(243, 1, 0, -50924, 1476, 0, 0, 39, '1475'),
	(243, 1, 0, -50924, 1477, 0, 0, 39, '1476'),
	(243, 1, 0, -50924, 1478, 0, 0, 39, '1477'),
	(243, 1, 0, -50924, 1479, 0, 0, 39, '1478'),
	(243, 1, 0, -50924, 1480, 0, 0, 39, '1479'),
	(243, 1, 0, -50924, 1481, 0, 0, 39, '1480'),
	(243, 1, 0, -50924, 1482, 0, 0, 39, '1481'),
	(243, 1, 0, -50924, 1483, 0, 0, 39, '1482'),
	(243, 1, 0, -50924, 1484, 0, 0, 39, '1483'),
	(243, 1, 0, -50924, 1485, 0, 0, 39, '1484'),
	(243, 1, 0, -50924, 1486, 0, 0, 39, '1485'),
	(243, 1, 0, -50924, 1487, 0, 0, 39, '1486'),
	(243, 1, 0, -50924, 1488, 0, 0, 39, '1487'),
	(243, 1, 0, -50924, 1489, 0, 0, 39, '1488'),
	(243, 1, 0, -50924, 1490, 0, 0, 39, '1489'),
	(243, 1, 0, -50924, 1491, 0, 0, 39, '1490'),
	(243, 1, 0, -50924, 1492, 0, 0, 39, '1491'),
	(243, 1, 0, -50924, 1493, 0, 0, 39, '1492'),
	(243, 1, 0, -50924, 1494, 0, 0, 39, '1493'),
	(243, 1, 0, -50924, 1495, 0, 0, 39, '1494'),
	(243, 1, 0, -50924, 1496, 0, 0, 39, '1495'),
	(243, 1, 0, -50924, 1497, 0, 0, 39, '1496'),
	(243, 1, 0, -50924, 1498, 0, 0, 39, '1497'),
	(243, 1, 0, -50924, 1499, 0, 0, 39, '1498'),
	(243, 1, 0, -50924, 1500, 0, 0, 39, '1499'),
	(243, 1, 0, -50924, 1501, 0, 0, 39, '1500'),
	(243, 1, 0, -50924, 1502, 0, 0, 39, '1501'),
	(243, 1, 0, -50924, 1503, 0, 0, 39, '1502'),
	(243, 1, 0, -50924, 1504, 0, 0, 39, '1503'),
	(243, 1, 0, -50924, 1505, 0, 0, 39, '1504'),
	(243, 1, 0, -50924, 1506, 0, 0, 39, '1505'),
	(243, 1, 0, -50924, 1507, 0, 0, 39, '1506'),
	(243, 1, 0, -50924, 1508, 0, 0, 39, '1507'),
	(243, 1, 0, -50924, 1509, 0, 0, 39, '1508'),
	(243, 1, 0, -50924, 1510, 0, 0, 39, '1509'),
	(243, 1, 0, -50924, 1511, 0, 0, 39, '1510'),
	(243, 1, 0, -50924, 1512, 0, 0, 39, '1511'),
	(243, 1, 0, -50924, 1513, 0, 0, 39, '1512'),
	(243, 1, 0, -50924, 1514, 0, 0, 39, '1513'),
	(243, 1, 0, -50924, 1515, 0, 0, 39, '1514'),
	(243, 1, 0, -50924, 1516, 0, 0, 39, '1515'),
	(243, 1, 0, -50924, 1517, 0, 0, 39, '1516'),
	(243, 1, 0, -50924, 1518, 0, 0, 39, '1517'),
	(243, 1, 0, -50924, 1519, 0, 0, 39, '1518'),
	(243, 1, 0, -50924, 1520, 0, 0, 39, '1519'),
	(243, 1, 0, -50924, 1521, 0, 0, 39, '1520'),
	(243, 1, 0, -50924, 1522, 0, 0, 39, '1521'),
	(243, 1, 0, -50924, 1523, 0, 0, 39, '1522'),
	(243, 1, 0, -50924, 1524, 0, 0, 39, '1523'),
	(243, 1, 0, -50924, 1525, 0, 0, 39, '1524'),
	(243, 1, 0, -50924, 1526, 0, 0, 39, '1525'),
	(243, 1, 0, -50924, 1527, 0, 0, 39, '1526'),
	(243, 1, 0, -50924, 1528, 0, 0, 39, '1527'),
	(243, 1, 0, -50924, 1529, 0, 0, 39, '1528'),
	(243, 1, 0, -50924, 1530, 0, 0, 39, '1529'),
	(243, 1, 0, -50924, 1531, 0, 0, 39, '1530'),
	(243, 1, 0, -50924, 1532, 0, 0, 39, '1531'),
	(243, 1, 0, -50924, 1533, 0, 0, 39, '1532'),
	(243, 1, 0, -50924, 1534, 0, 0, 39, '1533'),
	(243, 1, 0, -50924, 1535, 0, 0, 39, '1534'),
	(243, 1, 0, -50924, 1536, 0, 0, 39, '1535'),
	(243, 1, 0, -50924, 1537, 0, 0, 39, '1536'),
	(243, 1, 0, -50924, 1538, 0, 0, 39, '1537'),
	(243, 1, 0, -50924, 1539, 0, 0, 39, '1538'),
	(243, 1, 0, -50924, 1540, 0, 0, 39, '1539'),
	(243, 1, 0, -50924, 1541, 0, 0, 39, '1540'),
	(243, 1, 0, -50924, 1542, 0, 0, 39, '1541'),
	(243, 1, 0, -50924, 1543, 0, 0, 39, '1542'),
	(243, 1, 0, -50924, 1544, 0, 0, 39, '1543'),
	(243, 1, 0, -50924, 1545, 0, 0, 39, '1544'),
	(243, 1, 0, -50924, 1546, 0, 0, 39, '1545'),
	(243, 1, 0, -50924, 1547, 0, 0, 39, '1546'),
	(243, 1, 0, -50924, 1548, 0, 0, 39, '1547'),
	(243, 1, 0, -50924, 1549, 0, 0, 39, '1548'),
	(243, 1, 0, -50924, 1550, 0, 0, 39, '1549'),
	(243, 1, 0, -50924, 1551, 0, 0, 39, '1550'),
	(243, 1, 0, -50924, 1552, 0, 0, 39, '1551'),
	(243, 1, 0, -50924, 1553, 0, 0, 39, '1552'),
	(243, 1, 0, -50924, 1554, 0, 0, 39, '1553'),
	(243, 1, 0, -50924, 1555, 0, 0, 39, '1554'),
	(243, 1, 0, -50924, 1556, 0, 0, 39, '1555'),
	(243, 1, 0, -50924, 1557, 0, 0, 39, '1556'),
	(243, 1, 0, -50924, 1558, 0, 0, 39, '1557'),
	(243, 1, 0, -50924, 1559, 0, 0, 39, '1558'),
	(243, 1, 0, -50924, 1560, 0, 0, 39, '1559'),
	(243, 1, 0, -50924, 1561, 0, 0, 39, '1560'),
	(243, 1, 0, -50924, 1562, 0, 0, 39, '1561'),
	(243, 1, 0, -50924, 1563, 0, 0, 39, '1562'),
	(243, 1, 0, -50924, 1564, 0, 0, 39, '1563'),
	(243, 1, 0, -50924, 1565, 0, 0, 39, '1564'),
	(243, 1, 0, -50924, 1566, 0, 0, 39, '1565'),
	(243, 1, 0, -50924, 1567, 0, 0, 39, '1566'),
	(243, 1, 0, -50924, 1568, 0, 0, 39, '1567'),
	(243, 1, 0, -50924, 1569, 0, 0, 39, '1568'),
	(243, 1, 0, -50924, 1570, 0, 0, 39, '1569'),
	(243, 1, 0, -50924, 1571, 0, 0, 39, '1570'),
	(243, 1, 0, -50924, 1572, 0, 0, 39, '1571'),
	(243, 1, 0, -50924, 1573, 0, 0, 39, '1572'),
	(243, 1, 0, -50924, 1574, 0, 0, 39, '1573'),
	(243, 1, 0, -50924, 1575, 0, 0, 39, '1574'),
	(243, 1, 0, -50924, 1576, 0, 0, 39, '1575'),
	(243, 1, 0, -50924, 1577, 0, 0, 39, '1576'),
	(243, 1, 0, -50924, 1578, 0, 0, 39, '1577'),
	(243, 1, 0, -50924, 1579, 0, 0, 39, '1578'),
	(243, 1, 0, -50924, 1580, 0, 0, 39, '1579'),
	(243, 1, 0, -50924, 1581, 0, 0, 39, '1580'),
	(243, 1, 0, -50924, 1582, 0, 0, 39, '1581'),
	(243, 1, 0, -50924, 1583, 0, 0, 39, '1582'),
	(243, 1, 0, -50924, 1584, 0, 0, 39, '1583'),
	(243, 1, 0, -50924, 1585, 0, 0, 39, '1584'),
	(243, 1, 0, -50924, 1586, 0, 0, 39, '1585'),
	(243, 1, 0, -50924, 1587, 0, 0, 39, '1586'),
	(243, 1, 0, -50924, 1588, 0, 0, 39, '1587'),
	(243, 1, 0, -50924, 1589, 0, 0, 39, '1588'),
	(243, 1, 0, -50924, 1590, 0, 0, 39, '1589'),
	(243, 1, 0, -50924, 1591, 0, 0, 39, '1590'),
	(243, 1, 0, -50924, 1592, 0, 0, 39, '1591'),
	(243, 1, 0, -50924, 1593, 0, 0, 39, '1592'),
	(243, 1, 0, -50924, 1594, 0, 0, 39, '1593'),
	(243, 1, 0, -50924, 1595, 0, 0, 39, '1594'),
	(243, 1, 0, -50924, 1596, 0, 0, 39, '1595'),
	(243, 1, 0, -50924, 1597, 0, 0, 39, '1596'),
	(243, 1, 0, -50924, 1598, 0, 0, 39, '1597'),
	(243, 1, 0, -50924, 1599, 0, 0, 39, '1598'),
	(243, 1, 0, -50924, 1600, 0, 0, 39, '1599'),
	(243, 1, 0, -50924, 1601, 0, 0, 39, '1600'),
	(243, 1, 0, -50924, 1602, 0, 0, 39, '1601'),
	(243, 1, 0, -50924, 1603, 0, 0, 39, '1602'),
	(243, 1, 0, -50924, 1604, 0, 0, 39, '1603'),
	(243, 1, 0, -50924, 1605, 0, 0, 39, '1604'),
	(243, 1, 0, -50924, 1606, 0, 0, 39, '1605'),
	(243, 1, 0, -50924, 1607, 0, 0, 39, '1606'),
	(243, 1, 0, -50924, 1608, 0, 0, 39, '1607'),
	(243, 1, 0, -50924, 1609, 0, 0, 39, '1608'),
	(243, 1, 0, -50924, 1610, 0, 0, 39, '1609'),
	(243, 1, 0, -50924, 1611, 0, 0, 39, '1610'),
	(243, 1, 0, -50924, 1612, 0, 0, 39, '1611'),
	(243, 1, 0, -50924, 1613, 0, 0, 39, '1612'),
	(243, 1, 0, -50924, 1614, 0, 0, 39, '1613'),
	(243, 1, 0, -50924, 1615, 0, 0, 39, '1614'),
	(243, 1, 0, -50924, 1616, 0, 0, 39, '1615'),
	(243, 1, 0, -50924, 1617, 0, 0, 39, '1616'),
	(243, 1, 0, -50924, 1618, 0, 0, 39, '1617'),
	(243, 1, 0, -50924, 1619, 0, 0, 39, '1618'),
	(243, 1, 0, -50924, 1620, 0, 0, 39, '1619'),
	(243, 1, 0, -50924, 1621, 0, 0, 39, '1620'),
	(243, 1, 0, -50924, 1622, 0, 0, 39, '1621'),
	(243, 1, 0, -50924, 1623, 0, 0, 39, '1622'),
	(243, 1, 0, -50924, 1624, 0, 0, 39, '1623'),
	(243, 1, 0, -50924, 1625, 0, 0, 39, '1624'),
	(243, 1, 0, -50924, 1626, 0, 0, 39, '1625'),
	(243, 1, 0, -50924, 1627, 0, 0, 39, '1626'),
	(243, 1, 0, -50924, 1628, 0, 0, 39, '1627'),
	(243, 1, 0, -50924, 1629, 0, 0, 39, '1628'),
	(243, 1, 0, -50924, 1630, 0, 0, 39, '1629'),
	(243, 1, 0, -50924, 1631, 0, 0, 39, '1630'),
	(243, 1, 0, -50924, 1632, 0, 0, 39, '1631'),
	(243, 1, 0, -50924, 1633, 0, 0, 39, '1632'),
	(243, 1, 0, -50924, 1634, 0, 0, 39, '1633'),
	(243, 1, 0, -50924, 1635, 0, 0, 39, '1634'),
	(243, 1, 0, -50924, 1636, 0, 0, 39, '1635'),
	(243, 1, 0, -50924, 1637, 0, 0, 39, '1636'),
	(243, 1, 0, -50924, 1638, 0, 0, 39, '1637'),
	(243, 1, 0, -50924, 1639, 0, 0, 39, '1638'),
	(243, 1, 0, -50924, 1640, 0, 0, 39, '1639'),
	(243, 1, 0, -50924, 1641, 0, 0, 39, '1640'),
	(243, 1, 0, -50924, 1642, 0, 0, 39, '1641'),
	(243, 1, 0, -50924, 1643, 0, 0, 39, '1642'),
	(243, 1, 0, -50924, 1644, 0, 0, 39, '1643'),
	(243, 1, 0, -50924, 1645, 0, 0, 39, '1644'),
	(243, 1, 0, -50924, 1646, 0, 0, 39, '1645'),
	(243, 1, 0, -50924, 1647, 0, 0, 39, '1646'),
	(243, 1, 0, -50924, 1648, 0, 0, 39, '1647'),
	(243, 1, 0, -50924, 1649, 0, 0, 39, '1648'),
	(243, 1, 0, -50924, 1650, 0, 0, 39, '1649'),
	(243, 1, 0, -50924, 1651, 0, 0, 39, '1650'),
	(243, 1, 0, -50924, 1652, 0, 0, 39, '1651'),
	(243, 1, 0, -50924, 1653, 0, 0, 39, '1652'),
	(243, 1, 0, -50924, 1654, 0, 0, 39, '1653'),
	(243, 1, 0, -50924, 1655, 0, 0, 39, '1654'),
	(243, 1, 0, -50924, 1656, 0, 0, 39, '1655'),
	(243, 1, 0, -50924, 1657, 0, 0, 39, '1656'),
	(243, 1, 0, -50924, 1658, 0, 0, 39, '1657'),
	(243, 1, 0, -50924, 1659, 0, 0, 39, '1658'),
	(243, 1, 0, -50924, 1660, 0, 0, 39, '1659'),
	(243, 1, 0, -50924, 1661, 0, 0, 39, '1660'),
	(243, 1, 0, -50924, 1662, 0, 0, 39, '1661'),
	(243, 1, 0, -50924, 1663, 0, 0, 39, '1662'),
	(243, 1, 0, -50924, 1664, 0, 0, 39, '1663'),
	(243, 1, 0, -50924, 1665, 0, 0, 39, '1664'),
	(243, 1, 0, -50924, 1666, 0, 0, 39, '1665'),
	(243, 1, 0, -50924, 1667, 0, 0, 39, '1666'),
	(243, 1, 0, -50924, 1668, 0, 0, 39, '1667'),
	(243, 1, 0, -50924, 1669, 0, 0, 39, '1668'),
	(243, 1, 0, -50924, 1670, 0, 0, 39, '1669'),
	(243, 1, 0, -50924, 1671, 0, 0, 39, '1670'),
	(243, 1, 0, -50924, 1672, 0, 0, 39, '1671'),
	(243, 1, 0, -50924, 1673, 0, 0, 39, '1672'),
	(243, 1, 0, -50924, 1674, 0, 0, 39, '1673'),
	(243, 1, 0, -50924, 1675, 0, 0, 39, '1674'),
	(243, 1, 0, -50924, 1676, 0, 0, 39, '1675'),
	(243, 1, 0, -50924, 1677, 0, 0, 39, '1676'),
	(243, 1, 0, -50924, 1678, 0, 0, 39, '1677'),
	(243, 1, 0, -50924, 1679, 0, 0, 39, '1678'),
	(243, 1, 0, -50924, 1680, 0, 0, 39, '1679'),
	(243, 1, 0, -50924, 1681, 0, 0, 39, '1680'),
	(243, 1, 0, -50924, 1682, 0, 0, 39, '1681'),
	(243, 1, 0, -50924, 1683, 0, 0, 39, '1682'),
	(243, 1, 0, -50924, 1684, 0, 0, 39, '1683'),
	(243, 1, 0, -50924, 1685, 0, 0, 39, '1684'),
	(243, 1, 0, -50924, 1686, 0, 0, 39, '1685'),
	(243, 1, 0, -50924, 1687, 0, 0, 39, '1686'),
	(243, 1, 0, -50924, 1688, 0, 0, 39, '1687'),
	(243, 1, 0, -50924, 1689, 0, 0, 39, '1688'),
	(243, 1, 0, -50924, 1690, 0, 0, 39, '1689'),
	(243, 1, 0, -50924, 1691, 0, 0, 39, '1690'),
	(243, 1, 0, -50924, 1692, 0, 0, 39, '1691'),
	(243, 1, 0, -50924, 1693, 0, 0, 39, '1692'),
	(243, 1, 0, -50924, 1694, 0, 0, 39, '1693'),
	(243, 1, 0, -50924, 1695, 0, 0, 39, '1694'),
	(243, 1, 0, -50924, 1696, 0, 0, 39, '1695'),
	(243, 1, 0, -50924, 1697, 0, 0, 39, '1696'),
	(243, 1, 0, -50924, 1698, 0, 0, 39, '1697'),
	(243, 1, 0, -50924, 1699, 0, 0, 39, '1698'),
	(243, 1, 0, -50924, 1700, 0, 0, 39, '1699'),
	(243, 1, 0, -50924, 1701, 0, 0, 39, '1700'),
	(243, 1, 0, -50924, 1702, 0, 0, 39, '1701'),
	(243, 1, 0, -50924, 1703, 0, 0, 39, '1702'),
	(243, 1, 0, -50924, 1704, 0, 0, 39, '1703'),
	(243, 1, 0, -50924, 1705, 0, 0, 39, '1704'),
	(243, 1, 0, -50924, 1706, 0, 0, 39, '1705'),
	(243, 1, 0, -50924, 1707, 0, 0, 39, '1706'),
	(243, 1, 0, -50924, 1708, 0, 0, 39, '1707'),
	(243, 1, 0, -50924, 1709, 0, 0, 39, '1708'),
	(243, 1, 0, -50924, 1710, 0, 0, 39, '1709'),
	(243, 1, 0, -50924, 1711, 0, 0, 39, '1710'),
	(243, 1, 0, -50924, 1712, 0, 0, 39, '1711'),
	(243, 1, 0, -50924, 1713, 0, 0, 39, '1712'),
	(243, 1, 0, -50924, 1714, 0, 0, 39, '1713'),
	(243, 1, 0, -50924, 1715, 0, 0, 39, '1714'),
	(243, 1, 0, -50924, 1716, 0, 0, 39, '1715'),
	(243, 1, 0, -50924, 1717, 0, 0, 39, '1716'),
	(243, 1, 0, -50924, 1718, 0, 0, 39, '1717'),
	(243, 1, 0, -50924, 1719, 0, 0, 39, '1718'),
	(243, 1, 0, -50924, 1720, 0, 0, 39, '1719'),
	(243, 1, 0, -50924, 1721, 0, 0, 39, '1720'),
	(243, 1, 0, -50924, 1722, 0, 0, 39, '1721'),
	(243, 1, 0, -50924, 1723, 0, 0, 39, '1722'),
	(243, 1, 0, -50924, 1724, 0, 0, 39, '1723'),
	(243, 1, 0, -50924, 1725, 0, 0, 39, '1724'),
	(243, 1, 0, -50924, 1726, 0, 0, 39, '1725'),
	(243, 1, 0, -50924, 1727, 0, 0, 39, '1726'),
	(243, 1, 0, -50924, 1728, 0, 0, 39, '1727'),
	(243, 1, 0, -50924, 1729, 0, 0, 39, '1728'),
	(243, 1, 0, -50924, 1730, 0, 0, 39, '1729'),
	(243, 1, 0, -50924, 1731, 0, 0, 39, '1730'),
	(243, 1, 0, -50924, 1732, 0, 0, 39, '1731'),
	(243, 1, 0, -50924, 1733, 0, 0, 39, '1732'),
	(243, 1, 0, -50924, 1734, 0, 0, 39, '1733'),
	(243, 1, 0, -50924, 1735, 0, 0, 39, '1734'),
	(243, 1, 0, -50924, 1736, 0, 0, 39, '1735'),
	(243, 1, 0, -50924, 1737, 0, 0, 39, '1736'),
	(243, 1, 0, -50924, 1738, 0, 0, 39, '1737'),
	(243, 1, 0, -50924, 1739, 0, 0, 39, '1738'),
	(243, 1, 0, -50924, 1740, 0, 0, 39, '1739'),
	(243, 1, 0, -50924, 1741, 0, 0, 39, '1740'),
	(243, 1, 0, -50924, 1742, 0, 0, 39, '1741'),
	(243, 1, 0, -50924, 1743, 0, 0, 39, '1742'),
	(243, 1, 0, -50924, 1744, 0, 0, 39, '1743'),
	(243, 1, 0, -50924, 1745, 0, 0, 39, '1744'),
	(243, 1, 0, -50924, 1746, 0, 0, 39, '1745'),
	(243, 1, 0, -50924, 1747, 0, 0, 39, '1746'),
	(243, 1, 0, -50924, 1748, 0, 0, 39, '1747'),
	(243, 1, 0, -50924, 1749, 0, 0, 39, '1748'),
	(243, 1, 0, -50924, 1750, 0, 0, 39, '1749'),
	(243, 1, 0, -50924, 1751, 0, 0, 39, '1750'),
	(243, 1, 0, -50924, 1752, 0, 0, 39, '1751'),
	(243, 1, 0, -50924, 1753, 0, 0, 39, '1752'),
	(243, 1, 0, -50924, 1754, 0, 0, 39, '1753'),
	(243, 1, 0, -50924, 1755, 0, 0, 39, '1754'),
	(243, 1, 0, -50924, 1756, 0, 0, 39, '1755'),
	(243, 1, 0, -50924, 1757, 0, 0, 39, '1756'),
	(243, 1, 0, -50924, 1758, 0, 0, 39, '1757'),
	(243, 1, 0, -50924, 1759, 0, 0, 39, '1758'),
	(243, 1, 0, -50924, 1760, 0, 0, 39, '1759'),
	(243, 1, 0, -50924, 1761, 0, 0, 39, '1760'),
	(243, 1, 0, -50924, 1762, 0, 0, 39, '1761'),
	(243, 1, 0, -50924, 1763, 0, 0, 39, '1762'),
	(243, 1, 0, -50924, 1764, 0, 0, 39, '1763'),
	(243, 1, 0, -50924, 1765, 0, 0, 39, '1764'),
	(243, 1, 0, -50924, 1766, 0, 0, 39, '1765'),
	(243, 1, 0, -50924, 1767, 0, 0, 39, '1766'),
	(243, 1, 0, -50924, 1768, 0, 0, 39, '1767'),
	(243, 1, 0, -50924, 1769, 0, 0, 39, '1768'),
	(243, 1, 0, -50924, 1770, 0, 0, 39, '1769'),
	(243, 1, 0, -50924, 1771, 0, 0, 39, '1770'),
	(243, 1, 0, -50924, 1772, 0, 0, 39, '1771'),
	(243, 1, 0, -50924, 1773, 0, 0, 39, '1772'),
	(243, 1, 0, -50924, 1774, 0, 0, 39, '1773'),
	(243, 1, 0, -50924, 1775, 0, 0, 39, '1774'),
	(243, 1, 0, -50924, 1776, 0, 0, 39, '1775'),
	(243, 1, 0, -50924, 1777, 0, 0, 39, '1776'),
	(243, 1, 0, -50924, 1778, 0, 0, 39, '1777'),
	(243, 1, 0, -50924, 1779, 0, 0, 39, '1778'),
	(243, 1, 0, -50924, 1780, 0, 0, 39, '1779'),
	(243, 1, 0, -50924, 1781, 0, 0, 39, '1780'),
	(243, 1, 0, -50924, 1782, 0, 0, 39, '1781'),
	(243, 1, 0, -50924, 1783, 0, 0, 39, '1782'),
	(243, 1, 0, -50924, 1784, 0, 0, 39, '1783'),
	(243, 1, 0, -50924, 1785, 0, 0, 39, '1784'),
	(243, 1, 0, -50924, 1786, 0, 0, 39, '1785'),
	(243, 1, 0, -50924, 1787, 0, 0, 39, '1786'),
	(243, 1, 0, -50924, 1788, 0, 0, 39, '1787'),
	(243, 1, 0, -50924, 1789, 0, 0, 39, '1788'),
	(243, 1, 0, -50924, 1790, 0, 0, 39, '1789'),
	(243, 1, 0, -50924, 1791, 0, 0, 39, '1790'),
	(243, 1, 0, -50924, 1792, 0, 0, 39, '1791'),
	(243, 1, 0, -50924, 1793, 0, 0, 39, '1792'),
	(243, 1, 0, -50924, 1794, 0, 0, 39, '1793'),
	(243, 1, 0, -50924, 1795, 0, 0, 39, '1794'),
	(243, 1, 0, -50924, 1796, 0, 0, 39, '1795'),
	(243, 1, 0, -50924, 1797, 0, 0, 39, '1796'),
	(243, 1, 0, -50924, 1798, 0, 0, 39, '1797'),
	(243, 1, 0, -50924, 1799, 0, 0, 39, '1798'),
	(243, 1, 0, -50924, 1800, 0, 0, 39, '1799'),
	(243, 1, 0, -50924, 1801, 0, 0, 39, '1800'),
	(243, 1, 0, -50924, 1802, 0, 0, 39, '1801'),
	(243, 1, 0, -50924, 1803, 0, 0, 39, '1802'),
	(243, 1, 0, -50924, 1804, 0, 0, 39, '1803'),
	(243, 1, 0, -50924, 1805, 0, 0, 39, '1804'),
	(243, 1, 0, -50924, 1806, 0, 0, 39, '1805'),
	(243, 1, 0, -50924, 1807, 0, 0, 39, '1806'),
	(243, 1, 0, -50924, 1808, 0, 0, 39, '1807'),
	(243, 1, 0, -50924, 1809, 0, 0, 39, '1808'),
	(243, 1, 0, -50924, 1810, 0, 0, 39, '1809'),
	(243, 1, 0, -50924, 1811, 0, 0, 39, '1810'),
	(243, 1, 0, -50924, 1812, 0, 0, 39, '1811'),
	(243, 1, 0, -50924, 1813, 0, 0, 39, '1812'),
	(243, 1, 0, -50924, 1814, 0, 0, 39, '1813'),
	(243, 1, 0, -50924, 1815, 0, 0, 39, '1814'),
	(243, 1, 0, -50924, 1816, 0, 0, 39, '1815'),
	(243, 1, 0, -50924, 1817, 0, 0, 39, '1816'),
	(243, 1, 0, -50924, 1818, 0, 0, 39, '1817'),
	(243, 1, 0, -50924, 1819, 0, 0, 39, '1818'),
	(243, 1, 0, -50924, 1820, 0, 0, 39, '1819'),
	(243, 1, 0, -50924, 1821, 0, 0, 39, '1820'),
	(243, 1, 0, -50924, 1822, 0, 0, 39, '1821'),
	(243, 1, 0, -50924, 1823, 0, 0, 39, '1822'),
	(243, 1, 0, -50924, 1824, 0, 0, 39, '1823'),
	(243, 1, 0, -50924, 1825, 0, 0, 39, '1824'),
	(243, 1, 0, -50924, 1826, 0, 0, 39, '1825'),
	(243, 1, 0, -50924, 1827, 0, 0, 39, '1826'),
	(243, 1, 0, -50924, 1828, 0, 0, 39, '1827'),
	(243, 1, 0, -50924, 1829, 0, 0, 39, '1828'),
	(243, 1, 0, -50924, 1830, 0, 0, 39, '1829'),
	(243, 1, 0, -50924, 1831, 0, 0, 39, '1830'),
	(243, 1, 0, -50924, 1832, 0, 0, 39, '1831'),
	(243, 1, 0, -50924, 1833, 0, 0, 39, '1832'),
	(243, 1, 0, -50924, 1834, 0, 0, 39, '1833'),
	(243, 1, 0, -50924, 1835, 0, 0, 39, '1834'),
	(243, 1, 0, -50924, 1836, 0, 0, 39, '1835'),
	(243, 1, 0, -50924, 1837, 0, 0, 39, '1836'),
	(243, 1, 0, -50924, 1838, 0, 0, 39, '1837'),
	(243, 1, 0, -50924, 1839, 0, 0, 39, '1838'),
	(243, 1, 0, -50924, 1840, 0, 0, 39, '1839'),
	(243, 1, 0, -50924, 1841, 0, 0, 39, '1840'),
	(243, 1, 0, -50924, 1842, 0, 0, 39, '1841'),
	(243, 1, 0, -50924, 1843, 0, 0, 39, '1842'),
	(243, 1, 0, -50924, 1844, 0, 0, 39, '1843'),
	(243, 1, 0, -50924, 1845, 0, 0, 39, '1844'),
	(243, 1, 0, -50924, 1846, 0, 0, 39, '1845'),
	(243, 1, 0, -50924, 1847, 0, 0, 39, '1846'),
	(243, 1, 0, -50924, 1848, 0, 0, 39, '1847'),
	(243, 1, 0, -50924, 1849, 0, 0, 39, '1848'),
	(243, 1, 0, -50924, 1850, 0, 0, 39, '1849'),
	(243, 1, 0, -50924, 1851, 0, 0, 39, '1850'),
	(243, 1, 0, -50924, 1852, 0, 0, 39, '1851'),
	(243, 1, 0, -50924, 1853, 0, 0, 39, '1852'),
	(243, 1, 0, -50924, 1854, 0, 0, 39, '1853'),
	(243, 1, 0, -50924, 1855, 0, 0, 39, '1854'),
	(243, 1, 0, -50924, 1856, 0, 0, 39, '1855'),
	(243, 1, 0, -50924, 1857, 0, 0, 39, '1856'),
	(243, 1, 0, -50924, 1858, 0, 0, 39, '1857'),
	(243, 1, 0, -50924, 1859, 0, 0, 39, '1858'),
	(243, 1, 0, -50924, 1860, 0, 0, 39, '1859'),
	(243, 1, 0, -50924, 1861, 0, 0, 39, '1860'),
	(243, 1, 0, -50924, 1862, 0, 0, 39, '1861'),
	(243, 1, 0, -50924, 1863, 0, 0, 39, '1862'),
	(243, 1, 0, -50924, 1864, 0, 0, 39, '1863'),
	(243, 1, 0, -50924, 1865, 0, 0, 39, '1864'),
	(243, 1, 0, -50924, 1866, 0, 0, 39, '1865'),
	(243, 1, 0, -50924, 1867, 0, 0, 39, '1866'),
	(243, 1, 0, -50924, 1868, 0, 0, 39, '1867'),
	(243, 1, 0, -50924, 1869, 0, 0, 39, '1868'),
	(243, 1, 0, -50924, 1870, 0, 0, 39, '1869'),
	(243, 1, 0, -50924, 1871, 0, 0, 39, '1870'),
	(243, 1, 0, -50924, 1872, 0, 0, 39, '1871'),
	(243, 1, 0, -50924, 1873, 0, 0, 39, '1872'),
	(243, 1, 0, -50924, 1874, 0, 0, 39, '1873'),
	(243, 1, 0, -50924, 1875, 0, 0, 39, '1874'),
	(243, 1, 0, -50924, 1876, 0, 0, 39, '1875'),
	(243, 1, 0, -50924, 1877, 0, 0, 39, '1876'),
	(243, 1, 0, -50924, 1878, 0, 0, 39, '1877'),
	(243, 1, 0, -50924, 1879, 0, 0, 39, '1878'),
	(243, 1, 0, -50924, 1880, 0, 0, 39, '1879'),
	(243, 1, 0, -50924, 1881, 0, 0, 39, '1880'),
	(243, 1, 0, -50924, 1882, 0, 0, 39, '1881'),
	(243, 1, 0, -50924, 1883, 0, 0, 39, '1882'),
	(243, 1, 0, -50924, 1884, 0, 0, 39, '1883'),
	(243, 1, 0, -50924, 1885, 0, 0, 39, '1884'),
	(243, 1, 0, -50924, 1886, 0, 0, 39, '1885'),
	(243, 1, 0, -50924, 1887, 0, 0, 39, '1886'),
	(243, 1, 0, -50924, 1888, 0, 0, 39, '1887'),
	(243, 1, 0, -50924, 1889, 0, 0, 39, '1888'),
	(243, 1, 0, -50924, 1890, 0, 0, 39, '1889'),
	(243, 1, 0, -50924, 1891, 0, 0, 39, '1890'),
	(243, 1, 0, -50924, 1892, 0, 0, 39, '1891'),
	(243, 1, 0, -50924, 1893, 0, 0, 39, '1892'),
	(243, 1, 0, -50924, 1894, 0, 0, 39, '1893'),
	(243, 1, 0, -50924, 1895, 0, 0, 39, '1894'),
	(243, 1, 0, -50924, 1896, 0, 0, 39, '1895'),
	(243, 1, 0, -50924, 1897, 0, 0, 39, '1896'),
	(243, 1, 0, -50924, 1898, 0, 0, 39, '1897'),
	(243, 1, 0, -50924, 1899, 0, 0, 39, '1898'),
	(243, 1, 0, -50924, 1900, 0, 0, 39, '1899'),
	(243, 1, 0, -50924, 1901, 0, 0, 39, '1900'),
	(243, 1, 0, -50924, 1902, 0, 0, 39, '1901'),
	(243, 1, 0, -50924, 1903, 0, 0, 39, '1902'),
	(243, 1, 0, -50924, 1904, 0, 0, 39, '1903'),
	(243, 1, 0, -50924, 1905, 0, 0, 39, '1904'),
	(243, 1, 0, -50924, 1906, 0, 0, 39, '1905'),
	(243, 1, 0, -50924, 1907, 0, 0, 39, '1906'),
	(243, 1, 0, -50924, 1908, 0, 0, 39, '1907'),
	(243, 1, 0, -50924, 1909, 0, 0, 39, '1908'),
	(243, 1, 0, -50924, 1910, 0, 0, 39, '1909'),
	(243, 1, 0, -50924, 1911, 0, 0, 39, '1910'),
	(243, 1, 0, -50924, 1912, 0, 0, 39, '1911'),
	(243, 1, 0, -50924, 1913, 0, 0, 39, '1912'),
	(243, 1, 0, -50924, 1914, 0, 0, 39, '1913'),
	(243, 1, 0, -50924, 1915, 0, 0, 39, '1914'),
	(243, 1, 0, -50924, 1916, 0, 0, 39, '1915'),
	(243, 1, 0, -50924, 1917, 0, 0, 39, '1916'),
	(243, 1, 0, -50924, 1918, 0, 0, 39, '1917'),
	(243, 1, 0, -50924, 1919, 0, 0, 39, '1918'),
	(243, 1, 0, -50924, 1920, 0, 0, 39, '1919'),
	(243, 1, 0, -50924, 1921, 0, 0, 39, '1920'),
	(243, 1, 0, -50924, 1922, 0, 0, 39, '1921'),
	(243, 1, 0, -50924, 1923, 0, 0, 39, '1922'),
	(243, 1, 0, -50924, 1924, 0, 0, 39, '1923'),
	(243, 1, 0, -50924, 1925, 0, 0, 39, '1924'),
	(243, 1, 0, -50924, 1926, 0, 0, 39, '1925'),
	(243, 1, 0, -50924, 1927, 0, 0, 39, '1926'),
	(243, 1, 0, -50924, 1928, 0, 0, 39, '1927'),
	(243, 1, 0, -50924, 1929, 0, 0, 39, '1928'),
	(243, 1, 0, -50924, 1930, 0, 0, 39, '1929'),
	(243, 1, 0, -50924, 1931, 0, 0, 39, '1930'),
	(243, 1, 0, -50924, 1932, 0, 0, 39, '1931'),
	(243, 1, 0, -50924, 1933, 0, 0, 39, '1932'),
	(243, 1, 0, -50924, 1934, 0, 0, 39, '1933'),
	(243, 1, 0, -50924, 1935, 0, 0, 39, '1934'),
	(243, 1, 0, -50924, 1936, 0, 0, 39, '1935'),
	(243, 1, 0, -50924, 1937, 0, 0, 39, '1936'),
	(243, 1, 0, -50924, 1938, 0, 0, 39, '1937'),
	(243, 1, 0, -50924, 1939, 0, 0, 39, '1938'),
	(243, 1, 0, -50924, 1940, 0, 0, 39, '1939'),
	(243, 1, 0, -50924, 1941, 0, 0, 39, '1940'),
	(243, 1, 0, -50924, 1942, 0, 0, 39, '1941'),
	(243, 1, 0, -50924, 1943, 0, 0, 39, '1942'),
	(243, 1, 0, -50924, 1944, 0, 0, 39, '1943'),
	(243, 1, 0, -50924, 1945, 0, 0, 39, '1944'),
	(243, 1, 0, -50924, 1946, 0, 0, 39, '1945'),
	(243, 1, 0, -50924, 1947, 0, 0, 39, '1946'),
	(243, 1, 0, -50924, 1948, 0, 0, 39, '1947'),
	(243, 1, 0, -50924, 1949, 0, 0, 39, '1948'),
	(243, 1, 0, -50924, 1950, 0, 0, 39, '1949'),
	(243, 1, 0, -50924, 1951, 0, 0, 39, '1950'),
	(243, 1, 0, -50924, 1952, 0, 0, 39, '1951'),
	(243, 1, 0, -50924, 1953, 0, 0, 39, '1952'),
	(243, 1, 0, -50924, 1954, 0, 0, 39, '1953'),
	(243, 1, 0, -50924, 1955, 0, 0, 39, '1954'),
	(243, 1, 0, -50924, 1956, 0, 0, 39, '1955'),
	(243, 1, 0, -50924, 1957, 0, 0, 39, '1956'),
	(243, 1, 0, -50924, 1958, 0, 0, 39, '1957'),
	(243, 1, 0, -50924, 1959, 0, 0, 39, '1958'),
	(243, 1, 0, -50924, 1960, 0, 0, 39, '1959'),
	(243, 1, 0, -50924, 1961, 0, 0, 39, '1960'),
	(243, 1, 0, -50924, 1962, 0, 0, 39, '1961'),
	(243, 1, 0, -50924, 1963, 0, 0, 39, '1962'),
	(243, 1, 0, -50924, 1964, 0, 0, 39, '1963'),
	(243, 1, 0, -50924, 1965, 0, 0, 39, '1964'),
	(243, 1, 0, -50924, 1966, 0, 0, 39, '1965'),
	(243, 1, 0, -50924, 1967, 0, 0, 39, '1966'),
	(243, 1, 0, -50924, 1968, 0, 0, 39, '1967'),
	(243, 1, 0, -50924, 1969, 0, 0, 39, '1968'),
	(243, 1, 0, -50924, 1970, 0, 0, 39, '1969'),
	(243, 1, 0, -50924, 1971, 0, 0, 39, '1970'),
	(243, 1, 0, -50924, 1972, 0, 0, 39, '1971'),
	(243, 1, 0, -50924, 1973, 0, 0, 39, '1972'),
	(243, 1, 0, -50924, 1974, 0, 0, 39, '1973'),
	(243, 1, 0, -50924, 1975, 0, 0, 39, '1974'),
	(243, 1, 0, -50924, 1976, 0, 0, 39, '1975'),
	(243, 1, 0, -50924, 1977, 0, 0, 39, '1976'),
	(243, 1, 0, -50924, 1978, 0, 0, 39, '1977'),
	(243, 1, 0, -50924, 1979, 0, 0, 39, '1978'),
	(243, 1, 0, -50924, 1980, 0, 0, 39, '1979'),
	(243, 1, 0, -50924, 1981, 0, 0, 39, '1980'),
	(243, 1, 0, -50924, 1982, 0, 0, 39, '1981'),
	(243, 1, 0, -50924, 1983, 0, 0, 39, '1982'),
	(243, 1, 0, -50924, 1984, 0, 0, 39, '1983'),
	(243, 1, 0, -50924, 1985, 0, 0, 39, '1984'),
	(243, 1, 0, -50924, 1986, 0, 0, 39, '1985'),
	(243, 1, 0, -50924, 1987, 0, 0, 39, '1986'),
	(243, 1, 0, -50924, 1988, 0, 0, 39, '1987'),
	(243, 1, 0, -50924, 1989, 0, 0, 39, '1988'),
	(243, 1, 0, -50924, 1990, 0, 0, 39, '1989'),
	(243, 1, 0, -50924, 1991, 0, 0, 39, '1990'),
	(243, 1, 0, -50924, 1992, 0, 0, 39, '1991'),
	(243, 1, 0, -50924, 1993, 0, 0, 39, '1992'),
	(243, 1, 0, -50924, 1994, 0, 0, 39, '1993'),
	(243, 1, 0, -50924, 1995, 0, 0, 39, '1994'),
	(243, 1, 0, -50924, 1996, 0, 0, 39, '1995'),
	(243, 1, 0, -50924, 1997, 0, 0, 39, '1996'),
	(243, 1, 0, -50924, 1998, 0, 0, 39, '1997'),
	(243, 1, 0, -50924, 1999, 0, 0, 39, '1998'),
	(243, 1, 0, -50924, 2000, 0, 0, 39, '1999'),
	(243, 1, 0, -50924, 2001, 0, 0, 39, '2000'),
	(243, 1, 0, -50924, 2002, 0, 0, 39, '2001'),
	(243, 1, 0, -50924, 2003, 0, 0, 39, '2002'),
	(243, 1, 0, -50924, 2004, 0, 0, 39, '2003'),
	(243, 1, 0, -50924, 2005, 0, 0, 39, '2004'),
	(243, 1, 0, -50924, 2006, 0, 0, 39, '2005'),
	(243, 1, 0, -50924, 2007, 0, 0, 39, '2006'),
	(243, 1, 0, -50924, 2008, 0, 0, 39, '2007'),
	(243, 1, 0, -50924, 2009, 0, 0, 39, '2008'),
	(243, 1, 0, -50924, 2010, 0, 0, 39, '2009'),
	(243, 1, 0, -50924, 2011, 0, 0, 39, '2010'),
	(243, 1, 0, -50924, 2012, 0, 0, 39, '2011'),
	(243, 1, 0, -50924, 2013, 0, 0, 39, '2012'),
	(243, 1, 0, -50924, 2014, 0, 0, 39, '2013'),
	(243, 1, 0, -50924, 2015, 0, 0, 39, '2014'),
	(243, 1, 0, -50924, 2016, 0, 0, 39, '2015'),
	(243, 1, 0, -50924, 2017, 0, 0, 39, '2016'),
	(243, 1, 0, -50924, 2018, 0, 0, 39, '2017'),
	(243, 1, 0, -50924, 2019, 0, 0, 39, '2018'),
	(243, 1, 0, -50924, 2020, 0, 0, 39, '2019'),
	(243, 1, 0, -50924, 2021, 0, 0, 39, '2020'),
	(243, 1, 0, -50924, 2022, 0, 0, 39, '2021'),
	(243, 1, 0, -50924, 2023, 0, 0, 39, '2022'),
	(243, 1, 0, -50924, 2024, 0, 0, 39, '2023'),
	(243, 1, 0, -50924, 2025, 0, 0, 39, '2024'),
	(243, 1, 0, -50924, 2026, 0, 0, 39, '2025'),
	(243, 1, 0, -50924, 2027, 0, 0, 39, '2026'),
	(243, 1, 0, -50924, 2028, 0, 0, 39, '2027'),
	(243, 1, 0, -50924, 2029, 0, 0, 39, '2028'),
	(243, 1, 0, -50924, 2030, 0, 0, 39, '2029'),
	(243, 1, 0, -50924, 2031, 0, 0, 39, '2030'),
	(243, 1, 0, -50924, 2032, 0, 0, 39, '2031'),
	(243, 1, 0, -50924, 2033, 0, 0, 39, '2032'),
	(243, 1, 0, -50924, 2034, 0, 0, 39, '2033'),
	(243, 1, 0, -50924, 2035, 0, 0, 39, '2034'),
	(243, 1, 0, -50924, 2036, 0, 0, 39, '2035'),
	(243, 1, 0, -50924, 2037, 0, 0, 39, '2036'),
	(243, 1, 0, -50924, 2038, 0, 0, 39, '2037'),
	(243, 1, 0, -50924, 2039, 0, 0, 39, '2038'),
	(243, 1, 0, -50924, 2040, 0, 0, 39, '2039'),
	(243, 1, 0, -50924, 2041, 0, 0, 39, '2040'),
	(243, 1, 0, -50924, 2042, 0, 0, 39, '2041'),
	(243, 1, 0, -50924, 2043, 0, 0, 39, '2042'),
	(243, 1, 0, -50924, 2044, 0, 0, 39, '2043'),
	(243, 1, 0, -50924, 2045, 0, 0, 39, '2044'),
	(243, 1, 0, -50924, 2046, 0, 0, 39, '2045'),
	(243, 1, 0, -50924, 2047, 0, 0, 39, '2046'),
	(243, 1, 0, -50924, 2048, 0, 0, 39, '2047'),
	(243, 1, 0, -50553, 1, 0, 0, 39, '0'),
	(243, 1, 0, -50553, 2, 0, 0, 39, '1'),
	(243, 1, 0, -50553, 3, 0, 0, 39, '2'),
	(243, 1, 0, -50553, 4, 0, 0, 39, '3'),
	(243, 1, 0, -50553, 5, 0, 0, 39, '4'),
	(243, 1, 0, -50553, 6, 0, 0, 39, '5'),
	(243, 1, 0, -50553, 7, 0, 0, 39, '6'),
	(243, 1, 0, -50553, 8, 0, 0, 39, '7'),
	(243, 1, 0, -50553, 9, 0, 0, 39, '8'),
	(243, 1, 0, -50553, 10, 0, 0, 39, '9'),
	(243, 1, 0, -50553, 11, 0, 0, 39, '10'),
	(243, 1, 0, -50553, 12, 0, 0, 39, '11'),
	(243, 1, 0, -50553, 13, 0, 0, 39, '12'),
	(243, 1, 0, -50553, 14, 0, 0, 39, '13'),
	(243, 1, 0, -50553, 15, 0, 0, 39, '14'),
	(243, 1, 0, -50553, 16, 0, 0, 39, '15'),
	(243, 1, 0, -50553, 17, 0, 0, 39, '16'),
	(243, 1, 0, -50553, 18, 0, 0, 39, '17'),
	(243, 1, 0, -50553, 19, 0, 0, 39, '18'),
	(243, 1, 0, -50553, 20, 0, 0, 39, '19'),
	(243, 1, 0, -50553, 21, 0, 0, 39, '20'),
	(243, 1, 0, -50553, 22, 0, 0, 39, '21'),
	(243, 1, 0, -50553, 23, 0, 0, 39, '22'),
	(243, 1, 0, -50553, 24, 0, 0, 39, '23');
INSERT INTO `src_type_mod_withe#opty` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`, `ind1`, `ind2`, `ind3`, `opty_id`, `opty_value`) VALUES
	(243, 1, 0, -50553, 25, 0, 0, 39, '24'),
	(243, 1, 0, -50553, 26, 0, 0, 39, '25'),
	(243, 1, 0, -50553, 27, 0, 0, 39, '26'),
	(243, 1, 0, -50553, 28, 0, 0, 39, '27'),
	(243, 1, 0, -50553, 29, 0, 0, 39, '28'),
	(243, 1, 0, -50553, 30, 0, 0, 39, '29'),
	(243, 1, 0, -50553, 31, 0, 0, 39, '30'),
	(243, 1, 0, -50553, 32, 0, 0, 39, '31'),
	(243, 1, 0, -50553, 33, 0, 0, 39, '32'),
	(243, 1, 0, -50553, 34, 0, 0, 39, '33'),
	(243, 1, 0, -50553, 35, 0, 0, 39, '34'),
	(243, 1, 0, -50553, 36, 0, 0, 39, '35'),
	(243, 1, 0, -50553, 37, 0, 0, 39, '36'),
	(243, 1, 0, -50553, 38, 0, 0, 39, '37'),
	(243, 1, 0, -50553, 39, 0, 0, 39, '38'),
	(243, 1, 0, -50553, 40, 0, 0, 39, '39'),
	(243, 1, 0, -50553, 41, 0, 0, 39, '40'),
	(243, 1, 0, -50553, 42, 0, 0, 39, '41'),
	(243, 1, 0, -50553, 43, 0, 0, 39, '42'),
	(243, 1, 0, -50553, 44, 0, 0, 39, '43'),
	(243, 1, 0, -50553, 45, 0, 0, 39, '44'),
	(243, 1, 0, -50553, 46, 0, 0, 39, '45'),
	(243, 1, 0, -50553, 47, 0, 0, 39, '46'),
	(243, 1, 0, -50553, 48, 0, 0, 39, '47'),
	(243, 1, 0, -50553, 49, 0, 0, 39, '48'),
	(243, 1, 0, -50553, 50, 0, 0, 39, '49'),
	(243, 1, 0, -50553, 51, 0, 0, 39, '50'),
	(243, 1, 0, -50553, 52, 0, 0, 39, '51'),
	(243, 1, 0, -50553, 53, 0, 0, 39, '52'),
	(243, 1, 0, -50553, 54, 0, 0, 39, '53'),
	(243, 1, 0, -50553, 55, 0, 0, 39, '54'),
	(243, 1, 0, -50553, 56, 0, 0, 39, '55'),
	(243, 1, 0, -50553, 57, 0, 0, 39, '56'),
	(243, 1, 0, -50553, 58, 0, 0, 39, '57'),
	(243, 1, 0, -50553, 59, 0, 0, 39, '58'),
	(243, 1, 0, -50553, 60, 0, 0, 39, '59'),
	(243, 1, 0, -50553, 61, 0, 0, 39, '60'),
	(243, 1, 0, -50553, 62, 0, 0, 39, '61'),
	(243, 1, 0, -50553, 63, 0, 0, 39, '62'),
	(243, 1, 0, -50553, 64, 0, 0, 39, '63'),
	(243, 1, 0, -50553, 65, 0, 0, 39, '64'),
	(243, 1, 0, -50553, 66, 0, 0, 39, '65'),
	(243, 1, 0, -50553, 67, 0, 0, 39, '66'),
	(243, 1, 0, -50553, 68, 0, 0, 39, '67'),
	(243, 1, 0, -50553, 69, 0, 0, 39, '68'),
	(243, 1, 0, -50553, 70, 0, 0, 39, '69'),
	(243, 1, 0, -50553, 71, 0, 0, 39, '70'),
	(243, 1, 0, -50553, 72, 0, 0, 39, '71'),
	(243, 1, 0, -50553, 73, 0, 0, 39, '72'),
	(243, 1, 0, -50553, 74, 0, 0, 39, '73'),
	(243, 1, 0, -50553, 75, 0, 0, 39, '74'),
	(243, 1, 0, -50553, 76, 0, 0, 39, '75'),
	(243, 1, 0, -50553, 77, 0, 0, 39, '76'),
	(243, 1, 0, -50553, 78, 0, 0, 39, '77'),
	(243, 1, 0, -50553, 79, 0, 0, 39, '78'),
	(243, 1, 0, -50553, 80, 0, 0, 39, '79'),
	(243, 1, 0, -50553, 81, 0, 0, 39, '80'),
	(243, 1, 0, -50553, 82, 0, 0, 39, '81'),
	(243, 1, 0, -50553, 83, 0, 0, 39, '82'),
	(243, 1, 0, -50553, 84, 0, 0, 39, '83'),
	(243, 1, 0, -50553, 85, 0, 0, 39, '84'),
	(243, 1, 0, -50553, 86, 0, 0, 39, '85'),
	(243, 1, 0, -50553, 87, 0, 0, 39, '86'),
	(243, 1, 0, -50553, 88, 0, 0, 39, '87'),
	(243, 1, 0, -50553, 89, 0, 0, 39, '88'),
	(243, 1, 0, -50553, 90, 0, 0, 39, '89'),
	(243, 1, 0, -50553, 91, 0, 0, 39, '90'),
	(243, 1, 0, -50553, 92, 0, 0, 39, '91'),
	(243, 1, 0, -50553, 93, 0, 0, 39, '92'),
	(243, 1, 0, -50553, 94, 0, 0, 39, '93'),
	(243, 1, 0, -50553, 95, 0, 0, 39, '94'),
	(243, 1, 0, -50553, 96, 0, 0, 39, '95'),
	(243, 1, 0, -50553, 97, 0, 0, 39, '96'),
	(243, 1, 0, -50553, 98, 0, 0, 39, '97'),
	(243, 1, 0, -50553, 99, 0, 0, 39, '98'),
	(243, 1, 0, -50553, 100, 0, 0, 39, '99'),
	(243, 1, 0, -50553, 101, 0, 0, 39, '100'),
	(243, 1, 0, -50553, 102, 0, 0, 39, '101'),
	(243, 1, 0, -50553, 103, 0, 0, 39, '102'),
	(243, 1, 0, -50553, 104, 0, 0, 39, '103'),
	(243, 1, 0, -50553, 105, 0, 0, 39, '104'),
	(243, 1, 0, -50553, 106, 0, 0, 39, '105'),
	(243, 1, 0, -50553, 107, 0, 0, 39, '106'),
	(243, 1, 0, -50553, 108, 0, 0, 39, '107'),
	(243, 1, 0, -50553, 109, 0, 0, 39, '108'),
	(243, 1, 0, -50553, 110, 0, 0, 39, '109'),
	(243, 1, 0, -50553, 111, 0, 0, 39, '110'),
	(243, 1, 0, -50553, 112, 0, 0, 39, '111'),
	(243, 1, 0, -50553, 113, 0, 0, 39, '112'),
	(243, 1, 0, -50553, 114, 0, 0, 39, '113'),
	(243, 1, 0, -50553, 115, 0, 0, 39, '114'),
	(243, 1, 0, -50553, 116, 0, 0, 39, '115'),
	(243, 1, 0, -50553, 117, 0, 0, 39, '116'),
	(243, 1, 0, -50553, 118, 0, 0, 39, '117'),
	(243, 1, 0, -50553, 119, 0, 0, 39, '118'),
	(243, 1, 0, -50553, 120, 0, 0, 39, '119'),
	(243, 1, 0, -50553, 121, 0, 0, 39, '120'),
	(243, 1, 0, -50553, 122, 0, 0, 39, '121'),
	(243, 1, 0, -50553, 123, 0, 0, 39, '122'),
	(243, 1, 0, -50553, 124, 0, 0, 39, '123'),
	(243, 1, 0, -50553, 125, 0, 0, 39, '124'),
	(243, 1, 0, -50553, 126, 0, 0, 39, '125'),
	(243, 1, 0, -50553, 127, 0, 0, 39, '126'),
	(243, 1, 0, -50553, 128, 0, 0, 39, '127'),
	(243, 1, 0, -50553, 129, 0, 0, 39, '128'),
	(243, 1, 0, -50553, 130, 0, 0, 39, '129'),
	(243, 1, 0, -50553, 131, 0, 0, 39, '130'),
	(243, 1, 0, -50553, 132, 0, 0, 39, '131'),
	(243, 1, 0, -50553, 133, 0, 0, 39, '132'),
	(243, 1, 0, -50553, 134, 0, 0, 39, '133'),
	(243, 1, 0, -50553, 135, 0, 0, 39, '134'),
	(243, 1, 0, -50553, 136, 0, 0, 39, '135'),
	(243, 1, 0, -50553, 137, 0, 0, 39, '136'),
	(243, 1, 0, -50553, 138, 0, 0, 39, '137'),
	(243, 1, 0, -50553, 139, 0, 0, 39, '138'),
	(243, 1, 0, -50553, 140, 0, 0, 39, '139'),
	(243, 1, 0, -50553, 141, 0, 0, 39, '140'),
	(243, 1, 0, -50553, 142, 0, 0, 39, '141'),
	(243, 1, 0, -50553, 143, 0, 0, 39, '142'),
	(243, 1, 0, -50553, 144, 0, 0, 39, '143'),
	(243, 1, 0, -50553, 145, 0, 0, 39, '144'),
	(243, 1, 0, -50553, 146, 0, 0, 39, '145'),
	(243, 1, 0, -50553, 147, 0, 0, 39, '146'),
	(243, 1, 0, -50553, 148, 0, 0, 39, '147'),
	(243, 1, 0, -50553, 149, 0, 0, 39, '148'),
	(243, 1, 0, -50553, 150, 0, 0, 39, '149'),
	(243, 1, 0, -50553, 151, 0, 0, 39, '150'),
	(243, 1, 0, -50553, 152, 0, 0, 39, '151'),
	(243, 1, 0, -50553, 153, 0, 0, 39, '152'),
	(243, 1, 0, -50553, 154, 0, 0, 39, '153'),
	(243, 1, 0, -50553, 155, 0, 0, 39, '154'),
	(243, 1, 0, -50553, 156, 0, 0, 39, '155'),
	(243, 1, 0, -50553, 157, 0, 0, 39, '156'),
	(243, 1, 0, -50553, 158, 0, 0, 39, '157'),
	(243, 1, 0, -50553, 159, 0, 0, 39, '158'),
	(243, 1, 0, -50553, 160, 0, 0, 39, '159'),
	(243, 1, 0, -50553, 161, 0, 0, 39, '160'),
	(243, 1, 0, -50553, 162, 0, 0, 39, '161'),
	(243, 1, 0, -50553, 163, 0, 0, 39, '162'),
	(243, 1, 0, -50553, 164, 0, 0, 39, '163'),
	(243, 1, 0, -50553, 165, 0, 0, 39, '164'),
	(243, 1, 0, -50553, 166, 0, 0, 39, '165'),
	(243, 1, 0, -50553, 167, 0, 0, 39, '166'),
	(243, 1, 0, -50553, 168, 0, 0, 39, '167'),
	(243, 1, 0, -50553, 169, 0, 0, 39, '168'),
	(243, 1, 0, -50553, 170, 0, 0, 39, '169'),
	(243, 1, 0, -50553, 171, 0, 0, 39, '170'),
	(243, 1, 0, -50553, 172, 0, 0, 39, '171'),
	(243, 1, 0, -50553, 173, 0, 0, 39, '172'),
	(243, 1, 0, -50553, 174, 0, 0, 39, '173'),
	(243, 1, 0, -50553, 175, 0, 0, 39, '174'),
	(243, 1, 0, -50553, 176, 0, 0, 39, '175'),
	(243, 1, 0, -50553, 177, 0, 0, 39, '176'),
	(243, 1, 0, -50553, 178, 0, 0, 39, '177'),
	(243, 1, 0, -50553, 179, 0, 0, 39, '178'),
	(243, 1, 0, -50553, 180, 0, 0, 39, '179'),
	(243, 1, 0, -50553, 181, 0, 0, 39, '180'),
	(243, 1, 0, -50553, 182, 0, 0, 39, '181'),
	(243, 1, 0, -50553, 183, 0, 0, 39, '182'),
	(243, 1, 0, -50553, 184, 0, 0, 39, '183'),
	(243, 1, 0, -50553, 185, 0, 0, 39, '184'),
	(243, 1, 0, -50553, 186, 0, 0, 39, '185'),
	(243, 1, 0, -50553, 187, 0, 0, 39, '186'),
	(243, 1, 0, -50553, 188, 0, 0, 39, '187'),
	(243, 1, 0, -50553, 189, 0, 0, 39, '188'),
	(243, 1, 0, -50553, 190, 0, 0, 39, '189'),
	(243, 1, 0, -50553, 191, 0, 0, 39, '190'),
	(243, 1, 0, -50553, 192, 0, 0, 39, '191'),
	(243, 1, 0, -50553, 193, 0, 0, 39, '192'),
	(243, 1, 0, -50553, 194, 0, 0, 39, '193'),
	(243, 1, 0, -50553, 195, 0, 0, 39, '194'),
	(243, 1, 0, -50553, 196, 0, 0, 39, '195'),
	(243, 1, 0, -50553, 197, 0, 0, 39, '196'),
	(243, 1, 0, -50553, 198, 0, 0, 39, '197'),
	(243, 1, 0, -50553, 199, 0, 0, 39, '198'),
	(243, 1, 0, -50553, 200, 0, 0, 39, '199'),
	(243, 1, 0, -50553, 201, 0, 0, 39, '200'),
	(243, 1, 0, -50553, 202, 0, 0, 39, '201'),
	(243, 1, 0, -50553, 203, 0, 0, 39, '202'),
	(243, 1, 0, -50553, 204, 0, 0, 39, '203'),
	(243, 1, 0, -50553, 205, 0, 0, 39, '204'),
	(243, 1, 0, -50553, 206, 0, 0, 39, '205'),
	(243, 1, 0, -50553, 207, 0, 0, 39, '206'),
	(243, 1, 0, -50553, 208, 0, 0, 39, '207'),
	(243, 1, 0, -50553, 209, 0, 0, 39, '208'),
	(243, 1, 0, -50553, 210, 0, 0, 39, '209'),
	(243, 1, 0, -50553, 211, 0, 0, 39, '210'),
	(243, 1, 0, -50553, 212, 0, 0, 39, '211'),
	(243, 1, 0, -50553, 213, 0, 0, 39, '212'),
	(243, 1, 0, -50553, 214, 0, 0, 39, '213'),
	(243, 1, 0, -50553, 215, 0, 0, 39, '214'),
	(243, 1, 0, -50553, 216, 0, 0, 39, '215'),
	(243, 1, 0, -50553, 217, 0, 0, 39, '216'),
	(243, 1, 0, -50553, 218, 0, 0, 39, '217'),
	(243, 1, 0, -50553, 219, 0, 0, 39, '218'),
	(243, 1, 0, -50553, 220, 0, 0, 39, '219'),
	(243, 1, 0, -50553, 221, 0, 0, 39, '220'),
	(243, 1, 0, -50553, 222, 0, 0, 39, '221'),
	(243, 1, 0, -50553, 223, 0, 0, 39, '222'),
	(243, 1, 0, -50553, 224, 0, 0, 39, '223'),
	(243, 1, 0, -50553, 225, 0, 0, 39, '224'),
	(243, 1, 0, -50553, 226, 0, 0, 39, '225'),
	(243, 1, 0, -50553, 227, 0, 0, 39, '226'),
	(243, 1, 0, -50553, 228, 0, 0, 39, '227'),
	(243, 1, 0, -50553, 229, 0, 0, 39, '228'),
	(243, 1, 0, -50553, 230, 0, 0, 39, '229'),
	(243, 1, 0, -50553, 231, 0, 0, 39, '230'),
	(243, 1, 0, -50553, 232, 0, 0, 39, '231'),
	(243, 1, 0, -50553, 233, 0, 0, 39, '232'),
	(243, 1, 0, -50553, 234, 0, 0, 39, '233'),
	(243, 1, 0, -50553, 235, 0, 0, 39, '234'),
	(243, 1, 0, -50553, 236, 0, 0, 39, '235'),
	(243, 1, 0, -50553, 237, 0, 0, 39, '236'),
	(243, 1, 0, -50553, 238, 0, 0, 39, '237'),
	(243, 1, 0, -50553, 239, 0, 0, 39, '238'),
	(243, 1, 0, -50553, 240, 0, 0, 39, '239'),
	(243, 1, 0, -50553, 241, 0, 0, 39, '240'),
	(243, 1, 0, -50553, 242, 0, 0, 39, '241'),
	(243, 1, 0, -50553, 243, 0, 0, 39, '242'),
	(243, 1, 0, -50553, 244, 0, 0, 39, '243'),
	(243, 1, 0, -50553, 245, 0, 0, 39, '244'),
	(243, 1, 0, -50553, 246, 0, 0, 39, '245'),
	(243, 1, 0, -50553, 247, 0, 0, 39, '246'),
	(243, 1, 0, -50553, 248, 0, 0, 39, '247'),
	(243, 1, 0, -50553, 249, 0, 0, 39, '248'),
	(243, 1, 0, -50553, 250, 0, 0, 39, '249'),
	(243, 1, 0, -50553, 251, 0, 0, 39, '250'),
	(243, 1, 0, -50553, 252, 0, 0, 39, '251'),
	(243, 1, 0, -50553, 253, 0, 0, 39, '252'),
	(243, 1, 0, -50553, 254, 0, 0, 39, '253'),
	(243, 1, 0, -50553, 255, 0, 0, 39, '254'),
	(243, 1, 0, -50553, 256, 0, 0, 39, '255'),
	(243, 1, 0, -50553, 257, 0, 0, 39, '256'),
	(243, 1, 0, -50553, 258, 0, 0, 39, '257'),
	(243, 1, 0, -50553, 259, 0, 0, 39, '258'),
	(243, 1, 0, -50553, 260, 0, 0, 39, '259'),
	(243, 1, 0, -50553, 261, 0, 0, 39, '260'),
	(243, 1, 0, -50553, 262, 0, 0, 39, '261'),
	(243, 1, 0, -50553, 263, 0, 0, 39, '262'),
	(243, 1, 0, -50553, 264, 0, 0, 39, '263'),
	(243, 1, 0, -50553, 265, 0, 0, 39, '264'),
	(243, 1, 0, -50553, 266, 0, 0, 39, '265'),
	(243, 1, 0, -50553, 267, 0, 0, 39, '266'),
	(243, 1, 0, -50553, 268, 0, 0, 39, '267'),
	(243, 1, 0, -50553, 269, 0, 0, 39, '268'),
	(243, 1, 0, -50553, 270, 0, 0, 39, '269'),
	(243, 1, 0, -50553, 271, 0, 0, 39, '270'),
	(243, 1, 0, -50553, 272, 0, 0, 39, '271'),
	(243, 1, 0, -50553, 273, 0, 0, 39, '272'),
	(243, 1, 0, -50553, 274, 0, 0, 39, '273'),
	(243, 1, 0, -50553, 275, 0, 0, 39, '274'),
	(243, 1, 0, -50553, 276, 0, 0, 39, '275'),
	(243, 1, 0, -50553, 277, 0, 0, 39, '276'),
	(243, 1, 0, -50553, 278, 0, 0, 39, '277'),
	(243, 1, 0, -50553, 279, 0, 0, 39, '278'),
	(243, 1, 0, -50553, 280, 0, 0, 39, '279'),
	(243, 1, 0, -50553, 281, 0, 0, 39, '280'),
	(243, 1, 0, -50553, 282, 0, 0, 39, '281'),
	(243, 1, 0, -50553, 283, 0, 0, 39, '282'),
	(243, 1, 0, -50553, 284, 0, 0, 39, '283'),
	(243, 1, 0, -50553, 285, 0, 0, 39, '284'),
	(243, 1, 0, -50553, 286, 0, 0, 39, '285'),
	(243, 1, 0, -50553, 287, 0, 0, 39, '286'),
	(243, 1, 0, -50553, 288, 0, 0, 39, '287'),
	(243, 1, 0, -50553, 289, 0, 0, 39, '288'),
	(243, 1, 0, -50553, 290, 0, 0, 39, '289'),
	(243, 1, 0, -50553, 291, 0, 0, 39, '290'),
	(243, 1, 0, -50553, 292, 0, 0, 39, '291'),
	(243, 1, 0, -50553, 293, 0, 0, 39, '292'),
	(243, 1, 0, -50553, 294, 0, 0, 39, '293'),
	(243, 1, 0, -50553, 295, 0, 0, 39, '294'),
	(243, 1, 0, -50553, 296, 0, 0, 39, '295'),
	(243, 1, 0, -50553, 297, 0, 0, 39, '296'),
	(243, 1, 0, -50553, 298, 0, 0, 39, '297'),
	(243, 1, 0, -50553, 299, 0, 0, 39, '298'),
	(243, 1, 0, -50553, 300, 0, 0, 39, '299'),
	(243, 1, 0, -50553, 301, 0, 0, 39, '300'),
	(243, 1, 0, -50553, 302, 0, 0, 39, '301'),
	(243, 1, 0, -50553, 303, 0, 0, 39, '302'),
	(243, 1, 0, -50553, 304, 0, 0, 39, '303'),
	(243, 1, 0, -50553, 305, 0, 0, 39, '304'),
	(243, 1, 0, -50553, 306, 0, 0, 39, '305'),
	(243, 1, 0, -50553, 307, 0, 0, 39, '306'),
	(243, 1, 0, -50553, 308, 0, 0, 39, '307'),
	(243, 1, 0, -50553, 309, 0, 0, 39, '308'),
	(243, 1, 0, -50553, 310, 0, 0, 39, '309'),
	(243, 1, 0, -50553, 311, 0, 0, 39, '310'),
	(243, 1, 0, -50553, 312, 0, 0, 39, '311'),
	(243, 1, 0, -50553, 313, 0, 0, 39, '312'),
	(243, 1, 0, -50553, 314, 0, 0, 39, '313'),
	(243, 1, 0, -50553, 315, 0, 0, 39, '314'),
	(243, 1, 0, -50553, 316, 0, 0, 39, '315'),
	(243, 1, 0, -50553, 317, 0, 0, 39, '316'),
	(243, 1, 0, -50553, 318, 0, 0, 39, '317'),
	(243, 1, 0, -50553, 319, 0, 0, 39, '318'),
	(243, 1, 0, -50553, 320, 0, 0, 39, '319'),
	(243, 1, 0, -50553, 321, 0, 0, 39, '320'),
	(243, 1, 0, -50553, 322, 0, 0, 39, '321'),
	(243, 1, 0, -50553, 323, 0, 0, 39, '322'),
	(243, 1, 0, -50553, 324, 0, 0, 39, '323'),
	(243, 1, 0, -50553, 325, 0, 0, 39, '324'),
	(243, 1, 0, -50553, 326, 0, 0, 39, '325'),
	(243, 1, 0, -50553, 327, 0, 0, 39, '326'),
	(243, 1, 0, -50553, 328, 0, 0, 39, '327'),
	(243, 1, 0, -50553, 329, 0, 0, 39, '328'),
	(243, 1, 0, -50553, 330, 0, 0, 39, '329'),
	(243, 1, 0, -50553, 331, 0, 0, 39, '330'),
	(243, 1, 0, -50553, 332, 0, 0, 39, '331'),
	(243, 1, 0, -50553, 333, 0, 0, 39, '332'),
	(243, 1, 0, -50553, 334, 0, 0, 39, '333'),
	(243, 1, 0, -50553, 335, 0, 0, 39, '334'),
	(243, 1, 0, -50553, 336, 0, 0, 39, '335'),
	(243, 1, 0, -50553, 337, 0, 0, 39, '336'),
	(243, 1, 0, -50553, 338, 0, 0, 39, '337'),
	(243, 1, 0, -50553, 339, 0, 0, 39, '338'),
	(243, 1, 0, -50553, 340, 0, 0, 39, '339'),
	(243, 1, 0, -50553, 341, 0, 0, 39, '340'),
	(243, 1, 0, -50553, 342, 0, 0, 39, '341'),
	(243, 1, 0, -50553, 343, 0, 0, 39, '342'),
	(243, 1, 0, -50553, 344, 0, 0, 39, '343'),
	(243, 1, 0, -50553, 345, 0, 0, 39, '344'),
	(243, 1, 0, -50553, 346, 0, 0, 39, '345'),
	(243, 1, 0, -50553, 347, 0, 0, 39, '346'),
	(243, 1, 0, -50553, 348, 0, 0, 39, '347'),
	(243, 1, 0, -50553, 349, 0, 0, 39, '348'),
	(243, 1, 0, -50553, 350, 0, 0, 39, '349'),
	(243, 1, 0, -50553, 351, 0, 0, 39, '350'),
	(243, 1, 0, -50553, 352, 0, 0, 39, '351'),
	(243, 1, 0, -50553, 353, 0, 0, 39, '352'),
	(243, 1, 0, -50553, 354, 0, 0, 39, '353'),
	(243, 1, 0, -50553, 355, 0, 0, 39, '354'),
	(243, 1, 0, -50553, 356, 0, 0, 39, '355'),
	(243, 1, 0, -50553, 357, 0, 0, 39, '356'),
	(243, 1, 0, -50553, 358, 0, 0, 39, '357'),
	(243, 1, 0, -50553, 359, 0, 0, 39, '358'),
	(243, 1, 0, -50553, 360, 0, 0, 39, '359'),
	(243, 1, 0, -50553, 361, 0, 0, 39, '360'),
	(243, 1, 0, -50553, 362, 0, 0, 39, '361'),
	(243, 1, 0, -50553, 363, 0, 0, 39, '362'),
	(243, 1, 0, -50553, 364, 0, 0, 39, '363'),
	(243, 1, 0, -50553, 365, 0, 0, 39, '364'),
	(243, 1, 0, -50553, 366, 0, 0, 39, '365'),
	(243, 1, 0, -50553, 367, 0, 0, 39, '366'),
	(243, 1, 0, -50553, 368, 0, 0, 39, '367'),
	(243, 1, 0, -50553, 369, 0, 0, 39, '368'),
	(243, 1, 0, -50553, 370, 0, 0, 39, '369'),
	(243, 1, 0, -50553, 371, 0, 0, 39, '370'),
	(243, 1, 0, -50553, 372, 0, 0, 39, '371'),
	(243, 1, 0, -50553, 373, 0, 0, 39, '372'),
	(243, 1, 0, -50553, 374, 0, 0, 39, '373'),
	(243, 1, 0, -50553, 375, 0, 0, 39, '374'),
	(243, 1, 0, -50553, 376, 0, 0, 39, '375'),
	(243, 1, 0, -50553, 377, 0, 0, 39, '376'),
	(243, 1, 0, -50553, 378, 0, 0, 39, '377'),
	(243, 1, 0, -50553, 379, 0, 0, 39, '378'),
	(243, 1, 0, -50553, 380, 0, 0, 39, '379'),
	(243, 1, 0, -50553, 381, 0, 0, 39, '380'),
	(243, 1, 0, -50553, 382, 0, 0, 39, '381'),
	(243, 1, 0, -50553, 383, 0, 0, 39, '382'),
	(243, 1, 0, -50553, 384, 0, 0, 39, '383'),
	(243, 1, 0, -50553, 385, 0, 0, 39, '384'),
	(243, 1, 0, -50553, 386, 0, 0, 39, '385'),
	(243, 1, 0, -50553, 387, 0, 0, 39, '386'),
	(243, 1, 0, -50553, 388, 0, 0, 39, '387'),
	(243, 1, 0, -50553, 389, 0, 0, 39, '388'),
	(243, 1, 0, -50553, 390, 0, 0, 39, '389'),
	(243, 1, 0, -50553, 391, 0, 0, 39, '390'),
	(243, 1, 0, -50553, 392, 0, 0, 39, '391'),
	(243, 1, 0, -50553, 393, 0, 0, 39, '392'),
	(243, 1, 0, -50553, 394, 0, 0, 39, '393'),
	(243, 1, 0, -50553, 395, 0, 0, 39, '394'),
	(243, 1, 0, -50553, 396, 0, 0, 39, '395'),
	(243, 1, 0, -50553, 397, 0, 0, 39, '396'),
	(243, 1, 0, -50553, 398, 0, 0, 39, '397'),
	(243, 1, 0, -50553, 399, 0, 0, 39, '398'),
	(243, 1, 0, -50553, 400, 0, 0, 39, '399'),
	(243, 1, 0, -50553, 401, 0, 0, 39, '400'),
	(243, 1, 0, -50553, 402, 0, 0, 39, '401'),
	(243, 1, 0, -50553, 403, 0, 0, 39, '402'),
	(243, 1, 0, -50553, 404, 0, 0, 39, '403'),
	(243, 1, 0, -50553, 405, 0, 0, 39, '404'),
	(243, 1, 0, -50553, 406, 0, 0, 39, '405'),
	(243, 1, 0, -50553, 407, 0, 0, 39, '406'),
	(243, 1, 0, -50553, 408, 0, 0, 39, '407'),
	(243, 1, 0, -50553, 409, 0, 0, 39, '408'),
	(243, 1, 0, -50553, 410, 0, 0, 39, '409'),
	(243, 1, 0, -50553, 411, 0, 0, 39, '410'),
	(243, 1, 0, -50553, 412, 0, 0, 39, '411'),
	(243, 1, 0, -50553, 413, 0, 0, 39, '412'),
	(243, 1, 0, -50553, 414, 0, 0, 39, '413'),
	(243, 1, 0, -50553, 415, 0, 0, 39, '414'),
	(243, 1, 0, -50553, 416, 0, 0, 39, '415'),
	(243, 1, 0, -50553, 417, 0, 0, 39, '416'),
	(243, 1, 0, -50553, 418, 0, 0, 39, '417'),
	(243, 1, 0, -50553, 419, 0, 0, 39, '418'),
	(243, 1, 0, -50553, 420, 0, 0, 39, '419'),
	(243, 1, 0, -50553, 421, 0, 0, 39, '420'),
	(243, 1, 0, -50553, 422, 0, 0, 39, '421'),
	(243, 1, 0, -50553, 423, 0, 0, 39, '422'),
	(243, 1, 0, -50553, 424, 0, 0, 39, '423'),
	(243, 1, 0, -50553, 425, 0, 0, 39, '424'),
	(243, 1, 0, -50553, 426, 0, 0, 39, '425'),
	(243, 1, 0, -50553, 427, 0, 0, 39, '426'),
	(243, 1, 0, -50553, 428, 0, 0, 39, '427'),
	(243, 1, 0, -50553, 429, 0, 0, 39, '428'),
	(243, 1, 0, -50553, 430, 0, 0, 39, '429'),
	(243, 1, 0, -50553, 431, 0, 0, 39, '430'),
	(243, 1, 0, -50553, 432, 0, 0, 39, '431'),
	(243, 1, 0, -50553, 433, 0, 0, 39, '432'),
	(243, 1, 0, -50553, 434, 0, 0, 39, '433'),
	(243, 1, 0, -50553, 435, 0, 0, 39, '434'),
	(243, 1, 0, -50553, 436, 0, 0, 39, '435'),
	(243, 1, 0, -50553, 437, 0, 0, 39, '436'),
	(243, 1, 0, -50553, 438, 0, 0, 39, '437'),
	(243, 1, 0, -50553, 439, 0, 0, 39, '438'),
	(243, 1, 0, -50553, 440, 0, 0, 39, '439'),
	(243, 1, 0, -50553, 441, 0, 0, 39, '440'),
	(243, 1, 0, -50553, 442, 0, 0, 39, '441'),
	(243, 1, 0, -50553, 443, 0, 0, 39, '442'),
	(243, 1, 0, -50553, 444, 0, 0, 39, '443'),
	(243, 1, 0, -50553, 445, 0, 0, 39, '444'),
	(243, 1, 0, -50553, 446, 0, 0, 39, '445'),
	(243, 1, 0, -50553, 447, 0, 0, 39, '446'),
	(243, 1, 0, -50553, 448, 0, 0, 39, '447'),
	(243, 1, 0, -50553, 449, 0, 0, 39, '448'),
	(243, 1, 0, -50553, 450, 0, 0, 39, '449'),
	(243, 1, 0, -50553, 451, 0, 0, 39, '450'),
	(243, 1, 0, -50553, 452, 0, 0, 39, '451'),
	(243, 1, 0, -50553, 453, 0, 0, 39, '452'),
	(243, 1, 0, -50553, 454, 0, 0, 39, '453'),
	(243, 1, 0, -50553, 455, 0, 0, 39, '454'),
	(243, 1, 0, -50553, 456, 0, 0, 39, '455'),
	(243, 1, 0, -50553, 457, 0, 0, 39, '456'),
	(243, 1, 0, -50553, 458, 0, 0, 39, '457'),
	(243, 1, 0, -50553, 459, 0, 0, 39, '458'),
	(243, 1, 0, -50553, 460, 0, 0, 39, '459'),
	(243, 1, 0, -50553, 461, 0, 0, 39, '460'),
	(243, 1, 0, -50553, 462, 0, 0, 39, '461'),
	(243, 1, 0, -50553, 463, 0, 0, 39, '462'),
	(243, 1, 0, -50553, 464, 0, 0, 39, '463'),
	(243, 1, 0, -50553, 465, 0, 0, 39, '464'),
	(243, 1, 0, -50553, 466, 0, 0, 39, '465'),
	(243, 1, 0, -50553, 467, 0, 0, 39, '466'),
	(243, 1, 0, -50553, 468, 0, 0, 39, '467'),
	(243, 1, 0, -50553, 469, 0, 0, 39, '468'),
	(243, 1, 0, -50553, 470, 0, 0, 39, '469'),
	(243, 1, 0, -50553, 471, 0, 0, 39, '470'),
	(243, 1, 0, -50553, 472, 0, 0, 39, '471'),
	(243, 1, 0, -50553, 473, 0, 0, 39, '472'),
	(243, 1, 0, -50553, 474, 0, 0, 39, '473'),
	(243, 1, 0, -50553, 475, 0, 0, 39, '474'),
	(243, 1, 0, -50553, 476, 0, 0, 39, '475'),
	(243, 1, 0, -50553, 477, 0, 0, 39, '476'),
	(243, 1, 0, -50553, 478, 0, 0, 39, '477'),
	(243, 1, 0, -50553, 479, 0, 0, 39, '478'),
	(243, 1, 0, -50553, 480, 0, 0, 39, '479'),
	(243, 1, 0, -50553, 481, 0, 0, 39, '480'),
	(243, 1, 0, -50553, 482, 0, 0, 39, '481'),
	(243, 1, 0, -50553, 483, 0, 0, 39, '482'),
	(243, 1, 0, -50553, 484, 0, 0, 39, '483'),
	(243, 1, 0, -50553, 485, 0, 0, 39, '484'),
	(243, 1, 0, -50553, 486, 0, 0, 39, '485'),
	(243, 1, 0, -50553, 487, 0, 0, 39, '486'),
	(243, 1, 0, -50553, 488, 0, 0, 39, '487'),
	(243, 1, 0, -50553, 489, 0, 0, 39, '488'),
	(243, 1, 0, -50553, 490, 0, 0, 39, '489'),
	(243, 1, 0, -50553, 491, 0, 0, 39, '490'),
	(243, 1, 0, -50553, 492, 0, 0, 39, '491'),
	(243, 1, 0, -50553, 493, 0, 0, 39, '492'),
	(243, 1, 0, -50553, 494, 0, 0, 39, '493'),
	(243, 1, 0, -50553, 495, 0, 0, 39, '494'),
	(243, 1, 0, -50553, 496, 0, 0, 39, '495'),
	(243, 1, 0, -50553, 497, 0, 0, 39, '496'),
	(243, 1, 0, -50553, 498, 0, 0, 39, '497'),
	(243, 1, 0, -50553, 499, 0, 0, 39, '498'),
	(243, 1, 0, -50553, 500, 0, 0, 39, '499'),
	(243, 1, 0, -50553, 501, 0, 0, 39, '500'),
	(243, 1, 0, -50553, 502, 0, 0, 39, '501'),
	(243, 1, 0, -50553, 503, 0, 0, 39, '502'),
	(243, 1, 0, -50553, 504, 0, 0, 39, '503'),
	(243, 1, 0, -50553, 505, 0, 0, 39, '504'),
	(243, 1, 0, -50553, 506, 0, 0, 39, '505'),
	(243, 1, 0, -50553, 507, 0, 0, 39, '506'),
	(243, 1, 0, -50553, 508, 0, 0, 39, '507'),
	(243, 1, 0, -50553, 509, 0, 0, 39, '508'),
	(243, 1, 0, -50553, 510, 0, 0, 39, '509'),
	(243, 1, 0, -50553, 511, 0, 0, 39, '510'),
	(243, 1, 0, -50553, 512, 0, 0, 39, '511'),
	(243, 1, 0, -50553, 513, 0, 0, 39, '512'),
	(243, 1, 0, -50553, 514, 0, 0, 39, '513'),
	(243, 1, 0, -50553, 515, 0, 0, 39, '514'),
	(243, 1, 0, -50553, 516, 0, 0, 39, '515'),
	(243, 1, 0, -50553, 517, 0, 0, 39, '516'),
	(243, 1, 0, -50553, 518, 0, 0, 39, '517'),
	(243, 1, 0, -50553, 519, 0, 0, 39, '518'),
	(243, 1, 0, -50553, 520, 0, 0, 39, '519'),
	(243, 1, 0, -50553, 521, 0, 0, 39, '520'),
	(243, 1, 0, -50553, 522, 0, 0, 39, '521'),
	(243, 1, 0, -50553, 523, 0, 0, 39, '522'),
	(243, 1, 0, -50553, 524, 0, 0, 39, '523'),
	(243, 1, 0, -50553, 525, 0, 0, 39, '524'),
	(243, 1, 0, -50553, 526, 0, 0, 39, '525'),
	(243, 1, 0, -50553, 527, 0, 0, 39, '526'),
	(243, 1, 0, -50553, 528, 0, 0, 39, '527'),
	(243, 1, 0, -50553, 529, 0, 0, 39, '528'),
	(243, 1, 0, -50553, 530, 0, 0, 39, '529'),
	(243, 1, 0, -50553, 531, 0, 0, 39, '530'),
	(243, 1, 0, -50553, 532, 0, 0, 39, '531'),
	(243, 1, 0, -50553, 533, 0, 0, 39, '532'),
	(243, 1, 0, -50553, 534, 0, 0, 39, '533'),
	(243, 1, 0, -50553, 535, 0, 0, 39, '534'),
	(243, 1, 0, -50553, 536, 0, 0, 39, '535'),
	(243, 1, 0, -50553, 537, 0, 0, 39, '536'),
	(243, 1, 0, -50553, 538, 0, 0, 39, '537'),
	(243, 1, 0, -50553, 539, 0, 0, 39, '538'),
	(243, 1, 0, -50553, 540, 0, 0, 39, '539'),
	(243, 1, 0, -50553, 541, 0, 0, 39, '540'),
	(243, 1, 0, -50553, 542, 0, 0, 39, '541'),
	(243, 1, 0, -50553, 543, 0, 0, 39, '542'),
	(243, 1, 0, -50553, 544, 0, 0, 39, '543'),
	(243, 1, 0, -50553, 545, 0, 0, 39, '544'),
	(243, 1, 0, -50553, 546, 0, 0, 39, '545'),
	(243, 1, 0, -50553, 547, 0, 0, 39, '546'),
	(243, 1, 0, -50553, 548, 0, 0, 39, '547'),
	(243, 1, 0, -50553, 549, 0, 0, 39, '548'),
	(243, 1, 0, -50553, 550, 0, 0, 39, '549'),
	(243, 1, 0, -50553, 551, 0, 0, 39, '550'),
	(243, 1, 0, -50553, 552, 0, 0, 39, '551'),
	(243, 1, 0, -50553, 553, 0, 0, 39, '552'),
	(243, 1, 0, -50553, 554, 0, 0, 39, '553'),
	(243, 1, 0, -50553, 555, 0, 0, 39, '554'),
	(243, 1, 0, -50553, 556, 0, 0, 39, '555'),
	(243, 1, 0, -50553, 557, 0, 0, 39, '556'),
	(243, 1, 0, -50553, 558, 0, 0, 39, '557'),
	(243, 1, 0, -50553, 559, 0, 0, 39, '558'),
	(243, 1, 0, -50553, 560, 0, 0, 39, '559'),
	(243, 1, 0, -50553, 561, 0, 0, 39, '560'),
	(243, 1, 0, -50553, 562, 0, 0, 39, '561'),
	(243, 1, 0, -50553, 563, 0, 0, 39, '562'),
	(243, 1, 0, -50553, 564, 0, 0, 39, '563'),
	(243, 1, 0, -50553, 565, 0, 0, 39, '564'),
	(243, 1, 0, -50553, 566, 0, 0, 39, '565'),
	(243, 1, 0, -50553, 567, 0, 0, 39, '566'),
	(243, 1, 0, -50553, 568, 0, 0, 39, '567'),
	(243, 1, 0, -50553, 569, 0, 0, 39, '568'),
	(243, 1, 0, -50553, 570, 0, 0, 39, '569'),
	(243, 1, 0, -50553, 571, 0, 0, 39, '570'),
	(243, 1, 0, -50553, 572, 0, 0, 39, '571'),
	(243, 1, 0, -50553, 573, 0, 0, 39, '572'),
	(243, 1, 0, -50553, 574, 0, 0, 39, '573'),
	(243, 1, 0, -50553, 575, 0, 0, 39, '574'),
	(243, 1, 0, -50553, 576, 0, 0, 39, '575'),
	(243, 1, 0, -50553, 577, 0, 0, 39, '576'),
	(243, 1, 0, -50553, 578, 0, 0, 39, '577'),
	(243, 1, 0, -50553, 579, 0, 0, 39, '578'),
	(243, 1, 0, -50553, 580, 0, 0, 39, '579'),
	(243, 1, 0, -50553, 581, 0, 0, 39, '580'),
	(243, 1, 0, -50553, 582, 0, 0, 39, '581'),
	(243, 1, 0, -50553, 583, 0, 0, 39, '582'),
	(243, 1, 0, -50553, 584, 0, 0, 39, '583'),
	(243, 1, 0, -50553, 585, 0, 0, 39, '584'),
	(243, 1, 0, -50553, 586, 0, 0, 39, '585'),
	(243, 1, 0, -50553, 587, 0, 0, 39, '586'),
	(243, 1, 0, -50553, 588, 0, 0, 39, '587'),
	(243, 1, 0, -50553, 589, 0, 0, 39, '588'),
	(243, 1, 0, -50553, 590, 0, 0, 39, '589'),
	(243, 1, 0, -50553, 591, 0, 0, 39, '590'),
	(243, 1, 0, -50553, 592, 0, 0, 39, '591'),
	(243, 1, 0, -50553, 593, 0, 0, 39, '592'),
	(243, 1, 0, -50553, 594, 0, 0, 39, '593'),
	(243, 1, 0, -50553, 595, 0, 0, 39, '594'),
	(243, 1, 0, -50553, 596, 0, 0, 39, '595'),
	(243, 1, 0, -50553, 597, 0, 0, 39, '596'),
	(243, 1, 0, -50553, 598, 0, 0, 39, '597'),
	(243, 1, 0, -50553, 599, 0, 0, 39, '598'),
	(243, 1, 0, -50553, 600, 0, 0, 39, '599'),
	(243, 1, 0, -50553, 601, 0, 0, 39, '600'),
	(243, 1, 0, -50553, 602, 0, 0, 39, '601'),
	(243, 1, 0, -50553, 603, 0, 0, 39, '602'),
	(243, 1, 0, -50553, 604, 0, 0, 39, '603'),
	(243, 1, 0, -50553, 605, 0, 0, 39, '604'),
	(243, 1, 0, -50553, 606, 0, 0, 39, '605'),
	(243, 1, 0, -50553, 607, 0, 0, 39, '606'),
	(243, 1, 0, -50553, 608, 0, 0, 39, '607'),
	(243, 1, 0, -50553, 609, 0, 0, 39, '608'),
	(243, 1, 0, -50553, 610, 0, 0, 39, '609'),
	(243, 1, 0, -50553, 611, 0, 0, 39, '610'),
	(243, 1, 0, -50553, 612, 0, 0, 39, '611'),
	(243, 1, 0, -50553, 613, 0, 0, 39, '612'),
	(243, 1, 0, -50553, 614, 0, 0, 39, '613'),
	(243, 1, 0, -50553, 615, 0, 0, 39, '614'),
	(243, 1, 0, -50553, 616, 0, 0, 39, '615'),
	(243, 1, 0, -50553, 617, 0, 0, 39, '616'),
	(243, 1, 0, -50553, 618, 0, 0, 39, '617'),
	(243, 1, 0, -50553, 619, 0, 0, 39, '618'),
	(243, 1, 0, -50553, 620, 0, 0, 39, '619'),
	(243, 1, 0, -50553, 621, 0, 0, 39, '620'),
	(243, 1, 0, -50553, 622, 0, 0, 39, '621'),
	(243, 1, 0, -50553, 623, 0, 0, 39, '622'),
	(243, 1, 0, -50553, 624, 0, 0, 39, '623'),
	(243, 1, 0, -50553, 625, 0, 0, 39, '624'),
	(243, 1, 0, -50553, 626, 0, 0, 39, '625'),
	(243, 1, 0, -50553, 627, 0, 0, 39, '626'),
	(243, 1, 0, -50553, 628, 0, 0, 39, '627'),
	(243, 1, 0, -50553, 629, 0, 0, 39, '628'),
	(243, 1, 0, -50553, 630, 0, 0, 39, '629'),
	(243, 1, 0, -50553, 631, 0, 0, 39, '630'),
	(243, 1, 0, -50553, 632, 0, 0, 39, '631'),
	(243, 1, 0, -50553, 633, 0, 0, 39, '632'),
	(243, 1, 0, -50553, 634, 0, 0, 39, '633'),
	(243, 1, 0, -50553, 635, 0, 0, 39, '634'),
	(243, 1, 0, -50553, 636, 0, 0, 39, '635'),
	(243, 1, 0, -50553, 637, 0, 0, 39, '636'),
	(243, 1, 0, -50553, 638, 0, 0, 39, '637'),
	(243, 1, 0, -50553, 639, 0, 0, 39, '638'),
	(243, 1, 0, -50553, 640, 0, 0, 39, '639'),
	(243, 1, 0, -50553, 641, 0, 0, 39, '640'),
	(243, 1, 0, -50553, 642, 0, 0, 39, '641'),
	(243, 1, 0, -50553, 643, 0, 0, 39, '642'),
	(243, 1, 0, -50553, 644, 0, 0, 39, '643'),
	(243, 1, 0, -50553, 645, 0, 0, 39, '644'),
	(243, 1, 0, -50553, 646, 0, 0, 39, '645'),
	(243, 1, 0, -50553, 647, 0, 0, 39, '646'),
	(243, 1, 0, -50553, 648, 0, 0, 39, '647'),
	(243, 1, 0, -50553, 649, 0, 0, 39, '648'),
	(243, 1, 0, -50553, 650, 0, 0, 39, '649'),
	(243, 1, 0, -50553, 651, 0, 0, 39, '650'),
	(243, 1, 0, -50553, 652, 0, 0, 39, '651'),
	(243, 1, 0, -50553, 653, 0, 0, 39, '652'),
	(243, 1, 0, -50553, 654, 0, 0, 39, '653'),
	(243, 1, 0, -50553, 655, 0, 0, 39, '654'),
	(243, 1, 0, -50553, 656, 0, 0, 39, '655'),
	(243, 1, 0, -50553, 657, 0, 0, 39, '656'),
	(243, 1, 0, -50553, 658, 0, 0, 39, '657'),
	(243, 1, 0, -50553, 659, 0, 0, 39, '658'),
	(243, 1, 0, -50553, 660, 0, 0, 39, '659'),
	(243, 1, 0, -50553, 661, 0, 0, 39, '660'),
	(243, 1, 0, -50553, 662, 0, 0, 39, '661'),
	(243, 1, 0, -50553, 663, 0, 0, 39, '662'),
	(243, 1, 0, -50553, 664, 0, 0, 39, '663'),
	(243, 1, 0, -50553, 665, 0, 0, 39, '664'),
	(243, 1, 0, -50553, 666, 0, 0, 39, '665'),
	(243, 1, 0, -50553, 667, 0, 0, 39, '666'),
	(243, 1, 0, -50553, 668, 0, 0, 39, '667'),
	(243, 1, 0, -50553, 669, 0, 0, 39, '668'),
	(243, 1, 0, -50553, 670, 0, 0, 39, '669'),
	(243, 1, 0, -50553, 671, 0, 0, 39, '670'),
	(243, 1, 0, -50553, 672, 0, 0, 39, '671'),
	(243, 1, 0, -50553, 673, 0, 0, 39, '672'),
	(243, 1, 0, -50553, 674, 0, 0, 39, '673'),
	(243, 1, 0, -50553, 675, 0, 0, 39, '674'),
	(243, 1, 0, -50553, 676, 0, 0, 39, '675'),
	(243, 1, 0, -50553, 677, 0, 0, 39, '676'),
	(243, 1, 0, -50553, 678, 0, 0, 39, '677'),
	(243, 1, 0, -50553, 679, 0, 0, 39, '678'),
	(243, 1, 0, -50553, 680, 0, 0, 39, '679'),
	(243, 1, 0, -50553, 681, 0, 0, 39, '680'),
	(243, 1, 0, -50553, 682, 0, 0, 39, '681'),
	(243, 1, 0, -50553, 683, 0, 0, 39, '682'),
	(243, 1, 0, -50553, 684, 0, 0, 39, '683'),
	(243, 1, 0, -50553, 685, 0, 0, 39, '684'),
	(243, 1, 0, -50553, 686, 0, 0, 39, '685'),
	(243, 1, 0, -50553, 687, 0, 0, 39, '686'),
	(243, 1, 0, -50553, 688, 0, 0, 39, '687'),
	(243, 1, 0, -50553, 689, 0, 0, 39, '688'),
	(243, 1, 0, -50553, 690, 0, 0, 39, '689'),
	(243, 1, 0, -50553, 691, 0, 0, 39, '690'),
	(243, 1, 0, -50553, 692, 0, 0, 39, '691'),
	(243, 1, 0, -50553, 693, 0, 0, 39, '692'),
	(243, 1, 0, -50553, 694, 0, 0, 39, '693'),
	(243, 1, 0, -50553, 695, 0, 0, 39, '694'),
	(243, 1, 0, -50553, 696, 0, 0, 39, '695'),
	(243, 1, 0, -50553, 697, 0, 0, 39, '696'),
	(243, 1, 0, -50553, 698, 0, 0, 39, '697'),
	(243, 1, 0, -50553, 699, 0, 0, 39, '698'),
	(243, 1, 0, -50553, 700, 0, 0, 39, '699'),
	(243, 1, 0, -50553, 701, 0, 0, 39, '700'),
	(243, 1, 0, -50553, 702, 0, 0, 39, '701'),
	(243, 1, 0, -50553, 703, 0, 0, 39, '702'),
	(243, 1, 0, -50553, 704, 0, 0, 39, '703'),
	(243, 1, 0, -50553, 705, 0, 0, 39, '704'),
	(243, 1, 0, -50553, 706, 0, 0, 39, '705'),
	(243, 1, 0, -50553, 707, 0, 0, 39, '706'),
	(243, 1, 0, -50553, 708, 0, 0, 39, '707'),
	(243, 1, 0, -50553, 709, 0, 0, 39, '708'),
	(243, 1, 0, -50553, 710, 0, 0, 39, '709'),
	(243, 1, 0, -50553, 711, 0, 0, 39, '710'),
	(243, 1, 0, -50553, 712, 0, 0, 39, '711'),
	(243, 1, 0, -50553, 713, 0, 0, 39, '712'),
	(243, 1, 0, -50553, 714, 0, 0, 39, '713'),
	(243, 1, 0, -50553, 715, 0, 0, 39, '714'),
	(243, 1, 0, -50553, 716, 0, 0, 39, '715'),
	(243, 1, 0, -50553, 717, 0, 0, 39, '716'),
	(243, 1, 0, -50553, 718, 0, 0, 39, '717'),
	(243, 1, 0, -50553, 719, 0, 0, 39, '718'),
	(243, 1, 0, -50553, 720, 0, 0, 39, '719'),
	(243, 1, 0, -50553, 721, 0, 0, 39, '720'),
	(243, 1, 0, -50553, 722, 0, 0, 39, '721'),
	(243, 1, 0, -50553, 723, 0, 0, 39, '722'),
	(243, 1, 0, -50553, 724, 0, 0, 39, '723'),
	(243, 1, 0, -50553, 725, 0, 0, 39, '724'),
	(243, 1, 0, -50553, 726, 0, 0, 39, '725'),
	(243, 1, 0, -50553, 727, 0, 0, 39, '726'),
	(243, 1, 0, -50553, 728, 0, 0, 39, '727'),
	(243, 1, 0, -50553, 729, 0, 0, 39, '728'),
	(243, 1, 0, -50553, 730, 0, 0, 39, '729'),
	(243, 1, 0, -50553, 731, 0, 0, 39, '730'),
	(243, 1, 0, -50553, 732, 0, 0, 39, '731'),
	(243, 1, 0, -50553, 733, 0, 0, 39, '732'),
	(243, 1, 0, -50553, 734, 0, 0, 39, '733'),
	(243, 1, 0, -50553, 735, 0, 0, 39, '734'),
	(243, 1, 0, -50553, 736, 0, 0, 39, '735'),
	(243, 1, 0, -50553, 737, 0, 0, 39, '736'),
	(243, 1, 0, -50553, 738, 0, 0, 39, '737'),
	(243, 1, 0, -50553, 739, 0, 0, 39, '738'),
	(243, 1, 0, -50553, 740, 0, 0, 39, '739'),
	(243, 1, 0, -50553, 741, 0, 0, 39, '740'),
	(243, 1, 0, -50553, 742, 0, 0, 39, '741'),
	(243, 1, 0, -50553, 743, 0, 0, 39, '742'),
	(243, 1, 0, -50553, 744, 0, 0, 39, '743'),
	(243, 1, 0, -50553, 745, 0, 0, 39, '744'),
	(243, 1, 0, -50553, 746, 0, 0, 39, '745'),
	(243, 1, 0, -50553, 747, 0, 0, 39, '746'),
	(243, 1, 0, -50553, 748, 0, 0, 39, '747'),
	(243, 1, 0, -50553, 749, 0, 0, 39, '748'),
	(243, 1, 0, -50553, 750, 0, 0, 39, '749'),
	(243, 1, 0, -50553, 751, 0, 0, 39, '750'),
	(243, 1, 0, -50553, 752, 0, 0, 39, '751'),
	(243, 1, 0, -50553, 753, 0, 0, 39, '752'),
	(243, 1, 0, -50553, 754, 0, 0, 39, '753'),
	(243, 1, 0, -50553, 755, 0, 0, 39, '754'),
	(243, 1, 0, -50553, 756, 0, 0, 39, '755'),
	(243, 1, 0, -50553, 757, 0, 0, 39, '756'),
	(243, 1, 0, -50553, 758, 0, 0, 39, '757'),
	(243, 1, 0, -50553, 759, 0, 0, 39, '758'),
	(243, 1, 0, -50553, 760, 0, 0, 39, '759'),
	(243, 1, 0, -50553, 761, 0, 0, 39, '760'),
	(243, 1, 0, -50553, 762, 0, 0, 39, '761'),
	(243, 1, 0, -50553, 763, 0, 0, 39, '762'),
	(243, 1, 0, -50553, 764, 0, 0, 39, '763'),
	(243, 1, 0, -50553, 765, 0, 0, 39, '764'),
	(243, 1, 0, -50553, 766, 0, 0, 39, '765'),
	(243, 1, 0, -50553, 767, 0, 0, 39, '766'),
	(243, 1, 0, -50553, 768, 0, 0, 39, '767'),
	(243, 1, 0, -50553, 769, 0, 0, 39, '768'),
	(243, 1, 0, -50553, 770, 0, 0, 39, '769'),
	(243, 1, 0, -50553, 771, 0, 0, 39, '770'),
	(243, 1, 0, -50553, 772, 0, 0, 39, '771'),
	(243, 1, 0, -50553, 773, 0, 0, 39, '772'),
	(243, 1, 0, -50553, 774, 0, 0, 39, '773'),
	(243, 1, 0, -50553, 775, 0, 0, 39, '774'),
	(243, 1, 0, -50553, 776, 0, 0, 39, '775'),
	(243, 1, 0, -50553, 777, 0, 0, 39, '776'),
	(243, 1, 0, -50553, 778, 0, 0, 39, '777'),
	(243, 1, 0, -50553, 779, 0, 0, 39, '778'),
	(243, 1, 0, -50553, 780, 0, 0, 39, '779'),
	(243, 1, 0, -50553, 781, 0, 0, 39, '780'),
	(243, 1, 0, -50553, 782, 0, 0, 39, '781'),
	(243, 1, 0, -50553, 783, 0, 0, 39, '782'),
	(243, 1, 0, -50553, 784, 0, 0, 39, '783'),
	(243, 1, 0, -50553, 785, 0, 0, 39, '784'),
	(243, 1, 0, -50553, 786, 0, 0, 39, '785'),
	(243, 1, 0, -50553, 787, 0, 0, 39, '786'),
	(243, 1, 0, -50553, 788, 0, 0, 39, '787'),
	(243, 1, 0, -50553, 789, 0, 0, 39, '788'),
	(243, 1, 0, -50553, 790, 0, 0, 39, '789'),
	(243, 1, 0, -50553, 791, 0, 0, 39, '790'),
	(243, 1, 0, -50553, 792, 0, 0, 39, '791'),
	(243, 1, 0, -50553, 793, 0, 0, 39, '792'),
	(243, 1, 0, -50553, 794, 0, 0, 39, '793'),
	(243, 1, 0, -50553, 795, 0, 0, 39, '794'),
	(243, 1, 0, -50553, 796, 0, 0, 39, '795'),
	(243, 1, 0, -50553, 797, 0, 0, 39, '796'),
	(243, 1, 0, -50553, 798, 0, 0, 39, '797'),
	(243, 1, 0, -50553, 799, 0, 0, 39, '798'),
	(243, 1, 0, -50553, 800, 0, 0, 39, '799'),
	(243, 1, 0, -50553, 801, 0, 0, 39, '800'),
	(243, 1, 0, -50553, 802, 0, 0, 39, '801'),
	(243, 1, 0, -50553, 803, 0, 0, 39, '802'),
	(243, 1, 0, -50553, 804, 0, 0, 39, '803'),
	(243, 1, 0, -50553, 805, 0, 0, 39, '804'),
	(243, 1, 0, -50553, 806, 0, 0, 39, '805'),
	(243, 1, 0, -50553, 807, 0, 0, 39, '806'),
	(243, 1, 0, -50553, 808, 0, 0, 39, '807'),
	(243, 1, 0, -50553, 809, 0, 0, 39, '808'),
	(243, 1, 0, -50553, 810, 0, 0, 39, '809'),
	(243, 1, 0, -50553, 811, 0, 0, 39, '810'),
	(243, 1, 0, -50553, 812, 0, 0, 39, '811'),
	(243, 1, 0, -50553, 813, 0, 0, 39, '812'),
	(243, 1, 0, -50553, 814, 0, 0, 39, '813'),
	(243, 1, 0, -50553, 815, 0, 0, 39, '814'),
	(243, 1, 0, -50553, 816, 0, 0, 39, '815'),
	(243, 1, 0, -50553, 817, 0, 0, 39, '816'),
	(243, 1, 0, -50553, 818, 0, 0, 39, '817'),
	(243, 1, 0, -50553, 819, 0, 0, 39, '818'),
	(243, 1, 0, -50553, 820, 0, 0, 39, '819'),
	(243, 1, 0, -50553, 821, 0, 0, 39, '820'),
	(243, 1, 0, -50553, 822, 0, 0, 39, '821'),
	(243, 1, 0, -50553, 823, 0, 0, 39, '822'),
	(243, 1, 0, -50553, 824, 0, 0, 39, '823'),
	(243, 1, 0, -50553, 825, 0, 0, 39, '824'),
	(243, 1, 0, -50553, 826, 0, 0, 39, '825'),
	(243, 1, 0, -50553, 827, 0, 0, 39, '826'),
	(243, 1, 0, -50553, 828, 0, 0, 39, '827'),
	(243, 1, 0, -50553, 829, 0, 0, 39, '828'),
	(243, 1, 0, -50553, 830, 0, 0, 39, '829'),
	(243, 1, 0, -50553, 831, 0, 0, 39, '830'),
	(243, 1, 0, -50553, 832, 0, 0, 39, '831'),
	(243, 1, 0, -50553, 833, 0, 0, 39, '832'),
	(243, 1, 0, -50553, 834, 0, 0, 39, '833'),
	(243, 1, 0, -50553, 835, 0, 0, 39, '834'),
	(243, 1, 0, -50553, 836, 0, 0, 39, '835'),
	(243, 1, 0, -50553, 837, 0, 0, 39, '836'),
	(243, 1, 0, -50553, 838, 0, 0, 39, '837'),
	(243, 1, 0, -50553, 839, 0, 0, 39, '838'),
	(243, 1, 0, -50553, 840, 0, 0, 39, '839'),
	(243, 1, 0, -50553, 841, 0, 0, 39, '840'),
	(243, 1, 0, -50553, 842, 0, 0, 39, '841'),
	(243, 1, 0, -50553, 843, 0, 0, 39, '842'),
	(243, 1, 0, -50553, 844, 0, 0, 39, '843'),
	(243, 1, 0, -50553, 845, 0, 0, 39, '844'),
	(243, 1, 0, -50553, 846, 0, 0, 39, '845'),
	(243, 1, 0, -50553, 847, 0, 0, 39, '846'),
	(243, 1, 0, -50553, 848, 0, 0, 39, '847'),
	(243, 1, 0, -50553, 849, 0, 0, 39, '848'),
	(243, 1, 0, -50553, 850, 0, 0, 39, '849'),
	(243, 1, 0, -50553, 851, 0, 0, 39, '850'),
	(243, 1, 0, -50553, 852, 0, 0, 39, '851'),
	(243, 1, 0, -50553, 853, 0, 0, 39, '852'),
	(243, 1, 0, -50553, 854, 0, 0, 39, '853'),
	(243, 1, 0, -50553, 855, 0, 0, 39, '854'),
	(243, 1, 0, -50553, 856, 0, 0, 39, '855'),
	(243, 1, 0, -50553, 857, 0, 0, 39, '856'),
	(243, 1, 0, -50553, 858, 0, 0, 39, '857'),
	(243, 1, 0, -50553, 859, 0, 0, 39, '858'),
	(243, 1, 0, -50553, 860, 0, 0, 39, '859'),
	(243, 1, 0, -50553, 861, 0, 0, 39, '860'),
	(243, 1, 0, -50553, 862, 0, 0, 39, '861'),
	(243, 1, 0, -50553, 863, 0, 0, 39, '862'),
	(243, 1, 0, -50553, 864, 0, 0, 39, '863'),
	(243, 1, 0, -50553, 865, 0, 0, 39, '864'),
	(243, 1, 0, -50553, 866, 0, 0, 39, '865'),
	(243, 1, 0, -50553, 867, 0, 0, 39, '866'),
	(243, 1, 0, -50553, 868, 0, 0, 39, '867'),
	(243, 1, 0, -50553, 869, 0, 0, 39, '868'),
	(243, 1, 0, -50553, 870, 0, 0, 39, '869'),
	(243, 1, 0, -50553, 871, 0, 0, 39, '870'),
	(243, 1, 0, -50553, 872, 0, 0, 39, '871'),
	(243, 1, 0, -50553, 873, 0, 0, 39, '872'),
	(243, 1, 0, -50553, 874, 0, 0, 39, '873'),
	(243, 1, 0, -50553, 875, 0, 0, 39, '874'),
	(243, 1, 0, -50553, 876, 0, 0, 39, '875'),
	(243, 1, 0, -50553, 877, 0, 0, 39, '876'),
	(243, 1, 0, -50553, 878, 0, 0, 39, '877'),
	(243, 1, 0, -50553, 879, 0, 0, 39, '878'),
	(243, 1, 0, -50553, 880, 0, 0, 39, '879'),
	(243, 1, 0, -50553, 881, 0, 0, 39, '880'),
	(243, 1, 0, -50553, 882, 0, 0, 39, '881'),
	(243, 1, 0, -50553, 883, 0, 0, 39, '882'),
	(243, 1, 0, -50553, 884, 0, 0, 39, '883'),
	(243, 1, 0, -50553, 885, 0, 0, 39, '884'),
	(243, 1, 0, -50553, 886, 0, 0, 39, '885'),
	(243, 1, 0, -50553, 887, 0, 0, 39, '886'),
	(243, 1, 0, -50553, 888, 0, 0, 39, '887'),
	(243, 1, 0, -50553, 889, 0, 0, 39, '888'),
	(243, 1, 0, -50553, 890, 0, 0, 39, '889'),
	(243, 1, 0, -50553, 891, 0, 0, 39, '890'),
	(243, 1, 0, -50553, 892, 0, 0, 39, '891'),
	(243, 1, 0, -50553, 893, 0, 0, 39, '892'),
	(243, 1, 0, -50553, 894, 0, 0, 39, '893'),
	(243, 1, 0, -50553, 895, 0, 0, 39, '894'),
	(243, 1, 0, -50553, 896, 0, 0, 39, '895'),
	(243, 1, 0, -50553, 897, 0, 0, 39, '896'),
	(243, 1, 0, -50553, 898, 0, 0, 39, '897'),
	(243, 1, 0, -50553, 899, 0, 0, 39, '898'),
	(243, 1, 0, -50553, 900, 0, 0, 39, '899'),
	(243, 1, 0, -50553, 901, 0, 0, 39, '900'),
	(243, 1, 0, -50553, 902, 0, 0, 39, '901'),
	(243, 1, 0, -50553, 903, 0, 0, 39, '902'),
	(243, 1, 0, -50553, 904, 0, 0, 39, '903'),
	(243, 1, 0, -50553, 905, 0, 0, 39, '904'),
	(243, 1, 0, -50553, 906, 0, 0, 39, '905'),
	(243, 1, 0, -50553, 907, 0, 0, 39, '906'),
	(243, 1, 0, -50553, 908, 0, 0, 39, '907'),
	(243, 1, 0, -50553, 909, 0, 0, 39, '908'),
	(243, 1, 0, -50553, 910, 0, 0, 39, '909'),
	(243, 1, 0, -50553, 911, 0, 0, 39, '910'),
	(243, 1, 0, -50553, 912, 0, 0, 39, '911'),
	(243, 1, 0, -50553, 913, 0, 0, 39, '912'),
	(243, 1, 0, -50553, 914, 0, 0, 39, '913'),
	(243, 1, 0, -50553, 915, 0, 0, 39, '914'),
	(243, 1, 0, -50553, 916, 0, 0, 39, '915'),
	(243, 1, 0, -50553, 917, 0, 0, 39, '916'),
	(243, 1, 0, -50553, 918, 0, 0, 39, '917'),
	(243, 1, 0, -50553, 919, 0, 0, 39, '918'),
	(243, 1, 0, -50553, 920, 0, 0, 39, '919'),
	(243, 1, 0, -50553, 921, 0, 0, 39, '920'),
	(243, 1, 0, -50553, 922, 0, 0, 39, '921'),
	(243, 1, 0, -50553, 923, 0, 0, 39, '922'),
	(243, 1, 0, -50553, 924, 0, 0, 39, '923'),
	(243, 1, 0, -50553, 925, 0, 0, 39, '924'),
	(243, 1, 0, -50553, 926, 0, 0, 39, '925'),
	(243, 1, 0, -50553, 927, 0, 0, 39, '926'),
	(243, 1, 0, -50553, 928, 0, 0, 39, '927'),
	(243, 1, 0, -50553, 929, 0, 0, 39, '928'),
	(243, 1, 0, -50553, 930, 0, 0, 39, '929'),
	(243, 1, 0, -50553, 931, 0, 0, 39, '930'),
	(243, 1, 0, -50553, 932, 0, 0, 39, '931'),
	(243, 1, 0, -50553, 933, 0, 0, 39, '932'),
	(243, 1, 0, -50553, 934, 0, 0, 39, '933'),
	(243, 1, 0, -50553, 935, 0, 0, 39, '934'),
	(243, 1, 0, -50553, 936, 0, 0, 39, '935'),
	(243, 1, 0, -50553, 937, 0, 0, 39, '936'),
	(243, 1, 0, -50553, 938, 0, 0, 39, '937'),
	(243, 1, 0, -50553, 939, 0, 0, 39, '938'),
	(243, 1, 0, -50553, 940, 0, 0, 39, '939'),
	(243, 1, 0, -50553, 941, 0, 0, 39, '940'),
	(243, 1, 0, -50553, 942, 0, 0, 39, '941'),
	(243, 1, 0, -50553, 943, 0, 0, 39, '942'),
	(243, 1, 0, -50553, 944, 0, 0, 39, '943'),
	(243, 1, 0, -50553, 945, 0, 0, 39, '944'),
	(243, 1, 0, -50553, 946, 0, 0, 39, '945'),
	(243, 1, 0, -50553, 947, 0, 0, 39, '946'),
	(243, 1, 0, -50553, 948, 0, 0, 39, '947'),
	(243, 1, 0, -50553, 949, 0, 0, 39, '948'),
	(243, 1, 0, -50553, 950, 0, 0, 39, '949'),
	(243, 1, 0, -50553, 951, 0, 0, 39, '950'),
	(243, 1, 0, -50553, 952, 0, 0, 39, '951'),
	(243, 1, 0, -50553, 953, 0, 0, 39, '952'),
	(243, 1, 0, -50553, 954, 0, 0, 39, '953'),
	(243, 1, 0, -50553, 955, 0, 0, 39, '954'),
	(243, 1, 0, -50553, 956, 0, 0, 39, '955'),
	(243, 1, 0, -50553, 957, 0, 0, 39, '956'),
	(243, 1, 0, -50553, 958, 0, 0, 39, '957'),
	(243, 1, 0, -50553, 959, 0, 0, 39, '958'),
	(243, 1, 0, -50553, 960, 0, 0, 39, '959'),
	(243, 1, 0, -50553, 961, 0, 0, 39, '960'),
	(243, 1, 0, -50553, 962, 0, 0, 39, '961'),
	(243, 1, 0, -50553, 963, 0, 0, 39, '962'),
	(243, 1, 0, -50553, 964, 0, 0, 39, '963'),
	(243, 1, 0, -50553, 965, 0, 0, 39, '964'),
	(243, 1, 0, -50553, 966, 0, 0, 39, '965'),
	(243, 1, 0, -50553, 967, 0, 0, 39, '966'),
	(243, 1, 0, -50553, 968, 0, 0, 39, '967'),
	(243, 1, 0, -50553, 969, 0, 0, 39, '968'),
	(243, 1, 0, -50553, 970, 0, 0, 39, '969'),
	(243, 1, 0, -50553, 971, 0, 0, 39, '970'),
	(243, 1, 0, -50553, 972, 0, 0, 39, '971'),
	(243, 1, 0, -50553, 973, 0, 0, 39, '972'),
	(243, 1, 0, -50553, 974, 0, 0, 39, '973'),
	(243, 1, 0, -50553, 975, 0, 0, 39, '974'),
	(243, 1, 0, -50553, 976, 0, 0, 39, '975'),
	(243, 1, 0, -50553, 977, 0, 0, 39, '976'),
	(243, 1, 0, -50553, 978, 0, 0, 39, '977'),
	(243, 1, 0, -50553, 979, 0, 0, 39, '978'),
	(243, 1, 0, -50553, 980, 0, 0, 39, '979'),
	(243, 1, 0, -50553, 981, 0, 0, 39, '980'),
	(243, 1, 0, -50553, 982, 0, 0, 39, '981'),
	(243, 1, 0, -50553, 983, 0, 0, 39, '982'),
	(243, 1, 0, -50553, 984, 0, 0, 39, '983'),
	(243, 1, 0, -50553, 985, 0, 0, 39, '984'),
	(243, 1, 0, -50553, 986, 0, 0, 39, '985'),
	(243, 1, 0, -50553, 987, 0, 0, 39, '986'),
	(243, 1, 0, -50553, 988, 0, 0, 39, '987'),
	(243, 1, 0, -50553, 989, 0, 0, 39, '988'),
	(243, 1, 0, -50553, 990, 0, 0, 39, '989'),
	(243, 1, 0, -50553, 991, 0, 0, 39, '990'),
	(243, 1, 0, -50553, 992, 0, 0, 39, '991'),
	(243, 1, 0, -50553, 993, 0, 0, 39, '992'),
	(243, 1, 0, -50553, 994, 0, 0, 39, '993'),
	(243, 1, 0, -50553, 995, 0, 0, 39, '994'),
	(243, 1, 0, -50553, 996, 0, 0, 39, '995'),
	(243, 1, 0, -50553, 997, 0, 0, 39, '996'),
	(243, 1, 0, -50553, 998, 0, 0, 39, '997'),
	(243, 1, 0, -50553, 999, 0, 0, 39, '998'),
	(243, 1, 0, -50553, 1000, 0, 0, 39, '999'),
	(243, 1, 0, -50553, 1001, 0, 0, 39, '1000'),
	(243, 1, 0, -50553, 1002, 0, 0, 39, '1001'),
	(243, 1, 0, -50553, 1003, 0, 0, 39, '1002'),
	(243, 1, 0, -50553, 1004, 0, 0, 39, '1003'),
	(243, 1, 0, -50553, 1005, 0, 0, 39, '1004'),
	(243, 1, 0, -50553, 1006, 0, 0, 39, '1005'),
	(243, 1, 0, -50553, 1007, 0, 0, 39, '1006'),
	(243, 1, 0, -50553, 1008, 0, 0, 39, '1007'),
	(243, 1, 0, -50553, 1009, 0, 0, 39, '1008'),
	(243, 1, 0, -50553, 1010, 0, 0, 39, '1009'),
	(243, 1, 0, -50553, 1011, 0, 0, 39, '1010'),
	(243, 1, 0, -50553, 1012, 0, 0, 39, '1011'),
	(243, 1, 0, -50553, 1013, 0, 0, 39, '1012'),
	(243, 1, 0, -50553, 1014, 0, 0, 39, '1013'),
	(243, 1, 0, -50553, 1015, 0, 0, 39, '1014'),
	(243, 1, 0, -50553, 1016, 0, 0, 39, '1015'),
	(243, 1, 0, -50553, 1017, 0, 0, 39, '1016'),
	(243, 1, 0, -50553, 1018, 0, 0, 39, '1017'),
	(243, 1, 0, -50553, 1019, 0, 0, 39, '1018'),
	(243, 1, 0, -50553, 1020, 0, 0, 39, '1019'),
	(243, 1, 0, -50553, 1021, 0, 0, 39, '1020'),
	(243, 1, 0, -50553, 1022, 0, 0, 39, '1021'),
	(243, 1, 0, -50553, 1023, 0, 0, 39, '1022'),
	(243, 1, 0, -50553, 1024, 0, 0, 39, '1023'),
	(243, 1, 0, -50553, 1025, 0, 0, 39, '1024'),
	(243, 1, 0, -50553, 1026, 0, 0, 39, '1025'),
	(243, 1, 0, -50553, 1027, 0, 0, 39, '1026'),
	(243, 1, 0, -50553, 1028, 0, 0, 39, '1027'),
	(243, 1, 0, -50553, 1029, 0, 0, 39, '1028'),
	(243, 1, 0, -50553, 1030, 0, 0, 39, '1029'),
	(243, 1, 0, -50553, 1031, 0, 0, 39, '1030'),
	(243, 1, 0, -50553, 1032, 0, 0, 39, '1031'),
	(243, 1, 0, -50553, 1033, 0, 0, 39, '1032'),
	(243, 1, 0, -50553, 1034, 0, 0, 39, '1033'),
	(243, 1, 0, -50553, 1035, 0, 0, 39, '1034'),
	(243, 1, 0, -50553, 1036, 0, 0, 39, '1035'),
	(243, 1, 0, -50553, 1037, 0, 0, 39, '1036'),
	(243, 1, 0, -50553, 1038, 0, 0, 39, '1037'),
	(243, 1, 0, -50553, 1039, 0, 0, 39, '1038'),
	(243, 1, 0, -50553, 1040, 0, 0, 39, '1039'),
	(243, 1, 0, -50553, 1041, 0, 0, 39, '1040'),
	(243, 1, 0, -50553, 1042, 0, 0, 39, '1041'),
	(243, 1, 0, -50553, 1043, 0, 0, 39, '1042'),
	(243, 1, 0, -50553, 1044, 0, 0, 39, '1043'),
	(243, 1, 0, -50553, 1045, 0, 0, 39, '1044'),
	(243, 1, 0, -50553, 1046, 0, 0, 39, '1045'),
	(243, 1, 0, -50553, 1047, 0, 0, 39, '1046'),
	(243, 1, 0, -50553, 1048, 0, 0, 39, '1047'),
	(243, 1, 0, -50553, 1049, 0, 0, 39, '1048'),
	(243, 1, 0, -50553, 1050, 0, 0, 39, '1049'),
	(243, 1, 0, -50553, 1051, 0, 0, 39, '1050'),
	(243, 1, 0, -50553, 1052, 0, 0, 39, '1051'),
	(243, 1, 0, -50553, 1053, 0, 0, 39, '1052'),
	(243, 1, 0, -50553, 1054, 0, 0, 39, '1053'),
	(243, 1, 0, -50553, 1055, 0, 0, 39, '1054'),
	(243, 1, 0, -50553, 1056, 0, 0, 39, '1055'),
	(243, 1, 0, -50553, 1057, 0, 0, 39, '1056'),
	(243, 1, 0, -50553, 1058, 0, 0, 39, '1057'),
	(243, 1, 0, -50553, 1059, 0, 0, 39, '1058'),
	(243, 1, 0, -50553, 1060, 0, 0, 39, '1059'),
	(243, 1, 0, -50553, 1061, 0, 0, 39, '1060'),
	(243, 1, 0, -50553, 1062, 0, 0, 39, '1061'),
	(243, 1, 0, -50553, 1063, 0, 0, 39, '1062'),
	(243, 1, 0, -50553, 1064, 0, 0, 39, '1063'),
	(243, 1, 0, -50553, 1065, 0, 0, 39, '1064'),
	(243, 1, 0, -50553, 1066, 0, 0, 39, '1065'),
	(243, 1, 0, -50553, 1067, 0, 0, 39, '1066'),
	(243, 1, 0, -50553, 1068, 0, 0, 39, '1067'),
	(243, 1, 0, -50553, 1069, 0, 0, 39, '1068'),
	(243, 1, 0, -50553, 1070, 0, 0, 39, '1069'),
	(243, 1, 0, -50553, 1071, 0, 0, 39, '1070'),
	(243, 1, 0, -50553, 1072, 0, 0, 39, '1071'),
	(243, 1, 0, -50553, 1073, 0, 0, 39, '1072'),
	(243, 1, 0, -50553, 1074, 0, 0, 39, '1073'),
	(243, 1, 0, -50553, 1075, 0, 0, 39, '1074'),
	(243, 1, 0, -50553, 1076, 0, 0, 39, '1075'),
	(243, 1, 0, -50553, 1077, 0, 0, 39, '1076'),
	(243, 1, 0, -50553, 1078, 0, 0, 39, '1077'),
	(243, 1, 0, -50553, 1079, 0, 0, 39, '1078'),
	(243, 1, 0, -50553, 1080, 0, 0, 39, '1079'),
	(243, 1, 0, -50553, 1081, 0, 0, 39, '1080'),
	(243, 1, 0, -50553, 1082, 0, 0, 39, '1081'),
	(243, 1, 0, -50553, 1083, 0, 0, 39, '1082'),
	(243, 1, 0, -50553, 1084, 0, 0, 39, '1083'),
	(243, 1, 0, -50553, 1085, 0, 0, 39, '1084'),
	(243, 1, 0, -50553, 1086, 0, 0, 39, '1085'),
	(243, 1, 0, -50553, 1087, 0, 0, 39, '1086'),
	(243, 1, 0, -50553, 1088, 0, 0, 39, '1087'),
	(243, 1, 0, -50553, 1089, 0, 0, 39, '1088'),
	(243, 1, 0, -50553, 1090, 0, 0, 39, '1089'),
	(243, 1, 0, -50553, 1091, 0, 0, 39, '1090'),
	(243, 1, 0, -50553, 1092, 0, 0, 39, '1091'),
	(243, 1, 0, -50553, 1093, 0, 0, 39, '1092'),
	(243, 1, 0, -50553, 1094, 0, 0, 39, '1093'),
	(243, 1, 0, -50553, 1095, 0, 0, 39, '1094'),
	(243, 1, 0, -50553, 1096, 0, 0, 39, '1095'),
	(243, 1, 0, -50553, 1097, 0, 0, 39, '1096'),
	(243, 1, 0, -50553, 1098, 0, 0, 39, '1097'),
	(243, 1, 0, -50553, 1099, 0, 0, 39, '1098'),
	(243, 1, 0, -50553, 1100, 0, 0, 39, '1099'),
	(243, 1, 0, -50553, 1101, 0, 0, 39, '1100'),
	(243, 1, 0, -50553, 1102, 0, 0, 39, '1101'),
	(243, 1, 0, -50553, 1103, 0, 0, 39, '1102'),
	(243, 1, 0, -50553, 1104, 0, 0, 39, '1103'),
	(243, 1, 0, -50553, 1105, 0, 0, 39, '1104'),
	(243, 1, 0, -50553, 1106, 0, 0, 39, '1105'),
	(243, 1, 0, -50553, 1107, 0, 0, 39, '1106'),
	(243, 1, 0, -50553, 1108, 0, 0, 39, '1107'),
	(243, 1, 0, -50553, 1109, 0, 0, 39, '1108'),
	(243, 1, 0, -50553, 1110, 0, 0, 39, '1109'),
	(243, 1, 0, -50553, 1111, 0, 0, 39, '1110'),
	(243, 1, 0, -50553, 1112, 0, 0, 39, '1111'),
	(243, 1, 0, -50553, 1113, 0, 0, 39, '1112'),
	(243, 1, 0, -50553, 1114, 0, 0, 39, '1113'),
	(243, 1, 0, -50553, 1115, 0, 0, 39, '1114'),
	(243, 1, 0, -50553, 1116, 0, 0, 39, '1115'),
	(243, 1, 0, -50553, 1117, 0, 0, 39, '1116'),
	(243, 1, 0, -50553, 1118, 0, 0, 39, '1117'),
	(243, 1, 0, -50553, 1119, 0, 0, 39, '1118'),
	(243, 1, 0, -50553, 1120, 0, 0, 39, '1119'),
	(243, 1, 0, -50553, 1121, 0, 0, 39, '1120'),
	(243, 1, 0, -50553, 1122, 0, 0, 39, '1121'),
	(243, 1, 0, -50553, 1123, 0, 0, 39, '1122'),
	(243, 1, 0, -50553, 1124, 0, 0, 39, '1123'),
	(243, 1, 0, -50553, 1125, 0, 0, 39, '1124'),
	(243, 1, 0, -50553, 1126, 0, 0, 39, '1125'),
	(243, 1, 0, -50553, 1127, 0, 0, 39, '1126'),
	(243, 1, 0, -50553, 1128, 0, 0, 39, '1127'),
	(243, 1, 0, -50553, 1129, 0, 0, 39, '1128'),
	(243, 1, 0, -50553, 1130, 0, 0, 39, '1129'),
	(243, 1, 0, -50553, 1131, 0, 0, 39, '1130'),
	(243, 1, 0, -50553, 1132, 0, 0, 39, '1131'),
	(243, 1, 0, -50553, 1133, 0, 0, 39, '1132'),
	(243, 1, 0, -50553, 1134, 0, 0, 39, '1133'),
	(243, 1, 0, -50553, 1135, 0, 0, 39, '1134'),
	(243, 1, 0, -50553, 1136, 0, 0, 39, '1135'),
	(243, 1, 0, -50553, 1137, 0, 0, 39, '1136'),
	(243, 1, 0, -50553, 1138, 0, 0, 39, '1137'),
	(243, 1, 0, -50553, 1139, 0, 0, 39, '1138'),
	(243, 1, 0, -50553, 1140, 0, 0, 39, '1139'),
	(243, 1, 0, -50553, 1141, 0, 0, 39, '1140'),
	(243, 1, 0, -50553, 1142, 0, 0, 39, '1141'),
	(243, 1, 0, -50553, 1143, 0, 0, 39, '1142'),
	(243, 1, 0, -50553, 1144, 0, 0, 39, '1143'),
	(243, 1, 0, -50553, 1145, 0, 0, 39, '1144'),
	(243, 1, 0, -50553, 1146, 0, 0, 39, '1145'),
	(243, 1, 0, -50553, 1147, 0, 0, 39, '1146'),
	(243, 1, 0, -50553, 1148, 0, 0, 39, '1147'),
	(243, 1, 0, -50553, 1149, 0, 0, 39, '1148'),
	(243, 1, 0, -50553, 1150, 0, 0, 39, '1149'),
	(243, 1, 0, -50553, 1151, 0, 0, 39, '1150'),
	(243, 1, 0, -50553, 1152, 0, 0, 39, '1151'),
	(243, 1, 0, -50553, 1153, 0, 0, 39, '1152'),
	(243, 1, 0, -50553, 1154, 0, 0, 39, '1153'),
	(243, 1, 0, -50553, 1155, 0, 0, 39, '1154'),
	(243, 1, 0, -50553, 1156, 0, 0, 39, '1155'),
	(243, 1, 0, -50553, 1157, 0, 0, 39, '1156'),
	(243, 1, 0, -50553, 1158, 0, 0, 39, '1157'),
	(243, 1, 0, -50553, 1159, 0, 0, 39, '1158'),
	(243, 1, 0, -50553, 1160, 0, 0, 39, '1159'),
	(243, 1, 0, -50553, 1161, 0, 0, 39, '1160'),
	(243, 1, 0, -50553, 1162, 0, 0, 39, '1161'),
	(243, 1, 0, -50553, 1163, 0, 0, 39, '1162'),
	(243, 1, 0, -50553, 1164, 0, 0, 39, '1163'),
	(243, 1, 0, -50553, 1165, 0, 0, 39, '1164'),
	(243, 1, 0, -50553, 1166, 0, 0, 39, '1165'),
	(243, 1, 0, -50553, 1167, 0, 0, 39, '1166'),
	(243, 1, 0, -50553, 1168, 0, 0, 39, '1167'),
	(243, 1, 0, -50553, 1169, 0, 0, 39, '1168'),
	(243, 1, 0, -50553, 1170, 0, 0, 39, '1169'),
	(243, 1, 0, -50553, 1171, 0, 0, 39, '1170'),
	(243, 1, 0, -50553, 1172, 0, 0, 39, '1171'),
	(243, 1, 0, -50553, 1173, 0, 0, 39, '1172'),
	(243, 1, 0, -50553, 1174, 0, 0, 39, '1173'),
	(243, 1, 0, -50553, 1175, 0, 0, 39, '1174'),
	(243, 1, 0, -50553, 1176, 0, 0, 39, '1175'),
	(243, 1, 0, -50553, 1177, 0, 0, 39, '1176'),
	(243, 1, 0, -50553, 1178, 0, 0, 39, '1177'),
	(243, 1, 0, -50553, 1179, 0, 0, 39, '1178'),
	(243, 1, 0, -50553, 1180, 0, 0, 39, '1179'),
	(243, 1, 0, -50553, 1181, 0, 0, 39, '1180'),
	(243, 1, 0, -50553, 1182, 0, 0, 39, '1181'),
	(243, 1, 0, -50553, 1183, 0, 0, 39, '1182'),
	(243, 1, 0, -50553, 1184, 0, 0, 39, '1183'),
	(243, 1, 0, -50553, 1185, 0, 0, 39, '1184'),
	(243, 1, 0, -50553, 1186, 0, 0, 39, '1185'),
	(243, 1, 0, -50553, 1187, 0, 0, 39, '1186'),
	(243, 1, 0, -50553, 1188, 0, 0, 39, '1187'),
	(243, 1, 0, -50553, 1189, 0, 0, 39, '1188'),
	(243, 1, 0, -50553, 1190, 0, 0, 39, '1189'),
	(243, 1, 0, -50553, 1191, 0, 0, 39, '1190'),
	(243, 1, 0, -50553, 1192, 0, 0, 39, '1191'),
	(243, 1, 0, -50553, 1193, 0, 0, 39, '1192'),
	(243, 1, 0, -50553, 1194, 0, 0, 39, '1193'),
	(243, 1, 0, -50553, 1195, 0, 0, 39, '1194'),
	(243, 1, 0, -50553, 1196, 0, 0, 39, '1195'),
	(243, 1, 0, -50553, 1197, 0, 0, 39, '1196'),
	(243, 1, 0, -50553, 1198, 0, 0, 39, '1197'),
	(243, 1, 0, -50553, 1199, 0, 0, 39, '1198'),
	(243, 1, 0, -50553, 1200, 0, 0, 39, '1199'),
	(243, 1, 0, -50553, 1201, 0, 0, 39, '1200'),
	(243, 1, 0, -50553, 1202, 0, 0, 39, '1201'),
	(243, 1, 0, -50553, 1203, 0, 0, 39, '1202'),
	(243, 1, 0, -50553, 1204, 0, 0, 39, '1203'),
	(243, 1, 0, -50553, 1205, 0, 0, 39, '1204'),
	(243, 1, 0, -50553, 1206, 0, 0, 39, '1205'),
	(243, 1, 0, -50553, 1207, 0, 0, 39, '1206'),
	(243, 1, 0, -50553, 1208, 0, 0, 39, '1207'),
	(243, 1, 0, -50553, 1209, 0, 0, 39, '1208'),
	(243, 1, 0, -50553, 1210, 0, 0, 39, '1209'),
	(243, 1, 0, -50553, 1211, 0, 0, 39, '1210'),
	(243, 1, 0, -50553, 1212, 0, 0, 39, '1211'),
	(243, 1, 0, -50553, 1213, 0, 0, 39, '1212'),
	(243, 1, 0, -50553, 1214, 0, 0, 39, '1213'),
	(243, 1, 0, -50553, 1215, 0, 0, 39, '1214'),
	(243, 1, 0, -50553, 1216, 0, 0, 39, '1215'),
	(243, 1, 0, -50553, 1217, 0, 0, 39, '1216'),
	(243, 1, 0, -50553, 1218, 0, 0, 39, '1217'),
	(243, 1, 0, -50553, 1219, 0, 0, 39, '1218'),
	(243, 1, 0, -50553, 1220, 0, 0, 39, '1219'),
	(243, 1, 0, -50553, 1221, 0, 0, 39, '1220'),
	(243, 1, 0, -50553, 1222, 0, 0, 39, '1221'),
	(243, 1, 0, -50553, 1223, 0, 0, 39, '1222'),
	(243, 1, 0, -50553, 1224, 0, 0, 39, '1223'),
	(243, 1, 0, -50553, 1225, 0, 0, 39, '1224'),
	(243, 1, 0, -50553, 1226, 0, 0, 39, '1225'),
	(243, 1, 0, -50553, 1227, 0, 0, 39, '1226'),
	(243, 1, 0, -50553, 1228, 0, 0, 39, '1227'),
	(243, 1, 0, -50553, 1229, 0, 0, 39, '1228'),
	(243, 1, 0, -50553, 1230, 0, 0, 39, '1229'),
	(243, 1, 0, -50553, 1231, 0, 0, 39, '1230'),
	(243, 1, 0, -50553, 1232, 0, 0, 39, '1231'),
	(243, 1, 0, -50553, 1233, 0, 0, 39, '1232'),
	(243, 1, 0, -50553, 1234, 0, 0, 39, '1233'),
	(243, 1, 0, -50553, 1235, 0, 0, 39, '1234'),
	(243, 1, 0, -50553, 1236, 0, 0, 39, '1235'),
	(243, 1, 0, -50553, 1237, 0, 0, 39, '1236'),
	(243, 1, 0, -50553, 1238, 0, 0, 39, '1237'),
	(243, 1, 0, -50553, 1239, 0, 0, 39, '1238'),
	(243, 1, 0, -50553, 1240, 0, 0, 39, '1239'),
	(243, 1, 0, -50553, 1241, 0, 0, 39, '1240'),
	(243, 1, 0, -50553, 1242, 0, 0, 39, '1241'),
	(243, 1, 0, -50553, 1243, 0, 0, 39, '1242'),
	(243, 1, 0, -50553, 1244, 0, 0, 39, '1243'),
	(243, 1, 0, -50553, 1245, 0, 0, 39, '1244'),
	(243, 1, 0, -50553, 1246, 0, 0, 39, '1245'),
	(243, 1, 0, -50553, 1247, 0, 0, 39, '1246'),
	(243, 1, 0, -50553, 1248, 0, 0, 39, '1247'),
	(243, 1, 0, -50553, 1249, 0, 0, 39, '1248'),
	(243, 1, 0, -50553, 1250, 0, 0, 39, '1249'),
	(243, 1, 0, -50553, 1251, 0, 0, 39, '1250'),
	(243, 1, 0, -50553, 1252, 0, 0, 39, '1251'),
	(243, 1, 0, -50553, 1253, 0, 0, 39, '1252'),
	(243, 1, 0, -50553, 1254, 0, 0, 39, '1253'),
	(243, 1, 0, -50553, 1255, 0, 0, 39, '1254'),
	(243, 1, 0, -50553, 1256, 0, 0, 39, '1255'),
	(243, 1, 0, -50553, 1257, 0, 0, 39, '1256'),
	(243, 1, 0, -50553, 1258, 0, 0, 39, '1257'),
	(243, 1, 0, -50553, 1259, 0, 0, 39, '1258'),
	(243, 1, 0, -50553, 1260, 0, 0, 39, '1259'),
	(243, 1, 0, -50553, 1261, 0, 0, 39, '1260'),
	(243, 1, 0, -50553, 1262, 0, 0, 39, '1261'),
	(243, 1, 0, -50553, 1263, 0, 0, 39, '1262'),
	(243, 1, 0, -50553, 1264, 0, 0, 39, '1263'),
	(243, 1, 0, -50553, 1265, 0, 0, 39, '1264'),
	(243, 1, 0, -50553, 1266, 0, 0, 39, '1265'),
	(243, 1, 0, -50553, 1267, 0, 0, 39, '1266'),
	(243, 1, 0, -50553, 1268, 0, 0, 39, '1267'),
	(243, 1, 0, -50553, 1269, 0, 0, 39, '1268'),
	(243, 1, 0, -50553, 1270, 0, 0, 39, '1269'),
	(243, 1, 0, -50553, 1271, 0, 0, 39, '1270'),
	(243, 1, 0, -50553, 1272, 0, 0, 39, '1271'),
	(243, 1, 0, -50553, 1273, 0, 0, 39, '1272'),
	(243, 1, 0, -50553, 1274, 0, 0, 39, '1273'),
	(243, 1, 0, -50553, 1275, 0, 0, 39, '1274'),
	(243, 1, 0, -50553, 1276, 0, 0, 39, '1275'),
	(243, 1, 0, -50553, 1277, 0, 0, 39, '1276'),
	(243, 1, 0, -50553, 1278, 0, 0, 39, '1277'),
	(243, 1, 0, -50553, 1279, 0, 0, 39, '1278'),
	(243, 1, 0, -50553, 1280, 0, 0, 39, '1279'),
	(243, 1, 0, -50553, 1281, 0, 0, 39, '1280'),
	(243, 1, 0, -50553, 1282, 0, 0, 39, '1281'),
	(243, 1, 0, -50553, 1283, 0, 0, 39, '1282'),
	(243, 1, 0, -50553, 1284, 0, 0, 39, '1283'),
	(243, 1, 0, -50553, 1285, 0, 0, 39, '1284'),
	(243, 1, 0, -50553, 1286, 0, 0, 39, '1285'),
	(243, 1, 0, -50553, 1287, 0, 0, 39, '1286'),
	(243, 1, 0, -50553, 1288, 0, 0, 39, '1287'),
	(243, 1, 0, -50553, 1289, 0, 0, 39, '1288'),
	(243, 1, 0, -50553, 1290, 0, 0, 39, '1289'),
	(243, 1, 0, -50553, 1291, 0, 0, 39, '1290'),
	(243, 1, 0, -50553, 1292, 0, 0, 39, '1291'),
	(243, 1, 0, -50553, 1293, 0, 0, 39, '1292'),
	(243, 1, 0, -50553, 1294, 0, 0, 39, '1293'),
	(243, 1, 0, -50553, 1295, 0, 0, 39, '1294'),
	(243, 1, 0, -50553, 1296, 0, 0, 39, '1295'),
	(243, 1, 0, -50553, 1297, 0, 0, 39, '1296'),
	(243, 1, 0, -50553, 1298, 0, 0, 39, '1297'),
	(243, 1, 0, -50553, 1299, 0, 0, 39, '1298'),
	(243, 1, 0, -50553, 1300, 0, 0, 39, '1299'),
	(243, 1, 0, -50553, 1301, 0, 0, 39, '1300'),
	(243, 1, 0, -50553, 1302, 0, 0, 39, '1301'),
	(243, 1, 0, -50553, 1303, 0, 0, 39, '1302'),
	(243, 1, 0, -50553, 1304, 0, 0, 39, '1303'),
	(243, 1, 0, -50553, 1305, 0, 0, 39, '1304'),
	(243, 1, 0, -50553, 1306, 0, 0, 39, '1305'),
	(243, 1, 0, -50553, 1307, 0, 0, 39, '1306'),
	(243, 1, 0, -50553, 1308, 0, 0, 39, '1307'),
	(243, 1, 0, -50553, 1309, 0, 0, 39, '1308'),
	(243, 1, 0, -50553, 1310, 0, 0, 39, '1309'),
	(243, 1, 0, -50553, 1311, 0, 0, 39, '1310'),
	(243, 1, 0, -50553, 1312, 0, 0, 39, '1311'),
	(243, 1, 0, -50553, 1313, 0, 0, 39, '1312'),
	(243, 1, 0, -50553, 1314, 0, 0, 39, '1313'),
	(243, 1, 0, -50553, 1315, 0, 0, 39, '1314'),
	(243, 1, 0, -50553, 1316, 0, 0, 39, '1315'),
	(243, 1, 0, -50553, 1317, 0, 0, 39, '1316'),
	(243, 1, 0, -50553, 1318, 0, 0, 39, '1317'),
	(243, 1, 0, -50553, 1319, 0, 0, 39, '1318'),
	(243, 1, 0, -50553, 1320, 0, 0, 39, '1319'),
	(243, 1, 0, -50553, 1321, 0, 0, 39, '1320'),
	(243, 1, 0, -50553, 1322, 0, 0, 39, '1321'),
	(243, 1, 0, -50553, 1323, 0, 0, 39, '1322'),
	(243, 1, 0, -50553, 1324, 0, 0, 39, '1323'),
	(243, 1, 0, -50553, 1325, 0, 0, 39, '1324'),
	(243, 1, 0, -50553, 1326, 0, 0, 39, '1325'),
	(243, 1, 0, -50553, 1327, 0, 0, 39, '1326'),
	(243, 1, 0, -50553, 1328, 0, 0, 39, '1327'),
	(243, 1, 0, -50553, 1329, 0, 0, 39, '1328'),
	(243, 1, 0, -50553, 1330, 0, 0, 39, '1329'),
	(243, 1, 0, -50553, 1331, 0, 0, 39, '1330'),
	(243, 1, 0, -50553, 1332, 0, 0, 39, '1331'),
	(243, 1, 0, -50553, 1333, 0, 0, 39, '1332'),
	(243, 1, 0, -50553, 1334, 0, 0, 39, '1333'),
	(243, 1, 0, -50553, 1335, 0, 0, 39, '1334'),
	(243, 1, 0, -50553, 1336, 0, 0, 39, '1335'),
	(243, 1, 0, -50553, 1337, 0, 0, 39, '1336'),
	(243, 1, 0, -50553, 1338, 0, 0, 39, '1337'),
	(243, 1, 0, -50553, 1339, 0, 0, 39, '1338'),
	(243, 1, 0, -50553, 1340, 0, 0, 39, '1339'),
	(243, 1, 0, -50553, 1341, 0, 0, 39, '1340'),
	(243, 1, 0, -50553, 1342, 0, 0, 39, '1341'),
	(243, 1, 0, -50553, 1343, 0, 0, 39, '1342'),
	(243, 1, 0, -50553, 1344, 0, 0, 39, '1343'),
	(243, 1, 0, -50553, 1345, 0, 0, 39, '1344'),
	(243, 1, 0, -50553, 1346, 0, 0, 39, '1345'),
	(243, 1, 0, -50553, 1347, 0, 0, 39, '1346'),
	(243, 1, 0, -50553, 1348, 0, 0, 39, '1347'),
	(243, 1, 0, -50553, 1349, 0, 0, 39, '1348'),
	(243, 1, 0, -50553, 1350, 0, 0, 39, '1349'),
	(243, 1, 0, -50553, 1351, 0, 0, 39, '1350'),
	(243, 1, 0, -50553, 1352, 0, 0, 39, '1351'),
	(243, 1, 0, -50553, 1353, 0, 0, 39, '1352'),
	(243, 1, 0, -50553, 1354, 0, 0, 39, '1353'),
	(243, 1, 0, -50553, 1355, 0, 0, 39, '1354'),
	(243, 1, 0, -50553, 1356, 0, 0, 39, '1355'),
	(243, 1, 0, -50553, 1357, 0, 0, 39, '1356'),
	(243, 1, 0, -50553, 1358, 0, 0, 39, '1357'),
	(243, 1, 0, -50553, 1359, 0, 0, 39, '1358'),
	(243, 1, 0, -50553, 1360, 0, 0, 39, '1359'),
	(243, 1, 0, -50553, 1361, 0, 0, 39, '1360'),
	(243, 1, 0, -50553, 1362, 0, 0, 39, '1361'),
	(243, 1, 0, -50553, 1363, 0, 0, 39, '1362'),
	(243, 1, 0, -50553, 1364, 0, 0, 39, '1363'),
	(243, 1, 0, -50553, 1365, 0, 0, 39, '1364'),
	(243, 1, 0, -50553, 1366, 0, 0, 39, '1365'),
	(243, 1, 0, -50553, 1367, 0, 0, 39, '1366'),
	(243, 1, 0, -50553, 1368, 0, 0, 39, '1367'),
	(243, 1, 0, -50553, 1369, 0, 0, 39, '1368'),
	(243, 1, 0, -50553, 1370, 0, 0, 39, '1369'),
	(243, 1, 0, -50553, 1371, 0, 0, 39, '1370'),
	(243, 1, 0, -50553, 1372, 0, 0, 39, '1371'),
	(243, 1, 0, -50553, 1373, 0, 0, 39, '1372'),
	(243, 1, 0, -50553, 1374, 0, 0, 39, '1373'),
	(243, 1, 0, -50553, 1375, 0, 0, 39, '1374'),
	(243, 1, 0, -50553, 1376, 0, 0, 39, '1375'),
	(243, 1, 0, -50553, 1377, 0, 0, 39, '1376'),
	(243, 1, 0, -50553, 1378, 0, 0, 39, '1377'),
	(243, 1, 0, -50553, 1379, 0, 0, 39, '1378'),
	(243, 1, 0, -50553, 1380, 0, 0, 39, '1379'),
	(243, 1, 0, -50553, 1381, 0, 0, 39, '1380'),
	(243, 1, 0, -50553, 1382, 0, 0, 39, '1381'),
	(243, 1, 0, -50553, 1383, 0, 0, 39, '1382'),
	(243, 1, 0, -50553, 1384, 0, 0, 39, '1383'),
	(243, 1, 0, -50553, 1385, 0, 0, 39, '1384'),
	(243, 1, 0, -50553, 1386, 0, 0, 39, '1385'),
	(243, 1, 0, -50553, 1387, 0, 0, 39, '1386'),
	(243, 1, 0, -50553, 1388, 0, 0, 39, '1387'),
	(243, 1, 0, -50553, 1389, 0, 0, 39, '1388'),
	(243, 1, 0, -50553, 1390, 0, 0, 39, '1389'),
	(243, 1, 0, -50553, 1391, 0, 0, 39, '1390'),
	(243, 1, 0, -50553, 1392, 0, 0, 39, '1391'),
	(243, 1, 0, -50553, 1393, 0, 0, 39, '1392'),
	(243, 1, 0, -50553, 1394, 0, 0, 39, '1393'),
	(243, 1, 0, -50553, 1395, 0, 0, 39, '1394'),
	(243, 1, 0, -50553, 1396, 0, 0, 39, '1395'),
	(243, 1, 0, -50553, 1397, 0, 0, 39, '1396'),
	(243, 1, 0, -50553, 1398, 0, 0, 39, '1397'),
	(243, 1, 0, -50553, 1399, 0, 0, 39, '1398'),
	(243, 1, 0, -50553, 1400, 0, 0, 39, '1399'),
	(243, 1, 0, -50553, 1401, 0, 0, 39, '1400'),
	(243, 1, 0, -50553, 1402, 0, 0, 39, '1401'),
	(243, 1, 0, -50553, 1403, 0, 0, 39, '1402'),
	(243, 1, 0, -50553, 1404, 0, 0, 39, '1403'),
	(243, 1, 0, -50553, 1405, 0, 0, 39, '1404'),
	(243, 1, 0, -50553, 1406, 0, 0, 39, '1405'),
	(243, 1, 0, -50553, 1407, 0, 0, 39, '1406'),
	(243, 1, 0, -50553, 1408, 0, 0, 39, '1407'),
	(243, 1, 0, -50553, 1409, 0, 0, 39, '1408'),
	(243, 1, 0, -50553, 1410, 0, 0, 39, '1409'),
	(243, 1, 0, -50553, 1411, 0, 0, 39, '1410'),
	(243, 1, 0, -50553, 1412, 0, 0, 39, '1411'),
	(243, 1, 0, -50553, 1413, 0, 0, 39, '1412'),
	(243, 1, 0, -50553, 1414, 0, 0, 39, '1413'),
	(243, 1, 0, -50553, 1415, 0, 0, 39, '1414'),
	(243, 1, 0, -50553, 1416, 0, 0, 39, '1415'),
	(243, 1, 0, -50553, 1417, 0, 0, 39, '1416'),
	(243, 1, 0, -50553, 1418, 0, 0, 39, '1417'),
	(243, 1, 0, -50553, 1419, 0, 0, 39, '1418'),
	(243, 1, 0, -50553, 1420, 0, 0, 39, '1419'),
	(243, 1, 0, -50553, 1421, 0, 0, 39, '1420'),
	(243, 1, 0, -50553, 1422, 0, 0, 39, '1421'),
	(243, 1, 0, -50553, 1423, 0, 0, 39, '1422'),
	(243, 1, 0, -50553, 1424, 0, 0, 39, '1423'),
	(243, 1, 0, -50553, 1425, 0, 0, 39, '1424'),
	(243, 1, 0, -50553, 1426, 0, 0, 39, '1425'),
	(243, 1, 0, -50553, 1427, 0, 0, 39, '1426'),
	(243, 1, 0, -50553, 1428, 0, 0, 39, '1427'),
	(243, 1, 0, -50553, 1429, 0, 0, 39, '1428'),
	(243, 1, 0, -50553, 1430, 0, 0, 39, '1429'),
	(243, 1, 0, -50553, 1431, 0, 0, 39, '1430'),
	(243, 1, 0, -50553, 1432, 0, 0, 39, '1431'),
	(243, 1, 0, -50553, 1433, 0, 0, 39, '1432'),
	(243, 1, 0, -50553, 1434, 0, 0, 39, '1433'),
	(243, 1, 0, -50553, 1435, 0, 0, 39, '1434'),
	(243, 1, 0, -50553, 1436, 0, 0, 39, '1435'),
	(243, 1, 0, -50553, 1437, 0, 0, 39, '1436'),
	(243, 1, 0, -50553, 1438, 0, 0, 39, '1437'),
	(243, 1, 0, -50553, 1439, 0, 0, 39, '1438'),
	(243, 1, 0, -50553, 1440, 0, 0, 39, '1439'),
	(243, 1, 0, -50553, 1441, 0, 0, 39, '1440'),
	(243, 1, 0, -50553, 1442, 0, 0, 39, '1441'),
	(243, 1, 0, -50553, 1443, 0, 0, 39, '1442'),
	(243, 1, 0, -50553, 1444, 0, 0, 39, '1443'),
	(243, 1, 0, -50553, 1445, 0, 0, 39, '1444'),
	(243, 1, 0, -50553, 1446, 0, 0, 39, '1445'),
	(243, 1, 0, -50553, 1447, 0, 0, 39, '1446'),
	(243, 1, 0, -50553, 1448, 0, 0, 39, '1447'),
	(243, 1, 0, -50553, 1449, 0, 0, 39, '1448'),
	(243, 1, 0, -50553, 1450, 0, 0, 39, '1449'),
	(243, 1, 0, -50553, 1451, 0, 0, 39, '1450'),
	(243, 1, 0, -50553, 1452, 0, 0, 39, '1451'),
	(243, 1, 0, -50553, 1453, 0, 0, 39, '1452'),
	(243, 1, 0, -50553, 1454, 0, 0, 39, '1453'),
	(243, 1, 0, -50553, 1455, 0, 0, 39, '1454'),
	(243, 1, 0, -50553, 1456, 0, 0, 39, '1455'),
	(243, 1, 0, -50553, 1457, 0, 0, 39, '1456'),
	(243, 1, 0, -50553, 1458, 0, 0, 39, '1457'),
	(243, 1, 0, -50553, 1459, 0, 0, 39, '1458'),
	(243, 1, 0, -50553, 1460, 0, 0, 39, '1459'),
	(243, 1, 0, -50553, 1461, 0, 0, 39, '1460'),
	(243, 1, 0, -50553, 1462, 0, 0, 39, '1461'),
	(243, 1, 0, -50553, 1463, 0, 0, 39, '1462'),
	(243, 1, 0, -50553, 1464, 0, 0, 39, '1463'),
	(243, 1, 0, -50553, 1465, 0, 0, 39, '1464'),
	(243, 1, 0, -50553, 1466, 0, 0, 39, '1465'),
	(243, 1, 0, -50553, 1467, 0, 0, 39, '1466'),
	(243, 1, 0, -50553, 1468, 0, 0, 39, '1467'),
	(243, 1, 0, -50553, 1469, 0, 0, 39, '1468'),
	(243, 1, 0, -50553, 1470, 0, 0, 39, '1469'),
	(243, 1, 0, -50553, 1471, 0, 0, 39, '1470'),
	(243, 1, 0, -50553, 1472, 0, 0, 39, '1471'),
	(243, 1, 0, -50553, 1473, 0, 0, 39, '1472'),
	(243, 1, 0, -50553, 1474, 0, 0, 39, '1473'),
	(243, 1, 0, -50553, 1475, 0, 0, 39, '1474'),
	(243, 1, 0, -50553, 1476, 0, 0, 39, '1475'),
	(243, 1, 0, -50553, 1477, 0, 0, 39, '1476'),
	(243, 1, 0, -50553, 1478, 0, 0, 39, '1477'),
	(243, 1, 0, -50553, 1479, 0, 0, 39, '1478'),
	(243, 1, 0, -50553, 1480, 0, 0, 39, '1479'),
	(243, 1, 0, -50553, 1481, 0, 0, 39, '1480'),
	(243, 1, 0, -50553, 1482, 0, 0, 39, '1481'),
	(243, 1, 0, -50553, 1483, 0, 0, 39, '1482'),
	(243, 1, 0, -50553, 1484, 0, 0, 39, '1483'),
	(243, 1, 0, -50553, 1485, 0, 0, 39, '1484'),
	(243, 1, 0, -50553, 1486, 0, 0, 39, '1485'),
	(243, 1, 0, -50553, 1487, 0, 0, 39, '1486'),
	(243, 1, 0, -50553, 1488, 0, 0, 39, '1487'),
	(243, 1, 0, -50553, 1489, 0, 0, 39, '1488'),
	(243, 1, 0, -50553, 1490, 0, 0, 39, '1489'),
	(243, 1, 0, -50553, 1491, 0, 0, 39, '1490'),
	(243, 1, 0, -50553, 1492, 0, 0, 39, '1491'),
	(243, 1, 0, -50553, 1493, 0, 0, 39, '1492'),
	(243, 1, 0, -50553, 1494, 0, 0, 39, '1493'),
	(243, 1, 0, -50553, 1495, 0, 0, 39, '1494'),
	(243, 1, 0, -50553, 1496, 0, 0, 39, '1495'),
	(243, 1, 0, -50553, 1497, 0, 0, 39, '1496'),
	(243, 1, 0, -50553, 1498, 0, 0, 39, '1497'),
	(243, 1, 0, -50553, 1499, 0, 0, 39, '1498'),
	(243, 1, 0, -50553, 1500, 0, 0, 39, '1499'),
	(243, 1, 0, -50553, 1501, 0, 0, 39, '1500'),
	(243, 1, 0, -50553, 1502, 0, 0, 39, '1501'),
	(243, 1, 0, -50553, 1503, 0, 0, 39, '1502'),
	(243, 1, 0, -50553, 1504, 0, 0, 39, '1503'),
	(243, 1, 0, -50553, 1505, 0, 0, 39, '1504'),
	(243, 1, 0, -50553, 1506, 0, 0, 39, '1505'),
	(243, 1, 0, -50553, 1507, 0, 0, 39, '1506'),
	(243, 1, 0, -50553, 1508, 0, 0, 39, '1507'),
	(243, 1, 0, -50553, 1509, 0, 0, 39, '1508'),
	(243, 1, 0, -50553, 1510, 0, 0, 39, '1509'),
	(243, 1, 0, -50553, 1511, 0, 0, 39, '1510'),
	(243, 1, 0, -50553, 1512, 0, 0, 39, '1511'),
	(243, 1, 0, -50553, 1513, 0, 0, 39, '1512'),
	(243, 1, 0, -50553, 1514, 0, 0, 39, '1513'),
	(243, 1, 0, -50553, 1515, 0, 0, 39, '1514'),
	(243, 1, 0, -50553, 1516, 0, 0, 39, '1515'),
	(243, 1, 0, -50553, 1517, 0, 0, 39, '1516'),
	(243, 1, 0, -50553, 1518, 0, 0, 39, '1517'),
	(243, 1, 0, -50553, 1519, 0, 0, 39, '1518'),
	(243, 1, 0, -50553, 1520, 0, 0, 39, '1519'),
	(243, 1, 0, -50553, 1521, 0, 0, 39, '1520'),
	(243, 1, 0, -50553, 1522, 0, 0, 39, '1521'),
	(243, 1, 0, -50553, 1523, 0, 0, 39, '1522'),
	(243, 1, 0, -50553, 1524, 0, 0, 39, '1523'),
	(243, 1, 0, -50553, 1525, 0, 0, 39, '1524'),
	(243, 1, 0, -50553, 1526, 0, 0, 39, '1525'),
	(243, 1, 0, -50553, 1527, 0, 0, 39, '1526'),
	(243, 1, 0, -50553, 1528, 0, 0, 39, '1527'),
	(243, 1, 0, -50553, 1529, 0, 0, 39, '1528'),
	(243, 1, 0, -50553, 1530, 0, 0, 39, '1529'),
	(243, 1, 0, -50553, 1531, 0, 0, 39, '1530'),
	(243, 1, 0, -50553, 1532, 0, 0, 39, '1531'),
	(243, 1, 0, -50553, 1533, 0, 0, 39, '1532'),
	(243, 1, 0, -50553, 1534, 0, 0, 39, '1533'),
	(243, 1, 0, -50553, 1535, 0, 0, 39, '1534'),
	(243, 1, 0, -50553, 1536, 0, 0, 39, '1535'),
	(243, 1, 0, -50553, 1537, 0, 0, 39, '1536'),
	(243, 1, 0, -50553, 1538, 0, 0, 39, '1537'),
	(243, 1, 0, -50553, 1539, 0, 0, 39, '1538'),
	(243, 1, 0, -50553, 1540, 0, 0, 39, '1539'),
	(243, 1, 0, -50553, 1541, 0, 0, 39, '1540'),
	(243, 1, 0, -50553, 1542, 0, 0, 39, '1541'),
	(243, 1, 0, -50553, 1543, 0, 0, 39, '1542'),
	(243, 1, 0, -50553, 1544, 0, 0, 39, '1543'),
	(243, 1, 0, -50553, 1545, 0, 0, 39, '1544'),
	(243, 1, 0, -50553, 1546, 0, 0, 39, '1545'),
	(243, 1, 0, -50553, 1547, 0, 0, 39, '1546'),
	(243, 1, 0, -50553, 1548, 0, 0, 39, '1547'),
	(243, 1, 0, -50553, 1549, 0, 0, 39, '1548'),
	(243, 1, 0, -50553, 1550, 0, 0, 39, '1549'),
	(243, 1, 0, -50553, 1551, 0, 0, 39, '1550'),
	(243, 1, 0, -50553, 1552, 0, 0, 39, '1551'),
	(243, 1, 0, -50553, 1553, 0, 0, 39, '1552'),
	(243, 1, 0, -50553, 1554, 0, 0, 39, '1553'),
	(243, 1, 0, -50553, 1555, 0, 0, 39, '1554'),
	(243, 1, 0, -50553, 1556, 0, 0, 39, '1555'),
	(243, 1, 0, -50553, 1557, 0, 0, 39, '1556'),
	(243, 1, 0, -50553, 1558, 0, 0, 39, '1557'),
	(243, 1, 0, -50553, 1559, 0, 0, 39, '1558'),
	(243, 1, 0, -50553, 1560, 0, 0, 39, '1559'),
	(243, 1, 0, -50553, 1561, 0, 0, 39, '1560'),
	(243, 1, 0, -50553, 1562, 0, 0, 39, '1561'),
	(243, 1, 0, -50553, 1563, 0, 0, 39, '1562'),
	(243, 1, 0, -50553, 1564, 0, 0, 39, '1563'),
	(243, 1, 0, -50553, 1565, 0, 0, 39, '1564'),
	(243, 1, 0, -50553, 1566, 0, 0, 39, '1565'),
	(243, 1, 0, -50553, 1567, 0, 0, 39, '1566'),
	(243, 1, 0, -50553, 1568, 0, 0, 39, '1567'),
	(243, 1, 0, -50553, 1569, 0, 0, 39, '1568'),
	(243, 1, 0, -50553, 1570, 0, 0, 39, '1569'),
	(243, 1, 0, -50553, 1571, 0, 0, 39, '1570'),
	(243, 1, 0, -50553, 1572, 0, 0, 39, '1571'),
	(243, 1, 0, -50553, 1573, 0, 0, 39, '1572'),
	(243, 1, 0, -50553, 1574, 0, 0, 39, '1573'),
	(243, 1, 0, -50553, 1575, 0, 0, 39, '1574'),
	(243, 1, 0, -50553, 1576, 0, 0, 39, '1575'),
	(243, 1, 0, -50553, 1577, 0, 0, 39, '1576'),
	(243, 1, 0, -50553, 1578, 0, 0, 39, '1577'),
	(243, 1, 0, -50553, 1579, 0, 0, 39, '1578'),
	(243, 1, 0, -50553, 1580, 0, 0, 39, '1579'),
	(243, 1, 0, -50553, 1581, 0, 0, 39, '1580'),
	(243, 1, 0, -50553, 1582, 0, 0, 39, '1581'),
	(243, 1, 0, -50553, 1583, 0, 0, 39, '1582'),
	(243, 1, 0, -50553, 1584, 0, 0, 39, '1583'),
	(243, 1, 0, -50553, 1585, 0, 0, 39, '1584'),
	(243, 1, 0, -50553, 1586, 0, 0, 39, '1585'),
	(243, 1, 0, -50553, 1587, 0, 0, 39, '1586'),
	(243, 1, 0, -50553, 1588, 0, 0, 39, '1587'),
	(243, 1, 0, -50553, 1589, 0, 0, 39, '1588'),
	(243, 1, 0, -50553, 1590, 0, 0, 39, '1589'),
	(243, 1, 0, -50553, 1591, 0, 0, 39, '1590'),
	(243, 1, 0, -50553, 1592, 0, 0, 39, '1591'),
	(243, 1, 0, -50553, 1593, 0, 0, 39, '1592'),
	(243, 1, 0, -50553, 1594, 0, 0, 39, '1593'),
	(243, 1, 0, -50553, 1595, 0, 0, 39, '1594'),
	(243, 1, 0, -50553, 1596, 0, 0, 39, '1595'),
	(243, 1, 0, -50553, 1597, 0, 0, 39, '1596'),
	(243, 1, 0, -50553, 1598, 0, 0, 39, '1597'),
	(243, 1, 0, -50553, 1599, 0, 0, 39, '1598'),
	(243, 1, 0, -50553, 1600, 0, 0, 39, '1599'),
	(243, 1, 0, -50553, 1601, 0, 0, 39, '1600'),
	(243, 1, 0, -50553, 1602, 0, 0, 39, '1601'),
	(243, 1, 0, -50553, 1603, 0, 0, 39, '1602'),
	(243, 1, 0, -50553, 1604, 0, 0, 39, '1603'),
	(243, 1, 0, -50553, 1605, 0, 0, 39, '1604'),
	(243, 1, 0, -50553, 1606, 0, 0, 39, '1605'),
	(243, 1, 0, -50553, 1607, 0, 0, 39, '1606'),
	(243, 1, 0, -50553, 1608, 0, 0, 39, '1607'),
	(243, 1, 0, -50553, 1609, 0, 0, 39, '1608'),
	(243, 1, 0, -50553, 1610, 0, 0, 39, '1609'),
	(243, 1, 0, -50553, 1611, 0, 0, 39, '1610'),
	(243, 1, 0, -50553, 1612, 0, 0, 39, '1611'),
	(243, 1, 0, -50553, 1613, 0, 0, 39, '1612'),
	(243, 1, 0, -50553, 1614, 0, 0, 39, '1613'),
	(243, 1, 0, -50553, 1615, 0, 0, 39, '1614'),
	(243, 1, 0, -50553, 1616, 0, 0, 39, '1615'),
	(243, 1, 0, -50553, 1617, 0, 0, 39, '1616'),
	(243, 1, 0, -50553, 1618, 0, 0, 39, '1617'),
	(243, 1, 0, -50553, 1619, 0, 0, 39, '1618'),
	(243, 1, 0, -50553, 1620, 0, 0, 39, '1619'),
	(243, 1, 0, -50553, 1621, 0, 0, 39, '1620'),
	(243, 1, 0, -50553, 1622, 0, 0, 39, '1621'),
	(243, 1, 0, -50553, 1623, 0, 0, 39, '1622'),
	(243, 1, 0, -50553, 1624, 0, 0, 39, '1623'),
	(243, 1, 0, -50553, 1625, 0, 0, 39, '1624'),
	(243, 1, 0, -50553, 1626, 0, 0, 39, '1625'),
	(243, 1, 0, -50553, 1627, 0, 0, 39, '1626'),
	(243, 1, 0, -50553, 1628, 0, 0, 39, '1627'),
	(243, 1, 0, -50553, 1629, 0, 0, 39, '1628'),
	(243, 1, 0, -50553, 1630, 0, 0, 39, '1629'),
	(243, 1, 0, -50553, 1631, 0, 0, 39, '1630'),
	(243, 1, 0, -50553, 1632, 0, 0, 39, '1631'),
	(243, 1, 0, -50553, 1633, 0, 0, 39, '1632'),
	(243, 1, 0, -50553, 1634, 0, 0, 39, '1633'),
	(243, 1, 0, -50553, 1635, 0, 0, 39, '1634'),
	(243, 1, 0, -50553, 1636, 0, 0, 39, '1635'),
	(243, 1, 0, -50553, 1637, 0, 0, 39, '1636'),
	(243, 1, 0, -50553, 1638, 0, 0, 39, '1637'),
	(243, 1, 0, -50553, 1639, 0, 0, 39, '1638'),
	(243, 1, 0, -50553, 1640, 0, 0, 39, '1639'),
	(243, 1, 0, -50553, 1641, 0, 0, 39, '1640'),
	(243, 1, 0, -50553, 1642, 0, 0, 39, '1641'),
	(243, 1, 0, -50553, 1643, 0, 0, 39, '1642'),
	(243, 1, 0, -50553, 1644, 0, 0, 39, '1643'),
	(243, 1, 0, -50553, 1645, 0, 0, 39, '1644'),
	(243, 1, 0, -50553, 1646, 0, 0, 39, '1645'),
	(243, 1, 0, -50553, 1647, 0, 0, 39, '1646'),
	(243, 1, 0, -50553, 1648, 0, 0, 39, '1647'),
	(243, 1, 0, -50553, 1649, 0, 0, 39, '1648'),
	(243, 1, 0, -50553, 1650, 0, 0, 39, '1649'),
	(243, 1, 0, -50553, 1651, 0, 0, 39, '1650'),
	(243, 1, 0, -50553, 1652, 0, 0, 39, '1651'),
	(243, 1, 0, -50553, 1653, 0, 0, 39, '1652'),
	(243, 1, 0, -50553, 1654, 0, 0, 39, '1653'),
	(243, 1, 0, -50553, 1655, 0, 0, 39, '1654'),
	(243, 1, 0, -50553, 1656, 0, 0, 39, '1655'),
	(243, 1, 0, -50553, 1657, 0, 0, 39, '1656'),
	(243, 1, 0, -50553, 1658, 0, 0, 39, '1657'),
	(243, 1, 0, -50553, 1659, 0, 0, 39, '1658'),
	(243, 1, 0, -50553, 1660, 0, 0, 39, '1659'),
	(243, 1, 0, -50553, 1661, 0, 0, 39, '1660'),
	(243, 1, 0, -50553, 1662, 0, 0, 39, '1661'),
	(243, 1, 0, -50553, 1663, 0, 0, 39, '1662'),
	(243, 1, 0, -50553, 1664, 0, 0, 39, '1663'),
	(243, 1, 0, -50553, 1665, 0, 0, 39, '1664'),
	(243, 1, 0, -50553, 1666, 0, 0, 39, '1665'),
	(243, 1, 0, -50553, 1667, 0, 0, 39, '1666'),
	(243, 1, 0, -50553, 1668, 0, 0, 39, '1667'),
	(243, 1, 0, -50553, 1669, 0, 0, 39, '1668'),
	(243, 1, 0, -50553, 1670, 0, 0, 39, '1669'),
	(243, 1, 0, -50553, 1671, 0, 0, 39, '1670'),
	(243, 1, 0, -50553, 1672, 0, 0, 39, '1671'),
	(243, 1, 0, -50553, 1673, 0, 0, 39, '1672'),
	(243, 1, 0, -50553, 1674, 0, 0, 39, '1673'),
	(243, 1, 0, -50553, 1675, 0, 0, 39, '1674'),
	(243, 1, 0, -50553, 1676, 0, 0, 39, '1675'),
	(243, 1, 0, -50553, 1677, 0, 0, 39, '1676'),
	(243, 1, 0, -50553, 1678, 0, 0, 39, '1677'),
	(243, 1, 0, -50553, 1679, 0, 0, 39, '1678'),
	(243, 1, 0, -50553, 1680, 0, 0, 39, '1679'),
	(243, 1, 0, -50553, 1681, 0, 0, 39, '1680'),
	(243, 1, 0, -50553, 1682, 0, 0, 39, '1681'),
	(243, 1, 0, -50553, 1683, 0, 0, 39, '1682'),
	(243, 1, 0, -50553, 1684, 0, 0, 39, '1683'),
	(243, 1, 0, -50553, 1685, 0, 0, 39, '1684'),
	(243, 1, 0, -50553, 1686, 0, 0, 39, '1685'),
	(243, 1, 0, -50553, 1687, 0, 0, 39, '1686'),
	(243, 1, 0, -50553, 1688, 0, 0, 39, '1687'),
	(243, 1, 0, -50553, 1689, 0, 0, 39, '1688'),
	(243, 1, 0, -50553, 1690, 0, 0, 39, '1689'),
	(243, 1, 0, -50553, 1691, 0, 0, 39, '1690'),
	(243, 1, 0, -50553, 1692, 0, 0, 39, '1691'),
	(243, 1, 0, -50553, 1693, 0, 0, 39, '1692'),
	(243, 1, 0, -50553, 1694, 0, 0, 39, '1693'),
	(243, 1, 0, -50553, 1695, 0, 0, 39, '1694'),
	(243, 1, 0, -50553, 1696, 0, 0, 39, '1695'),
	(243, 1, 0, -50553, 1697, 0, 0, 39, '1696'),
	(243, 1, 0, -50553, 1698, 0, 0, 39, '1697'),
	(243, 1, 0, -50553, 1699, 0, 0, 39, '1698'),
	(243, 1, 0, -50553, 1700, 0, 0, 39, '1699'),
	(243, 1, 0, -50553, 1701, 0, 0, 39, '1700'),
	(243, 1, 0, -50553, 1702, 0, 0, 39, '1701'),
	(243, 1, 0, -50553, 1703, 0, 0, 39, '1702'),
	(243, 1, 0, -50553, 1704, 0, 0, 39, '1703'),
	(243, 1, 0, -50553, 1705, 0, 0, 39, '1704'),
	(243, 1, 0, -50553, 1706, 0, 0, 39, '1705'),
	(243, 1, 0, -50553, 1707, 0, 0, 39, '1706'),
	(243, 1, 0, -50553, 1708, 0, 0, 39, '1707'),
	(243, 1, 0, -50553, 1709, 0, 0, 39, '1708'),
	(243, 1, 0, -50553, 1710, 0, 0, 39, '1709'),
	(243, 1, 0, -50553, 1711, 0, 0, 39, '1710'),
	(243, 1, 0, -50553, 1712, 0, 0, 39, '1711'),
	(243, 1, 0, -50553, 1713, 0, 0, 39, '1712'),
	(243, 1, 0, -50553, 1714, 0, 0, 39, '1713'),
	(243, 1, 0, -50553, 1715, 0, 0, 39, '1714'),
	(243, 1, 0, -50553, 1716, 0, 0, 39, '1715'),
	(243, 1, 0, -50553, 1717, 0, 0, 39, '1716'),
	(243, 1, 0, -50553, 1718, 0, 0, 39, '1717'),
	(243, 1, 0, -50553, 1719, 0, 0, 39, '1718'),
	(243, 1, 0, -50553, 1720, 0, 0, 39, '1719'),
	(243, 1, 0, -50553, 1721, 0, 0, 39, '1720'),
	(243, 1, 0, -50553, 1722, 0, 0, 39, '1721'),
	(243, 1, 0, -50553, 1723, 0, 0, 39, '1722'),
	(243, 1, 0, -50553, 1724, 0, 0, 39, '1723'),
	(243, 1, 0, -50553, 1725, 0, 0, 39, '1724'),
	(243, 1, 0, -50553, 1726, 0, 0, 39, '1725'),
	(243, 1, 0, -50553, 1727, 0, 0, 39, '1726'),
	(243, 1, 0, -50553, 1728, 0, 0, 39, '1727'),
	(243, 1, 0, -50553, 1729, 0, 0, 39, '1728'),
	(243, 1, 0, -50553, 1730, 0, 0, 39, '1729'),
	(243, 1, 0, -50553, 1731, 0, 0, 39, '1730'),
	(243, 1, 0, -50553, 1732, 0, 0, 39, '1731'),
	(243, 1, 0, -50553, 1733, 0, 0, 39, '1732'),
	(243, 1, 0, -50553, 1734, 0, 0, 39, '1733'),
	(243, 1, 0, -50553, 1735, 0, 0, 39, '1734'),
	(243, 1, 0, -50553, 1736, 0, 0, 39, '1735'),
	(243, 1, 0, -50553, 1737, 0, 0, 39, '1736'),
	(243, 1, 0, -50553, 1738, 0, 0, 39, '1737'),
	(243, 1, 0, -50553, 1739, 0, 0, 39, '1738'),
	(243, 1, 0, -50553, 1740, 0, 0, 39, '1739'),
	(243, 1, 0, -50553, 1741, 0, 0, 39, '1740'),
	(243, 1, 0, -50553, 1742, 0, 0, 39, '1741'),
	(243, 1, 0, -50553, 1743, 0, 0, 39, '1742'),
	(243, 1, 0, -50553, 1744, 0, 0, 39, '1743'),
	(243, 1, 0, -50553, 1745, 0, 0, 39, '1744'),
	(243, 1, 0, -50553, 1746, 0, 0, 39, '1745'),
	(243, 1, 0, -50553, 1747, 0, 0, 39, '1746'),
	(243, 1, 0, -50553, 1748, 0, 0, 39, '1747'),
	(243, 1, 0, -50553, 1749, 0, 0, 39, '1748'),
	(243, 1, 0, -50553, 1750, 0, 0, 39, '1749'),
	(243, 1, 0, -50553, 1751, 0, 0, 39, '1750'),
	(243, 1, 0, -50553, 1752, 0, 0, 39, '1751'),
	(243, 1, 0, -50553, 1753, 0, 0, 39, '1752'),
	(243, 1, 0, -50553, 1754, 0, 0, 39, '1753'),
	(243, 1, 0, -50553, 1755, 0, 0, 39, '1754'),
	(243, 1, 0, -50553, 1756, 0, 0, 39, '1755'),
	(243, 1, 0, -50553, 1757, 0, 0, 39, '1756'),
	(243, 1, 0, -50553, 1758, 0, 0, 39, '1757'),
	(243, 1, 0, -50553, 1759, 0, 0, 39, '1758'),
	(243, 1, 0, -50553, 1760, 0, 0, 39, '1759'),
	(243, 1, 0, -50553, 1761, 0, 0, 39, '1760'),
	(243, 1, 0, -50553, 1762, 0, 0, 39, '1761'),
	(243, 1, 0, -50553, 1763, 0, 0, 39, '1762'),
	(243, 1, 0, -50553, 1764, 0, 0, 39, '1763'),
	(243, 1, 0, -50553, 1765, 0, 0, 39, '1764'),
	(243, 1, 0, -50553, 1766, 0, 0, 39, '1765'),
	(243, 1, 0, -50553, 1767, 0, 0, 39, '1766'),
	(243, 1, 0, -50553, 1768, 0, 0, 39, '1767'),
	(243, 1, 0, -50553, 1769, 0, 0, 39, '1768'),
	(243, 1, 0, -50553, 1770, 0, 0, 39, '1769'),
	(243, 1, 0, -50553, 1771, 0, 0, 39, '1770'),
	(243, 1, 0, -50553, 1772, 0, 0, 39, '1771'),
	(243, 1, 0, -50553, 1773, 0, 0, 39, '1772'),
	(243, 1, 0, -50553, 1774, 0, 0, 39, '1773'),
	(243, 1, 0, -50553, 1775, 0, 0, 39, '1774'),
	(243, 1, 0, -50553, 1776, 0, 0, 39, '1775'),
	(243, 1, 0, -50553, 1777, 0, 0, 39, '1776'),
	(243, 1, 0, -50553, 1778, 0, 0, 39, '1777'),
	(243, 1, 0, -50553, 1779, 0, 0, 39, '1778'),
	(243, 1, 0, -50553, 1780, 0, 0, 39, '1779'),
	(243, 1, 0, -50553, 1781, 0, 0, 39, '1780'),
	(243, 1, 0, -50553, 1782, 0, 0, 39, '1781'),
	(243, 1, 0, -50553, 1783, 0, 0, 39, '1782'),
	(243, 1, 0, -50553, 1784, 0, 0, 39, '1783'),
	(243, 1, 0, -50553, 1785, 0, 0, 39, '1784'),
	(243, 1, 0, -50553, 1786, 0, 0, 39, '1785'),
	(243, 1, 0, -50553, 1787, 0, 0, 39, '1786'),
	(243, 1, 0, -50553, 1788, 0, 0, 39, '1787'),
	(243, 1, 0, -50553, 1789, 0, 0, 39, '1788'),
	(243, 1, 0, -50553, 1790, 0, 0, 39, '1789'),
	(243, 1, 0, -50553, 1791, 0, 0, 39, '1790'),
	(243, 1, 0, -50553, 1792, 0, 0, 39, '1791'),
	(243, 1, 0, -50553, 1793, 0, 0, 39, '1792'),
	(243, 1, 0, -50553, 1794, 0, 0, 39, '1793'),
	(243, 1, 0, -50553, 1795, 0, 0, 39, '1794'),
	(243, 1, 0, -50553, 1796, 0, 0, 39, '1795'),
	(243, 1, 0, -50553, 1797, 0, 0, 39, '1796'),
	(243, 1, 0, -50553, 1798, 0, 0, 39, '1797'),
	(243, 1, 0, -50553, 1799, 0, 0, 39, '1798'),
	(243, 1, 0, -50553, 1800, 0, 0, 39, '1799'),
	(243, 1, 0, -50553, 1801, 0, 0, 39, '1800'),
	(243, 1, 0, -50553, 1802, 0, 0, 39, '1801'),
	(243, 1, 0, -50553, 1803, 0, 0, 39, '1802'),
	(243, 1, 0, -50553, 1804, 0, 0, 39, '1803'),
	(243, 1, 0, -50553, 1805, 0, 0, 39, '1804'),
	(243, 1, 0, -50553, 1806, 0, 0, 39, '1805'),
	(243, 1, 0, -50553, 1807, 0, 0, 39, '1806'),
	(243, 1, 0, -50553, 1808, 0, 0, 39, '1807'),
	(243, 1, 0, -50553, 1809, 0, 0, 39, '1808'),
	(243, 1, 0, -50553, 1810, 0, 0, 39, '1809'),
	(243, 1, 0, -50553, 1811, 0, 0, 39, '1810'),
	(243, 1, 0, -50553, 1812, 0, 0, 39, '1811'),
	(243, 1, 0, -50553, 1813, 0, 0, 39, '1812'),
	(243, 1, 0, -50553, 1814, 0, 0, 39, '1813'),
	(243, 1, 0, -50553, 1815, 0, 0, 39, '1814'),
	(243, 1, 0, -50553, 1816, 0, 0, 39, '1815'),
	(243, 1, 0, -50553, 1817, 0, 0, 39, '1816'),
	(243, 1, 0, -50553, 1818, 0, 0, 39, '1817'),
	(243, 1, 0, -50553, 1819, 0, 0, 39, '1818'),
	(243, 1, 0, -50553, 1820, 0, 0, 39, '1819'),
	(243, 1, 0, -50553, 1821, 0, 0, 39, '1820'),
	(243, 1, 0, -50553, 1822, 0, 0, 39, '1821'),
	(243, 1, 0, -50553, 1823, 0, 0, 39, '1822'),
	(243, 1, 0, -50553, 1824, 0, 0, 39, '1823'),
	(243, 1, 0, -50553, 1825, 0, 0, 39, '1824'),
	(243, 1, 0, -50553, 1826, 0, 0, 39, '1825'),
	(243, 1, 0, -50553, 1827, 0, 0, 39, '1826'),
	(243, 1, 0, -50553, 1828, 0, 0, 39, '1827'),
	(243, 1, 0, -50553, 1829, 0, 0, 39, '1828'),
	(243, 1, 0, -50553, 1830, 0, 0, 39, '1829'),
	(243, 1, 0, -50553, 1831, 0, 0, 39, '1830'),
	(243, 1, 0, -50553, 1832, 0, 0, 39, '1831'),
	(243, 1, 0, -50553, 1833, 0, 0, 39, '1832'),
	(243, 1, 0, -50553, 1834, 0, 0, 39, '1833'),
	(243, 1, 0, -50553, 1835, 0, 0, 39, '1834'),
	(243, 1, 0, -50553, 1836, 0, 0, 39, '1835'),
	(243, 1, 0, -50553, 1837, 0, 0, 39, '1836'),
	(243, 1, 0, -50553, 1838, 0, 0, 39, '1837'),
	(243, 1, 0, -50553, 1839, 0, 0, 39, '1838'),
	(243, 1, 0, -50553, 1840, 0, 0, 39, '1839'),
	(243, 1, 0, -50553, 1841, 0, 0, 39, '1840'),
	(243, 1, 0, -50553, 1842, 0, 0, 39, '1841'),
	(243, 1, 0, -50553, 1843, 0, 0, 39, '1842'),
	(243, 1, 0, -50553, 1844, 0, 0, 39, '1843'),
	(243, 1, 0, -50553, 1845, 0, 0, 39, '1844'),
	(243, 1, 0, -50553, 1846, 0, 0, 39, '1845'),
	(243, 1, 0, -50553, 1847, 0, 0, 39, '1846'),
	(243, 1, 0, -50553, 1848, 0, 0, 39, '1847'),
	(243, 1, 0, -50553, 1849, 0, 0, 39, '1848'),
	(243, 1, 0, -50553, 1850, 0, 0, 39, '1849'),
	(243, 1, 0, -50553, 1851, 0, 0, 39, '1850'),
	(243, 1, 0, -50553, 1852, 0, 0, 39, '1851'),
	(243, 1, 0, -50553, 1853, 0, 0, 39, '1852'),
	(243, 1, 0, -50553, 1854, 0, 0, 39, '1853'),
	(243, 1, 0, -50553, 1855, 0, 0, 39, '1854'),
	(243, 1, 0, -50553, 1856, 0, 0, 39, '1855'),
	(243, 1, 0, -50553, 1857, 0, 0, 39, '1856'),
	(243, 1, 0, -50553, 1858, 0, 0, 39, '1857'),
	(243, 1, 0, -50553, 1859, 0, 0, 39, '1858'),
	(243, 1, 0, -50553, 1860, 0, 0, 39, '1859'),
	(243, 1, 0, -50553, 1861, 0, 0, 39, '1860'),
	(243, 1, 0, -50553, 1862, 0, 0, 39, '1861'),
	(243, 1, 0, -50553, 1863, 0, 0, 39, '1862'),
	(243, 1, 0, -50553, 1864, 0, 0, 39, '1863'),
	(243, 1, 0, -50553, 1865, 0, 0, 39, '1864'),
	(243, 1, 0, -50553, 1866, 0, 0, 39, '1865'),
	(243, 1, 0, -50553, 1867, 0, 0, 39, '1866'),
	(243, 1, 0, -50553, 1868, 0, 0, 39, '1867'),
	(243, 1, 0, -50553, 1869, 0, 0, 39, '1868'),
	(243, 1, 0, -50553, 1870, 0, 0, 39, '1869'),
	(243, 1, 0, -50553, 1871, 0, 0, 39, '1870'),
	(243, 1, 0, -50553, 1872, 0, 0, 39, '1871'),
	(243, 1, 0, -50553, 1873, 0, 0, 39, '1872'),
	(243, 1, 0, -50553, 1874, 0, 0, 39, '1873'),
	(243, 1, 0, -50553, 1875, 0, 0, 39, '1874'),
	(243, 1, 0, -50553, 1876, 0, 0, 39, '1875'),
	(243, 1, 0, -50553, 1877, 0, 0, 39, '1876'),
	(243, 1, 0, -50553, 1878, 0, 0, 39, '1877'),
	(243, 1, 0, -50553, 1879, 0, 0, 39, '1878'),
	(243, 1, 0, -50553, 1880, 0, 0, 39, '1879'),
	(243, 1, 0, -50553, 1881, 0, 0, 39, '1880'),
	(243, 1, 0, -50553, 1882, 0, 0, 39, '1881'),
	(243, 1, 0, -50553, 1883, 0, 0, 39, '1882'),
	(243, 1, 0, -50553, 1884, 0, 0, 39, '1883'),
	(243, 1, 0, -50553, 1885, 0, 0, 39, '1884'),
	(243, 1, 0, -50553, 1886, 0, 0, 39, '1885'),
	(243, 1, 0, -50553, 1887, 0, 0, 39, '1886'),
	(243, 1, 0, -50553, 1888, 0, 0, 39, '1887'),
	(243, 1, 0, -50553, 1889, 0, 0, 39, '1888'),
	(243, 1, 0, -50553, 1890, 0, 0, 39, '1889'),
	(243, 1, 0, -50553, 1891, 0, 0, 39, '1890'),
	(243, 1, 0, -50553, 1892, 0, 0, 39, '1891'),
	(243, 1, 0, -50553, 1893, 0, 0, 39, '1892'),
	(243, 1, 0, -50553, 1894, 0, 0, 39, '1893'),
	(243, 1, 0, -50553, 1895, 0, 0, 39, '1894'),
	(243, 1, 0, -50553, 1896, 0, 0, 39, '1895'),
	(243, 1, 0, -50553, 1897, 0, 0, 39, '1896'),
	(243, 1, 0, -50553, 1898, 0, 0, 39, '1897'),
	(243, 1, 0, -50553, 1899, 0, 0, 39, '1898'),
	(243, 1, 0, -50553, 1900, 0, 0, 39, '1899'),
	(243, 1, 0, -50553, 1901, 0, 0, 39, '1900'),
	(243, 1, 0, -50553, 1902, 0, 0, 39, '1901'),
	(243, 1, 0, -50553, 1903, 0, 0, 39, '1902'),
	(243, 1, 0, -50553, 1904, 0, 0, 39, '1903'),
	(243, 1, 0, -50553, 1905, 0, 0, 39, '1904'),
	(243, 1, 0, -50553, 1906, 0, 0, 39, '1905'),
	(243, 1, 0, -50553, 1907, 0, 0, 39, '1906'),
	(243, 1, 0, -50553, 1908, 0, 0, 39, '1907'),
	(243, 1, 0, -50553, 1909, 0, 0, 39, '1908'),
	(243, 1, 0, -50553, 1910, 0, 0, 39, '1909'),
	(243, 1, 0, -50553, 1911, 0, 0, 39, '1910'),
	(243, 1, 0, -50553, 1912, 0, 0, 39, '1911'),
	(243, 1, 0, -50553, 1913, 0, 0, 39, '1912'),
	(243, 1, 0, -50553, 1914, 0, 0, 39, '1913'),
	(243, 1, 0, -50553, 1915, 0, 0, 39, '1914'),
	(243, 1, 0, -50553, 1916, 0, 0, 39, '1915'),
	(243, 1, 0, -50553, 1917, 0, 0, 39, '1916'),
	(243, 1, 0, -50553, 1918, 0, 0, 39, '1917'),
	(243, 1, 0, -50553, 1919, 0, 0, 39, '1918'),
	(243, 1, 0, -50553, 1920, 0, 0, 39, '1919'),
	(243, 1, 0, -50553, 1921, 0, 0, 39, '1920'),
	(243, 1, 0, -50553, 1922, 0, 0, 39, '1921'),
	(243, 1, 0, -50553, 1923, 0, 0, 39, '1922'),
	(243, 1, 0, -50553, 1924, 0, 0, 39, '1923'),
	(243, 1, 0, -50553, 1925, 0, 0, 39, '1924'),
	(243, 1, 0, -50553, 1926, 0, 0, 39, '1925'),
	(243, 1, 0, -50553, 1927, 0, 0, 39, '1926'),
	(243, 1, 0, -50553, 1928, 0, 0, 39, '1927'),
	(243, 1, 0, -50553, 1929, 0, 0, 39, '1928'),
	(243, 1, 0, -50553, 1930, 0, 0, 39, '1929'),
	(243, 1, 0, -50553, 1931, 0, 0, 39, '1930'),
	(243, 1, 0, -50553, 1932, 0, 0, 39, '1931'),
	(243, 1, 0, -50553, 1933, 0, 0, 39, '1932'),
	(243, 1, 0, -50553, 1934, 0, 0, 39, '1933'),
	(243, 1, 0, -50553, 1935, 0, 0, 39, '1934'),
	(243, 1, 0, -50553, 1936, 0, 0, 39, '1935'),
	(243, 1, 0, -50553, 1937, 0, 0, 39, '1936'),
	(243, 1, 0, -50553, 1938, 0, 0, 39, '1937'),
	(243, 1, 0, -50553, 1939, 0, 0, 39, '1938'),
	(243, 1, 0, -50553, 1940, 0, 0, 39, '1939'),
	(243, 1, 0, -50553, 1941, 0, 0, 39, '1940'),
	(243, 1, 0, -50553, 1942, 0, 0, 39, '1941'),
	(243, 1, 0, -50553, 1943, 0, 0, 39, '1942'),
	(243, 1, 0, -50553, 1944, 0, 0, 39, '1943'),
	(243, 1, 0, -50553, 1945, 0, 0, 39, '1944'),
	(243, 1, 0, -50553, 1946, 0, 0, 39, '1945'),
	(243, 1, 0, -50553, 1947, 0, 0, 39, '1946'),
	(243, 1, 0, -50553, 1948, 0, 0, 39, '1947'),
	(243, 1, 0, -50553, 1949, 0, 0, 39, '1948'),
	(243, 1, 0, -50553, 1950, 0, 0, 39, '1949'),
	(243, 1, 0, -50553, 1951, 0, 0, 39, '1950'),
	(243, 1, 0, -50553, 1952, 0, 0, 39, '1951'),
	(243, 1, 0, -50553, 1953, 0, 0, 39, '1952'),
	(243, 1, 0, -50553, 1954, 0, 0, 39, '1953'),
	(243, 1, 0, -50553, 1955, 0, 0, 39, '1954'),
	(243, 1, 0, -50553, 1956, 0, 0, 39, '1955'),
	(243, 1, 0, -50553, 1957, 0, 0, 39, '1956'),
	(243, 1, 0, -50553, 1958, 0, 0, 39, '1957'),
	(243, 1, 0, -50553, 1959, 0, 0, 39, '1958'),
	(243, 1, 0, -50553, 1960, 0, 0, 39, '1959'),
	(243, 1, 0, -50553, 1961, 0, 0, 39, '1960'),
	(243, 1, 0, -50553, 1962, 0, 0, 39, '1961'),
	(243, 1, 0, -50553, 1963, 0, 0, 39, '1962'),
	(243, 1, 0, -50553, 1964, 0, 0, 39, '1963'),
	(243, 1, 0, -50553, 1965, 0, 0, 39, '1964'),
	(243, 1, 0, -50553, 1966, 0, 0, 39, '1965'),
	(243, 1, 0, -50553, 1967, 0, 0, 39, '1966'),
	(243, 1, 0, -50553, 1968, 0, 0, 39, '1967'),
	(243, 1, 0, -50553, 1969, 0, 0, 39, '1968'),
	(243, 1, 0, -50553, 1970, 0, 0, 39, '1969'),
	(243, 1, 0, -50553, 1971, 0, 0, 39, '1970'),
	(243, 1, 0, -50553, 1972, 0, 0, 39, '1971'),
	(243, 1, 0, -50553, 1973, 0, 0, 39, '1972'),
	(243, 1, 0, -50553, 1974, 0, 0, 39, '1973'),
	(243, 1, 0, -50553, 1975, 0, 0, 39, '1974'),
	(243, 1, 0, -50553, 1976, 0, 0, 39, '1975'),
	(243, 1, 0, -50553, 1977, 0, 0, 39, '1976'),
	(243, 1, 0, -50553, 1978, 0, 0, 39, '1977'),
	(243, 1, 0, -50553, 1979, 0, 0, 39, '1978'),
	(243, 1, 0, -50553, 1980, 0, 0, 39, '1979'),
	(243, 1, 0, -50553, 1981, 0, 0, 39, '1980'),
	(243, 1, 0, -50553, 1982, 0, 0, 39, '1981'),
	(243, 1, 0, -50553, 1983, 0, 0, 39, '1982'),
	(243, 1, 0, -50553, 1984, 0, 0, 39, '1983'),
	(243, 1, 0, -50553, 1985, 0, 0, 39, '1984'),
	(243, 1, 0, -50553, 1986, 0, 0, 39, '1985'),
	(243, 1, 0, -50553, 1987, 0, 0, 39, '1986'),
	(243, 1, 0, -50553, 1988, 0, 0, 39, '1987'),
	(243, 1, 0, -50553, 1989, 0, 0, 39, '1988'),
	(243, 1, 0, -50553, 1990, 0, 0, 39, '1989'),
	(243, 1, 0, -50553, 1991, 0, 0, 39, '1990'),
	(243, 1, 0, -50553, 1992, 0, 0, 39, '1991'),
	(243, 1, 0, -50553, 1993, 0, 0, 39, '1992'),
	(243, 1, 0, -50553, 1994, 0, 0, 39, '1993'),
	(243, 1, 0, -50553, 1995, 0, 0, 39, '1994'),
	(243, 1, 0, -50553, 1996, 0, 0, 39, '1995'),
	(243, 1, 0, -50553, 1997, 0, 0, 39, '1996'),
	(243, 1, 0, -50553, 1998, 0, 0, 39, '1997'),
	(243, 1, 0, -50553, 1999, 0, 0, 39, '1998'),
	(243, 1, 0, -50553, 2000, 0, 0, 39, '1999'),
	(243, 1, 0, -50553, 2001, 0, 0, 39, '2000'),
	(243, 1, 0, -50553, 2002, 0, 0, 39, '2001'),
	(243, 1, 0, -50553, 2003, 0, 0, 39, '2002'),
	(243, 1, 0, -50553, 2004, 0, 0, 39, '2003'),
	(243, 1, 0, -50553, 2005, 0, 0, 39, '2004'),
	(243, 1, 0, -50553, 2006, 0, 0, 39, '2005'),
	(243, 1, 0, -50553, 2007, 0, 0, 39, '2006'),
	(243, 1, 0, -50553, 2008, 0, 0, 39, '2007'),
	(243, 1, 0, -50553, 2009, 0, 0, 39, '2008'),
	(243, 1, 0, -50553, 2010, 0, 0, 39, '2009'),
	(243, 1, 0, -50553, 2011, 0, 0, 39, '2010'),
	(243, 1, 0, -50553, 2012, 0, 0, 39, '2011'),
	(243, 1, 0, -50553, 2013, 0, 0, 39, '2012'),
	(243, 1, 0, -50553, 2014, 0, 0, 39, '2013'),
	(243, 1, 0, -50553, 2015, 0, 0, 39, '2014'),
	(243, 1, 0, -50553, 2016, 0, 0, 39, '2015'),
	(243, 1, 0, -50553, 2017, 0, 0, 39, '2016'),
	(243, 1, 0, -50553, 2018, 0, 0, 39, '2017'),
	(243, 1, 0, -50553, 2019, 0, 0, 39, '2018'),
	(243, 1, 0, -50553, 2020, 0, 0, 39, '2019'),
	(243, 1, 0, -50553, 2021, 0, 0, 39, '2020'),
	(243, 1, 0, -50553, 2022, 0, 0, 39, '2021'),
	(243, 1, 0, -50553, 2023, 0, 0, 39, '2022'),
	(243, 1, 0, -50553, 2024, 0, 0, 39, '2023'),
	(243, 1, 0, -50553, 2025, 0, 0, 39, '2024'),
	(243, 1, 0, -50553, 2026, 0, 0, 39, '2025'),
	(243, 1, 0, -50553, 2027, 0, 0, 39, '2026'),
	(243, 1, 0, -50553, 2028, 0, 0, 39, '2027'),
	(243, 1, 0, -50553, 2029, 0, 0, 39, '2028'),
	(243, 1, 0, -50553, 2030, 0, 0, 39, '2029'),
	(243, 1, 0, -50553, 2031, 0, 0, 39, '2030'),
	(243, 1, 0, -50553, 2032, 0, 0, 39, '2031'),
	(243, 1, 0, -50553, 2033, 0, 0, 39, '2032'),
	(243, 1, 0, -50553, 2034, 0, 0, 39, '2033'),
	(243, 1, 0, -50553, 2035, 0, 0, 39, '2034'),
	(243, 1, 0, -50553, 2036, 0, 0, 39, '2035'),
	(243, 1, 0, -50553, 2037, 0, 0, 39, '2036'),
	(243, 1, 0, -50553, 2038, 0, 0, 39, '2037'),
	(243, 1, 0, -50553, 2039, 0, 0, 39, '2038'),
	(243, 1, 0, -50553, 2040, 0, 0, 39, '2039'),
	(243, 1, 0, -50553, 2041, 0, 0, 39, '2040'),
	(243, 1, 0, -50553, 2042, 0, 0, 39, '2041'),
	(243, 1, 0, -50553, 2043, 0, 0, 39, '2042'),
	(243, 1, 0, -50553, 2044, 0, 0, 39, '2043'),
	(243, 1, 0, -50553, 2045, 0, 0, 39, '2044'),
	(243, 1, 0, -50553, 2046, 0, 0, 39, '2045'),
	(243, 1, 0, -50553, 2047, 0, 0, 39, '2046'),
	(243, 1, 0, -50553, 2048, 0, 0, 39, '2047'),
	(243, 1, 0, -50512, 1, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 1, 1, 0, 39, '0'),
	(243, 1, 0, -50512, 1, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 1, 2, 0, 39, '0'),
	(243, 1, 0, -50512, 1, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 1, 3, 0, 39, '0'),
	(243, 1, 0, -50512, 1, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 1, 4, 0, 39, '0'),
	(243, 1, 0, -50512, 2, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 2, 1, 0, 39, '1'),
	(243, 1, 0, -50512, 2, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 2, 2, 0, 39, '1'),
	(243, 1, 0, -50512, 2, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 2, 3, 0, 39, '1'),
	(243, 1, 0, -50512, 2, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 2, 4, 0, 39, '1'),
	(243, 1, 0, -50512, 3, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 3, 1, 0, 39, '2'),
	(243, 1, 0, -50512, 3, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 3, 2, 0, 39, '2'),
	(243, 1, 0, -50512, 3, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 3, 3, 0, 39, '2'),
	(243, 1, 0, -50512, 3, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 3, 4, 0, 39, '2'),
	(243, 1, 0, -50512, 4, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 4, 1, 0, 39, '3'),
	(243, 1, 0, -50512, 4, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 4, 2, 0, 39, '3'),
	(243, 1, 0, -50512, 4, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 4, 3, 0, 39, '3'),
	(243, 1, 0, -50512, 4, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 4, 4, 0, 39, '3'),
	(243, 1, 0, -50512, 5, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 5, 1, 0, 39, '4'),
	(243, 1, 0, -50512, 5, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 5, 2, 0, 39, '4'),
	(243, 1, 0, -50512, 5, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 5, 3, 0, 39, '4'),
	(243, 1, 0, -50512, 5, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 5, 4, 0, 39, '4'),
	(243, 1, 0, -50512, 6, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 6, 1, 0, 39, '5'),
	(243, 1, 0, -50512, 6, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 6, 2, 0, 39, '5'),
	(243, 1, 0, -50512, 6, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 6, 3, 0, 39, '5'),
	(243, 1, 0, -50512, 6, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 6, 4, 0, 39, '5'),
	(243, 1, 0, -50512, 7, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 7, 1, 0, 39, '6'),
	(243, 1, 0, -50512, 7, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 7, 2, 0, 39, '6'),
	(243, 1, 0, -50512, 7, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 7, 3, 0, 39, '6'),
	(243, 1, 0, -50512, 7, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 7, 4, 0, 39, '6'),
	(243, 1, 0, -50512, 8, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 8, 1, 0, 39, '7'),
	(243, 1, 0, -50512, 8, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 8, 2, 0, 39, '7'),
	(243, 1, 0, -50512, 8, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 8, 3, 0, 39, '7'),
	(243, 1, 0, -50512, 8, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 8, 4, 0, 39, '7'),
	(243, 1, 0, -50512, 9, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 9, 1, 0, 39, '8'),
	(243, 1, 0, -50512, 9, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 9, 2, 0, 39, '8'),
	(243, 1, 0, -50512, 9, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 9, 3, 0, 39, '8'),
	(243, 1, 0, -50512, 9, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 9, 4, 0, 39, '8'),
	(243, 1, 0, -50512, 10, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 10, 1, 0, 39, '9'),
	(243, 1, 0, -50512, 10, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 10, 2, 0, 39, '9'),
	(243, 1, 0, -50512, 10, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 10, 3, 0, 39, '9'),
	(243, 1, 0, -50512, 10, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 10, 4, 0, 39, '9'),
	(243, 1, 0, -50512, 11, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 11, 1, 0, 39, '10'),
	(243, 1, 0, -50512, 11, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 11, 2, 0, 39, '10'),
	(243, 1, 0, -50512, 11, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 11, 3, 0, 39, '10'),
	(243, 1, 0, -50512, 11, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 11, 4, 0, 39, '10'),
	(243, 1, 0, -50512, 12, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 12, 1, 0, 39, '11'),
	(243, 1, 0, -50512, 12, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 12, 2, 0, 39, '11'),
	(243, 1, 0, -50512, 12, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 12, 3, 0, 39, '11'),
	(243, 1, 0, -50512, 12, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 12, 4, 0, 39, '11'),
	(243, 1, 0, -50512, 13, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 13, 1, 0, 39, '12'),
	(243, 1, 0, -50512, 13, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 13, 2, 0, 39, '12'),
	(243, 1, 0, -50512, 13, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 13, 3, 0, 39, '12'),
	(243, 1, 0, -50512, 13, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 13, 4, 0, 39, '12'),
	(243, 1, 0, -50512, 14, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 14, 1, 0, 39, '13'),
	(243, 1, 0, -50512, 14, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 14, 2, 0, 39, '13'),
	(243, 1, 0, -50512, 14, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 14, 3, 0, 39, '13'),
	(243, 1, 0, -50512, 14, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 14, 4, 0, 39, '13'),
	(243, 1, 0, -50512, 15, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 15, 1, 0, 39, '14'),
	(243, 1, 0, -50512, 15, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 15, 2, 0, 39, '14'),
	(243, 1, 0, -50512, 15, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 15, 3, 0, 39, '14'),
	(243, 1, 0, -50512, 15, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 15, 4, 0, 39, '14'),
	(243, 1, 0, -50512, 16, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 16, 1, 0, 39, '15'),
	(243, 1, 0, -50512, 16, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 16, 2, 0, 39, '15'),
	(243, 1, 0, -50512, 16, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 16, 3, 0, 39, '15'),
	(243, 1, 0, -50512, 16, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 16, 4, 0, 39, '15'),
	(243, 1, 0, -50512, 17, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 17, 1, 0, 39, '16'),
	(243, 1, 0, -50512, 17, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 17, 2, 0, 39, '16'),
	(243, 1, 0, -50512, 17, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 17, 3, 0, 39, '16'),
	(243, 1, 0, -50512, 17, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 17, 4, 0, 39, '16'),
	(243, 1, 0, -50512, 18, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 18, 1, 0, 39, '17'),
	(243, 1, 0, -50512, 18, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 18, 2, 0, 39, '17'),
	(243, 1, 0, -50512, 18, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 18, 3, 0, 39, '17'),
	(243, 1, 0, -50512, 18, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 18, 4, 0, 39, '17'),
	(243, 1, 0, -50512, 19, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 19, 1, 0, 39, '18'),
	(243, 1, 0, -50512, 19, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 19, 2, 0, 39, '18'),
	(243, 1, 0, -50512, 19, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 19, 3, 0, 39, '18'),
	(243, 1, 0, -50512, 19, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 19, 4, 0, 39, '18'),
	(243, 1, 0, -50512, 20, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 20, 1, 0, 39, '19'),
	(243, 1, 0, -50512, 20, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 20, 2, 0, 39, '19'),
	(243, 1, 0, -50512, 20, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 20, 3, 0, 39, '19'),
	(243, 1, 0, -50512, 20, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 20, 4, 0, 39, '19'),
	(243, 1, 0, -50512, 21, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 21, 1, 0, 39, '20'),
	(243, 1, 0, -50512, 21, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 21, 2, 0, 39, '20'),
	(243, 1, 0, -50512, 21, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 21, 3, 0, 39, '20'),
	(243, 1, 0, -50512, 21, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 21, 4, 0, 39, '20'),
	(243, 1, 0, -50512, 22, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 22, 1, 0, 39, '21'),
	(243, 1, 0, -50512, 22, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 22, 2, 0, 39, '21'),
	(243, 1, 0, -50512, 22, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 22, 3, 0, 39, '21'),
	(243, 1, 0, -50512, 22, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 22, 4, 0, 39, '21'),
	(243, 1, 0, -50512, 23, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 23, 1, 0, 39, '22'),
	(243, 1, 0, -50512, 23, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 23, 2, 0, 39, '22'),
	(243, 1, 0, -50512, 23, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 23, 3, 0, 39, '22'),
	(243, 1, 0, -50512, 23, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 23, 4, 0, 39, '22'),
	(243, 1, 0, -50512, 24, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 24, 1, 0, 39, '23'),
	(243, 1, 0, -50512, 24, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 24, 2, 0, 39, '23'),
	(243, 1, 0, -50512, 24, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 24, 3, 0, 39, '23'),
	(243, 1, 0, -50512, 24, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 24, 4, 0, 39, '23'),
	(243, 1, 0, -50512, 25, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 25, 1, 0, 39, '24'),
	(243, 1, 0, -50512, 25, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 25, 2, 0, 39, '24'),
	(243, 1, 0, -50512, 25, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 25, 3, 0, 39, '24'),
	(243, 1, 0, -50512, 25, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 25, 4, 0, 39, '24'),
	(243, 1, 0, -50512, 26, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 26, 1, 0, 39, '25'),
	(243, 1, 0, -50512, 26, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 26, 2, 0, 39, '25'),
	(243, 1, 0, -50512, 26, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 26, 3, 0, 39, '25'),
	(243, 1, 0, -50512, 26, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 26, 4, 0, 39, '25'),
	(243, 1, 0, -50512, 27, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 27, 1, 0, 39, '26'),
	(243, 1, 0, -50512, 27, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 27, 2, 0, 39, '26'),
	(243, 1, 0, -50512, 27, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 27, 3, 0, 39, '26'),
	(243, 1, 0, -50512, 27, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 27, 4, 0, 39, '26'),
	(243, 1, 0, -50512, 28, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 28, 1, 0, 39, '27'),
	(243, 1, 0, -50512, 28, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 28, 2, 0, 39, '27'),
	(243, 1, 0, -50512, 28, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 28, 3, 0, 39, '27'),
	(243, 1, 0, -50512, 28, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 28, 4, 0, 39, '27'),
	(243, 1, 0, -50512, 29, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 29, 1, 0, 39, '28'),
	(243, 1, 0, -50512, 29, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 29, 2, 0, 39, '28'),
	(243, 1, 0, -50512, 29, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 29, 3, 0, 39, '28'),
	(243, 1, 0, -50512, 29, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 29, 4, 0, 39, '28'),
	(243, 1, 0, -50512, 30, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 30, 1, 0, 39, '29'),
	(243, 1, 0, -50512, 30, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 30, 2, 0, 39, '29'),
	(243, 1, 0, -50512, 30, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 30, 3, 0, 39, '29'),
	(243, 1, 0, -50512, 30, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 30, 4, 0, 39, '29'),
	(243, 1, 0, -50512, 31, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 31, 1, 0, 39, '30'),
	(243, 1, 0, -50512, 31, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 31, 2, 0, 39, '30'),
	(243, 1, 0, -50512, 31, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 31, 3, 0, 39, '30'),
	(243, 1, 0, -50512, 31, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 31, 4, 0, 39, '30'),
	(243, 1, 0, -50512, 32, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 32, 1, 0, 39, '31'),
	(243, 1, 0, -50512, 32, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 32, 2, 0, 39, '31'),
	(243, 1, 0, -50512, 32, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 32, 3, 0, 39, '31'),
	(243, 1, 0, -50512, 32, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 32, 4, 0, 39, '31'),
	(243, 1, 0, -50512, 33, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 33, 1, 0, 39, '32'),
	(243, 1, 0, -50512, 33, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 33, 2, 0, 39, '32'),
	(243, 1, 0, -50512, 33, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 33, 3, 0, 39, '32'),
	(243, 1, 0, -50512, 33, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 33, 4, 0, 39, '32'),
	(243, 1, 0, -50512, 34, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 34, 1, 0, 39, '33'),
	(243, 1, 0, -50512, 34, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 34, 2, 0, 39, '33'),
	(243, 1, 0, -50512, 34, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 34, 3, 0, 39, '33'),
	(243, 1, 0, -50512, 34, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 34, 4, 0, 39, '33'),
	(243, 1, 0, -50512, 35, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 35, 1, 0, 39, '34'),
	(243, 1, 0, -50512, 35, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 35, 2, 0, 39, '34'),
	(243, 1, 0, -50512, 35, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 35, 3, 0, 39, '34'),
	(243, 1, 0, -50512, 35, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 35, 4, 0, 39, '34'),
	(243, 1, 0, -50512, 36, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 36, 1, 0, 39, '35'),
	(243, 1, 0, -50512, 36, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 36, 2, 0, 39, '35'),
	(243, 1, 0, -50512, 36, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 36, 3, 0, 39, '35'),
	(243, 1, 0, -50512, 36, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 36, 4, 0, 39, '35'),
	(243, 1, 0, -50512, 37, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 37, 1, 0, 39, '36'),
	(243, 1, 0, -50512, 37, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 37, 2, 0, 39, '36'),
	(243, 1, 0, -50512, 37, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 37, 3, 0, 39, '36'),
	(243, 1, 0, -50512, 37, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 37, 4, 0, 39, '36'),
	(243, 1, 0, -50512, 38, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 38, 1, 0, 39, '37'),
	(243, 1, 0, -50512, 38, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 38, 2, 0, 39, '37'),
	(243, 1, 0, -50512, 38, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 38, 3, 0, 39, '37'),
	(243, 1, 0, -50512, 38, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 38, 4, 0, 39, '37'),
	(243, 1, 0, -50512, 39, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 39, 1, 0, 39, '38'),
	(243, 1, 0, -50512, 39, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 39, 2, 0, 39, '38'),
	(243, 1, 0, -50512, 39, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 39, 3, 0, 39, '38'),
	(243, 1, 0, -50512, 39, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 39, 4, 0, 39, '38'),
	(243, 1, 0, -50512, 40, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 40, 1, 0, 39, '39'),
	(243, 1, 0, -50512, 40, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 40, 2, 0, 39, '39'),
	(243, 1, 0, -50512, 40, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 40, 3, 0, 39, '39'),
	(243, 1, 0, -50512, 40, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 40, 4, 0, 39, '39'),
	(243, 1, 0, -50512, 41, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 41, 1, 0, 39, '40'),
	(243, 1, 0, -50512, 41, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 41, 2, 0, 39, '40'),
	(243, 1, 0, -50512, 41, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 41, 3, 0, 39, '40'),
	(243, 1, 0, -50512, 41, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 41, 4, 0, 39, '40'),
	(243, 1, 0, -50512, 42, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 42, 1, 0, 39, '41'),
	(243, 1, 0, -50512, 42, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 42, 2, 0, 39, '41'),
	(243, 1, 0, -50512, 42, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 42, 3, 0, 39, '41'),
	(243, 1, 0, -50512, 42, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 42, 4, 0, 39, '41'),
	(243, 1, 0, -50512, 43, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 43, 1, 0, 39, '42'),
	(243, 1, 0, -50512, 43, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 43, 2, 0, 39, '42'),
	(243, 1, 0, -50512, 43, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 43, 3, 0, 39, '42'),
	(243, 1, 0, -50512, 43, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 43, 4, 0, 39, '42'),
	(243, 1, 0, -50512, 44, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 44, 1, 0, 39, '43'),
	(243, 1, 0, -50512, 44, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 44, 2, 0, 39, '43'),
	(243, 1, 0, -50512, 44, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 44, 3, 0, 39, '43'),
	(243, 1, 0, -50512, 44, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 44, 4, 0, 39, '43'),
	(243, 1, 0, -50512, 45, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 45, 1, 0, 39, '44'),
	(243, 1, 0, -50512, 45, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 45, 2, 0, 39, '44'),
	(243, 1, 0, -50512, 45, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 45, 3, 0, 39, '44'),
	(243, 1, 0, -50512, 45, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 45, 4, 0, 39, '44'),
	(243, 1, 0, -50512, 46, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 46, 1, 0, 39, '45'),
	(243, 1, 0, -50512, 46, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 46, 2, 0, 39, '45'),
	(243, 1, 0, -50512, 46, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 46, 3, 0, 39, '45'),
	(243, 1, 0, -50512, 46, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 46, 4, 0, 39, '45'),
	(243, 1, 0, -50512, 47, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 47, 1, 0, 39, '46'),
	(243, 1, 0, -50512, 47, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 47, 2, 0, 39, '46'),
	(243, 1, 0, -50512, 47, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 47, 3, 0, 39, '46'),
	(243, 1, 0, -50512, 47, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 47, 4, 0, 39, '46'),
	(243, 1, 0, -50512, 48, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 48, 1, 0, 39, '47'),
	(243, 1, 0, -50512, 48, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 48, 2, 0, 39, '47'),
	(243, 1, 0, -50512, 48, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 48, 3, 0, 39, '47'),
	(243, 1, 0, -50512, 48, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 48, 4, 0, 39, '47'),
	(243, 1, 0, -50512, 49, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 49, 1, 0, 39, '48'),
	(243, 1, 0, -50512, 49, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 49, 2, 0, 39, '48'),
	(243, 1, 0, -50512, 49, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 49, 3, 0, 39, '48'),
	(243, 1, 0, -50512, 49, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 49, 4, 0, 39, '48'),
	(243, 1, 0, -50512, 50, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 50, 1, 0, 39, '49'),
	(243, 1, 0, -50512, 50, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 50, 2, 0, 39, '49'),
	(243, 1, 0, -50512, 50, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 50, 3, 0, 39, '49'),
	(243, 1, 0, -50512, 50, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 50, 4, 0, 39, '49'),
	(243, 1, 0, -50512, 51, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 51, 1, 0, 39, '50'),
	(243, 1, 0, -50512, 51, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 51, 2, 0, 39, '50'),
	(243, 1, 0, -50512, 51, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 51, 3, 0, 39, '50'),
	(243, 1, 0, -50512, 51, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 51, 4, 0, 39, '50'),
	(243, 1, 0, -50512, 52, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 52, 1, 0, 39, '51'),
	(243, 1, 0, -50512, 52, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 52, 2, 0, 39, '51'),
	(243, 1, 0, -50512, 52, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 52, 3, 0, 39, '51'),
	(243, 1, 0, -50512, 52, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 52, 4, 0, 39, '51'),
	(243, 1, 0, -50512, 53, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 53, 1, 0, 39, '52'),
	(243, 1, 0, -50512, 53, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 53, 2, 0, 39, '52'),
	(243, 1, 0, -50512, 53, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 53, 3, 0, 39, '52'),
	(243, 1, 0, -50512, 53, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 53, 4, 0, 39, '52'),
	(243, 1, 0, -50512, 54, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 54, 1, 0, 39, '53'),
	(243, 1, 0, -50512, 54, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 54, 2, 0, 39, '53'),
	(243, 1, 0, -50512, 54, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 54, 3, 0, 39, '53'),
	(243, 1, 0, -50512, 54, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 54, 4, 0, 39, '53'),
	(243, 1, 0, -50512, 55, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 55, 1, 0, 39, '54'),
	(243, 1, 0, -50512, 55, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 55, 2, 0, 39, '54'),
	(243, 1, 0, -50512, 55, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 55, 3, 0, 39, '54'),
	(243, 1, 0, -50512, 55, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 55, 4, 0, 39, '54'),
	(243, 1, 0, -50512, 56, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 56, 1, 0, 39, '55'),
	(243, 1, 0, -50512, 56, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 56, 2, 0, 39, '55'),
	(243, 1, 0, -50512, 56, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 56, 3, 0, 39, '55'),
	(243, 1, 0, -50512, 56, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 56, 4, 0, 39, '55'),
	(243, 1, 0, -50512, 57, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 57, 1, 0, 39, '56'),
	(243, 1, 0, -50512, 57, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 57, 2, 0, 39, '56'),
	(243, 1, 0, -50512, 57, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 57, 3, 0, 39, '56'),
	(243, 1, 0, -50512, 57, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 57, 4, 0, 39, '56'),
	(243, 1, 0, -50512, 58, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 58, 1, 0, 39, '57'),
	(243, 1, 0, -50512, 58, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 58, 2, 0, 39, '57'),
	(243, 1, 0, -50512, 58, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 58, 3, 0, 39, '57'),
	(243, 1, 0, -50512, 58, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 58, 4, 0, 39, '57'),
	(243, 1, 0, -50512, 59, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 59, 1, 0, 39, '58'),
	(243, 1, 0, -50512, 59, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 59, 2, 0, 39, '58'),
	(243, 1, 0, -50512, 59, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 59, 3, 0, 39, '58'),
	(243, 1, 0, -50512, 59, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 59, 4, 0, 39, '58'),
	(243, 1, 0, -50512, 60, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 60, 1, 0, 39, '59'),
	(243, 1, 0, -50512, 60, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 60, 2, 0, 39, '59'),
	(243, 1, 0, -50512, 60, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 60, 3, 0, 39, '59'),
	(243, 1, 0, -50512, 60, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 60, 4, 0, 39, '59'),
	(243, 1, 0, -50512, 61, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 61, 1, 0, 39, '60'),
	(243, 1, 0, -50512, 61, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 61, 2, 0, 39, '60'),
	(243, 1, 0, -50512, 61, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 61, 3, 0, 39, '60'),
	(243, 1, 0, -50512, 61, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 61, 4, 0, 39, '60'),
	(243, 1, 0, -50512, 62, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 62, 1, 0, 39, '61'),
	(243, 1, 0, -50512, 62, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 62, 2, 0, 39, '61'),
	(243, 1, 0, -50512, 62, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 62, 3, 0, 39, '61'),
	(243, 1, 0, -50512, 62, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 62, 4, 0, 39, '61'),
	(243, 1, 0, -50512, 63, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 63, 1, 0, 39, '62'),
	(243, 1, 0, -50512, 63, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 63, 2, 0, 39, '62'),
	(243, 1, 0, -50512, 63, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 63, 3, 0, 39, '62'),
	(243, 1, 0, -50512, 63, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 63, 4, 0, 39, '62'),
	(243, 1, 0, -50512, 64, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 64, 1, 0, 39, '63'),
	(243, 1, 0, -50512, 64, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 64, 2, 0, 39, '63'),
	(243, 1, 0, -50512, 64, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 64, 3, 0, 39, '63'),
	(243, 1, 0, -50512, 64, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 64, 4, 0, 39, '63'),
	(243, 1, 0, -50512, 65, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 65, 1, 0, 39, '64'),
	(243, 1, 0, -50512, 65, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 65, 2, 0, 39, '64'),
	(243, 1, 0, -50512, 65, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 65, 3, 0, 39, '64'),
	(243, 1, 0, -50512, 65, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 65, 4, 0, 39, '64'),
	(243, 1, 0, -50512, 66, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 66, 1, 0, 39, '65'),
	(243, 1, 0, -50512, 66, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 66, 2, 0, 39, '65'),
	(243, 1, 0, -50512, 66, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 66, 3, 0, 39, '65'),
	(243, 1, 0, -50512, 66, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 66, 4, 0, 39, '65'),
	(243, 1, 0, -50512, 67, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 67, 1, 0, 39, '66'),
	(243, 1, 0, -50512, 67, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 67, 2, 0, 39, '66'),
	(243, 1, 0, -50512, 67, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 67, 3, 0, 39, '66'),
	(243, 1, 0, -50512, 67, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 67, 4, 0, 39, '66'),
	(243, 1, 0, -50512, 68, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 68, 1, 0, 39, '67'),
	(243, 1, 0, -50512, 68, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 68, 2, 0, 39, '67'),
	(243, 1, 0, -50512, 68, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 68, 3, 0, 39, '67'),
	(243, 1, 0, -50512, 68, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 68, 4, 0, 39, '67'),
	(243, 1, 0, -50512, 69, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 69, 1, 0, 39, '68'),
	(243, 1, 0, -50512, 69, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 69, 2, 0, 39, '68'),
	(243, 1, 0, -50512, 69, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 69, 3, 0, 39, '68'),
	(243, 1, 0, -50512, 69, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 69, 4, 0, 39, '68'),
	(243, 1, 0, -50512, 70, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 70, 1, 0, 39, '69'),
	(243, 1, 0, -50512, 70, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 70, 2, 0, 39, '69'),
	(243, 1, 0, -50512, 70, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 70, 3, 0, 39, '69'),
	(243, 1, 0, -50512, 70, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 70, 4, 0, 39, '69'),
	(243, 1, 0, -50512, 71, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 71, 1, 0, 39, '70'),
	(243, 1, 0, -50512, 71, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 71, 2, 0, 39, '70'),
	(243, 1, 0, -50512, 71, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 71, 3, 0, 39, '70'),
	(243, 1, 0, -50512, 71, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 71, 4, 0, 39, '70'),
	(243, 1, 0, -50512, 72, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 72, 1, 0, 39, '71'),
	(243, 1, 0, -50512, 72, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 72, 2, 0, 39, '71'),
	(243, 1, 0, -50512, 72, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 72, 3, 0, 39, '71'),
	(243, 1, 0, -50512, 72, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 72, 4, 0, 39, '71'),
	(243, 1, 0, -50512, 73, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 73, 1, 0, 39, '72'),
	(243, 1, 0, -50512, 73, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 73, 2, 0, 39, '72'),
	(243, 1, 0, -50512, 73, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 73, 3, 0, 39, '72'),
	(243, 1, 0, -50512, 73, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 73, 4, 0, 39, '72'),
	(243, 1, 0, -50512, 74, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 74, 1, 0, 39, '73'),
	(243, 1, 0, -50512, 74, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 74, 2, 0, 39, '73'),
	(243, 1, 0, -50512, 74, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 74, 3, 0, 39, '73'),
	(243, 1, 0, -50512, 74, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 74, 4, 0, 39, '73'),
	(243, 1, 0, -50512, 75, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 75, 1, 0, 39, '74'),
	(243, 1, 0, -50512, 75, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 75, 2, 0, 39, '74'),
	(243, 1, 0, -50512, 75, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 75, 3, 0, 39, '74'),
	(243, 1, 0, -50512, 75, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 75, 4, 0, 39, '74'),
	(243, 1, 0, -50512, 76, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 76, 1, 0, 39, '75'),
	(243, 1, 0, -50512, 76, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 76, 2, 0, 39, '75'),
	(243, 1, 0, -50512, 76, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 76, 3, 0, 39, '75'),
	(243, 1, 0, -50512, 76, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 76, 4, 0, 39, '75'),
	(243, 1, 0, -50512, 77, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 77, 1, 0, 39, '76'),
	(243, 1, 0, -50512, 77, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 77, 2, 0, 39, '76'),
	(243, 1, 0, -50512, 77, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 77, 3, 0, 39, '76'),
	(243, 1, 0, -50512, 77, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 77, 4, 0, 39, '76'),
	(243, 1, 0, -50512, 78, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 78, 1, 0, 39, '77'),
	(243, 1, 0, -50512, 78, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 78, 2, 0, 39, '77'),
	(243, 1, 0, -50512, 78, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 78, 3, 0, 39, '77'),
	(243, 1, 0, -50512, 78, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 78, 4, 0, 39, '77'),
	(243, 1, 0, -50512, 79, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 79, 1, 0, 39, '78'),
	(243, 1, 0, -50512, 79, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 79, 2, 0, 39, '78'),
	(243, 1, 0, -50512, 79, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 79, 3, 0, 39, '78'),
	(243, 1, 0, -50512, 79, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 79, 4, 0, 39, '78'),
	(243, 1, 0, -50512, 80, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 80, 1, 0, 39, '79'),
	(243, 1, 0, -50512, 80, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 80, 2, 0, 39, '79'),
	(243, 1, 0, -50512, 80, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 80, 3, 0, 39, '79'),
	(243, 1, 0, -50512, 80, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 80, 4, 0, 39, '79'),
	(243, 1, 0, -50512, 81, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 81, 1, 0, 39, '80'),
	(243, 1, 0, -50512, 81, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 81, 2, 0, 39, '80'),
	(243, 1, 0, -50512, 81, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 81, 3, 0, 39, '80'),
	(243, 1, 0, -50512, 81, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 81, 4, 0, 39, '80'),
	(243, 1, 0, -50512, 82, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 82, 1, 0, 39, '81'),
	(243, 1, 0, -50512, 82, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 82, 2, 0, 39, '81'),
	(243, 1, 0, -50512, 82, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 82, 3, 0, 39, '81'),
	(243, 1, 0, -50512, 82, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 82, 4, 0, 39, '81'),
	(243, 1, 0, -50512, 83, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 83, 1, 0, 39, '82'),
	(243, 1, 0, -50512, 83, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 83, 2, 0, 39, '82'),
	(243, 1, 0, -50512, 83, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 83, 3, 0, 39, '82'),
	(243, 1, 0, -50512, 83, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 83, 4, 0, 39, '82'),
	(243, 1, 0, -50512, 84, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 84, 1, 0, 39, '83'),
	(243, 1, 0, -50512, 84, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 84, 2, 0, 39, '83'),
	(243, 1, 0, -50512, 84, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 84, 3, 0, 39, '83'),
	(243, 1, 0, -50512, 84, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 84, 4, 0, 39, '83'),
	(243, 1, 0, -50512, 85, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 85, 1, 0, 39, '84'),
	(243, 1, 0, -50512, 85, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 85, 2, 0, 39, '84'),
	(243, 1, 0, -50512, 85, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 85, 3, 0, 39, '84'),
	(243, 1, 0, -50512, 85, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 85, 4, 0, 39, '84'),
	(243, 1, 0, -50512, 86, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 86, 1, 0, 39, '85'),
	(243, 1, 0, -50512, 86, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 86, 2, 0, 39, '85'),
	(243, 1, 0, -50512, 86, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 86, 3, 0, 39, '85'),
	(243, 1, 0, -50512, 86, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 86, 4, 0, 39, '85'),
	(243, 1, 0, -50512, 87, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 87, 1, 0, 39, '86'),
	(243, 1, 0, -50512, 87, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 87, 2, 0, 39, '86'),
	(243, 1, 0, -50512, 87, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 87, 3, 0, 39, '86'),
	(243, 1, 0, -50512, 87, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 87, 4, 0, 39, '86'),
	(243, 1, 0, -50512, 88, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 88, 1, 0, 39, '87'),
	(243, 1, 0, -50512, 88, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 88, 2, 0, 39, '87'),
	(243, 1, 0, -50512, 88, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 88, 3, 0, 39, '87'),
	(243, 1, 0, -50512, 88, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 88, 4, 0, 39, '87'),
	(243, 1, 0, -50512, 89, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 89, 1, 0, 39, '88'),
	(243, 1, 0, -50512, 89, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 89, 2, 0, 39, '88'),
	(243, 1, 0, -50512, 89, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 89, 3, 0, 39, '88'),
	(243, 1, 0, -50512, 89, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 89, 4, 0, 39, '88'),
	(243, 1, 0, -50512, 90, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 90, 1, 0, 39, '89'),
	(243, 1, 0, -50512, 90, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 90, 2, 0, 39, '89'),
	(243, 1, 0, -50512, 90, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 90, 3, 0, 39, '89'),
	(243, 1, 0, -50512, 90, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 90, 4, 0, 39, '89'),
	(243, 1, 0, -50512, 91, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 91, 1, 0, 39, '90'),
	(243, 1, 0, -50512, 91, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 91, 2, 0, 39, '90'),
	(243, 1, 0, -50512, 91, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 91, 3, 0, 39, '90'),
	(243, 1, 0, -50512, 91, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 91, 4, 0, 39, '90'),
	(243, 1, 0, -50512, 92, 1, 0, 37, '12'),
	(243, 1, 0, -50512, 92, 1, 0, 39, '91'),
	(243, 1, 0, -50512, 92, 2, 0, 37, '13'),
	(243, 1, 0, -50512, 92, 2, 0, 39, '91'),
	(243, 1, 0, -50512, 92, 3, 0, 37, '14'),
	(243, 1, 0, -50512, 92, 3, 0, 39, '91'),
	(243, 1, 0, -50512, 92, 4, 0, 37, '15'),
	(243, 1, 0, -50512, 92, 4, 0, 39, '91'),
	(243, 1, 0, -50378, 1, 0, 0, 39, '0'),
	(243, 1, 0, -50378, 2, 0, 0, 39, '1'),
	(243, 1, 0, -50378, 3, 0, 0, 39, '2'),
	(243, 1, 0, -50378, 4, 0, 0, 39, '3'),
	(243, 1, 0, -50378, 5, 0, 0, 39, '4'),
	(243, 1, 0, -50378, 6, 0, 0, 39, '5'),
	(243, 1, 0, -50378, 7, 0, 0, 39, '6'),
	(243, 1, 0, -50378, 8, 0, 0, 39, '7'),
	(243, 1, 0, -50378, 9, 0, 0, 39, '8'),
	(243, 1, 0, -50378, 10, 0, 0, 39, '9'),
	(243, 1, 0, -50378, 11, 0, 0, 39, '10'),
	(243, 1, 0, -50378, 12, 0, 0, 39, '11'),
	(243, 1, 0, -50378, 13, 0, 0, 39, '12'),
	(243, 1, 0, -50378, 14, 0, 0, 39, '13'),
	(243, 1, 0, -50378, 15, 0, 0, 39, '14'),
	(243, 1, 0, -50378, 16, 0, 0, 39, '15'),
	(243, 1, 0, -50378, 17, 0, 0, 39, '16'),
	(243, 1, 0, -50378, 18, 0, 0, 39, '17'),
	(243, 1, 0, -50378, 19, 0, 0, 39, '18'),
	(243, 1, 0, -50378, 20, 0, 0, 39, '19'),
	(243, 1, 0, -50378, 21, 0, 0, 39, '20'),
	(243, 1, 0, -50378, 22, 0, 0, 39, '21'),
	(243, 1, 0, -50378, 23, 0, 0, 39, '22'),
	(243, 1, 0, -50378, 24, 0, 0, 39, '23'),
	(243, 1, 0, -50378, 25, 0, 0, 39, '24'),
	(243, 1, 0, -50378, 26, 0, 0, 39, '25'),
	(243, 1, 0, -50378, 27, 0, 0, 39, '26'),
	(243, 1, 0, -50378, 28, 0, 0, 39, '27'),
	(243, 1, 0, -50378, 29, 0, 0, 39, '28'),
	(243, 1, 0, -50378, 30, 0, 0, 39, '29'),
	(243, 1, 0, -50378, 31, 0, 0, 39, '30'),
	(243, 1, 0, -50378, 32, 0, 0, 39, '31'),
	(243, 1, 0, -50378, 33, 0, 0, 39, '32'),
	(243, 1, 0, -50378, 34, 0, 0, 39, '33'),
	(243, 1, 0, -50378, 35, 0, 0, 39, '34'),
	(243, 1, 0, -50378, 36, 0, 0, 39, '35'),
	(243, 1, 0, -50378, 37, 0, 0, 39, '36'),
	(243, 1, 0, -50378, 38, 0, 0, 39, '37'),
	(243, 1, 0, -50378, 39, 0, 0, 39, '38'),
	(243, 1, 0, -50378, 40, 0, 0, 39, '39'),
	(243, 1, 0, -50378, 41, 0, 0, 39, '40'),
	(243, 1, 0, -50378, 42, 0, 0, 39, '41'),
	(243, 1, 0, -50378, 43, 0, 0, 39, '42'),
	(243, 1, 0, -50378, 44, 0, 0, 39, '43'),
	(243, 1, 0, -50378, 45, 0, 0, 39, '44'),
	(243, 1, 0, -50378, 46, 0, 0, 39, '45'),
	(243, 1, 0, -50378, 47, 0, 0, 39, '46'),
	(243, 1, 0, -50378, 48, 0, 0, 39, '47'),
	(243, 1, 0, -50378, 49, 0, 0, 39, '48'),
	(243, 1, 0, -50378, 50, 0, 0, 39, '49'),
	(243, 1, 0, -50378, 51, 0, 0, 39, '50'),
	(243, 1, 0, -50378, 52, 0, 0, 39, '51'),
	(243, 1, 0, -50378, 53, 0, 0, 39, '52'),
	(243, 1, 0, -50378, 54, 0, 0, 39, '53'),
	(243, 1, 0, -50378, 55, 0, 0, 39, '54'),
	(243, 1, 0, -50378, 56, 0, 0, 39, '55'),
	(243, 1, 0, -50378, 57, 0, 0, 39, '56'),
	(243, 1, 0, -50378, 58, 0, 0, 39, '57'),
	(243, 1, 0, -50378, 59, 0, 0, 39, '58'),
	(243, 1, 0, -50378, 60, 0, 0, 39, '59'),
	(243, 1, 0, -50378, 61, 0, 0, 39, '60'),
	(243, 1, 0, -50378, 62, 0, 0, 39, '61'),
	(243, 1, 0, -50378, 63, 0, 0, 39, '62'),
	(243, 1, 0, -50378, 64, 0, 0, 39, '63'),
	(243, 1, 0, -50378, 65, 0, 0, 39, '64'),
	(243, 1, 0, -50378, 66, 0, 0, 39, '65'),
	(243, 1, 0, -50378, 67, 0, 0, 39, '66'),
	(243, 1, 0, -50378, 68, 0, 0, 39, '67'),
	(243, 1, 0, -50378, 69, 0, 0, 39, '68'),
	(243, 1, 0, -50378, 70, 0, 0, 39, '69'),
	(243, 1, 0, -50378, 71, 0, 0, 39, '70'),
	(243, 1, 0, -50378, 72, 0, 0, 39, '71'),
	(243, 1, 0, -50378, 73, 0, 0, 39, '72'),
	(243, 1, 0, -50378, 74, 0, 0, 39, '73'),
	(243, 1, 0, -50378, 75, 0, 0, 39, '74'),
	(243, 1, 0, -50378, 76, 0, 0, 39, '75'),
	(243, 1, 0, -50378, 77, 0, 0, 39, '76'),
	(243, 1, 0, -50378, 78, 0, 0, 39, '77'),
	(243, 1, 0, -50378, 79, 0, 0, 39, '78'),
	(243, 1, 0, -50378, 80, 0, 0, 39, '79'),
	(243, 1, 0, -50378, 81, 0, 0, 39, '80'),
	(243, 1, 0, -50378, 82, 0, 0, 39, '81'),
	(243, 1, 0, -50378, 83, 0, 0, 39, '82'),
	(243, 1, 0, -50378, 84, 0, 0, 39, '83'),
	(243, 1, 0, -50378, 85, 0, 0, 39, '84'),
	(243, 1, 0, -50378, 86, 0, 0, 39, '85'),
	(243, 1, 0, -50378, 87, 0, 0, 39, '86'),
	(243, 1, 0, -50378, 88, 0, 0, 39, '87'),
	(243, 1, 0, -50378, 89, 0, 0, 39, '88'),
	(243, 1, 0, -50378, 90, 0, 0, 39, '89'),
	(243, 1, 0, -50378, 91, 0, 0, 39, '90'),
	(243, 1, 0, -50378, 92, 0, 0, 39, '91'),
	(243, 1, 0, -50378, 93, 0, 0, 39, '92'),
	(243, 1, 0, -50378, 94, 0, 0, 39, '93'),
	(243, 1, 0, -50378, 95, 0, 0, 39, '94'),
	(243, 1, 0, -50378, 96, 0, 0, 39, '95'),
	(243, 1, 0, -50378, 97, 0, 0, 39, '96'),
	(243, 1, 0, -50378, 98, 0, 0, 39, '97'),
	(243, 1, 0, -50378, 99, 0, 0, 39, '98'),
	(243, 1, 0, -50378, 100, 0, 0, 39, '99'),
	(243, 1, 0, -50378, 101, 0, 0, 39, '100'),
	(243, 1, 0, -50378, 102, 0, 0, 39, '101'),
	(243, 1, 0, -50378, 103, 0, 0, 39, '102'),
	(243, 1, 0, -50378, 104, 0, 0, 39, '103'),
	(243, 1, 0, -50378, 105, 0, 0, 39, '104'),
	(243, 1, 0, -50378, 106, 0, 0, 39, '105'),
	(243, 1, 0, -50378, 107, 0, 0, 39, '106'),
	(243, 1, 0, -50378, 108, 0, 0, 39, '107'),
	(243, 1, 0, -50378, 109, 0, 0, 39, '108'),
	(243, 1, 0, -50378, 110, 0, 0, 39, '109'),
	(243, 1, 0, -50378, 111, 0, 0, 39, '110'),
	(243, 1, 0, -50378, 112, 0, 0, 39, '111'),
	(243, 1, 0, -50378, 113, 0, 0, 39, '112'),
	(243, 1, 0, -50378, 114, 0, 0, 39, '113'),
	(243, 1, 0, -50378, 115, 0, 0, 39, '114'),
	(243, 1, 0, -50378, 116, 0, 0, 39, '115'),
	(243, 1, 0, -50378, 117, 0, 0, 39, '116'),
	(243, 1, 0, -50378, 118, 0, 0, 39, '117'),
	(243, 1, 0, -50378, 119, 0, 0, 39, '118'),
	(243, 1, 0, -50378, 120, 0, 0, 39, '119'),
	(243, 1, 0, -50378, 121, 0, 0, 39, '120'),
	(243, 1, 0, -50378, 122, 0, 0, 39, '121'),
	(243, 1, 0, -50378, 123, 0, 0, 39, '122'),
	(243, 1, 0, -50378, 124, 0, 0, 39, '123'),
	(243, 1, 0, -50378, 125, 0, 0, 39, '124'),
	(243, 1, 0, -50378, 126, 0, 0, 39, '125'),
	(243, 1, 0, -50378, 127, 0, 0, 39, '126'),
	(243, 1, 0, -50378, 128, 0, 0, 39, '127'),
	(243, 1, 0, -50378, 129, 0, 0, 39, '128'),
	(243, 1, 0, -50378, 130, 0, 0, 39, '129'),
	(243, 1, 0, -50378, 131, 0, 0, 39, '130'),
	(243, 1, 0, -50378, 132, 0, 0, 39, '131'),
	(243, 1, 0, -50378, 133, 0, 0, 39, '132'),
	(243, 1, 0, -50378, 134, 0, 0, 39, '133'),
	(243, 1, 0, -50378, 135, 0, 0, 39, '134'),
	(243, 1, 0, -50378, 136, 0, 0, 39, '135'),
	(243, 1, 0, -50378, 137, 0, 0, 39, '136'),
	(243, 1, 0, -50378, 138, 0, 0, 39, '137'),
	(243, 1, 0, -50378, 139, 0, 0, 39, '138'),
	(243, 1, 0, -50378, 140, 0, 0, 39, '139'),
	(243, 1, 0, -50378, 141, 0, 0, 39, '140'),
	(243, 1, 0, -50378, 142, 0, 0, 39, '141'),
	(243, 1, 0, -50378, 143, 0, 0, 39, '142'),
	(243, 1, 0, -50378, 144, 0, 0, 39, '143'),
	(243, 1, 0, -50378, 145, 0, 0, 39, '144'),
	(243, 1, 0, -50378, 146, 0, 0, 39, '145'),
	(243, 1, 0, -50378, 147, 0, 0, 39, '146'),
	(243, 1, 0, -50378, 148, 0, 0, 39, '147'),
	(243, 1, 0, -50378, 149, 0, 0, 39, '148'),
	(243, 1, 0, -50378, 150, 0, 0, 39, '149'),
	(243, 1, 0, -50378, 151, 0, 0, 39, '150'),
	(243, 1, 0, -50378, 152, 0, 0, 39, '151'),
	(243, 1, 0, -50378, 153, 0, 0, 39, '152'),
	(243, 1, 0, -50378, 154, 0, 0, 39, '153'),
	(243, 1, 0, -50378, 155, 0, 0, 39, '154'),
	(243, 1, 0, -50378, 156, 0, 0, 39, '155'),
	(243, 1, 0, -50378, 157, 0, 0, 39, '156'),
	(243, 1, 0, -50378, 158, 0, 0, 39, '157'),
	(243, 1, 0, -50378, 159, 0, 0, 39, '158'),
	(243, 1, 0, -50378, 160, 0, 0, 39, '159'),
	(243, 1, 0, -50378, 161, 0, 0, 39, '160'),
	(243, 1, 0, -50378, 162, 0, 0, 39, '161'),
	(243, 1, 0, -50378, 163, 0, 0, 39, '162'),
	(243, 1, 0, -50378, 164, 0, 0, 39, '163'),
	(243, 1, 0, -50378, 165, 0, 0, 39, '164'),
	(243, 1, 0, -50378, 166, 0, 0, 39, '165'),
	(243, 1, 0, -50378, 167, 0, 0, 39, '166'),
	(243, 1, 0, -50378, 168, 0, 0, 39, '167'),
	(243, 1, 0, -50378, 169, 0, 0, 39, '168'),
	(243, 1, 0, -50378, 170, 0, 0, 39, '169'),
	(243, 1, 0, -50378, 171, 0, 0, 39, '170'),
	(243, 1, 0, -50378, 172, 0, 0, 39, '171'),
	(243, 1, 0, -50378, 173, 0, 0, 39, '172'),
	(243, 1, 0, -50378, 174, 0, 0, 39, '173'),
	(243, 1, 0, -50378, 175, 0, 0, 39, '174'),
	(243, 1, 0, -50378, 176, 0, 0, 39, '175'),
	(243, 1, 0, -50378, 177, 0, 0, 39, '176'),
	(243, 1, 0, -50378, 178, 0, 0, 39, '177'),
	(243, 1, 0, -50378, 179, 0, 0, 39, '178'),
	(243, 1, 0, -50378, 180, 0, 0, 39, '179'),
	(243, 1, 0, -50378, 181, 0, 0, 39, '180'),
	(243, 1, 0, -50378, 182, 0, 0, 39, '181'),
	(243, 1, 0, -50378, 183, 0, 0, 39, '182'),
	(243, 1, 0, -50378, 184, 0, 0, 39, '183'),
	(243, 1, 0, -50378, 185, 0, 0, 39, '184'),
	(243, 1, 0, -50378, 186, 0, 0, 39, '185'),
	(243, 1, 0, -50378, 187, 0, 0, 39, '186'),
	(243, 1, 0, -50378, 188, 0, 0, 39, '187'),
	(243, 1, 0, -50378, 189, 0, 0, 39, '188'),
	(243, 1, 0, -50378, 190, 0, 0, 39, '189'),
	(243, 1, 0, -50378, 191, 0, 0, 39, '190'),
	(243, 1, 0, -50378, 192, 0, 0, 39, '191'),
	(243, 1, 0, -50378, 193, 0, 0, 39, '192'),
	(243, 1, 0, -50378, 194, 0, 0, 39, '193'),
	(243, 1, 0, -50378, 195, 0, 0, 39, '194'),
	(243, 1, 0, -50378, 196, 0, 0, 39, '195'),
	(243, 1, 0, -50378, 197, 0, 0, 39, '196'),
	(243, 1, 0, -50378, 198, 0, 0, 39, '197'),
	(243, 1, 0, -50378, 199, 0, 0, 39, '198'),
	(243, 1, 0, -50378, 200, 0, 0, 39, '199'),
	(243, 1, 0, -50378, 201, 0, 0, 39, '200'),
	(243, 1, 0, -50378, 202, 0, 0, 39, '201'),
	(243, 1, 0, -50378, 203, 0, 0, 39, '202'),
	(243, 1, 0, -50378, 204, 0, 0, 39, '203'),
	(243, 1, 0, -50378, 205, 0, 0, 39, '204'),
	(243, 1, 0, -50378, 206, 0, 0, 39, '205'),
	(243, 1, 0, -50378, 207, 0, 0, 39, '206'),
	(243, 1, 0, -50378, 208, 0, 0, 39, '207'),
	(243, 1, 0, -50378, 209, 0, 0, 39, '208'),
	(243, 1, 0, -50378, 210, 0, 0, 39, '209'),
	(243, 1, 0, -50378, 211, 0, 0, 39, '210'),
	(243, 1, 0, -50378, 212, 0, 0, 39, '211'),
	(243, 1, 0, -50378, 213, 0, 0, 39, '212'),
	(243, 1, 0, -50378, 214, 0, 0, 39, '213'),
	(243, 1, 0, -50378, 215, 0, 0, 39, '214'),
	(243, 1, 0, -50378, 216, 0, 0, 39, '215'),
	(243, 1, 0, -50378, 217, 0, 0, 39, '216'),
	(243, 1, 0, -50378, 218, 0, 0, 39, '217'),
	(243, 1, 0, -50378, 219, 0, 0, 39, '218'),
	(243, 1, 0, -50378, 220, 0, 0, 39, '219'),
	(243, 1, 0, -50378, 221, 0, 0, 39, '220'),
	(243, 1, 0, -50378, 222, 0, 0, 39, '221'),
	(243, 1, 0, -50378, 223, 0, 0, 39, '222'),
	(243, 1, 0, -50378, 224, 0, 0, 39, '223'),
	(243, 1, 0, -50378, 225, 0, 0, 39, '224'),
	(243, 1, 0, -50378, 226, 0, 0, 39, '225'),
	(243, 1, 0, -50378, 227, 0, 0, 39, '226'),
	(243, 1, 0, -50378, 228, 0, 0, 39, '227'),
	(243, 1, 0, -50378, 229, 0, 0, 39, '228'),
	(243, 1, 0, -50378, 230, 0, 0, 39, '229'),
	(243, 1, 0, -50378, 231, 0, 0, 39, '230'),
	(243, 1, 0, -50378, 232, 0, 0, 39, '231'),
	(243, 1, 0, -50378, 233, 0, 0, 39, '232'),
	(243, 1, 0, -50378, 234, 0, 0, 39, '233'),
	(243, 1, 0, -50378, 235, 0, 0, 39, '234'),
	(243, 1, 0, -50378, 236, 0, 0, 39, '235'),
	(243, 1, 0, -50378, 237, 0, 0, 39, '236'),
	(243, 1, 0, -50378, 238, 0, 0, 39, '237'),
	(243, 1, 0, -50378, 239, 0, 0, 39, '238'),
	(243, 1, 0, -50378, 240, 0, 0, 39, '239'),
	(243, 1, 0, -50378, 241, 0, 0, 39, '240'),
	(243, 1, 0, -50378, 242, 0, 0, 39, '241'),
	(243, 1, 0, -50378, 243, 0, 0, 39, '242'),
	(243, 1, 0, -50378, 244, 0, 0, 39, '243'),
	(243, 1, 0, -50378, 245, 0, 0, 39, '244'),
	(243, 1, 0, -50378, 246, 0, 0, 39, '245'),
	(243, 1, 0, -50378, 247, 0, 0, 39, '246'),
	(243, 1, 0, -50378, 248, 0, 0, 39, '247'),
	(243, 1, 0, -50378, 249, 0, 0, 39, '248'),
	(243, 1, 0, -50378, 250, 0, 0, 39, '249'),
	(243, 1, 0, -50378, 251, 0, 0, 39, '250'),
	(243, 1, 0, -50378, 252, 0, 0, 39, '251'),
	(243, 1, 0, -50378, 253, 0, 0, 39, '252'),
	(243, 1, 0, -50378, 254, 0, 0, 39, '253'),
	(243, 1, 0, -50378, 255, 0, 0, 39, '254'),
	(243, 1, 0, -50378, 256, 0, 0, 39, '255'),
	(243, 1, 0, -50378, 257, 0, 0, 39, '256'),
	(243, 1, 0, -50378, 258, 0, 0, 39, '257'),
	(243, 1, 0, -50378, 259, 0, 0, 39, '258'),
	(243, 1, 0, -50378, 260, 0, 0, 39, '259'),
	(243, 1, 0, -50378, 261, 0, 0, 39, '260'),
	(243, 1, 0, -50378, 262, 0, 0, 39, '261'),
	(243, 1, 0, -50378, 263, 0, 0, 39, '262'),
	(243, 1, 0, -50378, 264, 0, 0, 39, '263'),
	(243, 1, 0, -50378, 265, 0, 0, 39, '264'),
	(243, 1, 0, -50378, 266, 0, 0, 39, '265'),
	(243, 1, 0, -50378, 267, 0, 0, 39, '266'),
	(243, 1, 0, -50378, 268, 0, 0, 39, '267'),
	(243, 1, 0, -50378, 269, 0, 0, 39, '268'),
	(243, 1, 0, -50378, 270, 0, 0, 39, '269'),
	(243, 1, 0, -50378, 271, 0, 0, 39, '270'),
	(243, 1, 0, -50378, 272, 0, 0, 39, '271'),
	(243, 1, 0, -50378, 273, 0, 0, 39, '272'),
	(243, 1, 0, -50378, 274, 0, 0, 39, '273'),
	(243, 1, 0, -50378, 275, 0, 0, 39, '274'),
	(243, 1, 0, -50378, 276, 0, 0, 39, '275'),
	(243, 1, 0, -50378, 277, 0, 0, 39, '276'),
	(243, 1, 0, -50378, 278, 0, 0, 39, '277'),
	(243, 1, 0, -50378, 279, 0, 0, 39, '278'),
	(243, 1, 0, -50378, 280, 0, 0, 39, '279'),
	(243, 1, 0, -50378, 281, 0, 0, 39, '280'),
	(243, 1, 0, -50378, 282, 0, 0, 39, '281'),
	(243, 1, 0, -50378, 283, 0, 0, 39, '282'),
	(243, 1, 0, -50378, 284, 0, 0, 39, '283'),
	(243, 1, 0, -50378, 285, 0, 0, 39, '284'),
	(243, 1, 0, -50378, 286, 0, 0, 39, '285'),
	(243, 1, 0, -50378, 287, 0, 0, 39, '286'),
	(243, 1, 0, -50378, 288, 0, 0, 39, '287'),
	(243, 1, 0, -50378, 289, 0, 0, 39, '288'),
	(243, 1, 0, -50378, 290, 0, 0, 39, '289'),
	(243, 1, 0, -50378, 291, 0, 0, 39, '290'),
	(243, 1, 0, -50378, 292, 0, 0, 39, '291'),
	(243, 1, 0, -50378, 293, 0, 0, 39, '292'),
	(243, 1, 0, -50378, 294, 0, 0, 39, '293'),
	(243, 1, 0, -50378, 295, 0, 0, 39, '294'),
	(243, 1, 0, -50378, 296, 0, 0, 39, '295'),
	(243, 1, 0, -50378, 297, 0, 0, 39, '296'),
	(243, 1, 0, -50378, 298, 0, 0, 39, '297'),
	(243, 1, 0, -50378, 299, 0, 0, 39, '298'),
	(243, 1, 0, -50378, 300, 0, 0, 39, '299'),
	(243, 1, 0, -50378, 301, 0, 0, 39, '300'),
	(243, 1, 0, -50378, 302, 0, 0, 39, '301'),
	(243, 1, 0, -50378, 303, 0, 0, 39, '302'),
	(243, 1, 0, -50378, 304, 0, 0, 39, '303'),
	(243, 1, 0, -50378, 305, 0, 0, 39, '304'),
	(243, 1, 0, -50378, 306, 0, 0, 39, '305'),
	(243, 1, 0, -50378, 307, 0, 0, 39, '306'),
	(243, 1, 0, -50378, 308, 0, 0, 39, '307'),
	(243, 1, 0, -50378, 309, 0, 0, 39, '308'),
	(243, 1, 0, -50378, 310, 0, 0, 39, '309'),
	(243, 1, 0, -50378, 311, 0, 0, 39, '310'),
	(243, 1, 0, -50378, 312, 0, 0, 39, '311'),
	(243, 1, 0, -50378, 313, 0, 0, 39, '312'),
	(243, 1, 0, -50378, 314, 0, 0, 39, '313'),
	(243, 1, 0, -50378, 315, 0, 0, 39, '314'),
	(243, 1, 0, -50378, 316, 0, 0, 39, '315'),
	(243, 1, 0, -50378, 317, 0, 0, 39, '316'),
	(243, 1, 0, -50378, 318, 0, 0, 39, '317'),
	(243, 1, 0, -50378, 319, 0, 0, 39, '318'),
	(243, 1, 0, -50378, 320, 0, 0, 39, '319'),
	(243, 1, 0, -50378, 321, 0, 0, 39, '320'),
	(243, 1, 0, -50378, 322, 0, 0, 39, '321'),
	(243, 1, 0, -50378, 323, 0, 0, 39, '322'),
	(243, 1, 0, -50378, 324, 0, 0, 39, '323'),
	(243, 1, 0, -50378, 325, 0, 0, 39, '324'),
	(243, 1, 0, -50378, 326, 0, 0, 39, '325'),
	(243, 1, 0, -50378, 327, 0, 0, 39, '326'),
	(243, 1, 0, -50378, 328, 0, 0, 39, '327'),
	(243, 1, 0, -50378, 329, 0, 0, 39, '328'),
	(243, 1, 0, -50378, 330, 0, 0, 39, '329'),
	(243, 1, 0, -50378, 331, 0, 0, 39, '330'),
	(243, 1, 0, -50378, 332, 0, 0, 39, '331'),
	(243, 1, 0, -50378, 333, 0, 0, 39, '332'),
	(243, 1, 0, -50378, 334, 0, 0, 39, '333'),
	(243, 1, 0, -50378, 335, 0, 0, 39, '334'),
	(243, 1, 0, -50378, 336, 0, 0, 39, '335'),
	(243, 1, 0, -50378, 337, 0, 0, 39, '336'),
	(243, 1, 0, -50378, 338, 0, 0, 39, '337'),
	(243, 1, 0, -50378, 339, 0, 0, 39, '338'),
	(243, 1, 0, -50378, 340, 0, 0, 39, '339'),
	(243, 1, 0, -50378, 341, 0, 0, 39, '340'),
	(243, 1, 0, -50378, 342, 0, 0, 39, '341'),
	(243, 1, 0, -50378, 343, 0, 0, 39, '342'),
	(243, 1, 0, -50378, 344, 0, 0, 39, '343'),
	(243, 1, 0, -50378, 345, 0, 0, 39, '344'),
	(243, 1, 0, -50378, 346, 0, 0, 39, '345'),
	(243, 1, 0, -50378, 347, 0, 0, 39, '346'),
	(243, 1, 0, -50378, 348, 0, 0, 39, '347'),
	(243, 1, 0, -50378, 349, 0, 0, 39, '348'),
	(243, 1, 0, -50378, 350, 0, 0, 39, '349'),
	(243, 1, 0, -50378, 351, 0, 0, 39, '350'),
	(243, 1, 0, -50378, 352, 0, 0, 39, '351'),
	(243, 1, 0, -50378, 353, 0, 0, 39, '352'),
	(243, 1, 0, -50378, 354, 0, 0, 39, '353'),
	(243, 1, 0, -50378, 355, 0, 0, 39, '354'),
	(243, 1, 0, -50378, 356, 0, 0, 39, '355'),
	(243, 1, 0, -50378, 357, 0, 0, 39, '356'),
	(243, 1, 0, -50378, 358, 0, 0, 39, '357'),
	(243, 1, 0, -50378, 359, 0, 0, 39, '358'),
	(243, 1, 0, -50378, 360, 0, 0, 39, '359'),
	(243, 1, 0, -50378, 361, 0, 0, 39, '360'),
	(243, 1, 0, -50378, 362, 0, 0, 39, '361'),
	(243, 1, 0, -50378, 363, 0, 0, 39, '362'),
	(243, 1, 0, -50378, 364, 0, 0, 39, '363'),
	(243, 1, 0, -50378, 365, 0, 0, 39, '364'),
	(243, 1, 0, -50378, 366, 0, 0, 39, '365'),
	(243, 1, 0, -50378, 367, 0, 0, 39, '366'),
	(243, 1, 0, -50378, 368, 0, 0, 39, '367'),
	(243, 1, 0, -50378, 369, 0, 0, 39, '368'),
	(243, 1, 0, -50378, 370, 0, 0, 39, '369'),
	(243, 1, 0, -50378, 371, 0, 0, 39, '370'),
	(243, 1, 0, -50378, 372, 0, 0, 39, '371'),
	(243, 1, 0, -50378, 373, 0, 0, 39, '372'),
	(243, 1, 0, -50378, 374, 0, 0, 39, '373'),
	(243, 1, 0, -50378, 375, 0, 0, 39, '374'),
	(243, 1, 0, -50378, 376, 0, 0, 39, '375'),
	(243, 1, 0, -50378, 377, 0, 0, 39, '376'),
	(243, 1, 0, -50378, 378, 0, 0, 39, '377'),
	(243, 1, 0, -50378, 379, 0, 0, 39, '378'),
	(243, 1, 0, -50378, 380, 0, 0, 39, '379'),
	(243, 1, 0, -50378, 381, 0, 0, 39, '380'),
	(243, 1, 0, -50378, 382, 0, 0, 39, '381'),
	(243, 1, 0, -50378, 383, 0, 0, 39, '382'),
	(243, 1, 0, -50378, 384, 0, 0, 39, '383'),
	(243, 1, 0, -50378, 385, 0, 0, 39, '384'),
	(243, 1, 0, -50378, 386, 0, 0, 39, '385'),
	(243, 1, 0, -50378, 387, 0, 0, 39, '386'),
	(243, 1, 0, -50378, 388, 0, 0, 39, '387'),
	(243, 1, 0, -50378, 389, 0, 0, 39, '388'),
	(243, 1, 0, -50378, 390, 0, 0, 39, '389'),
	(243, 1, 0, -50378, 391, 0, 0, 39, '390'),
	(243, 1, 0, -50378, 392, 0, 0, 39, '391'),
	(243, 1, 0, -50378, 393, 0, 0, 39, '392'),
	(243, 1, 0, -50378, 394, 0, 0, 39, '393'),
	(243, 1, 0, -50378, 395, 0, 0, 39, '394'),
	(243, 1, 0, -50378, 396, 0, 0, 39, '395'),
	(243, 1, 0, -50378, 397, 0, 0, 39, '396'),
	(243, 1, 0, -50378, 398, 0, 0, 39, '397'),
	(243, 1, 0, -50378, 399, 0, 0, 39, '398'),
	(243, 1, 0, -50378, 400, 0, 0, 39, '399'),
	(243, 1, 0, -50378, 401, 0, 0, 39, '400'),
	(243, 1, 0, -50378, 402, 0, 0, 39, '401'),
	(243, 1, 0, -50378, 403, 0, 0, 39, '402'),
	(243, 1, 0, -50378, 404, 0, 0, 39, '403'),
	(243, 1, 0, -50378, 405, 0, 0, 39, '404'),
	(243, 1, 0, -50378, 406, 0, 0, 39, '405'),
	(243, 1, 0, -50378, 407, 0, 0, 39, '406'),
	(243, 1, 0, -50378, 408, 0, 0, 39, '407'),
	(243, 1, 0, -50378, 409, 0, 0, 39, '408'),
	(243, 1, 0, -50378, 410, 0, 0, 39, '409'),
	(243, 1, 0, -50378, 411, 0, 0, 39, '410'),
	(243, 1, 0, -50378, 412, 0, 0, 39, '411'),
	(243, 1, 0, -50378, 413, 0, 0, 39, '412'),
	(243, 1, 0, -50378, 414, 0, 0, 39, '413'),
	(243, 1, 0, -50378, 415, 0, 0, 39, '414'),
	(243, 1, 0, -50378, 416, 0, 0, 39, '415'),
	(243, 1, 0, -50378, 417, 0, 0, 39, '416'),
	(243, 1, 0, -50378, 418, 0, 0, 39, '417'),
	(243, 1, 0, -50378, 419, 0, 0, 39, '418'),
	(243, 1, 0, -50378, 420, 0, 0, 39, '419'),
	(243, 1, 0, -50378, 421, 0, 0, 39, '420'),
	(243, 1, 0, -50378, 422, 0, 0, 39, '421'),
	(243, 1, 0, -50378, 423, 0, 0, 39, '422'),
	(243, 1, 0, -50378, 424, 0, 0, 39, '423'),
	(243, 1, 0, -50378, 425, 0, 0, 39, '424'),
	(243, 1, 0, -50378, 426, 0, 0, 39, '425'),
	(243, 1, 0, -50378, 427, 0, 0, 39, '426'),
	(243, 1, 0, -50378, 428, 0, 0, 39, '427'),
	(243, 1, 0, -50378, 429, 0, 0, 39, '428'),
	(243, 1, 0, -50378, 430, 0, 0, 39, '429'),
	(243, 1, 0, -50378, 431, 0, 0, 39, '430'),
	(243, 1, 0, -50378, 432, 0, 0, 39, '431'),
	(243, 1, 0, -50378, 433, 0, 0, 39, '432'),
	(243, 1, 0, -50378, 434, 0, 0, 39, '433'),
	(243, 1, 0, -50378, 435, 0, 0, 39, '434'),
	(243, 1, 0, -50378, 436, 0, 0, 39, '435'),
	(243, 1, 0, -50378, 437, 0, 0, 39, '436'),
	(243, 1, 0, -50378, 438, 0, 0, 39, '437'),
	(243, 1, 0, -50378, 439, 0, 0, 39, '438'),
	(243, 1, 0, -50378, 440, 0, 0, 39, '439'),
	(243, 1, 0, -50378, 441, 0, 0, 39, '440'),
	(243, 1, 0, -50378, 442, 0, 0, 39, '441'),
	(243, 1, 0, -50378, 443, 0, 0, 39, '442'),
	(243, 1, 0, -50378, 444, 0, 0, 39, '443'),
	(243, 1, 0, -50378, 445, 0, 0, 39, '444'),
	(243, 1, 0, -50378, 446, 0, 0, 39, '445'),
	(243, 1, 0, -50378, 447, 0, 0, 39, '446'),
	(243, 1, 0, -50378, 448, 0, 0, 39, '447'),
	(243, 1, 0, -50378, 449, 0, 0, 39, '448'),
	(243, 1, 0, -50378, 450, 0, 0, 39, '449'),
	(243, 1, 0, -50378, 451, 0, 0, 39, '450'),
	(243, 1, 0, -50378, 452, 0, 0, 39, '451'),
	(243, 1, 0, -50378, 453, 0, 0, 39, '452'),
	(243, 1, 0, -50378, 454, 0, 0, 39, '453'),
	(243, 1, 0, -50378, 455, 0, 0, 39, '454'),
	(243, 1, 0, -50378, 456, 0, 0, 39, '455'),
	(243, 1, 0, -50378, 457, 0, 0, 39, '456'),
	(243, 1, 0, -50378, 458, 0, 0, 39, '457'),
	(243, 1, 0, -50378, 459, 0, 0, 39, '458'),
	(243, 1, 0, -50378, 460, 0, 0, 39, '459'),
	(243, 1, 0, -50378, 461, 0, 0, 39, '460'),
	(243, 1, 0, -50378, 462, 0, 0, 39, '461'),
	(243, 1, 0, -50378, 463, 0, 0, 39, '462'),
	(243, 1, 0, -50378, 464, 0, 0, 39, '463'),
	(243, 1, 0, -50378, 465, 0, 0, 39, '464'),
	(243, 1, 0, -50378, 466, 0, 0, 39, '465'),
	(243, 1, 0, -50378, 467, 0, 0, 39, '466'),
	(243, 1, 0, -50378, 468, 0, 0, 39, '467'),
	(243, 1, 0, -50378, 469, 0, 0, 39, '468'),
	(243, 1, 0, -50378, 470, 0, 0, 39, '469'),
	(243, 1, 0, -50378, 471, 0, 0, 39, '470'),
	(243, 1, 0, -50378, 472, 0, 0, 39, '471'),
	(243, 1, 0, -50378, 473, 0, 0, 39, '472'),
	(243, 1, 0, -50378, 474, 0, 0, 39, '473'),
	(243, 1, 0, -50378, 475, 0, 0, 39, '474'),
	(243, 1, 0, -50378, 476, 0, 0, 39, '475'),
	(243, 1, 0, -50378, 477, 0, 0, 39, '476'),
	(243, 1, 0, -50378, 478, 0, 0, 39, '477'),
	(243, 1, 0, -50378, 479, 0, 0, 39, '478'),
	(243, 1, 0, -50378, 480, 0, 0, 39, '479'),
	(243, 1, 0, -50378, 481, 0, 0, 39, '480'),
	(243, 1, 0, -50378, 482, 0, 0, 39, '481'),
	(243, 1, 0, -50378, 483, 0, 0, 39, '482'),
	(243, 1, 0, -50378, 484, 0, 0, 39, '483'),
	(243, 1, 0, -50378, 485, 0, 0, 39, '484'),
	(243, 1, 0, -50378, 486, 0, 0, 39, '485'),
	(243, 1, 0, -50378, 487, 0, 0, 39, '486'),
	(243, 1, 0, -50378, 488, 0, 0, 39, '487'),
	(243, 1, 0, -50378, 489, 0, 0, 39, '488'),
	(243, 1, 0, -50378, 490, 0, 0, 39, '489'),
	(243, 1, 0, -50378, 491, 0, 0, 39, '490'),
	(243, 1, 0, -50378, 492, 0, 0, 39, '491'),
	(243, 1, 0, -50378, 493, 0, 0, 39, '492'),
	(243, 1, 0, -50378, 494, 0, 0, 39, '493'),
	(243, 1, 0, -50378, 495, 0, 0, 39, '494'),
	(243, 1, 0, -50378, 496, 0, 0, 39, '495'),
	(243, 1, 0, -50378, 497, 0, 0, 39, '496'),
	(243, 1, 0, -50378, 498, 0, 0, 39, '497'),
	(243, 1, 0, -50378, 499, 0, 0, 39, '498'),
	(243, 1, 0, -50378, 500, 0, 0, 39, '499'),
	(243, 1, 0, -50378, 501, 0, 0, 39, '500'),
	(243, 1, 0, -50378, 502, 0, 0, 39, '501'),
	(243, 1, 0, -50378, 503, 0, 0, 39, '502'),
	(243, 1, 0, -50378, 504, 0, 0, 39, '503'),
	(243, 1, 0, -50378, 505, 0, 0, 39, '504'),
	(243, 1, 0, -50378, 506, 0, 0, 39, '505'),
	(243, 1, 0, -50378, 507, 0, 0, 39, '506'),
	(243, 1, 0, -50378, 508, 0, 0, 39, '507'),
	(243, 1, 0, -50378, 509, 0, 0, 39, '508'),
	(243, 1, 0, -50378, 510, 0, 0, 39, '509'),
	(243, 1, 0, -50378, 511, 0, 0, 39, '510'),
	(243, 1, 0, -50378, 512, 0, 0, 39, '511'),
	(243, 1, 0, -50378, 513, 0, 0, 39, '512'),
	(243, 1, 0, -50378, 514, 0, 0, 39, '513'),
	(243, 1, 0, -50378, 515, 0, 0, 39, '514'),
	(243, 1, 0, -50378, 516, 0, 0, 39, '515'),
	(243, 1, 0, -50378, 517, 0, 0, 39, '516'),
	(243, 1, 0, -50378, 518, 0, 0, 39, '517'),
	(243, 1, 0, -50378, 519, 0, 0, 39, '518'),
	(243, 1, 0, -50378, 520, 0, 0, 39, '519'),
	(243, 1, 0, -50378, 521, 0, 0, 39, '520'),
	(243, 1, 0, -50378, 522, 0, 0, 39, '521'),
	(243, 1, 0, -50378, 523, 0, 0, 39, '522'),
	(243, 1, 0, -50378, 524, 0, 0, 39, '523'),
	(243, 1, 0, -50378, 525, 0, 0, 39, '524'),
	(243, 1, 0, -50378, 526, 0, 0, 39, '525'),
	(243, 1, 0, -50378, 527, 0, 0, 39, '526'),
	(243, 1, 0, -50378, 528, 0, 0, 39, '527'),
	(243, 1, 0, -50378, 529, 0, 0, 39, '528'),
	(243, 1, 0, -50378, 530, 0, 0, 39, '529'),
	(243, 1, 0, -50378, 531, 0, 0, 39, '530'),
	(243, 1, 0, -50378, 532, 0, 0, 39, '531'),
	(243, 1, 0, -50378, 533, 0, 0, 39, '532'),
	(243, 1, 0, -50378, 534, 0, 0, 39, '533'),
	(243, 1, 0, -50378, 535, 0, 0, 39, '534'),
	(243, 1, 0, -50378, 536, 0, 0, 39, '535'),
	(243, 1, 0, -50378, 537, 0, 0, 39, '536'),
	(243, 1, 0, -50378, 538, 0, 0, 39, '537'),
	(243, 1, 0, -50378, 539, 0, 0, 39, '538'),
	(243, 1, 0, -50378, 540, 0, 0, 39, '539'),
	(243, 1, 0, -50378, 541, 0, 0, 39, '540'),
	(243, 1, 0, -50378, 542, 0, 0, 39, '541'),
	(243, 1, 0, -50378, 543, 0, 0, 39, '542'),
	(243, 1, 0, -50378, 544, 0, 0, 39, '543'),
	(243, 1, 0, -50378, 545, 0, 0, 39, '544'),
	(243, 1, 0, -50378, 546, 0, 0, 39, '545'),
	(243, 1, 0, -50378, 547, 0, 0, 39, '546'),
	(243, 1, 0, -50378, 548, 0, 0, 39, '547'),
	(243, 1, 0, -50378, 549, 0, 0, 39, '548'),
	(243, 1, 0, -50378, 550, 0, 0, 39, '549'),
	(243, 1, 0, -50378, 551, 0, 0, 39, '550'),
	(243, 1, 0, -50378, 552, 0, 0, 39, '551'),
	(243, 1, 0, -50378, 553, 0, 0, 39, '552'),
	(243, 1, 0, -50378, 554, 0, 0, 39, '553'),
	(243, 1, 0, -50378, 555, 0, 0, 39, '554'),
	(243, 1, 0, -50378, 556, 0, 0, 39, '555'),
	(243, 1, 0, -50378, 557, 0, 0, 39, '556'),
	(243, 1, 0, -50378, 558, 0, 0, 39, '557'),
	(243, 1, 0, -50378, 559, 0, 0, 39, '558'),
	(243, 1, 0, -50378, 560, 0, 0, 39, '559'),
	(243, 1, 0, -50378, 561, 0, 0, 39, '560'),
	(243, 1, 0, -50378, 562, 0, 0, 39, '561'),
	(243, 1, 0, -50378, 563, 0, 0, 39, '562'),
	(243, 1, 0, -50378, 564, 0, 0, 39, '563'),
	(243, 1, 0, -50378, 565, 0, 0, 39, '564'),
	(243, 1, 0, -50378, 566, 0, 0, 39, '565'),
	(243, 1, 0, -50378, 567, 0, 0, 39, '566'),
	(243, 1, 0, -50378, 568, 0, 0, 39, '567'),
	(243, 1, 0, -50378, 569, 0, 0, 39, '568'),
	(243, 1, 0, -50378, 570, 0, 0, 39, '569'),
	(243, 1, 0, -50378, 571, 0, 0, 39, '570'),
	(243, 1, 0, -50378, 572, 0, 0, 39, '571'),
	(243, 1, 0, -50378, 573, 0, 0, 39, '572'),
	(243, 1, 0, -50378, 574, 0, 0, 39, '573'),
	(243, 1, 0, -50378, 575, 0, 0, 39, '574'),
	(243, 1, 0, -50378, 576, 0, 0, 39, '575'),
	(243, 1, 0, -50378, 577, 0, 0, 39, '576'),
	(243, 1, 0, -50378, 578, 0, 0, 39, '577'),
	(243, 1, 0, -50378, 579, 0, 0, 39, '578'),
	(243, 1, 0, -50378, 580, 0, 0, 39, '579'),
	(243, 1, 0, -50378, 581, 0, 0, 39, '580'),
	(243, 1, 0, -50378, 582, 0, 0, 39, '581'),
	(243, 1, 0, -50378, 583, 0, 0, 39, '582'),
	(243, 1, 0, -50378, 584, 0, 0, 39, '583'),
	(243, 1, 0, -50378, 585, 0, 0, 39, '584'),
	(243, 1, 0, -50378, 586, 0, 0, 39, '585'),
	(243, 1, 0, -50378, 587, 0, 0, 39, '586'),
	(243, 1, 0, -50378, 588, 0, 0, 39, '587'),
	(243, 1, 0, -50378, 589, 0, 0, 39, '588'),
	(243, 1, 0, -50378, 590, 0, 0, 39, '589'),
	(243, 1, 0, -50378, 591, 0, 0, 39, '590'),
	(243, 1, 0, -50378, 592, 0, 0, 39, '591'),
	(243, 1, 0, -50378, 593, 0, 0, 39, '592'),
	(243, 1, 0, -50378, 594, 0, 0, 39, '593'),
	(243, 1, 0, -50378, 595, 0, 0, 39, '594'),
	(243, 1, 0, -50378, 596, 0, 0, 39, '595'),
	(243, 1, 0, -50378, 597, 0, 0, 39, '596'),
	(243, 1, 0, -50378, 598, 0, 0, 39, '597'),
	(243, 1, 0, -50378, 599, 0, 0, 39, '598'),
	(243, 1, 0, -50378, 600, 0, 0, 39, '599'),
	(243, 1, 0, -50378, 601, 0, 0, 39, '600'),
	(243, 1, 0, -50378, 602, 0, 0, 39, '601'),
	(243, 1, 0, -50378, 603, 0, 0, 39, '602'),
	(243, 1, 0, -50378, 604, 0, 0, 39, '603'),
	(243, 1, 0, -50378, 605, 0, 0, 39, '604'),
	(243, 1, 0, -50378, 606, 0, 0, 39, '605'),
	(243, 1, 0, -50378, 607, 0, 0, 39, '606'),
	(243, 1, 0, -50378, 608, 0, 0, 39, '607'),
	(243, 1, 0, -50378, 609, 0, 0, 39, '608'),
	(243, 1, 0, -50378, 610, 0, 0, 39, '609'),
	(243, 1, 0, -50378, 611, 0, 0, 39, '610'),
	(243, 1, 0, -50378, 612, 0, 0, 39, '611'),
	(243, 1, 0, -50378, 613, 0, 0, 39, '612'),
	(243, 1, 0, -50378, 614, 0, 0, 39, '613'),
	(243, 1, 0, -50378, 615, 0, 0, 39, '614'),
	(243, 1, 0, -50378, 616, 0, 0, 39, '615'),
	(243, 1, 0, -50378, 617, 0, 0, 39, '616'),
	(243, 1, 0, -50378, 618, 0, 0, 39, '617'),
	(243, 1, 0, -50378, 619, 0, 0, 39, '618'),
	(243, 1, 0, -50378, 620, 0, 0, 39, '619'),
	(243, 1, 0, -50378, 621, 0, 0, 39, '620'),
	(243, 1, 0, -50378, 622, 0, 0, 39, '621'),
	(243, 1, 0, -50378, 623, 0, 0, 39, '622'),
	(243, 1, 0, -50378, 624, 0, 0, 39, '623'),
	(243, 1, 0, -50378, 625, 0, 0, 39, '624'),
	(243, 1, 0, -50378, 626, 0, 0, 39, '625'),
	(243, 1, 0, -50378, 627, 0, 0, 39, '626'),
	(243, 1, 0, -50378, 628, 0, 0, 39, '627'),
	(243, 1, 0, -50378, 629, 0, 0, 39, '628'),
	(243, 1, 0, -50378, 630, 0, 0, 39, '629'),
	(243, 1, 0, -50378, 631, 0, 0, 39, '630'),
	(243, 1, 0, -50378, 632, 0, 0, 39, '631'),
	(243, 1, 0, -50378, 633, 0, 0, 39, '632'),
	(243, 1, 0, -50378, 634, 0, 0, 39, '633'),
	(243, 1, 0, -50378, 635, 0, 0, 39, '634'),
	(243, 1, 0, -50378, 636, 0, 0, 39, '635'),
	(243, 1, 0, -50378, 637, 0, 0, 39, '636'),
	(243, 1, 0, -50378, 638, 0, 0, 39, '637'),
	(243, 1, 0, -50378, 639, 0, 0, 39, '638'),
	(243, 1, 0, -50378, 640, 0, 0, 39, '639'),
	(243, 1, 0, -50378, 641, 0, 0, 39, '640'),
	(243, 1, 0, -50378, 642, 0, 0, 39, '641'),
	(243, 1, 0, -50378, 643, 0, 0, 39, '642'),
	(243, 1, 0, -50378, 644, 0, 0, 39, '643'),
	(243, 1, 0, -50378, 645, 0, 0, 39, '644'),
	(243, 1, 0, -50378, 646, 0, 0, 39, '645'),
	(243, 1, 0, -50378, 647, 0, 0, 39, '646'),
	(243, 1, 0, -50378, 648, 0, 0, 39, '647'),
	(243, 1, 0, -50378, 649, 0, 0, 39, '648'),
	(243, 1, 0, -50378, 650, 0, 0, 39, '649'),
	(243, 1, 0, -50378, 651, 0, 0, 39, '650'),
	(243, 1, 0, -50378, 652, 0, 0, 39, '651'),
	(243, 1, 0, -50378, 653, 0, 0, 39, '652'),
	(243, 1, 0, -50378, 654, 0, 0, 39, '653'),
	(243, 1, 0, -50378, 655, 0, 0, 39, '654'),
	(243, 1, 0, -50378, 656, 0, 0, 39, '655'),
	(243, 1, 0, -50378, 657, 0, 0, 39, '656'),
	(243, 1, 0, -50378, 658, 0, 0, 39, '657'),
	(243, 1, 0, -50378, 659, 0, 0, 39, '658'),
	(243, 1, 0, -50378, 660, 0, 0, 39, '659'),
	(243, 1, 0, -50378, 661, 0, 0, 39, '660'),
	(243, 1, 0, -50378, 662, 0, 0, 39, '661'),
	(243, 1, 0, -50378, 663, 0, 0, 39, '662'),
	(243, 1, 0, -50378, 664, 0, 0, 39, '663'),
	(243, 1, 0, -50378, 665, 0, 0, 39, '664'),
	(243, 1, 0, -50378, 666, 0, 0, 39, '665'),
	(243, 1, 0, -50378, 667, 0, 0, 39, '666'),
	(243, 1, 0, -50378, 668, 0, 0, 39, '667'),
	(243, 1, 0, -50378, 669, 0, 0, 39, '668'),
	(243, 1, 0, -50378, 670, 0, 0, 39, '669'),
	(243, 1, 0, -50378, 671, 0, 0, 39, '670'),
	(243, 1, 0, -50378, 672, 0, 0, 39, '671'),
	(243, 1, 0, -50378, 673, 0, 0, 39, '672'),
	(243, 1, 0, -50378, 674, 0, 0, 39, '673'),
	(243, 1, 0, -50378, 675, 0, 0, 39, '674'),
	(243, 1, 0, -50378, 676, 0, 0, 39, '675'),
	(243, 1, 0, -50378, 677, 0, 0, 39, '676'),
	(243, 1, 0, -50378, 678, 0, 0, 39, '677'),
	(243, 1, 0, -50378, 679, 0, 0, 39, '678'),
	(243, 1, 0, -50378, 680, 0, 0, 39, '679'),
	(243, 1, 0, -50378, 681, 0, 0, 39, '680'),
	(243, 1, 0, -50378, 682, 0, 0, 39, '681'),
	(243, 1, 0, -50378, 683, 0, 0, 39, '682'),
	(243, 1, 0, -50378, 684, 0, 0, 39, '683'),
	(243, 1, 0, -50378, 685, 0, 0, 39, '684'),
	(243, 1, 0, -50378, 686, 0, 0, 39, '685'),
	(243, 1, 0, -50378, 687, 0, 0, 39, '686'),
	(243, 1, 0, -50378, 688, 0, 0, 39, '687'),
	(243, 1, 0, -50378, 689, 0, 0, 39, '688'),
	(243, 1, 0, -50378, 690, 0, 0, 39, '689'),
	(243, 1, 0, -50378, 691, 0, 0, 39, '690'),
	(243, 1, 0, -50378, 692, 0, 0, 39, '691'),
	(243, 1, 0, -50378, 693, 0, 0, 39, '692'),
	(243, 1, 0, -50378, 694, 0, 0, 39, '693'),
	(243, 1, 0, -50378, 695, 0, 0, 39, '694'),
	(243, 1, 0, -50378, 696, 0, 0, 39, '695'),
	(243, 1, 0, -50378, 697, 0, 0, 39, '696'),
	(243, 1, 0, -50378, 698, 0, 0, 39, '697'),
	(243, 1, 0, -50378, 699, 0, 0, 39, '698'),
	(243, 1, 0, -50378, 700, 0, 0, 39, '699'),
	(243, 1, 0, -50378, 701, 0, 0, 39, '700'),
	(243, 1, 0, -50378, 702, 0, 0, 39, '701'),
	(243, 1, 0, -50378, 703, 0, 0, 39, '702'),
	(243, 1, 0, -50378, 704, 0, 0, 39, '703'),
	(243, 1, 0, -50378, 705, 0, 0, 39, '704'),
	(243, 1, 0, -50378, 706, 0, 0, 39, '705'),
	(243, 1, 0, -50378, 707, 0, 0, 39, '706'),
	(243, 1, 0, -50378, 708, 0, 0, 39, '707'),
	(243, 1, 0, -50378, 709, 0, 0, 39, '708'),
	(243, 1, 0, -50378, 710, 0, 0, 39, '709'),
	(243, 1, 0, -50378, 711, 0, 0, 39, '710'),
	(243, 1, 0, -50378, 712, 0, 0, 39, '711'),
	(243, 1, 0, -50378, 713, 0, 0, 39, '712'),
	(243, 1, 0, -50378, 714, 0, 0, 39, '713'),
	(243, 1, 0, -50378, 715, 0, 0, 39, '714'),
	(243, 1, 0, -50378, 716, 0, 0, 39, '715'),
	(243, 1, 0, -50378, 717, 0, 0, 39, '716'),
	(243, 1, 0, -50378, 718, 0, 0, 39, '717'),
	(243, 1, 0, -50378, 719, 0, 0, 39, '718'),
	(243, 1, 0, -50378, 720, 0, 0, 39, '719'),
	(243, 1, 0, -50378, 721, 0, 0, 39, '720'),
	(243, 1, 0, -50378, 722, 0, 0, 39, '721'),
	(243, 1, 0, -50378, 723, 0, 0, 39, '722'),
	(243, 1, 0, -50378, 724, 0, 0, 39, '723'),
	(243, 1, 0, -50378, 725, 0, 0, 39, '724'),
	(243, 1, 0, -50378, 726, 0, 0, 39, '725'),
	(243, 1, 0, -50378, 727, 0, 0, 39, '726'),
	(243, 1, 0, -50378, 728, 0, 0, 39, '727'),
	(243, 1, 0, -50378, 729, 0, 0, 39, '728'),
	(243, 1, 0, -50378, 730, 0, 0, 39, '729'),
	(243, 1, 0, -50378, 731, 0, 0, 39, '730'),
	(243, 1, 0, -50378, 732, 0, 0, 39, '731'),
	(243, 1, 0, -50378, 733, 0, 0, 39, '732'),
	(243, 1, 0, -50378, 734, 0, 0, 39, '733'),
	(243, 1, 0, -50378, 735, 0, 0, 39, '734'),
	(243, 1, 0, -50378, 736, 0, 0, 39, '735'),
	(243, 1, 0, -50378, 737, 0, 0, 39, '736'),
	(243, 1, 0, -50378, 738, 0, 0, 39, '737'),
	(243, 1, 0, -50378, 739, 0, 0, 39, '738'),
	(243, 1, 0, -50378, 740, 0, 0, 39, '739'),
	(243, 1, 0, -50378, 741, 0, 0, 39, '740'),
	(243, 1, 0, -50378, 742, 0, 0, 39, '741'),
	(243, 1, 0, -50378, 743, 0, 0, 39, '742'),
	(243, 1, 0, -50378, 744, 0, 0, 39, '743'),
	(243, 1, 0, -50378, 745, 0, 0, 39, '744'),
	(243, 1, 0, -50378, 746, 0, 0, 39, '745'),
	(243, 1, 0, -50378, 747, 0, 0, 39, '746'),
	(243, 1, 0, -50378, 748, 0, 0, 39, '747'),
	(243, 1, 0, -50378, 749, 0, 0, 39, '748'),
	(243, 1, 0, -50378, 750, 0, 0, 39, '749'),
	(243, 1, 0, -50378, 751, 0, 0, 39, '750'),
	(243, 1, 0, -50378, 752, 0, 0, 39, '751'),
	(243, 1, 0, -50378, 753, 0, 0, 39, '752'),
	(243, 1, 0, -50378, 754, 0, 0, 39, '753'),
	(243, 1, 0, -50378, 755, 0, 0, 39, '754'),
	(243, 1, 0, -50378, 756, 0, 0, 39, '755'),
	(243, 1, 0, -50378, 757, 0, 0, 39, '756'),
	(243, 1, 0, -50378, 758, 0, 0, 39, '757'),
	(243, 1, 0, -50378, 759, 0, 0, 39, '758'),
	(243, 1, 0, -50378, 760, 0, 0, 39, '759'),
	(243, 1, 0, -50378, 761, 0, 0, 39, '760'),
	(243, 1, 0, -50378, 762, 0, 0, 39, '761'),
	(243, 1, 0, -50378, 763, 0, 0, 39, '762'),
	(243, 1, 0, -50378, 764, 0, 0, 39, '763'),
	(243, 1, 0, -50378, 765, 0, 0, 39, '764'),
	(243, 1, 0, -50378, 766, 0, 0, 39, '765'),
	(243, 1, 0, -50378, 767, 0, 0, 39, '766'),
	(243, 1, 0, -50378, 768, 0, 0, 39, '767'),
	(243, 1, 0, -50378, 769, 0, 0, 39, '768'),
	(243, 1, 0, -50378, 770, 0, 0, 39, '769'),
	(243, 1, 0, -50378, 771, 0, 0, 39, '770'),
	(243, 1, 0, -50378, 772, 0, 0, 39, '771'),
	(243, 1, 0, -50378, 773, 0, 0, 39, '772'),
	(243, 1, 0, -50378, 774, 0, 0, 39, '773'),
	(243, 1, 0, -50378, 775, 0, 0, 39, '774'),
	(243, 1, 0, -50378, 776, 0, 0, 39, '775'),
	(243, 1, 0, -50378, 777, 0, 0, 39, '776'),
	(243, 1, 0, -50378, 778, 0, 0, 39, '777'),
	(243, 1, 0, -50378, 779, 0, 0, 39, '778'),
	(243, 1, 0, -50378, 780, 0, 0, 39, '779'),
	(243, 1, 0, -50378, 781, 0, 0, 39, '780'),
	(243, 1, 0, -50378, 782, 0, 0, 39, '781'),
	(243, 1, 0, -50378, 783, 0, 0, 39, '782'),
	(243, 1, 0, -50378, 784, 0, 0, 39, '783'),
	(243, 1, 0, -50378, 785, 0, 0, 39, '784'),
	(243, 1, 0, -50378, 786, 0, 0, 39, '785'),
	(243, 1, 0, -50378, 787, 0, 0, 39, '786'),
	(243, 1, 0, -50378, 788, 0, 0, 39, '787'),
	(243, 1, 0, -50378, 789, 0, 0, 39, '788'),
	(243, 1, 0, -50378, 790, 0, 0, 39, '789'),
	(243, 1, 0, -50378, 791, 0, 0, 39, '790'),
	(243, 1, 0, -50378, 792, 0, 0, 39, '791'),
	(243, 1, 0, -50378, 793, 0, 0, 39, '792'),
	(243, 1, 0, -50378, 794, 0, 0, 39, '793'),
	(243, 1, 0, -50378, 795, 0, 0, 39, '794'),
	(243, 1, 0, -50378, 796, 0, 0, 39, '795'),
	(243, 1, 0, -50378, 797, 0, 0, 39, '796'),
	(243, 1, 0, -50378, 798, 0, 0, 39, '797'),
	(243, 1, 0, -50378, 799, 0, 0, 39, '798'),
	(243, 1, 0, -50378, 800, 0, 0, 39, '799'),
	(243, 1, 0, -50378, 801, 0, 0, 39, '800'),
	(243, 1, 0, -50378, 802, 0, 0, 39, '801'),
	(243, 1, 0, -50378, 803, 0, 0, 39, '802'),
	(243, 1, 0, -50378, 804, 0, 0, 39, '803'),
	(243, 1, 0, -50378, 805, 0, 0, 39, '804'),
	(243, 1, 0, -50378, 806, 0, 0, 39, '805'),
	(243, 1, 0, -50378, 807, 0, 0, 39, '806'),
	(243, 1, 0, -50378, 808, 0, 0, 39, '807'),
	(243, 1, 0, -50378, 809, 0, 0, 39, '808'),
	(243, 1, 0, -50378, 810, 0, 0, 39, '809'),
	(243, 1, 0, -50378, 811, 0, 0, 39, '810'),
	(243, 1, 0, -50378, 812, 0, 0, 39, '811'),
	(243, 1, 0, -50378, 813, 0, 0, 39, '812'),
	(243, 1, 0, -50378, 814, 0, 0, 39, '813'),
	(243, 1, 0, -50378, 815, 0, 0, 39, '814'),
	(243, 1, 0, -50378, 816, 0, 0, 39, '815'),
	(243, 1, 0, -50378, 817, 0, 0, 39, '816'),
	(243, 1, 0, -50378, 818, 0, 0, 39, '817'),
	(243, 1, 0, -50378, 819, 0, 0, 39, '818'),
	(243, 1, 0, -50378, 820, 0, 0, 39, '819'),
	(243, 1, 0, -50378, 821, 0, 0, 39, '820'),
	(243, 1, 0, -50378, 822, 0, 0, 39, '821'),
	(243, 1, 0, -50378, 823, 0, 0, 39, '822'),
	(243, 1, 0, -50378, 824, 0, 0, 39, '823'),
	(243, 1, 0, -50378, 825, 0, 0, 39, '824'),
	(243, 1, 0, -50378, 826, 0, 0, 39, '825'),
	(243, 1, 0, -50378, 827, 0, 0, 39, '826'),
	(243, 1, 0, -50378, 828, 0, 0, 39, '827'),
	(243, 1, 0, -50378, 829, 0, 0, 39, '828'),
	(243, 1, 0, -50378, 830, 0, 0, 39, '829'),
	(243, 1, 0, -50378, 831, 0, 0, 39, '830'),
	(243, 1, 0, -50378, 832, 0, 0, 39, '831'),
	(243, 1, 0, -50378, 833, 0, 0, 39, '832'),
	(243, 1, 0, -50378, 834, 0, 0, 39, '833'),
	(243, 1, 0, -50378, 835, 0, 0, 39, '834'),
	(243, 1, 0, -50378, 836, 0, 0, 39, '835'),
	(243, 1, 0, -50378, 837, 0, 0, 39, '836'),
	(243, 1, 0, -50378, 838, 0, 0, 39, '837'),
	(243, 1, 0, -50378, 839, 0, 0, 39, '838'),
	(243, 1, 0, -50378, 840, 0, 0, 39, '839'),
	(243, 1, 0, -50378, 841, 0, 0, 39, '840'),
	(243, 1, 0, -50378, 842, 0, 0, 39, '841'),
	(243, 1, 0, -50378, 843, 0, 0, 39, '842'),
	(243, 1, 0, -50378, 844, 0, 0, 39, '843'),
	(243, 1, 0, -50378, 845, 0, 0, 39, '844'),
	(243, 1, 0, -50378, 846, 0, 0, 39, '845'),
	(243, 1, 0, -50378, 847, 0, 0, 39, '846'),
	(243, 1, 0, -50378, 848, 0, 0, 39, '847'),
	(243, 1, 0, -50378, 849, 0, 0, 39, '848'),
	(243, 1, 0, -50378, 850, 0, 0, 39, '849'),
	(243, 1, 0, -50378, 851, 0, 0, 39, '850'),
	(243, 1, 0, -50378, 852, 0, 0, 39, '851'),
	(243, 1, 0, -50378, 853, 0, 0, 39, '852'),
	(243, 1, 0, -50378, 854, 0, 0, 39, '853'),
	(243, 1, 0, -50378, 855, 0, 0, 39, '854'),
	(243, 1, 0, -50378, 856, 0, 0, 39, '855'),
	(243, 1, 0, -50378, 857, 0, 0, 39, '856'),
	(243, 1, 0, -50378, 858, 0, 0, 39, '857'),
	(243, 1, 0, -50378, 859, 0, 0, 39, '858'),
	(243, 1, 0, -50378, 860, 0, 0, 39, '859'),
	(243, 1, 0, -50378, 861, 0, 0, 39, '860'),
	(243, 1, 0, -50378, 862, 0, 0, 39, '861'),
	(243, 1, 0, -50378, 863, 0, 0, 39, '862'),
	(243, 1, 0, -50378, 864, 0, 0, 39, '863'),
	(243, 1, 0, -50378, 865, 0, 0, 39, '864'),
	(243, 1, 0, -50378, 866, 0, 0, 39, '865'),
	(243, 1, 0, -50378, 867, 0, 0, 39, '866'),
	(243, 1, 0, -50378, 868, 0, 0, 39, '867'),
	(243, 1, 0, -50378, 869, 0, 0, 39, '868'),
	(243, 1, 0, -50378, 870, 0, 0, 39, '869'),
	(243, 1, 0, -50378, 871, 0, 0, 39, '870'),
	(243, 1, 0, -50378, 872, 0, 0, 39, '871'),
	(243, 1, 0, -50378, 873, 0, 0, 39, '872'),
	(243, 1, 0, -50378, 874, 0, 0, 39, '873'),
	(243, 1, 0, -50378, 875, 0, 0, 39, '874'),
	(243, 1, 0, -50378, 876, 0, 0, 39, '875'),
	(243, 1, 0, -50378, 877, 0, 0, 39, '876'),
	(243, 1, 0, -50378, 878, 0, 0, 39, '877'),
	(243, 1, 0, -50378, 879, 0, 0, 39, '878'),
	(243, 1, 0, -50378, 880, 0, 0, 39, '879'),
	(243, 1, 0, -50378, 881, 0, 0, 39, '880'),
	(243, 1, 0, -50378, 882, 0, 0, 39, '881'),
	(243, 1, 0, -50378, 883, 0, 0, 39, '882'),
	(243, 1, 0, -50378, 884, 0, 0, 39, '883'),
	(243, 1, 0, -50378, 885, 0, 0, 39, '884'),
	(243, 1, 0, -50378, 886, 0, 0, 39, '885'),
	(243, 1, 0, -50378, 887, 0, 0, 39, '886'),
	(243, 1, 0, -50378, 888, 0, 0, 39, '887'),
	(243, 1, 0, -50378, 889, 0, 0, 39, '888'),
	(243, 1, 0, -50378, 890, 0, 0, 39, '889'),
	(243, 1, 0, -50378, 891, 0, 0, 39, '890'),
	(243, 1, 0, -50378, 892, 0, 0, 39, '891'),
	(243, 1, 0, -50378, 893, 0, 0, 39, '892'),
	(243, 1, 0, -50378, 894, 0, 0, 39, '893'),
	(243, 1, 0, -50378, 895, 0, 0, 39, '894'),
	(243, 1, 0, -50378, 896, 0, 0, 39, '895'),
	(243, 1, 0, -50378, 897, 0, 0, 39, '896'),
	(243, 1, 0, -50378, 898, 0, 0, 39, '897'),
	(243, 1, 0, -50378, 899, 0, 0, 39, '898'),
	(243, 1, 0, -50378, 900, 0, 0, 39, '899'),
	(243, 1, 0, -50378, 901, 0, 0, 39, '900'),
	(243, 1, 0, -50378, 902, 0, 0, 39, '901'),
	(243, 1, 0, -50378, 903, 0, 0, 39, '902'),
	(243, 1, 0, -50378, 904, 0, 0, 39, '903'),
	(243, 1, 0, -50378, 905, 0, 0, 39, '904'),
	(243, 1, 0, -50378, 906, 0, 0, 39, '905'),
	(243, 1, 0, -50378, 907, 0, 0, 39, '906'),
	(243, 1, 0, -50378, 908, 0, 0, 39, '907'),
	(243, 1, 0, -50378, 909, 0, 0, 39, '908'),
	(243, 1, 0, -50378, 910, 0, 0, 39, '909'),
	(243, 1, 0, -50378, 911, 0, 0, 39, '910'),
	(243, 1, 0, -50378, 912, 0, 0, 39, '911'),
	(243, 1, 0, -50378, 913, 0, 0, 39, '912'),
	(243, 1, 0, -50378, 914, 0, 0, 39, '913'),
	(243, 1, 0, -50378, 915, 0, 0, 39, '914'),
	(243, 1, 0, -50378, 916, 0, 0, 39, '915'),
	(243, 1, 0, -50378, 917, 0, 0, 39, '916'),
	(243, 1, 0, -50378, 918, 0, 0, 39, '917'),
	(243, 1, 0, -50378, 919, 0, 0, 39, '918'),
	(243, 1, 0, -50378, 920, 0, 0, 39, '919'),
	(243, 1, 0, -50378, 921, 0, 0, 39, '920'),
	(243, 1, 0, -50378, 922, 0, 0, 39, '921'),
	(243, 1, 0, -50378, 923, 0, 0, 39, '922'),
	(243, 1, 0, -50378, 924, 0, 0, 39, '923'),
	(243, 1, 0, -50378, 925, 0, 0, 39, '924'),
	(243, 1, 0, -50378, 926, 0, 0, 39, '925'),
	(243, 1, 0, -50378, 927, 0, 0, 39, '926'),
	(243, 1, 0, -50378, 928, 0, 0, 39, '927'),
	(243, 1, 0, -50378, 929, 0, 0, 39, '928'),
	(243, 1, 0, -50378, 930, 0, 0, 39, '929'),
	(243, 1, 0, -50378, 931, 0, 0, 39, '930'),
	(243, 1, 0, -50378, 932, 0, 0, 39, '931'),
	(243, 1, 0, -50378, 933, 0, 0, 39, '932'),
	(243, 1, 0, -50378, 934, 0, 0, 39, '933'),
	(243, 1, 0, -50378, 935, 0, 0, 39, '934'),
	(243, 1, 0, -50378, 936, 0, 0, 39, '935'),
	(243, 1, 0, -50378, 937, 0, 0, 39, '936'),
	(243, 1, 0, -50378, 938, 0, 0, 39, '937'),
	(243, 1, 0, -50378, 939, 0, 0, 39, '938'),
	(243, 1, 0, -50378, 940, 0, 0, 39, '939'),
	(243, 1, 0, -50378, 941, 0, 0, 39, '940'),
	(243, 1, 0, -50378, 942, 0, 0, 39, '941'),
	(243, 1, 0, -50378, 943, 0, 0, 39, '942'),
	(243, 1, 0, -50378, 944, 0, 0, 39, '943'),
	(243, 1, 0, -50378, 945, 0, 0, 39, '944'),
	(243, 1, 0, -50378, 946, 0, 0, 39, '945'),
	(243, 1, 0, -50378, 947, 0, 0, 39, '946'),
	(243, 1, 0, -50378, 948, 0, 0, 39, '947'),
	(243, 1, 0, -50378, 949, 0, 0, 39, '948'),
	(243, 1, 0, -50378, 950, 0, 0, 39, '949'),
	(243, 1, 0, -50378, 951, 0, 0, 39, '950'),
	(243, 1, 0, -50378, 952, 0, 0, 39, '951'),
	(243, 1, 0, -50378, 953, 0, 0, 39, '952'),
	(243, 1, 0, -50378, 954, 0, 0, 39, '953'),
	(243, 1, 0, -50378, 955, 0, 0, 39, '954'),
	(243, 1, 0, -50378, 956, 0, 0, 39, '955'),
	(243, 1, 0, -50378, 957, 0, 0, 39, '956'),
	(243, 1, 0, -50378, 958, 0, 0, 39, '957'),
	(243, 1, 0, -50378, 959, 0, 0, 39, '958'),
	(243, 1, 0, -50378, 960, 0, 0, 39, '959'),
	(243, 1, 0, -50378, 961, 0, 0, 39, '960'),
	(243, 1, 0, -50378, 962, 0, 0, 39, '961'),
	(243, 1, 0, -50378, 963, 0, 0, 39, '962'),
	(243, 1, 0, -50378, 964, 0, 0, 39, '963'),
	(243, 1, 0, -50378, 965, 0, 0, 39, '964'),
	(243, 1, 0, -50378, 966, 0, 0, 39, '965'),
	(243, 1, 0, -50378, 967, 0, 0, 39, '966'),
	(243, 1, 0, -50378, 968, 0, 0, 39, '967'),
	(243, 1, 0, -50378, 969, 0, 0, 39, '968'),
	(243, 1, 0, -50378, 970, 0, 0, 39, '969'),
	(243, 1, 0, -50378, 971, 0, 0, 39, '970'),
	(243, 1, 0, -50378, 972, 0, 0, 39, '971'),
	(243, 1, 0, -50378, 973, 0, 0, 39, '972'),
	(243, 1, 0, -50378, 974, 0, 0, 39, '973'),
	(243, 1, 0, -50378, 975, 0, 0, 39, '974'),
	(243, 1, 0, -50378, 976, 0, 0, 39, '975'),
	(243, 1, 0, -50378, 977, 0, 0, 39, '976'),
	(243, 1, 0, -50378, 978, 0, 0, 39, '977'),
	(243, 1, 0, -50378, 979, 0, 0, 39, '978'),
	(243, 1, 0, -50378, 980, 0, 0, 39, '979'),
	(243, 1, 0, -50378, 981, 0, 0, 39, '980'),
	(243, 1, 0, -50378, 982, 0, 0, 39, '981'),
	(243, 1, 0, -50378, 983, 0, 0, 39, '982'),
	(243, 1, 0, -50378, 984, 0, 0, 39, '983'),
	(243, 1, 0, -50378, 985, 0, 0, 39, '984'),
	(243, 1, 0, -50378, 986, 0, 0, 39, '985'),
	(243, 1, 0, -50378, 987, 0, 0, 39, '986'),
	(243, 1, 0, -50378, 988, 0, 0, 39, '987'),
	(243, 1, 0, -50378, 989, 0, 0, 39, '988'),
	(243, 1, 0, -50378, 990, 0, 0, 39, '989'),
	(243, 1, 0, -50378, 991, 0, 0, 39, '990'),
	(243, 1, 0, -50378, 992, 0, 0, 39, '991'),
	(243, 1, 0, -50378, 993, 0, 0, 39, '992'),
	(243, 1, 0, -50378, 994, 0, 0, 39, '993'),
	(243, 1, 0, -50378, 995, 0, 0, 39, '994'),
	(243, 1, 0, -50378, 996, 0, 0, 39, '995'),
	(243, 1, 0, -50378, 997, 0, 0, 39, '996'),
	(243, 1, 0, -50378, 998, 0, 0, 39, '997'),
	(243, 1, 0, -50378, 999, 0, 0, 39, '998'),
	(243, 1, 0, -50378, 1000, 0, 0, 39, '999'),
	(243, 1, 0, -50378, 1001, 0, 0, 39, '1000'),
	(243, 1, 0, -50378, 1002, 0, 0, 39, '1001'),
	(243, 1, 0, -50378, 1003, 0, 0, 39, '1002'),
	(243, 1, 0, -50378, 1004, 0, 0, 39, '1003'),
	(243, 1, 0, -50378, 1005, 0, 0, 39, '1004'),
	(243, 1, 0, -50378, 1006, 0, 0, 39, '1005'),
	(243, 1, 0, -50378, 1007, 0, 0, 39, '1006'),
	(243, 1, 0, -50378, 1008, 0, 0, 39, '1007'),
	(243, 1, 0, -50378, 1009, 0, 0, 39, '1008'),
	(243, 1, 0, -50378, 1010, 0, 0, 39, '1009'),
	(243, 1, 0, -50378, 1011, 0, 0, 39, '1010'),
	(243, 1, 0, -50378, 1012, 0, 0, 39, '1011'),
	(243, 1, 0, -50378, 1013, 0, 0, 39, '1012'),
	(243, 1, 0, -50378, 1014, 0, 0, 39, '1013'),
	(243, 1, 0, -50378, 1015, 0, 0, 39, '1014'),
	(243, 1, 0, -50378, 1016, 0, 0, 39, '1015'),
	(243, 1, 0, -50378, 1017, 0, 0, 39, '1016'),
	(243, 1, 0, -50378, 1018, 0, 0, 39, '1017'),
	(243, 1, 0, -50378, 1019, 0, 0, 39, '1018'),
	(243, 1, 0, -50378, 1020, 0, 0, 39, '1019'),
	(243, 1, 0, -50378, 1021, 0, 0, 39, '1020'),
	(243, 1, 0, -50378, 1022, 0, 0, 39, '1021'),
	(243, 1, 0, -50378, 1023, 0, 0, 39, '1022'),
	(243, 1, 0, -50378, 1024, 0, 0, 39, '1023'),
	(243, 1, 0, -50378, 1025, 0, 0, 39, '1024'),
	(243, 1, 0, -50378, 1026, 0, 0, 39, '1025'),
	(243, 1, 0, -50378, 1027, 0, 0, 39, '1026'),
	(243, 1, 0, -50378, 1028, 0, 0, 39, '1027'),
	(243, 1, 0, -50378, 1029, 0, 0, 39, '1028'),
	(243, 1, 0, -50378, 1030, 0, 0, 39, '1029'),
	(243, 1, 0, -50378, 1031, 0, 0, 39, '1030'),
	(243, 1, 0, -50378, 1032, 0, 0, 39, '1031'),
	(243, 1, 0, -50378, 1033, 0, 0, 39, '1032'),
	(243, 1, 0, -50378, 1034, 0, 0, 39, '1033'),
	(243, 1, 0, -50378, 1035, 0, 0, 39, '1034'),
	(243, 1, 0, -50378, 1036, 0, 0, 39, '1035'),
	(243, 1, 0, -50378, 1037, 0, 0, 39, '1036'),
	(243, 1, 0, -50378, 1038, 0, 0, 39, '1037'),
	(243, 1, 0, -50378, 1039, 0, 0, 39, '1038'),
	(243, 1, 0, -50378, 1040, 0, 0, 39, '1039'),
	(243, 1, 0, -50378, 1041, 0, 0, 39, '1040'),
	(243, 1, 0, -50378, 1042, 0, 0, 39, '1041'),
	(243, 1, 0, -50378, 1043, 0, 0, 39, '1042'),
	(243, 1, 0, -50378, 1044, 0, 0, 39, '1043'),
	(243, 1, 0, -50378, 1045, 0, 0, 39, '1044'),
	(243, 1, 0, -50378, 1046, 0, 0, 39, '1045'),
	(243, 1, 0, -50378, 1047, 0, 0, 39, '1046'),
	(243, 1, 0, -50378, 1048, 0, 0, 39, '1047'),
	(243, 1, 0, -50378, 1049, 0, 0, 39, '1048'),
	(243, 1, 0, -50378, 1050, 0, 0, 39, '1049'),
	(243, 1, 0, -50378, 1051, 0, 0, 39, '1050'),
	(243, 1, 0, -50378, 1052, 0, 0, 39, '1051'),
	(243, 1, 0, -50378, 1053, 0, 0, 39, '1052'),
	(243, 1, 0, -50378, 1054, 0, 0, 39, '1053'),
	(243, 1, 0, -50378, 1055, 0, 0, 39, '1054'),
	(243, 1, 0, -50378, 1056, 0, 0, 39, '1055'),
	(243, 1, 0, -50378, 1057, 0, 0, 39, '1056'),
	(243, 1, 0, -50378, 1058, 0, 0, 39, '1057'),
	(243, 1, 0, -50378, 1059, 0, 0, 39, '1058'),
	(243, 1, 0, -50378, 1060, 0, 0, 39, '1059'),
	(243, 1, 0, -50378, 1061, 0, 0, 39, '1060'),
	(243, 1, 0, -50378, 1062, 0, 0, 39, '1061'),
	(243, 1, 0, -50378, 1063, 0, 0, 39, '1062'),
	(243, 1, 0, -50378, 1064, 0, 0, 39, '1063'),
	(243, 1, 0, -50378, 1065, 0, 0, 39, '1064'),
	(243, 1, 0, -50378, 1066, 0, 0, 39, '1065'),
	(243, 1, 0, -50378, 1067, 0, 0, 39, '1066'),
	(243, 1, 0, -50378, 1068, 0, 0, 39, '1067'),
	(243, 1, 0, -50378, 1069, 0, 0, 39, '1068'),
	(243, 1, 0, -50378, 1070, 0, 0, 39, '1069'),
	(243, 1, 0, -50378, 1071, 0, 0, 39, '1070'),
	(243, 1, 0, -50378, 1072, 0, 0, 39, '1071'),
	(243, 1, 0, -50378, 1073, 0, 0, 39, '1072'),
	(243, 1, 0, -50378, 1074, 0, 0, 39, '1073'),
	(243, 1, 0, -50378, 1075, 0, 0, 39, '1074'),
	(243, 1, 0, -50378, 1076, 0, 0, 39, '1075'),
	(243, 1, 0, -50378, 1077, 0, 0, 39, '1076'),
	(243, 1, 0, -50378, 1078, 0, 0, 39, '1077'),
	(243, 1, 0, -50378, 1079, 0, 0, 39, '1078'),
	(243, 1, 0, -50378, 1080, 0, 0, 39, '1079'),
	(243, 1, 0, -50378, 1081, 0, 0, 39, '1080'),
	(243, 1, 0, -50378, 1082, 0, 0, 39, '1081'),
	(243, 1, 0, -50378, 1083, 0, 0, 39, '1082'),
	(243, 1, 0, -50378, 1084, 0, 0, 39, '1083'),
	(243, 1, 0, -50378, 1085, 0, 0, 39, '1084'),
	(243, 1, 0, -50378, 1086, 0, 0, 39, '1085'),
	(243, 1, 0, -50378, 1087, 0, 0, 39, '1086'),
	(243, 1, 0, -50378, 1088, 0, 0, 39, '1087'),
	(243, 1, 0, -50378, 1089, 0, 0, 39, '1088'),
	(243, 1, 0, -50378, 1090, 0, 0, 39, '1089'),
	(243, 1, 0, -50378, 1091, 0, 0, 39, '1090'),
	(243, 1, 0, -50378, 1092, 0, 0, 39, '1091'),
	(243, 1, 0, -50378, 1093, 0, 0, 39, '1092'),
	(243, 1, 0, -50378, 1094, 0, 0, 39, '1093'),
	(243, 1, 0, -50378, 1095, 0, 0, 39, '1094'),
	(243, 1, 0, -50378, 1096, 0, 0, 39, '1095'),
	(243, 1, 0, -50378, 1097, 0, 0, 39, '1096'),
	(243, 1, 0, -50378, 1098, 0, 0, 39, '1097'),
	(243, 1, 0, -50378, 1099, 0, 0, 39, '1098'),
	(243, 1, 0, -50378, 1100, 0, 0, 39, '1099'),
	(243, 1, 0, -50378, 1101, 0, 0, 39, '1100'),
	(243, 1, 0, -50378, 1102, 0, 0, 39, '1101'),
	(243, 1, 0, -50378, 1103, 0, 0, 39, '1102'),
	(243, 1, 0, -50378, 1104, 0, 0, 39, '1103'),
	(243, 1, 0, -50378, 1105, 0, 0, 39, '1104'),
	(243, 1, 0, -50378, 1106, 0, 0, 39, '1105'),
	(243, 1, 0, -50378, 1107, 0, 0, 39, '1106'),
	(243, 1, 0, -50378, 1108, 0, 0, 39, '1107'),
	(243, 1, 0, -50378, 1109, 0, 0, 39, '1108'),
	(243, 1, 0, -50378, 1110, 0, 0, 39, '1109'),
	(243, 1, 0, -50378, 1111, 0, 0, 39, '1110'),
	(243, 1, 0, -50378, 1112, 0, 0, 39, '1111'),
	(243, 1, 0, -50378, 1113, 0, 0, 39, '1112'),
	(243, 1, 0, -50378, 1114, 0, 0, 39, '1113'),
	(243, 1, 0, -50378, 1115, 0, 0, 39, '1114'),
	(243, 1, 0, -50378, 1116, 0, 0, 39, '1115'),
	(243, 1, 0, -50378, 1117, 0, 0, 39, '1116'),
	(243, 1, 0, -50378, 1118, 0, 0, 39, '1117'),
	(243, 1, 0, -50378, 1119, 0, 0, 39, '1118'),
	(243, 1, 0, -50378, 1120, 0, 0, 39, '1119'),
	(243, 1, 0, -50378, 1121, 0, 0, 39, '1120'),
	(243, 1, 0, -50378, 1122, 0, 0, 39, '1121'),
	(243, 1, 0, -50378, 1123, 0, 0, 39, '1122'),
	(243, 1, 0, -50378, 1124, 0, 0, 39, '1123'),
	(243, 1, 0, -50378, 1125, 0, 0, 39, '1124'),
	(243, 1, 0, -50378, 1126, 0, 0, 39, '1125'),
	(243, 1, 0, -50378, 1127, 0, 0, 39, '1126'),
	(243, 1, 0, -50378, 1128, 0, 0, 39, '1127'),
	(243, 1, 0, -50378, 1129, 0, 0, 39, '1128'),
	(243, 1, 0, -50378, 1130, 0, 0, 39, '1129'),
	(243, 1, 0, -50378, 1131, 0, 0, 39, '1130'),
	(243, 1, 0, -50378, 1132, 0, 0, 39, '1131'),
	(243, 1, 0, -50378, 1133, 0, 0, 39, '1132'),
	(243, 1, 0, -50378, 1134, 0, 0, 39, '1133'),
	(243, 1, 0, -50378, 1135, 0, 0, 39, '1134'),
	(243, 1, 0, -50378, 1136, 0, 0, 39, '1135'),
	(243, 1, 0, -50378, 1137, 0, 0, 39, '1136'),
	(243, 1, 0, -50378, 1138, 0, 0, 39, '1137'),
	(243, 1, 0, -50378, 1139, 0, 0, 39, '1138'),
	(243, 1, 0, -50378, 1140, 0, 0, 39, '1139'),
	(243, 1, 0, -50378, 1141, 0, 0, 39, '1140'),
	(243, 1, 0, -50378, 1142, 0, 0, 39, '1141'),
	(243, 1, 0, -50378, 1143, 0, 0, 39, '1142'),
	(243, 1, 0, -50378, 1144, 0, 0, 39, '1143'),
	(243, 1, 0, -50378, 1145, 0, 0, 39, '1144'),
	(243, 1, 0, -50378, 1146, 0, 0, 39, '1145'),
	(243, 1, 0, -50378, 1147, 0, 0, 39, '1146'),
	(243, 1, 0, -50378, 1148, 0, 0, 39, '1147'),
	(243, 1, 0, -50378, 1149, 0, 0, 39, '1148'),
	(243, 1, 0, -50378, 1150, 0, 0, 39, '1149'),
	(243, 1, 0, -50378, 1151, 0, 0, 39, '1150'),
	(243, 1, 0, -50378, 1152, 0, 0, 39, '1151'),
	(243, 1, 0, -50378, 1153, 0, 0, 39, '1152'),
	(243, 1, 0, -50378, 1154, 0, 0, 39, '1153'),
	(243, 1, 0, -50378, 1155, 0, 0, 39, '1154'),
	(243, 1, 0, -50378, 1156, 0, 0, 39, '1155'),
	(243, 1, 0, -50378, 1157, 0, 0, 39, '1156'),
	(243, 1, 0, -50378, 1158, 0, 0, 39, '1157'),
	(243, 1, 0, -50378, 1159, 0, 0, 39, '1158'),
	(243, 1, 0, -50378, 1160, 0, 0, 39, '1159'),
	(243, 1, 0, -50378, 1161, 0, 0, 39, '1160'),
	(243, 1, 0, -50378, 1162, 0, 0, 39, '1161'),
	(243, 1, 0, -50378, 1163, 0, 0, 39, '1162'),
	(243, 1, 0, -50378, 1164, 0, 0, 39, '1163'),
	(243, 1, 0, -50378, 1165, 0, 0, 39, '1164'),
	(243, 1, 0, -50378, 1166, 0, 0, 39, '1165'),
	(243, 1, 0, -50378, 1167, 0, 0, 39, '1166'),
	(243, 1, 0, -50378, 1168, 0, 0, 39, '1167'),
	(243, 1, 0, -50378, 1169, 0, 0, 39, '1168'),
	(243, 1, 0, -50378, 1170, 0, 0, 39, '1169'),
	(243, 1, 0, -50378, 1171, 0, 0, 39, '1170'),
	(243, 1, 0, -50378, 1172, 0, 0, 39, '1171'),
	(243, 1, 0, -50378, 1173, 0, 0, 39, '1172'),
	(243, 1, 0, -50378, 1174, 0, 0, 39, '1173'),
	(243, 1, 0, -50378, 1175, 0, 0, 39, '1174'),
	(243, 1, 0, -50378, 1176, 0, 0, 39, '1175'),
	(243, 1, 0, -50378, 1177, 0, 0, 39, '1176'),
	(243, 1, 0, -50378, 1178, 0, 0, 39, '1177'),
	(243, 1, 0, -50378, 1179, 0, 0, 39, '1178'),
	(243, 1, 0, -50378, 1180, 0, 0, 39, '1179'),
	(243, 1, 0, -50378, 1181, 0, 0, 39, '1180'),
	(243, 1, 0, -50378, 1182, 0, 0, 39, '1181'),
	(243, 1, 0, -50378, 1183, 0, 0, 39, '1182'),
	(243, 1, 0, -50378, 1184, 0, 0, 39, '1183'),
	(243, 1, 0, -50378, 1185, 0, 0, 39, '1184'),
	(243, 1, 0, -50378, 1186, 0, 0, 39, '1185'),
	(243, 1, 0, -50378, 1187, 0, 0, 39, '1186'),
	(243, 1, 0, -50378, 1188, 0, 0, 39, '1187'),
	(243, 1, 0, -50378, 1189, 0, 0, 39, '1188'),
	(243, 1, 0, -50378, 1190, 0, 0, 39, '1189'),
	(243, 1, 0, -50378, 1191, 0, 0, 39, '1190'),
	(243, 1, 0, -50378, 1192, 0, 0, 39, '1191'),
	(243, 1, 0, -50378, 1193, 0, 0, 39, '1192'),
	(243, 1, 0, -50378, 1194, 0, 0, 39, '1193'),
	(243, 1, 0, -50378, 1195, 0, 0, 39, '1194'),
	(243, 1, 0, -50378, 1196, 0, 0, 39, '1195'),
	(243, 1, 0, -50378, 1197, 0, 0, 39, '1196'),
	(243, 1, 0, -50378, 1198, 0, 0, 39, '1197'),
	(243, 1, 0, -50378, 1199, 0, 0, 39, '1198'),
	(243, 1, 0, -50378, 1200, 0, 0, 39, '1199'),
	(243, 1, 0, -50378, 1201, 0, 0, 39, '1200'),
	(243, 1, 0, -50378, 1202, 0, 0, 39, '1201'),
	(243, 1, 0, -50378, 1203, 0, 0, 39, '1202'),
	(243, 1, 0, -50378, 1204, 0, 0, 39, '1203'),
	(243, 1, 0, -50378, 1205, 0, 0, 39, '1204'),
	(243, 1, 0, -50378, 1206, 0, 0, 39, '1205'),
	(243, 1, 0, -50378, 1207, 0, 0, 39, '1206'),
	(243, 1, 0, -50378, 1208, 0, 0, 39, '1207'),
	(243, 1, 0, -50378, 1209, 0, 0, 39, '1208'),
	(243, 1, 0, -50378, 1210, 0, 0, 39, '1209'),
	(243, 1, 0, -50378, 1211, 0, 0, 39, '1210'),
	(243, 1, 0, -50378, 1212, 0, 0, 39, '1211'),
	(243, 1, 0, -50378, 1213, 0, 0, 39, '1212'),
	(243, 1, 0, -50378, 1214, 0, 0, 39, '1213'),
	(243, 1, 0, -50378, 1215, 0, 0, 39, '1214'),
	(243, 1, 0, -50378, 1216, 0, 0, 39, '1215'),
	(243, 1, 0, -50378, 1217, 0, 0, 39, '1216'),
	(243, 1, 0, -50378, 1218, 0, 0, 39, '1217'),
	(243, 1, 0, -50378, 1219, 0, 0, 39, '1218'),
	(243, 1, 0, -50378, 1220, 0, 0, 39, '1219'),
	(243, 1, 0, -50378, 1221, 0, 0, 39, '1220'),
	(243, 1, 0, -50378, 1222, 0, 0, 39, '1221'),
	(243, 1, 0, -50378, 1223, 0, 0, 39, '1222'),
	(243, 1, 0, -50378, 1224, 0, 0, 39, '1223'),
	(243, 1, 0, -50378, 1225, 0, 0, 39, '1224'),
	(243, 1, 0, -50378, 1226, 0, 0, 39, '1225'),
	(243, 1, 0, -50378, 1227, 0, 0, 39, '1226'),
	(243, 1, 0, -50378, 1228, 0, 0, 39, '1227'),
	(243, 1, 0, -50378, 1229, 0, 0, 39, '1228'),
	(243, 1, 0, -50378, 1230, 0, 0, 39, '1229'),
	(243, 1, 0, -50378, 1231, 0, 0, 39, '1230'),
	(243, 1, 0, -50378, 1232, 0, 0, 39, '1231'),
	(243, 1, 0, -50378, 1233, 0, 0, 39, '1232'),
	(243, 1, 0, -50378, 1234, 0, 0, 39, '1233'),
	(243, 1, 0, -50378, 1235, 0, 0, 39, '1234'),
	(243, 1, 0, -50378, 1236, 0, 0, 39, '1235'),
	(243, 1, 0, -50378, 1237, 0, 0, 39, '1236'),
	(243, 1, 0, -50378, 1238, 0, 0, 39, '1237'),
	(243, 1, 0, -50378, 1239, 0, 0, 39, '1238'),
	(243, 1, 0, -50378, 1240, 0, 0, 39, '1239'),
	(243, 1, 0, -50378, 1241, 0, 0, 39, '1240'),
	(243, 1, 0, -50378, 1242, 0, 0, 39, '1241'),
	(243, 1, 0, -50378, 1243, 0, 0, 39, '1242'),
	(243, 1, 0, -50378, 1244, 0, 0, 39, '1243'),
	(243, 1, 0, -50378, 1245, 0, 0, 39, '1244'),
	(243, 1, 0, -50378, 1246, 0, 0, 39, '1245'),
	(243, 1, 0, -50378, 1247, 0, 0, 39, '1246'),
	(243, 1, 0, -50378, 1248, 0, 0, 39, '1247'),
	(243, 1, 0, -50378, 1249, 0, 0, 39, '1248'),
	(243, 1, 0, -50378, 1250, 0, 0, 39, '1249'),
	(243, 1, 0, -50378, 1251, 0, 0, 39, '1250'),
	(243, 1, 0, -50378, 1252, 0, 0, 39, '1251'),
	(243, 1, 0, -50378, 1253, 0, 0, 39, '1252'),
	(243, 1, 0, -50378, 1254, 0, 0, 39, '1253'),
	(243, 1, 0, -50378, 1255, 0, 0, 39, '1254'),
	(243, 1, 0, -50378, 1256, 0, 0, 39, '1255'),
	(243, 1, 0, -50378, 1257, 0, 0, 39, '1256'),
	(243, 1, 0, -50378, 1258, 0, 0, 39, '1257'),
	(243, 1, 0, -50378, 1259, 0, 0, 39, '1258'),
	(243, 1, 0, -50378, 1260, 0, 0, 39, '1259'),
	(243, 1, 0, -50378, 1261, 0, 0, 39, '1260'),
	(243, 1, 0, -50378, 1262, 0, 0, 39, '1261'),
	(243, 1, 0, -50378, 1263, 0, 0, 39, '1262'),
	(243, 1, 0, -50378, 1264, 0, 0, 39, '1263'),
	(243, 1, 0, -50378, 1265, 0, 0, 39, '1264'),
	(243, 1, 0, -50378, 1266, 0, 0, 39, '1265'),
	(243, 1, 0, -50378, 1267, 0, 0, 39, '1266'),
	(243, 1, 0, -50378, 1268, 0, 0, 39, '1267'),
	(243, 1, 0, -50378, 1269, 0, 0, 39, '1268'),
	(243, 1, 0, -50378, 1270, 0, 0, 39, '1269'),
	(243, 1, 0, -50378, 1271, 0, 0, 39, '1270'),
	(243, 1, 0, -50378, 1272, 0, 0, 39, '1271'),
	(243, 1, 0, -50378, 1273, 0, 0, 39, '1272'),
	(243, 1, 0, -50378, 1274, 0, 0, 39, '1273'),
	(243, 1, 0, -50378, 1275, 0, 0, 39, '1274'),
	(243, 1, 0, -50378, 1276, 0, 0, 39, '1275'),
	(243, 1, 0, -50378, 1277, 0, 0, 39, '1276'),
	(243, 1, 0, -50378, 1278, 0, 0, 39, '1277'),
	(243, 1, 0, -50378, 1279, 0, 0, 39, '1278'),
	(243, 1, 0, -50378, 1280, 0, 0, 39, '1279'),
	(243, 1, 0, -50378, 1281, 0, 0, 39, '1280'),
	(243, 1, 0, -50378, 1282, 0, 0, 39, '1281'),
	(243, 1, 0, -50378, 1283, 0, 0, 39, '1282'),
	(243, 1, 0, -50378, 1284, 0, 0, 39, '1283'),
	(243, 1, 0, -50378, 1285, 0, 0, 39, '1284'),
	(243, 1, 0, -50378, 1286, 0, 0, 39, '1285'),
	(243, 1, 0, -50378, 1287, 0, 0, 39, '1286'),
	(243, 1, 0, -50378, 1288, 0, 0, 39, '1287'),
	(243, 1, 0, -50378, 1289, 0, 0, 39, '1288'),
	(243, 1, 0, -50378, 1290, 0, 0, 39, '1289'),
	(243, 1, 0, -50378, 1291, 0, 0, 39, '1290'),
	(243, 1, 0, -50378, 1292, 0, 0, 39, '1291'),
	(243, 1, 0, -50378, 1293, 0, 0, 39, '1292'),
	(243, 1, 0, -50378, 1294, 0, 0, 39, '1293'),
	(243, 1, 0, -50378, 1295, 0, 0, 39, '1294'),
	(243, 1, 0, -50378, 1296, 0, 0, 39, '1295'),
	(243, 1, 0, -50378, 1297, 0, 0, 39, '1296'),
	(243, 1, 0, -50378, 1298, 0, 0, 39, '1297'),
	(243, 1, 0, -50378, 1299, 0, 0, 39, '1298'),
	(243, 1, 0, -50378, 1300, 0, 0, 39, '1299'),
	(243, 1, 0, -50378, 1301, 0, 0, 39, '1300'),
	(243, 1, 0, -50378, 1302, 0, 0, 39, '1301'),
	(243, 1, 0, -50378, 1303, 0, 0, 39, '1302'),
	(243, 1, 0, -50378, 1304, 0, 0, 39, '1303'),
	(243, 1, 0, -50378, 1305, 0, 0, 39, '1304'),
	(243, 1, 0, -50378, 1306, 0, 0, 39, '1305'),
	(243, 1, 0, -50378, 1307, 0, 0, 39, '1306'),
	(243, 1, 0, -50378, 1308, 0, 0, 39, '1307'),
	(243, 1, 0, -50378, 1309, 0, 0, 39, '1308'),
	(243, 1, 0, -50378, 1310, 0, 0, 39, '1309'),
	(243, 1, 0, -50378, 1311, 0, 0, 39, '1310'),
	(243, 1, 0, -50378, 1312, 0, 0, 39, '1311'),
	(243, 1, 0, -50378, 1313, 0, 0, 39, '1312'),
	(243, 1, 0, -50378, 1314, 0, 0, 39, '1313'),
	(243, 1, 0, -50378, 1315, 0, 0, 39, '1314'),
	(243, 1, 0, -50378, 1316, 0, 0, 39, '1315'),
	(243, 1, 0, -50378, 1317, 0, 0, 39, '1316'),
	(243, 1, 0, -50378, 1318, 0, 0, 39, '1317'),
	(243, 1, 0, -50378, 1319, 0, 0, 39, '1318'),
	(243, 1, 0, -50378, 1320, 0, 0, 39, '1319'),
	(243, 1, 0, -50378, 1321, 0, 0, 39, '1320'),
	(243, 1, 0, -50378, 1322, 0, 0, 39, '1321'),
	(243, 1, 0, -50378, 1323, 0, 0, 39, '1322'),
	(243, 1, 0, -50378, 1324, 0, 0, 39, '1323'),
	(243, 1, 0, -50378, 1325, 0, 0, 39, '1324'),
	(243, 1, 0, -50378, 1326, 0, 0, 39, '1325'),
	(243, 1, 0, -50378, 1327, 0, 0, 39, '1326'),
	(243, 1, 0, -50378, 1328, 0, 0, 39, '1327'),
	(243, 1, 0, -50378, 1329, 0, 0, 39, '1328'),
	(243, 1, 0, -50378, 1330, 0, 0, 39, '1329'),
	(243, 1, 0, -50378, 1331, 0, 0, 39, '1330'),
	(243, 1, 0, -50378, 1332, 0, 0, 39, '1331'),
	(243, 1, 0, -50378, 1333, 0, 0, 39, '1332'),
	(243, 1, 0, -50378, 1334, 0, 0, 39, '1333'),
	(243, 1, 0, -50378, 1335, 0, 0, 39, '1334'),
	(243, 1, 0, -50378, 1336, 0, 0, 39, '1335'),
	(243, 1, 0, -50378, 1337, 0, 0, 39, '1336'),
	(243, 1, 0, -50378, 1338, 0, 0, 39, '1337'),
	(243, 1, 0, -50378, 1339, 0, 0, 39, '1338'),
	(243, 1, 0, -50378, 1340, 0, 0, 39, '1339'),
	(243, 1, 0, -50378, 1341, 0, 0, 39, '1340'),
	(243, 1, 0, -50378, 1342, 0, 0, 39, '1341'),
	(243, 1, 0, -50378, 1343, 0, 0, 39, '1342'),
	(243, 1, 0, -50378, 1344, 0, 0, 39, '1343'),
	(243, 1, 0, -50378, 1345, 0, 0, 39, '1344'),
	(243, 1, 0, -50378, 1346, 0, 0, 39, '1345'),
	(243, 1, 0, -50378, 1347, 0, 0, 39, '1346'),
	(243, 1, 0, -50378, 1348, 0, 0, 39, '1347'),
	(243, 1, 0, -50378, 1349, 0, 0, 39, '1348'),
	(243, 1, 0, -50378, 1350, 0, 0, 39, '1349'),
	(243, 1, 0, -50378, 1351, 0, 0, 39, '1350'),
	(243, 1, 0, -50378, 1352, 0, 0, 39, '1351'),
	(243, 1, 0, -50378, 1353, 0, 0, 39, '1352'),
	(243, 1, 0, -50378, 1354, 0, 0, 39, '1353'),
	(243, 1, 0, -50378, 1355, 0, 0, 39, '1354'),
	(243, 1, 0, -50378, 1356, 0, 0, 39, '1355'),
	(243, 1, 0, -50378, 1357, 0, 0, 39, '1356'),
	(243, 1, 0, -50378, 1358, 0, 0, 39, '1357'),
	(243, 1, 0, -50378, 1359, 0, 0, 39, '1358'),
	(243, 1, 0, -50378, 1360, 0, 0, 39, '1359'),
	(243, 1, 0, -50378, 1361, 0, 0, 39, '1360'),
	(243, 1, 0, -50378, 1362, 0, 0, 39, '1361'),
	(243, 1, 0, -50378, 1363, 0, 0, 39, '1362'),
	(243, 1, 0, -50378, 1364, 0, 0, 39, '1363'),
	(243, 1, 0, -50378, 1365, 0, 0, 39, '1364'),
	(243, 1, 0, -50378, 1366, 0, 0, 39, '1365'),
	(243, 1, 0, -50378, 1367, 0, 0, 39, '1366'),
	(243, 1, 0, -50378, 1368, 0, 0, 39, '1367'),
	(243, 1, 0, -50378, 1369, 0, 0, 39, '1368'),
	(243, 1, 0, -50378, 1370, 0, 0, 39, '1369'),
	(243, 1, 0, -50378, 1371, 0, 0, 39, '1370'),
	(243, 1, 0, -50378, 1372, 0, 0, 39, '1371'),
	(243, 1, 0, -50378, 1373, 0, 0, 39, '1372'),
	(243, 1, 0, -50378, 1374, 0, 0, 39, '1373'),
	(243, 1, 0, -50378, 1375, 0, 0, 39, '1374'),
	(243, 1, 0, -50378, 1376, 0, 0, 39, '1375'),
	(243, 1, 0, -50378, 1377, 0, 0, 39, '1376'),
	(243, 1, 0, -50378, 1378, 0, 0, 39, '1377'),
	(243, 1, 0, -50378, 1379, 0, 0, 39, '1378'),
	(243, 1, 0, -50378, 1380, 0, 0, 39, '1379'),
	(243, 1, 0, -50378, 1381, 0, 0, 39, '1380'),
	(243, 1, 0, -50378, 1382, 0, 0, 39, '1381'),
	(243, 1, 0, -50378, 1383, 0, 0, 39, '1382'),
	(243, 1, 0, -50378, 1384, 0, 0, 39, '1383'),
	(243, 1, 0, -50378, 1385, 0, 0, 39, '1384'),
	(243, 1, 0, -50378, 1386, 0, 0, 39, '1385'),
	(243, 1, 0, -50378, 1387, 0, 0, 39, '1386'),
	(243, 1, 0, -50378, 1388, 0, 0, 39, '1387'),
	(243, 1, 0, -50378, 1389, 0, 0, 39, '1388'),
	(243, 1, 0, -50378, 1390, 0, 0, 39, '1389'),
	(243, 1, 0, -50378, 1391, 0, 0, 39, '1390'),
	(243, 1, 0, -50378, 1392, 0, 0, 39, '1391'),
	(243, 1, 0, -50378, 1393, 0, 0, 39, '1392'),
	(243, 1, 0, -50378, 1394, 0, 0, 39, '1393'),
	(243, 1, 0, -50378, 1395, 0, 0, 39, '1394'),
	(243, 1, 0, -50378, 1396, 0, 0, 39, '1395'),
	(243, 1, 0, -50378, 1397, 0, 0, 39, '1396'),
	(243, 1, 0, -50378, 1398, 0, 0, 39, '1397'),
	(243, 1, 0, -50378, 1399, 0, 0, 39, '1398'),
	(243, 1, 0, -50378, 1400, 0, 0, 39, '1399'),
	(243, 1, 0, -50378, 1401, 0, 0, 39, '1400'),
	(243, 1, 0, -50378, 1402, 0, 0, 39, '1401'),
	(243, 1, 0, -50378, 1403, 0, 0, 39, '1402'),
	(243, 1, 0, -50378, 1404, 0, 0, 39, '1403'),
	(243, 1, 0, -50378, 1405, 0, 0, 39, '1404'),
	(243, 1, 0, -50378, 1406, 0, 0, 39, '1405'),
	(243, 1, 0, -50378, 1407, 0, 0, 39, '1406'),
	(243, 1, 0, -50378, 1408, 0, 0, 39, '1407'),
	(243, 1, 0, -50378, 1409, 0, 0, 39, '1408'),
	(243, 1, 0, -50378, 1410, 0, 0, 39, '1409'),
	(243, 1, 0, -50378, 1411, 0, 0, 39, '1410'),
	(243, 1, 0, -50378, 1412, 0, 0, 39, '1411'),
	(243, 1, 0, -50378, 1413, 0, 0, 39, '1412'),
	(243, 1, 0, -50378, 1414, 0, 0, 39, '1413'),
	(243, 1, 0, -50378, 1415, 0, 0, 39, '1414'),
	(243, 1, 0, -50378, 1416, 0, 0, 39, '1415'),
	(243, 1, 0, -50378, 1417, 0, 0, 39, '1416'),
	(243, 1, 0, -50378, 1418, 0, 0, 39, '1417'),
	(243, 1, 0, -50378, 1419, 0, 0, 39, '1418'),
	(243, 1, 0, -50378, 1420, 0, 0, 39, '1419'),
	(243, 1, 0, -50378, 1421, 0, 0, 39, '1420'),
	(243, 1, 0, -50378, 1422, 0, 0, 39, '1421'),
	(243, 1, 0, -50378, 1423, 0, 0, 39, '1422'),
	(243, 1, 0, -50378, 1424, 0, 0, 39, '1423'),
	(243, 1, 0, -50378, 1425, 0, 0, 39, '1424'),
	(243, 1, 0, -50378, 1426, 0, 0, 39, '1425'),
	(243, 1, 0, -50378, 1427, 0, 0, 39, '1426'),
	(243, 1, 0, -50378, 1428, 0, 0, 39, '1427'),
	(243, 1, 0, -50378, 1429, 0, 0, 39, '1428'),
	(243, 1, 0, -50378, 1430, 0, 0, 39, '1429'),
	(243, 1, 0, -50378, 1431, 0, 0, 39, '1430'),
	(243, 1, 0, -50378, 1432, 0, 0, 39, '1431'),
	(243, 1, 0, -50378, 1433, 0, 0, 39, '1432'),
	(243, 1, 0, -50378, 1434, 0, 0, 39, '1433'),
	(243, 1, 0, -50378, 1435, 0, 0, 39, '1434'),
	(243, 1, 0, -50378, 1436, 0, 0, 39, '1435'),
	(243, 1, 0, -50378, 1437, 0, 0, 39, '1436'),
	(243, 1, 0, -50378, 1438, 0, 0, 39, '1437'),
	(243, 1, 0, -50378, 1439, 0, 0, 39, '1438'),
	(243, 1, 0, -50378, 1440, 0, 0, 39, '1439'),
	(243, 1, 0, -50378, 1441, 0, 0, 39, '1440'),
	(243, 1, 0, -50378, 1442, 0, 0, 39, '1441'),
	(243, 1, 0, -50378, 1443, 0, 0, 39, '1442'),
	(243, 1, 0, -50378, 1444, 0, 0, 39, '1443'),
	(243, 1, 0, -50378, 1445, 0, 0, 39, '1444'),
	(243, 1, 0, -50378, 1446, 0, 0, 39, '1445'),
	(243, 1, 0, -50378, 1447, 0, 0, 39, '1446'),
	(243, 1, 0, -50378, 1448, 0, 0, 39, '1447'),
	(243, 1, 0, -50378, 1449, 0, 0, 39, '1448'),
	(243, 1, 0, -50378, 1450, 0, 0, 39, '1449'),
	(243, 1, 0, -50378, 1451, 0, 0, 39, '1450'),
	(243, 1, 0, -50378, 1452, 0, 0, 39, '1451'),
	(243, 1, 0, -50378, 1453, 0, 0, 39, '1452'),
	(243, 1, 0, -50378, 1454, 0, 0, 39, '1453'),
	(243, 1, 0, -50378, 1455, 0, 0, 39, '1454'),
	(243, 1, 0, -50378, 1456, 0, 0, 39, '1455'),
	(243, 1, 0, -50378, 1457, 0, 0, 39, '1456'),
	(243, 1, 0, -50378, 1458, 0, 0, 39, '1457'),
	(243, 1, 0, -50378, 1459, 0, 0, 39, '1458'),
	(243, 1, 0, -50378, 1460, 0, 0, 39, '1459'),
	(243, 1, 0, -50378, 1461, 0, 0, 39, '1460'),
	(243, 1, 0, -50378, 1462, 0, 0, 39, '1461'),
	(243, 1, 0, -50378, 1463, 0, 0, 39, '1462'),
	(243, 1, 0, -50378, 1464, 0, 0, 39, '1463'),
	(243, 1, 0, -50378, 1465, 0, 0, 39, '1464'),
	(243, 1, 0, -50378, 1466, 0, 0, 39, '1465'),
	(243, 1, 0, -50378, 1467, 0, 0, 39, '1466'),
	(243, 1, 0, -50378, 1468, 0, 0, 39, '1467'),
	(243, 1, 0, -50378, 1469, 0, 0, 39, '1468'),
	(243, 1, 0, -50378, 1470, 0, 0, 39, '1469'),
	(243, 1, 0, -50378, 1471, 0, 0, 39, '1470'),
	(243, 1, 0, -50378, 1472, 0, 0, 39, '1471'),
	(243, 1, 0, -50378, 1473, 0, 0, 39, '1472'),
	(243, 1, 0, -50378, 1474, 0, 0, 39, '1473'),
	(243, 1, 0, -50378, 1475, 0, 0, 39, '1474'),
	(243, 1, 0, -50378, 1476, 0, 0, 39, '1475'),
	(243, 1, 0, -50378, 1477, 0, 0, 39, '1476'),
	(243, 1, 0, -50378, 1478, 0, 0, 39, '1477'),
	(243, 1, 0, -50378, 1479, 0, 0, 39, '1478'),
	(243, 1, 0, -50378, 1480, 0, 0, 39, '1479'),
	(243, 1, 0, -50378, 1481, 0, 0, 39, '1480'),
	(243, 1, 0, -50378, 1482, 0, 0, 39, '1481'),
	(243, 1, 0, -50378, 1483, 0, 0, 39, '1482'),
	(243, 1, 0, -50378, 1484, 0, 0, 39, '1483'),
	(243, 1, 0, -50378, 1485, 0, 0, 39, '1484'),
	(243, 1, 0, -50378, 1486, 0, 0, 39, '1485'),
	(243, 1, 0, -50378, 1487, 0, 0, 39, '1486'),
	(243, 1, 0, -50378, 1488, 0, 0, 39, '1487'),
	(243, 1, 0, -50378, 1489, 0, 0, 39, '1488'),
	(243, 1, 0, -50378, 1490, 0, 0, 39, '1489'),
	(243, 1, 0, -50378, 1491, 0, 0, 39, '1490'),
	(243, 1, 0, -50378, 1492, 0, 0, 39, '1491'),
	(243, 1, 0, -50378, 1493, 0, 0, 39, '1492'),
	(243, 1, 0, -50378, 1494, 0, 0, 39, '1493'),
	(243, 1, 0, -50378, 1495, 0, 0, 39, '1494'),
	(243, 1, 0, -50378, 1496, 0, 0, 39, '1495'),
	(243, 1, 0, -50378, 1497, 0, 0, 39, '1496'),
	(243, 1, 0, -50378, 1498, 0, 0, 39, '1497'),
	(243, 1, 0, -50378, 1499, 0, 0, 39, '1498'),
	(243, 1, 0, -50378, 1500, 0, 0, 39, '1499'),
	(243, 1, 0, -50378, 1501, 0, 0, 39, '1500'),
	(243, 1, 0, -50378, 1502, 0, 0, 39, '1501'),
	(243, 1, 0, -50378, 1503, 0, 0, 39, '1502'),
	(243, 1, 0, -50378, 1504, 0, 0, 39, '1503'),
	(243, 1, 0, -50378, 1505, 0, 0, 39, '1504'),
	(243, 1, 0, -50378, 1506, 0, 0, 39, '1505'),
	(243, 1, 0, -50378, 1507, 0, 0, 39, '1506'),
	(243, 1, 0, -50378, 1508, 0, 0, 39, '1507'),
	(243, 1, 0, -50378, 1509, 0, 0, 39, '1508'),
	(243, 1, 0, -50378, 1510, 0, 0, 39, '1509'),
	(243, 1, 0, -50378, 1511, 0, 0, 39, '1510'),
	(243, 1, 0, -50378, 1512, 0, 0, 39, '1511'),
	(243, 1, 0, -50378, 1513, 0, 0, 39, '1512'),
	(243, 1, 0, -50378, 1514, 0, 0, 39, '1513'),
	(243, 1, 0, -50378, 1515, 0, 0, 39, '1514'),
	(243, 1, 0, -50378, 1516, 0, 0, 39, '1515'),
	(243, 1, 0, -50378, 1517, 0, 0, 39, '1516'),
	(243, 1, 0, -50378, 1518, 0, 0, 39, '1517'),
	(243, 1, 0, -50378, 1519, 0, 0, 39, '1518'),
	(243, 1, 0, -50378, 1520, 0, 0, 39, '1519'),
	(243, 1, 0, -50378, 1521, 0, 0, 39, '1520'),
	(243, 1, 0, -50378, 1522, 0, 0, 39, '1521'),
	(243, 1, 0, -50378, 1523, 0, 0, 39, '1522'),
	(243, 1, 0, -50378, 1524, 0, 0, 39, '1523'),
	(243, 1, 0, -50378, 1525, 0, 0, 39, '1524'),
	(243, 1, 0, -50378, 1526, 0, 0, 39, '1525'),
	(243, 1, 0, -50378, 1527, 0, 0, 39, '1526'),
	(243, 1, 0, -50378, 1528, 0, 0, 39, '1527'),
	(243, 1, 0, -50378, 1529, 0, 0, 39, '1528'),
	(243, 1, 0, -50378, 1530, 0, 0, 39, '1529'),
	(243, 1, 0, -50378, 1531, 0, 0, 39, '1530'),
	(243, 1, 0, -50378, 1532, 0, 0, 39, '1531'),
	(243, 1, 0, -50378, 1533, 0, 0, 39, '1532'),
	(243, 1, 0, -50378, 1534, 0, 0, 39, '1533'),
	(243, 1, 0, -50378, 1535, 0, 0, 39, '1534'),
	(243, 1, 0, -50378, 1536, 0, 0, 39, '1535'),
	(243, 1, 0, -50378, 1537, 0, 0, 39, '1536'),
	(243, 1, 0, -50378, 1538, 0, 0, 39, '1537'),
	(243, 1, 0, -50378, 1539, 0, 0, 39, '1538'),
	(243, 1, 0, -50378, 1540, 0, 0, 39, '1539'),
	(243, 1, 0, -50378, 1541, 0, 0, 39, '1540'),
	(243, 1, 0, -50378, 1542, 0, 0, 39, '1541'),
	(243, 1, 0, -50378, 1543, 0, 0, 39, '1542'),
	(243, 1, 0, -50378, 1544, 0, 0, 39, '1543'),
	(243, 1, 0, -50378, 1545, 0, 0, 39, '1544'),
	(243, 1, 0, -50378, 1546, 0, 0, 39, '1545'),
	(243, 1, 0, -50378, 1547, 0, 0, 39, '1546'),
	(243, 1, 0, -50378, 1548, 0, 0, 39, '1547'),
	(243, 1, 0, -50378, 1549, 0, 0, 39, '1548'),
	(243, 1, 0, -50378, 1550, 0, 0, 39, '1549'),
	(243, 1, 0, -50378, 1551, 0, 0, 39, '1550'),
	(243, 1, 0, -50378, 1552, 0, 0, 39, '1551'),
	(243, 1, 0, -50378, 1553, 0, 0, 39, '1552'),
	(243, 1, 0, -50378, 1554, 0, 0, 39, '1553'),
	(243, 1, 0, -50378, 1555, 0, 0, 39, '1554'),
	(243, 1, 0, -50378, 1556, 0, 0, 39, '1555'),
	(243, 1, 0, -50378, 1557, 0, 0, 39, '1556'),
	(243, 1, 0, -50378, 1558, 0, 0, 39, '1557'),
	(243, 1, 0, -50378, 1559, 0, 0, 39, '1558'),
	(243, 1, 0, -50378, 1560, 0, 0, 39, '1559'),
	(243, 1, 0, -50378, 1561, 0, 0, 39, '1560'),
	(243, 1, 0, -50378, 1562, 0, 0, 39, '1561'),
	(243, 1, 0, -50378, 1563, 0, 0, 39, '1562'),
	(243, 1, 0, -50378, 1564, 0, 0, 39, '1563'),
	(243, 1, 0, -50378, 1565, 0, 0, 39, '1564'),
	(243, 1, 0, -50378, 1566, 0, 0, 39, '1565'),
	(243, 1, 0, -50378, 1567, 0, 0, 39, '1566'),
	(243, 1, 0, -50378, 1568, 0, 0, 39, '1567'),
	(243, 1, 0, -50378, 1569, 0, 0, 39, '1568'),
	(243, 1, 0, -50378, 1570, 0, 0, 39, '1569'),
	(243, 1, 0, -50378, 1571, 0, 0, 39, '1570'),
	(243, 1, 0, -50378, 1572, 0, 0, 39, '1571'),
	(243, 1, 0, -50378, 1573, 0, 0, 39, '1572'),
	(243, 1, 0, -50378, 1574, 0, 0, 39, '1573'),
	(243, 1, 0, -50378, 1575, 0, 0, 39, '1574'),
	(243, 1, 0, -50378, 1576, 0, 0, 39, '1575'),
	(243, 1, 0, -50378, 1577, 0, 0, 39, '1576'),
	(243, 1, 0, -50378, 1578, 0, 0, 39, '1577'),
	(243, 1, 0, -50378, 1579, 0, 0, 39, '1578'),
	(243, 1, 0, -50378, 1580, 0, 0, 39, '1579'),
	(243, 1, 0, -50378, 1581, 0, 0, 39, '1580'),
	(243, 1, 0, -50378, 1582, 0, 0, 39, '1581'),
	(243, 1, 0, -50378, 1583, 0, 0, 39, '1582'),
	(243, 1, 0, -50378, 1584, 0, 0, 39, '1583'),
	(243, 1, 0, -50378, 1585, 0, 0, 39, '1584'),
	(243, 1, 0, -50378, 1586, 0, 0, 39, '1585'),
	(243, 1, 0, -50378, 1587, 0, 0, 39, '1586'),
	(243, 1, 0, -50378, 1588, 0, 0, 39, '1587'),
	(243, 1, 0, -50378, 1589, 0, 0, 39, '1588'),
	(243, 1, 0, -50378, 1590, 0, 0, 39, '1589'),
	(243, 1, 0, -50378, 1591, 0, 0, 39, '1590'),
	(243, 1, 0, -50378, 1592, 0, 0, 39, '1591'),
	(243, 1, 0, -50378, 1593, 0, 0, 39, '1592'),
	(243, 1, 0, -50378, 1594, 0, 0, 39, '1593'),
	(243, 1, 0, -50378, 1595, 0, 0, 39, '1594'),
	(243, 1, 0, -50378, 1596, 0, 0, 39, '1595'),
	(243, 1, 0, -50378, 1597, 0, 0, 39, '1596'),
	(243, 1, 0, -50378, 1598, 0, 0, 39, '1597'),
	(243, 1, 0, -50378, 1599, 0, 0, 39, '1598'),
	(243, 1, 0, -50378, 1600, 0, 0, 39, '1599'),
	(243, 1, 0, -50378, 1601, 0, 0, 39, '1600'),
	(243, 1, 0, -50378, 1602, 0, 0, 39, '1601'),
	(243, 1, 0, -50378, 1603, 0, 0, 39, '1602'),
	(243, 1, 0, -50378, 1604, 0, 0, 39, '1603'),
	(243, 1, 0, -50378, 1605, 0, 0, 39, '1604'),
	(243, 1, 0, -50378, 1606, 0, 0, 39, '1605'),
	(243, 1, 0, -50378, 1607, 0, 0, 39, '1606'),
	(243, 1, 0, -50378, 1608, 0, 0, 39, '1607'),
	(243, 1, 0, -50378, 1609, 0, 0, 39, '1608'),
	(243, 1, 0, -50378, 1610, 0, 0, 39, '1609'),
	(243, 1, 0, -50378, 1611, 0, 0, 39, '1610'),
	(243, 1, 0, -50378, 1612, 0, 0, 39, '1611'),
	(243, 1, 0, -50378, 1613, 0, 0, 39, '1612'),
	(243, 1, 0, -50378, 1614, 0, 0, 39, '1613'),
	(243, 1, 0, -50378, 1615, 0, 0, 39, '1614'),
	(243, 1, 0, -50378, 1616, 0, 0, 39, '1615'),
	(243, 1, 0, -50378, 1617, 0, 0, 39, '1616'),
	(243, 1, 0, -50378, 1618, 0, 0, 39, '1617'),
	(243, 1, 0, -50378, 1619, 0, 0, 39, '1618'),
	(243, 1, 0, -50378, 1620, 0, 0, 39, '1619'),
	(243, 1, 0, -50378, 1621, 0, 0, 39, '1620'),
	(243, 1, 0, -50378, 1622, 0, 0, 39, '1621'),
	(243, 1, 0, -50378, 1623, 0, 0, 39, '1622'),
	(243, 1, 0, -50378, 1624, 0, 0, 39, '1623'),
	(243, 1, 0, -50378, 1625, 0, 0, 39, '1624'),
	(243, 1, 0, -50378, 1626, 0, 0, 39, '1625'),
	(243, 1, 0, -50378, 1627, 0, 0, 39, '1626'),
	(243, 1, 0, -50378, 1628, 0, 0, 39, '1627'),
	(243, 1, 0, -50378, 1629, 0, 0, 39, '1628'),
	(243, 1, 0, -50378, 1630, 0, 0, 39, '1629'),
	(243, 1, 0, -50378, 1631, 0, 0, 39, '1630'),
	(243, 1, 0, -50378, 1632, 0, 0, 39, '1631'),
	(243, 1, 0, -50378, 1633, 0, 0, 39, '1632'),
	(243, 1, 0, -50378, 1634, 0, 0, 39, '1633'),
	(243, 1, 0, -50378, 1635, 0, 0, 39, '1634'),
	(243, 1, 0, -50378, 1636, 0, 0, 39, '1635'),
	(243, 1, 0, -50378, 1637, 0, 0, 39, '1636'),
	(243, 1, 0, -50378, 1638, 0, 0, 39, '1637'),
	(243, 1, 0, -50378, 1639, 0, 0, 39, '1638'),
	(243, 1, 0, -50378, 1640, 0, 0, 39, '1639'),
	(243, 1, 0, -50378, 1641, 0, 0, 39, '1640'),
	(243, 1, 0, -50378, 1642, 0, 0, 39, '1641'),
	(243, 1, 0, -50378, 1643, 0, 0, 39, '1642'),
	(243, 1, 0, -50378, 1644, 0, 0, 39, '1643'),
	(243, 1, 0, -50378, 1645, 0, 0, 39, '1644'),
	(243, 1, 0, -50378, 1646, 0, 0, 39, '1645'),
	(243, 1, 0, -50378, 1647, 0, 0, 39, '1646'),
	(243, 1, 0, -50378, 1648, 0, 0, 39, '1647'),
	(243, 1, 0, -50378, 1649, 0, 0, 39, '1648'),
	(243, 1, 0, -50378, 1650, 0, 0, 39, '1649'),
	(243, 1, 0, -50378, 1651, 0, 0, 39, '1650'),
	(243, 1, 0, -50378, 1652, 0, 0, 39, '1651'),
	(243, 1, 0, -50378, 1653, 0, 0, 39, '1652'),
	(243, 1, 0, -50378, 1654, 0, 0, 39, '1653'),
	(243, 1, 0, -50378, 1655, 0, 0, 39, '1654'),
	(243, 1, 0, -50378, 1656, 0, 0, 39, '1655'),
	(243, 1, 0, -50378, 1657, 0, 0, 39, '1656'),
	(243, 1, 0, -50378, 1658, 0, 0, 39, '1657'),
	(243, 1, 0, -50378, 1659, 0, 0, 39, '1658'),
	(243, 1, 0, -50378, 1660, 0, 0, 39, '1659'),
	(243, 1, 0, -50378, 1661, 0, 0, 39, '1660'),
	(243, 1, 0, -50378, 1662, 0, 0, 39, '1661'),
	(243, 1, 0, -50378, 1663, 0, 0, 39, '1662'),
	(243, 1, 0, -50378, 1664, 0, 0, 39, '1663'),
	(243, 1, 0, -50378, 1665, 0, 0, 39, '1664'),
	(243, 1, 0, -50378, 1666, 0, 0, 39, '1665'),
	(243, 1, 0, -50378, 1667, 0, 0, 39, '1666'),
	(243, 1, 0, -50378, 1668, 0, 0, 39, '1667'),
	(243, 1, 0, -50378, 1669, 0, 0, 39, '1668'),
	(243, 1, 0, -50378, 1670, 0, 0, 39, '1669'),
	(243, 1, 0, -50378, 1671, 0, 0, 39, '1670'),
	(243, 1, 0, -50378, 1672, 0, 0, 39, '1671'),
	(243, 1, 0, -50378, 1673, 0, 0, 39, '1672'),
	(243, 1, 0, -50378, 1674, 0, 0, 39, '1673'),
	(243, 1, 0, -50378, 1675, 0, 0, 39, '1674'),
	(243, 1, 0, -50378, 1676, 0, 0, 39, '1675'),
	(243, 1, 0, -50378, 1677, 0, 0, 39, '1676'),
	(243, 1, 0, -50378, 1678, 0, 0, 39, '1677'),
	(243, 1, 0, -50378, 1679, 0, 0, 39, '1678'),
	(243, 1, 0, -50378, 1680, 0, 0, 39, '1679'),
	(243, 1, 0, -50378, 1681, 0, 0, 39, '1680'),
	(243, 1, 0, -50378, 1682, 0, 0, 39, '1681'),
	(243, 1, 0, -50378, 1683, 0, 0, 39, '1682'),
	(243, 1, 0, -50378, 1684, 0, 0, 39, '1683'),
	(243, 1, 0, -50378, 1685, 0, 0, 39, '1684'),
	(243, 1, 0, -50378, 1686, 0, 0, 39, '1685'),
	(243, 1, 0, -50378, 1687, 0, 0, 39, '1686'),
	(243, 1, 0, -50378, 1688, 0, 0, 39, '1687'),
	(243, 1, 0, -50378, 1689, 0, 0, 39, '1688'),
	(243, 1, 0, -50378, 1690, 0, 0, 39, '1689'),
	(243, 1, 0, -50378, 1691, 0, 0, 39, '1690'),
	(243, 1, 0, -50378, 1692, 0, 0, 39, '1691'),
	(243, 1, 0, -50378, 1693, 0, 0, 39, '1692'),
	(243, 1, 0, -50378, 1694, 0, 0, 39, '1693'),
	(243, 1, 0, -50378, 1695, 0, 0, 39, '1694'),
	(243, 1, 0, -50378, 1696, 0, 0, 39, '1695'),
	(243, 1, 0, -50378, 1697, 0, 0, 39, '1696'),
	(243, 1, 0, -50378, 1698, 0, 0, 39, '1697'),
	(243, 1, 0, -50378, 1699, 0, 0, 39, '1698'),
	(243, 1, 0, -50378, 1700, 0, 0, 39, '1699'),
	(243, 1, 0, -50378, 1701, 0, 0, 39, '1700'),
	(243, 1, 0, -50378, 1702, 0, 0, 39, '1701'),
	(243, 1, 0, -50378, 1703, 0, 0, 39, '1702'),
	(243, 1, 0, -50378, 1704, 0, 0, 39, '1703'),
	(243, 1, 0, -50378, 1705, 0, 0, 39, '1704'),
	(243, 1, 0, -50378, 1706, 0, 0, 39, '1705'),
	(243, 1, 0, -50378, 1707, 0, 0, 39, '1706'),
	(243, 1, 0, -50378, 1708, 0, 0, 39, '1707'),
	(243, 1, 0, -50378, 1709, 0, 0, 39, '1708'),
	(243, 1, 0, -50378, 1710, 0, 0, 39, '1709'),
	(243, 1, 0, -50378, 1711, 0, 0, 39, '1710'),
	(243, 1, 0, -50378, 1712, 0, 0, 39, '1711'),
	(243, 1, 0, -50378, 1713, 0, 0, 39, '1712'),
	(243, 1, 0, -50378, 1714, 0, 0, 39, '1713'),
	(243, 1, 0, -50378, 1715, 0, 0, 39, '1714'),
	(243, 1, 0, -50378, 1716, 0, 0, 39, '1715'),
	(243, 1, 0, -50378, 1717, 0, 0, 39, '1716'),
	(243, 1, 0, -50378, 1718, 0, 0, 39, '1717'),
	(243, 1, 0, -50378, 1719, 0, 0, 39, '1718'),
	(243, 1, 0, -50378, 1720, 0, 0, 39, '1719'),
	(243, 1, 0, -50378, 1721, 0, 0, 39, '1720'),
	(243, 1, 0, -50378, 1722, 0, 0, 39, '1721'),
	(243, 1, 0, -50378, 1723, 0, 0, 39, '1722'),
	(243, 1, 0, -50378, 1724, 0, 0, 39, '1723'),
	(243, 1, 0, -50378, 1725, 0, 0, 39, '1724'),
	(243, 1, 0, -50378, 1726, 0, 0, 39, '1725'),
	(243, 1, 0, -50378, 1727, 0, 0, 39, '1726'),
	(243, 1, 0, -50378, 1728, 0, 0, 39, '1727'),
	(243, 1, 0, -50378, 1729, 0, 0, 39, '1728'),
	(243, 1, 0, -50378, 1730, 0, 0, 39, '1729'),
	(243, 1, 0, -50378, 1731, 0, 0, 39, '1730'),
	(243, 1, 0, -50378, 1732, 0, 0, 39, '1731'),
	(243, 1, 0, -50378, 1733, 0, 0, 39, '1732'),
	(243, 1, 0, -50378, 1734, 0, 0, 39, '1733'),
	(243, 1, 0, -50378, 1735, 0, 0, 39, '1734'),
	(243, 1, 0, -50378, 1736, 0, 0, 39, '1735'),
	(243, 1, 0, -50378, 1737, 0, 0, 39, '1736'),
	(243, 1, 0, -50378, 1738, 0, 0, 39, '1737'),
	(243, 1, 0, -50378, 1739, 0, 0, 39, '1738'),
	(243, 1, 0, -50378, 1740, 0, 0, 39, '1739'),
	(243, 1, 0, -50378, 1741, 0, 0, 39, '1740'),
	(243, 1, 0, -50378, 1742, 0, 0, 39, '1741'),
	(243, 1, 0, -50378, 1743, 0, 0, 39, '1742'),
	(243, 1, 0, -50378, 1744, 0, 0, 39, '1743'),
	(243, 1, 0, -50378, 1745, 0, 0, 39, '1744'),
	(243, 1, 0, -50378, 1746, 0, 0, 39, '1745'),
	(243, 1, 0, -50378, 1747, 0, 0, 39, '1746'),
	(243, 1, 0, -50378, 1748, 0, 0, 39, '1747'),
	(243, 1, 0, -50378, 1749, 0, 0, 39, '1748'),
	(243, 1, 0, -50378, 1750, 0, 0, 39, '1749'),
	(243, 1, 0, -50378, 1751, 0, 0, 39, '1750'),
	(243, 1, 0, -50378, 1752, 0, 0, 39, '1751'),
	(243, 1, 0, -50378, 1753, 0, 0, 39, '1752'),
	(243, 1, 0, -50378, 1754, 0, 0, 39, '1753'),
	(243, 1, 0, -50378, 1755, 0, 0, 39, '1754'),
	(243, 1, 0, -50378, 1756, 0, 0, 39, '1755'),
	(243, 1, 0, -50378, 1757, 0, 0, 39, '1756'),
	(243, 1, 0, -50378, 1758, 0, 0, 39, '1757'),
	(243, 1, 0, -50378, 1759, 0, 0, 39, '1758'),
	(243, 1, 0, -50378, 1760, 0, 0, 39, '1759'),
	(243, 1, 0, -50378, 1761, 0, 0, 39, '1760'),
	(243, 1, 0, -50378, 1762, 0, 0, 39, '1761'),
	(243, 1, 0, -50378, 1763, 0, 0, 39, '1762'),
	(243, 1, 0, -50378, 1764, 0, 0, 39, '1763'),
	(243, 1, 0, -50378, 1765, 0, 0, 39, '1764'),
	(243, 1, 0, -50378, 1766, 0, 0, 39, '1765'),
	(243, 1, 0, -50378, 1767, 0, 0, 39, '1766'),
	(243, 1, 0, -50378, 1768, 0, 0, 39, '1767'),
	(243, 1, 0, -50378, 1769, 0, 0, 39, '1768'),
	(243, 1, 0, -50378, 1770, 0, 0, 39, '1769'),
	(243, 1, 0, -50378, 1771, 0, 0, 39, '1770'),
	(243, 1, 0, -50378, 1772, 0, 0, 39, '1771'),
	(243, 1, 0, -50378, 1773, 0, 0, 39, '1772'),
	(243, 1, 0, -50378, 1774, 0, 0, 39, '1773'),
	(243, 1, 0, -50378, 1775, 0, 0, 39, '1774'),
	(243, 1, 0, -50378, 1776, 0, 0, 39, '1775'),
	(243, 1, 0, -50378, 1777, 0, 0, 39, '1776'),
	(243, 1, 0, -50378, 1778, 0, 0, 39, '1777'),
	(243, 1, 0, -50378, 1779, 0, 0, 39, '1778'),
	(243, 1, 0, -50378, 1780, 0, 0, 39, '1779'),
	(243, 1, 0, -50378, 1781, 0, 0, 39, '1780'),
	(243, 1, 0, -50378, 1782, 0, 0, 39, '1781'),
	(243, 1, 0, -50378, 1783, 0, 0, 39, '1782'),
	(243, 1, 0, -50378, 1784, 0, 0, 39, '1783'),
	(243, 1, 0, -50378, 1785, 0, 0, 39, '1784'),
	(243, 1, 0, -50378, 1786, 0, 0, 39, '1785'),
	(243, 1, 0, -50378, 1787, 0, 0, 39, '1786'),
	(243, 1, 0, -50378, 1788, 0, 0, 39, '1787'),
	(243, 1, 0, -50378, 1789, 0, 0, 39, '1788'),
	(243, 1, 0, -50378, 1790, 0, 0, 39, '1789'),
	(243, 1, 0, -50378, 1791, 0, 0, 39, '1790'),
	(243, 1, 0, -50378, 1792, 0, 0, 39, '1791'),
	(243, 1, 0, -50378, 1793, 0, 0, 39, '1792'),
	(243, 1, 0, -50378, 1794, 0, 0, 39, '1793'),
	(243, 1, 0, -50378, 1795, 0, 0, 39, '1794'),
	(243, 1, 0, -50378, 1796, 0, 0, 39, '1795'),
	(243, 1, 0, -50378, 1797, 0, 0, 39, '1796'),
	(243, 1, 0, -50378, 1798, 0, 0, 39, '1797'),
	(243, 1, 0, -50378, 1799, 0, 0, 39, '1798'),
	(243, 1, 0, -50378, 1800, 0, 0, 39, '1799'),
	(243, 1, 0, -50378, 1801, 0, 0, 39, '1800'),
	(243, 1, 0, -50378, 1802, 0, 0, 39, '1801'),
	(243, 1, 0, -50378, 1803, 0, 0, 39, '1802'),
	(243, 1, 0, -50378, 1804, 0, 0, 39, '1803'),
	(243, 1, 0, -50378, 1805, 0, 0, 39, '1804'),
	(243, 1, 0, -50378, 1806, 0, 0, 39, '1805'),
	(243, 1, 0, -50378, 1807, 0, 0, 39, '1806'),
	(243, 1, 0, -50378, 1808, 0, 0, 39, '1807'),
	(243, 1, 0, -50378, 1809, 0, 0, 39, '1808'),
	(243, 1, 0, -50378, 1810, 0, 0, 39, '1809'),
	(243, 1, 0, -50378, 1811, 0, 0, 39, '1810'),
	(243, 1, 0, -50378, 1812, 0, 0, 39, '1811'),
	(243, 1, 0, -50378, 1813, 0, 0, 39, '1812'),
	(243, 1, 0, -50378, 1814, 0, 0, 39, '1813'),
	(243, 1, 0, -50378, 1815, 0, 0, 39, '1814'),
	(243, 1, 0, -50378, 1816, 0, 0, 39, '1815'),
	(243, 1, 0, -50378, 1817, 0, 0, 39, '1816'),
	(243, 1, 0, -50378, 1818, 0, 0, 39, '1817'),
	(243, 1, 0, -50378, 1819, 0, 0, 39, '1818'),
	(243, 1, 0, -50378, 1820, 0, 0, 39, '1819'),
	(243, 1, 0, -50378, 1821, 0, 0, 39, '1820'),
	(243, 1, 0, -50378, 1822, 0, 0, 39, '1821'),
	(243, 1, 0, -50378, 1823, 0, 0, 39, '1822'),
	(243, 1, 0, -50378, 1824, 0, 0, 39, '1823'),
	(243, 1, 0, -50378, 1825, 0, 0, 39, '1824'),
	(243, 1, 0, -50378, 1826, 0, 0, 39, '1825'),
	(243, 1, 0, -50378, 1827, 0, 0, 39, '1826'),
	(243, 1, 0, -50378, 1828, 0, 0, 39, '1827'),
	(243, 1, 0, -50378, 1829, 0, 0, 39, '1828'),
	(243, 1, 0, -50378, 1830, 0, 0, 39, '1829'),
	(243, 1, 0, -50378, 1831, 0, 0, 39, '1830'),
	(243, 1, 0, -50378, 1832, 0, 0, 39, '1831'),
	(243, 1, 0, -50378, 1833, 0, 0, 39, '1832'),
	(243, 1, 0, -50378, 1834, 0, 0, 39, '1833'),
	(243, 1, 0, -50378, 1835, 0, 0, 39, '1834'),
	(243, 1, 0, -50378, 1836, 0, 0, 39, '1835'),
	(243, 1, 0, -50378, 1837, 0, 0, 39, '1836'),
	(243, 1, 0, -50378, 1838, 0, 0, 39, '1837'),
	(243, 1, 0, -50378, 1839, 0, 0, 39, '1838'),
	(243, 1, 0, -50378, 1840, 0, 0, 39, '1839'),
	(243, 1, 0, -50378, 1841, 0, 0, 39, '1840'),
	(243, 1, 0, -50378, 1842, 0, 0, 39, '1841'),
	(243, 1, 0, -50378, 1843, 0, 0, 39, '1842'),
	(243, 1, 0, -50378, 1844, 0, 0, 39, '1843'),
	(243, 1, 0, -50378, 1845, 0, 0, 39, '1844'),
	(243, 1, 0, -50378, 1846, 0, 0, 39, '1845'),
	(243, 1, 0, -50378, 1847, 0, 0, 39, '1846'),
	(243, 1, 0, -50378, 1848, 0, 0, 39, '1847'),
	(243, 1, 0, -50378, 1849, 0, 0, 39, '1848'),
	(243, 1, 0, -50378, 1850, 0, 0, 39, '1849'),
	(243, 1, 0, -50378, 1851, 0, 0, 39, '1850'),
	(243, 1, 0, -50378, 1852, 0, 0, 39, '1851'),
	(243, 1, 0, -50378, 1853, 0, 0, 39, '1852'),
	(243, 1, 0, -50378, 1854, 0, 0, 39, '1853'),
	(243, 1, 0, -50378, 1855, 0, 0, 39, '1854'),
	(243, 1, 0, -50378, 1856, 0, 0, 39, '1855'),
	(243, 1, 0, -50378, 1857, 0, 0, 39, '1856'),
	(243, 1, 0, -50378, 1858, 0, 0, 39, '1857'),
	(243, 1, 0, -50378, 1859, 0, 0, 39, '1858'),
	(243, 1, 0, -50378, 1860, 0, 0, 39, '1859'),
	(243, 1, 0, -50378, 1861, 0, 0, 39, '1860'),
	(243, 1, 0, -50378, 1862, 0, 0, 39, '1861'),
	(243, 1, 0, -50378, 1863, 0, 0, 39, '1862'),
	(243, 1, 0, -50378, 1864, 0, 0, 39, '1863'),
	(243, 1, 0, -50378, 1865, 0, 0, 39, '1864'),
	(243, 1, 0, -50378, 1866, 0, 0, 39, '1865'),
	(243, 1, 0, -50378, 1867, 0, 0, 39, '1866'),
	(243, 1, 0, -50378, 1868, 0, 0, 39, '1867'),
	(243, 1, 0, -50378, 1869, 0, 0, 39, '1868'),
	(243, 1, 0, -50378, 1870, 0, 0, 39, '1869'),
	(243, 1, 0, -50378, 1871, 0, 0, 39, '1870'),
	(243, 1, 0, -50378, 1872, 0, 0, 39, '1871'),
	(243, 1, 0, -50378, 1873, 0, 0, 39, '1872'),
	(243, 1, 0, -50378, 1874, 0, 0, 39, '1873'),
	(243, 1, 0, -50378, 1875, 0, 0, 39, '1874'),
	(243, 1, 0, -50378, 1876, 0, 0, 39, '1875'),
	(243, 1, 0, -50378, 1877, 0, 0, 39, '1876'),
	(243, 1, 0, -50378, 1878, 0, 0, 39, '1877'),
	(243, 1, 0, -50378, 1879, 0, 0, 39, '1878'),
	(243, 1, 0, -50378, 1880, 0, 0, 39, '1879'),
	(243, 1, 0, -50378, 1881, 0, 0, 39, '1880'),
	(243, 1, 0, -50378, 1882, 0, 0, 39, '1881'),
	(243, 1, 0, -50378, 1883, 0, 0, 39, '1882'),
	(243, 1, 0, -50378, 1884, 0, 0, 39, '1883'),
	(243, 1, 0, -50378, 1885, 0, 0, 39, '1884'),
	(243, 1, 0, -50378, 1886, 0, 0, 39, '1885'),
	(243, 1, 0, -50378, 1887, 0, 0, 39, '1886'),
	(243, 1, 0, -50378, 1888, 0, 0, 39, '1887'),
	(243, 1, 0, -50378, 1889, 0, 0, 39, '1888'),
	(243, 1, 0, -50378, 1890, 0, 0, 39, '1889'),
	(243, 1, 0, -50378, 1891, 0, 0, 39, '1890'),
	(243, 1, 0, -50378, 1892, 0, 0, 39, '1891'),
	(243, 1, 0, -50378, 1893, 0, 0, 39, '1892'),
	(243, 1, 0, -50378, 1894, 0, 0, 39, '1893'),
	(243, 1, 0, -50378, 1895, 0, 0, 39, '1894'),
	(243, 1, 0, -50378, 1896, 0, 0, 39, '1895'),
	(243, 1, 0, -50378, 1897, 0, 0, 39, '1896'),
	(243, 1, 0, -50378, 1898, 0, 0, 39, '1897'),
	(243, 1, 0, -50378, 1899, 0, 0, 39, '1898'),
	(243, 1, 0, -50378, 1900, 0, 0, 39, '1899'),
	(243, 1, 0, -50378, 1901, 0, 0, 39, '1900'),
	(243, 1, 0, -50378, 1902, 0, 0, 39, '1901'),
	(243, 1, 0, -50378, 1903, 0, 0, 39, '1902'),
	(243, 1, 0, -50378, 1904, 0, 0, 39, '1903'),
	(243, 1, 0, -50378, 1905, 0, 0, 39, '1904'),
	(243, 1, 0, -50378, 1906, 0, 0, 39, '1905'),
	(243, 1, 0, -50378, 1907, 0, 0, 39, '1906'),
	(243, 1, 0, -50378, 1908, 0, 0, 39, '1907'),
	(243, 1, 0, -50378, 1909, 0, 0, 39, '1908'),
	(243, 1, 0, -50378, 1910, 0, 0, 39, '1909'),
	(243, 1, 0, -50378, 1911, 0, 0, 39, '1910'),
	(243, 1, 0, -50378, 1912, 0, 0, 39, '1911'),
	(243, 1, 0, -50378, 1913, 0, 0, 39, '1912'),
	(243, 1, 0, -50378, 1914, 0, 0, 39, '1913'),
	(243, 1, 0, -50378, 1915, 0, 0, 39, '1914'),
	(243, 1, 0, -50378, 1916, 0, 0, 39, '1915'),
	(243, 1, 0, -50378, 1917, 0, 0, 39, '1916'),
	(243, 1, 0, -50378, 1918, 0, 0, 39, '1917'),
	(243, 1, 0, -50378, 1919, 0, 0, 39, '1918'),
	(243, 1, 0, -50378, 1920, 0, 0, 39, '1919'),
	(243, 1, 0, -50378, 1921, 0, 0, 39, '1920'),
	(243, 1, 0, -50378, 1922, 0, 0, 39, '1921'),
	(243, 1, 0, -50378, 1923, 0, 0, 39, '1922'),
	(243, 1, 0, -50378, 1924, 0, 0, 39, '1923'),
	(243, 1, 0, -50378, 1925, 0, 0, 39, '1924'),
	(243, 1, 0, -50378, 1926, 0, 0, 39, '1925'),
	(243, 1, 0, -50378, 1927, 0, 0, 39, '1926'),
	(243, 1, 0, -50378, 1928, 0, 0, 39, '1927'),
	(243, 1, 0, -50378, 1929, 0, 0, 39, '1928'),
	(243, 1, 0, -50378, 1930, 0, 0, 39, '1929'),
	(243, 1, 0, -50378, 1931, 0, 0, 39, '1930'),
	(243, 1, 0, -50378, 1932, 0, 0, 39, '1931'),
	(243, 1, 0, -50378, 1933, 0, 0, 39, '1932'),
	(243, 1, 0, -50378, 1934, 0, 0, 39, '1933'),
	(243, 1, 0, -50378, 1935, 0, 0, 39, '1934'),
	(243, 1, 0, -50378, 1936, 0, 0, 39, '1935'),
	(243, 1, 0, -50378, 1937, 0, 0, 39, '1936'),
	(243, 1, 0, -50378, 1938, 0, 0, 39, '1937'),
	(243, 1, 0, -50378, 1939, 0, 0, 39, '1938'),
	(243, 1, 0, -50378, 1940, 0, 0, 39, '1939'),
	(243, 1, 0, -50378, 1941, 0, 0, 39, '1940'),
	(243, 1, 0, -50378, 1942, 0, 0, 39, '1941'),
	(243, 1, 0, -50378, 1943, 0, 0, 39, '1942'),
	(243, 1, 0, -50378, 1944, 0, 0, 39, '1943'),
	(243, 1, 0, -50378, 1945, 0, 0, 39, '1944'),
	(243, 1, 0, -50378, 1946, 0, 0, 39, '1945'),
	(243, 1, 0, -50378, 1947, 0, 0, 39, '1946'),
	(243, 1, 0, -50378, 1948, 0, 0, 39, '1947'),
	(243, 1, 0, -50378, 1949, 0, 0, 39, '1948'),
	(243, 1, 0, -50378, 1950, 0, 0, 39, '1949'),
	(243, 1, 0, -50378, 1951, 0, 0, 39, '1950'),
	(243, 1, 0, -50378, 1952, 0, 0, 39, '1951'),
	(243, 1, 0, -50378, 1953, 0, 0, 39, '1952'),
	(243, 1, 0, -50378, 1954, 0, 0, 39, '1953'),
	(243, 1, 0, -50378, 1955, 0, 0, 39, '1954'),
	(243, 1, 0, -50378, 1956, 0, 0, 39, '1955'),
	(243, 1, 0, -50378, 1957, 0, 0, 39, '1956'),
	(243, 1, 0, -50378, 1958, 0, 0, 39, '1957'),
	(243, 1, 0, -50378, 1959, 0, 0, 39, '1958'),
	(243, 1, 0, -50378, 1960, 0, 0, 39, '1959'),
	(243, 1, 0, -50378, 1961, 0, 0, 39, '1960'),
	(243, 1, 0, -50378, 1962, 0, 0, 39, '1961'),
	(243, 1, 0, -50378, 1963, 0, 0, 39, '1962'),
	(243, 1, 0, -50378, 1964, 0, 0, 39, '1963'),
	(243, 1, 0, -50378, 1965, 0, 0, 39, '1964'),
	(243, 1, 0, -50378, 1966, 0, 0, 39, '1965'),
	(243, 1, 0, -50378, 1967, 0, 0, 39, '1966'),
	(243, 1, 0, -50378, 1968, 0, 0, 39, '1967'),
	(243, 1, 0, -50378, 1969, 0, 0, 39, '1968'),
	(243, 1, 0, -50378, 1970, 0, 0, 39, '1969'),
	(243, 1, 0, -50378, 1971, 0, 0, 39, '1970'),
	(243, 1, 0, -50378, 1972, 0, 0, 39, '1971'),
	(243, 1, 0, -50378, 1973, 0, 0, 39, '1972'),
	(243, 1, 0, -50378, 1974, 0, 0, 39, '1973'),
	(243, 1, 0, -50378, 1975, 0, 0, 39, '1974'),
	(243, 1, 0, -50378, 1976, 0, 0, 39, '1975'),
	(243, 1, 0, -50378, 1977, 0, 0, 39, '1976'),
	(243, 1, 0, -50378, 1978, 0, 0, 39, '1977'),
	(243, 1, 0, -50378, 1979, 0, 0, 39, '1978'),
	(243, 1, 0, -50378, 1980, 0, 0, 39, '1979'),
	(243, 1, 0, -50378, 1981, 0, 0, 39, '1980'),
	(243, 1, 0, -50378, 1982, 0, 0, 39, '1981'),
	(243, 1, 0, -50378, 1983, 0, 0, 39, '1982'),
	(243, 1, 0, -50378, 1984, 0, 0, 39, '1983'),
	(243, 1, 0, -50378, 1985, 0, 0, 39, '1984'),
	(243, 1, 0, -50378, 1986, 0, 0, 39, '1985'),
	(243, 1, 0, -50378, 1987, 0, 0, 39, '1986'),
	(243, 1, 0, -50378, 1988, 0, 0, 39, '1987'),
	(243, 1, 0, -50378, 1989, 0, 0, 39, '1988'),
	(243, 1, 0, -50378, 1990, 0, 0, 39, '1989'),
	(243, 1, 0, -50378, 1991, 0, 0, 39, '1990'),
	(243, 1, 0, -50378, 1992, 0, 0, 39, '1991'),
	(243, 1, 0, -50378, 1993, 0, 0, 39, '1992'),
	(243, 1, 0, -50378, 1994, 0, 0, 39, '1993'),
	(243, 1, 0, -50378, 1995, 0, 0, 39, '1994'),
	(243, 1, 0, -50378, 1996, 0, 0, 39, '1995'),
	(243, 1, 0, -50378, 1997, 0, 0, 39, '1996'),
	(243, 1, 0, -50378, 1998, 0, 0, 39, '1997'),
	(243, 1, 0, -50378, 1999, 0, 0, 39, '1998'),
	(243, 1, 0, -50378, 2000, 0, 0, 39, '1999'),
	(243, 1, 0, -50378, 2001, 0, 0, 39, '2000'),
	(243, 1, 0, -50378, 2002, 0, 0, 39, '2001'),
	(243, 1, 0, -50378, 2003, 0, 0, 39, '2002'),
	(243, 1, 0, -50378, 2004, 0, 0, 39, '2003'),
	(243, 1, 0, -50378, 2005, 0, 0, 39, '2004'),
	(243, 1, 0, -50378, 2006, 0, 0, 39, '2005'),
	(243, 1, 0, -50378, 2007, 0, 0, 39, '2006'),
	(243, 1, 0, -50378, 2008, 0, 0, 39, '2007'),
	(243, 1, 0, -50378, 2009, 0, 0, 39, '2008'),
	(243, 1, 0, -50378, 2010, 0, 0, 39, '2009'),
	(243, 1, 0, -50378, 2011, 0, 0, 39, '2010'),
	(243, 1, 0, -50378, 2012, 0, 0, 39, '2011'),
	(243, 1, 0, -50378, 2013, 0, 0, 39, '2012'),
	(243, 1, 0, -50378, 2014, 0, 0, 39, '2013'),
	(243, 1, 0, -50378, 2015, 0, 0, 39, '2014'),
	(243, 1, 0, -50378, 2016, 0, 0, 39, '2015'),
	(243, 1, 0, -50378, 2017, 0, 0, 39, '2016'),
	(243, 1, 0, -50378, 2018, 0, 0, 39, '2017'),
	(243, 1, 0, -50378, 2019, 0, 0, 39, '2018'),
	(243, 1, 0, -50378, 2020, 0, 0, 39, '2019'),
	(243, 1, 0, -50378, 2021, 0, 0, 39, '2020'),
	(243, 1, 0, -50378, 2022, 0, 0, 39, '2021'),
	(243, 1, 0, -50378, 2023, 0, 0, 39, '2022'),
	(243, 1, 0, -50378, 2024, 0, 0, 39, '2023'),
	(243, 1, 0, -50378, 2025, 0, 0, 39, '2024'),
	(243, 1, 0, -50378, 2026, 0, 0, 39, '2025'),
	(243, 1, 0, -50378, 2027, 0, 0, 39, '2026'),
	(243, 1, 0, -50378, 2028, 0, 0, 39, '2027'),
	(243, 1, 0, -50378, 2029, 0, 0, 39, '2028'),
	(243, 1, 0, -50378, 2030, 0, 0, 39, '2029'),
	(243, 1, 0, -50378, 2031, 0, 0, 39, '2030'),
	(243, 1, 0, -50378, 2032, 0, 0, 39, '2031'),
	(243, 1, 0, -50378, 2033, 0, 0, 39, '2032'),
	(243, 1, 0, -50378, 2034, 0, 0, 39, '2033'),
	(243, 1, 0, -50378, 2035, 0, 0, 39, '2034'),
	(243, 1, 0, -50378, 2036, 0, 0, 39, '2035'),
	(243, 1, 0, -50378, 2037, 0, 0, 39, '2036'),
	(243, 1, 0, -50378, 2038, 0, 0, 39, '2037'),
	(243, 1, 0, -50378, 2039, 0, 0, 39, '2038'),
	(243, 1, 0, -50378, 2040, 0, 0, 39, '2039'),
	(243, 1, 0, -50378, 2041, 0, 0, 39, '2040'),
	(243, 1, 0, -50378, 2042, 0, 0, 39, '2041'),
	(243, 1, 0, -50378, 2043, 0, 0, 39, '2042'),
	(243, 1, 0, -50378, 2044, 0, 0, 39, '2043'),
	(243, 1, 0, -50378, 2045, 0, 0, 39, '2044'),
	(243, 1, 0, -50378, 2046, 0, 0, 39, '2045'),
	(243, 1, 0, -50378, 2047, 0, 0, 39, '2046'),
	(243, 1, 0, -50378, 2048, 0, 0, 39, '2047'),
	(243, 1, 0, -50242, 1, 0, 0, 39, '0'),
	(243, 1, 0, -50242, 2, 0, 0, 39, '1'),
	(243, 1, 0, -50242, 3, 0, 0, 39, '2'),
	(243, 1, 0, -50242, 4, 0, 0, 39, '3'),
	(243, 1, 0, -50242, 5, 0, 0, 39, '4'),
	(243, 1, 0, -50242, 6, 0, 0, 39, '5'),
	(243, 1, 0, -50242, 7, 0, 0, 39, '6'),
	(243, 1, 0, -50242, 8, 0, 0, 39, '7'),
	(243, 1, 0, -50242, 9, 0, 0, 39, '8'),
	(243, 1, 0, -50242, 10, 0, 0, 39, '9'),
	(243, 1, 0, -50242, 11, 0, 0, 39, '10'),
	(243, 1, 0, -50242, 12, 0, 0, 39, '11'),
	(243, 1, 0, -50242, 13, 0, 0, 39, '12'),
	(243, 1, 0, -50242, 14, 0, 0, 39, '13'),
	(243, 1, 0, -50242, 15, 0, 0, 39, '14'),
	(243, 1, 0, -50242, 16, 0, 0, 39, '15'),
	(243, 1, 0, -50242, 17, 0, 0, 39, '16'),
	(243, 1, 0, -50242, 18, 0, 0, 39, '17'),
	(243, 1, 0, -50242, 19, 0, 0, 39, '18'),
	(243, 1, 0, -50242, 20, 0, 0, 39, '19'),
	(243, 1, 0, -50242, 21, 0, 0, 39, '20'),
	(243, 1, 0, -50242, 22, 0, 0, 39, '21'),
	(243, 1, 0, -50242, 23, 0, 0, 39, '22'),
	(243, 1, 0, -50242, 24, 0, 0, 39, '23'),
	(243, 1, 0, -50242, 25, 0, 0, 39, '24'),
	(243, 1, 0, -50242, 26, 0, 0, 39, '25'),
	(243, 1, 0, -50242, 27, 0, 0, 39, '26'),
	(243, 1, 0, -50242, 28, 0, 0, 39, '27'),
	(243, 1, 0, -50242, 29, 0, 0, 39, '28'),
	(243, 1, 0, -50242, 30, 0, 0, 39, '29'),
	(243, 1, 0, -50242, 31, 0, 0, 39, '30'),
	(243, 1, 0, -50242, 32, 0, 0, 39, '31'),
	(243, 1, 0, -50242, 33, 0, 0, 39, '32'),
	(243, 1, 0, -50242, 34, 0, 0, 39, '33'),
	(243, 1, 0, -50242, 35, 0, 0, 39, '34'),
	(243, 1, 0, -50242, 36, 0, 0, 39, '35'),
	(243, 1, 0, -50242, 37, 0, 0, 39, '36'),
	(243, 1, 0, -50242, 38, 0, 0, 39, '37'),
	(243, 1, 0, -50242, 39, 0, 0, 39, '38'),
	(243, 1, 0, -50242, 40, 0, 0, 39, '39'),
	(243, 1, 0, -50242, 41, 0, 0, 39, '40'),
	(243, 1, 0, -50242, 42, 0, 0, 39, '41'),
	(243, 1, 0, -50242, 43, 0, 0, 39, '42'),
	(243, 1, 0, -50242, 44, 0, 0, 39, '43'),
	(243, 1, 0, -50242, 45, 0, 0, 39, '44'),
	(243, 1, 0, -50242, 46, 0, 0, 39, '45'),
	(243, 1, 0, -50242, 47, 0, 0, 39, '46'),
	(243, 1, 0, -50242, 48, 0, 0, 39, '47'),
	(243, 1, 0, -50242, 49, 0, 0, 39, '48'),
	(243, 1, 0, -50242, 50, 0, 0, 39, '49'),
	(243, 1, 0, -50242, 51, 0, 0, 39, '50'),
	(243, 1, 0, -50242, 52, 0, 0, 39, '51'),
	(243, 1, 0, -50242, 53, 0, 0, 39, '52'),
	(243, 1, 0, -50242, 54, 0, 0, 39, '53'),
	(243, 1, 0, -50242, 55, 0, 0, 39, '54'),
	(243, 1, 0, -50242, 56, 0, 0, 39, '55'),
	(243, 1, 0, -50242, 57, 0, 0, 39, '56'),
	(243, 1, 0, -50242, 58, 0, 0, 39, '57'),
	(243, 1, 0, -50242, 59, 0, 0, 39, '58'),
	(243, 1, 0, -50242, 60, 0, 0, 39, '59'),
	(243, 1, 0, -50242, 61, 0, 0, 39, '60'),
	(243, 1, 0, -50242, 62, 0, 0, 39, '61'),
	(243, 1, 0, -50242, 63, 0, 0, 39, '62'),
	(243, 1, 0, -50242, 64, 0, 0, 39, '63'),
	(243, 1, 0, -50242, 65, 0, 0, 39, '64'),
	(243, 1, 0, -50242, 66, 0, 0, 39, '65'),
	(243, 1, 0, -50242, 67, 0, 0, 39, '66'),
	(243, 1, 0, -50242, 68, 0, 0, 39, '67'),
	(243, 1, 0, -50242, 69, 0, 0, 39, '68'),
	(243, 1, 0, -50242, 70, 0, 0, 39, '69'),
	(243, 1, 0, -50242, 71, 0, 0, 39, '70'),
	(243, 1, 0, -50242, 72, 0, 0, 39, '71'),
	(243, 1, 0, -50242, 73, 0, 0, 39, '72'),
	(243, 1, 0, -50242, 74, 0, 0, 39, '73'),
	(243, 1, 0, -50242, 75, 0, 0, 39, '74'),
	(243, 1, 0, -50242, 76, 0, 0, 39, '75'),
	(243, 1, 0, -50242, 77, 0, 0, 39, '76'),
	(243, 1, 0, -50242, 78, 0, 0, 39, '77'),
	(243, 1, 0, -50242, 79, 0, 0, 39, '78'),
	(243, 1, 0, -50242, 80, 0, 0, 39, '79'),
	(243, 1, 0, -50242, 81, 0, 0, 39, '80'),
	(243, 1, 0, -50242, 82, 0, 0, 39, '81'),
	(243, 1, 0, -50242, 83, 0, 0, 39, '82'),
	(243, 1, 0, -50242, 84, 0, 0, 39, '83'),
	(243, 1, 0, -50242, 85, 0, 0, 39, '84'),
	(243, 1, 0, -50242, 86, 0, 0, 39, '85'),
	(243, 1, 0, -50242, 87, 0, 0, 39, '86'),
	(243, 1, 0, -50242, 88, 0, 0, 39, '87'),
	(243, 1, 0, -50242, 89, 0, 0, 39, '88'),
	(243, 1, 0, -50242, 90, 0, 0, 39, '89'),
	(243, 1, 0, -50242, 91, 0, 0, 39, '90'),
	(243, 1, 0, -50242, 92, 0, 0, 39, '91'),
	(243, 1, 0, -50242, 93, 0, 0, 39, '92'),
	(243, 1, 0, -50242, 94, 0, 0, 39, '93'),
	(243, 1, 0, -50242, 95, 0, 0, 39, '94'),
	(243, 1, 0, -50242, 96, 0, 0, 39, '95'),
	(243, 1, 0, -50242, 97, 0, 0, 39, '96'),
	(243, 1, 0, -50242, 98, 0, 0, 39, '97'),
	(243, 1, 0, -50242, 99, 0, 0, 39, '98'),
	(243, 1, 0, -50242, 100, 0, 0, 39, '99'),
	(243, 1, 0, -50242, 101, 0, 0, 39, '100'),
	(243, 1, 0, -50242, 102, 0, 0, 39, '101'),
	(243, 1, 0, -50242, 103, 0, 0, 39, '102'),
	(243, 1, 0, -50242, 104, 0, 0, 39, '103'),
	(243, 1, 0, -50242, 105, 0, 0, 39, '104'),
	(243, 1, 0, -50242, 106, 0, 0, 39, '105'),
	(243, 1, 0, -50242, 107, 0, 0, 39, '106'),
	(243, 1, 0, -50242, 108, 0, 0, 39, '107'),
	(243, 1, 0, -50242, 109, 0, 0, 39, '108'),
	(243, 1, 0, -50242, 110, 0, 0, 39, '109'),
	(243, 1, 0, -50242, 111, 0, 0, 39, '110'),
	(243, 1, 0, -50242, 112, 0, 0, 39, '111'),
	(243, 1, 0, -50242, 113, 0, 0, 39, '112'),
	(243, 1, 0, -50242, 114, 0, 0, 39, '113'),
	(243, 1, 0, -50242, 115, 0, 0, 39, '114'),
	(243, 1, 0, -50242, 116, 0, 0, 39, '115'),
	(243, 1, 0, -50242, 117, 0, 0, 39, '116'),
	(243, 1, 0, -50242, 118, 0, 0, 39, '117'),
	(243, 1, 0, -50242, 119, 0, 0, 39, '118'),
	(243, 1, 0, -50242, 120, 0, 0, 39, '119'),
	(243, 1, 0, -50242, 121, 0, 0, 39, '120'),
	(243, 1, 0, -50242, 122, 0, 0, 39, '121'),
	(243, 1, 0, -50242, 123, 0, 0, 39, '122'),
	(243, 1, 0, -50242, 124, 0, 0, 39, '123'),
	(243, 1, 0, -50242, 125, 0, 0, 39, '124'),
	(243, 1, 0, -50242, 126, 0, 0, 39, '125'),
	(243, 1, 0, -50242, 127, 0, 0, 39, '126'),
	(243, 1, 0, -50242, 128, 0, 0, 39, '127'),
	(243, 1, 0, -50242, 129, 0, 0, 39, '128'),
	(243, 1, 0, -50242, 130, 0, 0, 39, '129'),
	(243, 1, 0, -50242, 131, 0, 0, 39, '130'),
	(243, 1, 0, -50242, 132, 0, 0, 39, '131'),
	(243, 1, 0, -50242, 133, 0, 0, 39, '132'),
	(243, 1, 0, -50242, 134, 0, 0, 39, '133'),
	(243, 1, 0, -50242, 135, 0, 0, 39, '134'),
	(243, 1, 0, -50242, 136, 0, 0, 39, '135'),
	(243, 1, 0, -50242, 137, 0, 0, 39, '136'),
	(243, 1, 0, -50242, 138, 0, 0, 39, '137'),
	(243, 1, 0, -50242, 139, 0, 0, 39, '138'),
	(243, 1, 0, -50242, 140, 0, 0, 39, '139'),
	(243, 1, 0, -50242, 141, 0, 0, 39, '140'),
	(243, 1, 0, -50242, 142, 0, 0, 39, '141'),
	(243, 1, 0, -50242, 143, 0, 0, 39, '142'),
	(243, 1, 0, -50242, 144, 0, 0, 39, '143'),
	(243, 1, 0, -50242, 145, 0, 0, 39, '144'),
	(243, 1, 0, -50242, 146, 0, 0, 39, '145'),
	(243, 1, 0, -50242, 147, 0, 0, 39, '146'),
	(243, 1, 0, -50242, 148, 0, 0, 39, '147'),
	(243, 1, 0, -50242, 149, 0, 0, 39, '148'),
	(243, 1, 0, -50242, 150, 0, 0, 39, '149'),
	(243, 1, 0, -50242, 151, 0, 0, 39, '150'),
	(243, 1, 0, -50242, 152, 0, 0, 39, '151'),
	(243, 1, 0, -50242, 153, 0, 0, 39, '152'),
	(243, 1, 0, -50242, 154, 0, 0, 39, '153'),
	(243, 1, 0, -50242, 155, 0, 0, 39, '154'),
	(243, 1, 0, -50242, 156, 0, 0, 39, '155'),
	(243, 1, 0, -50242, 157, 0, 0, 39, '156'),
	(243, 1, 0, -50242, 158, 0, 0, 39, '157'),
	(243, 1, 0, -50242, 159, 0, 0, 39, '158'),
	(243, 1, 0, -50242, 160, 0, 0, 39, '159'),
	(243, 1, 0, -50242, 161, 0, 0, 39, '160'),
	(243, 1, 0, -50242, 162, 0, 0, 39, '161'),
	(243, 1, 0, -50242, 163, 0, 0, 39, '162'),
	(243, 1, 0, -50242, 164, 0, 0, 39, '163'),
	(243, 1, 0, -50242, 165, 0, 0, 39, '164'),
	(243, 1, 0, -50242, 166, 0, 0, 39, '165'),
	(243, 1, 0, -50242, 167, 0, 0, 39, '166'),
	(243, 1, 0, -50242, 168, 0, 0, 39, '167'),
	(243, 1, 0, -50242, 169, 0, 0, 39, '168'),
	(243, 1, 0, -50242, 170, 0, 0, 39, '169'),
	(243, 1, 0, -50242, 171, 0, 0, 39, '170'),
	(243, 1, 0, -50242, 172, 0, 0, 39, '171'),
	(243, 1, 0, -50242, 173, 0, 0, 39, '172'),
	(243, 1, 0, -50242, 174, 0, 0, 39, '173'),
	(243, 1, 0, -50242, 175, 0, 0, 39, '174'),
	(243, 1, 0, -50242, 176, 0, 0, 39, '175'),
	(243, 1, 0, -50242, 177, 0, 0, 39, '176'),
	(243, 1, 0, -50242, 178, 0, 0, 39, '177'),
	(243, 1, 0, -50242, 179, 0, 0, 39, '178'),
	(243, 1, 0, -50242, 180, 0, 0, 39, '179'),
	(243, 1, 0, -50242, 181, 0, 0, 39, '180'),
	(243, 1, 0, -50242, 182, 0, 0, 39, '181'),
	(243, 1, 0, -50242, 183, 0, 0, 39, '182'),
	(243, 1, 0, -50242, 184, 0, 0, 39, '183'),
	(243, 1, 0, -50242, 185, 0, 0, 39, '184'),
	(243, 1, 0, -50242, 186, 0, 0, 39, '185'),
	(243, 1, 0, -50242, 187, 0, 0, 39, '186'),
	(243, 1, 0, -50242, 188, 0, 0, 39, '187'),
	(243, 1, 0, -50242, 189, 0, 0, 39, '188'),
	(243, 1, 0, -50242, 190, 0, 0, 39, '189'),
	(243, 1, 0, -50242, 191, 0, 0, 39, '190'),
	(243, 1, 0, -50242, 192, 0, 0, 39, '191'),
	(243, 1, 0, -50242, 193, 0, 0, 39, '192'),
	(243, 1, 0, -50242, 194, 0, 0, 39, '193'),
	(243, 1, 0, -50242, 195, 0, 0, 39, '194'),
	(243, 1, 0, -50242, 196, 0, 0, 39, '195'),
	(243, 1, 0, -50242, 197, 0, 0, 39, '196'),
	(243, 1, 0, -50242, 198, 0, 0, 39, '197'),
	(243, 1, 0, -50242, 199, 0, 0, 39, '198'),
	(243, 1, 0, -50242, 200, 0, 0, 39, '199'),
	(243, 1, 0, -50242, 201, 0, 0, 39, '200'),
	(243, 1, 0, -50242, 202, 0, 0, 39, '201'),
	(243, 1, 0, -50242, 203, 0, 0, 39, '202'),
	(243, 1, 0, -50242, 204, 0, 0, 39, '203'),
	(243, 1, 0, -50242, 205, 0, 0, 39, '204'),
	(243, 1, 0, -50242, 206, 0, 0, 39, '205'),
	(243, 1, 0, -50242, 207, 0, 0, 39, '206'),
	(243, 1, 0, -50242, 208, 0, 0, 39, '207'),
	(243, 1, 0, -50242, 209, 0, 0, 39, '208'),
	(243, 1, 0, -50242, 210, 0, 0, 39, '209'),
	(243, 1, 0, -50242, 211, 0, 0, 39, '210'),
	(243, 1, 0, -50242, 212, 0, 0, 39, '211'),
	(243, 1, 0, -50242, 213, 0, 0, 39, '212'),
	(243, 1, 0, -50242, 214, 0, 0, 39, '213'),
	(243, 1, 0, -50242, 215, 0, 0, 39, '214'),
	(243, 1, 0, -50242, 216, 0, 0, 39, '215'),
	(243, 1, 0, -50242, 217, 0, 0, 39, '216'),
	(243, 1, 0, -50242, 218, 0, 0, 39, '217'),
	(243, 1, 0, -50242, 219, 0, 0, 39, '218'),
	(243, 1, 0, -50242, 220, 0, 0, 39, '219'),
	(243, 1, 0, -50242, 221, 0, 0, 39, '220'),
	(243, 1, 0, -50242, 222, 0, 0, 39, '221'),
	(243, 1, 0, -50242, 223, 0, 0, 39, '222'),
	(243, 1, 0, -50242, 224, 0, 0, 39, '223'),
	(243, 1, 0, -50242, 225, 0, 0, 39, '224'),
	(243, 1, 0, -50242, 226, 0, 0, 39, '225'),
	(243, 1, 0, -50242, 227, 0, 0, 39, '226'),
	(243, 1, 0, -50242, 228, 0, 0, 39, '227'),
	(243, 1, 0, -50242, 229, 0, 0, 39, '228'),
	(243, 1, 0, -50242, 230, 0, 0, 39, '229'),
	(243, 1, 0, -50242, 231, 0, 0, 39, '230'),
	(243, 1, 0, -50242, 232, 0, 0, 39, '231'),
	(243, 1, 0, -50242, 233, 0, 0, 39, '232'),
	(243, 1, 0, -50242, 234, 0, 0, 39, '233'),
	(243, 1, 0, -50242, 235, 0, 0, 39, '234'),
	(243, 1, 0, -50242, 236, 0, 0, 39, '235'),
	(243, 1, 0, -50242, 237, 0, 0, 39, '236'),
	(243, 1, 0, -50242, 238, 0, 0, 39, '237'),
	(243, 1, 0, -50242, 239, 0, 0, 39, '238'),
	(243, 1, 0, -50242, 240, 0, 0, 39, '239'),
	(243, 1, 0, -50242, 241, 0, 0, 39, '240'),
	(243, 1, 0, -50242, 242, 0, 0, 39, '241'),
	(243, 1, 0, -50242, 243, 0, 0, 39, '242'),
	(243, 1, 0, -50242, 244, 0, 0, 39, '243'),
	(243, 1, 0, -50242, 245, 0, 0, 39, '244'),
	(243, 1, 0, -50242, 246, 0, 0, 39, '245'),
	(243, 1, 0, -50242, 247, 0, 0, 39, '246'),
	(243, 1, 0, -50242, 248, 0, 0, 39, '247'),
	(243, 1, 0, -50242, 249, 0, 0, 39, '248'),
	(243, 1, 0, -50242, 250, 0, 0, 39, '249'),
	(243, 1, 0, -50242, 251, 0, 0, 39, '250'),
	(243, 1, 0, -50242, 252, 0, 0, 39, '251'),
	(243, 1, 0, -50242, 253, 0, 0, 39, '252'),
	(243, 1, 0, -50242, 254, 0, 0, 39, '253'),
	(243, 1, 0, -50242, 255, 0, 0, 39, '254'),
	(243, 1, 0, -50242, 256, 0, 0, 39, '255'),
	(243, 1, 0, -50242, 257, 0, 0, 39, '256'),
	(243, 1, 0, -50242, 258, 0, 0, 39, '257'),
	(243, 1, 0, -50242, 259, 0, 0, 39, '258'),
	(243, 1, 0, -50242, 260, 0, 0, 39, '259'),
	(243, 1, 0, -50242, 261, 0, 0, 39, '260'),
	(243, 1, 0, -50242, 262, 0, 0, 39, '261'),
	(243, 1, 0, -50242, 263, 0, 0, 39, '262'),
	(243, 1, 0, -50242, 264, 0, 0, 39, '263'),
	(243, 1, 0, -50242, 265, 0, 0, 39, '264'),
	(243, 1, 0, -50242, 266, 0, 0, 39, '265'),
	(243, 1, 0, -50242, 267, 0, 0, 39, '266'),
	(243, 1, 0, -50242, 268, 0, 0, 39, '267'),
	(243, 1, 0, -50242, 269, 0, 0, 39, '268'),
	(243, 1, 0, -50242, 270, 0, 0, 39, '269'),
	(243, 1, 0, -50242, 271, 0, 0, 39, '270'),
	(243, 1, 0, -50242, 272, 0, 0, 39, '271'),
	(243, 1, 0, -50242, 273, 0, 0, 39, '272'),
	(243, 1, 0, -50242, 274, 0, 0, 39, '273'),
	(243, 1, 0, -50242, 275, 0, 0, 39, '274'),
	(243, 1, 0, -50242, 276, 0, 0, 39, '275'),
	(243, 1, 0, -50242, 277, 0, 0, 39, '276'),
	(243, 1, 0, -50242, 278, 0, 0, 39, '277'),
	(243, 1, 0, -50242, 279, 0, 0, 39, '278'),
	(243, 1, 0, -50242, 280, 0, 0, 39, '279'),
	(243, 1, 0, -50242, 281, 0, 0, 39, '280'),
	(243, 1, 0, -50242, 282, 0, 0, 39, '281'),
	(243, 1, 0, -50242, 283, 0, 0, 39, '282'),
	(243, 1, 0, -50242, 284, 0, 0, 39, '283'),
	(243, 1, 0, -50242, 285, 0, 0, 39, '284'),
	(243, 1, 0, -50242, 286, 0, 0, 39, '285'),
	(243, 1, 0, -50242, 287, 0, 0, 39, '286'),
	(243, 1, 0, -50242, 288, 0, 0, 39, '287'),
	(243, 1, 0, -50242, 289, 0, 0, 39, '288'),
	(243, 1, 0, -50242, 290, 0, 0, 39, '289'),
	(243, 1, 0, -50242, 291, 0, 0, 39, '290'),
	(243, 1, 0, -50242, 292, 0, 0, 39, '291'),
	(243, 1, 0, -50242, 293, 0, 0, 39, '292'),
	(243, 1, 0, -50242, 294, 0, 0, 39, '293'),
	(243, 1, 0, -50242, 295, 0, 0, 39, '294'),
	(243, 1, 0, -50242, 296, 0, 0, 39, '295'),
	(243, 1, 0, -50242, 297, 0, 0, 39, '296'),
	(243, 1, 0, -50242, 298, 0, 0, 39, '297'),
	(243, 1, 0, -50242, 299, 0, 0, 39, '298'),
	(243, 1, 0, -50242, 300, 0, 0, 39, '299'),
	(243, 1, 0, -50242, 301, 0, 0, 39, '300'),
	(243, 1, 0, -50242, 302, 0, 0, 39, '301'),
	(243, 1, 0, -50242, 303, 0, 0, 39, '302'),
	(243, 1, 0, -50242, 304, 0, 0, 39, '303'),
	(243, 1, 0, -50242, 305, 0, 0, 39, '304'),
	(243, 1, 0, -50242, 306, 0, 0, 39, '305'),
	(243, 1, 0, -50242, 307, 0, 0, 39, '306'),
	(243, 1, 0, -50242, 308, 0, 0, 39, '307'),
	(243, 1, 0, -50242, 309, 0, 0, 39, '308'),
	(243, 1, 0, -50242, 310, 0, 0, 39, '309'),
	(243, 1, 0, -50242, 311, 0, 0, 39, '310'),
	(243, 1, 0, -50242, 312, 0, 0, 39, '311'),
	(243, 1, 0, -50242, 313, 0, 0, 39, '312'),
	(243, 1, 0, -50242, 314, 0, 0, 39, '313'),
	(243, 1, 0, -50242, 315, 0, 0, 39, '314'),
	(243, 1, 0, -50242, 316, 0, 0, 39, '315'),
	(243, 1, 0, -50242, 317, 0, 0, 39, '316'),
	(243, 1, 0, -50242, 318, 0, 0, 39, '317'),
	(243, 1, 0, -50242, 319, 0, 0, 39, '318'),
	(243, 1, 0, -50242, 320, 0, 0, 39, '319'),
	(243, 1, 0, -50242, 321, 0, 0, 39, '320'),
	(243, 1, 0, -50242, 322, 0, 0, 39, '321'),
	(243, 1, 0, -50242, 323, 0, 0, 39, '322'),
	(243, 1, 0, -50242, 324, 0, 0, 39, '323'),
	(243, 1, 0, -50242, 325, 0, 0, 39, '324'),
	(243, 1, 0, -50242, 326, 0, 0, 39, '325'),
	(243, 1, 0, -50242, 327, 0, 0, 39, '326'),
	(243, 1, 0, -50242, 328, 0, 0, 39, '327'),
	(243, 1, 0, -50242, 329, 0, 0, 39, '328'),
	(243, 1, 0, -50242, 330, 0, 0, 39, '329'),
	(243, 1, 0, -50242, 331, 0, 0, 39, '330'),
	(243, 1, 0, -50242, 332, 0, 0, 39, '331'),
	(243, 1, 0, -50242, 333, 0, 0, 39, '332'),
	(243, 1, 0, -50242, 334, 0, 0, 39, '333'),
	(243, 1, 0, -50242, 335, 0, 0, 39, '334'),
	(243, 1, 0, -50242, 336, 0, 0, 39, '335'),
	(243, 1, 0, -50242, 337, 0, 0, 39, '336'),
	(243, 1, 0, -50242, 338, 0, 0, 39, '337'),
	(243, 1, 0, -50242, 339, 0, 0, 39, '338'),
	(243, 1, 0, -50242, 340, 0, 0, 39, '339'),
	(243, 1, 0, -50242, 341, 0, 0, 39, '340'),
	(243, 1, 0, -50242, 342, 0, 0, 39, '341'),
	(243, 1, 0, -50242, 343, 0, 0, 39, '342'),
	(243, 1, 0, -50242, 344, 0, 0, 39, '343'),
	(243, 1, 0, -50242, 345, 0, 0, 39, '344'),
	(243, 1, 0, -50242, 346, 0, 0, 39, '345'),
	(243, 1, 0, -50242, 347, 0, 0, 39, '346'),
	(243, 1, 0, -50242, 348, 0, 0, 39, '347'),
	(243, 1, 0, -50242, 349, 0, 0, 39, '348'),
	(243, 1, 0, -50242, 350, 0, 0, 39, '349'),
	(243, 1, 0, -50242, 351, 0, 0, 39, '350'),
	(243, 1, 0, -50242, 352, 0, 0, 39, '351'),
	(243, 1, 0, -50242, 353, 0, 0, 39, '352'),
	(243, 1, 0, -50242, 354, 0, 0, 39, '353'),
	(243, 1, 0, -50242, 355, 0, 0, 39, '354'),
	(243, 1, 0, -50242, 356, 0, 0, 39, '355'),
	(243, 1, 0, -50242, 357, 0, 0, 39, '356'),
	(243, 1, 0, -50242, 358, 0, 0, 39, '357'),
	(243, 1, 0, -50242, 359, 0, 0, 39, '358'),
	(243, 1, 0, -50242, 360, 0, 0, 39, '359'),
	(243, 1, 0, -50242, 361, 0, 0, 39, '360'),
	(243, 1, 0, -50242, 362, 0, 0, 39, '361'),
	(243, 1, 0, -50242, 363, 0, 0, 39, '362'),
	(243, 1, 0, -50242, 364, 0, 0, 39, '363'),
	(243, 1, 0, -50242, 365, 0, 0, 39, '364'),
	(243, 1, 0, -50242, 366, 0, 0, 39, '365'),
	(243, 1, 0, -50242, 367, 0, 0, 39, '366'),
	(243, 1, 0, -50242, 368, 0, 0, 39, '367'),
	(243, 1, 0, -50242, 369, 0, 0, 39, '368'),
	(243, 1, 0, -50242, 370, 0, 0, 39, '369'),
	(243, 1, 0, -50242, 371, 0, 0, 39, '370'),
	(243, 1, 0, -50242, 372, 0, 0, 39, '371'),
	(243, 1, 0, -50242, 373, 0, 0, 39, '372'),
	(243, 1, 0, -50242, 374, 0, 0, 39, '373'),
	(243, 1, 0, -50242, 375, 0, 0, 39, '374'),
	(243, 1, 0, -50242, 376, 0, 0, 39, '375'),
	(243, 1, 0, -50242, 377, 0, 0, 39, '376'),
	(243, 1, 0, -50242, 378, 0, 0, 39, '377'),
	(243, 1, 0, -50242, 379, 0, 0, 39, '378'),
	(243, 1, 0, -50242, 380, 0, 0, 39, '379'),
	(243, 1, 0, -50242, 381, 0, 0, 39, '380'),
	(243, 1, 0, -50242, 382, 0, 0, 39, '381'),
	(243, 1, 0, -50242, 383, 0, 0, 39, '382'),
	(243, 1, 0, -50242, 384, 0, 0, 39, '383'),
	(243, 1, 0, -50242, 385, 0, 0, 39, '384'),
	(243, 1, 0, -50242, 386, 0, 0, 39, '385'),
	(243, 1, 0, -50242, 387, 0, 0, 39, '386'),
	(243, 1, 0, -50242, 388, 0, 0, 39, '387'),
	(243, 1, 0, -50242, 389, 0, 0, 39, '388'),
	(243, 1, 0, -50242, 390, 0, 0, 39, '389'),
	(243, 1, 0, -50242, 391, 0, 0, 39, '390'),
	(243, 1, 0, -50242, 392, 0, 0, 39, '391'),
	(243, 1, 0, -50242, 393, 0, 0, 39, '392'),
	(243, 1, 0, -50242, 394, 0, 0, 39, '393'),
	(243, 1, 0, -50242, 395, 0, 0, 39, '394'),
	(243, 1, 0, -50242, 396, 0, 0, 39, '395'),
	(243, 1, 0, -50242, 397, 0, 0, 39, '396'),
	(243, 1, 0, -50242, 398, 0, 0, 39, '397'),
	(243, 1, 0, -50242, 399, 0, 0, 39, '398'),
	(243, 1, 0, -50242, 400, 0, 0, 39, '399'),
	(243, 1, 0, -50242, 401, 0, 0, 39, '400'),
	(243, 1, 0, -50242, 402, 0, 0, 39, '401'),
	(243, 1, 0, -50242, 403, 0, 0, 39, '402'),
	(243, 1, 0, -50242, 404, 0, 0, 39, '403'),
	(243, 1, 0, -50242, 405, 0, 0, 39, '404'),
	(243, 1, 0, -50242, 406, 0, 0, 39, '405'),
	(243, 1, 0, -50242, 407, 0, 0, 39, '406'),
	(243, 1, 0, -50242, 408, 0, 0, 39, '407'),
	(243, 1, 0, -50242, 409, 0, 0, 39, '408'),
	(243, 1, 0, -50242, 410, 0, 0, 39, '409'),
	(243, 1, 0, -50242, 411, 0, 0, 39, '410'),
	(243, 1, 0, -50242, 412, 0, 0, 39, '411'),
	(243, 1, 0, -50242, 413, 0, 0, 39, '412'),
	(243, 1, 0, -50242, 414, 0, 0, 39, '413'),
	(243, 1, 0, -50242, 415, 0, 0, 39, '414'),
	(243, 1, 0, -50242, 416, 0, 0, 39, '415'),
	(243, 1, 0, -50242, 417, 0, 0, 39, '416'),
	(243, 1, 0, -50242, 418, 0, 0, 39, '417'),
	(243, 1, 0, -50242, 419, 0, 0, 39, '418'),
	(243, 1, 0, -50242, 420, 0, 0, 39, '419'),
	(243, 1, 0, -50242, 421, 0, 0, 39, '420'),
	(243, 1, 0, -50242, 422, 0, 0, 39, '421'),
	(243, 1, 0, -50242, 423, 0, 0, 39, '422'),
	(243, 1, 0, -50242, 424, 0, 0, 39, '423'),
	(243, 1, 0, -50242, 425, 0, 0, 39, '424'),
	(243, 1, 0, -50242, 426, 0, 0, 39, '425'),
	(243, 1, 0, -50242, 427, 0, 0, 39, '426'),
	(243, 1, 0, -50242, 428, 0, 0, 39, '427'),
	(243, 1, 0, -50242, 429, 0, 0, 39, '428'),
	(243, 1, 0, -50242, 430, 0, 0, 39, '429'),
	(243, 1, 0, -50242, 431, 0, 0, 39, '430'),
	(243, 1, 0, -50242, 432, 0, 0, 39, '431'),
	(243, 1, 0, -50242, 433, 0, 0, 39, '432'),
	(243, 1, 0, -50242, 434, 0, 0, 39, '433'),
	(243, 1, 0, -50242, 435, 0, 0, 39, '434'),
	(243, 1, 0, -50242, 436, 0, 0, 39, '435'),
	(243, 1, 0, -50242, 437, 0, 0, 39, '436'),
	(243, 1, 0, -50242, 438, 0, 0, 39, '437'),
	(243, 1, 0, -50242, 439, 0, 0, 39, '438'),
	(243, 1, 0, -50242, 440, 0, 0, 39, '439'),
	(243, 1, 0, -50242, 441, 0, 0, 39, '440'),
	(243, 1, 0, -50242, 442, 0, 0, 39, '441'),
	(243, 1, 0, -50242, 443, 0, 0, 39, '442'),
	(243, 1, 0, -50242, 444, 0, 0, 39, '443'),
	(243, 1, 0, -50242, 445, 0, 0, 39, '444'),
	(243, 1, 0, -50242, 446, 0, 0, 39, '445'),
	(243, 1, 0, -50242, 447, 0, 0, 39, '446'),
	(243, 1, 0, -50242, 448, 0, 0, 39, '447'),
	(243, 1, 0, -50242, 449, 0, 0, 39, '448'),
	(243, 1, 0, -50242, 450, 0, 0, 39, '449'),
	(243, 1, 0, -50242, 451, 0, 0, 39, '450'),
	(243, 1, 0, -50242, 452, 0, 0, 39, '451'),
	(243, 1, 0, -50242, 453, 0, 0, 39, '452'),
	(243, 1, 0, -50242, 454, 0, 0, 39, '453'),
	(243, 1, 0, -50242, 455, 0, 0, 39, '454'),
	(243, 1, 0, -50242, 456, 0, 0, 39, '455'),
	(243, 1, 0, -50242, 457, 0, 0, 39, '456'),
	(243, 1, 0, -50242, 458, 0, 0, 39, '457'),
	(243, 1, 0, -50242, 459, 0, 0, 39, '458'),
	(243, 1, 0, -50242, 460, 0, 0, 39, '459'),
	(243, 1, 0, -50242, 461, 0, 0, 39, '460'),
	(243, 1, 0, -50242, 462, 0, 0, 39, '461'),
	(243, 1, 0, -50242, 463, 0, 0, 39, '462'),
	(243, 1, 0, -50242, 464, 0, 0, 39, '463'),
	(243, 1, 0, -50242, 465, 0, 0, 39, '464'),
	(243, 1, 0, -50242, 466, 0, 0, 39, '465'),
	(243, 1, 0, -50242, 467, 0, 0, 39, '466'),
	(243, 1, 0, -50242, 468, 0, 0, 39, '467'),
	(243, 1, 0, -50242, 469, 0, 0, 39, '468'),
	(243, 1, 0, -50242, 470, 0, 0, 39, '469'),
	(243, 1, 0, -50242, 471, 0, 0, 39, '470'),
	(243, 1, 0, -50242, 472, 0, 0, 39, '471'),
	(243, 1, 0, -50242, 473, 0, 0, 39, '472'),
	(243, 1, 0, -50242, 474, 0, 0, 39, '473'),
	(243, 1, 0, -50242, 475, 0, 0, 39, '474'),
	(243, 1, 0, -50242, 476, 0, 0, 39, '475'),
	(243, 1, 0, -50242, 477, 0, 0, 39, '476'),
	(243, 1, 0, -50242, 478, 0, 0, 39, '477'),
	(243, 1, 0, -50242, 479, 0, 0, 39, '478'),
	(243, 1, 0, -50242, 480, 0, 0, 39, '479'),
	(243, 1, 0, -50242, 481, 0, 0, 39, '480'),
	(243, 1, 0, -50242, 482, 0, 0, 39, '481'),
	(243, 1, 0, -50242, 483, 0, 0, 39, '482'),
	(243, 1, 0, -50242, 484, 0, 0, 39, '483'),
	(243, 1, 0, -50242, 485, 0, 0, 39, '484'),
	(243, 1, 0, -50242, 486, 0, 0, 39, '485'),
	(243, 1, 0, -50242, 487, 0, 0, 39, '486'),
	(243, 1, 0, -50242, 488, 0, 0, 39, '487'),
	(243, 1, 0, -50242, 489, 0, 0, 39, '488'),
	(243, 1, 0, -50242, 490, 0, 0, 39, '489'),
	(243, 1, 0, -50242, 491, 0, 0, 39, '490'),
	(243, 1, 0, -50242, 492, 0, 0, 39, '491'),
	(243, 1, 0, -50242, 493, 0, 0, 39, '492'),
	(243, 1, 0, -50242, 494, 0, 0, 39, '493'),
	(243, 1, 0, -50242, 495, 0, 0, 39, '494'),
	(243, 1, 0, -50242, 496, 0, 0, 39, '495'),
	(243, 1, 0, -50242, 497, 0, 0, 39, '496'),
	(243, 1, 0, -50242, 498, 0, 0, 39, '497'),
	(243, 1, 0, -50242, 499, 0, 0, 39, '498'),
	(243, 1, 0, -50242, 500, 0, 0, 39, '499'),
	(243, 1, 0, -50242, 501, 0, 0, 39, '500'),
	(243, 1, 0, -50242, 502, 0, 0, 39, '501'),
	(243, 1, 0, -50242, 503, 0, 0, 39, '502'),
	(243, 1, 0, -50242, 504, 0, 0, 39, '503'),
	(243, 1, 0, -50242, 505, 0, 0, 39, '504'),
	(243, 1, 0, -50242, 506, 0, 0, 39, '505'),
	(243, 1, 0, -50242, 507, 0, 0, 39, '506'),
	(243, 1, 0, -50242, 508, 0, 0, 39, '507'),
	(243, 1, 0, -50242, 509, 0, 0, 39, '508'),
	(243, 1, 0, -50242, 510, 0, 0, 39, '509'),
	(243, 1, 0, -50242, 511, 0, 0, 39, '510'),
	(243, 1, 0, -50242, 512, 0, 0, 39, '511'),
	(243, 1, 0, -50242, 513, 0, 0, 39, '512'),
	(243, 1, 0, -50242, 514, 0, 0, 39, '513'),
	(243, 1, 0, -50242, 515, 0, 0, 39, '514'),
	(243, 1, 0, -50242, 516, 0, 0, 39, '515'),
	(243, 1, 0, -50242, 517, 0, 0, 39, '516'),
	(243, 1, 0, -50242, 518, 0, 0, 39, '517'),
	(243, 1, 0, -50242, 519, 0, 0, 39, '518'),
	(243, 1, 0, -50242, 520, 0, 0, 39, '519'),
	(243, 1, 0, -50242, 521, 0, 0, 39, '520'),
	(243, 1, 0, -50242, 522, 0, 0, 39, '521'),
	(243, 1, 0, -50242, 523, 0, 0, 39, '522'),
	(243, 1, 0, -50242, 524, 0, 0, 39, '523'),
	(243, 1, 0, -50242, 525, 0, 0, 39, '524'),
	(243, 1, 0, -50242, 526, 0, 0, 39, '525'),
	(243, 1, 0, -50242, 527, 0, 0, 39, '526'),
	(243, 1, 0, -50242, 528, 0, 0, 39, '527'),
	(243, 1, 0, -50242, 529, 0, 0, 39, '528'),
	(243, 1, 0, -50242, 530, 0, 0, 39, '529'),
	(243, 1, 0, -50242, 531, 0, 0, 39, '530'),
	(243, 1, 0, -50242, 532, 0, 0, 39, '531'),
	(243, 1, 0, -50242, 533, 0, 0, 39, '532'),
	(243, 1, 0, -50242, 534, 0, 0, 39, '533'),
	(243, 1, 0, -50242, 535, 0, 0, 39, '534'),
	(243, 1, 0, -50242, 536, 0, 0, 39, '535'),
	(243, 1, 0, -50242, 537, 0, 0, 39, '536'),
	(243, 1, 0, -50242, 538, 0, 0, 39, '537'),
	(243, 1, 0, -50242, 539, 0, 0, 39, '538'),
	(243, 1, 0, -50242, 540, 0, 0, 39, '539'),
	(243, 1, 0, -50242, 541, 0, 0, 39, '540'),
	(243, 1, 0, -50242, 542, 0, 0, 39, '541'),
	(243, 1, 0, -50242, 543, 0, 0, 39, '542'),
	(243, 1, 0, -50242, 544, 0, 0, 39, '543'),
	(243, 1, 0, -50242, 545, 0, 0, 39, '544'),
	(243, 1, 0, -50242, 546, 0, 0, 39, '545'),
	(243, 1, 0, -50242, 547, 0, 0, 39, '546'),
	(243, 1, 0, -50242, 548, 0, 0, 39, '547'),
	(243, 1, 0, -50242, 549, 0, 0, 39, '548'),
	(243, 1, 0, -50242, 550, 0, 0, 39, '549'),
	(243, 1, 0, -50242, 551, 0, 0, 39, '550'),
	(243, 1, 0, -50242, 552, 0, 0, 39, '551'),
	(243, 1, 0, -50242, 553, 0, 0, 39, '552'),
	(243, 1, 0, -50242, 554, 0, 0, 39, '553'),
	(243, 1, 0, -50242, 555, 0, 0, 39, '554'),
	(243, 1, 0, -50242, 556, 0, 0, 39, '555'),
	(243, 1, 0, -50242, 557, 0, 0, 39, '556'),
	(243, 1, 0, -50242, 558, 0, 0, 39, '557'),
	(243, 1, 0, -50242, 559, 0, 0, 39, '558'),
	(243, 1, 0, -50242, 560, 0, 0, 39, '559'),
	(243, 1, 0, -50242, 561, 0, 0, 39, '560'),
	(243, 1, 0, -50242, 562, 0, 0, 39, '561'),
	(243, 1, 0, -50242, 563, 0, 0, 39, '562'),
	(243, 1, 0, -50242, 564, 0, 0, 39, '563'),
	(243, 1, 0, -50242, 565, 0, 0, 39, '564'),
	(243, 1, 0, -50242, 566, 0, 0, 39, '565'),
	(243, 1, 0, -50242, 567, 0, 0, 39, '566'),
	(243, 1, 0, -50242, 568, 0, 0, 39, '567'),
	(243, 1, 0, -50242, 569, 0, 0, 39, '568'),
	(243, 1, 0, -50242, 570, 0, 0, 39, '569'),
	(243, 1, 0, -50242, 571, 0, 0, 39, '570'),
	(243, 1, 0, -50242, 572, 0, 0, 39, '571'),
	(243, 1, 0, -50242, 573, 0, 0, 39, '572'),
	(243, 1, 0, -50242, 574, 0, 0, 39, '573'),
	(243, 1, 0, -50242, 575, 0, 0, 39, '574'),
	(243, 1, 0, -50242, 576, 0, 0, 39, '575'),
	(243, 1, 0, -50242, 577, 0, 0, 39, '576'),
	(243, 1, 0, -50242, 578, 0, 0, 39, '577'),
	(243, 1, 0, -50242, 579, 0, 0, 39, '578'),
	(243, 1, 0, -50242, 580, 0, 0, 39, '579'),
	(243, 1, 0, -50242, 581, 0, 0, 39, '580'),
	(243, 1, 0, -50242, 582, 0, 0, 39, '581'),
	(243, 1, 0, -50242, 583, 0, 0, 39, '582'),
	(243, 1, 0, -50242, 584, 0, 0, 39, '583'),
	(243, 1, 0, -50242, 585, 0, 0, 39, '584'),
	(243, 1, 0, -50242, 586, 0, 0, 39, '585'),
	(243, 1, 0, -50242, 587, 0, 0, 39, '586'),
	(243, 1, 0, -50242, 588, 0, 0, 39, '587'),
	(243, 1, 0, -50242, 589, 0, 0, 39, '588'),
	(243, 1, 0, -50242, 590, 0, 0, 39, '589'),
	(243, 1, 0, -50242, 591, 0, 0, 39, '590'),
	(243, 1, 0, -50242, 592, 0, 0, 39, '591'),
	(243, 1, 0, -50242, 593, 0, 0, 39, '592'),
	(243, 1, 0, -50242, 594, 0, 0, 39, '593'),
	(243, 1, 0, -50242, 595, 0, 0, 39, '594'),
	(243, 1, 0, -50242, 596, 0, 0, 39, '595'),
	(243, 1, 0, -50242, 597, 0, 0, 39, '596'),
	(243, 1, 0, -50242, 598, 0, 0, 39, '597'),
	(243, 1, 0, -50242, 599, 0, 0, 39, '598'),
	(243, 1, 0, -50242, 600, 0, 0, 39, '599'),
	(243, 1, 0, -50242, 601, 0, 0, 39, '600'),
	(243, 1, 0, -50242, 602, 0, 0, 39, '601'),
	(243, 1, 0, -50242, 603, 0, 0, 39, '602'),
	(243, 1, 0, -50242, 604, 0, 0, 39, '603'),
	(243, 1, 0, -50242, 605, 0, 0, 39, '604'),
	(243, 1, 0, -50242, 606, 0, 0, 39, '605'),
	(243, 1, 0, -50242, 607, 0, 0, 39, '606'),
	(243, 1, 0, -50242, 608, 0, 0, 39, '607'),
	(243, 1, 0, -50242, 609, 0, 0, 39, '608'),
	(243, 1, 0, -50242, 610, 0, 0, 39, '609'),
	(243, 1, 0, -50242, 611, 0, 0, 39, '610'),
	(243, 1, 0, -50242, 612, 0, 0, 39, '611'),
	(243, 1, 0, -50242, 613, 0, 0, 39, '612'),
	(243, 1, 0, -50242, 614, 0, 0, 39, '613'),
	(243, 1, 0, -50242, 615, 0, 0, 39, '614'),
	(243, 1, 0, -50242, 616, 0, 0, 39, '615'),
	(243, 1, 0, -50242, 617, 0, 0, 39, '616'),
	(243, 1, 0, -50242, 618, 0, 0, 39, '617'),
	(243, 1, 0, -50242, 619, 0, 0, 39, '618'),
	(243, 1, 0, -50242, 620, 0, 0, 39, '619'),
	(243, 1, 0, -50242, 621, 0, 0, 39, '620'),
	(243, 1, 0, -50242, 622, 0, 0, 39, '621'),
	(243, 1, 0, -50242, 623, 0, 0, 39, '622'),
	(243, 1, 0, -50242, 624, 0, 0, 39, '623'),
	(243, 1, 0, -50242, 625, 0, 0, 39, '624'),
	(243, 1, 0, -50242, 626, 0, 0, 39, '625'),
	(243, 1, 0, -50242, 627, 0, 0, 39, '626'),
	(243, 1, 0, -50242, 628, 0, 0, 39, '627'),
	(243, 1, 0, -50242, 629, 0, 0, 39, '628'),
	(243, 1, 0, -50242, 630, 0, 0, 39, '629'),
	(243, 1, 0, -50242, 631, 0, 0, 39, '630'),
	(243, 1, 0, -50242, 632, 0, 0, 39, '631'),
	(243, 1, 0, -50242, 633, 0, 0, 39, '632'),
	(243, 1, 0, -50242, 634, 0, 0, 39, '633'),
	(243, 1, 0, -50242, 635, 0, 0, 39, '634'),
	(243, 1, 0, -50242, 636, 0, 0, 39, '635'),
	(243, 1, 0, -50242, 637, 0, 0, 39, '636'),
	(243, 1, 0, -50242, 638, 0, 0, 39, '637'),
	(243, 1, 0, -50242, 639, 0, 0, 39, '638'),
	(243, 1, 0, -50242, 640, 0, 0, 39, '639'),
	(243, 1, 0, -50242, 641, 0, 0, 39, '640'),
	(243, 1, 0, -50242, 642, 0, 0, 39, '641'),
	(243, 1, 0, -50242, 643, 0, 0, 39, '642'),
	(243, 1, 0, -50242, 644, 0, 0, 39, '643'),
	(243, 1, 0, -50242, 645, 0, 0, 39, '644'),
	(243, 1, 0, -50242, 646, 0, 0, 39, '645'),
	(243, 1, 0, -50242, 647, 0, 0, 39, '646'),
	(243, 1, 0, -50242, 648, 0, 0, 39, '647'),
	(243, 1, 0, -50242, 649, 0, 0, 39, '648'),
	(243, 1, 0, -50242, 650, 0, 0, 39, '649'),
	(243, 1, 0, -50242, 651, 0, 0, 39, '650'),
	(243, 1, 0, -50242, 652, 0, 0, 39, '651'),
	(243, 1, 0, -50242, 653, 0, 0, 39, '652'),
	(243, 1, 0, -50242, 654, 0, 0, 39, '653'),
	(243, 1, 0, -50242, 655, 0, 0, 39, '654'),
	(243, 1, 0, -50242, 656, 0, 0, 39, '655'),
	(243, 1, 0, -50242, 657, 0, 0, 39, '656'),
	(243, 1, 0, -50242, 658, 0, 0, 39, '657'),
	(243, 1, 0, -50242, 659, 0, 0, 39, '658'),
	(243, 1, 0, -50242, 660, 0, 0, 39, '659'),
	(243, 1, 0, -50242, 661, 0, 0, 39, '660'),
	(243, 1, 0, -50242, 662, 0, 0, 39, '661'),
	(243, 1, 0, -50242, 663, 0, 0, 39, '662'),
	(243, 1, 0, -50242, 664, 0, 0, 39, '663'),
	(243, 1, 0, -50242, 665, 0, 0, 39, '664'),
	(243, 1, 0, -50242, 666, 0, 0, 39, '665'),
	(243, 1, 0, -50242, 667, 0, 0, 39, '666'),
	(243, 1, 0, -50242, 668, 0, 0, 39, '667'),
	(243, 1, 0, -50242, 669, 0, 0, 39, '668'),
	(243, 1, 0, -50242, 670, 0, 0, 39, '669'),
	(243, 1, 0, -50242, 671, 0, 0, 39, '670'),
	(243, 1, 0, -50242, 672, 0, 0, 39, '671'),
	(243, 1, 0, -50242, 673, 0, 0, 39, '672'),
	(243, 1, 0, -50242, 674, 0, 0, 39, '673'),
	(243, 1, 0, -50242, 675, 0, 0, 39, '674'),
	(243, 1, 0, -50242, 676, 0, 0, 39, '675'),
	(243, 1, 0, -50242, 677, 0, 0, 39, '676'),
	(243, 1, 0, -50242, 678, 0, 0, 39, '677'),
	(243, 1, 0, -50242, 679, 0, 0, 39, '678'),
	(243, 1, 0, -50242, 680, 0, 0, 39, '679'),
	(243, 1, 0, -50242, 681, 0, 0, 39, '680'),
	(243, 1, 0, -50242, 682, 0, 0, 39, '681'),
	(243, 1, 0, -50242, 683, 0, 0, 39, '682'),
	(243, 1, 0, -50242, 684, 0, 0, 39, '683'),
	(243, 1, 0, -50242, 685, 0, 0, 39, '684'),
	(243, 1, 0, -50242, 686, 0, 0, 39, '685'),
	(243, 1, 0, -50242, 687, 0, 0, 39, '686'),
	(243, 1, 0, -50242, 688, 0, 0, 39, '687'),
	(243, 1, 0, -50242, 689, 0, 0, 39, '688'),
	(243, 1, 0, -50242, 690, 0, 0, 39, '689'),
	(243, 1, 0, -50242, 691, 0, 0, 39, '690'),
	(243, 1, 0, -50242, 692, 0, 0, 39, '691'),
	(243, 1, 0, -50242, 693, 0, 0, 39, '692'),
	(243, 1, 0, -50242, 694, 0, 0, 39, '693'),
	(243, 1, 0, -50242, 695, 0, 0, 39, '694'),
	(243, 1, 0, -50242, 696, 0, 0, 39, '695'),
	(243, 1, 0, -50242, 697, 0, 0, 39, '696'),
	(243, 1, 0, -50242, 698, 0, 0, 39, '697'),
	(243, 1, 0, -50242, 699, 0, 0, 39, '698'),
	(243, 1, 0, -50242, 700, 0, 0, 39, '699'),
	(243, 1, 0, -50242, 701, 0, 0, 39, '700'),
	(243, 1, 0, -50242, 702, 0, 0, 39, '701'),
	(243, 1, 0, -50242, 703, 0, 0, 39, '702'),
	(243, 1, 0, -50242, 704, 0, 0, 39, '703'),
	(243, 1, 0, -50242, 705, 0, 0, 39, '704'),
	(243, 1, 0, -50242, 706, 0, 0, 39, '705'),
	(243, 1, 0, -50242, 707, 0, 0, 39, '706'),
	(243, 1, 0, -50242, 708, 0, 0, 39, '707'),
	(243, 1, 0, -50242, 709, 0, 0, 39, '708'),
	(243, 1, 0, -50242, 710, 0, 0, 39, '709'),
	(243, 1, 0, -50242, 711, 0, 0, 39, '710'),
	(243, 1, 0, -50242, 712, 0, 0, 39, '711'),
	(243, 1, 0, -50242, 713, 0, 0, 39, '712'),
	(243, 1, 0, -50242, 714, 0, 0, 39, '713'),
	(243, 1, 0, -50242, 715, 0, 0, 39, '714'),
	(243, 1, 0, -50242, 716, 0, 0, 39, '715'),
	(243, 1, 0, -50242, 717, 0, 0, 39, '716'),
	(243, 1, 0, -50242, 718, 0, 0, 39, '717'),
	(243, 1, 0, -50242, 719, 0, 0, 39, '718'),
	(243, 1, 0, -50242, 720, 0, 0, 39, '719'),
	(243, 1, 0, -50242, 721, 0, 0, 39, '720'),
	(243, 1, 0, -50242, 722, 0, 0, 39, '721'),
	(243, 1, 0, -50242, 723, 0, 0, 39, '722'),
	(243, 1, 0, -50242, 724, 0, 0, 39, '723'),
	(243, 1, 0, -50242, 725, 0, 0, 39, '724'),
	(243, 1, 0, -50242, 726, 0, 0, 39, '725'),
	(243, 1, 0, -50242, 727, 0, 0, 39, '726'),
	(243, 1, 0, -50242, 728, 0, 0, 39, '727'),
	(243, 1, 0, -50242, 729, 0, 0, 39, '728'),
	(243, 1, 0, -50242, 730, 0, 0, 39, '729'),
	(243, 1, 0, -50242, 731, 0, 0, 39, '730'),
	(243, 1, 0, -50242, 732, 0, 0, 39, '731'),
	(243, 1, 0, -50242, 733, 0, 0, 39, '732'),
	(243, 1, 0, -50242, 734, 0, 0, 39, '733'),
	(243, 1, 0, -50242, 735, 0, 0, 39, '734'),
	(243, 1, 0, -50242, 736, 0, 0, 39, '735'),
	(243, 1, 0, -50242, 737, 0, 0, 39, '736'),
	(243, 1, 0, -50242, 738, 0, 0, 39, '737'),
	(243, 1, 0, -50242, 739, 0, 0, 39, '738'),
	(243, 1, 0, -50242, 740, 0, 0, 39, '739'),
	(243, 1, 0, -50242, 741, 0, 0, 39, '740'),
	(243, 1, 0, -50242, 742, 0, 0, 39, '741'),
	(243, 1, 0, -50242, 743, 0, 0, 39, '742'),
	(243, 1, 0, -50242, 744, 0, 0, 39, '743'),
	(243, 1, 0, -50242, 745, 0, 0, 39, '744'),
	(243, 1, 0, -50242, 746, 0, 0, 39, '745'),
	(243, 1, 0, -50242, 747, 0, 0, 39, '746'),
	(243, 1, 0, -50242, 748, 0, 0, 39, '747'),
	(243, 1, 0, -50242, 749, 0, 0, 39, '748'),
	(243, 1, 0, -50242, 750, 0, 0, 39, '749'),
	(243, 1, 0, -50242, 751, 0, 0, 39, '750'),
	(243, 1, 0, -50242, 752, 0, 0, 39, '751'),
	(243, 1, 0, -50242, 753, 0, 0, 39, '752'),
	(243, 1, 0, -50242, 754, 0, 0, 39, '753'),
	(243, 1, 0, -50242, 755, 0, 0, 39, '754'),
	(243, 1, 0, -50242, 756, 0, 0, 39, '755'),
	(243, 1, 0, -50242, 757, 0, 0, 39, '756'),
	(243, 1, 0, -50242, 758, 0, 0, 39, '757'),
	(243, 1, 0, -50242, 759, 0, 0, 39, '758'),
	(243, 1, 0, -50242, 760, 0, 0, 39, '759'),
	(243, 1, 0, -50242, 761, 0, 0, 39, '760'),
	(243, 1, 0, -50242, 762, 0, 0, 39, '761'),
	(243, 1, 0, -50242, 763, 0, 0, 39, '762'),
	(243, 1, 0, -50242, 764, 0, 0, 39, '763'),
	(243, 1, 0, -50242, 765, 0, 0, 39, '764'),
	(243, 1, 0, -50242, 766, 0, 0, 39, '765'),
	(243, 1, 0, -50242, 767, 0, 0, 39, '766'),
	(243, 1, 0, -50242, 768, 0, 0, 39, '767'),
	(243, 1, 0, -50242, 769, 0, 0, 39, '768'),
	(243, 1, 0, -50242, 770, 0, 0, 39, '769'),
	(243, 1, 0, -50242, 771, 0, 0, 39, '770'),
	(243, 1, 0, -50242, 772, 0, 0, 39, '771'),
	(243, 1, 0, -50242, 773, 0, 0, 39, '772'),
	(243, 1, 0, -50242, 774, 0, 0, 39, '773'),
	(243, 1, 0, -50242, 775, 0, 0, 39, '774'),
	(243, 1, 0, -50242, 776, 0, 0, 39, '775'),
	(243, 1, 0, -50242, 777, 0, 0, 39, '776'),
	(243, 1, 0, -50242, 778, 0, 0, 39, '777'),
	(243, 1, 0, -50242, 779, 0, 0, 39, '778'),
	(243, 1, 0, -50242, 780, 0, 0, 39, '779'),
	(243, 1, 0, -50242, 781, 0, 0, 39, '780'),
	(243, 1, 0, -50242, 782, 0, 0, 39, '781'),
	(243, 1, 0, -50242, 783, 0, 0, 39, '782'),
	(243, 1, 0, -50242, 784, 0, 0, 39, '783'),
	(243, 1, 0, -50242, 785, 0, 0, 39, '784'),
	(243, 1, 0, -50242, 786, 0, 0, 39, '785'),
	(243, 1, 0, -50242, 787, 0, 0, 39, '786'),
	(243, 1, 0, -50242, 788, 0, 0, 39, '787'),
	(243, 1, 0, -50242, 789, 0, 0, 39, '788'),
	(243, 1, 0, -50242, 790, 0, 0, 39, '789'),
	(243, 1, 0, -50242, 791, 0, 0, 39, '790'),
	(243, 1, 0, -50242, 792, 0, 0, 39, '791'),
	(243, 1, 0, -50242, 793, 0, 0, 39, '792'),
	(243, 1, 0, -50242, 794, 0, 0, 39, '793'),
	(243, 1, 0, -50242, 795, 0, 0, 39, '794'),
	(243, 1, 0, -50242, 796, 0, 0, 39, '795'),
	(243, 1, 0, -50242, 797, 0, 0, 39, '796'),
	(243, 1, 0, -50242, 798, 0, 0, 39, '797'),
	(243, 1, 0, -50242, 799, 0, 0, 39, '798'),
	(243, 1, 0, -50242, 800, 0, 0, 39, '799'),
	(243, 1, 0, -50242, 801, 0, 0, 39, '800'),
	(243, 1, 0, -50242, 802, 0, 0, 39, '801'),
	(243, 1, 0, -50242, 803, 0, 0, 39, '802'),
	(243, 1, 0, -50242, 804, 0, 0, 39, '803'),
	(243, 1, 0, -50242, 805, 0, 0, 39, '804'),
	(243, 1, 0, -50242, 806, 0, 0, 39, '805'),
	(243, 1, 0, -50242, 807, 0, 0, 39, '806'),
	(243, 1, 0, -50242, 808, 0, 0, 39, '807'),
	(243, 1, 0, -50242, 809, 0, 0, 39, '808'),
	(243, 1, 0, -50242, 810, 0, 0, 39, '809'),
	(243, 1, 0, -50242, 811, 0, 0, 39, '810'),
	(243, 1, 0, -50242, 812, 0, 0, 39, '811'),
	(243, 1, 0, -50242, 813, 0, 0, 39, '812'),
	(243, 1, 0, -50242, 814, 0, 0, 39, '813'),
	(243, 1, 0, -50242, 815, 0, 0, 39, '814'),
	(243, 1, 0, -50242, 816, 0, 0, 39, '815'),
	(243, 1, 0, -50242, 817, 0, 0, 39, '816'),
	(243, 1, 0, -50242, 818, 0, 0, 39, '817'),
	(243, 1, 0, -50242, 819, 0, 0, 39, '818'),
	(243, 1, 0, -50242, 820, 0, 0, 39, '819'),
	(243, 1, 0, -50242, 821, 0, 0, 39, '820'),
	(243, 1, 0, -50242, 822, 0, 0, 39, '821'),
	(243, 1, 0, -50242, 823, 0, 0, 39, '822'),
	(243, 1, 0, -50242, 824, 0, 0, 39, '823'),
	(243, 1, 0, -50242, 825, 0, 0, 39, '824'),
	(243, 1, 0, -50242, 826, 0, 0, 39, '825'),
	(243, 1, 0, -50242, 827, 0, 0, 39, '826'),
	(243, 1, 0, -50242, 828, 0, 0, 39, '827'),
	(243, 1, 0, -50242, 829, 0, 0, 39, '828'),
	(243, 1, 0, -50242, 830, 0, 0, 39, '829'),
	(243, 1, 0, -50242, 831, 0, 0, 39, '830'),
	(243, 1, 0, -50242, 832, 0, 0, 39, '831'),
	(243, 1, 0, -50242, 833, 0, 0, 39, '832'),
	(243, 1, 0, -50242, 834, 0, 0, 39, '833'),
	(243, 1, 0, -50242, 835, 0, 0, 39, '834'),
	(243, 1, 0, -50242, 836, 0, 0, 39, '835'),
	(243, 1, 0, -50242, 837, 0, 0, 39, '836'),
	(243, 1, 0, -50242, 838, 0, 0, 39, '837'),
	(243, 1, 0, -50242, 839, 0, 0, 39, '838'),
	(243, 1, 0, -50242, 840, 0, 0, 39, '839'),
	(243, 1, 0, -50242, 841, 0, 0, 39, '840'),
	(243, 1, 0, -50242, 842, 0, 0, 39, '841'),
	(243, 1, 0, -50242, 843, 0, 0, 39, '842'),
	(243, 1, 0, -50242, 844, 0, 0, 39, '843'),
	(243, 1, 0, -50242, 845, 0, 0, 39, '844'),
	(243, 1, 0, -50242, 846, 0, 0, 39, '845'),
	(243, 1, 0, -50242, 847, 0, 0, 39, '846'),
	(243, 1, 0, -50242, 848, 0, 0, 39, '847'),
	(243, 1, 0, -50242, 849, 0, 0, 39, '848'),
	(243, 1, 0, -50242, 850, 0, 0, 39, '849'),
	(243, 1, 0, -50242, 851, 0, 0, 39, '850'),
	(243, 1, 0, -50242, 852, 0, 0, 39, '851'),
	(243, 1, 0, -50242, 853, 0, 0, 39, '852'),
	(243, 1, 0, -50242, 854, 0, 0, 39, '853'),
	(243, 1, 0, -50242, 855, 0, 0, 39, '854'),
	(243, 1, 0, -50242, 856, 0, 0, 39, '855'),
	(243, 1, 0, -50242, 857, 0, 0, 39, '856'),
	(243, 1, 0, -50242, 858, 0, 0, 39, '857'),
	(243, 1, 0, -50242, 859, 0, 0, 39, '858'),
	(243, 1, 0, -50242, 860, 0, 0, 39, '859'),
	(243, 1, 0, -50242, 861, 0, 0, 39, '860'),
	(243, 1, 0, -50242, 862, 0, 0, 39, '861'),
	(243, 1, 0, -50242, 863, 0, 0, 39, '862'),
	(243, 1, 0, -50242, 864, 0, 0, 39, '863'),
	(243, 1, 0, -50242, 865, 0, 0, 39, '864'),
	(243, 1, 0, -50242, 866, 0, 0, 39, '865'),
	(243, 1, 0, -50242, 867, 0, 0, 39, '866'),
	(243, 1, 0, -50242, 868, 0, 0, 39, '867'),
	(243, 1, 0, -50242, 869, 0, 0, 39, '868'),
	(243, 1, 0, -50242, 870, 0, 0, 39, '869'),
	(243, 1, 0, -50242, 871, 0, 0, 39, '870'),
	(243, 1, 0, -50242, 872, 0, 0, 39, '871'),
	(243, 1, 0, -50242, 873, 0, 0, 39, '872'),
	(243, 1, 0, -50242, 874, 0, 0, 39, '873'),
	(243, 1, 0, -50242, 875, 0, 0, 39, '874'),
	(243, 1, 0, -50242, 876, 0, 0, 39, '875'),
	(243, 1, 0, -50242, 877, 0, 0, 39, '876'),
	(243, 1, 0, -50242, 878, 0, 0, 39, '877'),
	(243, 1, 0, -50242, 879, 0, 0, 39, '878'),
	(243, 1, 0, -50242, 880, 0, 0, 39, '879'),
	(243, 1, 0, -50242, 881, 0, 0, 39, '880'),
	(243, 1, 0, -50242, 882, 0, 0, 39, '881'),
	(243, 1, 0, -50242, 883, 0, 0, 39, '882'),
	(243, 1, 0, -50242, 884, 0, 0, 39, '883'),
	(243, 1, 0, -50242, 885, 0, 0, 39, '884'),
	(243, 1, 0, -50242, 886, 0, 0, 39, '885'),
	(243, 1, 0, -50242, 887, 0, 0, 39, '886'),
	(243, 1, 0, -50242, 888, 0, 0, 39, '887'),
	(243, 1, 0, -50242, 889, 0, 0, 39, '888'),
	(243, 1, 0, -50242, 890, 0, 0, 39, '889'),
	(243, 1, 0, -50242, 891, 0, 0, 39, '890'),
	(243, 1, 0, -50242, 892, 0, 0, 39, '891'),
	(243, 1, 0, -50242, 893, 0, 0, 39, '892'),
	(243, 1, 0, -50242, 894, 0, 0, 39, '893'),
	(243, 1, 0, -50242, 895, 0, 0, 39, '894'),
	(243, 1, 0, -50242, 896, 0, 0, 39, '895'),
	(243, 1, 0, -50242, 897, 0, 0, 39, '896'),
	(243, 1, 0, -50242, 898, 0, 0, 39, '897'),
	(243, 1, 0, -50242, 899, 0, 0, 39, '898'),
	(243, 1, 0, -50242, 900, 0, 0, 39, '899'),
	(243, 1, 0, -50242, 901, 0, 0, 39, '900'),
	(243, 1, 0, -50242, 902, 0, 0, 39, '901'),
	(243, 1, 0, -50242, 903, 0, 0, 39, '902'),
	(243, 1, 0, -50242, 904, 0, 0, 39, '903'),
	(243, 1, 0, -50242, 905, 0, 0, 39, '904'),
	(243, 1, 0, -50242, 906, 0, 0, 39, '905'),
	(243, 1, 0, -50242, 907, 0, 0, 39, '906'),
	(243, 1, 0, -50242, 908, 0, 0, 39, '907'),
	(243, 1, 0, -50242, 909, 0, 0, 39, '908'),
	(243, 1, 0, -50242, 910, 0, 0, 39, '909'),
	(243, 1, 0, -50242, 911, 0, 0, 39, '910'),
	(243, 1, 0, -50242, 912, 0, 0, 39, '911'),
	(243, 1, 0, -50242, 913, 0, 0, 39, '912'),
	(243, 1, 0, -50242, 914, 0, 0, 39, '913'),
	(243, 1, 0, -50242, 915, 0, 0, 39, '914'),
	(243, 1, 0, -50242, 916, 0, 0, 39, '915'),
	(243, 1, 0, -50242, 917, 0, 0, 39, '916'),
	(243, 1, 0, -50242, 918, 0, 0, 39, '917'),
	(243, 1, 0, -50242, 919, 0, 0, 39, '918'),
	(243, 1, 0, -50242, 920, 0, 0, 39, '919'),
	(243, 1, 0, -50242, 921, 0, 0, 39, '920'),
	(243, 1, 0, -50242, 922, 0, 0, 39, '921'),
	(243, 1, 0, -50242, 923, 0, 0, 39, '922'),
	(243, 1, 0, -50242, 924, 0, 0, 39, '923'),
	(243, 1, 0, -50242, 925, 0, 0, 39, '924'),
	(243, 1, 0, -50242, 926, 0, 0, 39, '925'),
	(243, 1, 0, -50242, 927, 0, 0, 39, '926'),
	(243, 1, 0, -50242, 928, 0, 0, 39, '927'),
	(243, 1, 0, -50242, 929, 0, 0, 39, '928'),
	(243, 1, 0, -50242, 930, 0, 0, 39, '929'),
	(243, 1, 0, -50242, 931, 0, 0, 39, '930'),
	(243, 1, 0, -50242, 932, 0, 0, 39, '931'),
	(243, 1, 0, -50242, 933, 0, 0, 39, '932'),
	(243, 1, 0, -50242, 934, 0, 0, 39, '933'),
	(243, 1, 0, -50242, 935, 0, 0, 39, '934'),
	(243, 1, 0, -50242, 936, 0, 0, 39, '935'),
	(243, 1, 0, -50242, 937, 0, 0, 39, '936'),
	(243, 1, 0, -50242, 938, 0, 0, 39, '937'),
	(243, 1, 0, -50242, 939, 0, 0, 39, '938'),
	(243, 1, 0, -50242, 940, 0, 0, 39, '939'),
	(243, 1, 0, -50242, 941, 0, 0, 39, '940'),
	(243, 1, 0, -50242, 942, 0, 0, 39, '941'),
	(243, 1, 0, -50242, 943, 0, 0, 39, '942'),
	(243, 1, 0, -50242, 944, 0, 0, 39, '943'),
	(243, 1, 0, -50242, 945, 0, 0, 39, '944'),
	(243, 1, 0, -50242, 946, 0, 0, 39, '945'),
	(243, 1, 0, -50242, 947, 0, 0, 39, '946'),
	(243, 1, 0, -50242, 948, 0, 0, 39, '947'),
	(243, 1, 0, -50242, 949, 0, 0, 39, '948'),
	(243, 1, 0, -50242, 950, 0, 0, 39, '949'),
	(243, 1, 0, -50242, 951, 0, 0, 39, '950'),
	(243, 1, 0, -50242, 952, 0, 0, 39, '951'),
	(243, 1, 0, -50242, 953, 0, 0, 39, '952'),
	(243, 1, 0, -50242, 954, 0, 0, 39, '953'),
	(243, 1, 0, -50242, 955, 0, 0, 39, '954'),
	(243, 1, 0, -50242, 956, 0, 0, 39, '955'),
	(243, 1, 0, -50242, 957, 0, 0, 39, '956'),
	(243, 1, 0, -50242, 958, 0, 0, 39, '957'),
	(243, 1, 0, -50242, 959, 0, 0, 39, '958'),
	(243, 1, 0, -50242, 960, 0, 0, 39, '959'),
	(243, 1, 0, -50242, 961, 0, 0, 39, '960'),
	(243, 1, 0, -50242, 962, 0, 0, 39, '961'),
	(243, 1, 0, -50242, 963, 0, 0, 39, '962'),
	(243, 1, 0, -50242, 964, 0, 0, 39, '963'),
	(243, 1, 0, -50242, 965, 0, 0, 39, '964'),
	(243, 1, 0, -50242, 966, 0, 0, 39, '965'),
	(243, 1, 0, -50242, 967, 0, 0, 39, '966'),
	(243, 1, 0, -50242, 968, 0, 0, 39, '967'),
	(243, 1, 0, -50242, 969, 0, 0, 39, '968'),
	(243, 1, 0, -50242, 970, 0, 0, 39, '969'),
	(243, 1, 0, -50242, 971, 0, 0, 39, '970'),
	(243, 1, 0, -50242, 972, 0, 0, 39, '971'),
	(243, 1, 0, -50242, 973, 0, 0, 39, '972'),
	(243, 1, 0, -50242, 974, 0, 0, 39, '973'),
	(243, 1, 0, -50242, 975, 0, 0, 39, '974'),
	(243, 1, 0, -50242, 976, 0, 0, 39, '975'),
	(243, 1, 0, -50242, 977, 0, 0, 39, '976'),
	(243, 1, 0, -50242, 978, 0, 0, 39, '977'),
	(243, 1, 0, -50242, 979, 0, 0, 39, '978'),
	(243, 1, 0, -50242, 980, 0, 0, 39, '979'),
	(243, 1, 0, -50242, 981, 0, 0, 39, '980'),
	(243, 1, 0, -50242, 982, 0, 0, 39, '981'),
	(243, 1, 0, -50242, 983, 0, 0, 39, '982'),
	(243, 1, 0, -50242, 984, 0, 0, 39, '983'),
	(243, 1, 0, -50242, 985, 0, 0, 39, '984'),
	(243, 1, 0, -50242, 986, 0, 0, 39, '985'),
	(243, 1, 0, -50242, 987, 0, 0, 39, '986'),
	(243, 1, 0, -50242, 988, 0, 0, 39, '987'),
	(243, 1, 0, -50242, 989, 0, 0, 39, '988'),
	(243, 1, 0, -50242, 990, 0, 0, 39, '989'),
	(243, 1, 0, -50242, 991, 0, 0, 39, '990'),
	(243, 1, 0, -50242, 992, 0, 0, 39, '991'),
	(243, 1, 0, -50242, 993, 0, 0, 39, '992'),
	(243, 1, 0, -50242, 994, 0, 0, 39, '993'),
	(243, 1, 0, -50242, 995, 0, 0, 39, '994'),
	(243, 1, 0, -50242, 996, 0, 0, 39, '995'),
	(243, 1, 0, -50242, 997, 0, 0, 39, '996'),
	(243, 1, 0, -50242, 998, 0, 0, 39, '997'),
	(243, 1, 0, -50242, 999, 0, 0, 39, '998'),
	(243, 1, 0, -50242, 1000, 0, 0, 39, '999'),
	(243, 1, 0, -50242, 1001, 0, 0, 39, '1000'),
	(243, 1, 0, -50242, 1002, 0, 0, 39, '1001'),
	(243, 1, 0, -50242, 1003, 0, 0, 39, '1002'),
	(243, 1, 0, -50242, 1004, 0, 0, 39, '1003'),
	(243, 1, 0, -50242, 1005, 0, 0, 39, '1004'),
	(243, 1, 0, -50242, 1006, 0, 0, 39, '1005'),
	(243, 1, 0, -50242, 1007, 0, 0, 39, '1006'),
	(243, 1, 0, -50242, 1008, 0, 0, 39, '1007'),
	(243, 1, 0, -50242, 1009, 0, 0, 39, '1008'),
	(243, 1, 0, -50242, 1010, 0, 0, 39, '1009'),
	(243, 1, 0, -50242, 1011, 0, 0, 39, '1010'),
	(243, 1, 0, -50242, 1012, 0, 0, 39, '1011'),
	(243, 1, 0, -50242, 1013, 0, 0, 39, '1012'),
	(243, 1, 0, -50242, 1014, 0, 0, 39, '1013'),
	(243, 1, 0, -50242, 1015, 0, 0, 39, '1014'),
	(243, 1, 0, -50242, 1016, 0, 0, 39, '1015'),
	(243, 1, 0, -50242, 1017, 0, 0, 39, '1016'),
	(243, 1, 0, -50242, 1018, 0, 0, 39, '1017'),
	(243, 1, 0, -50242, 1019, 0, 0, 39, '1018'),
	(243, 1, 0, -50242, 1020, 0, 0, 39, '1019'),
	(243, 1, 0, -50242, 1021, 0, 0, 39, '1020'),
	(243, 1, 0, -50242, 1022, 0, 0, 39, '1021'),
	(243, 1, 0, -50242, 1023, 0, 0, 39, '1022'),
	(243, 1, 0, -50242, 1024, 0, 0, 39, '1023'),
	(243, 1, 0, -50242, 1025, 0, 0, 39, '1024'),
	(243, 1, 0, -50242, 1026, 0, 0, 39, '1025'),
	(243, 1, 0, -50242, 1027, 0, 0, 39, '1026'),
	(243, 1, 0, -50242, 1028, 0, 0, 39, '1027'),
	(243, 1, 0, -50242, 1029, 0, 0, 39, '1028'),
	(243, 1, 0, -50242, 1030, 0, 0, 39, '1029'),
	(243, 1, 0, -50242, 1031, 0, 0, 39, '1030'),
	(243, 1, 0, -50242, 1032, 0, 0, 39, '1031'),
	(243, 1, 0, -50242, 1033, 0, 0, 39, '1032'),
	(243, 1, 0, -50242, 1034, 0, 0, 39, '1033'),
	(243, 1, 0, -50242, 1035, 0, 0, 39, '1034'),
	(243, 1, 0, -50242, 1036, 0, 0, 39, '1035'),
	(243, 1, 0, -50242, 1037, 0, 0, 39, '1036'),
	(243, 1, 0, -50242, 1038, 0, 0, 39, '1037'),
	(243, 1, 0, -50242, 1039, 0, 0, 39, '1038'),
	(243, 1, 0, -50242, 1040, 0, 0, 39, '1039'),
	(243, 1, 0, -50242, 1041, 0, 0, 39, '1040'),
	(243, 1, 0, -50242, 1042, 0, 0, 39, '1041'),
	(243, 1, 0, -50242, 1043, 0, 0, 39, '1042'),
	(243, 1, 0, -50242, 1044, 0, 0, 39, '1043'),
	(243, 1, 0, -50242, 1045, 0, 0, 39, '1044'),
	(243, 1, 0, -50242, 1046, 0, 0, 39, '1045'),
	(243, 1, 0, -50242, 1047, 0, 0, 39, '1046'),
	(243, 1, 0, -50242, 1048, 0, 0, 39, '1047'),
	(243, 1, 0, -50242, 1049, 0, 0, 39, '1048'),
	(243, 1, 0, -50242, 1050, 0, 0, 39, '1049'),
	(243, 1, 0, -50242, 1051, 0, 0, 39, '1050'),
	(243, 1, 0, -50242, 1052, 0, 0, 39, '1051'),
	(243, 1, 0, -50242, 1053, 0, 0, 39, '1052'),
	(243, 1, 0, -50242, 1054, 0, 0, 39, '1053'),
	(243, 1, 0, -50242, 1055, 0, 0, 39, '1054'),
	(243, 1, 0, -50242, 1056, 0, 0, 39, '1055'),
	(243, 1, 0, -50242, 1057, 0, 0, 39, '1056'),
	(243, 1, 0, -50242, 1058, 0, 0, 39, '1057'),
	(243, 1, 0, -50242, 1059, 0, 0, 39, '1058'),
	(243, 1, 0, -50242, 1060, 0, 0, 39, '1059'),
	(243, 1, 0, -50242, 1061, 0, 0, 39, '1060'),
	(243, 1, 0, -50242, 1062, 0, 0, 39, '1061'),
	(243, 1, 0, -50242, 1063, 0, 0, 39, '1062'),
	(243, 1, 0, -50242, 1064, 0, 0, 39, '1063'),
	(243, 1, 0, -50242, 1065, 0, 0, 39, '1064'),
	(243, 1, 0, -50242, 1066, 0, 0, 39, '1065'),
	(243, 1, 0, -50242, 1067, 0, 0, 39, '1066'),
	(243, 1, 0, -50242, 1068, 0, 0, 39, '1067'),
	(243, 1, 0, -50242, 1069, 0, 0, 39, '1068'),
	(243, 1, 0, -50242, 1070, 0, 0, 39, '1069'),
	(243, 1, 0, -50242, 1071, 0, 0, 39, '1070'),
	(243, 1, 0, -50242, 1072, 0, 0, 39, '1071'),
	(243, 1, 0, -50242, 1073, 0, 0, 39, '1072'),
	(243, 1, 0, -50242, 1074, 0, 0, 39, '1073'),
	(243, 1, 0, -50242, 1075, 0, 0, 39, '1074'),
	(243, 1, 0, -50242, 1076, 0, 0, 39, '1075'),
	(243, 1, 0, -50242, 1077, 0, 0, 39, '1076'),
	(243, 1, 0, -50242, 1078, 0, 0, 39, '1077'),
	(243, 1, 0, -50242, 1079, 0, 0, 39, '1078'),
	(243, 1, 0, -50242, 1080, 0, 0, 39, '1079'),
	(243, 1, 0, -50242, 1081, 0, 0, 39, '1080'),
	(243, 1, 0, -50242, 1082, 0, 0, 39, '1081'),
	(243, 1, 0, -50242, 1083, 0, 0, 39, '1082'),
	(243, 1, 0, -50242, 1084, 0, 0, 39, '1083'),
	(243, 1, 0, -50242, 1085, 0, 0, 39, '1084'),
	(243, 1, 0, -50242, 1086, 0, 0, 39, '1085'),
	(243, 1, 0, -50242, 1087, 0, 0, 39, '1086'),
	(243, 1, 0, -50242, 1088, 0, 0, 39, '1087'),
	(243, 1, 0, -50242, 1089, 0, 0, 39, '1088'),
	(243, 1, 0, -50242, 1090, 0, 0, 39, '1089'),
	(243, 1, 0, -50242, 1091, 0, 0, 39, '1090'),
	(243, 1, 0, -50242, 1092, 0, 0, 39, '1091'),
	(243, 1, 0, -50242, 1093, 0, 0, 39, '1092'),
	(243, 1, 0, -50242, 1094, 0, 0, 39, '1093'),
	(243, 1, 0, -50242, 1095, 0, 0, 39, '1094'),
	(243, 1, 0, -50242, 1096, 0, 0, 39, '1095'),
	(243, 1, 0, -50242, 1097, 0, 0, 39, '1096'),
	(243, 1, 0, -50242, 1098, 0, 0, 39, '1097'),
	(243, 1, 0, -50242, 1099, 0, 0, 39, '1098'),
	(243, 1, 0, -50242, 1100, 0, 0, 39, '1099'),
	(243, 1, 0, -50242, 1101, 0, 0, 39, '1100'),
	(243, 1, 0, -50242, 1102, 0, 0, 39, '1101'),
	(243, 1, 0, -50242, 1103, 0, 0, 39, '1102'),
	(243, 1, 0, -50242, 1104, 0, 0, 39, '1103'),
	(243, 1, 0, -50242, 1105, 0, 0, 39, '1104'),
	(243, 1, 0, -50242, 1106, 0, 0, 39, '1105'),
	(243, 1, 0, -50242, 1107, 0, 0, 39, '1106'),
	(243, 1, 0, -50242, 1108, 0, 0, 39, '1107'),
	(243, 1, 0, -50242, 1109, 0, 0, 39, '1108'),
	(243, 1, 0, -50242, 1110, 0, 0, 39, '1109'),
	(243, 1, 0, -50242, 1111, 0, 0, 39, '1110'),
	(243, 1, 0, -50242, 1112, 0, 0, 39, '1111'),
	(243, 1, 0, -50242, 1113, 0, 0, 39, '1112'),
	(243, 1, 0, -50242, 1114, 0, 0, 39, '1113'),
	(243, 1, 0, -50242, 1115, 0, 0, 39, '1114'),
	(243, 1, 0, -50242, 1116, 0, 0, 39, '1115'),
	(243, 1, 0, -50242, 1117, 0, 0, 39, '1116'),
	(243, 1, 0, -50242, 1118, 0, 0, 39, '1117'),
	(243, 1, 0, -50242, 1119, 0, 0, 39, '1118'),
	(243, 1, 0, -50242, 1120, 0, 0, 39, '1119'),
	(243, 1, 0, -50242, 1121, 0, 0, 39, '1120'),
	(243, 1, 0, -50242, 1122, 0, 0, 39, '1121'),
	(243, 1, 0, -50242, 1123, 0, 0, 39, '1122'),
	(243, 1, 0, -50242, 1124, 0, 0, 39, '1123'),
	(243, 1, 0, -50242, 1125, 0, 0, 39, '1124'),
	(243, 1, 0, -50242, 1126, 0, 0, 39, '1125'),
	(243, 1, 0, -50242, 1127, 0, 0, 39, '1126'),
	(243, 1, 0, -50242, 1128, 0, 0, 39, '1127'),
	(243, 1, 0, -50242, 1129, 0, 0, 39, '1128'),
	(243, 1, 0, -50242, 1130, 0, 0, 39, '1129'),
	(243, 1, 0, -50242, 1131, 0, 0, 39, '1130'),
	(243, 1, 0, -50242, 1132, 0, 0, 39, '1131'),
	(243, 1, 0, -50242, 1133, 0, 0, 39, '1132'),
	(243, 1, 0, -50242, 1134, 0, 0, 39, '1133'),
	(243, 1, 0, -50242, 1135, 0, 0, 39, '1134'),
	(243, 1, 0, -50242, 1136, 0, 0, 39, '1135'),
	(243, 1, 0, -50242, 1137, 0, 0, 39, '1136'),
	(243, 1, 0, -50242, 1138, 0, 0, 39, '1137'),
	(243, 1, 0, -50242, 1139, 0, 0, 39, '1138'),
	(243, 1, 0, -50242, 1140, 0, 0, 39, '1139'),
	(243, 1, 0, -50242, 1141, 0, 0, 39, '1140'),
	(243, 1, 0, -50242, 1142, 0, 0, 39, '1141'),
	(243, 1, 0, -50242, 1143, 0, 0, 39, '1142'),
	(243, 1, 0, -50242, 1144, 0, 0, 39, '1143'),
	(243, 1, 0, -50242, 1145, 0, 0, 39, '1144'),
	(243, 1, 0, -50242, 1146, 0, 0, 39, '1145'),
	(243, 1, 0, -50242, 1147, 0, 0, 39, '1146'),
	(243, 1, 0, -50242, 1148, 0, 0, 39, '1147'),
	(243, 1, 0, -50242, 1149, 0, 0, 39, '1148'),
	(243, 1, 0, -50242, 1150, 0, 0, 39, '1149'),
	(243, 1, 0, -50242, 1151, 0, 0, 39, '1150'),
	(243, 1, 0, -50242, 1152, 0, 0, 39, '1151'),
	(243, 1, 0, -50242, 1153, 0, 0, 39, '1152'),
	(243, 1, 0, -50242, 1154, 0, 0, 39, '1153'),
	(243, 1, 0, -50242, 1155, 0, 0, 39, '1154'),
	(243, 1, 0, -50242, 1156, 0, 0, 39, '1155'),
	(243, 1, 0, -50242, 1157, 0, 0, 39, '1156'),
	(243, 1, 0, -50242, 1158, 0, 0, 39, '1157'),
	(243, 1, 0, -50242, 1159, 0, 0, 39, '1158'),
	(243, 1, 0, -50242, 1160, 0, 0, 39, '1159'),
	(243, 1, 0, -50242, 1161, 0, 0, 39, '1160'),
	(243, 1, 0, -50242, 1162, 0, 0, 39, '1161'),
	(243, 1, 0, -50242, 1163, 0, 0, 39, '1162'),
	(243, 1, 0, -50242, 1164, 0, 0, 39, '1163'),
	(243, 1, 0, -50242, 1165, 0, 0, 39, '1164'),
	(243, 1, 0, -50242, 1166, 0, 0, 39, '1165'),
	(243, 1, 0, -50242, 1167, 0, 0, 39, '1166'),
	(243, 1, 0, -50242, 1168, 0, 0, 39, '1167'),
	(243, 1, 0, -50242, 1169, 0, 0, 39, '1168'),
	(243, 1, 0, -50242, 1170, 0, 0, 39, '1169'),
	(243, 1, 0, -50242, 1171, 0, 0, 39, '1170'),
	(243, 1, 0, -50242, 1172, 0, 0, 39, '1171'),
	(243, 1, 0, -50242, 1173, 0, 0, 39, '1172'),
	(243, 1, 0, -50242, 1174, 0, 0, 39, '1173'),
	(243, 1, 0, -50242, 1175, 0, 0, 39, '1174'),
	(243, 1, 0, -50242, 1176, 0, 0, 39, '1175'),
	(243, 1, 0, -50242, 1177, 0, 0, 39, '1176'),
	(243, 1, 0, -50242, 1178, 0, 0, 39, '1177'),
	(243, 1, 0, -50242, 1179, 0, 0, 39, '1178'),
	(243, 1, 0, -50242, 1180, 0, 0, 39, '1179'),
	(243, 1, 0, -50242, 1181, 0, 0, 39, '1180'),
	(243, 1, 0, -50242, 1182, 0, 0, 39, '1181'),
	(243, 1, 0, -50242, 1183, 0, 0, 39, '1182'),
	(243, 1, 0, -50242, 1184, 0, 0, 39, '1183'),
	(243, 1, 0, -50242, 1185, 0, 0, 39, '1184'),
	(243, 1, 0, -50242, 1186, 0, 0, 39, '1185'),
	(243, 1, 0, -50242, 1187, 0, 0, 39, '1186'),
	(243, 1, 0, -50242, 1188, 0, 0, 39, '1187'),
	(243, 1, 0, -50242, 1189, 0, 0, 39, '1188'),
	(243, 1, 0, -50242, 1190, 0, 0, 39, '1189'),
	(243, 1, 0, -50242, 1191, 0, 0, 39, '1190'),
	(243, 1, 0, -50242, 1192, 0, 0, 39, '1191'),
	(243, 1, 0, -50242, 1193, 0, 0, 39, '1192'),
	(243, 1, 0, -50242, 1194, 0, 0, 39, '1193'),
	(243, 1, 0, -50242, 1195, 0, 0, 39, '1194'),
	(243, 1, 0, -50242, 1196, 0, 0, 39, '1195'),
	(243, 1, 0, -50242, 1197, 0, 0, 39, '1196'),
	(243, 1, 0, -50242, 1198, 0, 0, 39, '1197'),
	(243, 1, 0, -50242, 1199, 0, 0, 39, '1198'),
	(243, 1, 0, -50242, 1200, 0, 0, 39, '1199'),
	(243, 1, 0, -50242, 1201, 0, 0, 39, '1200'),
	(243, 1, 0, -50242, 1202, 0, 0, 39, '1201'),
	(243, 1, 0, -50242, 1203, 0, 0, 39, '1202'),
	(243, 1, 0, -50242, 1204, 0, 0, 39, '1203'),
	(243, 1, 0, -50242, 1205, 0, 0, 39, '1204'),
	(243, 1, 0, -50242, 1206, 0, 0, 39, '1205'),
	(243, 1, 0, -50242, 1207, 0, 0, 39, '1206'),
	(243, 1, 0, -50242, 1208, 0, 0, 39, '1207'),
	(243, 1, 0, -50242, 1209, 0, 0, 39, '1208'),
	(243, 1, 0, -50242, 1210, 0, 0, 39, '1209'),
	(243, 1, 0, -50242, 1211, 0, 0, 39, '1210'),
	(243, 1, 0, -50242, 1212, 0, 0, 39, '1211'),
	(243, 1, 0, -50242, 1213, 0, 0, 39, '1212'),
	(243, 1, 0, -50242, 1214, 0, 0, 39, '1213'),
	(243, 1, 0, -50242, 1215, 0, 0, 39, '1214'),
	(243, 1, 0, -50242, 1216, 0, 0, 39, '1215'),
	(243, 1, 0, -50242, 1217, 0, 0, 39, '1216'),
	(243, 1, 0, -50242, 1218, 0, 0, 39, '1217'),
	(243, 1, 0, -50242, 1219, 0, 0, 39, '1218'),
	(243, 1, 0, -50242, 1220, 0, 0, 39, '1219'),
	(243, 1, 0, -50242, 1221, 0, 0, 39, '1220'),
	(243, 1, 0, -50242, 1222, 0, 0, 39, '1221'),
	(243, 1, 0, -50242, 1223, 0, 0, 39, '1222'),
	(243, 1, 0, -50242, 1224, 0, 0, 39, '1223'),
	(243, 1, 0, -50242, 1225, 0, 0, 39, '1224'),
	(243, 1, 0, -50242, 1226, 0, 0, 39, '1225'),
	(243, 1, 0, -50242, 1227, 0, 0, 39, '1226'),
	(243, 1, 0, -50242, 1228, 0, 0, 39, '1227'),
	(243, 1, 0, -50242, 1229, 0, 0, 39, '1228'),
	(243, 1, 0, -50242, 1230, 0, 0, 39, '1229'),
	(243, 1, 0, -50242, 1231, 0, 0, 39, '1230'),
	(243, 1, 0, -50242, 1232, 0, 0, 39, '1231'),
	(243, 1, 0, -50242, 1233, 0, 0, 39, '1232'),
	(243, 1, 0, -50242, 1234, 0, 0, 39, '1233'),
	(243, 1, 0, -50242, 1235, 0, 0, 39, '1234'),
	(243, 1, 0, -50242, 1236, 0, 0, 39, '1235'),
	(243, 1, 0, -50242, 1237, 0, 0, 39, '1236'),
	(243, 1, 0, -50242, 1238, 0, 0, 39, '1237'),
	(243, 1, 0, -50242, 1239, 0, 0, 39, '1238'),
	(243, 1, 0, -50242, 1240, 0, 0, 39, '1239'),
	(243, 1, 0, -50242, 1241, 0, 0, 39, '1240'),
	(243, 1, 0, -50242, 1242, 0, 0, 39, '1241'),
	(243, 1, 0, -50242, 1243, 0, 0, 39, '1242'),
	(243, 1, 0, -50242, 1244, 0, 0, 39, '1243'),
	(243, 1, 0, -50242, 1245, 0, 0, 39, '1244'),
	(243, 1, 0, -50242, 1246, 0, 0, 39, '1245'),
	(243, 1, 0, -50242, 1247, 0, 0, 39, '1246'),
	(243, 1, 0, -50242, 1248, 0, 0, 39, '1247'),
	(243, 1, 0, -50242, 1249, 0, 0, 39, '1248'),
	(243, 1, 0, -50242, 1250, 0, 0, 39, '1249'),
	(243, 1, 0, -50242, 1251, 0, 0, 39, '1250'),
	(243, 1, 0, -50242, 1252, 0, 0, 39, '1251'),
	(243, 1, 0, -50242, 1253, 0, 0, 39, '1252'),
	(243, 1, 0, -50242, 1254, 0, 0, 39, '1253'),
	(243, 1, 0, -50242, 1255, 0, 0, 39, '1254'),
	(243, 1, 0, -50242, 1256, 0, 0, 39, '1255'),
	(243, 1, 0, -50242, 1257, 0, 0, 39, '1256'),
	(243, 1, 0, -50242, 1258, 0, 0, 39, '1257'),
	(243, 1, 0, -50242, 1259, 0, 0, 39, '1258'),
	(243, 1, 0, -50242, 1260, 0, 0, 39, '1259'),
	(243, 1, 0, -50242, 1261, 0, 0, 39, '1260'),
	(243, 1, 0, -50242, 1262, 0, 0, 39, '1261'),
	(243, 1, 0, -50242, 1263, 0, 0, 39, '1262'),
	(243, 1, 0, -50242, 1264, 0, 0, 39, '1263'),
	(243, 1, 0, -50242, 1265, 0, 0, 39, '1264'),
	(243, 1, 0, -50242, 1266, 0, 0, 39, '1265'),
	(243, 1, 0, -50242, 1267, 0, 0, 39, '1266'),
	(243, 1, 0, -50242, 1268, 0, 0, 39, '1267'),
	(243, 1, 0, -50242, 1269, 0, 0, 39, '1268'),
	(243, 1, 0, -50242, 1270, 0, 0, 39, '1269'),
	(243, 1, 0, -50242, 1271, 0, 0, 39, '1270'),
	(243, 1, 0, -50242, 1272, 0, 0, 39, '1271'),
	(243, 1, 0, -50242, 1273, 0, 0, 39, '1272'),
	(243, 1, 0, -50242, 1274, 0, 0, 39, '1273'),
	(243, 1, 0, -50242, 1275, 0, 0, 39, '1274'),
	(243, 1, 0, -50242, 1276, 0, 0, 39, '1275'),
	(243, 1, 0, -50242, 1277, 0, 0, 39, '1276'),
	(243, 1, 0, -50242, 1278, 0, 0, 39, '1277'),
	(243, 1, 0, -50242, 1279, 0, 0, 39, '1278'),
	(243, 1, 0, -50242, 1280, 0, 0, 39, '1279'),
	(243, 1, 0, -50242, 1281, 0, 0, 39, '1280'),
	(243, 1, 0, -50242, 1282, 0, 0, 39, '1281'),
	(243, 1, 0, -50242, 1283, 0, 0, 39, '1282'),
	(243, 1, 0, -50242, 1284, 0, 0, 39, '1283'),
	(243, 1, 0, -50242, 1285, 0, 0, 39, '1284'),
	(243, 1, 0, -50242, 1286, 0, 0, 39, '1285'),
	(243, 1, 0, -50242, 1287, 0, 0, 39, '1286'),
	(243, 1, 0, -50242, 1288, 0, 0, 39, '1287'),
	(243, 1, 0, -50242, 1289, 0, 0, 39, '1288'),
	(243, 1, 0, -50242, 1290, 0, 0, 39, '1289'),
	(243, 1, 0, -50242, 1291, 0, 0, 39, '1290'),
	(243, 1, 0, -50242, 1292, 0, 0, 39, '1291'),
	(243, 1, 0, -50242, 1293, 0, 0, 39, '1292'),
	(243, 1, 0, -50242, 1294, 0, 0, 39, '1293'),
	(243, 1, 0, -50242, 1295, 0, 0, 39, '1294'),
	(243, 1, 0, -50242, 1296, 0, 0, 39, '1295'),
	(243, 1, 0, -50242, 1297, 0, 0, 39, '1296'),
	(243, 1, 0, -50242, 1298, 0, 0, 39, '1297'),
	(243, 1, 0, -50242, 1299, 0, 0, 39, '1298'),
	(243, 1, 0, -50242, 1300, 0, 0, 39, '1299'),
	(243, 1, 0, -50242, 1301, 0, 0, 39, '1300'),
	(243, 1, 0, -50242, 1302, 0, 0, 39, '1301'),
	(243, 1, 0, -50242, 1303, 0, 0, 39, '1302'),
	(243, 1, 0, -50242, 1304, 0, 0, 39, '1303'),
	(243, 1, 0, -50242, 1305, 0, 0, 39, '1304'),
	(243, 1, 0, -50242, 1306, 0, 0, 39, '1305'),
	(243, 1, 0, -50242, 1307, 0, 0, 39, '1306'),
	(243, 1, 0, -50242, 1308, 0, 0, 39, '1307'),
	(243, 1, 0, -50242, 1309, 0, 0, 39, '1308'),
	(243, 1, 0, -50242, 1310, 0, 0, 39, '1309'),
	(243, 1, 0, -50242, 1311, 0, 0, 39, '1310'),
	(243, 1, 0, -50242, 1312, 0, 0, 39, '1311'),
	(243, 1, 0, -50242, 1313, 0, 0, 39, '1312'),
	(243, 1, 0, -50242, 1314, 0, 0, 39, '1313'),
	(243, 1, 0, -50242, 1315, 0, 0, 39, '1314'),
	(243, 1, 0, -50242, 1316, 0, 0, 39, '1315'),
	(243, 1, 0, -50242, 1317, 0, 0, 39, '1316'),
	(243, 1, 0, -50242, 1318, 0, 0, 39, '1317'),
	(243, 1, 0, -50242, 1319, 0, 0, 39, '1318'),
	(243, 1, 0, -50242, 1320, 0, 0, 39, '1319'),
	(243, 1, 0, -50242, 1321, 0, 0, 39, '1320'),
	(243, 1, 0, -50242, 1322, 0, 0, 39, '1321'),
	(243, 1, 0, -50242, 1323, 0, 0, 39, '1322'),
	(243, 1, 0, -50242, 1324, 0, 0, 39, '1323'),
	(243, 1, 0, -50242, 1325, 0, 0, 39, '1324'),
	(243, 1, 0, -50242, 1326, 0, 0, 39, '1325'),
	(243, 1, 0, -50242, 1327, 0, 0, 39, '1326'),
	(243, 1, 0, -50242, 1328, 0, 0, 39, '1327'),
	(243, 1, 0, -50242, 1329, 0, 0, 39, '1328'),
	(243, 1, 0, -50242, 1330, 0, 0, 39, '1329'),
	(243, 1, 0, -50242, 1331, 0, 0, 39, '1330'),
	(243, 1, 0, -50242, 1332, 0, 0, 39, '1331'),
	(243, 1, 0, -50242, 1333, 0, 0, 39, '1332'),
	(243, 1, 0, -50242, 1334, 0, 0, 39, '1333'),
	(243, 1, 0, -50242, 1335, 0, 0, 39, '1334'),
	(243, 1, 0, -50242, 1336, 0, 0, 39, '1335'),
	(243, 1, 0, -50242, 1337, 0, 0, 39, '1336'),
	(243, 1, 0, -50242, 1338, 0, 0, 39, '1337'),
	(243, 1, 0, -50242, 1339, 0, 0, 39, '1338'),
	(243, 1, 0, -50242, 1340, 0, 0, 39, '1339'),
	(243, 1, 0, -50242, 1341, 0, 0, 39, '1340'),
	(243, 1, 0, -50242, 1342, 0, 0, 39, '1341'),
	(243, 1, 0, -50242, 1343, 0, 0, 39, '1342'),
	(243, 1, 0, -50242, 1344, 0, 0, 39, '1343'),
	(243, 1, 0, -50242, 1345, 0, 0, 39, '1344'),
	(243, 1, 0, -50242, 1346, 0, 0, 39, '1345'),
	(243, 1, 0, -50242, 1347, 0, 0, 39, '1346'),
	(243, 1, 0, -50242, 1348, 0, 0, 39, '1347'),
	(243, 1, 0, -50242, 1349, 0, 0, 39, '1348'),
	(243, 1, 0, -50242, 1350, 0, 0, 39, '1349'),
	(243, 1, 0, -50242, 1351, 0, 0, 39, '1350'),
	(243, 1, 0, -50242, 1352, 0, 0, 39, '1351'),
	(243, 1, 0, -50242, 1353, 0, 0, 39, '1352'),
	(243, 1, 0, -50242, 1354, 0, 0, 39, '1353'),
	(243, 1, 0, -50242, 1355, 0, 0, 39, '1354'),
	(243, 1, 0, -50242, 1356, 0, 0, 39, '1355'),
	(243, 1, 0, -50242, 1357, 0, 0, 39, '1356'),
	(243, 1, 0, -50242, 1358, 0, 0, 39, '1357'),
	(243, 1, 0, -50242, 1359, 0, 0, 39, '1358'),
	(243, 1, 0, -50242, 1360, 0, 0, 39, '1359'),
	(243, 1, 0, -50242, 1361, 0, 0, 39, '1360'),
	(243, 1, 0, -50242, 1362, 0, 0, 39, '1361'),
	(243, 1, 0, -50242, 1363, 0, 0, 39, '1362'),
	(243, 1, 0, -50242, 1364, 0, 0, 39, '1363'),
	(243, 1, 0, -50242, 1365, 0, 0, 39, '1364'),
	(243, 1, 0, -50242, 1366, 0, 0, 39, '1365'),
	(243, 1, 0, -50242, 1367, 0, 0, 39, '1366'),
	(243, 1, 0, -50242, 1368, 0, 0, 39, '1367'),
	(243, 1, 0, -50242, 1369, 0, 0, 39, '1368'),
	(243, 1, 0, -50242, 1370, 0, 0, 39, '1369'),
	(243, 1, 0, -50242, 1371, 0, 0, 39, '1370'),
	(243, 1, 0, -50242, 1372, 0, 0, 39, '1371'),
	(243, 1, 0, -50242, 1373, 0, 0, 39, '1372'),
	(243, 1, 0, -50242, 1374, 0, 0, 39, '1373'),
	(243, 1, 0, -50242, 1375, 0, 0, 39, '1374'),
	(243, 1, 0, -50242, 1376, 0, 0, 39, '1375'),
	(243, 1, 0, -50242, 1377, 0, 0, 39, '1376'),
	(243, 1, 0, -50242, 1378, 0, 0, 39, '1377'),
	(243, 1, 0, -50242, 1379, 0, 0, 39, '1378'),
	(243, 1, 0, -50242, 1380, 0, 0, 39, '1379'),
	(243, 1, 0, -50242, 1381, 0, 0, 39, '1380'),
	(243, 1, 0, -50242, 1382, 0, 0, 39, '1381'),
	(243, 1, 0, -50242, 1383, 0, 0, 39, '1382'),
	(243, 1, 0, -50242, 1384, 0, 0, 39, '1383'),
	(243, 1, 0, -50242, 1385, 0, 0, 39, '1384'),
	(243, 1, 0, -50242, 1386, 0, 0, 39, '1385'),
	(243, 1, 0, -50242, 1387, 0, 0, 39, '1386'),
	(243, 1, 0, -50242, 1388, 0, 0, 39, '1387'),
	(243, 1, 0, -50242, 1389, 0, 0, 39, '1388'),
	(243, 1, 0, -50242, 1390, 0, 0, 39, '1389'),
	(243, 1, 0, -50242, 1391, 0, 0, 39, '1390'),
	(243, 1, 0, -50242, 1392, 0, 0, 39, '1391'),
	(243, 1, 0, -50242, 1393, 0, 0, 39, '1392'),
	(243, 1, 0, -50242, 1394, 0, 0, 39, '1393'),
	(243, 1, 0, -50242, 1395, 0, 0, 39, '1394'),
	(243, 1, 0, -50242, 1396, 0, 0, 39, '1395'),
	(243, 1, 0, -50242, 1397, 0, 0, 39, '1396'),
	(243, 1, 0, -50242, 1398, 0, 0, 39, '1397'),
	(243, 1, 0, -50242, 1399, 0, 0, 39, '1398'),
	(243, 1, 0, -50242, 1400, 0, 0, 39, '1399'),
	(243, 1, 0, -50242, 1401, 0, 0, 39, '1400'),
	(243, 1, 0, -50242, 1402, 0, 0, 39, '1401'),
	(243, 1, 0, -50242, 1403, 0, 0, 39, '1402'),
	(243, 1, 0, -50242, 1404, 0, 0, 39, '1403'),
	(243, 1, 0, -50242, 1405, 0, 0, 39, '1404'),
	(243, 1, 0, -50242, 1406, 0, 0, 39, '1405'),
	(243, 1, 0, -50242, 1407, 0, 0, 39, '1406'),
	(243, 1, 0, -50242, 1408, 0, 0, 39, '1407'),
	(243, 1, 0, -50242, 1409, 0, 0, 39, '1408'),
	(243, 1, 0, -50242, 1410, 0, 0, 39, '1409'),
	(243, 1, 0, -50242, 1411, 0, 0, 39, '1410'),
	(243, 1, 0, -50242, 1412, 0, 0, 39, '1411'),
	(243, 1, 0, -50242, 1413, 0, 0, 39, '1412'),
	(243, 1, 0, -50242, 1414, 0, 0, 39, '1413'),
	(243, 1, 0, -50242, 1415, 0, 0, 39, '1414'),
	(243, 1, 0, -50242, 1416, 0, 0, 39, '1415'),
	(243, 1, 0, -50242, 1417, 0, 0, 39, '1416'),
	(243, 1, 0, -50242, 1418, 0, 0, 39, '1417'),
	(243, 1, 0, -50242, 1419, 0, 0, 39, '1418'),
	(243, 1, 0, -50242, 1420, 0, 0, 39, '1419'),
	(243, 1, 0, -50242, 1421, 0, 0, 39, '1420'),
	(243, 1, 0, -50242, 1422, 0, 0, 39, '1421'),
	(243, 1, 0, -50242, 1423, 0, 0, 39, '1422'),
	(243, 1, 0, -50242, 1424, 0, 0, 39, '1423'),
	(243, 1, 0, -50242, 1425, 0, 0, 39, '1424'),
	(243, 1, 0, -50242, 1426, 0, 0, 39, '1425'),
	(243, 1, 0, -50242, 1427, 0, 0, 39, '1426'),
	(243, 1, 0, -50242, 1428, 0, 0, 39, '1427'),
	(243, 1, 0, -50242, 1429, 0, 0, 39, '1428'),
	(243, 1, 0, -50242, 1430, 0, 0, 39, '1429'),
	(243, 1, 0, -50242, 1431, 0, 0, 39, '1430'),
	(243, 1, 0, -50242, 1432, 0, 0, 39, '1431'),
	(243, 1, 0, -50242, 1433, 0, 0, 39, '1432'),
	(243, 1, 0, -50242, 1434, 0, 0, 39, '1433'),
	(243, 1, 0, -50242, 1435, 0, 0, 39, '1434'),
	(243, 1, 0, -50242, 1436, 0, 0, 39, '1435'),
	(243, 1, 0, -50242, 1437, 0, 0, 39, '1436'),
	(243, 1, 0, -50242, 1438, 0, 0, 39, '1437'),
	(243, 1, 0, -50242, 1439, 0, 0, 39, '1438'),
	(243, 1, 0, -50242, 1440, 0, 0, 39, '1439'),
	(243, 1, 0, -50242, 1441, 0, 0, 39, '1440'),
	(243, 1, 0, -50242, 1442, 0, 0, 39, '1441'),
	(243, 1, 0, -50242, 1443, 0, 0, 39, '1442'),
	(243, 1, 0, -50242, 1444, 0, 0, 39, '1443'),
	(243, 1, 0, -50242, 1445, 0, 0, 39, '1444'),
	(243, 1, 0, -50242, 1446, 0, 0, 39, '1445'),
	(243, 1, 0, -50242, 1447, 0, 0, 39, '1446'),
	(243, 1, 0, -50242, 1448, 0, 0, 39, '1447'),
	(243, 1, 0, -50242, 1449, 0, 0, 39, '1448'),
	(243, 1, 0, -50242, 1450, 0, 0, 39, '1449'),
	(243, 1, 0, -50242, 1451, 0, 0, 39, '1450'),
	(243, 1, 0, -50242, 1452, 0, 0, 39, '1451'),
	(243, 1, 0, -50242, 1453, 0, 0, 39, '1452'),
	(243, 1, 0, -50242, 1454, 0, 0, 39, '1453'),
	(243, 1, 0, -50242, 1455, 0, 0, 39, '1454'),
	(243, 1, 0, -50242, 1456, 0, 0, 39, '1455'),
	(243, 1, 0, -50242, 1457, 0, 0, 39, '1456'),
	(243, 1, 0, -50242, 1458, 0, 0, 39, '1457'),
	(243, 1, 0, -50242, 1459, 0, 0, 39, '1458'),
	(243, 1, 0, -50242, 1460, 0, 0, 39, '1459'),
	(243, 1, 0, -50242, 1461, 0, 0, 39, '1460'),
	(243, 1, 0, -50242, 1462, 0, 0, 39, '1461'),
	(243, 1, 0, -50242, 1463, 0, 0, 39, '1462'),
	(243, 1, 0, -50242, 1464, 0, 0, 39, '1463'),
	(243, 1, 0, -50242, 1465, 0, 0, 39, '1464'),
	(243, 1, 0, -50242, 1466, 0, 0, 39, '1465'),
	(243, 1, 0, -50242, 1467, 0, 0, 39, '1466'),
	(243, 1, 0, -50242, 1468, 0, 0, 39, '1467'),
	(243, 1, 0, -50242, 1469, 0, 0, 39, '1468'),
	(243, 1, 0, -50242, 1470, 0, 0, 39, '1469'),
	(243, 1, 0, -50242, 1471, 0, 0, 39, '1470'),
	(243, 1, 0, -50242, 1472, 0, 0, 39, '1471'),
	(243, 1, 0, -50242, 1473, 0, 0, 39, '1472'),
	(243, 1, 0, -50242, 1474, 0, 0, 39, '1473'),
	(243, 1, 0, -50242, 1475, 0, 0, 39, '1474'),
	(243, 1, 0, -50242, 1476, 0, 0, 39, '1475'),
	(243, 1, 0, -50242, 1477, 0, 0, 39, '1476'),
	(243, 1, 0, -50242, 1478, 0, 0, 39, '1477'),
	(243, 1, 0, -50242, 1479, 0, 0, 39, '1478'),
	(243, 1, 0, -50242, 1480, 0, 0, 39, '1479'),
	(243, 1, 0, -50242, 1481, 0, 0, 39, '1480'),
	(243, 1, 0, -50242, 1482, 0, 0, 39, '1481'),
	(243, 1, 0, -50242, 1483, 0, 0, 39, '1482'),
	(243, 1, 0, -50242, 1484, 0, 0, 39, '1483'),
	(243, 1, 0, -50242, 1485, 0, 0, 39, '1484'),
	(243, 1, 0, -50242, 1486, 0, 0, 39, '1485'),
	(243, 1, 0, -50242, 1487, 0, 0, 39, '1486'),
	(243, 1, 0, -50242, 1488, 0, 0, 39, '1487'),
	(243, 1, 0, -50242, 1489, 0, 0, 39, '1488'),
	(243, 1, 0, -50242, 1490, 0, 0, 39, '1489'),
	(243, 1, 0, -50242, 1491, 0, 0, 39, '1490'),
	(243, 1, 0, -50242, 1492, 0, 0, 39, '1491'),
	(243, 1, 0, -50242, 1493, 0, 0, 39, '1492'),
	(243, 1, 0, -50242, 1494, 0, 0, 39, '1493'),
	(243, 1, 0, -50242, 1495, 0, 0, 39, '1494'),
	(243, 1, 0, -50242, 1496, 0, 0, 39, '1495'),
	(243, 1, 0, -50242, 1497, 0, 0, 39, '1496'),
	(243, 1, 0, -50242, 1498, 0, 0, 39, '1497'),
	(243, 1, 0, -50242, 1499, 0, 0, 39, '1498'),
	(243, 1, 0, -50242, 1500, 0, 0, 39, '1499'),
	(243, 1, 0, -50242, 1501, 0, 0, 39, '1500'),
	(243, 1, 0, -50242, 1502, 0, 0, 39, '1501'),
	(243, 1, 0, -50242, 1503, 0, 0, 39, '1502'),
	(243, 1, 0, -50242, 1504, 0, 0, 39, '1503'),
	(243, 1, 0, -50242, 1505, 0, 0, 39, '1504'),
	(243, 1, 0, -50242, 1506, 0, 0, 39, '1505'),
	(243, 1, 0, -50242, 1507, 0, 0, 39, '1506'),
	(243, 1, 0, -50242, 1508, 0, 0, 39, '1507'),
	(243, 1, 0, -50242, 1509, 0, 0, 39, '1508'),
	(243, 1, 0, -50242, 1510, 0, 0, 39, '1509'),
	(243, 1, 0, -50242, 1511, 0, 0, 39, '1510'),
	(243, 1, 0, -50242, 1512, 0, 0, 39, '1511'),
	(243, 1, 0, -50242, 1513, 0, 0, 39, '1512'),
	(243, 1, 0, -50242, 1514, 0, 0, 39, '1513'),
	(243, 1, 0, -50242, 1515, 0, 0, 39, '1514'),
	(243, 1, 0, -50242, 1516, 0, 0, 39, '1515'),
	(243, 1, 0, -50242, 1517, 0, 0, 39, '1516'),
	(243, 1, 0, -50242, 1518, 0, 0, 39, '1517'),
	(243, 1, 0, -50242, 1519, 0, 0, 39, '1518'),
	(243, 1, 0, -50242, 1520, 0, 0, 39, '1519'),
	(243, 1, 0, -50242, 1521, 0, 0, 39, '1520'),
	(243, 1, 0, -50242, 1522, 0, 0, 39, '1521'),
	(243, 1, 0, -50242, 1523, 0, 0, 39, '1522'),
	(243, 1, 0, -50242, 1524, 0, 0, 39, '1523'),
	(243, 1, 0, -50242, 1525, 0, 0, 39, '1524'),
	(243, 1, 0, -50242, 1526, 0, 0, 39, '1525'),
	(243, 1, 0, -50242, 1527, 0, 0, 39, '1526'),
	(243, 1, 0, -50242, 1528, 0, 0, 39, '1527'),
	(243, 1, 0, -50242, 1529, 0, 0, 39, '1528'),
	(243, 1, 0, -50242, 1530, 0, 0, 39, '1529'),
	(243, 1, 0, -50242, 1531, 0, 0, 39, '1530'),
	(243, 1, 0, -50242, 1532, 0, 0, 39, '1531'),
	(243, 1, 0, -50242, 1533, 0, 0, 39, '1532'),
	(243, 1, 0, -50242, 1534, 0, 0, 39, '1533'),
	(243, 1, 0, -50242, 1535, 0, 0, 39, '1534'),
	(243, 1, 0, -50242, 1536, 0, 0, 39, '1535'),
	(243, 1, 0, -50242, 1537, 0, 0, 39, '1536'),
	(243, 1, 0, -50242, 1538, 0, 0, 39, '1537'),
	(243, 1, 0, -50242, 1539, 0, 0, 39, '1538'),
	(243, 1, 0, -50242, 1540, 0, 0, 39, '1539'),
	(243, 1, 0, -50242, 1541, 0, 0, 39, '1540'),
	(243, 1, 0, -50242, 1542, 0, 0, 39, '1541'),
	(243, 1, 0, -50242, 1543, 0, 0, 39, '1542'),
	(243, 1, 0, -50242, 1544, 0, 0, 39, '1543'),
	(243, 1, 0, -50242, 1545, 0, 0, 39, '1544'),
	(243, 1, 0, -50242, 1546, 0, 0, 39, '1545'),
	(243, 1, 0, -50242, 1547, 0, 0, 39, '1546'),
	(243, 1, 0, -50242, 1548, 0, 0, 39, '1547'),
	(243, 1, 0, -50242, 1549, 0, 0, 39, '1548'),
	(243, 1, 0, -50242, 1550, 0, 0, 39, '1549'),
	(243, 1, 0, -50242, 1551, 0, 0, 39, '1550'),
	(243, 1, 0, -50242, 1552, 0, 0, 39, '1551'),
	(243, 1, 0, -50242, 1553, 0, 0, 39, '1552'),
	(243, 1, 0, -50242, 1554, 0, 0, 39, '1553'),
	(243, 1, 0, -50242, 1555, 0, 0, 39, '1554'),
	(243, 1, 0, -50242, 1556, 0, 0, 39, '1555'),
	(243, 1, 0, -50242, 1557, 0, 0, 39, '1556'),
	(243, 1, 0, -50242, 1558, 0, 0, 39, '1557'),
	(243, 1, 0, -50242, 1559, 0, 0, 39, '1558'),
	(243, 1, 0, -50242, 1560, 0, 0, 39, '1559'),
	(243, 1, 0, -50242, 1561, 0, 0, 39, '1560'),
	(243, 1, 0, -50242, 1562, 0, 0, 39, '1561'),
	(243, 1, 0, -50242, 1563, 0, 0, 39, '1562'),
	(243, 1, 0, -50242, 1564, 0, 0, 39, '1563'),
	(243, 1, 0, -50242, 1565, 0, 0, 39, '1564'),
	(243, 1, 0, -50242, 1566, 0, 0, 39, '1565'),
	(243, 1, 0, -50242, 1567, 0, 0, 39, '1566'),
	(243, 1, 0, -50242, 1568, 0, 0, 39, '1567'),
	(243, 1, 0, -50242, 1569, 0, 0, 39, '1568'),
	(243, 1, 0, -50242, 1570, 0, 0, 39, '1569'),
	(243, 1, 0, -50242, 1571, 0, 0, 39, '1570'),
	(243, 1, 0, -50242, 1572, 0, 0, 39, '1571'),
	(243, 1, 0, -50242, 1573, 0, 0, 39, '1572'),
	(243, 1, 0, -50242, 1574, 0, 0, 39, '1573'),
	(243, 1, 0, -50242, 1575, 0, 0, 39, '1574'),
	(243, 1, 0, -50242, 1576, 0, 0, 39, '1575'),
	(243, 1, 0, -50242, 1577, 0, 0, 39, '1576'),
	(243, 1, 0, -50242, 1578, 0, 0, 39, '1577'),
	(243, 1, 0, -50242, 1579, 0, 0, 39, '1578'),
	(243, 1, 0, -50242, 1580, 0, 0, 39, '1579'),
	(243, 1, 0, -50242, 1581, 0, 0, 39, '1580'),
	(243, 1, 0, -50242, 1582, 0, 0, 39, '1581'),
	(243, 1, 0, -50242, 1583, 0, 0, 39, '1582'),
	(243, 1, 0, -50242, 1584, 0, 0, 39, '1583'),
	(243, 1, 0, -50242, 1585, 0, 0, 39, '1584'),
	(243, 1, 0, -50242, 1586, 0, 0, 39, '1585'),
	(243, 1, 0, -50242, 1587, 0, 0, 39, '1586'),
	(243, 1, 0, -50242, 1588, 0, 0, 39, '1587'),
	(243, 1, 0, -50242, 1589, 0, 0, 39, '1588'),
	(243, 1, 0, -50242, 1590, 0, 0, 39, '1589'),
	(243, 1, 0, -50242, 1591, 0, 0, 39, '1590'),
	(243, 1, 0, -50242, 1592, 0, 0, 39, '1591'),
	(243, 1, 0, -50242, 1593, 0, 0, 39, '1592'),
	(243, 1, 0, -50242, 1594, 0, 0, 39, '1593'),
	(243, 1, 0, -50242, 1595, 0, 0, 39, '1594'),
	(243, 1, 0, -50242, 1596, 0, 0, 39, '1595'),
	(243, 1, 0, -50242, 1597, 0, 0, 39, '1596'),
	(243, 1, 0, -50242, 1598, 0, 0, 39, '1597'),
	(243, 1, 0, -50242, 1599, 0, 0, 39, '1598'),
	(243, 1, 0, -50242, 1600, 0, 0, 39, '1599'),
	(243, 1, 0, -50242, 1601, 0, 0, 39, '1600'),
	(243, 1, 0, -50242, 1602, 0, 0, 39, '1601'),
	(243, 1, 0, -50242, 1603, 0, 0, 39, '1602'),
	(243, 1, 0, -50242, 1604, 0, 0, 39, '1603'),
	(243, 1, 0, -50242, 1605, 0, 0, 39, '1604'),
	(243, 1, 0, -50242, 1606, 0, 0, 39, '1605'),
	(243, 1, 0, -50242, 1607, 0, 0, 39, '1606'),
	(243, 1, 0, -50242, 1608, 0, 0, 39, '1607'),
	(243, 1, 0, -50242, 1609, 0, 0, 39, '1608'),
	(243, 1, 0, -50242, 1610, 0, 0, 39, '1609'),
	(243, 1, 0, -50242, 1611, 0, 0, 39, '1610'),
	(243, 1, 0, -50242, 1612, 0, 0, 39, '1611'),
	(243, 1, 0, -50242, 1613, 0, 0, 39, '1612'),
	(243, 1, 0, -50242, 1614, 0, 0, 39, '1613'),
	(243, 1, 0, -50242, 1615, 0, 0, 39, '1614'),
	(243, 1, 0, -50242, 1616, 0, 0, 39, '1615'),
	(243, 1, 0, -50242, 1617, 0, 0, 39, '1616'),
	(243, 1, 0, -50242, 1618, 0, 0, 39, '1617'),
	(243, 1, 0, -50242, 1619, 0, 0, 39, '1618'),
	(243, 1, 0, -50242, 1620, 0, 0, 39, '1619'),
	(243, 1, 0, -50242, 1621, 0, 0, 39, '1620'),
	(243, 1, 0, -50242, 1622, 0, 0, 39, '1621'),
	(243, 1, 0, -50242, 1623, 0, 0, 39, '1622'),
	(243, 1, 0, -50242, 1624, 0, 0, 39, '1623'),
	(243, 1, 0, -50242, 1625, 0, 0, 39, '1624'),
	(243, 1, 0, -50242, 1626, 0, 0, 39, '1625'),
	(243, 1, 0, -50242, 1627, 0, 0, 39, '1626'),
	(243, 1, 0, -50242, 1628, 0, 0, 39, '1627'),
	(243, 1, 0, -50242, 1629, 0, 0, 39, '1628'),
	(243, 1, 0, -50242, 1630, 0, 0, 39, '1629'),
	(243, 1, 0, -50242, 1631, 0, 0, 39, '1630'),
	(243, 1, 0, -50242, 1632, 0, 0, 39, '1631'),
	(243, 1, 0, -50242, 1633, 0, 0, 39, '1632'),
	(243, 1, 0, -50242, 1634, 0, 0, 39, '1633'),
	(243, 1, 0, -50242, 1635, 0, 0, 39, '1634'),
	(243, 1, 0, -50242, 1636, 0, 0, 39, '1635'),
	(243, 1, 0, -50242, 1637, 0, 0, 39, '1636'),
	(243, 1, 0, -50242, 1638, 0, 0, 39, '1637'),
	(243, 1, 0, -50242, 1639, 0, 0, 39, '1638'),
	(243, 1, 0, -50242, 1640, 0, 0, 39, '1639'),
	(243, 1, 0, -50242, 1641, 0, 0, 39, '1640'),
	(243, 1, 0, -50242, 1642, 0, 0, 39, '1641'),
	(243, 1, 0, -50242, 1643, 0, 0, 39, '1642'),
	(243, 1, 0, -50242, 1644, 0, 0, 39, '1643'),
	(243, 1, 0, -50242, 1645, 0, 0, 39, '1644'),
	(243, 1, 0, -50242, 1646, 0, 0, 39, '1645'),
	(243, 1, 0, -50242, 1647, 0, 0, 39, '1646'),
	(243, 1, 0, -50242, 1648, 0, 0, 39, '1647'),
	(243, 1, 0, -50242, 1649, 0, 0, 39, '1648'),
	(243, 1, 0, -50242, 1650, 0, 0, 39, '1649'),
	(243, 1, 0, -50242, 1651, 0, 0, 39, '1650'),
	(243, 1, 0, -50242, 1652, 0, 0, 39, '1651'),
	(243, 1, 0, -50242, 1653, 0, 0, 39, '1652'),
	(243, 1, 0, -50242, 1654, 0, 0, 39, '1653'),
	(243, 1, 0, -50242, 1655, 0, 0, 39, '1654'),
	(243, 1, 0, -50242, 1656, 0, 0, 39, '1655'),
	(243, 1, 0, -50242, 1657, 0, 0, 39, '1656'),
	(243, 1, 0, -50242, 1658, 0, 0, 39, '1657'),
	(243, 1, 0, -50242, 1659, 0, 0, 39, '1658'),
	(243, 1, 0, -50242, 1660, 0, 0, 39, '1659'),
	(243, 1, 0, -50242, 1661, 0, 0, 39, '1660'),
	(243, 1, 0, -50242, 1662, 0, 0, 39, '1661'),
	(243, 1, 0, -50242, 1663, 0, 0, 39, '1662'),
	(243, 1, 0, -50242, 1664, 0, 0, 39, '1663'),
	(243, 1, 0, -50242, 1665, 0, 0, 39, '1664'),
	(243, 1, 0, -50242, 1666, 0, 0, 39, '1665'),
	(243, 1, 0, -50242, 1667, 0, 0, 39, '1666'),
	(243, 1, 0, -50242, 1668, 0, 0, 39, '1667'),
	(243, 1, 0, -50242, 1669, 0, 0, 39, '1668'),
	(243, 1, 0, -50242, 1670, 0, 0, 39, '1669'),
	(243, 1, 0, -50242, 1671, 0, 0, 39, '1670'),
	(243, 1, 0, -50242, 1672, 0, 0, 39, '1671'),
	(243, 1, 0, -50242, 1673, 0, 0, 39, '1672'),
	(243, 1, 0, -50242, 1674, 0, 0, 39, '1673'),
	(243, 1, 0, -50242, 1675, 0, 0, 39, '1674'),
	(243, 1, 0, -50242, 1676, 0, 0, 39, '1675'),
	(243, 1, 0, -50242, 1677, 0, 0, 39, '1676'),
	(243, 1, 0, -50242, 1678, 0, 0, 39, '1677'),
	(243, 1, 0, -50242, 1679, 0, 0, 39, '1678'),
	(243, 1, 0, -50242, 1680, 0, 0, 39, '1679'),
	(243, 1, 0, -50242, 1681, 0, 0, 39, '1680'),
	(243, 1, 0, -50242, 1682, 0, 0, 39, '1681'),
	(243, 1, 0, -50242, 1683, 0, 0, 39, '1682'),
	(243, 1, 0, -50242, 1684, 0, 0, 39, '1683'),
	(243, 1, 0, -50242, 1685, 0, 0, 39, '1684'),
	(243, 1, 0, -50242, 1686, 0, 0, 39, '1685'),
	(243, 1, 0, -50242, 1687, 0, 0, 39, '1686'),
	(243, 1, 0, -50242, 1688, 0, 0, 39, '1687'),
	(243, 1, 0, -50242, 1689, 0, 0, 39, '1688'),
	(243, 1, 0, -50242, 1690, 0, 0, 39, '1689'),
	(243, 1, 0, -50242, 1691, 0, 0, 39, '1690'),
	(243, 1, 0, -50242, 1692, 0, 0, 39, '1691'),
	(243, 1, 0, -50242, 1693, 0, 0, 39, '1692'),
	(243, 1, 0, -50242, 1694, 0, 0, 39, '1693'),
	(243, 1, 0, -50242, 1695, 0, 0, 39, '1694'),
	(243, 1, 0, -50242, 1696, 0, 0, 39, '1695'),
	(243, 1, 0, -50242, 1697, 0, 0, 39, '1696'),
	(243, 1, 0, -50242, 1698, 0, 0, 39, '1697'),
	(243, 1, 0, -50242, 1699, 0, 0, 39, '1698'),
	(243, 1, 0, -50242, 1700, 0, 0, 39, '1699'),
	(243, 1, 0, -50242, 1701, 0, 0, 39, '1700'),
	(243, 1, 0, -50242, 1702, 0, 0, 39, '1701'),
	(243, 1, 0, -50242, 1703, 0, 0, 39, '1702'),
	(243, 1, 0, -50242, 1704, 0, 0, 39, '1703'),
	(243, 1, 0, -50242, 1705, 0, 0, 39, '1704'),
	(243, 1, 0, -50242, 1706, 0, 0, 39, '1705'),
	(243, 1, 0, -50242, 1707, 0, 0, 39, '1706'),
	(243, 1, 0, -50242, 1708, 0, 0, 39, '1707'),
	(243, 1, 0, -50242, 1709, 0, 0, 39, '1708'),
	(243, 1, 0, -50242, 1710, 0, 0, 39, '1709'),
	(243, 1, 0, -50242, 1711, 0, 0, 39, '1710'),
	(243, 1, 0, -50242, 1712, 0, 0, 39, '1711'),
	(243, 1, 0, -50242, 1713, 0, 0, 39, '1712'),
	(243, 1, 0, -50242, 1714, 0, 0, 39, '1713'),
	(243, 1, 0, -50242, 1715, 0, 0, 39, '1714'),
	(243, 1, 0, -50242, 1716, 0, 0, 39, '1715'),
	(243, 1, 0, -50242, 1717, 0, 0, 39, '1716'),
	(243, 1, 0, -50242, 1718, 0, 0, 39, '1717'),
	(243, 1, 0, -50242, 1719, 0, 0, 39, '1718'),
	(243, 1, 0, -50242, 1720, 0, 0, 39, '1719'),
	(243, 1, 0, -50242, 1721, 0, 0, 39, '1720'),
	(243, 1, 0, -50242, 1722, 0, 0, 39, '1721'),
	(243, 1, 0, -50242, 1723, 0, 0, 39, '1722'),
	(243, 1, 0, -50242, 1724, 0, 0, 39, '1723'),
	(243, 1, 0, -50242, 1725, 0, 0, 39, '1724'),
	(243, 1, 0, -50242, 1726, 0, 0, 39, '1725'),
	(243, 1, 0, -50242, 1727, 0, 0, 39, '1726'),
	(243, 1, 0, -50242, 1728, 0, 0, 39, '1727'),
	(243, 1, 0, -50242, 1729, 0, 0, 39, '1728'),
	(243, 1, 0, -50242, 1730, 0, 0, 39, '1729'),
	(243, 1, 0, -50242, 1731, 0, 0, 39, '1730'),
	(243, 1, 0, -50242, 1732, 0, 0, 39, '1731'),
	(243, 1, 0, -50242, 1733, 0, 0, 39, '1732'),
	(243, 1, 0, -50242, 1734, 0, 0, 39, '1733'),
	(243, 1, 0, -50242, 1735, 0, 0, 39, '1734'),
	(243, 1, 0, -50242, 1736, 0, 0, 39, '1735'),
	(243, 1, 0, -50242, 1737, 0, 0, 39, '1736'),
	(243, 1, 0, -50242, 1738, 0, 0, 39, '1737'),
	(243, 1, 0, -50242, 1739, 0, 0, 39, '1738'),
	(243, 1, 0, -50242, 1740, 0, 0, 39, '1739'),
	(243, 1, 0, -50242, 1741, 0, 0, 39, '1740'),
	(243, 1, 0, -50242, 1742, 0, 0, 39, '1741'),
	(243, 1, 0, -50242, 1743, 0, 0, 39, '1742'),
	(243, 1, 0, -50242, 1744, 0, 0, 39, '1743'),
	(243, 1, 0, -50242, 1745, 0, 0, 39, '1744'),
	(243, 1, 0, -50242, 1746, 0, 0, 39, '1745'),
	(243, 1, 0, -50242, 1747, 0, 0, 39, '1746'),
	(243, 1, 0, -50242, 1748, 0, 0, 39, '1747'),
	(243, 1, 0, -50242, 1749, 0, 0, 39, '1748'),
	(243, 1, 0, -50242, 1750, 0, 0, 39, '1749'),
	(243, 1, 0, -50242, 1751, 0, 0, 39, '1750'),
	(243, 1, 0, -50242, 1752, 0, 0, 39, '1751'),
	(243, 1, 0, -50242, 1753, 0, 0, 39, '1752'),
	(243, 1, 0, -50242, 1754, 0, 0, 39, '1753'),
	(243, 1, 0, -50242, 1755, 0, 0, 39, '1754'),
	(243, 1, 0, -50242, 1756, 0, 0, 39, '1755'),
	(243, 1, 0, -50242, 1757, 0, 0, 39, '1756'),
	(243, 1, 0, -50242, 1758, 0, 0, 39, '1757'),
	(243, 1, 0, -50242, 1759, 0, 0, 39, '1758'),
	(243, 1, 0, -50242, 1760, 0, 0, 39, '1759'),
	(243, 1, 0, -50242, 1761, 0, 0, 39, '1760'),
	(243, 1, 0, -50242, 1762, 0, 0, 39, '1761'),
	(243, 1, 0, -50242, 1763, 0, 0, 39, '1762'),
	(243, 1, 0, -50242, 1764, 0, 0, 39, '1763'),
	(243, 1, 0, -50242, 1765, 0, 0, 39, '1764'),
	(243, 1, 0, -50242, 1766, 0, 0, 39, '1765'),
	(243, 1, 0, -50242, 1767, 0, 0, 39, '1766'),
	(243, 1, 0, -50242, 1768, 0, 0, 39, '1767'),
	(243, 1, 0, -50242, 1769, 0, 0, 39, '1768'),
	(243, 1, 0, -50242, 1770, 0, 0, 39, '1769'),
	(243, 1, 0, -50242, 1771, 0, 0, 39, '1770'),
	(243, 1, 0, -50242, 1772, 0, 0, 39, '1771'),
	(243, 1, 0, -50242, 1773, 0, 0, 39, '1772'),
	(243, 1, 0, -50242, 1774, 0, 0, 39, '1773'),
	(243, 1, 0, -50242, 1775, 0, 0, 39, '1774'),
	(243, 1, 0, -50242, 1776, 0, 0, 39, '1775'),
	(243, 1, 0, -50242, 1777, 0, 0, 39, '1776'),
	(243, 1, 0, -50242, 1778, 0, 0, 39, '1777'),
	(243, 1, 0, -50242, 1779, 0, 0, 39, '1778'),
	(243, 1, 0, -50242, 1780, 0, 0, 39, '1779'),
	(243, 1, 0, -50242, 1781, 0, 0, 39, '1780'),
	(243, 1, 0, -50242, 1782, 0, 0, 39, '1781'),
	(243, 1, 0, -50242, 1783, 0, 0, 39, '1782'),
	(243, 1, 0, -50242, 1784, 0, 0, 39, '1783'),
	(243, 1, 0, -50242, 1785, 0, 0, 39, '1784'),
	(243, 1, 0, -50242, 1786, 0, 0, 39, '1785'),
	(243, 1, 0, -50242, 1787, 0, 0, 39, '1786'),
	(243, 1, 0, -50242, 1788, 0, 0, 39, '1787'),
	(243, 1, 0, -50242, 1789, 0, 0, 39, '1788'),
	(243, 1, 0, -50242, 1790, 0, 0, 39, '1789'),
	(243, 1, 0, -50242, 1791, 0, 0, 39, '1790'),
	(243, 1, 0, -50242, 1792, 0, 0, 39, '1791'),
	(243, 1, 0, -50242, 1793, 0, 0, 39, '1792'),
	(243, 1, 0, -50242, 1794, 0, 0, 39, '1793'),
	(243, 1, 0, -50242, 1795, 0, 0, 39, '1794'),
	(243, 1, 0, -50242, 1796, 0, 0, 39, '1795'),
	(243, 1, 0, -50242, 1797, 0, 0, 39, '1796'),
	(243, 1, 0, -50242, 1798, 0, 0, 39, '1797'),
	(243, 1, 0, -50242, 1799, 0, 0, 39, '1798'),
	(243, 1, 0, -50242, 1800, 0, 0, 39, '1799'),
	(243, 1, 0, -50242, 1801, 0, 0, 39, '1800'),
	(243, 1, 0, -50242, 1802, 0, 0, 39, '1801'),
	(243, 1, 0, -50242, 1803, 0, 0, 39, '1802'),
	(243, 1, 0, -50242, 1804, 0, 0, 39, '1803'),
	(243, 1, 0, -50242, 1805, 0, 0, 39, '1804'),
	(243, 1, 0, -50242, 1806, 0, 0, 39, '1805'),
	(243, 1, 0, -50242, 1807, 0, 0, 39, '1806'),
	(243, 1, 0, -50242, 1808, 0, 0, 39, '1807'),
	(243, 1, 0, -50242, 1809, 0, 0, 39, '1808'),
	(243, 1, 0, -50242, 1810, 0, 0, 39, '1809'),
	(243, 1, 0, -50242, 1811, 0, 0, 39, '1810'),
	(243, 1, 0, -50242, 1812, 0, 0, 39, '1811'),
	(243, 1, 0, -50242, 1813, 0, 0, 39, '1812'),
	(243, 1, 0, -50242, 1814, 0, 0, 39, '1813'),
	(243, 1, 0, -50242, 1815, 0, 0, 39, '1814'),
	(243, 1, 0, -50242, 1816, 0, 0, 39, '1815'),
	(243, 1, 0, -50242, 1817, 0, 0, 39, '1816'),
	(243, 1, 0, -50242, 1818, 0, 0, 39, '1817'),
	(243, 1, 0, -50242, 1819, 0, 0, 39, '1818'),
	(243, 1, 0, -50242, 1820, 0, 0, 39, '1819'),
	(243, 1, 0, -50242, 1821, 0, 0, 39, '1820'),
	(243, 1, 0, -50242, 1822, 0, 0, 39, '1821'),
	(243, 1, 0, -50242, 1823, 0, 0, 39, '1822'),
	(243, 1, 0, -50242, 1824, 0, 0, 39, '1823'),
	(243, 1, 0, -50242, 1825, 0, 0, 39, '1824'),
	(243, 1, 0, -50242, 1826, 0, 0, 39, '1825'),
	(243, 1, 0, -50242, 1827, 0, 0, 39, '1826'),
	(243, 1, 0, -50242, 1828, 0, 0, 39, '1827'),
	(243, 1, 0, -50242, 1829, 0, 0, 39, '1828'),
	(243, 1, 0, -50242, 1830, 0, 0, 39, '1829'),
	(243, 1, 0, -50242, 1831, 0, 0, 39, '1830'),
	(243, 1, 0, -50242, 1832, 0, 0, 39, '1831'),
	(243, 1, 0, -50242, 1833, 0, 0, 39, '1832'),
	(243, 1, 0, -50242, 1834, 0, 0, 39, '1833'),
	(243, 1, 0, -50242, 1835, 0, 0, 39, '1834'),
	(243, 1, 0, -50242, 1836, 0, 0, 39, '1835'),
	(243, 1, 0, -50242, 1837, 0, 0, 39, '1836'),
	(243, 1, 0, -50242, 1838, 0, 0, 39, '1837'),
	(243, 1, 0, -50242, 1839, 0, 0, 39, '1838'),
	(243, 1, 0, -50242, 1840, 0, 0, 39, '1839'),
	(243, 1, 0, -50242, 1841, 0, 0, 39, '1840'),
	(243, 1, 0, -50242, 1842, 0, 0, 39, '1841'),
	(243, 1, 0, -50242, 1843, 0, 0, 39, '1842'),
	(243, 1, 0, -50242, 1844, 0, 0, 39, '1843'),
	(243, 1, 0, -50242, 1845, 0, 0, 39, '1844'),
	(243, 1, 0, -50242, 1846, 0, 0, 39, '1845'),
	(243, 1, 0, -50242, 1847, 0, 0, 39, '1846'),
	(243, 1, 0, -50242, 1848, 0, 0, 39, '1847'),
	(243, 1, 0, -50242, 1849, 0, 0, 39, '1848'),
	(243, 1, 0, -50242, 1850, 0, 0, 39, '1849'),
	(243, 1, 0, -50242, 1851, 0, 0, 39, '1850'),
	(243, 1, 0, -50242, 1852, 0, 0, 39, '1851'),
	(243, 1, 0, -50242, 1853, 0, 0, 39, '1852'),
	(243, 1, 0, -50242, 1854, 0, 0, 39, '1853'),
	(243, 1, 0, -50242, 1855, 0, 0, 39, '1854'),
	(243, 1, 0, -50242, 1856, 0, 0, 39, '1855'),
	(243, 1, 0, -50242, 1857, 0, 0, 39, '1856'),
	(243, 1, 0, -50242, 1858, 0, 0, 39, '1857'),
	(243, 1, 0, -50242, 1859, 0, 0, 39, '1858'),
	(243, 1, 0, -50242, 1860, 0, 0, 39, '1859'),
	(243, 1, 0, -50242, 1861, 0, 0, 39, '1860'),
	(243, 1, 0, -50242, 1862, 0, 0, 39, '1861'),
	(243, 1, 0, -50242, 1863, 0, 0, 39, '1862'),
	(243, 1, 0, -50242, 1864, 0, 0, 39, '1863'),
	(243, 1, 0, -50242, 1865, 0, 0, 39, '1864'),
	(243, 1, 0, -50242, 1866, 0, 0, 39, '1865'),
	(243, 1, 0, -50242, 1867, 0, 0, 39, '1866'),
	(243, 1, 0, -50242, 1868, 0, 0, 39, '1867'),
	(243, 1, 0, -50242, 1869, 0, 0, 39, '1868'),
	(243, 1, 0, -50242, 1870, 0, 0, 39, '1869'),
	(243, 1, 0, -50242, 1871, 0, 0, 39, '1870'),
	(243, 1, 0, -50242, 1872, 0, 0, 39, '1871'),
	(243, 1, 0, -50242, 1873, 0, 0, 39, '1872'),
	(243, 1, 0, -50242, 1874, 0, 0, 39, '1873'),
	(243, 1, 0, -50242, 1875, 0, 0, 39, '1874'),
	(243, 1, 0, -50242, 1876, 0, 0, 39, '1875'),
	(243, 1, 0, -50242, 1877, 0, 0, 39, '1876'),
	(243, 1, 0, -50242, 1878, 0, 0, 39, '1877'),
	(243, 1, 0, -50242, 1879, 0, 0, 39, '1878'),
	(243, 1, 0, -50242, 1880, 0, 0, 39, '1879'),
	(243, 1, 0, -50242, 1881, 0, 0, 39, '1880'),
	(243, 1, 0, -50242, 1882, 0, 0, 39, '1881'),
	(243, 1, 0, -50242, 1883, 0, 0, 39, '1882'),
	(243, 1, 0, -50242, 1884, 0, 0, 39, '1883'),
	(243, 1, 0, -50242, 1885, 0, 0, 39, '1884'),
	(243, 1, 0, -50242, 1886, 0, 0, 39, '1885'),
	(243, 1, 0, -50242, 1887, 0, 0, 39, '1886'),
	(243, 1, 0, -50242, 1888, 0, 0, 39, '1887'),
	(243, 1, 0, -50242, 1889, 0, 0, 39, '1888'),
	(243, 1, 0, -50242, 1890, 0, 0, 39, '1889'),
	(243, 1, 0, -50242, 1891, 0, 0, 39, '1890'),
	(243, 1, 0, -50242, 1892, 0, 0, 39, '1891'),
	(243, 1, 0, -50242, 1893, 0, 0, 39, '1892'),
	(243, 1, 0, -50242, 1894, 0, 0, 39, '1893'),
	(243, 1, 0, -50242, 1895, 0, 0, 39, '1894'),
	(243, 1, 0, -50242, 1896, 0, 0, 39, '1895'),
	(243, 1, 0, -50242, 1897, 0, 0, 39, '1896'),
	(243, 1, 0, -50242, 1898, 0, 0, 39, '1897'),
	(243, 1, 0, -50242, 1899, 0, 0, 39, '1898'),
	(243, 1, 0, -50242, 1900, 0, 0, 39, '1899'),
	(243, 1, 0, -50242, 1901, 0, 0, 39, '1900'),
	(243, 1, 0, -50242, 1902, 0, 0, 39, '1901'),
	(243, 1, 0, -50242, 1903, 0, 0, 39, '1902'),
	(243, 1, 0, -50242, 1904, 0, 0, 39, '1903'),
	(243, 1, 0, -50242, 1905, 0, 0, 39, '1904'),
	(243, 1, 0, -50242, 1906, 0, 0, 39, '1905'),
	(243, 1, 0, -50242, 1907, 0, 0, 39, '1906'),
	(243, 1, 0, -50242, 1908, 0, 0, 39, '1907'),
	(243, 1, 0, -50242, 1909, 0, 0, 39, '1908'),
	(243, 1, 0, -50242, 1910, 0, 0, 39, '1909'),
	(243, 1, 0, -50242, 1911, 0, 0, 39, '1910'),
	(243, 1, 0, -50242, 1912, 0, 0, 39, '1911'),
	(243, 1, 0, -50242, 1913, 0, 0, 39, '1912'),
	(243, 1, 0, -50242, 1914, 0, 0, 39, '1913'),
	(243, 1, 0, -50242, 1915, 0, 0, 39, '1914'),
	(243, 1, 0, -50242, 1916, 0, 0, 39, '1915'),
	(243, 1, 0, -50242, 1917, 0, 0, 39, '1916'),
	(243, 1, 0, -50242, 1918, 0, 0, 39, '1917'),
	(243, 1, 0, -50242, 1919, 0, 0, 39, '1918'),
	(243, 1, 0, -50242, 1920, 0, 0, 39, '1919'),
	(243, 1, 0, -50242, 1921, 0, 0, 39, '1920'),
	(243, 1, 0, -50242, 1922, 0, 0, 39, '1921'),
	(243, 1, 0, -50242, 1923, 0, 0, 39, '1922'),
	(243, 1, 0, -50242, 1924, 0, 0, 39, '1923'),
	(243, 1, 0, -50242, 1925, 0, 0, 39, '1924'),
	(243, 1, 0, -50242, 1926, 0, 0, 39, '1925'),
	(243, 1, 0, -50242, 1927, 0, 0, 39, '1926'),
	(243, 1, 0, -50242, 1928, 0, 0, 39, '1927'),
	(243, 1, 0, -50242, 1929, 0, 0, 39, '1928'),
	(243, 1, 0, -50242, 1930, 0, 0, 39, '1929'),
	(243, 1, 0, -50242, 1931, 0, 0, 39, '1930'),
	(243, 1, 0, -50242, 1932, 0, 0, 39, '1931'),
	(243, 1, 0, -50242, 1933, 0, 0, 39, '1932'),
	(243, 1, 0, -50242, 1934, 0, 0, 39, '1933'),
	(243, 1, 0, -50242, 1935, 0, 0, 39, '1934'),
	(243, 1, 0, -50242, 1936, 0, 0, 39, '1935'),
	(243, 1, 0, -50242, 1937, 0, 0, 39, '1936'),
	(243, 1, 0, -50242, 1938, 0, 0, 39, '1937'),
	(243, 1, 0, -50242, 1939, 0, 0, 39, '1938'),
	(243, 1, 0, -50242, 1940, 0, 0, 39, '1939'),
	(243, 1, 0, -50242, 1941, 0, 0, 39, '1940'),
	(243, 1, 0, -50242, 1942, 0, 0, 39, '1941'),
	(243, 1, 0, -50242, 1943, 0, 0, 39, '1942'),
	(243, 1, 0, -50242, 1944, 0, 0, 39, '1943'),
	(243, 1, 0, -50242, 1945, 0, 0, 39, '1944'),
	(243, 1, 0, -50242, 1946, 0, 0, 39, '1945'),
	(243, 1, 0, -50242, 1947, 0, 0, 39, '1946'),
	(243, 1, 0, -50242, 1948, 0, 0, 39, '1947'),
	(243, 1, 0, -50242, 1949, 0, 0, 39, '1948'),
	(243, 1, 0, -50242, 1950, 0, 0, 39, '1949'),
	(243, 1, 0, -50242, 1951, 0, 0, 39, '1950'),
	(243, 1, 0, -50242, 1952, 0, 0, 39, '1951'),
	(243, 1, 0, -50242, 1953, 0, 0, 39, '1952'),
	(243, 1, 0, -50242, 1954, 0, 0, 39, '1953'),
	(243, 1, 0, -50242, 1955, 0, 0, 39, '1954'),
	(243, 1, 0, -50242, 1956, 0, 0, 39, '1955'),
	(243, 1, 0, -50242, 1957, 0, 0, 39, '1956'),
	(243, 1, 0, -50242, 1958, 0, 0, 39, '1957'),
	(243, 1, 0, -50242, 1959, 0, 0, 39, '1958'),
	(243, 1, 0, -50242, 1960, 0, 0, 39, '1959'),
	(243, 1, 0, -50242, 1961, 0, 0, 39, '1960'),
	(243, 1, 0, -50242, 1962, 0, 0, 39, '1961'),
	(243, 1, 0, -50242, 1963, 0, 0, 39, '1962'),
	(243, 1, 0, -50242, 1964, 0, 0, 39, '1963'),
	(243, 1, 0, -50242, 1965, 0, 0, 39, '1964'),
	(243, 1, 0, -50242, 1966, 0, 0, 39, '1965'),
	(243, 1, 0, -50242, 1967, 0, 0, 39, '1966'),
	(243, 1, 0, -50242, 1968, 0, 0, 39, '1967'),
	(243, 1, 0, -50242, 1969, 0, 0, 39, '1968'),
	(243, 1, 0, -50242, 1970, 0, 0, 39, '1969'),
	(243, 1, 0, -50242, 1971, 0, 0, 39, '1970'),
	(243, 1, 0, -50242, 1972, 0, 0, 39, '1971'),
	(243, 1, 0, -50242, 1973, 0, 0, 39, '1972'),
	(243, 1, 0, -50242, 1974, 0, 0, 39, '1973'),
	(243, 1, 0, -50242, 1975, 0, 0, 39, '1974'),
	(243, 1, 0, -50242, 1976, 0, 0, 39, '1975'),
	(243, 1, 0, -50242, 1977, 0, 0, 39, '1976'),
	(243, 1, 0, -50242, 1978, 0, 0, 39, '1977'),
	(243, 1, 0, -50242, 1979, 0, 0, 39, '1978'),
	(243, 1, 0, -50242, 1980, 0, 0, 39, '1979'),
	(243, 1, 0, -50242, 1981, 0, 0, 39, '1980'),
	(243, 1, 0, -50242, 1982, 0, 0, 39, '1981'),
	(243, 1, 0, -50242, 1983, 0, 0, 39, '1982'),
	(243, 1, 0, -50242, 1984, 0, 0, 39, '1983'),
	(243, 1, 0, -50242, 1985, 0, 0, 39, '1984'),
	(243, 1, 0, -50242, 1986, 0, 0, 39, '1985'),
	(243, 1, 0, -50242, 1987, 0, 0, 39, '1986'),
	(243, 1, 0, -50242, 1988, 0, 0, 39, '1987'),
	(243, 1, 0, -50242, 1989, 0, 0, 39, '1988'),
	(243, 1, 0, -50242, 1990, 0, 0, 39, '1989'),
	(243, 1, 0, -50242, 1991, 0, 0, 39, '1990'),
	(243, 1, 0, -50242, 1992, 0, 0, 39, '1991'),
	(243, 1, 0, -50242, 1993, 0, 0, 39, '1992'),
	(243, 1, 0, -50242, 1994, 0, 0, 39, '1993'),
	(243, 1, 0, -50242, 1995, 0, 0, 39, '1994'),
	(243, 1, 0, -50242, 1996, 0, 0, 39, '1995'),
	(243, 1, 0, -50242, 1997, 0, 0, 39, '1996'),
	(243, 1, 0, -50242, 1998, 0, 0, 39, '1997'),
	(243, 1, 0, -50242, 1999, 0, 0, 39, '1998'),
	(243, 1, 0, -50242, 2000, 0, 0, 39, '1999'),
	(243, 1, 0, -50242, 2001, 0, 0, 39, '2000'),
	(243, 1, 0, -50242, 2002, 0, 0, 39, '2001'),
	(243, 1, 0, -50242, 2003, 0, 0, 39, '2002'),
	(243, 1, 0, -50242, 2004, 0, 0, 39, '2003'),
	(243, 1, 0, -50242, 2005, 0, 0, 39, '2004'),
	(243, 1, 0, -50242, 2006, 0, 0, 39, '2005'),
	(243, 1, 0, -50242, 2007, 0, 0, 39, '2006'),
	(243, 1, 0, -50242, 2008, 0, 0, 39, '2007'),
	(243, 1, 0, -50242, 2009, 0, 0, 39, '2008'),
	(243, 1, 0, -50242, 2010, 0, 0, 39, '2009'),
	(243, 1, 0, -50242, 2011, 0, 0, 39, '2010'),
	(243, 1, 0, -50242, 2012, 0, 0, 39, '2011'),
	(243, 1, 0, -50242, 2013, 0, 0, 39, '2012'),
	(243, 1, 0, -50242, 2014, 0, 0, 39, '2013'),
	(243, 1, 0, -50242, 2015, 0, 0, 39, '2014'),
	(243, 1, 0, -50242, 2016, 0, 0, 39, '2015'),
	(243, 1, 0, -50242, 2017, 0, 0, 39, '2016'),
	(243, 1, 0, -50242, 2018, 0, 0, 39, '2017'),
	(243, 1, 0, -50242, 2019, 0, 0, 39, '2018'),
	(243, 1, 0, -50242, 2020, 0, 0, 39, '2019'),
	(243, 1, 0, -50242, 2021, 0, 0, 39, '2020'),
	(243, 1, 0, -50242, 2022, 0, 0, 39, '2021'),
	(243, 1, 0, -50242, 2023, 0, 0, 39, '2022'),
	(243, 1, 0, -50242, 2024, 0, 0, 39, '2023'),
	(243, 1, 0, -50242, 2025, 0, 0, 39, '2024'),
	(243, 1, 0, -50242, 2026, 0, 0, 39, '2025'),
	(243, 1, 0, -50242, 2027, 0, 0, 39, '2026'),
	(243, 1, 0, -50242, 2028, 0, 0, 39, '2027'),
	(243, 1, 0, -50242, 2029, 0, 0, 39, '2028'),
	(243, 1, 0, -50242, 2030, 0, 0, 39, '2029'),
	(243, 1, 0, -50242, 2031, 0, 0, 39, '2030'),
	(243, 1, 0, -50242, 2032, 0, 0, 39, '2031'),
	(243, 1, 0, -50242, 2033, 0, 0, 39, '2032'),
	(243, 1, 0, -50242, 2034, 0, 0, 39, '2033'),
	(243, 1, 0, -50242, 2035, 0, 0, 39, '2034'),
	(243, 1, 0, -50242, 2036, 0, 0, 39, '2035'),
	(243, 1, 0, -50242, 2037, 0, 0, 39, '2036'),
	(243, 1, 0, -50242, 2038, 0, 0, 39, '2037'),
	(243, 1, 0, -50242, 2039, 0, 0, 39, '2038'),
	(243, 1, 0, -50242, 2040, 0, 0, 39, '2039'),
	(243, 1, 0, -50242, 2041, 0, 0, 39, '2040'),
	(243, 1, 0, -50242, 2042, 0, 0, 39, '2041'),
	(243, 1, 0, -50242, 2043, 0, 0, 39, '2042'),
	(243, 1, 0, -50242, 2044, 0, 0, 39, '2043'),
	(243, 1, 0, -50242, 2045, 0, 0, 39, '2044'),
	(243, 1, 0, -50242, 2046, 0, 0, 39, '2045'),
	(243, 1, 0, -50242, 2047, 0, 0, 39, '2046'),
	(243, 1, 0, -50242, 2048, 0, 0, 39, '2047'),
	(243, 1, 0, -50020, 1, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 1, 1, 0, 39, '0'),
	(243, 1, 0, -50020, 1, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 1, 2, 0, 39, '0'),
	(243, 1, 0, -50020, 1, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 1, 3, 0, 39, '0'),
	(243, 1, 0, -50020, 1, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 1, 4, 0, 39, '0'),
	(243, 1, 0, -50020, 2, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 2, 1, 0, 39, '1'),
	(243, 1, 0, -50020, 2, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 2, 2, 0, 39, '1'),
	(243, 1, 0, -50020, 2, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 2, 3, 0, 39, '1'),
	(243, 1, 0, -50020, 2, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 2, 4, 0, 39, '1'),
	(243, 1, 0, -50020, 3, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 3, 1, 0, 39, '2'),
	(243, 1, 0, -50020, 3, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 3, 2, 0, 39, '2'),
	(243, 1, 0, -50020, 3, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 3, 3, 0, 39, '2'),
	(243, 1, 0, -50020, 3, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 3, 4, 0, 39, '2'),
	(243, 1, 0, -50020, 4, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 4, 1, 0, 39, '3'),
	(243, 1, 0, -50020, 4, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 4, 2, 0, 39, '3'),
	(243, 1, 0, -50020, 4, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 4, 3, 0, 39, '3'),
	(243, 1, 0, -50020, 4, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 4, 4, 0, 39, '3'),
	(243, 1, 0, -50020, 5, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 5, 1, 0, 39, '4'),
	(243, 1, 0, -50020, 5, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 5, 2, 0, 39, '4'),
	(243, 1, 0, -50020, 5, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 5, 3, 0, 39, '4'),
	(243, 1, 0, -50020, 5, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 5, 4, 0, 39, '4'),
	(243, 1, 0, -50020, 6, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 6, 1, 0, 39, '5'),
	(243, 1, 0, -50020, 6, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 6, 2, 0, 39, '5'),
	(243, 1, 0, -50020, 6, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 6, 3, 0, 39, '5'),
	(243, 1, 0, -50020, 6, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 6, 4, 0, 39, '5'),
	(243, 1, 0, -50020, 7, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 7, 1, 0, 39, '6'),
	(243, 1, 0, -50020, 7, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 7, 2, 0, 39, '6'),
	(243, 1, 0, -50020, 7, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 7, 3, 0, 39, '6'),
	(243, 1, 0, -50020, 7, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 7, 4, 0, 39, '6'),
	(243, 1, 0, -50020, 8, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 8, 1, 0, 39, '7'),
	(243, 1, 0, -50020, 8, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 8, 2, 0, 39, '7'),
	(243, 1, 0, -50020, 8, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 8, 3, 0, 39, '7'),
	(243, 1, 0, -50020, 8, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 8, 4, 0, 39, '7'),
	(243, 1, 0, -50020, 9, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 9, 1, 0, 39, '8'),
	(243, 1, 0, -50020, 9, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 9, 2, 0, 39, '8'),
	(243, 1, 0, -50020, 9, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 9, 3, 0, 39, '8'),
	(243, 1, 0, -50020, 9, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 9, 4, 0, 39, '8'),
	(243, 1, 0, -50020, 10, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 10, 1, 0, 39, '9'),
	(243, 1, 0, -50020, 10, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 10, 2, 0, 39, '9'),
	(243, 1, 0, -50020, 10, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 10, 3, 0, 39, '9'),
	(243, 1, 0, -50020, 10, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 10, 4, 0, 39, '9'),
	(243, 1, 0, -50020, 11, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 11, 1, 0, 39, '10'),
	(243, 1, 0, -50020, 11, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 11, 2, 0, 39, '10'),
	(243, 1, 0, -50020, 11, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 11, 3, 0, 39, '10'),
	(243, 1, 0, -50020, 11, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 11, 4, 0, 39, '10'),
	(243, 1, 0, -50020, 12, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 12, 1, 0, 39, '11'),
	(243, 1, 0, -50020, 12, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 12, 2, 0, 39, '11'),
	(243, 1, 0, -50020, 12, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 12, 3, 0, 39, '11'),
	(243, 1, 0, -50020, 12, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 12, 4, 0, 39, '11'),
	(243, 1, 0, -50020, 13, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 13, 1, 0, 39, '12'),
	(243, 1, 0, -50020, 13, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 13, 2, 0, 39, '12'),
	(243, 1, 0, -50020, 13, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 13, 3, 0, 39, '12'),
	(243, 1, 0, -50020, 13, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 13, 4, 0, 39, '12'),
	(243, 1, 0, -50020, 14, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 14, 1, 0, 39, '13'),
	(243, 1, 0, -50020, 14, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 14, 2, 0, 39, '13'),
	(243, 1, 0, -50020, 14, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 14, 3, 0, 39, '13'),
	(243, 1, 0, -50020, 14, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 14, 4, 0, 39, '13'),
	(243, 1, 0, -50020, 15, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 15, 1, 0, 39, '14'),
	(243, 1, 0, -50020, 15, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 15, 2, 0, 39, '14'),
	(243, 1, 0, -50020, 15, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 15, 3, 0, 39, '14'),
	(243, 1, 0, -50020, 15, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 15, 4, 0, 39, '14'),
	(243, 1, 0, -50020, 16, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 16, 1, 0, 39, '15'),
	(243, 1, 0, -50020, 16, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 16, 2, 0, 39, '15'),
	(243, 1, 0, -50020, 16, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 16, 3, 0, 39, '15'),
	(243, 1, 0, -50020, 16, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 16, 4, 0, 39, '15'),
	(243, 1, 0, -50020, 17, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 17, 1, 0, 39, '16'),
	(243, 1, 0, -50020, 17, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 17, 2, 0, 39, '16'),
	(243, 1, 0, -50020, 17, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 17, 3, 0, 39, '16'),
	(243, 1, 0, -50020, 17, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 17, 4, 0, 39, '16'),
	(243, 1, 0, -50020, 18, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 18, 1, 0, 39, '17'),
	(243, 1, 0, -50020, 18, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 18, 2, 0, 39, '17'),
	(243, 1, 0, -50020, 18, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 18, 3, 0, 39, '17'),
	(243, 1, 0, -50020, 18, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 18, 4, 0, 39, '17'),
	(243, 1, 0, -50020, 19, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 19, 1, 0, 39, '18'),
	(243, 1, 0, -50020, 19, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 19, 2, 0, 39, '18'),
	(243, 1, 0, -50020, 19, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 19, 3, 0, 39, '18'),
	(243, 1, 0, -50020, 19, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 19, 4, 0, 39, '18'),
	(243, 1, 0, -50020, 20, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 20, 1, 0, 39, '19'),
	(243, 1, 0, -50020, 20, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 20, 2, 0, 39, '19'),
	(243, 1, 0, -50020, 20, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 20, 3, 0, 39, '19'),
	(243, 1, 0, -50020, 20, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 20, 4, 0, 39, '19'),
	(243, 1, 0, -50020, 21, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 21, 1, 0, 39, '20'),
	(243, 1, 0, -50020, 21, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 21, 2, 0, 39, '20'),
	(243, 1, 0, -50020, 21, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 21, 3, 0, 39, '20'),
	(243, 1, 0, -50020, 21, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 21, 4, 0, 39, '20'),
	(243, 1, 0, -50020, 22, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 22, 1, 0, 39, '21'),
	(243, 1, 0, -50020, 22, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 22, 2, 0, 39, '21'),
	(243, 1, 0, -50020, 22, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 22, 3, 0, 39, '21'),
	(243, 1, 0, -50020, 22, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 22, 4, 0, 39, '21'),
	(243, 1, 0, -50020, 23, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 23, 1, 0, 39, '22'),
	(243, 1, 0, -50020, 23, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 23, 2, 0, 39, '22'),
	(243, 1, 0, -50020, 23, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 23, 3, 0, 39, '22'),
	(243, 1, 0, -50020, 23, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 23, 4, 0, 39, '22'),
	(243, 1, 0, -50020, 24, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 24, 1, 0, 39, '23'),
	(243, 1, 0, -50020, 24, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 24, 2, 0, 39, '23'),
	(243, 1, 0, -50020, 24, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 24, 3, 0, 39, '23'),
	(243, 1, 0, -50020, 24, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 24, 4, 0, 39, '23'),
	(243, 1, 0, -50020, 25, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 25, 1, 0, 39, '24'),
	(243, 1, 0, -50020, 25, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 25, 2, 0, 39, '24'),
	(243, 1, 0, -50020, 25, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 25, 3, 0, 39, '24'),
	(243, 1, 0, -50020, 25, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 25, 4, 0, 39, '24'),
	(243, 1, 0, -50020, 26, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 26, 1, 0, 39, '25'),
	(243, 1, 0, -50020, 26, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 26, 2, 0, 39, '25'),
	(243, 1, 0, -50020, 26, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 26, 3, 0, 39, '25'),
	(243, 1, 0, -50020, 26, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 26, 4, 0, 39, '25'),
	(243, 1, 0, -50020, 27, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 27, 1, 0, 39, '26'),
	(243, 1, 0, -50020, 27, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 27, 2, 0, 39, '26'),
	(243, 1, 0, -50020, 27, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 27, 3, 0, 39, '26'),
	(243, 1, 0, -50020, 27, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 27, 4, 0, 39, '26'),
	(243, 1, 0, -50020, 28, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 28, 1, 0, 39, '27'),
	(243, 1, 0, -50020, 28, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 28, 2, 0, 39, '27'),
	(243, 1, 0, -50020, 28, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 28, 3, 0, 39, '27'),
	(243, 1, 0, -50020, 28, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 28, 4, 0, 39, '27'),
	(243, 1, 0, -50020, 29, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 29, 1, 0, 39, '28'),
	(243, 1, 0, -50020, 29, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 29, 2, 0, 39, '28'),
	(243, 1, 0, -50020, 29, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 29, 3, 0, 39, '28'),
	(243, 1, 0, -50020, 29, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 29, 4, 0, 39, '28'),
	(243, 1, 0, -50020, 30, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 30, 1, 0, 39, '29'),
	(243, 1, 0, -50020, 30, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 30, 2, 0, 39, '29'),
	(243, 1, 0, -50020, 30, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 30, 3, 0, 39, '29'),
	(243, 1, 0, -50020, 30, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 30, 4, 0, 39, '29'),
	(243, 1, 0, -50020, 31, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 31, 1, 0, 39, '30'),
	(243, 1, 0, -50020, 31, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 31, 2, 0, 39, '30'),
	(243, 1, 0, -50020, 31, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 31, 3, 0, 39, '30'),
	(243, 1, 0, -50020, 31, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 31, 4, 0, 39, '30'),
	(243, 1, 0, -50020, 32, 1, 0, 37, '12'),
	(243, 1, 0, -50020, 32, 1, 0, 39, '31'),
	(243, 1, 0, -50020, 32, 2, 0, 37, '13'),
	(243, 1, 0, -50020, 32, 2, 0, 39, '31'),
	(243, 1, 0, -50020, 32, 3, 0, 37, '14'),
	(243, 1, 0, -50020, 32, 3, 0, 39, '31'),
	(243, 1, 0, -50020, 32, 4, 0, 37, '15'),
	(243, 1, 0, -50020, 32, 4, 0, 39, '31'),
	(243, 1, 0, -50017, 1, 1, 0, 37, '12'),
	(243, 1, 0, -50017, 1, 1, 0, 39, '0'),
	(243, 1, 0, -50017, 1, 2, 0, 37, '13'),
	(243, 1, 0, -50017, 1, 2, 0, 39, '0'),
	(243, 1, 0, -50017, 1, 3, 0, 37, '14'),
	(243, 1, 0, -50017, 1, 3, 0, 39, '0'),
	(243, 1, 0, -50017, 1, 4, 0, 37, '15'),
	(243, 1, 0, -50017, 1, 4, 0, 39, '0'),
	(243, 1, 0, -50017, 2, 1, 0, 37, '12'),
	(243, 1, 0, -50017, 2, 1, 0, 39, '1'),
	(243, 1, 0, -50017, 2, 2, 0, 37, '13'),
	(243, 1, 0, -50017, 2, 2, 0, 39, '1'),
	(243, 1, 0, -50017, 2, 3, 0, 37, '14'),
	(243, 1, 0, -50017, 2, 3, 0, 39, '1'),
	(243, 1, 0, -50017, 2, 4, 0, 37, '15'),
	(243, 1, 0, -50017, 2, 4, 0, 39, '1'),
	(243, 1, 0, -50017, 3, 1, 0, 37, '12'),
	(243, 1, 0, -50017, 3, 1, 0, 39, '2'),
	(243, 1, 0, -50017, 3, 2, 0, 37, '13'),
	(243, 1, 0, -50017, 3, 2, 0, 39, '2'),
	(243, 1, 0, -50017, 3, 3, 0, 37, '14'),
	(243, 1, 0, -50017, 3, 3, 0, 39, '2'),
	(243, 1, 0, -50017, 3, 4, 0, 37, '15'),
	(243, 1, 0, -50017, 3, 4, 0, 39, '2'),
	(243, 1, 0, -50017, 4, 1, 0, 37, '12'),
	(243, 1, 0, -50017, 4, 1, 0, 39, '3'),
	(243, 1, 0, -50017, 4, 2, 0, 37, '13'),
	(243, 1, 0, -50017, 4, 2, 0, 39, '3'),
	(243, 1, 0, -50017, 4, 3, 0, 37, '14'),
	(243, 1, 0, -50017, 4, 3, 0, 39, '3'),
	(243, 1, 0, -50017, 4, 4, 0, 37, '15'),
	(243, 1, 0, -50017, 4, 4, 0, 39, '3'),
	(243, 1, 0, -50017, 5, 1, 0, 37, '12'),
	(243, 1, 0, -50017, 5, 1, 0, 39, '4'),
	(243, 1, 0, -50017, 5, 2, 0, 37, '13'),
	(243, 1, 0, -50017, 5, 2, 0, 39, '4'),
	(243, 1, 0, -50017, 5, 3, 0, 37, '14'),
	(243, 1, 0, -50017, 5, 3, 0, 39, '4'),
	(243, 1, 0, -50017, 5, 4, 0, 37, '15'),
	(243, 1, 0, -50017, 5, 4, 0, 39, '4'),
	(243, 1, 0, -50017, 6, 1, 0, 37, '12'),
	(243, 1, 0, -50017, 6, 1, 0, 39, '5'),
	(243, 1, 0, -50017, 6, 2, 0, 37, '13'),
	(243, 1, 0, -50017, 6, 2, 0, 39, '5'),
	(243, 1, 0, -50017, 6, 3, 0, 37, '14'),
	(243, 1, 0, -50017, 6, 3, 0, 39, '5'),
	(243, 1, 0, -50017, 6, 4, 0, 37, '15'),
	(243, 1, 0, -50017, 6, 4, 0, 39, '5'),
	(243, 1, 0, -50017, 7, 1, 0, 37, '12'),
	(243, 1, 0, -50017, 7, 1, 0, 39, '6'),
	(243, 1, 0, -50017, 7, 2, 0, 37, '13'),
	(243, 1, 0, -50017, 7, 2, 0, 39, '6'),
	(243, 1, 0, -50017, 7, 3, 0, 37, '14'),
	(243, 1, 0, -50017, 7, 3, 0, 39, '6'),
	(243, 1, 0, -50017, 7, 4, 0, 37, '15'),
	(243, 1, 0, -50017, 7, 4, 0, 39, '6'),
	(243, 1, 0, -50017, 8, 1, 0, 37, '12'),
	(243, 1, 0, -50017, 8, 1, 0, 39, '7'),
	(243, 1, 0, -50017, 8, 2, 0, 37, '13'),
	(243, 1, 0, -50017, 8, 2, 0, 39, '7'),
	(243, 1, 0, -50017, 8, 3, 0, 37, '14'),
	(243, 1, 0, -50017, 8, 3, 0, 39, '7'),
	(243, 1, 0, -50017, 8, 4, 0, 37, '15'),
	(243, 1, 0, -50017, 8, 4, 0, 39, '7'),
	(243, 1, 0, -50017, 9, 1, 0, 37, '12'),
	(243, 1, 0, -50017, 9, 1, 0, 39, '8'),
	(243, 1, 0, -50017, 9, 2, 0, 37, '13'),
	(243, 1, 0, -50017, 9, 2, 0, 39, '8'),
	(243, 1, 0, -50017, 9, 3, 0, 37, '14'),
	(243, 1, 0, -50017, 9, 3, 0, 39, '8'),
	(243, 1, 0, -50017, 9, 4, 0, 37, '15'),
	(243, 1, 0, -50017, 9, 4, 0, 39, '8'),
	(243, 1, 0, -50017, 10, 1, 0, 37, '12'),
	(243, 1, 0, -50017, 10, 1, 0, 39, '9'),
	(243, 1, 0, -50017, 10, 2, 0, 37, '13'),
	(243, 1, 0, -50017, 10, 2, 0, 39, '9'),
	(243, 1, 0, -50017, 10, 3, 0, 37, '14'),
	(243, 1, 0, -50017, 10, 3, 0, 39, '9'),
	(243, 1, 0, -50017, 10, 4, 0, 37, '15'),
	(243, 1, 0, -50017, 10, 4, 0, 39, '9'),
	(243, 1, 0, -50017, 11, 1, 0, 37, '12'),
	(243, 1, 0, -50017, 11, 1, 0, 39, '10'),
	(243, 1, 0, -50017, 11, 2, 0, 37, '13'),
	(243, 1, 0, -50017, 11, 2, 0, 39, '10'),
	(243, 1, 0, -50017, 11, 3, 0, 37, '14'),
	(243, 1, 0, -50017, 11, 3, 0, 39, '10'),
	(243, 1, 0, -50017, 11, 4, 0, 37, '15'),
	(243, 1, 0, -50017, 11, 4, 0, 39, '10'),
	(243, 1, 0, -50017, 12, 1, 0, 37, '12'),
	(243, 1, 0, -50017, 12, 1, 0, 39, '11'),
	(243, 1, 0, -50017, 12, 2, 0, 37, '13'),
	(243, 1, 0, -50017, 12, 2, 0, 39, '11'),
	(243, 1, 0, -50017, 12, 3, 0, 37, '14'),
	(243, 1, 0, -50017, 12, 3, 0, 39, '11'),
	(243, 1, 0, -50017, 12, 4, 0, 37, '15'),
	(243, 1, 0, -50017, 12, 4, 0, 39, '11'),
	(243, 1, 0, -50016, 1, 1, 0, 37, '12'),
	(243, 1, 0, -50016, 1, 1, 0, 39, '0'),
	(243, 1, 0, -50016, 1, 2, 0, 37, '13'),
	(243, 1, 0, -50016, 1, 2, 0, 39, '0'),
	(243, 1, 0, -50016, 1, 3, 0, 37, '14'),
	(243, 1, 0, -50016, 1, 3, 0, 39, '0'),
	(243, 1, 0, -50016, 1, 4, 0, 37, '15'),
	(243, 1, 0, -50016, 1, 4, 0, 39, '0'),
	(243, 1, 0, -50016, 2, 1, 0, 37, '12'),
	(243, 1, 0, -50016, 2, 1, 0, 39, '1'),
	(243, 1, 0, -50016, 2, 2, 0, 37, '13'),
	(243, 1, 0, -50016, 2, 2, 0, 39, '1'),
	(243, 1, 0, -50016, 2, 3, 0, 37, '14'),
	(243, 1, 0, -50016, 2, 3, 0, 39, '1'),
	(243, 1, 0, -50016, 2, 4, 0, 37, '15'),
	(243, 1, 0, -50016, 2, 4, 0, 39, '1'),
	(243, 1, 0, -50016, 3, 1, 0, 37, '12'),
	(243, 1, 0, -50016, 3, 1, 0, 39, '2'),
	(243, 1, 0, -50016, 3, 2, 0, 37, '13'),
	(243, 1, 0, -50016, 3, 2, 0, 39, '2'),
	(243, 1, 0, -50016, 3, 3, 0, 37, '14'),
	(243, 1, 0, -50016, 3, 3, 0, 39, '2'),
	(243, 1, 0, -50016, 3, 4, 0, 37, '15'),
	(243, 1, 0, -50016, 3, 4, 0, 39, '2'),
	(243, 1, 0, -50016, 4, 1, 0, 37, '12'),
	(243, 1, 0, -50016, 4, 1, 0, 39, '3'),
	(243, 1, 0, -50016, 4, 2, 0, 37, '13'),
	(243, 1, 0, -50016, 4, 2, 0, 39, '3'),
	(243, 1, 0, -50016, 4, 3, 0, 37, '14'),
	(243, 1, 0, -50016, 4, 3, 0, 39, '3'),
	(243, 1, 0, -50016, 4, 4, 0, 37, '15'),
	(243, 1, 0, -50016, 4, 4, 0, 39, '3'),
	(243, 1, 0, -50016, 5, 1, 0, 37, '12'),
	(243, 1, 0, -50016, 5, 1, 0, 39, '4'),
	(243, 1, 0, -50016, 5, 2, 0, 37, '13'),
	(243, 1, 0, -50016, 5, 2, 0, 39, '4'),
	(243, 1, 0, -50016, 5, 3, 0, 37, '14'),
	(243, 1, 0, -50016, 5, 3, 0, 39, '4'),
	(243, 1, 0, -50016, 5, 4, 0, 37, '15'),
	(243, 1, 0, -50016, 5, 4, 0, 39, '4'),
	(243, 1, 0, -50016, 6, 1, 0, 37, '12'),
	(243, 1, 0, -50016, 6, 1, 0, 39, '5'),
	(243, 1, 0, -50016, 6, 2, 0, 37, '13'),
	(243, 1, 0, -50016, 6, 2, 0, 39, '5'),
	(243, 1, 0, -50016, 6, 3, 0, 37, '14'),
	(243, 1, 0, -50016, 6, 3, 0, 39, '5'),
	(243, 1, 0, -50016, 6, 4, 0, 37, '15'),
	(243, 1, 0, -50016, 6, 4, 0, 39, '5'),
	(243, 1, 0, -50016, 7, 1, 0, 37, '12'),
	(243, 1, 0, -50016, 7, 1, 0, 39, '6'),
	(243, 1, 0, -50016, 7, 2, 0, 37, '13'),
	(243, 1, 0, -50016, 7, 2, 0, 39, '6'),
	(243, 1, 0, -50016, 7, 3, 0, 37, '14'),
	(243, 1, 0, -50016, 7, 3, 0, 39, '6'),
	(243, 1, 0, -50016, 7, 4, 0, 37, '15'),
	(243, 1, 0, -50016, 7, 4, 0, 39, '6'),
	(243, 1, 0, -50016, 8, 1, 0, 37, '12'),
	(243, 1, 0, -50016, 8, 1, 0, 39, '7'),
	(243, 1, 0, -50016, 8, 2, 0, 37, '13'),
	(243, 1, 0, -50016, 8, 2, 0, 39, '7'),
	(243, 1, 0, -50016, 8, 3, 0, 37, '14'),
	(243, 1, 0, -50016, 8, 3, 0, 39, '7'),
	(243, 1, 0, -50016, 8, 4, 0, 37, '15'),
	(243, 1, 0, -50016, 8, 4, 0, 39, '7'),
	(243, 1, 0, -50016, 9, 1, 0, 37, '12'),
	(243, 1, 0, -50016, 9, 1, 0, 39, '8'),
	(243, 1, 0, -50016, 9, 2, 0, 37, '13'),
	(243, 1, 0, -50016, 9, 2, 0, 39, '8'),
	(243, 1, 0, -50016, 9, 3, 0, 37, '14'),
	(243, 1, 0, -50016, 9, 3, 0, 39, '8'),
	(243, 1, 0, -50016, 9, 4, 0, 37, '15'),
	(243, 1, 0, -50016, 9, 4, 0, 39, '8'),
	(243, 1, 0, -50016, 10, 1, 0, 37, '12'),
	(243, 1, 0, -50016, 10, 1, 0, 39, '9'),
	(243, 1, 0, -50016, 10, 2, 0, 37, '13'),
	(243, 1, 0, -50016, 10, 2, 0, 39, '9'),
	(243, 1, 0, -50016, 10, 3, 0, 37, '14'),
	(243, 1, 0, -50016, 10, 3, 0, 39, '9'),
	(243, 1, 0, -50016, 10, 4, 0, 37, '15'),
	(243, 1, 0, -50016, 10, 4, 0, 39, '9'),
	(243, 1, 0, -50016, 11, 1, 0, 37, '12'),
	(243, 1, 0, -50016, 11, 1, 0, 39, '10'),
	(243, 1, 0, -50016, 11, 2, 0, 37, '13'),
	(243, 1, 0, -50016, 11, 2, 0, 39, '10'),
	(243, 1, 0, -50016, 11, 3, 0, 37, '14'),
	(243, 1, 0, -50016, 11, 3, 0, 39, '10'),
	(243, 1, 0, -50016, 11, 4, 0, 37, '15'),
	(243, 1, 0, -50016, 11, 4, 0, 39, '10'),
	(243, 1, 0, -50016, 12, 1, 0, 37, '12'),
	(243, 1, 0, -50016, 12, 1, 0, 39, '11'),
	(243, 1, 0, -50016, 12, 2, 0, 37, '13'),
	(243, 1, 0, -50016, 12, 2, 0, 39, '11'),
	(243, 1, 0, -50016, 12, 3, 0, 37, '14'),
	(243, 1, 0, -50016, 12, 3, 0, 39, '11'),
	(243, 1, 0, -50016, 12, 4, 0, 37, '15'),
	(243, 1, 0, -50016, 12, 4, 0, 39, '11'),
	(243, 1, 0, -50015, 1, 1, 0, 37, '12'),
	(243, 1, 0, -50015, 1, 1, 0, 39, '0'),
	(243, 1, 0, -50015, 1, 2, 0, 37, '13'),
	(243, 1, 0, -50015, 1, 2, 0, 39, '0'),
	(243, 1, 0, -50015, 1, 3, 0, 37, '14'),
	(243, 1, 0, -50015, 1, 3, 0, 39, '0'),
	(243, 1, 0, -50015, 1, 4, 0, 37, '15'),
	(243, 1, 0, -50015, 1, 4, 0, 39, '0'),
	(243, 1, 0, -50015, 2, 1, 0, 37, '12'),
	(243, 1, 0, -50015, 2, 1, 0, 39, '1'),
	(243, 1, 0, -50015, 2, 2, 0, 37, '13'),
	(243, 1, 0, -50015, 2, 2, 0, 39, '1'),
	(243, 1, 0, -50015, 2, 3, 0, 37, '14'),
	(243, 1, 0, -50015, 2, 3, 0, 39, '1'),
	(243, 1, 0, -50015, 2, 4, 0, 37, '15'),
	(243, 1, 0, -50015, 2, 4, 0, 39, '1'),
	(243, 1, 0, -50015, 3, 1, 0, 37, '12'),
	(243, 1, 0, -50015, 3, 1, 0, 39, '2'),
	(243, 1, 0, -50015, 3, 2, 0, 37, '13'),
	(243, 1, 0, -50015, 3, 2, 0, 39, '2'),
	(243, 1, 0, -50015, 3, 3, 0, 37, '14'),
	(243, 1, 0, -50015, 3, 3, 0, 39, '2'),
	(243, 1, 0, -50015, 3, 4, 0, 37, '15'),
	(243, 1, 0, -50015, 3, 4, 0, 39, '2'),
	(243, 1, 0, -50015, 4, 1, 0, 37, '12'),
	(243, 1, 0, -50015, 4, 1, 0, 39, '3'),
	(243, 1, 0, -50015, 4, 2, 0, 37, '13'),
	(243, 1, 0, -50015, 4, 2, 0, 39, '3'),
	(243, 1, 0, -50015, 4, 3, 0, 37, '14'),
	(243, 1, 0, -50015, 4, 3, 0, 39, '3'),
	(243, 1, 0, -50015, 4, 4, 0, 37, '15'),
	(243, 1, 0, -50015, 4, 4, 0, 39, '3'),
	(243, 1, 0, -50015, 5, 1, 0, 37, '12'),
	(243, 1, 0, -50015, 5, 1, 0, 39, '4'),
	(243, 1, 0, -50015, 5, 2, 0, 37, '13'),
	(243, 1, 0, -50015, 5, 2, 0, 39, '4'),
	(243, 1, 0, -50015, 5, 3, 0, 37, '14'),
	(243, 1, 0, -50015, 5, 3, 0, 39, '4'),
	(243, 1, 0, -50015, 5, 4, 0, 37, '15'),
	(243, 1, 0, -50015, 5, 4, 0, 39, '4'),
	(243, 1, 0, -50015, 6, 1, 0, 37, '12'),
	(243, 1, 0, -50015, 6, 1, 0, 39, '5'),
	(243, 1, 0, -50015, 6, 2, 0, 37, '13'),
	(243, 1, 0, -50015, 6, 2, 0, 39, '5'),
	(243, 1, 0, -50015, 6, 3, 0, 37, '14'),
	(243, 1, 0, -50015, 6, 3, 0, 39, '5'),
	(243, 1, 0, -50015, 6, 4, 0, 37, '15'),
	(243, 1, 0, -50015, 6, 4, 0, 39, '5'),
	(243, 1, 0, -50015, 7, 1, 0, 37, '12'),
	(243, 1, 0, -50015, 7, 1, 0, 39, '6'),
	(243, 1, 0, -50015, 7, 2, 0, 37, '13'),
	(243, 1, 0, -50015, 7, 2, 0, 39, '6'),
	(243, 1, 0, -50015, 7, 3, 0, 37, '14'),
	(243, 1, 0, -50015, 7, 3, 0, 39, '6'),
	(243, 1, 0, -50015, 7, 4, 0, 37, '15'),
	(243, 1, 0, -50015, 7, 4, 0, 39, '6'),
	(243, 1, 0, -50015, 8, 1, 0, 37, '12'),
	(243, 1, 0, -50015, 8, 1, 0, 39, '7'),
	(243, 1, 0, -50015, 8, 2, 0, 37, '13'),
	(243, 1, 0, -50015, 8, 2, 0, 39, '7'),
	(243, 1, 0, -50015, 8, 3, 0, 37, '14'),
	(243, 1, 0, -50015, 8, 3, 0, 39, '7'),
	(243, 1, 0, -50015, 8, 4, 0, 37, '15'),
	(243, 1, 0, -50015, 8, 4, 0, 39, '7'),
	(243, 1, 0, -50015, 9, 1, 0, 37, '12'),
	(243, 1, 0, -50015, 9, 1, 0, 39, '8'),
	(243, 1, 0, -50015, 9, 2, 0, 37, '13'),
	(243, 1, 0, -50015, 9, 2, 0, 39, '8'),
	(243, 1, 0, -50015, 9, 3, 0, 37, '14'),
	(243, 1, 0, -50015, 9, 3, 0, 39, '8'),
	(243, 1, 0, -50015, 9, 4, 0, 37, '15'),
	(243, 1, 0, -50015, 9, 4, 0, 39, '8'),
	(243, 1, 0, -50015, 10, 1, 0, 37, '12'),
	(243, 1, 0, -50015, 10, 1, 0, 39, '9'),
	(243, 1, 0, -50015, 10, 2, 0, 37, '13'),
	(243, 1, 0, -50015, 10, 2, 0, 39, '9'),
	(243, 1, 0, -50015, 10, 3, 0, 37, '14'),
	(243, 1, 0, -50015, 10, 3, 0, 39, '9'),
	(243, 1, 0, -50015, 10, 4, 0, 37, '15'),
	(243, 1, 0, -50015, 10, 4, 0, 39, '9'),
	(243, 1, 0, -50015, 11, 1, 0, 37, '12'),
	(243, 1, 0, -50015, 11, 1, 0, 39, '10'),
	(243, 1, 0, -50015, 11, 2, 0, 37, '13'),
	(243, 1, 0, -50015, 11, 2, 0, 39, '10'),
	(243, 1, 0, -50015, 11, 3, 0, 37, '14'),
	(243, 1, 0, -50015, 11, 3, 0, 39, '10'),
	(243, 1, 0, -50015, 11, 4, 0, 37, '15'),
	(243, 1, 0, -50015, 11, 4, 0, 39, '10'),
	(243, 1, 0, -50015, 12, 1, 0, 37, '12'),
	(243, 1, 0, -50015, 12, 1, 0, 39, '11'),
	(243, 1, 0, -50015, 12, 2, 0, 37, '13'),
	(243, 1, 0, -50015, 12, 2, 0, 39, '11'),
	(243, 1, 0, -50015, 12, 3, 0, 37, '14'),
	(243, 1, 0, -50015, 12, 3, 0, 39, '11'),
	(243, 1, 0, -50015, 12, 4, 0, 37, '15'),
	(243, 1, 0, -50015, 12, 4, 0, 39, '11'),
	(243, 1, 0, -50014, 1, 1, 0, 37, '12'),
	(243, 1, 0, -50014, 1, 1, 0, 39, '0'),
	(243, 1, 0, -50014, 1, 2, 0, 37, '13'),
	(243, 1, 0, -50014, 1, 2, 0, 39, '0'),
	(243, 1, 0, -50014, 1, 3, 0, 37, '14'),
	(243, 1, 0, -50014, 1, 3, 0, 39, '0'),
	(243, 1, 0, -50014, 1, 4, 0, 37, '15'),
	(243, 1, 0, -50014, 1, 4, 0, 39, '0'),
	(243, 1, 0, -50014, 2, 1, 0, 37, '12'),
	(243, 1, 0, -50014, 2, 1, 0, 39, '1'),
	(243, 1, 0, -50014, 2, 2, 0, 37, '13'),
	(243, 1, 0, -50014, 2, 2, 0, 39, '1'),
	(243, 1, 0, -50014, 2, 3, 0, 37, '14'),
	(243, 1, 0, -50014, 2, 3, 0, 39, '1'),
	(243, 1, 0, -50014, 2, 4, 0, 37, '15'),
	(243, 1, 0, -50014, 2, 4, 0, 39, '1'),
	(243, 1, 0, -50014, 3, 1, 0, 37, '12'),
	(243, 1, 0, -50014, 3, 1, 0, 39, '2'),
	(243, 1, 0, -50014, 3, 2, 0, 37, '13'),
	(243, 1, 0, -50014, 3, 2, 0, 39, '2'),
	(243, 1, 0, -50014, 3, 3, 0, 37, '14'),
	(243, 1, 0, -50014, 3, 3, 0, 39, '2'),
	(243, 1, 0, -50014, 3, 4, 0, 37, '15'),
	(243, 1, 0, -50014, 3, 4, 0, 39, '2'),
	(243, 1, 0, -50014, 4, 1, 0, 37, '12'),
	(243, 1, 0, -50014, 4, 1, 0, 39, '3'),
	(243, 1, 0, -50014, 4, 2, 0, 37, '13'),
	(243, 1, 0, -50014, 4, 2, 0, 39, '3'),
	(243, 1, 0, -50014, 4, 3, 0, 37, '14'),
	(243, 1, 0, -50014, 4, 3, 0, 39, '3'),
	(243, 1, 0, -50014, 4, 4, 0, 37, '15'),
	(243, 1, 0, -50014, 4, 4, 0, 39, '3'),
	(243, 1, 0, -50014, 5, 1, 0, 37, '12'),
	(243, 1, 0, -50014, 5, 1, 0, 39, '4'),
	(243, 1, 0, -50014, 5, 2, 0, 37, '13'),
	(243, 1, 0, -50014, 5, 2, 0, 39, '4'),
	(243, 1, 0, -50014, 5, 3, 0, 37, '14'),
	(243, 1, 0, -50014, 5, 3, 0, 39, '4'),
	(243, 1, 0, -50014, 5, 4, 0, 37, '15'),
	(243, 1, 0, -50014, 5, 4, 0, 39, '4'),
	(243, 1, 0, -50014, 6, 1, 0, 37, '12'),
	(243, 1, 0, -50014, 6, 1, 0, 39, '5'),
	(243, 1, 0, -50014, 6, 2, 0, 37, '13'),
	(243, 1, 0, -50014, 6, 2, 0, 39, '5'),
	(243, 1, 0, -50014, 6, 3, 0, 37, '14'),
	(243, 1, 0, -50014, 6, 3, 0, 39, '5'),
	(243, 1, 0, -50014, 6, 4, 0, 37, '15'),
	(243, 1, 0, -50014, 6, 4, 0, 39, '5'),
	(243, 1, 0, -50014, 7, 1, 0, 37, '12'),
	(243, 1, 0, -50014, 7, 1, 0, 39, '6'),
	(243, 1, 0, -50014, 7, 2, 0, 37, '13'),
	(243, 1, 0, -50014, 7, 2, 0, 39, '6'),
	(243, 1, 0, -50014, 7, 3, 0, 37, '14'),
	(243, 1, 0, -50014, 7, 3, 0, 39, '6'),
	(243, 1, 0, -50014, 7, 4, 0, 37, '15'),
	(243, 1, 0, -50014, 7, 4, 0, 39, '6'),
	(243, 1, 0, -50014, 8, 1, 0, 37, '12'),
	(243, 1, 0, -50014, 8, 1, 0, 39, '7'),
	(243, 1, 0, -50014, 8, 2, 0, 37, '13'),
	(243, 1, 0, -50014, 8, 2, 0, 39, '7'),
	(243, 1, 0, -50014, 8, 3, 0, 37, '14'),
	(243, 1, 0, -50014, 8, 3, 0, 39, '7'),
	(243, 1, 0, -50014, 8, 4, 0, 37, '15'),
	(243, 1, 0, -50014, 8, 4, 0, 39, '7'),
	(243, 1, 0, -50014, 9, 1, 0, 37, '12'),
	(243, 1, 0, -50014, 9, 1, 0, 39, '8'),
	(243, 1, 0, -50014, 9, 2, 0, 37, '13'),
	(243, 1, 0, -50014, 9, 2, 0, 39, '8'),
	(243, 1, 0, -50014, 9, 3, 0, 37, '14'),
	(243, 1, 0, -50014, 9, 3, 0, 39, '8'),
	(243, 1, 0, -50014, 9, 4, 0, 37, '15'),
	(243, 1, 0, -50014, 9, 4, 0, 39, '8'),
	(243, 1, 0, -50014, 10, 1, 0, 37, '12'),
	(243, 1, 0, -50014, 10, 1, 0, 39, '9'),
	(243, 1, 0, -50014, 10, 2, 0, 37, '13'),
	(243, 1, 0, -50014, 10, 2, 0, 39, '9'),
	(243, 1, 0, -50014, 10, 3, 0, 37, '14'),
	(243, 1, 0, -50014, 10, 3, 0, 39, '9'),
	(243, 1, 0, -50014, 10, 4, 0, 37, '15'),
	(243, 1, 0, -50014, 10, 4, 0, 39, '9'),
	(243, 1, 0, -50014, 11, 1, 0, 37, '12'),
	(243, 1, 0, -50014, 11, 1, 0, 39, '10'),
	(243, 1, 0, -50014, 11, 2, 0, 37, '13'),
	(243, 1, 0, -50014, 11, 2, 0, 39, '10'),
	(243, 1, 0, -50014, 11, 3, 0, 37, '14'),
	(243, 1, 0, -50014, 11, 3, 0, 39, '10'),
	(243, 1, 0, -50014, 11, 4, 0, 37, '15'),
	(243, 1, 0, -50014, 11, 4, 0, 39, '10'),
	(243, 1, 0, -50014, 12, 1, 0, 37, '12'),
	(243, 1, 0, -50014, 12, 1, 0, 39, '11'),
	(243, 1, 0, -50014, 12, 2, 0, 37, '13'),
	(243, 1, 0, -50014, 12, 2, 0, 39, '11'),
	(243, 1, 0, -50014, 12, 3, 0, 37, '14'),
	(243, 1, 0, -50014, 12, 3, 0, 39, '11'),
	(243, 1, 0, -50014, 12, 4, 0, 37, '15'),
	(243, 1, 0, -50014, 12, 4, 0, 39, '11'),
	(243, 1, 0, -50013, 1, 1, 0, 37, '12'),
	(243, 1, 0, -50013, 1, 1, 0, 39, '0'),
	(243, 1, 0, -50013, 1, 2, 0, 37, '13'),
	(243, 1, 0, -50013, 1, 2, 0, 39, '0'),
	(243, 1, 0, -50013, 1, 3, 0, 37, '14'),
	(243, 1, 0, -50013, 1, 3, 0, 39, '0'),
	(243, 1, 0, -50013, 1, 4, 0, 37, '15'),
	(243, 1, 0, -50013, 1, 4, 0, 39, '0'),
	(243, 1, 0, -50013, 2, 1, 0, 37, '12'),
	(243, 1, 0, -50013, 2, 1, 0, 39, '1'),
	(243, 1, 0, -50013, 2, 2, 0, 37, '13'),
	(243, 1, 0, -50013, 2, 2, 0, 39, '1'),
	(243, 1, 0, -50013, 2, 3, 0, 37, '14'),
	(243, 1, 0, -50013, 2, 3, 0, 39, '1'),
	(243, 1, 0, -50013, 2, 4, 0, 37, '15'),
	(243, 1, 0, -50013, 2, 4, 0, 39, '1'),
	(243, 1, 0, -50013, 3, 1, 0, 37, '12'),
	(243, 1, 0, -50013, 3, 1, 0, 39, '2'),
	(243, 1, 0, -50013, 3, 2, 0, 37, '13'),
	(243, 1, 0, -50013, 3, 2, 0, 39, '2'),
	(243, 1, 0, -50013, 3, 3, 0, 37, '14'),
	(243, 1, 0, -50013, 3, 3, 0, 39, '2'),
	(243, 1, 0, -50013, 3, 4, 0, 37, '15'),
	(243, 1, 0, -50013, 3, 4, 0, 39, '2'),
	(243, 1, 0, -50013, 4, 1, 0, 37, '12'),
	(243, 1, 0, -50013, 4, 1, 0, 39, '3'),
	(243, 1, 0, -50013, 4, 2, 0, 37, '13'),
	(243, 1, 0, -50013, 4, 2, 0, 39, '3'),
	(243, 1, 0, -50013, 4, 3, 0, 37, '14'),
	(243, 1, 0, -50013, 4, 3, 0, 39, '3'),
	(243, 1, 0, -50013, 4, 4, 0, 37, '15'),
	(243, 1, 0, -50013, 4, 4, 0, 39, '3'),
	(243, 1, 0, -50013, 5, 1, 0, 37, '12'),
	(243, 1, 0, -50013, 5, 1, 0, 39, '4'),
	(243, 1, 0, -50013, 5, 2, 0, 37, '13'),
	(243, 1, 0, -50013, 5, 2, 0, 39, '4'),
	(243, 1, 0, -50013, 5, 3, 0, 37, '14'),
	(243, 1, 0, -50013, 5, 3, 0, 39, '4'),
	(243, 1, 0, -50013, 5, 4, 0, 37, '15'),
	(243, 1, 0, -50013, 5, 4, 0, 39, '4'),
	(243, 1, 0, -50013, 6, 1, 0, 37, '12'),
	(243, 1, 0, -50013, 6, 1, 0, 39, '5'),
	(243, 1, 0, -50013, 6, 2, 0, 37, '13'),
	(243, 1, 0, -50013, 6, 2, 0, 39, '5'),
	(243, 1, 0, -50013, 6, 3, 0, 37, '14'),
	(243, 1, 0, -50013, 6, 3, 0, 39, '5'),
	(243, 1, 0, -50013, 6, 4, 0, 37, '15'),
	(243, 1, 0, -50013, 6, 4, 0, 39, '5'),
	(243, 1, 0, -50013, 7, 1, 0, 37, '12'),
	(243, 1, 0, -50013, 7, 1, 0, 39, '6'),
	(243, 1, 0, -50013, 7, 2, 0, 37, '13'),
	(243, 1, 0, -50013, 7, 2, 0, 39, '6'),
	(243, 1, 0, -50013, 7, 3, 0, 37, '14'),
	(243, 1, 0, -50013, 7, 3, 0, 39, '6'),
	(243, 1, 0, -50013, 7, 4, 0, 37, '15'),
	(243, 1, 0, -50013, 7, 4, 0, 39, '6'),
	(243, 1, 0, -50013, 8, 1, 0, 37, '12'),
	(243, 1, 0, -50013, 8, 1, 0, 39, '7'),
	(243, 1, 0, -50013, 8, 2, 0, 37, '13'),
	(243, 1, 0, -50013, 8, 2, 0, 39, '7'),
	(243, 1, 0, -50013, 8, 3, 0, 37, '14'),
	(243, 1, 0, -50013, 8, 3, 0, 39, '7'),
	(243, 1, 0, -50013, 8, 4, 0, 37, '15'),
	(243, 1, 0, -50013, 8, 4, 0, 39, '7'),
	(243, 1, 0, -50013, 9, 1, 0, 37, '12'),
	(243, 1, 0, -50013, 9, 1, 0, 39, '8'),
	(243, 1, 0, -50013, 9, 2, 0, 37, '13'),
	(243, 1, 0, -50013, 9, 2, 0, 39, '8'),
	(243, 1, 0, -50013, 9, 3, 0, 37, '14'),
	(243, 1, 0, -50013, 9, 3, 0, 39, '8'),
	(243, 1, 0, -50013, 9, 4, 0, 37, '15'),
	(243, 1, 0, -50013, 9, 4, 0, 39, '8'),
	(243, 1, 0, -50013, 10, 1, 0, 37, '12'),
	(243, 1, 0, -50013, 10, 1, 0, 39, '9'),
	(243, 1, 0, -50013, 10, 2, 0, 37, '13'),
	(243, 1, 0, -50013, 10, 2, 0, 39, '9'),
	(243, 1, 0, -50013, 10, 3, 0, 37, '14'),
	(243, 1, 0, -50013, 10, 3, 0, 39, '9'),
	(243, 1, 0, -50013, 10, 4, 0, 37, '15'),
	(243, 1, 0, -50013, 10, 4, 0, 39, '9'),
	(243, 1, 0, -50013, 11, 1, 0, 37, '12'),
	(243, 1, 0, -50013, 11, 1, 0, 39, '10'),
	(243, 1, 0, -50013, 11, 2, 0, 37, '13'),
	(243, 1, 0, -50013, 11, 2, 0, 39, '10'),
	(243, 1, 0, -50013, 11, 3, 0, 37, '14'),
	(243, 1, 0, -50013, 11, 3, 0, 39, '10'),
	(243, 1, 0, -50013, 11, 4, 0, 37, '15'),
	(243, 1, 0, -50013, 11, 4, 0, 39, '10'),
	(243, 1, 0, -50013, 12, 1, 0, 37, '12'),
	(243, 1, 0, -50013, 12, 1, 0, 39, '11'),
	(243, 1, 0, -50013, 12, 2, 0, 37, '13'),
	(243, 1, 0, -50013, 12, 2, 0, 39, '11'),
	(243, 1, 0, -50013, 12, 3, 0, 37, '14'),
	(243, 1, 0, -50013, 12, 3, 0, 39, '11'),
	(243, 1, 0, -50013, 12, 4, 0, 37, '15'),
	(243, 1, 0, -50013, 12, 4, 0, 39, '11'),
	(243, 1, 0, -50012, 1, 1, 0, 37, '12'),
	(243, 1, 0, -50012, 1, 1, 0, 39, '0'),
	(243, 1, 0, -50012, 1, 2, 0, 37, '13'),
	(243, 1, 0, -50012, 1, 2, 0, 39, '0'),
	(243, 1, 0, -50012, 1, 3, 0, 37, '14'),
	(243, 1, 0, -50012, 1, 3, 0, 39, '0'),
	(243, 1, 0, -50012, 1, 4, 0, 37, '15'),
	(243, 1, 0, -50012, 1, 4, 0, 39, '0'),
	(243, 1, 0, -50012, 2, 1, 0, 37, '12'),
	(243, 1, 0, -50012, 2, 1, 0, 39, '1'),
	(243, 1, 0, -50012, 2, 2, 0, 37, '13'),
	(243, 1, 0, -50012, 2, 2, 0, 39, '1'),
	(243, 1, 0, -50012, 2, 3, 0, 37, '14'),
	(243, 1, 0, -50012, 2, 3, 0, 39, '1'),
	(243, 1, 0, -50012, 2, 4, 0, 37, '15'),
	(243, 1, 0, -50012, 2, 4, 0, 39, '1'),
	(243, 1, 0, -50012, 3, 1, 0, 37, '12'),
	(243, 1, 0, -50012, 3, 1, 0, 39, '2'),
	(243, 1, 0, -50012, 3, 2, 0, 37, '13'),
	(243, 1, 0, -50012, 3, 2, 0, 39, '2'),
	(243, 1, 0, -50012, 3, 3, 0, 37, '14'),
	(243, 1, 0, -50012, 3, 3, 0, 39, '2'),
	(243, 1, 0, -50012, 3, 4, 0, 37, '15'),
	(243, 1, 0, -50012, 3, 4, 0, 39, '2'),
	(243, 1, 0, -50012, 4, 1, 0, 37, '12'),
	(243, 1, 0, -50012, 4, 1, 0, 39, '3'),
	(243, 1, 0, -50012, 4, 2, 0, 37, '13'),
	(243, 1, 0, -50012, 4, 2, 0, 39, '3'),
	(243, 1, 0, -50012, 4, 3, 0, 37, '14'),
	(243, 1, 0, -50012, 4, 3, 0, 39, '3'),
	(243, 1, 0, -50012, 4, 4, 0, 37, '15'),
	(243, 1, 0, -50012, 4, 4, 0, 39, '3'),
	(243, 1, 0, -50012, 5, 1, 0, 37, '12'),
	(243, 1, 0, -50012, 5, 1, 0, 39, '4'),
	(243, 1, 0, -50012, 5, 2, 0, 37, '13'),
	(243, 1, 0, -50012, 5, 2, 0, 39, '4'),
	(243, 1, 0, -50012, 5, 3, 0, 37, '14'),
	(243, 1, 0, -50012, 5, 3, 0, 39, '4'),
	(243, 1, 0, -50012, 5, 4, 0, 37, '15'),
	(243, 1, 0, -50012, 5, 4, 0, 39, '4'),
	(243, 1, 0, -50012, 6, 1, 0, 37, '12'),
	(243, 1, 0, -50012, 6, 1, 0, 39, '5'),
	(243, 1, 0, -50012, 6, 2, 0, 37, '13'),
	(243, 1, 0, -50012, 6, 2, 0, 39, '5'),
	(243, 1, 0, -50012, 6, 3, 0, 37, '14'),
	(243, 1, 0, -50012, 6, 3, 0, 39, '5'),
	(243, 1, 0, -50012, 6, 4, 0, 37, '15'),
	(243, 1, 0, -50012, 6, 4, 0, 39, '5'),
	(243, 1, 0, -50012, 7, 1, 0, 37, '12'),
	(243, 1, 0, -50012, 7, 1, 0, 39, '6'),
	(243, 1, 0, -50012, 7, 2, 0, 37, '13'),
	(243, 1, 0, -50012, 7, 2, 0, 39, '6'),
	(243, 1, 0, -50012, 7, 3, 0, 37, '14'),
	(243, 1, 0, -50012, 7, 3, 0, 39, '6'),
	(243, 1, 0, -50012, 7, 4, 0, 37, '15'),
	(243, 1, 0, -50012, 7, 4, 0, 39, '6'),
	(243, 1, 0, -50012, 8, 1, 0, 37, '12'),
	(243, 1, 0, -50012, 8, 1, 0, 39, '7'),
	(243, 1, 0, -50012, 8, 2, 0, 37, '13'),
	(243, 1, 0, -50012, 8, 2, 0, 39, '7'),
	(243, 1, 0, -50012, 8, 3, 0, 37, '14'),
	(243, 1, 0, -50012, 8, 3, 0, 39, '7'),
	(243, 1, 0, -50012, 8, 4, 0, 37, '15'),
	(243, 1, 0, -50012, 8, 4, 0, 39, '7'),
	(243, 1, 0, -50012, 9, 1, 0, 37, '12'),
	(243, 1, 0, -50012, 9, 1, 0, 39, '8'),
	(243, 1, 0, -50012, 9, 2, 0, 37, '13'),
	(243, 1, 0, -50012, 9, 2, 0, 39, '8'),
	(243, 1, 0, -50012, 9, 3, 0, 37, '14'),
	(243, 1, 0, -50012, 9, 3, 0, 39, '8'),
	(243, 1, 0, -50012, 9, 4, 0, 37, '15'),
	(243, 1, 0, -50012, 9, 4, 0, 39, '8'),
	(243, 1, 0, -50012, 10, 1, 0, 37, '12'),
	(243, 1, 0, -50012, 10, 1, 0, 39, '9'),
	(243, 1, 0, -50012, 10, 2, 0, 37, '13'),
	(243, 1, 0, -50012, 10, 2, 0, 39, '9'),
	(243, 1, 0, -50012, 10, 3, 0, 37, '14'),
	(243, 1, 0, -50012, 10, 3, 0, 39, '9'),
	(243, 1, 0, -50012, 10, 4, 0, 37, '15'),
	(243, 1, 0, -50012, 10, 4, 0, 39, '9'),
	(243, 1, 0, -50012, 11, 1, 0, 37, '12'),
	(243, 1, 0, -50012, 11, 1, 0, 39, '10'),
	(243, 1, 0, -50012, 11, 2, 0, 37, '13'),
	(243, 1, 0, -50012, 11, 2, 0, 39, '10'),
	(243, 1, 0, -50012, 11, 3, 0, 37, '14'),
	(243, 1, 0, -50012, 11, 3, 0, 39, '10'),
	(243, 1, 0, -50012, 11, 4, 0, 37, '15'),
	(243, 1, 0, -50012, 11, 4, 0, 39, '10'),
	(243, 1, 0, -50012, 12, 1, 0, 37, '12'),
	(243, 1, 0, -50012, 12, 1, 0, 39, '11'),
	(243, 1, 0, -50012, 12, 2, 0, 37, '13'),
	(243, 1, 0, -50012, 12, 2, 0, 39, '11'),
	(243, 1, 0, -50012, 12, 3, 0, 37, '14'),
	(243, 1, 0, -50012, 12, 3, 0, 39, '11'),
	(243, 1, 0, -50012, 12, 4, 0, 37, '15'),
	(243, 1, 0, -50012, 12, 4, 0, 39, '11'),
	(243, 1, 0, -50011, 1, 1, 0, 37, '12'),
	(243, 1, 0, -50011, 1, 1, 0, 39, '0'),
	(243, 1, 0, -50011, 1, 2, 0, 37, '13'),
	(243, 1, 0, -50011, 1, 2, 0, 39, '0'),
	(243, 1, 0, -50011, 1, 3, 0, 37, '14'),
	(243, 1, 0, -50011, 1, 3, 0, 39, '0'),
	(243, 1, 0, -50011, 1, 4, 0, 37, '15'),
	(243, 1, 0, -50011, 1, 4, 0, 39, '0'),
	(243, 1, 0, -50011, 2, 1, 0, 37, '12'),
	(243, 1, 0, -50011, 2, 1, 0, 39, '1'),
	(243, 1, 0, -50011, 2, 2, 0, 37, '13'),
	(243, 1, 0, -50011, 2, 2, 0, 39, '1'),
	(243, 1, 0, -50011, 2, 3, 0, 37, '14'),
	(243, 1, 0, -50011, 2, 3, 0, 39, '1'),
	(243, 1, 0, -50011, 2, 4, 0, 37, '15'),
	(243, 1, 0, -50011, 2, 4, 0, 39, '1'),
	(243, 1, 0, -50011, 3, 1, 0, 37, '12'),
	(243, 1, 0, -50011, 3, 1, 0, 39, '2'),
	(243, 1, 0, -50011, 3, 2, 0, 37, '13'),
	(243, 1, 0, -50011, 3, 2, 0, 39, '2'),
	(243, 1, 0, -50011, 3, 3, 0, 37, '14'),
	(243, 1, 0, -50011, 3, 3, 0, 39, '2'),
	(243, 1, 0, -50011, 3, 4, 0, 37, '15'),
	(243, 1, 0, -50011, 3, 4, 0, 39, '2'),
	(243, 1, 0, -50011, 4, 1, 0, 37, '12'),
	(243, 1, 0, -50011, 4, 1, 0, 39, '3'),
	(243, 1, 0, -50011, 4, 2, 0, 37, '13'),
	(243, 1, 0, -50011, 4, 2, 0, 39, '3'),
	(243, 1, 0, -50011, 4, 3, 0, 37, '14'),
	(243, 1, 0, -50011, 4, 3, 0, 39, '3'),
	(243, 1, 0, -50011, 4, 4, 0, 37, '15'),
	(243, 1, 0, -50011, 4, 4, 0, 39, '3'),
	(243, 1, 0, -50011, 5, 1, 0, 37, '12'),
	(243, 1, 0, -50011, 5, 1, 0, 39, '4'),
	(243, 1, 0, -50011, 5, 2, 0, 37, '13'),
	(243, 1, 0, -50011, 5, 2, 0, 39, '4'),
	(243, 1, 0, -50011, 5, 3, 0, 37, '14'),
	(243, 1, 0, -50011, 5, 3, 0, 39, '4'),
	(243, 1, 0, -50011, 5, 4, 0, 37, '15'),
	(243, 1, 0, -50011, 5, 4, 0, 39, '4'),
	(243, 1, 0, -50011, 6, 1, 0, 37, '12'),
	(243, 1, 0, -50011, 6, 1, 0, 39, '5'),
	(243, 1, 0, -50011, 6, 2, 0, 37, '13'),
	(243, 1, 0, -50011, 6, 2, 0, 39, '5'),
	(243, 1, 0, -50011, 6, 3, 0, 37, '14'),
	(243, 1, 0, -50011, 6, 3, 0, 39, '5'),
	(243, 1, 0, -50011, 6, 4, 0, 37, '15'),
	(243, 1, 0, -50011, 6, 4, 0, 39, '5'),
	(243, 1, 0, -50011, 7, 1, 0, 37, '12'),
	(243, 1, 0, -50011, 7, 1, 0, 39, '6'),
	(243, 1, 0, -50011, 7, 2, 0, 37, '13'),
	(243, 1, 0, -50011, 7, 2, 0, 39, '6'),
	(243, 1, 0, -50011, 7, 3, 0, 37, '14'),
	(243, 1, 0, -50011, 7, 3, 0, 39, '6'),
	(243, 1, 0, -50011, 7, 4, 0, 37, '15'),
	(243, 1, 0, -50011, 7, 4, 0, 39, '6'),
	(243, 1, 0, -50011, 8, 1, 0, 37, '12'),
	(243, 1, 0, -50011, 8, 1, 0, 39, '7'),
	(243, 1, 0, -50011, 8, 2, 0, 37, '13'),
	(243, 1, 0, -50011, 8, 2, 0, 39, '7'),
	(243, 1, 0, -50011, 8, 3, 0, 37, '14'),
	(243, 1, 0, -50011, 8, 3, 0, 39, '7'),
	(243, 1, 0, -50011, 8, 4, 0, 37, '15'),
	(243, 1, 0, -50011, 8, 4, 0, 39, '7'),
	(243, 1, 0, -50011, 9, 1, 0, 37, '12'),
	(243, 1, 0, -50011, 9, 1, 0, 39, '8'),
	(243, 1, 0, -50011, 9, 2, 0, 37, '13'),
	(243, 1, 0, -50011, 9, 2, 0, 39, '8'),
	(243, 1, 0, -50011, 9, 3, 0, 37, '14'),
	(243, 1, 0, -50011, 9, 3, 0, 39, '8'),
	(243, 1, 0, -50011, 9, 4, 0, 37, '15'),
	(243, 1, 0, -50011, 9, 4, 0, 39, '8'),
	(243, 1, 0, -50011, 10, 1, 0, 37, '12'),
	(243, 1, 0, -50011, 10, 1, 0, 39, '9'),
	(243, 1, 0, -50011, 10, 2, 0, 37, '13'),
	(243, 1, 0, -50011, 10, 2, 0, 39, '9'),
	(243, 1, 0, -50011, 10, 3, 0, 37, '14'),
	(243, 1, 0, -50011, 10, 3, 0, 39, '9'),
	(243, 1, 0, -50011, 10, 4, 0, 37, '15'),
	(243, 1, 0, -50011, 10, 4, 0, 39, '9'),
	(243, 1, 0, -50011, 11, 1, 0, 37, '12'),
	(243, 1, 0, -50011, 11, 1, 0, 39, '10'),
	(243, 1, 0, -50011, 11, 2, 0, 37, '13'),
	(243, 1, 0, -50011, 11, 2, 0, 39, '10'),
	(243, 1, 0, -50011, 11, 3, 0, 37, '14'),
	(243, 1, 0, -50011, 11, 3, 0, 39, '10'),
	(243, 1, 0, -50011, 11, 4, 0, 37, '15'),
	(243, 1, 0, -50011, 11, 4, 0, 39, '10'),
	(243, 1, 0, -50011, 12, 1, 0, 37, '12'),
	(243, 1, 0, -50011, 12, 1, 0, 39, '11'),
	(243, 1, 0, -50011, 12, 2, 0, 37, '13'),
	(243, 1, 0, -50011, 12, 2, 0, 39, '11'),
	(243, 1, 0, -50011, 12, 3, 0, 37, '14'),
	(243, 1, 0, -50011, 12, 3, 0, 39, '11'),
	(243, 1, 0, -50011, 12, 4, 0, 37, '15'),
	(243, 1, 0, -50011, 12, 4, 0, 39, '11'),
	(243, 1, 0, -50008, 1, 1, 0, 37, '12'),
	(243, 1, 0, -50008, 1, 1, 0, 39, '0'),
	(243, 1, 0, -50008, 1, 2, 0, 37, '13'),
	(243, 1, 0, -50008, 1, 2, 0, 39, '0'),
	(243, 1, 0, -50008, 1, 3, 0, 37, '14'),
	(243, 1, 0, -50008, 1, 3, 0, 39, '0'),
	(243, 1, 0, -50008, 1, 4, 0, 37, '15'),
	(243, 1, 0, -50008, 1, 4, 0, 39, '0'),
	(243, 1, 0, -50008, 2, 1, 0, 37, '12'),
	(243, 1, 0, -50008, 2, 1, 0, 39, '1'),
	(243, 1, 0, -50008, 2, 2, 0, 37, '13'),
	(243, 1, 0, -50008, 2, 2, 0, 39, '1'),
	(243, 1, 0, -50008, 2, 3, 0, 37, '14'),
	(243, 1, 0, -50008, 2, 3, 0, 39, '1'),
	(243, 1, 0, -50008, 2, 4, 0, 37, '15'),
	(243, 1, 0, -50008, 2, 4, 0, 39, '1'),
	(243, 1, 0, -50008, 3, 1, 0, 37, '12'),
	(243, 1, 0, -50008, 3, 1, 0, 39, '2'),
	(243, 1, 0, -50008, 3, 2, 0, 37, '13'),
	(243, 1, 0, -50008, 3, 2, 0, 39, '2'),
	(243, 1, 0, -50008, 3, 3, 0, 37, '14'),
	(243, 1, 0, -50008, 3, 3, 0, 39, '2'),
	(243, 1, 0, -50008, 3, 4, 0, 37, '15'),
	(243, 1, 0, -50008, 3, 4, 0, 39, '2'),
	(243, 1, 0, -50008, 4, 1, 0, 37, '12'),
	(243, 1, 0, -50008, 4, 1, 0, 39, '3'),
	(243, 1, 0, -50008, 4, 2, 0, 37, '13'),
	(243, 1, 0, -50008, 4, 2, 0, 39, '3'),
	(243, 1, 0, -50008, 4, 3, 0, 37, '14'),
	(243, 1, 0, -50008, 4, 3, 0, 39, '3'),
	(243, 1, 0, -50008, 4, 4, 0, 37, '15'),
	(243, 1, 0, -50008, 4, 4, 0, 39, '3'),
	(243, 1, 0, -50008, 5, 1, 0, 37, '12'),
	(243, 1, 0, -50008, 5, 1, 0, 39, '4'),
	(243, 1, 0, -50008, 5, 2, 0, 37, '13'),
	(243, 1, 0, -50008, 5, 2, 0, 39, '4'),
	(243, 1, 0, -50008, 5, 3, 0, 37, '14'),
	(243, 1, 0, -50008, 5, 3, 0, 39, '4'),
	(243, 1, 0, -50008, 5, 4, 0, 37, '15'),
	(243, 1, 0, -50008, 5, 4, 0, 39, '4'),
	(243, 1, 0, -50008, 6, 1, 0, 37, '12'),
	(243, 1, 0, -50008, 6, 1, 0, 39, '5'),
	(243, 1, 0, -50008, 6, 2, 0, 37, '13'),
	(243, 1, 0, -50008, 6, 2, 0, 39, '5'),
	(243, 1, 0, -50008, 6, 3, 0, 37, '14'),
	(243, 1, 0, -50008, 6, 3, 0, 39, '5'),
	(243, 1, 0, -50008, 6, 4, 0, 37, '15'),
	(243, 1, 0, -50008, 6, 4, 0, 39, '5'),
	(243, 1, 0, -50008, 7, 1, 0, 37, '12'),
	(243, 1, 0, -50008, 7, 1, 0, 39, '6'),
	(243, 1, 0, -50008, 7, 2, 0, 37, '13'),
	(243, 1, 0, -50008, 7, 2, 0, 39, '6'),
	(243, 1, 0, -50008, 7, 3, 0, 37, '14'),
	(243, 1, 0, -50008, 7, 3, 0, 39, '6'),
	(243, 1, 0, -50008, 7, 4, 0, 37, '15'),
	(243, 1, 0, -50008, 7, 4, 0, 39, '6'),
	(243, 1, 0, -50008, 8, 1, 0, 37, '12'),
	(243, 1, 0, -50008, 8, 1, 0, 39, '7'),
	(243, 1, 0, -50008, 8, 2, 0, 37, '13'),
	(243, 1, 0, -50008, 8, 2, 0, 39, '7'),
	(243, 1, 0, -50008, 8, 3, 0, 37, '14'),
	(243, 1, 0, -50008, 8, 3, 0, 39, '7'),
	(243, 1, 0, -50008, 8, 4, 0, 37, '15'),
	(243, 1, 0, -50008, 8, 4, 0, 39, '7'),
	(243, 1, 0, -50008, 9, 1, 0, 37, '12'),
	(243, 1, 0, -50008, 9, 1, 0, 39, '8'),
	(243, 1, 0, -50008, 9, 2, 0, 37, '13'),
	(243, 1, 0, -50008, 9, 2, 0, 39, '8'),
	(243, 1, 0, -50008, 9, 3, 0, 37, '14'),
	(243, 1, 0, -50008, 9, 3, 0, 39, '8'),
	(243, 1, 0, -50008, 9, 4, 0, 37, '15'),
	(243, 1, 0, -50008, 9, 4, 0, 39, '8'),
	(243, 1, 0, -50008, 10, 1, 0, 37, '12'),
	(243, 1, 0, -50008, 10, 1, 0, 39, '9'),
	(243, 1, 0, -50008, 10, 2, 0, 37, '13'),
	(243, 1, 0, -50008, 10, 2, 0, 39, '9'),
	(243, 1, 0, -50008, 10, 3, 0, 37, '14'),
	(243, 1, 0, -50008, 10, 3, 0, 39, '9'),
	(243, 1, 0, -50008, 10, 4, 0, 37, '15'),
	(243, 1, 0, -50008, 10, 4, 0, 39, '9'),
	(243, 1, 0, -50008, 11, 1, 0, 37, '12'),
	(243, 1, 0, -50008, 11, 1, 0, 39, '10'),
	(243, 1, 0, -50008, 11, 2, 0, 37, '13'),
	(243, 1, 0, -50008, 11, 2, 0, 39, '10'),
	(243, 1, 0, -50008, 11, 3, 0, 37, '14'),
	(243, 1, 0, -50008, 11, 3, 0, 39, '10'),
	(243, 1, 0, -50008, 11, 4, 0, 37, '15'),
	(243, 1, 0, -50008, 11, 4, 0, 39, '10'),
	(243, 1, 0, -50008, 12, 1, 0, 37, '12'),
	(243, 1, 0, -50008, 12, 1, 0, 39, '11'),
	(243, 1, 0, -50008, 12, 2, 0, 37, '13'),
	(243, 1, 0, -50008, 12, 2, 0, 39, '11'),
	(243, 1, 0, -50008, 12, 3, 0, 37, '14'),
	(243, 1, 0, -50008, 12, 3, 0, 39, '11'),
	(243, 1, 0, -50008, 12, 4, 0, 37, '15'),
	(243, 1, 0, -50008, 12, 4, 0, 39, '11'),
	(243, 1, 0, -50007, 1, 1, 0, 37, '12'),
	(243, 1, 0, -50007, 1, 1, 0, 39, '0'),
	(243, 1, 0, -50007, 1, 2, 0, 37, '13'),
	(243, 1, 0, -50007, 1, 2, 0, 39, '0'),
	(243, 1, 0, -50007, 1, 3, 0, 37, '14'),
	(243, 1, 0, -50007, 1, 3, 0, 39, '0'),
	(243, 1, 0, -50007, 1, 4, 0, 37, '15'),
	(243, 1, 0, -50007, 1, 4, 0, 39, '0'),
	(243, 1, 0, -50007, 2, 1, 0, 37, '12'),
	(243, 1, 0, -50007, 2, 1, 0, 39, '1'),
	(243, 1, 0, -50007, 2, 2, 0, 37, '13'),
	(243, 1, 0, -50007, 2, 2, 0, 39, '1'),
	(243, 1, 0, -50007, 2, 3, 0, 37, '14'),
	(243, 1, 0, -50007, 2, 3, 0, 39, '1'),
	(243, 1, 0, -50007, 2, 4, 0, 37, '15'),
	(243, 1, 0, -50007, 2, 4, 0, 39, '1'),
	(243, 1, 0, -50007, 3, 1, 0, 37, '12'),
	(243, 1, 0, -50007, 3, 1, 0, 39, '2'),
	(243, 1, 0, -50007, 3, 2, 0, 37, '13'),
	(243, 1, 0, -50007, 3, 2, 0, 39, '2'),
	(243, 1, 0, -50007, 3, 3, 0, 37, '14'),
	(243, 1, 0, -50007, 3, 3, 0, 39, '2'),
	(243, 1, 0, -50007, 3, 4, 0, 37, '15'),
	(243, 1, 0, -50007, 3, 4, 0, 39, '2'),
	(243, 1, 0, -50007, 4, 1, 0, 37, '12'),
	(243, 1, 0, -50007, 4, 1, 0, 39, '3'),
	(243, 1, 0, -50007, 4, 2, 0, 37, '13'),
	(243, 1, 0, -50007, 4, 2, 0, 39, '3'),
	(243, 1, 0, -50007, 4, 3, 0, 37, '14'),
	(243, 1, 0, -50007, 4, 3, 0, 39, '3'),
	(243, 1, 0, -50007, 4, 4, 0, 37, '15'),
	(243, 1, 0, -50007, 4, 4, 0, 39, '3'),
	(243, 1, 0, -50007, 5, 1, 0, 37, '12'),
	(243, 1, 0, -50007, 5, 1, 0, 39, '4'),
	(243, 1, 0, -50007, 5, 2, 0, 37, '13'),
	(243, 1, 0, -50007, 5, 2, 0, 39, '4'),
	(243, 1, 0, -50007, 5, 3, 0, 37, '14'),
	(243, 1, 0, -50007, 5, 3, 0, 39, '4'),
	(243, 1, 0, -50007, 5, 4, 0, 37, '15'),
	(243, 1, 0, -50007, 5, 4, 0, 39, '4'),
	(243, 1, 0, -50007, 6, 1, 0, 37, '12'),
	(243, 1, 0, -50007, 6, 1, 0, 39, '5'),
	(243, 1, 0, -50007, 6, 2, 0, 37, '13'),
	(243, 1, 0, -50007, 6, 2, 0, 39, '5'),
	(243, 1, 0, -50007, 6, 3, 0, 37, '14'),
	(243, 1, 0, -50007, 6, 3, 0, 39, '5'),
	(243, 1, 0, -50007, 6, 4, 0, 37, '15'),
	(243, 1, 0, -50007, 6, 4, 0, 39, '5'),
	(243, 1, 0, -50007, 7, 1, 0, 37, '12'),
	(243, 1, 0, -50007, 7, 1, 0, 39, '6'),
	(243, 1, 0, -50007, 7, 2, 0, 37, '13'),
	(243, 1, 0, -50007, 7, 2, 0, 39, '6'),
	(243, 1, 0, -50007, 7, 3, 0, 37, '14'),
	(243, 1, 0, -50007, 7, 3, 0, 39, '6'),
	(243, 1, 0, -50007, 7, 4, 0, 37, '15'),
	(243, 1, 0, -50007, 7, 4, 0, 39, '6'),
	(243, 1, 0, -50007, 8, 1, 0, 37, '12'),
	(243, 1, 0, -50007, 8, 1, 0, 39, '7'),
	(243, 1, 0, -50007, 8, 2, 0, 37, '13'),
	(243, 1, 0, -50007, 8, 2, 0, 39, '7'),
	(243, 1, 0, -50007, 8, 3, 0, 37, '14'),
	(243, 1, 0, -50007, 8, 3, 0, 39, '7'),
	(243, 1, 0, -50007, 8, 4, 0, 37, '15'),
	(243, 1, 0, -50007, 8, 4, 0, 39, '7'),
	(243, 1, 0, -50007, 9, 1, 0, 37, '12'),
	(243, 1, 0, -50007, 9, 1, 0, 39, '8'),
	(243, 1, 0, -50007, 9, 2, 0, 37, '13'),
	(243, 1, 0, -50007, 9, 2, 0, 39, '8'),
	(243, 1, 0, -50007, 9, 3, 0, 37, '14'),
	(243, 1, 0, -50007, 9, 3, 0, 39, '8'),
	(243, 1, 0, -50007, 9, 4, 0, 37, '15'),
	(243, 1, 0, -50007, 9, 4, 0, 39, '8'),
	(243, 1, 0, -50007, 10, 1, 0, 37, '12'),
	(243, 1, 0, -50007, 10, 1, 0, 39, '9'),
	(243, 1, 0, -50007, 10, 2, 0, 37, '13'),
	(243, 1, 0, -50007, 10, 2, 0, 39, '9'),
	(243, 1, 0, -50007, 10, 3, 0, 37, '14'),
	(243, 1, 0, -50007, 10, 3, 0, 39, '9'),
	(243, 1, 0, -50007, 10, 4, 0, 37, '15'),
	(243, 1, 0, -50007, 10, 4, 0, 39, '9'),
	(243, 1, 0, -50007, 11, 1, 0, 37, '12'),
	(243, 1, 0, -50007, 11, 1, 0, 39, '10'),
	(243, 1, 0, -50007, 11, 2, 0, 37, '13'),
	(243, 1, 0, -50007, 11, 2, 0, 39, '10'),
	(243, 1, 0, -50007, 11, 3, 0, 37, '14'),
	(243, 1, 0, -50007, 11, 3, 0, 39, '10'),
	(243, 1, 0, -50007, 11, 4, 0, 37, '15'),
	(243, 1, 0, -50007, 11, 4, 0, 39, '10'),
	(243, 1, 0, -50007, 12, 1, 0, 37, '12'),
	(243, 1, 0, -50007, 12, 1, 0, 39, '11'),
	(243, 1, 0, -50007, 12, 2, 0, 37, '13'),
	(243, 1, 0, -50007, 12, 2, 0, 39, '11'),
	(243, 1, 0, -50007, 12, 3, 0, 37, '14'),
	(243, 1, 0, -50007, 12, 3, 0, 39, '11'),
	(243, 1, 0, -50007, 12, 4, 0, 37, '15'),
	(243, 1, 0, -50007, 12, 4, 0, 39, '11'),
	(243, 1, 0, -50007, 13, 1, 0, 37, '12'),
	(243, 1, 0, -50007, 13, 1, 0, 39, '12'),
	(243, 1, 0, -50007, 13, 2, 0, 37, '13'),
	(243, 1, 0, -50007, 13, 2, 0, 39, '12'),
	(243, 1, 0, -50007, 13, 3, 0, 37, '14'),
	(243, 1, 0, -50007, 13, 3, 0, 39, '12'),
	(243, 1, 0, -50007, 13, 4, 0, 37, '15'),
	(243, 1, 0, -50007, 13, 4, 0, 39, '12'),
	(243, 1, 0, -50007, 14, 1, 0, 37, '12'),
	(243, 1, 0, -50007, 14, 1, 0, 39, '13'),
	(243, 1, 0, -50007, 14, 2, 0, 37, '13'),
	(243, 1, 0, -50007, 14, 2, 0, 39, '13'),
	(243, 1, 0, -50007, 14, 3, 0, 37, '14'),
	(243, 1, 0, -50007, 14, 3, 0, 39, '13'),
	(243, 1, 0, -50007, 14, 4, 0, 37, '15'),
	(243, 1, 0, -50007, 14, 4, 0, 39, '13'),
	(243, 1, 0, -50007, 15, 1, 0, 37, '12'),
	(243, 1, 0, -50007, 15, 1, 0, 39, '14'),
	(243, 1, 0, -50007, 15, 2, 0, 37, '13'),
	(243, 1, 0, -50007, 15, 2, 0, 39, '14'),
	(243, 1, 0, -50007, 15, 3, 0, 37, '14'),
	(243, 1, 0, -50007, 15, 3, 0, 39, '14'),
	(243, 1, 0, -50007, 15, 4, 0, 37, '15'),
	(243, 1, 0, -50007, 15, 4, 0, 39, '14'),
	(243, 1, 0, -50007, 16, 1, 0, 37, '12'),
	(243, 1, 0, -50007, 16, 1, 0, 39, '15'),
	(243, 1, 0, -50007, 16, 2, 0, 37, '13'),
	(243, 1, 0, -50007, 16, 2, 0, 39, '15'),
	(243, 1, 0, -50007, 16, 3, 0, 37, '14'),
	(243, 1, 0, -50007, 16, 3, 0, 39, '15'),
	(243, 1, 0, -50007, 16, 4, 0, 37, '15'),
	(243, 1, 0, -50007, 16, 4, 0, 39, '15'),
	(243, 1, 0, -50006, 1, 1, 0, 37, '12'),
	(243, 1, 0, -50006, 1, 1, 0, 39, '0'),
	(243, 1, 0, -50006, 1, 2, 0, 37, '13'),
	(243, 1, 0, -50006, 1, 2, 0, 39, '0'),
	(243, 1, 0, -50006, 1, 3, 0, 37, '14'),
	(243, 1, 0, -50006, 1, 3, 0, 39, '0'),
	(243, 1, 0, -50006, 1, 4, 0, 37, '15'),
	(243, 1, 0, -50006, 1, 4, 0, 39, '0'),
	(243, 1, 0, -50006, 2, 1, 0, 37, '12'),
	(243, 1, 0, -50006, 2, 1, 0, 39, '1'),
	(243, 1, 0, -50006, 2, 2, 0, 37, '13'),
	(243, 1, 0, -50006, 2, 2, 0, 39, '1'),
	(243, 1, 0, -50006, 2, 3, 0, 37, '14'),
	(243, 1, 0, -50006, 2, 3, 0, 39, '1'),
	(243, 1, 0, -50006, 2, 4, 0, 37, '15'),
	(243, 1, 0, -50006, 2, 4, 0, 39, '1'),
	(243, 1, 0, -50006, 3, 1, 0, 37, '12'),
	(243, 1, 0, -50006, 3, 1, 0, 39, '2'),
	(243, 1, 0, -50006, 3, 2, 0, 37, '13'),
	(243, 1, 0, -50006, 3, 2, 0, 39, '2'),
	(243, 1, 0, -50006, 3, 3, 0, 37, '14'),
	(243, 1, 0, -50006, 3, 3, 0, 39, '2'),
	(243, 1, 0, -50006, 3, 4, 0, 37, '15'),
	(243, 1, 0, -50006, 3, 4, 0, 39, '2'),
	(243, 1, 0, -50006, 4, 1, 0, 37, '12'),
	(243, 1, 0, -50006, 4, 1, 0, 39, '3'),
	(243, 1, 0, -50006, 4, 2, 0, 37, '13'),
	(243, 1, 0, -50006, 4, 2, 0, 39, '3'),
	(243, 1, 0, -50006, 4, 3, 0, 37, '14'),
	(243, 1, 0, -50006, 4, 3, 0, 39, '3'),
	(243, 1, 0, -50006, 4, 4, 0, 37, '15'),
	(243, 1, 0, -50006, 4, 4, 0, 39, '3'),
	(243, 1, 0, -50006, 5, 1, 0, 37, '12'),
	(243, 1, 0, -50006, 5, 1, 0, 39, '4'),
	(243, 1, 0, -50006, 5, 2, 0, 37, '13'),
	(243, 1, 0, -50006, 5, 2, 0, 39, '4'),
	(243, 1, 0, -50006, 5, 3, 0, 37, '14'),
	(243, 1, 0, -50006, 5, 3, 0, 39, '4'),
	(243, 1, 0, -50006, 5, 4, 0, 37, '15'),
	(243, 1, 0, -50006, 5, 4, 0, 39, '4'),
	(243, 1, 0, -50006, 6, 1, 0, 37, '12'),
	(243, 1, 0, -50006, 6, 1, 0, 39, '5'),
	(243, 1, 0, -50006, 6, 2, 0, 37, '13'),
	(243, 1, 0, -50006, 6, 2, 0, 39, '5'),
	(243, 1, 0, -50006, 6, 3, 0, 37, '14'),
	(243, 1, 0, -50006, 6, 3, 0, 39, '5'),
	(243, 1, 0, -50006, 6, 4, 0, 37, '15'),
	(243, 1, 0, -50006, 6, 4, 0, 39, '5'),
	(243, 1, 0, -50006, 7, 1, 0, 37, '12'),
	(243, 1, 0, -50006, 7, 1, 0, 39, '6'),
	(243, 1, 0, -50006, 7, 2, 0, 37, '13'),
	(243, 1, 0, -50006, 7, 2, 0, 39, '6'),
	(243, 1, 0, -50006, 7, 3, 0, 37, '14'),
	(243, 1, 0, -50006, 7, 3, 0, 39, '6'),
	(243, 1, 0, -50006, 7, 4, 0, 37, '15'),
	(243, 1, 0, -50006, 7, 4, 0, 39, '6'),
	(243, 1, 0, -50006, 8, 1, 0, 37, '12'),
	(243, 1, 0, -50006, 8, 1, 0, 39, '7'),
	(243, 1, 0, -50006, 8, 2, 0, 37, '13'),
	(243, 1, 0, -50006, 8, 2, 0, 39, '7'),
	(243, 1, 0, -50006, 8, 3, 0, 37, '14'),
	(243, 1, 0, -50006, 8, 3, 0, 39, '7'),
	(243, 1, 0, -50006, 8, 4, 0, 37, '15'),
	(243, 1, 0, -50006, 8, 4, 0, 39, '7'),
	(243, 1, 0, -50006, 9, 1, 0, 37, '12'),
	(243, 1, 0, -50006, 9, 1, 0, 39, '8'),
	(243, 1, 0, -50006, 9, 2, 0, 37, '13'),
	(243, 1, 0, -50006, 9, 2, 0, 39, '8'),
	(243, 1, 0, -50006, 9, 3, 0, 37, '14'),
	(243, 1, 0, -50006, 9, 3, 0, 39, '8'),
	(243, 1, 0, -50006, 9, 4, 0, 37, '15'),
	(243, 1, 0, -50006, 9, 4, 0, 39, '8'),
	(243, 1, 0, -50006, 10, 1, 0, 37, '12'),
	(243, 1, 0, -50006, 10, 1, 0, 39, '9'),
	(243, 1, 0, -50006, 10, 2, 0, 37, '13'),
	(243, 1, 0, -50006, 10, 2, 0, 39, '9'),
	(243, 1, 0, -50006, 10, 3, 0, 37, '14'),
	(243, 1, 0, -50006, 10, 3, 0, 39, '9'),
	(243, 1, 0, -50006, 10, 4, 0, 37, '15'),
	(243, 1, 0, -50006, 10, 4, 0, 39, '9'),
	(243, 1, 0, -50006, 11, 1, 0, 37, '12'),
	(243, 1, 0, -50006, 11, 1, 0, 39, '10'),
	(243, 1, 0, -50006, 11, 2, 0, 37, '13'),
	(243, 1, 0, -50006, 11, 2, 0, 39, '10'),
	(243, 1, 0, -50006, 11, 3, 0, 37, '14'),
	(243, 1, 0, -50006, 11, 3, 0, 39, '10'),
	(243, 1, 0, -50006, 11, 4, 0, 37, '15'),
	(243, 1, 0, -50006, 11, 4, 0, 39, '10'),
	(243, 1, 0, -50006, 12, 1, 0, 37, '12'),
	(243, 1, 0, -50006, 12, 1, 0, 39, '11'),
	(243, 1, 0, -50006, 12, 2, 0, 37, '13'),
	(243, 1, 0, -50006, 12, 2, 0, 39, '11'),
	(243, 1, 0, -50006, 12, 3, 0, 37, '14'),
	(243, 1, 0, -50006, 12, 3, 0, 39, '11'),
	(243, 1, 0, -50006, 12, 4, 0, 37, '15'),
	(243, 1, 0, -50006, 12, 4, 0, 39, '11'),
	(243, 1, 0, -50006, 13, 1, 0, 37, '12'),
	(243, 1, 0, -50006, 13, 1, 0, 39, '12'),
	(243, 1, 0, -50006, 13, 2, 0, 37, '13'),
	(243, 1, 0, -50006, 13, 2, 0, 39, '12'),
	(243, 1, 0, -50006, 13, 3, 0, 37, '14'),
	(243, 1, 0, -50006, 13, 3, 0, 39, '12'),
	(243, 1, 0, -50006, 13, 4, 0, 37, '15'),
	(243, 1, 0, -50006, 13, 4, 0, 39, '12'),
	(243, 1, 0, -50006, 14, 1, 0, 37, '12'),
	(243, 1, 0, -50006, 14, 1, 0, 39, '13'),
	(243, 1, 0, -50006, 14, 2, 0, 37, '13'),
	(243, 1, 0, -50006, 14, 2, 0, 39, '13'),
	(243, 1, 0, -50006, 14, 3, 0, 37, '14'),
	(243, 1, 0, -50006, 14, 3, 0, 39, '13'),
	(243, 1, 0, -50006, 14, 4, 0, 37, '15'),
	(243, 1, 0, -50006, 14, 4, 0, 39, '13'),
	(243, 1, 0, -50006, 15, 1, 0, 37, '12'),
	(243, 1, 0, -50006, 15, 1, 0, 39, '14'),
	(243, 1, 0, -50006, 15, 2, 0, 37, '13'),
	(243, 1, 0, -50006, 15, 2, 0, 39, '14'),
	(243, 1, 0, -50006, 15, 3, 0, 37, '14'),
	(243, 1, 0, -50006, 15, 3, 0, 39, '14'),
	(243, 1, 0, -50006, 15, 4, 0, 37, '15'),
	(243, 1, 0, -50006, 15, 4, 0, 39, '14'),
	(243, 1, 0, -50006, 16, 1, 0, 37, '12'),
	(243, 1, 0, -50006, 16, 1, 0, 39, '15'),
	(243, 1, 0, -50006, 16, 2, 0, 37, '13'),
	(243, 1, 0, -50006, 16, 2, 0, 39, '15'),
	(243, 1, 0, -50006, 16, 3, 0, 37, '14'),
	(243, 1, 0, -50006, 16, 3, 0, 39, '15'),
	(243, 1, 0, -50006, 16, 4, 0, 37, '15'),
	(243, 1, 0, -50006, 16, 4, 0, 39, '15'),
	(243, 1, 0, -50005, 1, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 1, 1, 0, 39, '0'),
	(243, 1, 0, -50005, 1, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 1, 2, 0, 39, '0'),
	(243, 1, 0, -50005, 1, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 1, 3, 0, 39, '0'),
	(243, 1, 0, -50005, 1, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 1, 4, 0, 39, '0'),
	(243, 1, 0, -50005, 2, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 2, 1, 0, 39, '1'),
	(243, 1, 0, -50005, 2, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 2, 2, 0, 39, '1'),
	(243, 1, 0, -50005, 2, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 2, 3, 0, 39, '1'),
	(243, 1, 0, -50005, 2, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 2, 4, 0, 39, '1'),
	(243, 1, 0, -50005, 3, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 3, 1, 0, 39, '2'),
	(243, 1, 0, -50005, 3, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 3, 2, 0, 39, '2'),
	(243, 1, 0, -50005, 3, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 3, 3, 0, 39, '2'),
	(243, 1, 0, -50005, 3, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 3, 4, 0, 39, '2'),
	(243, 1, 0, -50005, 4, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 4, 1, 0, 39, '3'),
	(243, 1, 0, -50005, 4, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 4, 2, 0, 39, '3'),
	(243, 1, 0, -50005, 4, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 4, 3, 0, 39, '3'),
	(243, 1, 0, -50005, 4, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 4, 4, 0, 39, '3'),
	(243, 1, 0, -50005, 5, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 5, 1, 0, 39, '4'),
	(243, 1, 0, -50005, 5, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 5, 2, 0, 39, '4'),
	(243, 1, 0, -50005, 5, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 5, 3, 0, 39, '4'),
	(243, 1, 0, -50005, 5, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 5, 4, 0, 39, '4'),
	(243, 1, 0, -50005, 6, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 6, 1, 0, 39, '5'),
	(243, 1, 0, -50005, 6, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 6, 2, 0, 39, '5'),
	(243, 1, 0, -50005, 6, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 6, 3, 0, 39, '5'),
	(243, 1, 0, -50005, 6, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 6, 4, 0, 39, '5'),
	(243, 1, 0, -50005, 7, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 7, 1, 0, 39, '6'),
	(243, 1, 0, -50005, 7, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 7, 2, 0, 39, '6'),
	(243, 1, 0, -50005, 7, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 7, 3, 0, 39, '6'),
	(243, 1, 0, -50005, 7, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 7, 4, 0, 39, '6'),
	(243, 1, 0, -50005, 8, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 8, 1, 0, 39, '7'),
	(243, 1, 0, -50005, 8, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 8, 2, 0, 39, '7'),
	(243, 1, 0, -50005, 8, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 8, 3, 0, 39, '7'),
	(243, 1, 0, -50005, 8, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 8, 4, 0, 39, '7'),
	(243, 1, 0, -50005, 9, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 9, 1, 0, 39, '8'),
	(243, 1, 0, -50005, 9, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 9, 2, 0, 39, '8'),
	(243, 1, 0, -50005, 9, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 9, 3, 0, 39, '8'),
	(243, 1, 0, -50005, 9, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 9, 4, 0, 39, '8'),
	(243, 1, 0, -50005, 10, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 10, 1, 0, 39, '9'),
	(243, 1, 0, -50005, 10, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 10, 2, 0, 39, '9'),
	(243, 1, 0, -50005, 10, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 10, 3, 0, 39, '9'),
	(243, 1, 0, -50005, 10, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 10, 4, 0, 39, '9'),
	(243, 1, 0, -50005, 11, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 11, 1, 0, 39, '10'),
	(243, 1, 0, -50005, 11, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 11, 2, 0, 39, '10'),
	(243, 1, 0, -50005, 11, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 11, 3, 0, 39, '10'),
	(243, 1, 0, -50005, 11, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 11, 4, 0, 39, '10'),
	(243, 1, 0, -50005, 12, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 12, 1, 0, 39, '11'),
	(243, 1, 0, -50005, 12, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 12, 2, 0, 39, '11'),
	(243, 1, 0, -50005, 12, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 12, 3, 0, 39, '11'),
	(243, 1, 0, -50005, 12, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 12, 4, 0, 39, '11'),
	(243, 1, 0, -50005, 13, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 13, 1, 0, 39, '12'),
	(243, 1, 0, -50005, 13, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 13, 2, 0, 39, '12'),
	(243, 1, 0, -50005, 13, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 13, 3, 0, 39, '12'),
	(243, 1, 0, -50005, 13, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 13, 4, 0, 39, '12'),
	(243, 1, 0, -50005, 14, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 14, 1, 0, 39, '13'),
	(243, 1, 0, -50005, 14, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 14, 2, 0, 39, '13'),
	(243, 1, 0, -50005, 14, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 14, 3, 0, 39, '13'),
	(243, 1, 0, -50005, 14, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 14, 4, 0, 39, '13'),
	(243, 1, 0, -50005, 15, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 15, 1, 0, 39, '14'),
	(243, 1, 0, -50005, 15, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 15, 2, 0, 39, '14'),
	(243, 1, 0, -50005, 15, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 15, 3, 0, 39, '14'),
	(243, 1, 0, -50005, 15, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 15, 4, 0, 39, '14'),
	(243, 1, 0, -50005, 16, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 16, 1, 0, 39, '15'),
	(243, 1, 0, -50005, 16, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 16, 2, 0, 39, '15'),
	(243, 1, 0, -50005, 16, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 16, 3, 0, 39, '15'),
	(243, 1, 0, -50005, 16, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 16, 4, 0, 39, '15'),
	(243, 1, 0, -50005, 17, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 17, 1, 0, 39, '16'),
	(243, 1, 0, -50005, 17, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 17, 2, 0, 39, '16'),
	(243, 1, 0, -50005, 17, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 17, 3, 0, 39, '16'),
	(243, 1, 0, -50005, 17, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 17, 4, 0, 39, '16'),
	(243, 1, 0, -50005, 18, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 18, 1, 0, 39, '17'),
	(243, 1, 0, -50005, 18, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 18, 2, 0, 39, '17'),
	(243, 1, 0, -50005, 18, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 18, 3, 0, 39, '17'),
	(243, 1, 0, -50005, 18, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 18, 4, 0, 39, '17'),
	(243, 1, 0, -50005, 19, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 19, 1, 0, 39, '18'),
	(243, 1, 0, -50005, 19, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 19, 2, 0, 39, '18'),
	(243, 1, 0, -50005, 19, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 19, 3, 0, 39, '18'),
	(243, 1, 0, -50005, 19, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 19, 4, 0, 39, '18'),
	(243, 1, 0, -50005, 20, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 20, 1, 0, 39, '19'),
	(243, 1, 0, -50005, 20, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 20, 2, 0, 39, '19'),
	(243, 1, 0, -50005, 20, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 20, 3, 0, 39, '19'),
	(243, 1, 0, -50005, 20, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 20, 4, 0, 39, '19'),
	(243, 1, 0, -50005, 21, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 21, 1, 0, 39, '20'),
	(243, 1, 0, -50005, 21, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 21, 2, 0, 39, '20'),
	(243, 1, 0, -50005, 21, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 21, 3, 0, 39, '20'),
	(243, 1, 0, -50005, 21, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 21, 4, 0, 39, '20'),
	(243, 1, 0, -50005, 22, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 22, 1, 0, 39, '21'),
	(243, 1, 0, -50005, 22, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 22, 2, 0, 39, '21'),
	(243, 1, 0, -50005, 22, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 22, 3, 0, 39, '21'),
	(243, 1, 0, -50005, 22, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 22, 4, 0, 39, '21'),
	(243, 1, 0, -50005, 23, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 23, 1, 0, 39, '22'),
	(243, 1, 0, -50005, 23, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 23, 2, 0, 39, '22'),
	(243, 1, 0, -50005, 23, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 23, 3, 0, 39, '22'),
	(243, 1, 0, -50005, 23, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 23, 4, 0, 39, '22'),
	(243, 1, 0, -50005, 24, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 24, 1, 0, 39, '23'),
	(243, 1, 0, -50005, 24, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 24, 2, 0, 39, '23'),
	(243, 1, 0, -50005, 24, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 24, 3, 0, 39, '23'),
	(243, 1, 0, -50005, 24, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 24, 4, 0, 39, '23'),
	(243, 1, 0, -50005, 25, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 25, 1, 0, 39, '24'),
	(243, 1, 0, -50005, 25, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 25, 2, 0, 39, '24'),
	(243, 1, 0, -50005, 25, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 25, 3, 0, 39, '24'),
	(243, 1, 0, -50005, 25, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 25, 4, 0, 39, '24'),
	(243, 1, 0, -50005, 26, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 26, 1, 0, 39, '25'),
	(243, 1, 0, -50005, 26, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 26, 2, 0, 39, '25'),
	(243, 1, 0, -50005, 26, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 26, 3, 0, 39, '25'),
	(243, 1, 0, -50005, 26, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 26, 4, 0, 39, '25'),
	(243, 1, 0, -50005, 27, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 27, 1, 0, 39, '26'),
	(243, 1, 0, -50005, 27, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 27, 2, 0, 39, '26'),
	(243, 1, 0, -50005, 27, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 27, 3, 0, 39, '26'),
	(243, 1, 0, -50005, 27, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 27, 4, 0, 39, '26'),
	(243, 1, 0, -50005, 28, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 28, 1, 0, 39, '27'),
	(243, 1, 0, -50005, 28, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 28, 2, 0, 39, '27'),
	(243, 1, 0, -50005, 28, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 28, 3, 0, 39, '27'),
	(243, 1, 0, -50005, 28, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 28, 4, 0, 39, '27'),
	(243, 1, 0, -50005, 29, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 29, 1, 0, 39, '28'),
	(243, 1, 0, -50005, 29, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 29, 2, 0, 39, '28'),
	(243, 1, 0, -50005, 29, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 29, 3, 0, 39, '28'),
	(243, 1, 0, -50005, 29, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 29, 4, 0, 39, '28'),
	(243, 1, 0, -50005, 30, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 30, 1, 0, 39, '29'),
	(243, 1, 0, -50005, 30, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 30, 2, 0, 39, '29'),
	(243, 1, 0, -50005, 30, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 30, 3, 0, 39, '29'),
	(243, 1, 0, -50005, 30, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 30, 4, 0, 39, '29'),
	(243, 1, 0, -50005, 31, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 31, 1, 0, 39, '30'),
	(243, 1, 0, -50005, 31, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 31, 2, 0, 39, '30'),
	(243, 1, 0, -50005, 31, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 31, 3, 0, 39, '30'),
	(243, 1, 0, -50005, 31, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 31, 4, 0, 39, '30'),
	(243, 1, 0, -50005, 32, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 32, 1, 0, 39, '31'),
	(243, 1, 0, -50005, 32, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 32, 2, 0, 39, '31'),
	(243, 1, 0, -50005, 32, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 32, 3, 0, 39, '31'),
	(243, 1, 0, -50005, 32, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 32, 4, 0, 39, '31'),
	(243, 1, 0, -50005, 33, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 33, 1, 0, 39, '32'),
	(243, 1, 0, -50005, 33, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 33, 2, 0, 39, '32'),
	(243, 1, 0, -50005, 33, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 33, 3, 0, 39, '32'),
	(243, 1, 0, -50005, 33, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 33, 4, 0, 39, '32'),
	(243, 1, 0, -50005, 34, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 34, 1, 0, 39, '33'),
	(243, 1, 0, -50005, 34, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 34, 2, 0, 39, '33'),
	(243, 1, 0, -50005, 34, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 34, 3, 0, 39, '33'),
	(243, 1, 0, -50005, 34, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 34, 4, 0, 39, '33'),
	(243, 1, 0, -50005, 35, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 35, 1, 0, 39, '34'),
	(243, 1, 0, -50005, 35, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 35, 2, 0, 39, '34'),
	(243, 1, 0, -50005, 35, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 35, 3, 0, 39, '34'),
	(243, 1, 0, -50005, 35, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 35, 4, 0, 39, '34'),
	(243, 1, 0, -50005, 36, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 36, 1, 0, 39, '35'),
	(243, 1, 0, -50005, 36, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 36, 2, 0, 39, '35'),
	(243, 1, 0, -50005, 36, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 36, 3, 0, 39, '35'),
	(243, 1, 0, -50005, 36, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 36, 4, 0, 39, '35'),
	(243, 1, 0, -50005, 37, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 37, 1, 0, 39, '36'),
	(243, 1, 0, -50005, 37, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 37, 2, 0, 39, '36'),
	(243, 1, 0, -50005, 37, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 37, 3, 0, 39, '36'),
	(243, 1, 0, -50005, 37, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 37, 4, 0, 39, '36'),
	(243, 1, 0, -50005, 38, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 38, 1, 0, 39, '37'),
	(243, 1, 0, -50005, 38, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 38, 2, 0, 39, '37'),
	(243, 1, 0, -50005, 38, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 38, 3, 0, 39, '37'),
	(243, 1, 0, -50005, 38, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 38, 4, 0, 39, '37'),
	(243, 1, 0, -50005, 39, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 39, 1, 0, 39, '38'),
	(243, 1, 0, -50005, 39, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 39, 2, 0, 39, '38'),
	(243, 1, 0, -50005, 39, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 39, 3, 0, 39, '38'),
	(243, 1, 0, -50005, 39, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 39, 4, 0, 39, '38'),
	(243, 1, 0, -50005, 40, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 40, 1, 0, 39, '39'),
	(243, 1, 0, -50005, 40, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 40, 2, 0, 39, '39'),
	(243, 1, 0, -50005, 40, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 40, 3, 0, 39, '39'),
	(243, 1, 0, -50005, 40, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 40, 4, 0, 39, '39'),
	(243, 1, 0, -50005, 41, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 41, 1, 0, 39, '40'),
	(243, 1, 0, -50005, 41, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 41, 2, 0, 39, '40'),
	(243, 1, 0, -50005, 41, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 41, 3, 0, 39, '40'),
	(243, 1, 0, -50005, 41, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 41, 4, 0, 39, '40'),
	(243, 1, 0, -50005, 42, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 42, 1, 0, 39, '41'),
	(243, 1, 0, -50005, 42, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 42, 2, 0, 39, '41'),
	(243, 1, 0, -50005, 42, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 42, 3, 0, 39, '41'),
	(243, 1, 0, -50005, 42, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 42, 4, 0, 39, '41'),
	(243, 1, 0, -50005, 43, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 43, 1, 0, 39, '42'),
	(243, 1, 0, -50005, 43, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 43, 2, 0, 39, '42'),
	(243, 1, 0, -50005, 43, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 43, 3, 0, 39, '42'),
	(243, 1, 0, -50005, 43, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 43, 4, 0, 39, '42'),
	(243, 1, 0, -50005, 44, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 44, 1, 0, 39, '43'),
	(243, 1, 0, -50005, 44, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 44, 2, 0, 39, '43'),
	(243, 1, 0, -50005, 44, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 44, 3, 0, 39, '43'),
	(243, 1, 0, -50005, 44, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 44, 4, 0, 39, '43'),
	(243, 1, 0, -50005, 45, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 45, 1, 0, 39, '44'),
	(243, 1, 0, -50005, 45, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 45, 2, 0, 39, '44'),
	(243, 1, 0, -50005, 45, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 45, 3, 0, 39, '44'),
	(243, 1, 0, -50005, 45, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 45, 4, 0, 39, '44'),
	(243, 1, 0, -50005, 46, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 46, 1, 0, 39, '45'),
	(243, 1, 0, -50005, 46, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 46, 2, 0, 39, '45'),
	(243, 1, 0, -50005, 46, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 46, 3, 0, 39, '45'),
	(243, 1, 0, -50005, 46, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 46, 4, 0, 39, '45'),
	(243, 1, 0, -50005, 47, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 47, 1, 0, 39, '46'),
	(243, 1, 0, -50005, 47, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 47, 2, 0, 39, '46'),
	(243, 1, 0, -50005, 47, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 47, 3, 0, 39, '46'),
	(243, 1, 0, -50005, 47, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 47, 4, 0, 39, '46'),
	(243, 1, 0, -50005, 48, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 48, 1, 0, 39, '47'),
	(243, 1, 0, -50005, 48, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 48, 2, 0, 39, '47'),
	(243, 1, 0, -50005, 48, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 48, 3, 0, 39, '47'),
	(243, 1, 0, -50005, 48, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 48, 4, 0, 39, '47'),
	(243, 1, 0, -50005, 49, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 49, 1, 0, 39, '48'),
	(243, 1, 0, -50005, 49, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 49, 2, 0, 39, '48'),
	(243, 1, 0, -50005, 49, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 49, 3, 0, 39, '48'),
	(243, 1, 0, -50005, 49, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 49, 4, 0, 39, '48'),
	(243, 1, 0, -50005, 50, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 50, 1, 0, 39, '49'),
	(243, 1, 0, -50005, 50, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 50, 2, 0, 39, '49'),
	(243, 1, 0, -50005, 50, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 50, 3, 0, 39, '49'),
	(243, 1, 0, -50005, 50, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 50, 4, 0, 39, '49'),
	(243, 1, 0, -50005, 51, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 51, 1, 0, 39, '50'),
	(243, 1, 0, -50005, 51, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 51, 2, 0, 39, '50'),
	(243, 1, 0, -50005, 51, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 51, 3, 0, 39, '50'),
	(243, 1, 0, -50005, 51, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 51, 4, 0, 39, '50'),
	(243, 1, 0, -50005, 52, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 52, 1, 0, 39, '51'),
	(243, 1, 0, -50005, 52, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 52, 2, 0, 39, '51'),
	(243, 1, 0, -50005, 52, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 52, 3, 0, 39, '51'),
	(243, 1, 0, -50005, 52, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 52, 4, 0, 39, '51'),
	(243, 1, 0, -50005, 53, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 53, 1, 0, 39, '52'),
	(243, 1, 0, -50005, 53, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 53, 2, 0, 39, '52'),
	(243, 1, 0, -50005, 53, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 53, 3, 0, 39, '52'),
	(243, 1, 0, -50005, 53, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 53, 4, 0, 39, '52'),
	(243, 1, 0, -50005, 54, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 54, 1, 0, 39, '53'),
	(243, 1, 0, -50005, 54, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 54, 2, 0, 39, '53'),
	(243, 1, 0, -50005, 54, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 54, 3, 0, 39, '53'),
	(243, 1, 0, -50005, 54, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 54, 4, 0, 39, '53'),
	(243, 1, 0, -50005, 55, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 55, 1, 0, 39, '54'),
	(243, 1, 0, -50005, 55, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 55, 2, 0, 39, '54'),
	(243, 1, 0, -50005, 55, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 55, 3, 0, 39, '54'),
	(243, 1, 0, -50005, 55, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 55, 4, 0, 39, '54'),
	(243, 1, 0, -50005, 56, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 56, 1, 0, 39, '55'),
	(243, 1, 0, -50005, 56, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 56, 2, 0, 39, '55'),
	(243, 1, 0, -50005, 56, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 56, 3, 0, 39, '55'),
	(243, 1, 0, -50005, 56, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 56, 4, 0, 39, '55'),
	(243, 1, 0, -50005, 57, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 57, 1, 0, 39, '56'),
	(243, 1, 0, -50005, 57, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 57, 2, 0, 39, '56'),
	(243, 1, 0, -50005, 57, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 57, 3, 0, 39, '56'),
	(243, 1, 0, -50005, 57, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 57, 4, 0, 39, '56'),
	(243, 1, 0, -50005, 58, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 58, 1, 0, 39, '57'),
	(243, 1, 0, -50005, 58, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 58, 2, 0, 39, '57'),
	(243, 1, 0, -50005, 58, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 58, 3, 0, 39, '57'),
	(243, 1, 0, -50005, 58, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 58, 4, 0, 39, '57'),
	(243, 1, 0, -50005, 59, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 59, 1, 0, 39, '58'),
	(243, 1, 0, -50005, 59, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 59, 2, 0, 39, '58'),
	(243, 1, 0, -50005, 59, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 59, 3, 0, 39, '58'),
	(243, 1, 0, -50005, 59, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 59, 4, 0, 39, '58'),
	(243, 1, 0, -50005, 60, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 60, 1, 0, 39, '59'),
	(243, 1, 0, -50005, 60, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 60, 2, 0, 39, '59'),
	(243, 1, 0, -50005, 60, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 60, 3, 0, 39, '59'),
	(243, 1, 0, -50005, 60, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 60, 4, 0, 39, '59'),
	(243, 1, 0, -50005, 61, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 61, 1, 0, 39, '60'),
	(243, 1, 0, -50005, 61, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 61, 2, 0, 39, '60'),
	(243, 1, 0, -50005, 61, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 61, 3, 0, 39, '60'),
	(243, 1, 0, -50005, 61, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 61, 4, 0, 39, '60'),
	(243, 1, 0, -50005, 62, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 62, 1, 0, 39, '61'),
	(243, 1, 0, -50005, 62, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 62, 2, 0, 39, '61'),
	(243, 1, 0, -50005, 62, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 62, 3, 0, 39, '61'),
	(243, 1, 0, -50005, 62, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 62, 4, 0, 39, '61'),
	(243, 1, 0, -50005, 63, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 63, 1, 0, 39, '62'),
	(243, 1, 0, -50005, 63, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 63, 2, 0, 39, '62'),
	(243, 1, 0, -50005, 63, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 63, 3, 0, 39, '62'),
	(243, 1, 0, -50005, 63, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 63, 4, 0, 39, '62'),
	(243, 1, 0, -50005, 64, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 64, 1, 0, 39, '63'),
	(243, 1, 0, -50005, 64, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 64, 2, 0, 39, '63'),
	(243, 1, 0, -50005, 64, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 64, 3, 0, 39, '63'),
	(243, 1, 0, -50005, 64, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 64, 4, 0, 39, '63'),
	(243, 1, 0, -50005, 65, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 65, 1, 0, 39, '64'),
	(243, 1, 0, -50005, 65, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 65, 2, 0, 39, '64'),
	(243, 1, 0, -50005, 65, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 65, 3, 0, 39, '64'),
	(243, 1, 0, -50005, 65, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 65, 4, 0, 39, '64'),
	(243, 1, 0, -50005, 66, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 66, 1, 0, 39, '65'),
	(243, 1, 0, -50005, 66, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 66, 2, 0, 39, '65'),
	(243, 1, 0, -50005, 66, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 66, 3, 0, 39, '65'),
	(243, 1, 0, -50005, 66, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 66, 4, 0, 39, '65'),
	(243, 1, 0, -50005, 67, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 67, 1, 0, 39, '66'),
	(243, 1, 0, -50005, 67, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 67, 2, 0, 39, '66'),
	(243, 1, 0, -50005, 67, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 67, 3, 0, 39, '66'),
	(243, 1, 0, -50005, 67, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 67, 4, 0, 39, '66'),
	(243, 1, 0, -50005, 68, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 68, 1, 0, 39, '67'),
	(243, 1, 0, -50005, 68, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 68, 2, 0, 39, '67'),
	(243, 1, 0, -50005, 68, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 68, 3, 0, 39, '67'),
	(243, 1, 0, -50005, 68, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 68, 4, 0, 39, '67'),
	(243, 1, 0, -50005, 69, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 69, 1, 0, 39, '68'),
	(243, 1, 0, -50005, 69, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 69, 2, 0, 39, '68'),
	(243, 1, 0, -50005, 69, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 69, 3, 0, 39, '68'),
	(243, 1, 0, -50005, 69, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 69, 4, 0, 39, '68'),
	(243, 1, 0, -50005, 70, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 70, 1, 0, 39, '69'),
	(243, 1, 0, -50005, 70, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 70, 2, 0, 39, '69'),
	(243, 1, 0, -50005, 70, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 70, 3, 0, 39, '69'),
	(243, 1, 0, -50005, 70, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 70, 4, 0, 39, '69'),
	(243, 1, 0, -50005, 71, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 71, 1, 0, 39, '70'),
	(243, 1, 0, -50005, 71, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 71, 2, 0, 39, '70'),
	(243, 1, 0, -50005, 71, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 71, 3, 0, 39, '70'),
	(243, 1, 0, -50005, 71, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 71, 4, 0, 39, '70'),
	(243, 1, 0, -50005, 72, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 72, 1, 0, 39, '71'),
	(243, 1, 0, -50005, 72, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 72, 2, 0, 39, '71'),
	(243, 1, 0, -50005, 72, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 72, 3, 0, 39, '71'),
	(243, 1, 0, -50005, 72, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 72, 4, 0, 39, '71'),
	(243, 1, 0, -50005, 73, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 73, 1, 0, 39, '72'),
	(243, 1, 0, -50005, 73, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 73, 2, 0, 39, '72'),
	(243, 1, 0, -50005, 73, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 73, 3, 0, 39, '72'),
	(243, 1, 0, -50005, 73, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 73, 4, 0, 39, '72'),
	(243, 1, 0, -50005, 74, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 74, 1, 0, 39, '73'),
	(243, 1, 0, -50005, 74, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 74, 2, 0, 39, '73'),
	(243, 1, 0, -50005, 74, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 74, 3, 0, 39, '73'),
	(243, 1, 0, -50005, 74, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 74, 4, 0, 39, '73'),
	(243, 1, 0, -50005, 75, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 75, 1, 0, 39, '74'),
	(243, 1, 0, -50005, 75, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 75, 2, 0, 39, '74'),
	(243, 1, 0, -50005, 75, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 75, 3, 0, 39, '74'),
	(243, 1, 0, -50005, 75, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 75, 4, 0, 39, '74'),
	(243, 1, 0, -50005, 76, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 76, 1, 0, 39, '75'),
	(243, 1, 0, -50005, 76, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 76, 2, 0, 39, '75'),
	(243, 1, 0, -50005, 76, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 76, 3, 0, 39, '75'),
	(243, 1, 0, -50005, 76, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 76, 4, 0, 39, '75'),
	(243, 1, 0, -50005, 77, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 77, 1, 0, 39, '76'),
	(243, 1, 0, -50005, 77, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 77, 2, 0, 39, '76'),
	(243, 1, 0, -50005, 77, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 77, 3, 0, 39, '76'),
	(243, 1, 0, -50005, 77, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 77, 4, 0, 39, '76'),
	(243, 1, 0, -50005, 78, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 78, 1, 0, 39, '77'),
	(243, 1, 0, -50005, 78, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 78, 2, 0, 39, '77'),
	(243, 1, 0, -50005, 78, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 78, 3, 0, 39, '77'),
	(243, 1, 0, -50005, 78, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 78, 4, 0, 39, '77'),
	(243, 1, 0, -50005, 79, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 79, 1, 0, 39, '78'),
	(243, 1, 0, -50005, 79, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 79, 2, 0, 39, '78'),
	(243, 1, 0, -50005, 79, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 79, 3, 0, 39, '78'),
	(243, 1, 0, -50005, 79, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 79, 4, 0, 39, '78'),
	(243, 1, 0, -50005, 80, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 80, 1, 0, 39, '79'),
	(243, 1, 0, -50005, 80, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 80, 2, 0, 39, '79'),
	(243, 1, 0, -50005, 80, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 80, 3, 0, 39, '79'),
	(243, 1, 0, -50005, 80, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 80, 4, 0, 39, '79'),
	(243, 1, 0, -50005, 81, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 81, 1, 0, 39, '80'),
	(243, 1, 0, -50005, 81, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 81, 2, 0, 39, '80'),
	(243, 1, 0, -50005, 81, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 81, 3, 0, 39, '80'),
	(243, 1, 0, -50005, 81, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 81, 4, 0, 39, '80'),
	(243, 1, 0, -50005, 82, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 82, 1, 0, 39, '81'),
	(243, 1, 0, -50005, 82, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 82, 2, 0, 39, '81'),
	(243, 1, 0, -50005, 82, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 82, 3, 0, 39, '81'),
	(243, 1, 0, -50005, 82, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 82, 4, 0, 39, '81'),
	(243, 1, 0, -50005, 83, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 83, 1, 0, 39, '82'),
	(243, 1, 0, -50005, 83, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 83, 2, 0, 39, '82'),
	(243, 1, 0, -50005, 83, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 83, 3, 0, 39, '82'),
	(243, 1, 0, -50005, 83, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 83, 4, 0, 39, '82'),
	(243, 1, 0, -50005, 84, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 84, 1, 0, 39, '83'),
	(243, 1, 0, -50005, 84, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 84, 2, 0, 39, '83'),
	(243, 1, 0, -50005, 84, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 84, 3, 0, 39, '83'),
	(243, 1, 0, -50005, 84, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 84, 4, 0, 39, '83'),
	(243, 1, 0, -50005, 85, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 85, 1, 0, 39, '84'),
	(243, 1, 0, -50005, 85, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 85, 2, 0, 39, '84'),
	(243, 1, 0, -50005, 85, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 85, 3, 0, 39, '84'),
	(243, 1, 0, -50005, 85, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 85, 4, 0, 39, '84'),
	(243, 1, 0, -50005, 86, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 86, 1, 0, 39, '85'),
	(243, 1, 0, -50005, 86, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 86, 2, 0, 39, '85'),
	(243, 1, 0, -50005, 86, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 86, 3, 0, 39, '85'),
	(243, 1, 0, -50005, 86, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 86, 4, 0, 39, '85'),
	(243, 1, 0, -50005, 87, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 87, 1, 0, 39, '86'),
	(243, 1, 0, -50005, 87, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 87, 2, 0, 39, '86'),
	(243, 1, 0, -50005, 87, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 87, 3, 0, 39, '86'),
	(243, 1, 0, -50005, 87, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 87, 4, 0, 39, '86'),
	(243, 1, 0, -50005, 88, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 88, 1, 0, 39, '87'),
	(243, 1, 0, -50005, 88, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 88, 2, 0, 39, '87'),
	(243, 1, 0, -50005, 88, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 88, 3, 0, 39, '87'),
	(243, 1, 0, -50005, 88, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 88, 4, 0, 39, '87'),
	(243, 1, 0, -50005, 89, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 89, 1, 0, 39, '88'),
	(243, 1, 0, -50005, 89, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 89, 2, 0, 39, '88'),
	(243, 1, 0, -50005, 89, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 89, 3, 0, 39, '88'),
	(243, 1, 0, -50005, 89, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 89, 4, 0, 39, '88'),
	(243, 1, 0, -50005, 90, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 90, 1, 0, 39, '89'),
	(243, 1, 0, -50005, 90, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 90, 2, 0, 39, '89'),
	(243, 1, 0, -50005, 90, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 90, 3, 0, 39, '89'),
	(243, 1, 0, -50005, 90, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 90, 4, 0, 39, '89'),
	(243, 1, 0, -50005, 91, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 91, 1, 0, 39, '90'),
	(243, 1, 0, -50005, 91, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 91, 2, 0, 39, '90'),
	(243, 1, 0, -50005, 91, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 91, 3, 0, 39, '90'),
	(243, 1, 0, -50005, 91, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 91, 4, 0, 39, '90'),
	(243, 1, 0, -50005, 92, 1, 0, 37, '12'),
	(243, 1, 0, -50005, 92, 1, 0, 39, '91'),
	(243, 1, 0, -50005, 92, 2, 0, 37, '13'),
	(243, 1, 0, -50005, 92, 2, 0, 39, '91'),
	(243, 1, 0, -50005, 92, 3, 0, 37, '14'),
	(243, 1, 0, -50005, 92, 3, 0, 39, '91'),
	(243, 1, 0, -50005, 92, 4, 0, 37, '15'),
	(243, 1, 0, -50005, 92, 4, 0, 39, '91'),
	(243, 1, 0, -10, 1, 0, 0, 39, '0'),
	(243, 1, 0, -10, 2, 0, 0, 39, '1'),
	(243, 1, 0, -10, 3, 0, 0, 39, '2'),
	(243, 1, 0, -10, 4, 0, 0, 39, '3'),
	(243, 1, 0, -10, 5, 0, 0, 39, '4'),
	(243, 1, 0, -10, 6, 0, 0, 39, '5'),
	(243, 1, 0, -10, 7, 0, 0, 39, '6'),
	(243, 1, 0, -10, 8, 0, 0, 39, '7'),
	(243, 1, 0, -10, 9, 0, 0, 39, '8'),
	(243, 1, 0, -10, 10, 0, 0, 39, '9'),
	(243, 1, 0, -10, 11, 0, 0, 39, '10'),
	(243, 1, 0, -10, 12, 0, 0, 39, '11'),
	(243, 1, 0, -10, 13, 0, 0, 39, '12'),
	(243, 1, 0, -10, 14, 0, 0, 39, '13'),
	(243, 1, 0, -10, 15, 0, 0, 39, '14'),
	(243, 1, 0, -10, 16, 0, 0, 39, '15'),
	(243, 1, 0, -10, 17, 0, 0, 39, '16'),
	(243, 1, 0, -10, 18, 0, 0, 39, '17'),
	(243, 1, 0, -10, 19, 0, 0, 39, '18'),
	(243, 1, 0, -10, 20, 0, 0, 39, '19'),
	(243, 1, 0, -10, 21, 0, 0, 39, '20'),
	(243, 1, 0, -10, 22, 0, 0, 39, '21'),
	(243, 1, 0, -10, 23, 0, 0, 39, '22'),
	(243, 1, 0, -10, 24, 0, 0, 39, '23'),
	(243, 1, 0, -10, 25, 0, 0, 39, '24'),
	(243, 1, 0, -10, 26, 0, 0, 39, '25'),
	(243, 1, 0, -10, 27, 0, 0, 39, '26'),
	(243, 1, 0, -10, 28, 0, 0, 39, '27'),
	(243, 1, 0, -10, 29, 0, 0, 39, '28'),
	(243, 1, 0, -10, 30, 0, 0, 39, '29'),
	(243, 1, 0, -10, 31, 0, 0, 39, '30'),
	(243, 1, 0, -10, 32, 0, 0, 39, '31'),
	(243, 1, 0, -10, 33, 0, 0, 39, '32'),
	(243, 1, 0, -10, 34, 0, 0, 39, '33'),
	(243, 1, 0, -10, 35, 0, 0, 39, '34'),
	(243, 1, 0, -10, 36, 0, 0, 39, '35'),
	(243, 1, 0, -10, 37, 0, 0, 39, '36'),
	(243, 1, 0, -10, 38, 0, 0, 39, '37'),
	(243, 1, 0, -10, 39, 0, 0, 39, '38'),
	(243, 1, 0, -10, 40, 0, 0, 39, '39'),
	(243, 1, 0, -10, 41, 0, 0, 39, '40'),
	(243, 1, 0, -10, 42, 0, 0, 39, '41'),
	(243, 1, 0, -10, 43, 0, 0, 39, '42'),
	(243, 1, 0, -10, 44, 0, 0, 39, '43'),
	(243, 1, 0, -10, 45, 0, 0, 39, '44'),
	(243, 1, 0, -10, 46, 0, 0, 39, '45'),
	(243, 1, 0, -10, 47, 0, 0, 39, '46'),
	(243, 1, 0, -10, 48, 0, 0, 39, '47'),
	(243, 1, 0, -10, 49, 0, 0, 39, '48'),
	(243, 1, 0, -10, 50, 0, 0, 39, '49'),
	(243, 1, 0, -10, 51, 0, 0, 39, '50'),
	(243, 1, 0, -10, 52, 0, 0, 39, '51'),
	(243, 1, 0, -10, 53, 0, 0, 39, '52'),
	(243, 1, 0, -10, 54, 0, 0, 39, '53'),
	(243, 1, 0, -10, 55, 0, 0, 39, '54'),
	(243, 1, 0, -10, 56, 0, 0, 39, '55'),
	(243, 1, 0, -10, 57, 0, 0, 39, '56'),
	(243, 1, 0, -10, 58, 0, 0, 39, '57'),
	(243, 1, 0, -10, 59, 0, 0, 39, '58'),
	(243, 1, 0, -10, 60, 0, 0, 39, '59'),
	(243, 1, 0, -10, 61, 0, 0, 39, '60'),
	(243, 1, 0, -10, 62, 0, 0, 39, '61'),
	(243, 1, 0, -10, 63, 0, 0, 39, '62'),
	(243, 1, 0, -10, 64, 0, 0, 39, '63'),
	(243, 1, 0, -10, 65, 0, 0, 39, '64'),
	(243, 1, 0, -10, 66, 0, 0, 39, '65'),
	(243, 1, 0, -10, 67, 0, 0, 39, '66'),
	(243, 1, 0, -10, 68, 0, 0, 39, '67'),
	(243, 1, 0, -10, 69, 0, 0, 39, '68'),
	(243, 1, 0, -10, 70, 0, 0, 39, '69'),
	(243, 1, 0, -10, 71, 0, 0, 39, '70'),
	(243, 1, 0, -10, 72, 0, 0, 39, '71'),
	(243, 1, 0, -10, 73, 0, 0, 39, '72'),
	(243, 1, 0, -10, 74, 0, 0, 39, '73'),
	(243, 1, 0, -10, 75, 0, 0, 39, '74'),
	(243, 1, 0, -10, 76, 0, 0, 39, '75'),
	(243, 1, 0, -10, 77, 0, 0, 39, '76'),
	(243, 1, 0, -10, 78, 0, 0, 39, '77'),
	(243, 1, 0, -10, 79, 0, 0, 39, '78'),
	(243, 1, 0, -10, 80, 0, 0, 39, '79'),
	(243, 1, 0, -10, 81, 0, 0, 39, '80'),
	(243, 1, 0, -10, 82, 0, 0, 39, '81'),
	(243, 1, 0, -10, 83, 0, 0, 39, '82'),
	(243, 1, 0, -10, 84, 0, 0, 39, '83'),
	(243, 1, 0, -10, 85, 0, 0, 39, '84'),
	(243, 1, 0, -10, 86, 0, 0, 39, '85'),
	(243, 1, 0, -10, 87, 0, 0, 39, '86'),
	(243, 1, 0, -10, 88, 0, 0, 39, '87'),
	(243, 1, 0, -10, 89, 0, 0, 39, '88'),
	(243, 1, 0, -10, 90, 0, 0, 39, '89'),
	(243, 1, 0, -10, 91, 0, 0, 39, '90'),
	(243, 1, 0, -10, 92, 0, 0, 39, '91'),
	(243, 1, 0, -10, 93, 0, 0, 39, '92'),
	(243, 1, 0, -10, 94, 0, 0, 39, '93'),
	(243, 1, 0, -10, 95, 0, 0, 39, '94'),
	(243, 1, 0, -10, 96, 0, 0, 39, '95'),
	(243, 1, 0, -10, 97, 0, 0, 39, '96'),
	(243, 1, 0, -10, 98, 0, 0, 39, '97'),
	(243, 1, 0, -10, 99, 0, 0, 39, '98'),
	(243, 1, 0, -10, 100, 0, 0, 39, '99'),
	(243, 1, 0, -10, 101, 0, 0, 39, '100'),
	(243, 1, 0, -10, 102, 0, 0, 39, '101'),
	(243, 1, 0, -10, 103, 0, 0, 39, '102'),
	(243, 1, 0, -10, 104, 0, 0, 39, '103'),
	(243, 1, 0, -10, 105, 0, 0, 39, '104'),
	(243, 1, 0, -10, 106, 0, 0, 39, '105'),
	(243, 1, 0, -10, 107, 0, 0, 39, '106'),
	(243, 1, 0, -10, 108, 0, 0, 39, '107'),
	(243, 1, 0, -10, 109, 0, 0, 39, '108'),
	(243, 1, 0, -10, 110, 0, 0, 39, '109'),
	(243, 1, 0, -10, 111, 0, 0, 39, '110'),
	(243, 1, 0, -10, 112, 0, 0, 39, '111'),
	(243, 1, 0, -10, 113, 0, 0, 39, '112'),
	(243, 1, 0, -10, 114, 0, 0, 39, '113'),
	(243, 1, 0, -10, 115, 0, 0, 39, '114'),
	(243, 1, 0, -10, 116, 0, 0, 39, '115'),
	(243, 1, 0, -10, 117, 0, 0, 39, '116'),
	(243, 1, 0, -10, 118, 0, 0, 39, '117'),
	(243, 1, 0, -10, 119, 0, 0, 39, '118'),
	(243, 1, 0, -10, 120, 0, 0, 39, '119'),
	(243, 1, 0, -10, 121, 0, 0, 39, '120'),
	(243, 1, 0, -10, 122, 0, 0, 39, '121'),
	(243, 1, 0, -10, 123, 0, 0, 39, '122'),
	(243, 1, 0, -10, 124, 0, 0, 39, '123'),
	(243, 1, 0, -10, 125, 0, 0, 39, '124'),
	(243, 1, 0, -10, 126, 0, 0, 39, '125'),
	(243, 1, 0, -10, 127, 0, 0, 39, '126'),
	(243, 1, 0, -10, 128, 0, 0, 39, '127'),
	(243, 1, 0, -10, 129, 0, 0, 39, '128'),
	(243, 1, 0, -10, 130, 0, 0, 39, '129'),
	(243, 1, 0, -10, 131, 0, 0, 39, '130'),
	(243, 1, 0, -10, 132, 0, 0, 39, '131'),
	(243, 1, 0, -10, 133, 0, 0, 39, '132'),
	(243, 1, 0, -10, 134, 0, 0, 39, '133'),
	(243, 1, 0, -10, 135, 0, 0, 39, '134'),
	(243, 1, 0, -10, 136, 0, 0, 39, '135'),
	(243, 1, 0, -10, 137, 0, 0, 39, '136'),
	(243, 1, 0, -10, 138, 0, 0, 39, '137'),
	(243, 1, 0, -10, 139, 0, 0, 39, '138'),
	(243, 1, 0, -10, 140, 0, 0, 39, '139'),
	(243, 1, 0, -10, 141, 0, 0, 39, '140'),
	(243, 1, 0, -10, 142, 0, 0, 39, '141'),
	(243, 1, 0, -10, 143, 0, 0, 39, '142'),
	(243, 1, 0, -10, 144, 0, 0, 39, '143'),
	(243, 1, 0, -10, 145, 0, 0, 39, '144'),
	(243, 1, 0, -10, 146, 0, 0, 39, '145'),
	(243, 1, 0, -10, 147, 0, 0, 39, '146'),
	(243, 1, 0, -10, 148, 0, 0, 39, '147'),
	(243, 1, 0, -10, 149, 0, 0, 39, '148'),
	(243, 1, 0, -10, 150, 0, 0, 39, '149'),
	(243, 1, 0, -10, 151, 0, 0, 39, '150'),
	(243, 1, 0, -10, 152, 0, 0, 39, '151'),
	(243, 1, 0, -10, 153, 0, 0, 39, '152'),
	(243, 1, 0, -10, 154, 0, 0, 39, '153'),
	(243, 1, 0, -10, 155, 0, 0, 39, '154'),
	(243, 1, 0, -10, 156, 0, 0, 39, '155'),
	(243, 1, 0, -10, 157, 0, 0, 39, '156'),
	(243, 1, 0, -10, 158, 0, 0, 39, '157'),
	(243, 1, 0, -10, 159, 0, 0, 39, '158'),
	(243, 1, 0, -10, 160, 0, 0, 39, '159'),
	(243, 1, 0, -10, 161, 0, 0, 39, '160'),
	(243, 1, 0, -10, 162, 0, 0, 39, '161'),
	(243, 1, 0, -10, 163, 0, 0, 39, '162'),
	(243, 1, 0, -10, 164, 0, 0, 39, '163'),
	(243, 1, 0, -10, 165, 0, 0, 39, '164'),
	(243, 1, 0, -10, 166, 0, 0, 39, '165'),
	(243, 1, 0, -10, 167, 0, 0, 39, '166'),
	(243, 1, 0, -10, 168, 0, 0, 39, '167'),
	(243, 1, 0, -10, 169, 0, 0, 39, '168'),
	(243, 1, 0, -10, 170, 0, 0, 39, '169'),
	(243, 1, 0, -10, 171, 0, 0, 39, '170'),
	(243, 1, 0, -10, 172, 0, 0, 39, '171'),
	(243, 1, 0, -10, 173, 0, 0, 39, '172'),
	(243, 1, 0, -10, 174, 0, 0, 39, '173'),
	(243, 1, 0, -10, 175, 0, 0, 39, '174'),
	(243, 1, 0, -10, 176, 0, 0, 39, '175'),
	(243, 1, 0, -10, 177, 0, 0, 39, '176'),
	(243, 1, 0, -10, 178, 0, 0, 39, '177'),
	(243, 1, 0, -10, 179, 0, 0, 39, '178'),
	(243, 1, 0, -10, 180, 0, 0, 39, '179'),
	(243, 1, 0, -10, 181, 0, 0, 39, '180'),
	(243, 1, 0, -10, 182, 0, 0, 39, '181'),
	(243, 1, 0, -10, 183, 0, 0, 39, '182'),
	(243, 1, 0, -10, 184, 0, 0, 39, '183'),
	(243, 1, 0, -10, 185, 0, 0, 39, '184'),
	(243, 1, 0, -10, 186, 0, 0, 39, '185'),
	(243, 1, 0, -10, 187, 0, 0, 39, '186'),
	(243, 1, 0, -10, 188, 0, 0, 39, '187'),
	(243, 1, 0, -10, 189, 0, 0, 39, '188'),
	(243, 1, 0, -10, 190, 0, 0, 39, '189'),
	(243, 1, 0, -10, 191, 0, 0, 39, '190'),
	(243, 1, 0, -10, 192, 0, 0, 39, '191'),
	(243, 1, 0, -10, 193, 0, 0, 39, '192'),
	(243, 1, 0, -10, 194, 0, 0, 39, '193'),
	(243, 1, 0, -10, 195, 0, 0, 39, '194'),
	(243, 1, 0, -10, 196, 0, 0, 39, '195'),
	(243, 1, 0, -10, 197, 0, 0, 39, '196'),
	(243, 1, 0, -10, 198, 0, 0, 39, '197'),
	(243, 1, 0, -10, 199, 0, 0, 39, '198'),
	(243, 1, 0, -10, 200, 0, 0, 39, '199'),
	(243, 1, 0, -10, 201, 0, 0, 39, '200'),
	(243, 1, 0, -10, 202, 0, 0, 39, '201'),
	(243, 1, 0, -10, 203, 0, 0, 39, '202'),
	(243, 1, 0, -10, 204, 0, 0, 39, '203'),
	(243, 1, 0, -10, 205, 0, 0, 39, '204'),
	(243, 1, 0, -10, 206, 0, 0, 39, '205'),
	(243, 1, 0, -10, 207, 0, 0, 39, '206'),
	(243, 1, 0, -10, 208, 0, 0, 39, '207'),
	(243, 1, 0, -10, 209, 0, 0, 39, '208'),
	(243, 1, 0, -10, 210, 0, 0, 39, '209'),
	(243, 1, 0, -10, 211, 0, 0, 39, '210'),
	(243, 1, 0, -10, 212, 0, 0, 39, '211'),
	(243, 1, 0, -10, 213, 0, 0, 39, '212'),
	(243, 1, 0, -10, 214, 0, 0, 39, '213'),
	(243, 1, 0, -10, 215, 0, 0, 39, '214'),
	(243, 1, 0, -10, 216, 0, 0, 39, '215'),
	(243, 1, 0, -10, 217, 0, 0, 39, '216'),
	(243, 1, 0, -10, 218, 0, 0, 39, '217'),
	(243, 1, 0, -10, 219, 0, 0, 39, '218'),
	(243, 1, 0, -10, 220, 0, 0, 39, '219'),
	(243, 1, 0, -10, 221, 0, 0, 39, '220'),
	(243, 1, 0, -10, 222, 0, 0, 39, '221'),
	(243, 1, 0, -10, 223, 0, 0, 39, '222'),
	(243, 1, 0, -10, 224, 0, 0, 39, '223'),
	(243, 1, 0, -10, 225, 0, 0, 39, '224'),
	(243, 1, 0, -10, 226, 0, 0, 39, '225'),
	(243, 1, 0, -10, 227, 0, 0, 39, '226'),
	(243, 1, 0, -10, 228, 0, 0, 39, '227'),
	(243, 1, 0, -10, 229, 0, 0, 39, '228'),
	(243, 1, 0, -10, 230, 0, 0, 39, '229'),
	(243, 1, 0, -10, 231, 0, 0, 39, '230'),
	(243, 1, 0, -10, 232, 0, 0, 39, '231'),
	(243, 1, 0, -10, 233, 0, 0, 39, '232'),
	(243, 1, 0, -10, 234, 0, 0, 39, '233'),
	(243, 1, 0, -10, 235, 0, 0, 39, '234'),
	(243, 1, 0, -10, 236, 0, 0, 39, '235'),
	(243, 1, 0, -10, 237, 0, 0, 39, '236'),
	(243, 1, 0, -10, 238, 0, 0, 39, '237'),
	(243, 1, 0, -10, 239, 0, 0, 39, '238'),
	(243, 1, 0, -10, 240, 0, 0, 39, '239'),
	(243, 1, 0, -10, 241, 0, 0, 39, '240'),
	(243, 1, 0, -10, 242, 0, 0, 39, '241'),
	(243, 1, 0, -10, 243, 0, 0, 39, '242'),
	(243, 1, 0, -10, 244, 0, 0, 39, '243'),
	(243, 1, 0, -10, 245, 0, 0, 39, '244'),
	(243, 1, 0, -10, 246, 0, 0, 39, '245'),
	(243, 1, 0, -10, 247, 0, 0, 39, '246'),
	(243, 1, 0, -10, 248, 0, 0, 39, '247'),
	(243, 1, 0, -10, 249, 0, 0, 39, '248'),
	(243, 1, 0, -10, 250, 0, 0, 39, '249'),
	(243, 1, 0, -10, 251, 0, 0, 39, '250'),
	(243, 1, 0, -10, 252, 0, 0, 39, '251'),
	(243, 1, 0, -10, 253, 0, 0, 39, '252'),
	(243, 1, 0, -10, 254, 0, 0, 39, '253'),
	(243, 1, 0, -10, 255, 0, 0, 39, '254'),
	(243, 1, 0, -10, 256, 0, 0, 39, '255'),
	(243, 1, 0, -10, 257, 0, 0, 39, '256'),
	(243, 1, 0, -10, 258, 0, 0, 39, '257'),
	(243, 1, 0, -10, 259, 0, 0, 39, '258'),
	(243, 1, 0, -10, 260, 0, 0, 39, '259'),
	(243, 1, 0, -10, 261, 0, 0, 39, '260'),
	(243, 1, 0, -10, 262, 0, 0, 39, '261'),
	(243, 1, 0, -10, 263, 0, 0, 39, '262'),
	(243, 1, 0, -10, 264, 0, 0, 39, '263'),
	(243, 1, 0, -10, 265, 0, 0, 39, '264'),
	(243, 1, 0, -10, 266, 0, 0, 39, '265'),
	(243, 1, 0, -10, 267, 0, 0, 39, '266'),
	(243, 1, 0, -10, 268, 0, 0, 39, '267'),
	(243, 1, 0, -10, 269, 0, 0, 39, '268'),
	(243, 1, 0, -10, 270, 0, 0, 39, '269'),
	(243, 1, 0, -10, 271, 0, 0, 39, '270'),
	(243, 1, 0, -10, 272, 0, 0, 39, '271'),
	(243, 1, 0, -10, 273, 0, 0, 39, '272'),
	(243, 1, 0, -10, 274, 0, 0, 39, '273'),
	(243, 1, 0, -10, 275, 0, 0, 39, '274'),
	(243, 1, 0, -10, 276, 0, 0, 39, '275'),
	(243, 1, 0, -10, 277, 0, 0, 39, '276'),
	(243, 1, 0, -10, 278, 0, 0, 39, '277'),
	(243, 1, 0, -10, 279, 0, 0, 39, '278'),
	(243, 1, 0, -10, 280, 0, 0, 39, '279'),
	(243, 1, 0, -10, 281, 0, 0, 39, '280'),
	(243, 1, 0, -10, 282, 0, 0, 39, '281'),
	(243, 1, 0, -10, 283, 0, 0, 39, '282'),
	(243, 1, 0, -10, 284, 0, 0, 39, '283'),
	(243, 1, 0, -10, 285, 0, 0, 39, '284'),
	(243, 1, 0, -10, 286, 0, 0, 39, '285'),
	(243, 1, 0, -10, 287, 0, 0, 39, '286'),
	(243, 1, 0, -10, 288, 0, 0, 39, '287'),
	(243, 1, 0, -10, 289, 0, 0, 39, '288'),
	(243, 1, 0, -10, 290, 0, 0, 39, '289'),
	(243, 1, 0, -10, 291, 0, 0, 39, '290'),
	(243, 1, 0, -10, 292, 0, 0, 39, '291'),
	(243, 1, 0, -10, 293, 0, 0, 39, '292'),
	(243, 1, 0, -10, 294, 0, 0, 39, '293'),
	(243, 1, 0, -10, 295, 0, 0, 39, '294'),
	(243, 1, 0, -10, 296, 0, 0, 39, '295'),
	(243, 1, 0, -10, 297, 0, 0, 39, '296'),
	(243, 1, 0, -10, 298, 0, 0, 39, '297'),
	(243, 1, 0, -10, 299, 0, 0, 39, '298'),
	(243, 1, 0, -10, 300, 0, 0, 39, '299'),
	(243, 1, 0, -10, 301, 0, 0, 39, '300'),
	(243, 1, 0, -10, 302, 0, 0, 39, '301'),
	(243, 1, 0, -10, 303, 0, 0, 39, '302'),
	(243, 1, 0, -10, 304, 0, 0, 39, '303'),
	(243, 1, 0, -10, 305, 0, 0, 39, '304'),
	(243, 1, 0, -10, 306, 0, 0, 39, '305'),
	(243, 1, 0, -10, 307, 0, 0, 39, '306'),
	(243, 1, 0, -10, 308, 0, 0, 39, '307'),
	(243, 1, 0, -10, 309, 0, 0, 39, '308'),
	(243, 1, 0, -10, 310, 0, 0, 39, '309'),
	(243, 1, 0, -10, 311, 0, 0, 39, '310'),
	(243, 1, 0, -10, 312, 0, 0, 39, '311'),
	(243, 1, 0, -10, 313, 0, 0, 39, '312'),
	(243, 1, 0, -10, 314, 0, 0, 39, '313'),
	(243, 1, 0, -10, 315, 0, 0, 39, '314'),
	(243, 1, 0, -10, 316, 0, 0, 39, '315'),
	(243, 1, 0, -10, 317, 0, 0, 39, '316'),
	(243, 1, 0, -10, 318, 0, 0, 39, '317'),
	(243, 1, 0, -10, 319, 0, 0, 39, '318'),
	(243, 1, 0, -10, 320, 0, 0, 39, '319'),
	(243, 1, 0, -10, 321, 0, 0, 39, '320'),
	(243, 1, 0, -10, 322, 0, 0, 39, '321'),
	(243, 1, 0, -10, 323, 0, 0, 39, '322'),
	(243, 1, 0, -10, 324, 0, 0, 39, '323'),
	(243, 1, 0, -10, 325, 0, 0, 39, '324'),
	(243, 1, 0, -10, 326, 0, 0, 39, '325'),
	(243, 1, 0, -10, 327, 0, 0, 39, '326'),
	(243, 1, 0, -10, 328, 0, 0, 39, '327'),
	(243, 1, 0, -10, 329, 0, 0, 39, '328'),
	(243, 1, 0, -10, 330, 0, 0, 39, '329'),
	(243, 1, 0, -10, 331, 0, 0, 39, '330'),
	(243, 1, 0, -10, 332, 0, 0, 39, '331'),
	(243, 1, 0, -10, 333, 0, 0, 39, '332'),
	(243, 1, 0, -10, 334, 0, 0, 39, '333'),
	(243, 1, 0, -10, 335, 0, 0, 39, '334'),
	(243, 1, 0, -10, 336, 0, 0, 39, '335'),
	(243, 1, 0, -10, 337, 0, 0, 39, '336'),
	(243, 1, 0, -10, 338, 0, 0, 39, '337'),
	(243, 1, 0, -10, 339, 0, 0, 39, '338'),
	(243, 1, 0, -10, 340, 0, 0, 39, '339'),
	(243, 1, 0, -10, 341, 0, 0, 39, '340'),
	(243, 1, 0, -10, 342, 0, 0, 39, '341'),
	(243, 1, 0, -10, 343, 0, 0, 39, '342'),
	(243, 1, 0, -10, 344, 0, 0, 39, '343'),
	(243, 1, 0, -10, 345, 0, 0, 39, '344'),
	(243, 1, 0, -10, 346, 0, 0, 39, '345'),
	(243, 1, 0, -10, 347, 0, 0, 39, '346'),
	(243, 1, 0, -10, 348, 0, 0, 39, '347'),
	(243, 1, 0, -10, 349, 0, 0, 39, '348'),
	(243, 1, 0, -10, 350, 0, 0, 39, '349'),
	(243, 1, 0, -10, 351, 0, 0, 39, '350'),
	(243, 1, 0, -10, 352, 0, 0, 39, '351'),
	(243, 1, 0, -10, 353, 0, 0, 39, '352'),
	(243, 1, 0, -10, 354, 0, 0, 39, '353'),
	(243, 1, 0, -10, 355, 0, 0, 39, '354'),
	(243, 1, 0, -10, 356, 0, 0, 39, '355'),
	(243, 1, 0, -10, 357, 0, 0, 39, '356'),
	(243, 1, 0, -10, 358, 0, 0, 39, '357'),
	(243, 1, 0, -10, 359, 0, 0, 39, '358'),
	(243, 1, 0, -10, 360, 0, 0, 39, '359'),
	(243, 1, 0, -10, 361, 0, 0, 39, '360'),
	(243, 1, 0, -10, 362, 0, 0, 39, '361'),
	(243, 1, 0, -10, 363, 0, 0, 39, '362'),
	(243, 1, 0, -10, 364, 0, 0, 39, '363'),
	(243, 1, 0, -10, 365, 0, 0, 39, '364'),
	(243, 1, 0, -10, 366, 0, 0, 39, '365'),
	(243, 1, 0, -10, 367, 0, 0, 39, '366'),
	(243, 1, 0, -10, 368, 0, 0, 39, '367'),
	(243, 1, 0, -10, 369, 0, 0, 39, '368'),
	(243, 1, 0, -10, 370, 0, 0, 39, '369'),
	(243, 1, 0, -10, 371, 0, 0, 39, '370'),
	(243, 1, 0, -10, 372, 0, 0, 39, '371'),
	(243, 1, 0, -10, 373, 0, 0, 39, '372'),
	(243, 1, 0, -10, 374, 0, 0, 39, '373'),
	(243, 1, 0, -10, 375, 0, 0, 39, '374'),
	(243, 1, 0, -10, 376, 0, 0, 39, '375'),
	(243, 1, 0, -10, 377, 0, 0, 39, '376'),
	(243, 1, 0, -10, 378, 0, 0, 39, '377'),
	(243, 1, 0, -10, 379, 0, 0, 39, '378'),
	(243, 1, 0, -10, 380, 0, 0, 39, '379'),
	(243, 1, 0, -10, 381, 0, 0, 39, '380'),
	(243, 1, 0, -10, 382, 0, 0, 39, '381'),
	(243, 1, 0, -10, 383, 0, 0, 39, '382'),
	(243, 1, 0, -10, 384, 0, 0, 39, '383'),
	(243, 1, 0, -10, 385, 0, 0, 39, '384'),
	(243, 1, 0, -10, 386, 0, 0, 39, '385'),
	(243, 1, 0, -10, 387, 0, 0, 39, '386'),
	(243, 1, 0, -10, 388, 0, 0, 39, '387'),
	(243, 1, 0, -10, 389, 0, 0, 39, '388'),
	(243, 1, 0, -10, 390, 0, 0, 39, '389'),
	(243, 1, 0, -10, 391, 0, 0, 39, '390'),
	(243, 1, 0, -10, 392, 0, 0, 39, '391'),
	(243, 1, 0, -10, 393, 0, 0, 39, '392'),
	(243, 1, 0, -10, 394, 0, 0, 39, '393'),
	(243, 1, 0, -10, 395, 0, 0, 39, '394'),
	(243, 1, 0, -10, 396, 0, 0, 39, '395'),
	(243, 1, 0, -10, 397, 0, 0, 39, '396'),
	(243, 1, 0, -10, 398, 0, 0, 39, '397'),
	(243, 1, 0, -10, 399, 0, 0, 39, '398'),
	(243, 1, 0, -10, 400, 0, 0, 39, '399'),
	(243, 1, 0, -10, 401, 0, 0, 39, '400'),
	(243, 1, 0, -10, 402, 0, 0, 39, '401'),
	(243, 1, 0, -10, 403, 0, 0, 39, '402'),
	(243, 1, 0, -10, 404, 0, 0, 39, '403'),
	(243, 1, 0, -10, 405, 0, 0, 39, '404'),
	(243, 1, 0, -10, 406, 0, 0, 39, '405'),
	(243, 1, 0, -10, 407, 0, 0, 39, '406'),
	(243, 1, 0, -10, 408, 0, 0, 39, '407'),
	(243, 1, 0, -10, 409, 0, 0, 39, '408'),
	(243, 1, 0, -10, 410, 0, 0, 39, '409'),
	(243, 1, 0, -10, 411, 0, 0, 39, '410'),
	(243, 1, 0, -10, 412, 0, 0, 39, '411'),
	(243, 1, 0, -10, 413, 0, 0, 39, '412'),
	(243, 1, 0, -10, 414, 0, 0, 39, '413'),
	(243, 1, 0, -10, 415, 0, 0, 39, '414'),
	(243, 1, 0, -10, 416, 0, 0, 39, '415'),
	(243, 1, 0, -10, 417, 0, 0, 39, '416'),
	(243, 1, 0, -10, 418, 0, 0, 39, '417'),
	(243, 1, 0, -10, 419, 0, 0, 39, '418'),
	(243, 1, 0, -10, 420, 0, 0, 39, '419'),
	(243, 1, 0, -10, 421, 0, 0, 39, '420'),
	(243, 1, 0, -10, 422, 0, 0, 39, '421'),
	(243, 1, 0, -10, 423, 0, 0, 39, '422'),
	(243, 1, 0, -10, 424, 0, 0, 39, '423'),
	(243, 1, 0, -10, 425, 0, 0, 39, '424'),
	(243, 1, 0, -10, 426, 0, 0, 39, '425'),
	(243, 1, 0, -10, 427, 0, 0, 39, '426'),
	(243, 1, 0, -10, 428, 0, 0, 39, '427'),
	(243, 1, 0, -10, 429, 0, 0, 39, '428'),
	(243, 1, 0, -10, 430, 0, 0, 39, '429'),
	(243, 1, 0, -10, 431, 0, 0, 39, '430'),
	(243, 1, 0, -10, 432, 0, 0, 39, '431'),
	(243, 1, 0, -10, 433, 0, 0, 39, '432'),
	(243, 1, 0, -10, 434, 0, 0, 39, '433'),
	(243, 1, 0, -10, 435, 0, 0, 39, '434'),
	(243, 1, 0, -10, 436, 0, 0, 39, '435'),
	(243, 1, 0, -10, 437, 0, 0, 39, '436'),
	(243, 1, 0, -10, 438, 0, 0, 39, '437'),
	(243, 1, 0, -10, 439, 0, 0, 39, '438'),
	(243, 1, 0, -10, 440, 0, 0, 39, '439'),
	(243, 1, 0, -10, 441, 0, 0, 39, '440'),
	(243, 1, 0, -10, 442, 0, 0, 39, '441'),
	(243, 1, 0, -10, 443, 0, 0, 39, '442'),
	(243, 1, 0, -10, 444, 0, 0, 39, '443'),
	(243, 1, 0, -10, 445, 0, 0, 39, '444'),
	(243, 1, 0, -10, 446, 0, 0, 39, '445'),
	(243, 1, 0, -10, 447, 0, 0, 39, '446'),
	(243, 1, 0, -10, 448, 0, 0, 39, '447'),
	(243, 1, 0, -10, 449, 0, 0, 39, '448'),
	(243, 1, 0, -10, 450, 0, 0, 39, '449'),
	(243, 1, 0, -10, 451, 0, 0, 39, '450'),
	(243, 1, 0, -10, 452, 0, 0, 39, '451'),
	(243, 1, 0, -10, 453, 0, 0, 39, '452'),
	(243, 1, 0, -10, 454, 0, 0, 39, '453'),
	(243, 1, 0, -10, 455, 0, 0, 39, '454'),
	(243, 1, 0, -10, 456, 0, 0, 39, '455'),
	(243, 1, 0, -10, 457, 0, 0, 39, '456'),
	(243, 1, 0, -10, 458, 0, 0, 39, '457'),
	(243, 1, 0, -10, 459, 0, 0, 39, '458'),
	(243, 1, 0, -10, 460, 0, 0, 39, '459'),
	(243, 1, 0, -10, 461, 0, 0, 39, '460'),
	(243, 1, 0, -10, 462, 0, 0, 39, '461'),
	(243, 1, 0, -10, 463, 0, 0, 39, '462'),
	(243, 1, 0, -10, 464, 0, 0, 39, '463'),
	(243, 1, 0, -10, 465, 0, 0, 39, '464'),
	(243, 1, 0, -10, 466, 0, 0, 39, '465'),
	(243, 1, 0, -10, 467, 0, 0, 39, '466'),
	(243, 1, 0, -10, 468, 0, 0, 39, '467'),
	(243, 1, 0, -10, 469, 0, 0, 39, '468'),
	(243, 1, 0, -10, 470, 0, 0, 39, '469'),
	(243, 1, 0, -10, 471, 0, 0, 39, '470'),
	(243, 1, 0, -10, 472, 0, 0, 39, '471'),
	(243, 1, 0, -10, 473, 0, 0, 39, '472'),
	(243, 1, 0, -10, 474, 0, 0, 39, '473'),
	(243, 1, 0, -10, 475, 0, 0, 39, '474'),
	(243, 1, 0, -10, 476, 0, 0, 39, '475'),
	(243, 1, 0, -10, 477, 0, 0, 39, '476'),
	(243, 1, 0, -10, 478, 0, 0, 39, '477'),
	(243, 1, 0, -10, 479, 0, 0, 39, '478'),
	(243, 1, 0, -10, 480, 0, 0, 39, '479'),
	(243, 1, 0, -10, 481, 0, 0, 39, '480'),
	(243, 1, 0, -10, 482, 0, 0, 39, '481'),
	(243, 1, 0, -10, 483, 0, 0, 39, '482'),
	(243, 1, 0, -10, 484, 0, 0, 39, '483'),
	(243, 1, 0, -10, 485, 0, 0, 39, '484'),
	(243, 1, 0, -10, 486, 0, 0, 39, '485'),
	(243, 1, 0, -10, 487, 0, 0, 39, '486'),
	(243, 1, 0, -10, 488, 0, 0, 39, '487'),
	(243, 1, 0, -10, 489, 0, 0, 39, '488'),
	(243, 1, 0, -10, 490, 0, 0, 39, '489'),
	(243, 1, 0, -10, 491, 0, 0, 39, '490'),
	(243, 1, 0, -10, 492, 0, 0, 39, '491'),
	(243, 1, 0, -10, 493, 0, 0, 39, '492'),
	(243, 1, 0, -10, 494, 0, 0, 39, '493'),
	(243, 1, 0, -10, 495, 0, 0, 39, '494'),
	(243, 1, 0, -10, 496, 0, 0, 39, '495'),
	(243, 1, 0, -10, 497, 0, 0, 39, '496'),
	(243, 1, 0, -10, 498, 0, 0, 39, '497'),
	(243, 1, 0, -10, 499, 0, 0, 39, '498'),
	(243, 1, 0, -10, 500, 0, 0, 39, '499'),
	(243, 1, 0, -10, 501, 0, 0, 39, '500'),
	(243, 1, 0, -10, 502, 0, 0, 39, '501'),
	(243, 1, 0, -10, 503, 0, 0, 39, '502'),
	(243, 1, 0, -10, 504, 0, 0, 39, '503'),
	(243, 1, 0, -10, 505, 0, 0, 39, '504'),
	(243, 1, 0, -10, 506, 0, 0, 39, '505'),
	(243, 1, 0, -10, 507, 0, 0, 39, '506'),
	(243, 1, 0, -10, 508, 0, 0, 39, '507'),
	(243, 1, 0, -10, 509, 0, 0, 39, '508'),
	(243, 1, 0, -10, 510, 0, 0, 39, '509'),
	(243, 1, 0, -10, 511, 0, 0, 39, '510'),
	(243, 1, 0, -10, 512, 0, 0, 39, '511'),
	(243, 1, 0, -10, 513, 0, 0, 39, '512'),
	(243, 1, 0, -10, 514, 0, 0, 39, '513'),
	(243, 1, 0, -10, 515, 0, 0, 39, '514'),
	(243, 1, 0, -10, 516, 0, 0, 39, '515'),
	(243, 1, 0, -10, 517, 0, 0, 39, '516'),
	(243, 1, 0, -10, 518, 0, 0, 39, '517'),
	(243, 1, 0, -10, 519, 0, 0, 39, '518'),
	(243, 1, 0, -10, 520, 0, 0, 39, '519'),
	(243, 1, 0, -10, 521, 0, 0, 39, '520'),
	(243, 1, 0, -10, 522, 0, 0, 39, '521'),
	(243, 1, 0, -10, 523, 0, 0, 39, '522'),
	(243, 1, 0, -10, 524, 0, 0, 39, '523'),
	(243, 1, 0, -10, 525, 0, 0, 39, '524'),
	(243, 1, 0, -10, 526, 0, 0, 39, '525'),
	(243, 1, 0, -10, 527, 0, 0, 39, '526'),
	(243, 1, 0, -10, 528, 0, 0, 39, '527'),
	(243, 1, 0, -10, 529, 0, 0, 39, '528'),
	(243, 1, 0, -10, 530, 0, 0, 39, '529'),
	(243, 1, 0, -10, 531, 0, 0, 39, '530'),
	(243, 1, 0, -10, 532, 0, 0, 39, '531'),
	(243, 1, 0, -10, 533, 0, 0, 39, '532'),
	(243, 1, 0, -10, 534, 0, 0, 39, '533'),
	(243, 1, 0, -10, 535, 0, 0, 39, '534'),
	(243, 1, 0, -10, 536, 0, 0, 39, '535'),
	(243, 1, 0, -10, 537, 0, 0, 39, '536'),
	(243, 1, 0, -10, 538, 0, 0, 39, '537'),
	(243, 1, 0, -10, 539, 0, 0, 39, '538'),
	(243, 1, 0, -10, 540, 0, 0, 39, '539'),
	(243, 1, 0, -10, 541, 0, 0, 39, '540'),
	(243, 1, 0, -10, 542, 0, 0, 39, '541'),
	(243, 1, 0, -10, 543, 0, 0, 39, '542'),
	(243, 1, 0, -10, 544, 0, 0, 39, '543'),
	(243, 1, 0, -10, 545, 0, 0, 39, '544'),
	(243, 1, 0, -10, 546, 0, 0, 39, '545'),
	(243, 1, 0, -10, 547, 0, 0, 39, '546'),
	(243, 1, 0, -10, 548, 0, 0, 39, '547'),
	(243, 1, 0, -10, 549, 0, 0, 39, '548'),
	(243, 1, 0, -10, 550, 0, 0, 39, '549'),
	(243, 1, 0, -10, 551, 0, 0, 39, '550'),
	(243, 1, 0, -10, 552, 0, 0, 39, '551'),
	(243, 1, 0, -10, 553, 0, 0, 39, '552'),
	(243, 1, 0, -10, 554, 0, 0, 39, '553'),
	(243, 1, 0, -10, 555, 0, 0, 39, '554'),
	(243, 1, 0, -10, 556, 0, 0, 39, '555'),
	(243, 1, 0, -10, 557, 0, 0, 39, '556'),
	(243, 1, 0, -10, 558, 0, 0, 39, '557'),
	(243, 1, 0, -10, 559, 0, 0, 39, '558'),
	(243, 1, 0, -10, 560, 0, 0, 39, '559'),
	(243, 1, 0, -10, 561, 0, 0, 39, '560'),
	(243, 1, 0, -10, 562, 0, 0, 39, '561'),
	(243, 1, 0, -10, 563, 0, 0, 39, '562'),
	(243, 1, 0, -10, 564, 0, 0, 39, '563'),
	(243, 1, 0, -10, 565, 0, 0, 39, '564'),
	(243, 1, 0, -10, 566, 0, 0, 39, '565'),
	(243, 1, 0, -10, 567, 0, 0, 39, '566'),
	(243, 1, 0, -10, 568, 0, 0, 39, '567'),
	(243, 1, 0, -10, 569, 0, 0, 39, '568'),
	(243, 1, 0, -10, 570, 0, 0, 39, '569'),
	(243, 1, 0, -10, 571, 0, 0, 39, '570'),
	(243, 1, 0, -10, 572, 0, 0, 39, '571'),
	(243, 1, 0, -10, 573, 0, 0, 39, '572'),
	(243, 1, 0, -10, 574, 0, 0, 39, '573'),
	(243, 1, 0, -10, 575, 0, 0, 39, '574'),
	(243, 1, 0, -10, 576, 0, 0, 39, '575'),
	(243, 1, 0, -10, 577, 0, 0, 39, '576'),
	(243, 1, 0, -10, 578, 0, 0, 39, '577'),
	(243, 1, 0, -10, 579, 0, 0, 39, '578'),
	(243, 1, 0, -10, 580, 0, 0, 39, '579'),
	(243, 1, 0, -10, 581, 0, 0, 39, '580'),
	(243, 1, 0, -10, 582, 0, 0, 39, '581'),
	(243, 1, 0, -10, 583, 0, 0, 39, '582'),
	(243, 1, 0, -10, 584, 0, 0, 39, '583'),
	(243, 1, 0, -10, 585, 0, 0, 39, '584'),
	(243, 1, 0, -10, 586, 0, 0, 39, '585'),
	(243, 1, 0, -10, 587, 0, 0, 39, '586'),
	(243, 1, 0, -10, 588, 0, 0, 39, '587'),
	(243, 1, 0, -10, 589, 0, 0, 39, '588'),
	(243, 1, 0, -10, 590, 0, 0, 39, '589'),
	(243, 1, 0, -10, 591, 0, 0, 39, '590'),
	(243, 1, 0, -10, 592, 0, 0, 39, '591'),
	(243, 1, 0, -10, 593, 0, 0, 39, '592'),
	(243, 1, 0, -10, 594, 0, 0, 39, '593'),
	(243, 1, 0, -10, 595, 0, 0, 39, '594'),
	(243, 1, 0, -10, 596, 0, 0, 39, '595'),
	(243, 1, 0, -10, 597, 0, 0, 39, '596'),
	(243, 1, 0, -10, 598, 0, 0, 39, '597'),
	(243, 1, 0, -10, 599, 0, 0, 39, '598'),
	(243, 1, 0, -10, 600, 0, 0, 39, '599'),
	(243, 1, 0, -10, 601, 0, 0, 39, '600'),
	(243, 1, 0, -10, 602, 0, 0, 39, '601'),
	(243, 1, 0, -10, 603, 0, 0, 39, '602'),
	(243, 1, 0, -10, 604, 0, 0, 39, '603'),
	(243, 1, 0, -10, 605, 0, 0, 39, '604'),
	(243, 1, 0, -10, 606, 0, 0, 39, '605'),
	(243, 1, 0, -10, 607, 0, 0, 39, '606'),
	(243, 1, 0, -10, 608, 0, 0, 39, '607'),
	(243, 1, 0, -10, 609, 0, 0, 39, '608'),
	(243, 1, 0, -10, 610, 0, 0, 39, '609'),
	(243, 1, 0, -10, 611, 0, 0, 39, '610'),
	(243, 1, 0, -10, 612, 0, 0, 39, '611'),
	(243, 1, 0, -10, 613, 0, 0, 39, '612'),
	(243, 1, 0, -10, 614, 0, 0, 39, '613'),
	(243, 1, 0, -10, 615, 0, 0, 39, '614'),
	(243, 1, 0, -10, 616, 0, 0, 39, '615'),
	(243, 1, 0, -10, 617, 0, 0, 39, '616'),
	(243, 1, 0, -10, 618, 0, 0, 39, '617'),
	(243, 1, 0, -10, 619, 0, 0, 39, '618'),
	(243, 1, 0, -10, 620, 0, 0, 39, '619'),
	(243, 1, 0, -10, 621, 0, 0, 39, '620'),
	(243, 1, 0, -10, 622, 0, 0, 39, '621'),
	(243, 1, 0, -10, 623, 0, 0, 39, '622'),
	(243, 1, 0, -10, 624, 0, 0, 39, '623'),
	(243, 1, 0, -10, 625, 0, 0, 39, '624'),
	(243, 1, 0, -10, 626, 0, 0, 39, '625'),
	(243, 1, 0, -10, 627, 0, 0, 39, '626'),
	(243, 1, 0, -10, 628, 0, 0, 39, '627'),
	(243, 1, 0, -10, 629, 0, 0, 39, '628'),
	(243, 1, 0, -10, 630, 0, 0, 39, '629'),
	(243, 1, 0, -10, 631, 0, 0, 39, '630'),
	(243, 1, 0, -10, 632, 0, 0, 39, '631'),
	(243, 1, 0, -10, 633, 0, 0, 39, '632'),
	(243, 1, 0, -10, 634, 0, 0, 39, '633'),
	(243, 1, 0, -10, 635, 0, 0, 39, '634'),
	(243, 1, 0, -10, 636, 0, 0, 39, '635'),
	(243, 1, 0, -10, 637, 0, 0, 39, '636'),
	(243, 1, 0, -10, 638, 0, 0, 39, '637'),
	(243, 1, 0, -10, 639, 0, 0, 39, '638'),
	(243, 1, 0, -10, 640, 0, 0, 39, '639'),
	(243, 1, 0, -10, 641, 0, 0, 39, '640'),
	(243, 1, 0, -10, 642, 0, 0, 39, '641'),
	(243, 1, 0, -10, 643, 0, 0, 39, '642'),
	(243, 1, 0, -10, 644, 0, 0, 39, '643'),
	(243, 1, 0, -10, 645, 0, 0, 39, '644'),
	(243, 1, 0, -10, 646, 0, 0, 39, '645'),
	(243, 1, 0, -10, 647, 0, 0, 39, '646'),
	(243, 1, 0, -10, 648, 0, 0, 39, '647'),
	(243, 1, 0, -10, 649, 0, 0, 39, '648'),
	(243, 1, 0, -10, 650, 0, 0, 39, '649'),
	(243, 1, 0, -10, 651, 0, 0, 39, '650'),
	(243, 1, 0, -10, 652, 0, 0, 39, '651'),
	(243, 1, 0, -10, 653, 0, 0, 39, '652'),
	(243, 1, 0, -10, 654, 0, 0, 39, '653'),
	(243, 1, 0, -10, 655, 0, 0, 39, '654'),
	(243, 1, 0, -10, 656, 0, 0, 39, '655'),
	(243, 1, 0, -10, 657, 0, 0, 39, '656'),
	(243, 1, 0, -10, 658, 0, 0, 39, '657'),
	(243, 1, 0, -10, 659, 0, 0, 39, '658'),
	(243, 1, 0, -10, 660, 0, 0, 39, '659'),
	(243, 1, 0, -10, 661, 0, 0, 39, '660'),
	(243, 1, 0, -10, 662, 0, 0, 39, '661'),
	(243, 1, 0, -10, 663, 0, 0, 39, '662'),
	(243, 1, 0, -10, 664, 0, 0, 39, '663'),
	(243, 1, 0, -10, 665, 0, 0, 39, '664'),
	(243, 1, 0, -10, 666, 0, 0, 39, '665'),
	(243, 1, 0, -10, 667, 0, 0, 39, '666'),
	(243, 1, 0, -10, 668, 0, 0, 39, '667'),
	(243, 1, 0, -10, 669, 0, 0, 39, '668'),
	(243, 1, 0, -10, 670, 0, 0, 39, '669'),
	(243, 1, 0, -10, 671, 0, 0, 39, '670'),
	(243, 1, 0, -10, 672, 0, 0, 39, '671'),
	(243, 1, 0, -10, 673, 0, 0, 39, '672'),
	(243, 1, 0, -10, 674, 0, 0, 39, '673'),
	(243, 1, 0, -10, 675, 0, 0, 39, '674'),
	(243, 1, 0, -10, 676, 0, 0, 39, '675'),
	(243, 1, 0, -10, 677, 0, 0, 39, '676'),
	(243, 1, 0, -10, 678, 0, 0, 39, '677'),
	(243, 1, 0, -10, 679, 0, 0, 39, '678'),
	(243, 1, 0, -10, 680, 0, 0, 39, '679'),
	(243, 1, 0, -10, 681, 0, 0, 39, '680'),
	(243, 1, 0, -10, 682, 0, 0, 39, '681'),
	(243, 1, 0, -10, 683, 0, 0, 39, '682'),
	(243, 1, 0, -10, 684, 0, 0, 39, '683'),
	(243, 1, 0, -10, 685, 0, 0, 39, '684'),
	(243, 1, 0, -10, 686, 0, 0, 39, '685'),
	(243, 1, 0, -10, 687, 0, 0, 39, '686'),
	(243, 1, 0, -10, 688, 0, 0, 39, '687'),
	(243, 1, 0, -10, 689, 0, 0, 39, '688'),
	(243, 1, 0, -10, 690, 0, 0, 39, '689'),
	(243, 1, 0, -10, 691, 0, 0, 39, '690'),
	(243, 1, 0, -10, 692, 0, 0, 39, '691'),
	(243, 1, 0, -10, 693, 0, 0, 39, '692'),
	(243, 1, 0, -10, 694, 0, 0, 39, '693'),
	(243, 1, 0, -10, 695, 0, 0, 39, '694'),
	(243, 1, 0, -10, 696, 0, 0, 39, '695'),
	(243, 1, 0, -10, 697, 0, 0, 39, '696'),
	(243, 1, 0, -10, 698, 0, 0, 39, '697'),
	(243, 1, 0, -10, 699, 0, 0, 39, '698'),
	(243, 1, 0, -10, 700, 0, 0, 39, '699'),
	(243, 1, 0, -10, 701, 0, 0, 39, '700'),
	(243, 1, 0, -10, 702, 0, 0, 39, '701'),
	(243, 1, 0, -10, 703, 0, 0, 39, '702'),
	(243, 1, 0, -10, 704, 0, 0, 39, '703'),
	(243, 1, 0, -10, 705, 0, 0, 39, '704'),
	(243, 1, 0, -10, 706, 0, 0, 39, '705'),
	(243, 1, 0, -10, 707, 0, 0, 39, '706'),
	(243, 1, 0, -10, 708, 0, 0, 39, '707'),
	(243, 1, 0, -10, 709, 0, 0, 39, '708'),
	(243, 1, 0, -10, 710, 0, 0, 39, '709'),
	(243, 1, 0, -10, 711, 0, 0, 39, '710'),
	(243, 1, 0, -10, 712, 0, 0, 39, '711'),
	(243, 1, 0, -10, 713, 0, 0, 39, '712'),
	(243, 1, 0, -10, 714, 0, 0, 39, '713'),
	(243, 1, 0, -10, 715, 0, 0, 39, '714'),
	(243, 1, 0, -10, 716, 0, 0, 39, '715'),
	(243, 1, 0, -10, 717, 0, 0, 39, '716'),
	(243, 1, 0, -10, 718, 0, 0, 39, '717'),
	(243, 1, 0, -10, 719, 0, 0, 39, '718'),
	(243, 1, 0, -10, 720, 0, 0, 39, '719'),
	(243, 1, 0, -10, 721, 0, 0, 39, '720'),
	(243, 1, 0, -10, 722, 0, 0, 39, '721'),
	(243, 1, 0, -10, 723, 0, 0, 39, '722'),
	(243, 1, 0, -10, 724, 0, 0, 39, '723'),
	(243, 1, 0, -10, 725, 0, 0, 39, '724'),
	(243, 1, 0, -10, 726, 0, 0, 39, '725'),
	(243, 1, 0, -10, 727, 0, 0, 39, '726'),
	(243, 1, 0, -10, 728, 0, 0, 39, '727'),
	(243, 1, 0, -10, 729, 0, 0, 39, '728'),
	(243, 1, 0, -10, 730, 0, 0, 39, '729'),
	(243, 1, 0, -10, 731, 0, 0, 39, '730'),
	(243, 1, 0, -10, 732, 0, 0, 39, '731'),
	(243, 1, 0, -10, 733, 0, 0, 39, '732'),
	(243, 1, 0, -10, 734, 0, 0, 39, '733'),
	(243, 1, 0, -10, 735, 0, 0, 39, '734'),
	(243, 1, 0, -10, 736, 0, 0, 39, '735'),
	(243, 1, 0, -10, 737, 0, 0, 39, '736'),
	(243, 1, 0, -10, 738, 0, 0, 39, '737'),
	(243, 1, 0, -10, 739, 0, 0, 39, '738'),
	(243, 1, 0, -10, 740, 0, 0, 39, '739'),
	(243, 1, 0, -10, 741, 0, 0, 39, '740'),
	(243, 1, 0, -10, 742, 0, 0, 39, '741'),
	(243, 1, 0, -10, 743, 0, 0, 39, '742'),
	(243, 1, 0, -10, 744, 0, 0, 39, '743'),
	(243, 1, 0, -10, 745, 0, 0, 39, '744'),
	(243, 1, 0, -10, 746, 0, 0, 39, '745'),
	(243, 1, 0, -10, 747, 0, 0, 39, '746'),
	(243, 1, 0, -10, 748, 0, 0, 39, '747'),
	(243, 1, 0, -10, 749, 0, 0, 39, '748'),
	(243, 1, 0, -10, 750, 0, 0, 39, '749'),
	(243, 1, 0, -10, 751, 0, 0, 39, '750'),
	(243, 1, 0, -10, 752, 0, 0, 39, '751'),
	(243, 1, 0, -10, 753, 0, 0, 39, '752'),
	(243, 1, 0, -10, 754, 0, 0, 39, '753'),
	(243, 1, 0, -10, 755, 0, 0, 39, '754'),
	(243, 1, 0, -10, 756, 0, 0, 39, '755'),
	(243, 1, 0, -10, 757, 0, 0, 39, '756'),
	(243, 1, 0, -10, 758, 0, 0, 39, '757'),
	(243, 1, 0, -10, 759, 0, 0, 39, '758'),
	(243, 1, 0, -10, 760, 0, 0, 39, '759'),
	(243, 1, 0, -10, 761, 0, 0, 39, '760'),
	(243, 1, 0, -10, 762, 0, 0, 39, '761'),
	(243, 1, 0, -10, 763, 0, 0, 39, '762'),
	(243, 1, 0, -10, 764, 0, 0, 39, '763'),
	(243, 1, 0, -10, 765, 0, 0, 39, '764'),
	(243, 1, 0, -10, 766, 0, 0, 39, '765'),
	(243, 1, 0, -10, 767, 0, 0, 39, '766'),
	(243, 1, 0, -10, 768, 0, 0, 39, '767'),
	(243, 1, 0, -10, 769, 0, 0, 39, '768'),
	(243, 1, 0, -10, 770, 0, 0, 39, '769'),
	(243, 1, 0, -10, 771, 0, 0, 39, '770'),
	(243, 1, 0, -10, 772, 0, 0, 39, '771'),
	(243, 1, 0, -10, 773, 0, 0, 39, '772'),
	(243, 1, 0, -10, 774, 0, 0, 39, '773'),
	(243, 1, 0, -10, 775, 0, 0, 39, '774'),
	(243, 1, 0, -10, 776, 0, 0, 39, '775'),
	(243, 1, 0, -10, 777, 0, 0, 39, '776'),
	(243, 1, 0, -10, 778, 0, 0, 39, '777'),
	(243, 1, 0, -10, 779, 0, 0, 39, '778'),
	(243, 1, 0, -10, 780, 0, 0, 39, '779'),
	(243, 1, 0, -10, 781, 0, 0, 39, '780'),
	(243, 1, 0, -10, 782, 0, 0, 39, '781'),
	(243, 1, 0, -10, 783, 0, 0, 39, '782'),
	(243, 1, 0, -10, 784, 0, 0, 39, '783'),
	(243, 1, 0, -10, 785, 0, 0, 39, '784'),
	(243, 1, 0, -10, 786, 0, 0, 39, '785'),
	(243, 1, 0, -10, 787, 0, 0, 39, '786'),
	(243, 1, 0, -10, 788, 0, 0, 39, '787'),
	(243, 1, 0, -10, 789, 0, 0, 39, '788'),
	(243, 1, 0, -10, 790, 0, 0, 39, '789'),
	(243, 1, 0, -10, 791, 0, 0, 39, '790'),
	(243, 1, 0, -10, 792, 0, 0, 39, '791'),
	(243, 1, 0, -10, 793, 0, 0, 39, '792'),
	(243, 1, 0, -10, 794, 0, 0, 39, '793'),
	(243, 1, 0, -10, 795, 0, 0, 39, '794'),
	(243, 1, 0, -10, 796, 0, 0, 39, '795'),
	(243, 1, 0, -10, 797, 0, 0, 39, '796'),
	(243, 1, 0, -10, 798, 0, 0, 39, '797'),
	(243, 1, 0, -10, 799, 0, 0, 39, '798'),
	(243, 1, 0, -10, 800, 0, 0, 39, '799'),
	(243, 1, 0, -10, 801, 0, 0, 39, '800'),
	(243, 1, 0, -10, 802, 0, 0, 39, '801'),
	(243, 1, 0, -10, 803, 0, 0, 39, '802'),
	(243, 1, 0, -10, 804, 0, 0, 39, '803'),
	(243, 1, 0, -10, 805, 0, 0, 39, '804'),
	(243, 1, 0, -10, 806, 0, 0, 39, '805'),
	(243, 1, 0, -10, 807, 0, 0, 39, '806'),
	(243, 1, 0, -10, 808, 0, 0, 39, '807'),
	(243, 1, 0, -10, 809, 0, 0, 39, '808'),
	(243, 1, 0, -10, 810, 0, 0, 39, '809'),
	(243, 1, 0, -10, 811, 0, 0, 39, '810'),
	(243, 1, 0, -10, 812, 0, 0, 39, '811'),
	(243, 1, 0, -10, 813, 0, 0, 39, '812'),
	(243, 1, 0, -10, 814, 0, 0, 39, '813'),
	(243, 1, 0, -10, 815, 0, 0, 39, '814'),
	(243, 1, 0, -10, 816, 0, 0, 39, '815'),
	(243, 1, 0, -10, 817, 0, 0, 39, '816'),
	(243, 1, 0, -10, 818, 0, 0, 39, '817'),
	(243, 1, 0, -10, 819, 0, 0, 39, '818'),
	(243, 1, 0, -10, 820, 0, 0, 39, '819'),
	(243, 1, 0, -10, 821, 0, 0, 39, '820'),
	(243, 1, 0, -10, 822, 0, 0, 39, '821'),
	(243, 1, 0, -10, 823, 0, 0, 39, '822'),
	(243, 1, 0, -10, 824, 0, 0, 39, '823'),
	(243, 1, 0, -10, 825, 0, 0, 39, '824'),
	(243, 1, 0, -10, 826, 0, 0, 39, '825'),
	(243, 1, 0, -10, 827, 0, 0, 39, '826'),
	(243, 1, 0, -10, 828, 0, 0, 39, '827'),
	(243, 1, 0, -10, 829, 0, 0, 39, '828'),
	(243, 1, 0, -10, 830, 0, 0, 39, '829'),
	(243, 1, 0, -10, 831, 0, 0, 39, '830'),
	(243, 1, 0, -10, 832, 0, 0, 39, '831'),
	(243, 1, 0, -10, 833, 0, 0, 39, '832'),
	(243, 1, 0, -10, 834, 0, 0, 39, '833'),
	(243, 1, 0, -10, 835, 0, 0, 39, '834'),
	(243, 1, 0, -10, 836, 0, 0, 39, '835'),
	(243, 1, 0, -10, 837, 0, 0, 39, '836'),
	(243, 1, 0, -10, 838, 0, 0, 39, '837'),
	(243, 1, 0, -10, 839, 0, 0, 39, '838'),
	(243, 1, 0, -10, 840, 0, 0, 39, '839'),
	(243, 1, 0, -10, 841, 0, 0, 39, '840'),
	(243, 1, 0, -10, 842, 0, 0, 39, '841'),
	(243, 1, 0, -10, 843, 0, 0, 39, '842'),
	(243, 1, 0, -10, 844, 0, 0, 39, '843'),
	(243, 1, 0, -10, 845, 0, 0, 39, '844'),
	(243, 1, 0, -10, 846, 0, 0, 39, '845'),
	(243, 1, 0, -10, 847, 0, 0, 39, '846'),
	(243, 1, 0, -10, 848, 0, 0, 39, '847'),
	(243, 1, 0, -10, 849, 0, 0, 39, '848'),
	(243, 1, 0, -10, 850, 0, 0, 39, '849'),
	(243, 1, 0, -10, 851, 0, 0, 39, '850'),
	(243, 1, 0, -10, 852, 0, 0, 39, '851'),
	(243, 1, 0, -10, 853, 0, 0, 39, '852'),
	(243, 1, 0, -10, 854, 0, 0, 39, '853'),
	(243, 1, 0, -10, 855, 0, 0, 39, '854'),
	(243, 1, 0, -10, 856, 0, 0, 39, '855'),
	(243, 1, 0, -10, 857, 0, 0, 39, '856'),
	(243, 1, 0, -10, 858, 0, 0, 39, '857'),
	(243, 1, 0, -10, 859, 0, 0, 39, '858'),
	(243, 1, 0, -10, 860, 0, 0, 39, '859'),
	(243, 1, 0, -10, 861, 0, 0, 39, '860'),
	(243, 1, 0, -10, 862, 0, 0, 39, '861'),
	(243, 1, 0, -10, 863, 0, 0, 39, '862'),
	(243, 1, 0, -10, 864, 0, 0, 39, '863'),
	(243, 1, 0, -10, 865, 0, 0, 39, '864'),
	(243, 1, 0, -10, 866, 0, 0, 39, '865'),
	(243, 1, 0, -10, 867, 0, 0, 39, '866'),
	(243, 1, 0, -10, 868, 0, 0, 39, '867'),
	(243, 1, 0, -10, 869, 0, 0, 39, '868'),
	(243, 1, 0, -10, 870, 0, 0, 39, '869'),
	(243, 1, 0, -10, 871, 0, 0, 39, '870'),
	(243, 1, 0, -10, 872, 0, 0, 39, '871'),
	(243, 1, 0, -10, 873, 0, 0, 39, '872'),
	(243, 1, 0, -10, 874, 0, 0, 39, '873'),
	(243, 1, 0, -10, 875, 0, 0, 39, '874'),
	(243, 1, 0, -10, 876, 0, 0, 39, '875'),
	(243, 1, 0, -10, 877, 0, 0, 39, '876'),
	(243, 1, 0, -10, 878, 0, 0, 39, '877'),
	(243, 1, 0, -10, 879, 0, 0, 39, '878'),
	(243, 1, 0, -10, 880, 0, 0, 39, '879'),
	(243, 1, 0, -10, 881, 0, 0, 39, '880'),
	(243, 1, 0, -10, 882, 0, 0, 39, '881'),
	(243, 1, 0, -10, 883, 0, 0, 39, '882'),
	(243, 1, 0, -10, 884, 0, 0, 39, '883'),
	(243, 1, 0, -10, 885, 0, 0, 39, '884'),
	(243, 1, 0, -10, 886, 0, 0, 39, '885'),
	(243, 1, 0, -10, 887, 0, 0, 39, '886'),
	(243, 1, 0, -10, 888, 0, 0, 39, '887'),
	(243, 1, 0, -10, 889, 0, 0, 39, '888'),
	(243, 1, 0, -10, 890, 0, 0, 39, '889'),
	(243, 1, 0, -10, 891, 0, 0, 39, '890'),
	(243, 1, 0, -10, 892, 0, 0, 39, '891'),
	(243, 1, 0, -10, 893, 0, 0, 39, '892'),
	(243, 1, 0, -10, 894, 0, 0, 39, '893'),
	(243, 1, 0, -10, 895, 0, 0, 39, '894'),
	(243, 1, 0, -10, 896, 0, 0, 39, '895'),
	(243, 1, 0, -10, 897, 0, 0, 39, '896'),
	(243, 1, 0, -10, 898, 0, 0, 39, '897'),
	(243, 1, 0, -10, 899, 0, 0, 39, '898'),
	(243, 1, 0, -10, 900, 0, 0, 39, '899'),
	(243, 1, 0, -10, 901, 0, 0, 39, '900'),
	(243, 1, 0, -10, 902, 0, 0, 39, '901'),
	(243, 1, 0, -10, 903, 0, 0, 39, '902'),
	(243, 1, 0, -10, 904, 0, 0, 39, '903'),
	(243, 1, 0, -10, 905, 0, 0, 39, '904'),
	(243, 1, 0, -10, 906, 0, 0, 39, '905'),
	(243, 1, 0, -10, 907, 0, 0, 39, '906'),
	(243, 1, 0, -10, 908, 0, 0, 39, '907'),
	(243, 1, 0, -10, 909, 0, 0, 39, '908'),
	(243, 1, 0, -10, 910, 0, 0, 39, '909'),
	(243, 1, 0, -10, 911, 0, 0, 39, '910'),
	(243, 1, 0, -10, 912, 0, 0, 39, '911'),
	(243, 1, 0, -10, 913, 0, 0, 39, '912'),
	(243, 1, 0, -10, 914, 0, 0, 39, '913'),
	(243, 1, 0, -10, 915, 0, 0, 39, '914'),
	(243, 1, 0, -10, 916, 0, 0, 39, '915'),
	(243, 1, 0, -10, 917, 0, 0, 39, '916'),
	(243, 1, 0, -10, 918, 0, 0, 39, '917'),
	(243, 1, 0, -10, 919, 0, 0, 39, '918'),
	(243, 1, 0, -10, 920, 0, 0, 39, '919'),
	(243, 1, 0, -10, 921, 0, 0, 39, '920'),
	(243, 1, 0, -10, 922, 0, 0, 39, '921'),
	(243, 1, 0, -10, 923, 0, 0, 39, '922'),
	(243, 1, 0, -10, 924, 0, 0, 39, '923'),
	(243, 1, 0, -10, 925, 0, 0, 39, '924'),
	(243, 1, 0, -10, 926, 0, 0, 39, '925'),
	(243, 1, 0, -10, 927, 0, 0, 39, '926'),
	(243, 1, 0, -10, 928, 0, 0, 39, '927'),
	(243, 1, 0, -10, 929, 0, 0, 39, '928'),
	(243, 1, 0, -10, 930, 0, 0, 39, '929'),
	(243, 1, 0, -10, 931, 0, 0, 39, '930'),
	(243, 1, 0, -10, 932, 0, 0, 39, '931'),
	(243, 1, 0, -10, 933, 0, 0, 39, '932'),
	(243, 1, 0, -10, 934, 0, 0, 39, '933'),
	(243, 1, 0, -10, 935, 0, 0, 39, '934'),
	(243, 1, 0, -10, 936, 0, 0, 39, '935'),
	(243, 1, 0, -10, 937, 0, 0, 39, '936'),
	(243, 1, 0, -10, 938, 0, 0, 39, '937'),
	(243, 1, 0, -10, 939, 0, 0, 39, '938'),
	(243, 1, 0, -10, 940, 0, 0, 39, '939'),
	(243, 1, 0, -10, 941, 0, 0, 39, '940'),
	(243, 1, 0, -10, 942, 0, 0, 39, '941'),
	(243, 1, 0, -10, 943, 0, 0, 39, '942'),
	(243, 1, 0, -10, 944, 0, 0, 39, '943'),
	(243, 1, 0, -10, 945, 0, 0, 39, '944'),
	(243, 1, 0, -10, 946, 0, 0, 39, '945'),
	(243, 1, 0, -10, 947, 0, 0, 39, '946'),
	(243, 1, 0, -10, 948, 0, 0, 39, '947'),
	(243, 1, 0, -10, 949, 0, 0, 39, '948'),
	(243, 1, 0, -10, 950, 0, 0, 39, '949'),
	(243, 1, 0, -10, 951, 0, 0, 39, '950'),
	(243, 1, 0, -10, 952, 0, 0, 39, '951'),
	(243, 1, 0, -10, 953, 0, 0, 39, '952'),
	(243, 1, 0, -10, 954, 0, 0, 39, '953'),
	(243, 1, 0, -10, 955, 0, 0, 39, '954'),
	(243, 1, 0, -10, 956, 0, 0, 39, '955'),
	(243, 1, 0, -10, 957, 0, 0, 39, '956'),
	(243, 1, 0, -10, 958, 0, 0, 39, '957'),
	(243, 1, 0, -10, 959, 0, 0, 39, '958'),
	(243, 1, 0, -10, 960, 0, 0, 39, '959'),
	(243, 1, 0, -10, 961, 0, 0, 39, '960'),
	(243, 1, 0, -10, 962, 0, 0, 39, '961'),
	(243, 1, 0, -10, 963, 0, 0, 39, '962'),
	(243, 1, 0, -10, 964, 0, 0, 39, '963'),
	(243, 1, 0, -10, 965, 0, 0, 39, '964'),
	(243, 1, 0, -10, 966, 0, 0, 39, '965'),
	(243, 1, 0, -10, 967, 0, 0, 39, '966'),
	(243, 1, 0, -10, 968, 0, 0, 39, '967'),
	(243, 1, 0, -10, 969, 0, 0, 39, '968'),
	(243, 1, 0, -10, 970, 0, 0, 39, '969'),
	(243, 1, 0, -10, 971, 0, 0, 39, '970'),
	(243, 1, 0, -10, 972, 0, 0, 39, '971'),
	(243, 1, 0, -10, 973, 0, 0, 39, '972'),
	(243, 1, 0, -10, 974, 0, 0, 39, '973'),
	(243, 1, 0, -10, 975, 0, 0, 39, '974'),
	(243, 1, 0, -10, 976, 0, 0, 39, '975'),
	(243, 1, 0, -10, 977, 0, 0, 39, '976'),
	(243, 1, 0, -10, 978, 0, 0, 39, '977'),
	(243, 1, 0, -10, 979, 0, 0, 39, '978'),
	(243, 1, 0, -10, 980, 0, 0, 39, '979'),
	(243, 1, 0, -10, 981, 0, 0, 39, '980'),
	(243, 1, 0, -10, 982, 0, 0, 39, '981'),
	(243, 1, 0, -10, 983, 0, 0, 39, '982'),
	(243, 1, 0, -10, 984, 0, 0, 39, '983'),
	(243, 1, 0, -10, 985, 0, 0, 39, '984'),
	(243, 1, 0, -10, 986, 0, 0, 39, '985'),
	(243, 1, 0, -10, 987, 0, 0, 39, '986'),
	(243, 1, 0, -10, 988, 0, 0, 39, '987'),
	(243, 1, 0, -10, 989, 0, 0, 39, '988'),
	(243, 1, 0, -10, 990, 0, 0, 39, '989'),
	(243, 1, 0, -10, 991, 0, 0, 39, '990'),
	(243, 1, 0, -10, 992, 0, 0, 39, '991'),
	(243, 1, 0, -10, 993, 0, 0, 39, '992'),
	(243, 1, 0, -10, 994, 0, 0, 39, '993'),
	(243, 1, 0, -10, 995, 0, 0, 39, '994'),
	(243, 1, 0, -10, 996, 0, 0, 39, '995'),
	(243, 1, 0, -10, 997, 0, 0, 39, '996'),
	(243, 1, 0, -10, 998, 0, 0, 39, '997'),
	(243, 1, 0, -10, 999, 0, 0, 39, '998'),
	(243, 1, 0, -10, 1000, 0, 0, 39, '999'),
	(243, 1, 0, -10, 1001, 0, 0, 39, '1000'),
	(243, 1, 0, -10, 1002, 0, 0, 39, '1001'),
	(243, 1, 0, -10, 1003, 0, 0, 39, '1002'),
	(243, 1, 0, -10, 1004, 0, 0, 39, '1003'),
	(243, 1, 0, -10, 1005, 0, 0, 39, '1004'),
	(243, 1, 0, -10, 1006, 0, 0, 39, '1005'),
	(243, 1, 0, -10, 1007, 0, 0, 39, '1006'),
	(243, 1, 0, -10, 1008, 0, 0, 39, '1007'),
	(243, 1, 0, -10, 1009, 0, 0, 39, '1008'),
	(243, 1, 0, -10, 1010, 0, 0, 39, '1009'),
	(243, 1, 0, -10, 1011, 0, 0, 39, '1010'),
	(243, 1, 0, -10, 1012, 0, 0, 39, '1011'),
	(243, 1, 0, -10, 1013, 0, 0, 39, '1012'),
	(243, 1, 0, -10, 1014, 0, 0, 39, '1013'),
	(243, 1, 0, -10, 1015, 0, 0, 39, '1014'),
	(243, 1, 0, -10, 1016, 0, 0, 39, '1015'),
	(243, 1, 0, -10, 1017, 0, 0, 39, '1016'),
	(243, 1, 0, -10, 1018, 0, 0, 39, '1017'),
	(243, 1, 0, -10, 1019, 0, 0, 39, '1018'),
	(243, 1, 0, -10, 1020, 0, 0, 39, '1019'),
	(243, 1, 0, -10, 1021, 0, 0, 39, '1020'),
	(243, 1, 0, -10, 1022, 0, 0, 39, '1021'),
	(243, 1, 0, -10, 1023, 0, 0, 39, '1022'),
	(243, 1, 0, -10, 1024, 0, 0, 39, '1023'),
	(243, 1, 0, -10, 1025, 0, 0, 39, '1024'),
	(243, 1, 0, -10, 1026, 0, 0, 39, '1025'),
	(243, 1, 0, -10, 1027, 0, 0, 39, '1026'),
	(243, 1, 0, -10, 1028, 0, 0, 39, '1027'),
	(243, 1, 0, -10, 1029, 0, 0, 39, '1028'),
	(243, 1, 0, -10, 1030, 0, 0, 39, '1029'),
	(243, 1, 0, -10, 1031, 0, 0, 39, '1030'),
	(243, 1, 0, -10, 1032, 0, 0, 39, '1031'),
	(243, 1, 0, -10, 1033, 0, 0, 39, '1032'),
	(243, 1, 0, -10, 1034, 0, 0, 39, '1033'),
	(243, 1, 0, -10, 1035, 0, 0, 39, '1034'),
	(243, 1, 0, -10, 1036, 0, 0, 39, '1035'),
	(243, 1, 0, -10, 1037, 0, 0, 39, '1036'),
	(243, 1, 0, -10, 1038, 0, 0, 39, '1037'),
	(243, 1, 0, -10, 1039, 0, 0, 39, '1038'),
	(243, 1, 0, -10, 1040, 0, 0, 39, '1039'),
	(243, 1, 0, -10, 1041, 0, 0, 39, '1040'),
	(243, 1, 0, -10, 1042, 0, 0, 39, '1041'),
	(243, 1, 0, -10, 1043, 0, 0, 39, '1042'),
	(243, 1, 0, -10, 1044, 0, 0, 39, '1043'),
	(243, 1, 0, -10, 1045, 0, 0, 39, '1044'),
	(243, 1, 0, -10, 1046, 0, 0, 39, '1045'),
	(243, 1, 0, -10, 1047, 0, 0, 39, '1046'),
	(243, 1, 0, -10, 1048, 0, 0, 39, '1047'),
	(243, 1, 0, -10, 1049, 0, 0, 39, '1048'),
	(243, 1, 0, -10, 1050, 0, 0, 39, '1049'),
	(243, 1, 0, -10, 1051, 0, 0, 39, '1050'),
	(243, 1, 0, -10, 1052, 0, 0, 39, '1051'),
	(243, 1, 0, -10, 1053, 0, 0, 39, '1052'),
	(243, 1, 0, -10, 1054, 0, 0, 39, '1053'),
	(243, 1, 0, -10, 1055, 0, 0, 39, '1054'),
	(243, 1, 0, -10, 1056, 0, 0, 39, '1055'),
	(243, 1, 0, -10, 1057, 0, 0, 39, '1056'),
	(243, 1, 0, -10, 1058, 0, 0, 39, '1057'),
	(243, 1, 0, -10, 1059, 0, 0, 39, '1058'),
	(243, 1, 0, -10, 1060, 0, 0, 39, '1059'),
	(243, 1, 0, -10, 1061, 0, 0, 39, '1060'),
	(243, 1, 0, -10, 1062, 0, 0, 39, '1061'),
	(243, 1, 0, -10, 1063, 0, 0, 39, '1062'),
	(243, 1, 0, -10, 1064, 0, 0, 39, '1063'),
	(243, 1, 0, -10, 1065, 0, 0, 39, '1064'),
	(243, 1, 0, -10, 1066, 0, 0, 39, '1065'),
	(243, 1, 0, -10, 1067, 0, 0, 39, '1066'),
	(243, 1, 0, -10, 1068, 0, 0, 39, '1067'),
	(243, 1, 0, -10, 1069, 0, 0, 39, '1068'),
	(243, 1, 0, -10, 1070, 0, 0, 39, '1069'),
	(243, 1, 0, -10, 1071, 0, 0, 39, '1070'),
	(243, 1, 0, -10, 1072, 0, 0, 39, '1071'),
	(243, 1, 0, -10, 1073, 0, 0, 39, '1072'),
	(243, 1, 0, -10, 1074, 0, 0, 39, '1073'),
	(243, 1, 0, -10, 1075, 0, 0, 39, '1074'),
	(243, 1, 0, -10, 1076, 0, 0, 39, '1075'),
	(243, 1, 0, -10, 1077, 0, 0, 39, '1076'),
	(243, 1, 0, -10, 1078, 0, 0, 39, '1077'),
	(243, 1, 0, -10, 1079, 0, 0, 39, '1078'),
	(243, 1, 0, -10, 1080, 0, 0, 39, '1079'),
	(243, 1, 0, -10, 1081, 0, 0, 39, '1080'),
	(243, 1, 0, -10, 1082, 0, 0, 39, '1081'),
	(243, 1, 0, -10, 1083, 0, 0, 39, '1082'),
	(243, 1, 0, -10, 1084, 0, 0, 39, '1083'),
	(243, 1, 0, -10, 1085, 0, 0, 39, '1084'),
	(243, 1, 0, -10, 1086, 0, 0, 39, '1085'),
	(243, 1, 0, -10, 1087, 0, 0, 39, '1086'),
	(243, 1, 0, -10, 1088, 0, 0, 39, '1087'),
	(243, 1, 0, -10, 1089, 0, 0, 39, '1088'),
	(243, 1, 0, -10, 1090, 0, 0, 39, '1089'),
	(243, 1, 0, -10, 1091, 0, 0, 39, '1090'),
	(243, 1, 0, -10, 1092, 0, 0, 39, '1091'),
	(243, 1, 0, -10, 1093, 0, 0, 39, '1092'),
	(243, 1, 0, -10, 1094, 0, 0, 39, '1093'),
	(243, 1, 0, -10, 1095, 0, 0, 39, '1094'),
	(243, 1, 0, -10, 1096, 0, 0, 39, '1095'),
	(243, 1, 0, -10, 1097, 0, 0, 39, '1096'),
	(243, 1, 0, -10, 1098, 0, 0, 39, '1097'),
	(243, 1, 0, -10, 1099, 0, 0, 39, '1098'),
	(243, 1, 0, -10, 1100, 0, 0, 39, '1099'),
	(243, 1, 0, -10, 1101, 0, 0, 39, '1100'),
	(243, 1, 0, -10, 1102, 0, 0, 39, '1101'),
	(243, 1, 0, -10, 1103, 0, 0, 39, '1102'),
	(243, 1, 0, -10, 1104, 0, 0, 39, '1103'),
	(243, 1, 0, -10, 1105, 0, 0, 39, '1104'),
	(243, 1, 0, -10, 1106, 0, 0, 39, '1105'),
	(243, 1, 0, -10, 1107, 0, 0, 39, '1106'),
	(243, 1, 0, -10, 1108, 0, 0, 39, '1107'),
	(243, 1, 0, -10, 1109, 0, 0, 39, '1108'),
	(243, 1, 0, -10, 1110, 0, 0, 39, '1109'),
	(243, 1, 0, -10, 1111, 0, 0, 39, '1110'),
	(243, 1, 0, -10, 1112, 0, 0, 39, '1111'),
	(243, 1, 0, -10, 1113, 0, 0, 39, '1112'),
	(243, 1, 0, -10, 1114, 0, 0, 39, '1113'),
	(243, 1, 0, -10, 1115, 0, 0, 39, '1114'),
	(243, 1, 0, -10, 1116, 0, 0, 39, '1115'),
	(243, 1, 0, -10, 1117, 0, 0, 39, '1116'),
	(243, 1, 0, -10, 1118, 0, 0, 39, '1117'),
	(243, 1, 0, -10, 1119, 0, 0, 39, '1118'),
	(243, 1, 0, -10, 1120, 0, 0, 39, '1119'),
	(243, 1, 0, -10, 1121, 0, 0, 39, '1120'),
	(243, 1, 0, -10, 1122, 0, 0, 39, '1121'),
	(243, 1, 0, -10, 1123, 0, 0, 39, '1122'),
	(243, 1, 0, -10, 1124, 0, 0, 39, '1123'),
	(243, 1, 0, -10, 1125, 0, 0, 39, '1124'),
	(243, 1, 0, -10, 1126, 0, 0, 39, '1125'),
	(243, 1, 0, -10, 1127, 0, 0, 39, '1126'),
	(243, 1, 0, -10, 1128, 0, 0, 39, '1127'),
	(243, 1, 0, -10, 1129, 0, 0, 39, '1128'),
	(243, 1, 0, -10, 1130, 0, 0, 39, '1129'),
	(243, 1, 0, -10, 1131, 0, 0, 39, '1130'),
	(243, 1, 0, -10, 1132, 0, 0, 39, '1131'),
	(243, 1, 0, -10, 1133, 0, 0, 39, '1132'),
	(243, 1, 0, -10, 1134, 0, 0, 39, '1133'),
	(243, 1, 0, -10, 1135, 0, 0, 39, '1134'),
	(243, 1, 0, -10, 1136, 0, 0, 39, '1135'),
	(243, 1, 0, -10, 1137, 0, 0, 39, '1136'),
	(243, 1, 0, -10, 1138, 0, 0, 39, '1137'),
	(243, 1, 0, -10, 1139, 0, 0, 39, '1138'),
	(243, 1, 0, -10, 1140, 0, 0, 39, '1139'),
	(243, 1, 0, -10, 1141, 0, 0, 39, '1140'),
	(243, 1, 0, -10, 1142, 0, 0, 39, '1141'),
	(243, 1, 0, -10, 1143, 0, 0, 39, '1142'),
	(243, 1, 0, -10, 1144, 0, 0, 39, '1143'),
	(243, 1, 0, -10, 1145, 0, 0, 39, '1144'),
	(243, 1, 0, -10, 1146, 0, 0, 39, '1145'),
	(243, 1, 0, -10, 1147, 0, 0, 39, '1146'),
	(243, 1, 0, -10, 1148, 0, 0, 39, '1147'),
	(243, 1, 0, -10, 1149, 0, 0, 39, '1148'),
	(243, 1, 0, -10, 1150, 0, 0, 39, '1149'),
	(243, 1, 0, -10, 1151, 0, 0, 39, '1150'),
	(243, 1, 0, -10, 1152, 0, 0, 39, '1151'),
	(243, 1, 0, -10, 1153, 0, 0, 39, '1152'),
	(243, 1, 0, -10, 1154, 0, 0, 39, '1153'),
	(243, 1, 0, -10, 1155, 0, 0, 39, '1154'),
	(243, 1, 0, -10, 1156, 0, 0, 39, '1155'),
	(243, 1, 0, -10, 1157, 0, 0, 39, '1156'),
	(243, 1, 0, -10, 1158, 0, 0, 39, '1157'),
	(243, 1, 0, -10, 1159, 0, 0, 39, '1158'),
	(243, 1, 0, -10, 1160, 0, 0, 39, '1159'),
	(243, 1, 0, -10, 1161, 0, 0, 39, '1160'),
	(243, 1, 0, -10, 1162, 0, 0, 39, '1161'),
	(243, 1, 0, -10, 1163, 0, 0, 39, '1162'),
	(243, 1, 0, -10, 1164, 0, 0, 39, '1163'),
	(243, 1, 0, -10, 1165, 0, 0, 39, '1164'),
	(243, 1, 0, -10, 1166, 0, 0, 39, '1165'),
	(243, 1, 0, -10, 1167, 0, 0, 39, '1166'),
	(243, 1, 0, -10, 1168, 0, 0, 39, '1167'),
	(243, 1, 0, -10, 1169, 0, 0, 39, '1168'),
	(243, 1, 0, -10, 1170, 0, 0, 39, '1169'),
	(243, 1, 0, -10, 1171, 0, 0, 39, '1170'),
	(243, 1, 0, -10, 1172, 0, 0, 39, '1171'),
	(243, 1, 0, -10, 1173, 0, 0, 39, '1172'),
	(243, 1, 0, -10, 1174, 0, 0, 39, '1173'),
	(243, 1, 0, -10, 1175, 0, 0, 39, '1174'),
	(243, 1, 0, -10, 1176, 0, 0, 39, '1175'),
	(243, 1, 0, -10, 1177, 0, 0, 39, '1176'),
	(243, 1, 0, -10, 1178, 0, 0, 39, '1177'),
	(243, 1, 0, -10, 1179, 0, 0, 39, '1178'),
	(243, 1, 0, -10, 1180, 0, 0, 39, '1179'),
	(243, 1, 0, -10, 1181, 0, 0, 39, '1180'),
	(243, 1, 0, -10, 1182, 0, 0, 39, '1181'),
	(243, 1, 0, -10, 1183, 0, 0, 39, '1182'),
	(243, 1, 0, -10, 1184, 0, 0, 39, '1183'),
	(243, 1, 0, -10, 1185, 0, 0, 39, '1184'),
	(243, 1, 0, -10, 1186, 0, 0, 39, '1185'),
	(243, 1, 0, -10, 1187, 0, 0, 39, '1186'),
	(243, 1, 0, -10, 1188, 0, 0, 39, '1187'),
	(243, 1, 0, -10, 1189, 0, 0, 39, '1188'),
	(243, 1, 0, -10, 1190, 0, 0, 39, '1189'),
	(243, 1, 0, -10, 1191, 0, 0, 39, '1190'),
	(243, 1, 0, -10, 1192, 0, 0, 39, '1191'),
	(243, 1, 0, -10, 1193, 0, 0, 39, '1192'),
	(243, 1, 0, -10, 1194, 0, 0, 39, '1193'),
	(243, 1, 0, -10, 1195, 0, 0, 39, '1194'),
	(243, 1, 0, -10, 1196, 0, 0, 39, '1195'),
	(243, 1, 0, -10, 1197, 0, 0, 39, '1196'),
	(243, 1, 0, -10, 1198, 0, 0, 39, '1197'),
	(243, 1, 0, -10, 1199, 0, 0, 39, '1198'),
	(243, 1, 0, -10, 1200, 0, 0, 39, '1199'),
	(243, 1, 0, -10, 1201, 0, 0, 39, '1200'),
	(243, 1, 0, -10, 1202, 0, 0, 39, '1201'),
	(243, 1, 0, -10, 1203, 0, 0, 39, '1202'),
	(243, 1, 0, -10, 1204, 0, 0, 39, '1203'),
	(243, 1, 0, -10, 1205, 0, 0, 39, '1204'),
	(243, 1, 0, -10, 1206, 0, 0, 39, '1205'),
	(243, 1, 0, -10, 1207, 0, 0, 39, '1206'),
	(243, 1, 0, -10, 1208, 0, 0, 39, '1207'),
	(243, 1, 0, -10, 1209, 0, 0, 39, '1208'),
	(243, 1, 0, -10, 1210, 0, 0, 39, '1209'),
	(243, 1, 0, -10, 1211, 0, 0, 39, '1210'),
	(243, 1, 0, -10, 1212, 0, 0, 39, '1211'),
	(243, 1, 0, -10, 1213, 0, 0, 39, '1212'),
	(243, 1, 0, -10, 1214, 0, 0, 39, '1213'),
	(243, 1, 0, -10, 1215, 0, 0, 39, '1214'),
	(243, 1, 0, -10, 1216, 0, 0, 39, '1215'),
	(243, 1, 0, -10, 1217, 0, 0, 39, '1216'),
	(243, 1, 0, -10, 1218, 0, 0, 39, '1217'),
	(243, 1, 0, -10, 1219, 0, 0, 39, '1218'),
	(243, 1, 0, -10, 1220, 0, 0, 39, '1219'),
	(243, 1, 0, -10, 1221, 0, 0, 39, '1220'),
	(243, 1, 0, -10, 1222, 0, 0, 39, '1221'),
	(243, 1, 0, -10, 1223, 0, 0, 39, '1222'),
	(243, 1, 0, -10, 1224, 0, 0, 39, '1223'),
	(243, 1, 0, -10, 1225, 0, 0, 39, '1224'),
	(243, 1, 0, -10, 1226, 0, 0, 39, '1225'),
	(243, 1, 0, -10, 1227, 0, 0, 39, '1226'),
	(243, 1, 0, -10, 1228, 0, 0, 39, '1227'),
	(243, 1, 0, -10, 1229, 0, 0, 39, '1228'),
	(243, 1, 0, -10, 1230, 0, 0, 39, '1229'),
	(243, 1, 0, -10, 1231, 0, 0, 39, '1230'),
	(243, 1, 0, -10, 1232, 0, 0, 39, '1231'),
	(243, 1, 0, -10, 1233, 0, 0, 39, '1232'),
	(243, 1, 0, -10, 1234, 0, 0, 39, '1233'),
	(243, 1, 0, -10, 1235, 0, 0, 39, '1234'),
	(243, 1, 0, -10, 1236, 0, 0, 39, '1235'),
	(243, 1, 0, -10, 1237, 0, 0, 39, '1236'),
	(243, 1, 0, -10, 1238, 0, 0, 39, '1237'),
	(243, 1, 0, -10, 1239, 0, 0, 39, '1238'),
	(243, 1, 0, -10, 1240, 0, 0, 39, '1239'),
	(243, 1, 0, -10, 1241, 0, 0, 39, '1240'),
	(243, 1, 0, -10, 1242, 0, 0, 39, '1241'),
	(243, 1, 0, -10, 1243, 0, 0, 39, '1242'),
	(243, 1, 0, -10, 1244, 0, 0, 39, '1243'),
	(243, 1, 0, -10, 1245, 0, 0, 39, '1244'),
	(243, 1, 0, -10, 1246, 0, 0, 39, '1245'),
	(243, 1, 0, -10, 1247, 0, 0, 39, '1246'),
	(243, 1, 0, -10, 1248, 0, 0, 39, '1247'),
	(243, 1, 0, -10, 1249, 0, 0, 39, '1248'),
	(243, 1, 0, -10, 1250, 0, 0, 39, '1249'),
	(243, 1, 0, -10, 1251, 0, 0, 39, '1250'),
	(243, 1, 0, -10, 1252, 0, 0, 39, '1251'),
	(243, 1, 0, -10, 1253, 0, 0, 39, '1252'),
	(243, 1, 0, -10, 1254, 0, 0, 39, '1253'),
	(243, 1, 0, -10, 1255, 0, 0, 39, '1254'),
	(243, 1, 0, -10, 1256, 0, 0, 39, '1255'),
	(243, 1, 0, -10, 1257, 0, 0, 39, '1256'),
	(243, 1, 0, -10, 1258, 0, 0, 39, '1257'),
	(243, 1, 0, -10, 1259, 0, 0, 39, '1258'),
	(243, 1, 0, -10, 1260, 0, 0, 39, '1259'),
	(243, 1, 0, -10, 1261, 0, 0, 39, '1260'),
	(243, 1, 0, -10, 1262, 0, 0, 39, '1261'),
	(243, 1, 0, -10, 1263, 0, 0, 39, '1262'),
	(243, 1, 0, -10, 1264, 0, 0, 39, '1263'),
	(243, 1, 0, -10, 1265, 0, 0, 39, '1264'),
	(243, 1, 0, -10, 1266, 0, 0, 39, '1265'),
	(243, 1, 0, -10, 1267, 0, 0, 39, '1266'),
	(243, 1, 0, -10, 1268, 0, 0, 39, '1267'),
	(243, 1, 0, -10, 1269, 0, 0, 39, '1268'),
	(243, 1, 0, -10, 1270, 0, 0, 39, '1269'),
	(243, 1, 0, -10, 1271, 0, 0, 39, '1270'),
	(243, 1, 0, -10, 1272, 0, 0, 39, '1271'),
	(243, 1, 0, -10, 1273, 0, 0, 39, '1272'),
	(243, 1, 0, -10, 1274, 0, 0, 39, '1273'),
	(243, 1, 0, -10, 1275, 0, 0, 39, '1274'),
	(243, 1, 0, -10, 1276, 0, 0, 39, '1275'),
	(243, 1, 0, -10, 1277, 0, 0, 39, '1276'),
	(243, 1, 0, -10, 1278, 0, 0, 39, '1277'),
	(243, 1, 0, -10, 1279, 0, 0, 39, '1278'),
	(243, 1, 0, -10, 1280, 0, 0, 39, '1279'),
	(243, 1, 0, -10, 1281, 0, 0, 39, '1280'),
	(243, 1, 0, -10, 1282, 0, 0, 39, '1281'),
	(243, 1, 0, -10, 1283, 0, 0, 39, '1282'),
	(243, 1, 0, -10, 1284, 0, 0, 39, '1283'),
	(243, 1, 0, -10, 1285, 0, 0, 39, '1284'),
	(243, 1, 0, -10, 1286, 0, 0, 39, '1285'),
	(243, 1, 0, -10, 1287, 0, 0, 39, '1286'),
	(243, 1, 0, -10, 1288, 0, 0, 39, '1287'),
	(243, 1, 0, -10, 1289, 0, 0, 39, '1288'),
	(243, 1, 0, -10, 1290, 0, 0, 39, '1289'),
	(243, 1, 0, -10, 1291, 0, 0, 39, '1290'),
	(243, 1, 0, -10, 1292, 0, 0, 39, '1291'),
	(243, 1, 0, -10, 1293, 0, 0, 39, '1292'),
	(243, 1, 0, -10, 1294, 0, 0, 39, '1293'),
	(243, 1, 0, -10, 1295, 0, 0, 39, '1294'),
	(243, 1, 0, -10, 1296, 0, 0, 39, '1295'),
	(243, 1, 0, -10, 1297, 0, 0, 39, '1296'),
	(243, 1, 0, -10, 1298, 0, 0, 39, '1297'),
	(243, 1, 0, -10, 1299, 0, 0, 39, '1298'),
	(243, 1, 0, -10, 1300, 0, 0, 39, '1299'),
	(243, 1, 0, -10, 1301, 0, 0, 39, '1300'),
	(243, 1, 0, -10, 1302, 0, 0, 39, '1301'),
	(243, 1, 0, -10, 1303, 0, 0, 39, '1302'),
	(243, 1, 0, -10, 1304, 0, 0, 39, '1303'),
	(243, 1, 0, -10, 1305, 0, 0, 39, '1304'),
	(243, 1, 0, -10, 1306, 0, 0, 39, '1305'),
	(243, 1, 0, -10, 1307, 0, 0, 39, '1306'),
	(243, 1, 0, -10, 1308, 0, 0, 39, '1307'),
	(243, 1, 0, -10, 1309, 0, 0, 39, '1308'),
	(243, 1, 0, -10, 1310, 0, 0, 39, '1309'),
	(243, 1, 0, -10, 1311, 0, 0, 39, '1310'),
	(243, 1, 0, -10, 1312, 0, 0, 39, '1311'),
	(243, 1, 0, -10, 1313, 0, 0, 39, '1312'),
	(243, 1, 0, -10, 1314, 0, 0, 39, '1313'),
	(243, 1, 0, -10, 1315, 0, 0, 39, '1314'),
	(243, 1, 0, -10, 1316, 0, 0, 39, '1315'),
	(243, 1, 0, -10, 1317, 0, 0, 39, '1316'),
	(243, 1, 0, -10, 1318, 0, 0, 39, '1317'),
	(243, 1, 0, -10, 1319, 0, 0, 39, '1318'),
	(243, 1, 0, -10, 1320, 0, 0, 39, '1319'),
	(243, 1, 0, -10, 1321, 0, 0, 39, '1320'),
	(243, 1, 0, -10, 1322, 0, 0, 39, '1321'),
	(243, 1, 0, -10, 1323, 0, 0, 39, '1322'),
	(243, 1, 0, -10, 1324, 0, 0, 39, '1323'),
	(243, 1, 0, -10, 1325, 0, 0, 39, '1324'),
	(243, 1, 0, -10, 1326, 0, 0, 39, '1325'),
	(243, 1, 0, -10, 1327, 0, 0, 39, '1326'),
	(243, 1, 0, -10, 1328, 0, 0, 39, '1327'),
	(243, 1, 0, -10, 1329, 0, 0, 39, '1328'),
	(243, 1, 0, -10, 1330, 0, 0, 39, '1329'),
	(243, 1, 0, -10, 1331, 0, 0, 39, '1330'),
	(243, 1, 0, -10, 1332, 0, 0, 39, '1331'),
	(243, 1, 0, -10, 1333, 0, 0, 39, '1332'),
	(243, 1, 0, -10, 1334, 0, 0, 39, '1333'),
	(243, 1, 0, -10, 1335, 0, 0, 39, '1334'),
	(243, 1, 0, -10, 1336, 0, 0, 39, '1335'),
	(243, 1, 0, -10, 1337, 0, 0, 39, '1336'),
	(243, 1, 0, -10, 1338, 0, 0, 39, '1337'),
	(243, 1, 0, -10, 1339, 0, 0, 39, '1338'),
	(243, 1, 0, -10, 1340, 0, 0, 39, '1339'),
	(243, 1, 0, -10, 1341, 0, 0, 39, '1340'),
	(243, 1, 0, -10, 1342, 0, 0, 39, '1341'),
	(243, 1, 0, -10, 1343, 0, 0, 39, '1342'),
	(243, 1, 0, -10, 1344, 0, 0, 39, '1343'),
	(243, 1, 0, -10, 1345, 0, 0, 39, '1344'),
	(243, 1, 0, -10, 1346, 0, 0, 39, '1345'),
	(243, 1, 0, -10, 1347, 0, 0, 39, '1346'),
	(243, 1, 0, -10, 1348, 0, 0, 39, '1347'),
	(243, 1, 0, -10, 1349, 0, 0, 39, '1348'),
	(243, 1, 0, -10, 1350, 0, 0, 39, '1349'),
	(243, 1, 0, -10, 1351, 0, 0, 39, '1350'),
	(243, 1, 0, -10, 1352, 0, 0, 39, '1351'),
	(243, 1, 0, -10, 1353, 0, 0, 39, '1352'),
	(243, 1, 0, -10, 1354, 0, 0, 39, '1353'),
	(243, 1, 0, -10, 1355, 0, 0, 39, '1354'),
	(243, 1, 0, -10, 1356, 0, 0, 39, '1355'),
	(243, 1, 0, -10, 1357, 0, 0, 39, '1356'),
	(243, 1, 0, -10, 1358, 0, 0, 39, '1357'),
	(243, 1, 0, -10, 1359, 0, 0, 39, '1358'),
	(243, 1, 0, -10, 1360, 0, 0, 39, '1359'),
	(243, 1, 0, -10, 1361, 0, 0, 39, '1360'),
	(243, 1, 0, -10, 1362, 0, 0, 39, '1361'),
	(243, 1, 0, -10, 1363, 0, 0, 39, '1362'),
	(243, 1, 0, -10, 1364, 0, 0, 39, '1363'),
	(243, 1, 0, -10, 1365, 0, 0, 39, '1364'),
	(243, 1, 0, -10, 1366, 0, 0, 39, '1365'),
	(243, 1, 0, -10, 1367, 0, 0, 39, '1366'),
	(243, 1, 0, -10, 1368, 0, 0, 39, '1367'),
	(243, 1, 0, -10, 1369, 0, 0, 39, '1368'),
	(243, 1, 0, -10, 1370, 0, 0, 39, '1369'),
	(243, 1, 0, -10, 1371, 0, 0, 39, '1370'),
	(243, 1, 0, -10, 1372, 0, 0, 39, '1371'),
	(243, 1, 0, -10, 1373, 0, 0, 39, '1372'),
	(243, 1, 0, -10, 1374, 0, 0, 39, '1373'),
	(243, 1, 0, -10, 1375, 0, 0, 39, '1374'),
	(243, 1, 0, -10, 1376, 0, 0, 39, '1375'),
	(243, 1, 0, -10, 1377, 0, 0, 39, '1376'),
	(243, 1, 0, -10, 1378, 0, 0, 39, '1377'),
	(243, 1, 0, -10, 1379, 0, 0, 39, '1378'),
	(243, 1, 0, -10, 1380, 0, 0, 39, '1379'),
	(243, 1, 0, -10, 1381, 0, 0, 39, '1380'),
	(243, 1, 0, -10, 1382, 0, 0, 39, '1381'),
	(243, 1, 0, -10, 1383, 0, 0, 39, '1382'),
	(243, 1, 0, -10, 1384, 0, 0, 39, '1383'),
	(243, 1, 0, -10, 1385, 0, 0, 39, '1384'),
	(243, 1, 0, -10, 1386, 0, 0, 39, '1385'),
	(243, 1, 0, -10, 1387, 0, 0, 39, '1386'),
	(243, 1, 0, -10, 1388, 0, 0, 39, '1387'),
	(243, 1, 0, -10, 1389, 0, 0, 39, '1388'),
	(243, 1, 0, -10, 1390, 0, 0, 39, '1389'),
	(243, 1, 0, -10, 1391, 0, 0, 39, '1390'),
	(243, 1, 0, -10, 1392, 0, 0, 39, '1391'),
	(243, 1, 0, -10, 1393, 0, 0, 39, '1392'),
	(243, 1, 0, -10, 1394, 0, 0, 39, '1393'),
	(243, 1, 0, -10, 1395, 0, 0, 39, '1394'),
	(243, 1, 0, -10, 1396, 0, 0, 39, '1395'),
	(243, 1, 0, -10, 1397, 0, 0, 39, '1396'),
	(243, 1, 0, -10, 1398, 0, 0, 39, '1397'),
	(243, 1, 0, -10, 1399, 0, 0, 39, '1398'),
	(243, 1, 0, -10, 1400, 0, 0, 39, '1399'),
	(243, 1, 0, -10, 1401, 0, 0, 39, '1400'),
	(243, 1, 0, -10, 1402, 0, 0, 39, '1401'),
	(243, 1, 0, -10, 1403, 0, 0, 39, '1402'),
	(243, 1, 0, -10, 1404, 0, 0, 39, '1403'),
	(243, 1, 0, -10, 1405, 0, 0, 39, '1404'),
	(243, 1, 0, -10, 1406, 0, 0, 39, '1405'),
	(243, 1, 0, -10, 1407, 0, 0, 39, '1406'),
	(243, 1, 0, -10, 1408, 0, 0, 39, '1407'),
	(243, 1, 0, -10, 1409, 0, 0, 39, '1408'),
	(243, 1, 0, -10, 1410, 0, 0, 39, '1409'),
	(243, 1, 0, -10, 1411, 0, 0, 39, '1410'),
	(243, 1, 0, -10, 1412, 0, 0, 39, '1411'),
	(243, 1, 0, -10, 1413, 0, 0, 39, '1412'),
	(243, 1, 0, -10, 1414, 0, 0, 39, '1413'),
	(243, 1, 0, -10, 1415, 0, 0, 39, '1414'),
	(243, 1, 0, -10, 1416, 0, 0, 39, '1415'),
	(243, 1, 0, -10, 1417, 0, 0, 39, '1416'),
	(243, 1, 0, -10, 1418, 0, 0, 39, '1417'),
	(243, 1, 0, -10, 1419, 0, 0, 39, '1418'),
	(243, 1, 0, -10, 1420, 0, 0, 39, '1419'),
	(243, 1, 0, -10, 1421, 0, 0, 39, '1420'),
	(243, 1, 0, -10, 1422, 0, 0, 39, '1421'),
	(243, 1, 0, -10, 1423, 0, 0, 39, '1422'),
	(243, 1, 0, -10, 1424, 0, 0, 39, '1423'),
	(243, 1, 0, -10, 1425, 0, 0, 39, '1424'),
	(243, 1, 0, -10, 1426, 0, 0, 39, '1425'),
	(243, 1, 0, -10, 1427, 0, 0, 39, '1426'),
	(243, 1, 0, -10, 1428, 0, 0, 39, '1427'),
	(243, 1, 0, -10, 1429, 0, 0, 39, '1428'),
	(243, 1, 0, -10, 1430, 0, 0, 39, '1429'),
	(243, 1, 0, -10, 1431, 0, 0, 39, '1430'),
	(243, 1, 0, -10, 1432, 0, 0, 39, '1431'),
	(243, 1, 0, -10, 1433, 0, 0, 39, '1432'),
	(243, 1, 0, -10, 1434, 0, 0, 39, '1433'),
	(243, 1, 0, -10, 1435, 0, 0, 39, '1434'),
	(243, 1, 0, -10, 1436, 0, 0, 39, '1435'),
	(243, 1, 0, -10, 1437, 0, 0, 39, '1436'),
	(243, 1, 0, -10, 1438, 0, 0, 39, '1437'),
	(243, 1, 0, -10, 1439, 0, 0, 39, '1438'),
	(243, 1, 0, -10, 1440, 0, 0, 39, '1439'),
	(243, 1, 0, -10, 1441, 0, 0, 39, '1440'),
	(243, 1, 0, -10, 1442, 0, 0, 39, '1441'),
	(243, 1, 0, -10, 1443, 0, 0, 39, '1442'),
	(243, 1, 0, -10, 1444, 0, 0, 39, '1443'),
	(243, 1, 0, -10, 1445, 0, 0, 39, '1444'),
	(243, 1, 0, -10, 1446, 0, 0, 39, '1445'),
	(243, 1, 0, -10, 1447, 0, 0, 39, '1446'),
	(243, 1, 0, -10, 1448, 0, 0, 39, '1447'),
	(243, 1, 0, -10, 1449, 0, 0, 39, '1448'),
	(243, 1, 0, -10, 1450, 0, 0, 39, '1449'),
	(243, 1, 0, -10, 1451, 0, 0, 39, '1450'),
	(243, 1, 0, -10, 1452, 0, 0, 39, '1451'),
	(243, 1, 0, -10, 1453, 0, 0, 39, '1452'),
	(243, 1, 0, -10, 1454, 0, 0, 39, '1453'),
	(243, 1, 0, -10, 1455, 0, 0, 39, '1454'),
	(243, 1, 0, -10, 1456, 0, 0, 39, '1455'),
	(243, 1, 0, -10, 1457, 0, 0, 39, '1456'),
	(243, 1, 0, -10, 1458, 0, 0, 39, '1457'),
	(243, 1, 0, -10, 1459, 0, 0, 39, '1458'),
	(243, 1, 0, -10, 1460, 0, 0, 39, '1459'),
	(243, 1, 0, -10, 1461, 0, 0, 39, '1460'),
	(243, 1, 0, -10, 1462, 0, 0, 39, '1461'),
	(243, 1, 0, -10, 1463, 0, 0, 39, '1462'),
	(243, 1, 0, -10, 1464, 0, 0, 39, '1463'),
	(243, 1, 0, -10, 1465, 0, 0, 39, '1464'),
	(243, 1, 0, -10, 1466, 0, 0, 39, '1465'),
	(243, 1, 0, -10, 1467, 0, 0, 39, '1466'),
	(243, 1, 0, -10, 1468, 0, 0, 39, '1467'),
	(243, 1, 0, -10, 1469, 0, 0, 39, '1468'),
	(243, 1, 0, -10, 1470, 0, 0, 39, '1469'),
	(243, 1, 0, -10, 1471, 0, 0, 39, '1470'),
	(243, 1, 0, -10, 1472, 0, 0, 39, '1471'),
	(243, 1, 0, -10, 1473, 0, 0, 39, '1472'),
	(243, 1, 0, -10, 1474, 0, 0, 39, '1473'),
	(243, 1, 0, -10, 1475, 0, 0, 39, '1474'),
	(243, 1, 0, -10, 1476, 0, 0, 39, '1475'),
	(243, 1, 0, -10, 1477, 0, 0, 39, '1476'),
	(243, 1, 0, -10, 1478, 0, 0, 39, '1477'),
	(243, 1, 0, -10, 1479, 0, 0, 39, '1478'),
	(243, 1, 0, -10, 1480, 0, 0, 39, '1479'),
	(243, 1, 0, -10, 1481, 0, 0, 39, '1480'),
	(243, 1, 0, -10, 1482, 0, 0, 39, '1481'),
	(243, 1, 0, -10, 1483, 0, 0, 39, '1482'),
	(243, 1, 0, -10, 1484, 0, 0, 39, '1483'),
	(243, 1, 0, -10, 1485, 0, 0, 39, '1484'),
	(243, 1, 0, -10, 1486, 0, 0, 39, '1485'),
	(243, 1, 0, -10, 1487, 0, 0, 39, '1486'),
	(243, 1, 0, -10, 1488, 0, 0, 39, '1487'),
	(243, 1, 0, -10, 1489, 0, 0, 39, '1488'),
	(243, 1, 0, -10, 1490, 0, 0, 39, '1489'),
	(243, 1, 0, -10, 1491, 0, 0, 39, '1490'),
	(243, 1, 0, -10, 1492, 0, 0, 39, '1491'),
	(243, 1, 0, -10, 1493, 0, 0, 39, '1492'),
	(243, 1, 0, -10, 1494, 0, 0, 39, '1493'),
	(243, 1, 0, -10, 1495, 0, 0, 39, '1494'),
	(243, 1, 0, -10, 1496, 0, 0, 39, '1495'),
	(243, 1, 0, -10, 1497, 0, 0, 39, '1496'),
	(243, 1, 0, -10, 1498, 0, 0, 39, '1497'),
	(243, 1, 0, -10, 1499, 0, 0, 39, '1498'),
	(243, 1, 0, -10, 1500, 0, 0, 39, '1499'),
	(243, 1, 0, -10, 1501, 0, 0, 39, '1500'),
	(243, 1, 0, -10, 1502, 0, 0, 39, '1501'),
	(243, 1, 0, -10, 1503, 0, 0, 39, '1502'),
	(243, 1, 0, -10, 1504, 0, 0, 39, '1503'),
	(243, 1, 0, -10, 1505, 0, 0, 39, '1504'),
	(243, 1, 0, -10, 1506, 0, 0, 39, '1505'),
	(243, 1, 0, -10, 1507, 0, 0, 39, '1506'),
	(243, 1, 0, -10, 1508, 0, 0, 39, '1507'),
	(243, 1, 0, -10, 1509, 0, 0, 39, '1508'),
	(243, 1, 0, -10, 1510, 0, 0, 39, '1509'),
	(243, 1, 0, -10, 1511, 0, 0, 39, '1510'),
	(243, 1, 0, -10, 1512, 0, 0, 39, '1511'),
	(243, 1, 0, -10, 1513, 0, 0, 39, '1512'),
	(243, 1, 0, -10, 1514, 0, 0, 39, '1513'),
	(243, 1, 0, -10, 1515, 0, 0, 39, '1514'),
	(243, 1, 0, -10, 1516, 0, 0, 39, '1515'),
	(243, 1, 0, -10, 1517, 0, 0, 39, '1516'),
	(243, 1, 0, -10, 1518, 0, 0, 39, '1517'),
	(243, 1, 0, -10, 1519, 0, 0, 39, '1518'),
	(243, 1, 0, -10, 1520, 0, 0, 39, '1519'),
	(243, 1, 0, -10, 1521, 0, 0, 39, '1520'),
	(243, 1, 0, -10, 1522, 0, 0, 39, '1521'),
	(243, 1, 0, -10, 1523, 0, 0, 39, '1522'),
	(243, 1, 0, -10, 1524, 0, 0, 39, '1523'),
	(243, 1, 0, -10, 1525, 0, 0, 39, '1524'),
	(243, 1, 0, -10, 1526, 0, 0, 39, '1525'),
	(243, 1, 0, -10, 1527, 0, 0, 39, '1526'),
	(243, 1, 0, -10, 1528, 0, 0, 39, '1527'),
	(243, 1, 0, -10, 1529, 0, 0, 39, '1528'),
	(243, 1, 0, -10, 1530, 0, 0, 39, '1529'),
	(243, 1, 0, -10, 1531, 0, 0, 39, '1530'),
	(243, 1, 0, -10, 1532, 0, 0, 39, '1531'),
	(243, 1, 0, -10, 1533, 0, 0, 39, '1532'),
	(243, 1, 0, -10, 1534, 0, 0, 39, '1533'),
	(243, 1, 0, -10, 1535, 0, 0, 39, '1534'),
	(243, 1, 0, -10, 1536, 0, 0, 39, '1535'),
	(243, 1, 0, -10, 1537, 0, 0, 39, '1536'),
	(243, 1, 0, -10, 1538, 0, 0, 39, '1537'),
	(243, 1, 0, -10, 1539, 0, 0, 39, '1538'),
	(243, 1, 0, -10, 1540, 0, 0, 39, '1539'),
	(243, 1, 0, -10, 1541, 0, 0, 39, '1540'),
	(243, 1, 0, -10, 1542, 0, 0, 39, '1541'),
	(243, 1, 0, -10, 1543, 0, 0, 39, '1542'),
	(243, 1, 0, -10, 1544, 0, 0, 39, '1543'),
	(243, 1, 0, -10, 1545, 0, 0, 39, '1544'),
	(243, 1, 0, -10, 1546, 0, 0, 39, '1545'),
	(243, 1, 0, -10, 1547, 0, 0, 39, '1546'),
	(243, 1, 0, -10, 1548, 0, 0, 39, '1547'),
	(243, 1, 0, -10, 1549, 0, 0, 39, '1548'),
	(243, 1, 0, -10, 1550, 0, 0, 39, '1549'),
	(243, 1, 0, -10, 1551, 0, 0, 39, '1550'),
	(243, 1, 0, -10, 1552, 0, 0, 39, '1551'),
	(243, 1, 0, -10, 1553, 0, 0, 39, '1552'),
	(243, 1, 0, -10, 1554, 0, 0, 39, '1553'),
	(243, 1, 0, -10, 1555, 0, 0, 39, '1554'),
	(243, 1, 0, -10, 1556, 0, 0, 39, '1555'),
	(243, 1, 0, -10, 1557, 0, 0, 39, '1556'),
	(243, 1, 0, -10, 1558, 0, 0, 39, '1557'),
	(243, 1, 0, -10, 1559, 0, 0, 39, '1558'),
	(243, 1, 0, -10, 1560, 0, 0, 39, '1559'),
	(243, 1, 0, -10, 1561, 0, 0, 39, '1560'),
	(243, 1, 0, -10, 1562, 0, 0, 39, '1561'),
	(243, 1, 0, -10, 1563, 0, 0, 39, '1562'),
	(243, 1, 0, -10, 1564, 0, 0, 39, '1563'),
	(243, 1, 0, -10, 1565, 0, 0, 39, '1564'),
	(243, 1, 0, -10, 1566, 0, 0, 39, '1565'),
	(243, 1, 0, -10, 1567, 0, 0, 39, '1566'),
	(243, 1, 0, -10, 1568, 0, 0, 39, '1567'),
	(243, 1, 0, -10, 1569, 0, 0, 39, '1568'),
	(243, 1, 0, -10, 1570, 0, 0, 39, '1569'),
	(243, 1, 0, -10, 1571, 0, 0, 39, '1570'),
	(243, 1, 0, -10, 1572, 0, 0, 39, '1571'),
	(243, 1, 0, -10, 1573, 0, 0, 39, '1572'),
	(243, 1, 0, -10, 1574, 0, 0, 39, '1573'),
	(243, 1, 0, -10, 1575, 0, 0, 39, '1574'),
	(243, 1, 0, -10, 1576, 0, 0, 39, '1575'),
	(243, 1, 0, -10, 1577, 0, 0, 39, '1576'),
	(243, 1, 0, -10, 1578, 0, 0, 39, '1577'),
	(243, 1, 0, -10, 1579, 0, 0, 39, '1578'),
	(243, 1, 0, -10, 1580, 0, 0, 39, '1579'),
	(243, 1, 0, -10, 1581, 0, 0, 39, '1580'),
	(243, 1, 0, -10, 1582, 0, 0, 39, '1581'),
	(243, 1, 0, -10, 1583, 0, 0, 39, '1582'),
	(243, 1, 0, -10, 1584, 0, 0, 39, '1583'),
	(243, 1, 0, -10, 1585, 0, 0, 39, '1584'),
	(243, 1, 0, -10, 1586, 0, 0, 39, '1585'),
	(243, 1, 0, -10, 1587, 0, 0, 39, '1586'),
	(243, 1, 0, -10, 1588, 0, 0, 39, '1587'),
	(243, 1, 0, -10, 1589, 0, 0, 39, '1588'),
	(243, 1, 0, -10, 1590, 0, 0, 39, '1589'),
	(243, 1, 0, -10, 1591, 0, 0, 39, '1590'),
	(243, 1, 0, -10, 1592, 0, 0, 39, '1591'),
	(243, 1, 0, -10, 1593, 0, 0, 39, '1592'),
	(243, 1, 0, -10, 1594, 0, 0, 39, '1593'),
	(243, 1, 0, -10, 1595, 0, 0, 39, '1594'),
	(243, 1, 0, -10, 1596, 0, 0, 39, '1595'),
	(243, 1, 0, -10, 1597, 0, 0, 39, '1596'),
	(243, 1, 0, -10, 1598, 0, 0, 39, '1597'),
	(243, 1, 0, -10, 1599, 0, 0, 39, '1598'),
	(243, 1, 0, -10, 1600, 0, 0, 39, '1599'),
	(243, 1, 0, -10, 1601, 0, 0, 39, '1600'),
	(243, 1, 0, -10, 1602, 0, 0, 39, '1601'),
	(243, 1, 0, -10, 1603, 0, 0, 39, '1602'),
	(243, 1, 0, -10, 1604, 0, 0, 39, '1603'),
	(243, 1, 0, -10, 1605, 0, 0, 39, '1604'),
	(243, 1, 0, -10, 1606, 0, 0, 39, '1605'),
	(243, 1, 0, -10, 1607, 0, 0, 39, '1606'),
	(243, 1, 0, -10, 1608, 0, 0, 39, '1607'),
	(243, 1, 0, -10, 1609, 0, 0, 39, '1608'),
	(243, 1, 0, -10, 1610, 0, 0, 39, '1609'),
	(243, 1, 0, -10, 1611, 0, 0, 39, '1610'),
	(243, 1, 0, -10, 1612, 0, 0, 39, '1611'),
	(243, 1, 0, -10, 1613, 0, 0, 39, '1612'),
	(243, 1, 0, -10, 1614, 0, 0, 39, '1613'),
	(243, 1, 0, -10, 1615, 0, 0, 39, '1614'),
	(243, 1, 0, -10, 1616, 0, 0, 39, '1615'),
	(243, 1, 0, -10, 1617, 0, 0, 39, '1616'),
	(243, 1, 0, -10, 1618, 0, 0, 39, '1617'),
	(243, 1, 0, -10, 1619, 0, 0, 39, '1618'),
	(243, 1, 0, -10, 1620, 0, 0, 39, '1619'),
	(243, 1, 0, -10, 1621, 0, 0, 39, '1620'),
	(243, 1, 0, -10, 1622, 0, 0, 39, '1621'),
	(243, 1, 0, -10, 1623, 0, 0, 39, '1622'),
	(243, 1, 0, -10, 1624, 0, 0, 39, '1623'),
	(243, 1, 0, -10, 1625, 0, 0, 39, '1624'),
	(243, 1, 0, -10, 1626, 0, 0, 39, '1625'),
	(243, 1, 0, -10, 1627, 0, 0, 39, '1626'),
	(243, 1, 0, -10, 1628, 0, 0, 39, '1627'),
	(243, 1, 0, -10, 1629, 0, 0, 39, '1628'),
	(243, 1, 0, -10, 1630, 0, 0, 39, '1629'),
	(243, 1, 0, -10, 1631, 0, 0, 39, '1630'),
	(243, 1, 0, -10, 1632, 0, 0, 39, '1631'),
	(243, 1, 0, -10, 1633, 0, 0, 39, '1632'),
	(243, 1, 0, -10, 1634, 0, 0, 39, '1633'),
	(243, 1, 0, -10, 1635, 0, 0, 39, '1634'),
	(243, 1, 0, -10, 1636, 0, 0, 39, '1635'),
	(243, 1, 0, -10, 1637, 0, 0, 39, '1636'),
	(243, 1, 0, -10, 1638, 0, 0, 39, '1637'),
	(243, 1, 0, -10, 1639, 0, 0, 39, '1638'),
	(243, 1, 0, -10, 1640, 0, 0, 39, '1639'),
	(243, 1, 0, -10, 1641, 0, 0, 39, '1640'),
	(243, 1, 0, -10, 1642, 0, 0, 39, '1641'),
	(243, 1, 0, -10, 1643, 0, 0, 39, '1642'),
	(243, 1, 0, -10, 1644, 0, 0, 39, '1643'),
	(243, 1, 0, -10, 1645, 0, 0, 39, '1644'),
	(243, 1, 0, -10, 1646, 0, 0, 39, '1645'),
	(243, 1, 0, -10, 1647, 0, 0, 39, '1646'),
	(243, 1, 0, -10, 1648, 0, 0, 39, '1647'),
	(243, 1, 0, -10, 1649, 0, 0, 39, '1648'),
	(243, 1, 0, -10, 1650, 0, 0, 39, '1649'),
	(243, 1, 0, -10, 1651, 0, 0, 39, '1650'),
	(243, 1, 0, -10, 1652, 0, 0, 39, '1651'),
	(243, 1, 0, -10, 1653, 0, 0, 39, '1652'),
	(243, 1, 0, -10, 1654, 0, 0, 39, '1653'),
	(243, 1, 0, -10, 1655, 0, 0, 39, '1654'),
	(243, 1, 0, -10, 1656, 0, 0, 39, '1655'),
	(243, 1, 0, -10, 1657, 0, 0, 39, '1656'),
	(243, 1, 0, -10, 1658, 0, 0, 39, '1657'),
	(243, 1, 0, -10, 1659, 0, 0, 39, '1658'),
	(243, 1, 0, -10, 1660, 0, 0, 39, '1659'),
	(243, 1, 0, -10, 1661, 0, 0, 39, '1660'),
	(243, 1, 0, -10, 1662, 0, 0, 39, '1661'),
	(243, 1, 0, -10, 1663, 0, 0, 39, '1662'),
	(243, 1, 0, -10, 1664, 0, 0, 39, '1663'),
	(243, 1, 0, -10, 1665, 0, 0, 39, '1664'),
	(243, 1, 0, -10, 1666, 0, 0, 39, '1665'),
	(243, 1, 0, -10, 1667, 0, 0, 39, '1666'),
	(243, 1, 0, -10, 1668, 0, 0, 39, '1667'),
	(243, 1, 0, -10, 1669, 0, 0, 39, '1668'),
	(243, 1, 0, -10, 1670, 0, 0, 39, '1669'),
	(243, 1, 0, -10, 1671, 0, 0, 39, '1670'),
	(243, 1, 0, -10, 1672, 0, 0, 39, '1671'),
	(243, 1, 0, -10, 1673, 0, 0, 39, '1672'),
	(243, 1, 0, -10, 1674, 0, 0, 39, '1673'),
	(243, 1, 0, -10, 1675, 0, 0, 39, '1674'),
	(243, 1, 0, -10, 1676, 0, 0, 39, '1675'),
	(243, 1, 0, -10, 1677, 0, 0, 39, '1676'),
	(243, 1, 0, -10, 1678, 0, 0, 39, '1677'),
	(243, 1, 0, -10, 1679, 0, 0, 39, '1678'),
	(243, 1, 0, -10, 1680, 0, 0, 39, '1679'),
	(243, 1, 0, -10, 1681, 0, 0, 39, '1680'),
	(243, 1, 0, -10, 1682, 0, 0, 39, '1681'),
	(243, 1, 0, -10, 1683, 0, 0, 39, '1682'),
	(243, 1, 0, -10, 1684, 0, 0, 39, '1683'),
	(243, 1, 0, -10, 1685, 0, 0, 39, '1684'),
	(243, 1, 0, -10, 1686, 0, 0, 39, '1685'),
	(243, 1, 0, -10, 1687, 0, 0, 39, '1686'),
	(243, 1, 0, -10, 1688, 0, 0, 39, '1687'),
	(243, 1, 0, -10, 1689, 0, 0, 39, '1688'),
	(243, 1, 0, -10, 1690, 0, 0, 39, '1689'),
	(243, 1, 0, -10, 1691, 0, 0, 39, '1690'),
	(243, 1, 0, -10, 1692, 0, 0, 39, '1691'),
	(243, 1, 0, -10, 1693, 0, 0, 39, '1692'),
	(243, 1, 0, -10, 1694, 0, 0, 39, '1693'),
	(243, 1, 0, -10, 1695, 0, 0, 39, '1694'),
	(243, 1, 0, -10, 1696, 0, 0, 39, '1695'),
	(243, 1, 0, -10, 1697, 0, 0, 39, '1696'),
	(243, 1, 0, -10, 1698, 0, 0, 39, '1697'),
	(243, 1, 0, -10, 1699, 0, 0, 39, '1698'),
	(243, 1, 0, -10, 1700, 0, 0, 39, '1699'),
	(243, 1, 0, -10, 1701, 0, 0, 39, '1700'),
	(243, 1, 0, -10, 1702, 0, 0, 39, '1701'),
	(243, 1, 0, -10, 1703, 0, 0, 39, '1702'),
	(243, 1, 0, -10, 1704, 0, 0, 39, '1703'),
	(243, 1, 0, -10, 1705, 0, 0, 39, '1704'),
	(243, 1, 0, -10, 1706, 0, 0, 39, '1705'),
	(243, 1, 0, -10, 1707, 0, 0, 39, '1706'),
	(243, 1, 0, -10, 1708, 0, 0, 39, '1707'),
	(243, 1, 0, -10, 1709, 0, 0, 39, '1708'),
	(243, 1, 0, -10, 1710, 0, 0, 39, '1709'),
	(243, 1, 0, -10, 1711, 0, 0, 39, '1710'),
	(243, 1, 0, -10, 1712, 0, 0, 39, '1711'),
	(243, 1, 0, -10, 1713, 0, 0, 39, '1712'),
	(243, 1, 0, -10, 1714, 0, 0, 39, '1713'),
	(243, 1, 0, -10, 1715, 0, 0, 39, '1714'),
	(243, 1, 0, -10, 1716, 0, 0, 39, '1715'),
	(243, 1, 0, -10, 1717, 0, 0, 39, '1716'),
	(243, 1, 0, -10, 1718, 0, 0, 39, '1717'),
	(243, 1, 0, -10, 1719, 0, 0, 39, '1718'),
	(243, 1, 0, -10, 1720, 0, 0, 39, '1719'),
	(243, 1, 0, -10, 1721, 0, 0, 39, '1720'),
	(243, 1, 0, -10, 1722, 0, 0, 39, '1721'),
	(243, 1, 0, -10, 1723, 0, 0, 39, '1722'),
	(243, 1, 0, -10, 1724, 0, 0, 39, '1723'),
	(243, 1, 0, -10, 1725, 0, 0, 39, '1724'),
	(243, 1, 0, -10, 1726, 0, 0, 39, '1725'),
	(243, 1, 0, -10, 1727, 0, 0, 39, '1726'),
	(243, 1, 0, -10, 1728, 0, 0, 39, '1727'),
	(243, 1, 0, -10, 1729, 0, 0, 39, '1728'),
	(243, 1, 0, -10, 1730, 0, 0, 39, '1729'),
	(243, 1, 0, -10, 1731, 0, 0, 39, '1730'),
	(243, 1, 0, -10, 1732, 0, 0, 39, '1731'),
	(243, 1, 0, -10, 1733, 0, 0, 39, '1732'),
	(243, 1, 0, -10, 1734, 0, 0, 39, '1733'),
	(243, 1, 0, -10, 1735, 0, 0, 39, '1734'),
	(243, 1, 0, -10, 1736, 0, 0, 39, '1735'),
	(243, 1, 0, -10, 1737, 0, 0, 39, '1736'),
	(243, 1, 0, -10, 1738, 0, 0, 39, '1737'),
	(243, 1, 0, -10, 1739, 0, 0, 39, '1738'),
	(243, 1, 0, -10, 1740, 0, 0, 39, '1739'),
	(243, 1, 0, -10, 1741, 0, 0, 39, '1740'),
	(243, 1, 0, -10, 1742, 0, 0, 39, '1741'),
	(243, 1, 0, -10, 1743, 0, 0, 39, '1742'),
	(243, 1, 0, -10, 1744, 0, 0, 39, '1743'),
	(243, 1, 0, -10, 1745, 0, 0, 39, '1744'),
	(243, 1, 0, -10, 1746, 0, 0, 39, '1745'),
	(243, 1, 0, -10, 1747, 0, 0, 39, '1746'),
	(243, 1, 0, -10, 1748, 0, 0, 39, '1747'),
	(243, 1, 0, -10, 1749, 0, 0, 39, '1748'),
	(243, 1, 0, -10, 1750, 0, 0, 39, '1749'),
	(243, 1, 0, -10, 1751, 0, 0, 39, '1750'),
	(243, 1, 0, -10, 1752, 0, 0, 39, '1751'),
	(243, 1, 0, -10, 1753, 0, 0, 39, '1752'),
	(243, 1, 0, -10, 1754, 0, 0, 39, '1753'),
	(243, 1, 0, -10, 1755, 0, 0, 39, '1754'),
	(243, 1, 0, -10, 1756, 0, 0, 39, '1755'),
	(243, 1, 0, -10, 1757, 0, 0, 39, '1756'),
	(243, 1, 0, -10, 1758, 0, 0, 39, '1757'),
	(243, 1, 0, -10, 1759, 0, 0, 39, '1758'),
	(243, 1, 0, -10, 1760, 0, 0, 39, '1759'),
	(243, 1, 0, -10, 1761, 0, 0, 39, '1760'),
	(243, 1, 0, -10, 1762, 0, 0, 39, '1761'),
	(243, 1, 0, -10, 1763, 0, 0, 39, '1762'),
	(243, 1, 0, -10, 1764, 0, 0, 39, '1763'),
	(243, 1, 0, -10, 1765, 0, 0, 39, '1764'),
	(243, 1, 0, -10, 1766, 0, 0, 39, '1765'),
	(243, 1, 0, -10, 1767, 0, 0, 39, '1766'),
	(243, 1, 0, -10, 1768, 0, 0, 39, '1767'),
	(243, 1, 0, -10, 1769, 0, 0, 39, '1768'),
	(243, 1, 0, -10, 1770, 0, 0, 39, '1769'),
	(243, 1, 0, -10, 1771, 0, 0, 39, '1770'),
	(243, 1, 0, -10, 1772, 0, 0, 39, '1771'),
	(243, 1, 0, -10, 1773, 0, 0, 39, '1772'),
	(243, 1, 0, -10, 1774, 0, 0, 39, '1773'),
	(243, 1, 0, -10, 1775, 0, 0, 39, '1774'),
	(243, 1, 0, -10, 1776, 0, 0, 39, '1775'),
	(243, 1, 0, -10, 1777, 0, 0, 39, '1776'),
	(243, 1, 0, -10, 1778, 0, 0, 39, '1777'),
	(243, 1, 0, -10, 1779, 0, 0, 39, '1778'),
	(243, 1, 0, -10, 1780, 0, 0, 39, '1779'),
	(243, 1, 0, -10, 1781, 0, 0, 39, '1780'),
	(243, 1, 0, -10, 1782, 0, 0, 39, '1781'),
	(243, 1, 0, -10, 1783, 0, 0, 39, '1782'),
	(243, 1, 0, -10, 1784, 0, 0, 39, '1783'),
	(243, 1, 0, -10, 1785, 0, 0, 39, '1784'),
	(243, 1, 0, -10, 1786, 0, 0, 39, '1785'),
	(243, 1, 0, -10, 1787, 0, 0, 39, '1786'),
	(243, 1, 0, -10, 1788, 0, 0, 39, '1787'),
	(243, 1, 0, -10, 1789, 0, 0, 39, '1788'),
	(243, 1, 0, -10, 1790, 0, 0, 39, '1789'),
	(243, 1, 0, -10, 1791, 0, 0, 39, '1790'),
	(243, 1, 0, -10, 1792, 0, 0, 39, '1791'),
	(243, 1, 0, -10, 1793, 0, 0, 39, '1792'),
	(243, 1, 0, -10, 1794, 0, 0, 39, '1793'),
	(243, 1, 0, -10, 1795, 0, 0, 39, '1794'),
	(243, 1, 0, -10, 1796, 0, 0, 39, '1795'),
	(243, 1, 0, -10, 1797, 0, 0, 39, '1796'),
	(243, 1, 0, -10, 1798, 0, 0, 39, '1797'),
	(243, 1, 0, -10, 1799, 0, 0, 39, '1798'),
	(243, 1, 0, -10, 1800, 0, 0, 39, '1799'),
	(243, 1, 0, -10, 1801, 0, 0, 39, '1800'),
	(243, 1, 0, -10, 1802, 0, 0, 39, '1801'),
	(243, 1, 0, -10, 1803, 0, 0, 39, '1802'),
	(243, 1, 0, -10, 1804, 0, 0, 39, '1803'),
	(243, 1, 0, -10, 1805, 0, 0, 39, '1804'),
	(243, 1, 0, -10, 1806, 0, 0, 39, '1805'),
	(243, 1, 0, -10, 1807, 0, 0, 39, '1806'),
	(243, 1, 0, -10, 1808, 0, 0, 39, '1807'),
	(243, 1, 0, -10, 1809, 0, 0, 39, '1808'),
	(243, 1, 0, -10, 1810, 0, 0, 39, '1809'),
	(243, 1, 0, -10, 1811, 0, 0, 39, '1810'),
	(243, 1, 0, -10, 1812, 0, 0, 39, '1811'),
	(243, 1, 0, -10, 1813, 0, 0, 39, '1812'),
	(243, 1, 0, -10, 1814, 0, 0, 39, '1813'),
	(243, 1, 0, -10, 1815, 0, 0, 39, '1814'),
	(243, 1, 0, -10, 1816, 0, 0, 39, '1815'),
	(243, 1, 0, -10, 1817, 0, 0, 39, '1816'),
	(243, 1, 0, -10, 1818, 0, 0, 39, '1817'),
	(243, 1, 0, -10, 1819, 0, 0, 39, '1818'),
	(243, 1, 0, -10, 1820, 0, 0, 39, '1819'),
	(243, 1, 0, -10, 1821, 0, 0, 39, '1820'),
	(243, 1, 0, -10, 1822, 0, 0, 39, '1821'),
	(243, 1, 0, -10, 1823, 0, 0, 39, '1822'),
	(243, 1, 0, -10, 1824, 0, 0, 39, '1823'),
	(243, 1, 0, -10, 1825, 0, 0, 39, '1824'),
	(243, 1, 0, -10, 1826, 0, 0, 39, '1825'),
	(243, 1, 0, -10, 1827, 0, 0, 39, '1826'),
	(243, 1, 0, -10, 1828, 0, 0, 39, '1827'),
	(243, 1, 0, -10, 1829, 0, 0, 39, '1828'),
	(243, 1, 0, -10, 1830, 0, 0, 39, '1829'),
	(243, 1, 0, -10, 1831, 0, 0, 39, '1830'),
	(243, 1, 0, -10, 1832, 0, 0, 39, '1831'),
	(243, 1, 0, -10, 1833, 0, 0, 39, '1832'),
	(243, 1, 0, -10, 1834, 0, 0, 39, '1833'),
	(243, 1, 0, -10, 1835, 0, 0, 39, '1834'),
	(243, 1, 0, -10, 1836, 0, 0, 39, '1835'),
	(243, 1, 0, -10, 1837, 0, 0, 39, '1836'),
	(243, 1, 0, -10, 1838, 0, 0, 39, '1837'),
	(243, 1, 0, -10, 1839, 0, 0, 39, '1838'),
	(243, 1, 0, -10, 1840, 0, 0, 39, '1839'),
	(243, 1, 0, -10, 1841, 0, 0, 39, '1840'),
	(243, 1, 0, -10, 1842, 0, 0, 39, '1841'),
	(243, 1, 0, -10, 1843, 0, 0, 39, '1842'),
	(243, 1, 0, -10, 1844, 0, 0, 39, '1843'),
	(243, 1, 0, -10, 1845, 0, 0, 39, '1844'),
	(243, 1, 0, -10, 1846, 0, 0, 39, '1845'),
	(243, 1, 0, -10, 1847, 0, 0, 39, '1846'),
	(243, 1, 0, -10, 1848, 0, 0, 39, '1847'),
	(243, 1, 0, -10, 1849, 0, 0, 39, '1848'),
	(243, 1, 0, -10, 1850, 0, 0, 39, '1849'),
	(243, 1, 0, -10, 1851, 0, 0, 39, '1850'),
	(243, 1, 0, -10, 1852, 0, 0, 39, '1851'),
	(243, 1, 0, -10, 1853, 0, 0, 39, '1852'),
	(243, 1, 0, -10, 1854, 0, 0, 39, '1853'),
	(243, 1, 0, -10, 1855, 0, 0, 39, '1854'),
	(243, 1, 0, -10, 1856, 0, 0, 39, '1855'),
	(243, 1, 0, -10, 1857, 0, 0, 39, '1856'),
	(243, 1, 0, -10, 1858, 0, 0, 39, '1857'),
	(243, 1, 0, -10, 1859, 0, 0, 39, '1858'),
	(243, 1, 0, -10, 1860, 0, 0, 39, '1859'),
	(243, 1, 0, -10, 1861, 0, 0, 39, '1860'),
	(243, 1, 0, -10, 1862, 0, 0, 39, '1861'),
	(243, 1, 0, -10, 1863, 0, 0, 39, '1862'),
	(243, 1, 0, -10, 1864, 0, 0, 39, '1863'),
	(243, 1, 0, -10, 1865, 0, 0, 39, '1864'),
	(243, 1, 0, -10, 1866, 0, 0, 39, '1865'),
	(243, 1, 0, -10, 1867, 0, 0, 39, '1866'),
	(243, 1, 0, -10, 1868, 0, 0, 39, '1867'),
	(243, 1, 0, -10, 1869, 0, 0, 39, '1868'),
	(243, 1, 0, -10, 1870, 0, 0, 39, '1869'),
	(243, 1, 0, -10, 1871, 0, 0, 39, '1870'),
	(243, 1, 0, -10, 1872, 0, 0, 39, '1871'),
	(243, 1, 0, -10, 1873, 0, 0, 39, '1872'),
	(243, 1, 0, -10, 1874, 0, 0, 39, '1873'),
	(243, 1, 0, -10, 1875, 0, 0, 39, '1874'),
	(243, 1, 0, -10, 1876, 0, 0, 39, '1875'),
	(243, 1, 0, -10, 1877, 0, 0, 39, '1876'),
	(243, 1, 0, -10, 1878, 0, 0, 39, '1877'),
	(243, 1, 0, -10, 1879, 0, 0, 39, '1878'),
	(243, 1, 0, -10, 1880, 0, 0, 39, '1879'),
	(243, 1, 0, -10, 1881, 0, 0, 39, '1880'),
	(243, 1, 0, -10, 1882, 0, 0, 39, '1881'),
	(243, 1, 0, -10, 1883, 0, 0, 39, '1882'),
	(243, 1, 0, -10, 1884, 0, 0, 39, '1883'),
	(243, 1, 0, -10, 1885, 0, 0, 39, '1884'),
	(243, 1, 0, -10, 1886, 0, 0, 39, '1885'),
	(243, 1, 0, -10, 1887, 0, 0, 39, '1886'),
	(243, 1, 0, -10, 1888, 0, 0, 39, '1887'),
	(243, 1, 0, -10, 1889, 0, 0, 39, '1888'),
	(243, 1, 0, -10, 1890, 0, 0, 39, '1889'),
	(243, 1, 0, -10, 1891, 0, 0, 39, '1890'),
	(243, 1, 0, -10, 1892, 0, 0, 39, '1891'),
	(243, 1, 0, -10, 1893, 0, 0, 39, '1892'),
	(243, 1, 0, -10, 1894, 0, 0, 39, '1893'),
	(243, 1, 0, -10, 1895, 0, 0, 39, '1894'),
	(243, 1, 0, -10, 1896, 0, 0, 39, '1895'),
	(243, 1, 0, -10, 1897, 0, 0, 39, '1896'),
	(243, 1, 0, -10, 1898, 0, 0, 39, '1897'),
	(243, 1, 0, -10, 1899, 0, 0, 39, '1898'),
	(243, 1, 0, -10, 1900, 0, 0, 39, '1899'),
	(243, 1, 0, -10, 1901, 0, 0, 39, '1900'),
	(243, 1, 0, -10, 1902, 0, 0, 39, '1901'),
	(243, 1, 0, -10, 1903, 0, 0, 39, '1902'),
	(243, 1, 0, -10, 1904, 0, 0, 39, '1903'),
	(243, 1, 0, -10, 1905, 0, 0, 39, '1904'),
	(243, 1, 0, -10, 1906, 0, 0, 39, '1905'),
	(243, 1, 0, -10, 1907, 0, 0, 39, '1906'),
	(243, 1, 0, -10, 1908, 0, 0, 39, '1907'),
	(243, 1, 0, -10, 1909, 0, 0, 39, '1908'),
	(243, 1, 0, -10, 1910, 0, 0, 39, '1909'),
	(243, 1, 0, -10, 1911, 0, 0, 39, '1910'),
	(243, 1, 0, -10, 1912, 0, 0, 39, '1911'),
	(243, 1, 0, -10, 1913, 0, 0, 39, '1912'),
	(243, 1, 0, -10, 1914, 0, 0, 39, '1913'),
	(243, 1, 0, -10, 1915, 0, 0, 39, '1914'),
	(243, 1, 0, -10, 1916, 0, 0, 39, '1915'),
	(243, 1, 0, -10, 1917, 0, 0, 39, '1916'),
	(243, 1, 0, -10, 1918, 0, 0, 39, '1917'),
	(243, 1, 0, -10, 1919, 0, 0, 39, '1918'),
	(243, 1, 0, -10, 1920, 0, 0, 39, '1919'),
	(243, 1, 0, -10, 1921, 0, 0, 39, '1920'),
	(243, 1, 0, -10, 1922, 0, 0, 39, '1921'),
	(243, 1, 0, -10, 1923, 0, 0, 39, '1922'),
	(243, 1, 0, -10, 1924, 0, 0, 39, '1923'),
	(243, 1, 0, -10, 1925, 0, 0, 39, '1924'),
	(243, 1, 0, -10, 1926, 0, 0, 39, '1925'),
	(243, 1, 0, -10, 1927, 0, 0, 39, '1926'),
	(243, 1, 0, -10, 1928, 0, 0, 39, '1927'),
	(243, 1, 0, -10, 1929, 0, 0, 39, '1928'),
	(243, 1, 0, -10, 1930, 0, 0, 39, '1929'),
	(243, 1, 0, -10, 1931, 0, 0, 39, '1930'),
	(243, 1, 0, -10, 1932, 0, 0, 39, '1931'),
	(243, 1, 0, -10, 1933, 0, 0, 39, '1932'),
	(243, 1, 0, -10, 1934, 0, 0, 39, '1933'),
	(243, 1, 0, -10, 1935, 0, 0, 39, '1934'),
	(243, 1, 0, -10, 1936, 0, 0, 39, '1935'),
	(243, 1, 0, -10, 1937, 0, 0, 39, '1936'),
	(243, 1, 0, -10, 1938, 0, 0, 39, '1937'),
	(243, 1, 0, -10, 1939, 0, 0, 39, '1938'),
	(243, 1, 0, -10, 1940, 0, 0, 39, '1939'),
	(243, 1, 0, -10, 1941, 0, 0, 39, '1940'),
	(243, 1, 0, -10, 1942, 0, 0, 39, '1941'),
	(243, 1, 0, -10, 1943, 0, 0, 39, '1942'),
	(243, 1, 0, -10, 1944, 0, 0, 39, '1943'),
	(243, 1, 0, -10, 1945, 0, 0, 39, '1944'),
	(243, 1, 0, -10, 1946, 0, 0, 39, '1945'),
	(243, 1, 0, -10, 1947, 0, 0, 39, '1946'),
	(243, 1, 0, -10, 1948, 0, 0, 39, '1947'),
	(243, 1, 0, -10, 1949, 0, 0, 39, '1948'),
	(243, 1, 0, -10, 1950, 0, 0, 39, '1949'),
	(243, 1, 0, -10, 1951, 0, 0, 39, '1950'),
	(243, 1, 0, -10, 1952, 0, 0, 39, '1951'),
	(243, 1, 0, -10, 1953, 0, 0, 39, '1952'),
	(243, 1, 0, -10, 1954, 0, 0, 39, '1953'),
	(243, 1, 0, -10, 1955, 0, 0, 39, '1954'),
	(243, 1, 0, -10, 1956, 0, 0, 39, '1955'),
	(243, 1, 0, -10, 1957, 0, 0, 39, '1956'),
	(243, 1, 0, -10, 1958, 0, 0, 39, '1957'),
	(243, 1, 0, -10, 1959, 0, 0, 39, '1958'),
	(243, 1, 0, -10, 1960, 0, 0, 39, '1959'),
	(243, 1, 0, -10, 1961, 0, 0, 39, '1960'),
	(243, 1, 0, -10, 1962, 0, 0, 39, '1961'),
	(243, 1, 0, -10, 1963, 0, 0, 39, '1962'),
	(243, 1, 0, -10, 1964, 0, 0, 39, '1963'),
	(243, 1, 0, -10, 1965, 0, 0, 39, '1964'),
	(243, 1, 0, -10, 1966, 0, 0, 39, '1965'),
	(243, 1, 0, -10, 1967, 0, 0, 39, '1966'),
	(243, 1, 0, -10, 1968, 0, 0, 39, '1967'),
	(243, 1, 0, -10, 1969, 0, 0, 39, '1968'),
	(243, 1, 0, -10, 1970, 0, 0, 39, '1969'),
	(243, 1, 0, -10, 1971, 0, 0, 39, '1970'),
	(243, 1, 0, -10, 1972, 0, 0, 39, '1971'),
	(243, 1, 0, -10, 1973, 0, 0, 39, '1972'),
	(243, 1, 0, -10, 1974, 0, 0, 39, '1973'),
	(243, 1, 0, -10, 1975, 0, 0, 39, '1974'),
	(243, 1, 0, -10, 1976, 0, 0, 39, '1975'),
	(243, 1, 0, -10, 1977, 0, 0, 39, '1976'),
	(243, 1, 0, -10, 1978, 0, 0, 39, '1977'),
	(243, 1, 0, -10, 1979, 0, 0, 39, '1978'),
	(243, 1, 0, -10, 1980, 0, 0, 39, '1979'),
	(243, 1, 0, -10, 1981, 0, 0, 39, '1980'),
	(243, 1, 0, -10, 1982, 0, 0, 39, '1981'),
	(243, 1, 0, -10, 1983, 0, 0, 39, '1982'),
	(243, 1, 0, -10, 1984, 0, 0, 39, '1983'),
	(243, 1, 0, -10, 1985, 0, 0, 39, '1984'),
	(243, 1, 0, -10, 1986, 0, 0, 39, '1985'),
	(243, 1, 0, -10, 1987, 0, 0, 39, '1986'),
	(243, 1, 0, -10, 1988, 0, 0, 39, '1987'),
	(243, 1, 0, -10, 1989, 0, 0, 39, '1988'),
	(243, 1, 0, -10, 1990, 0, 0, 39, '1989'),
	(243, 1, 0, -10, 1991, 0, 0, 39, '1990'),
	(243, 1, 0, -10, 1992, 0, 0, 39, '1991'),
	(243, 1, 0, -10, 1993, 0, 0, 39, '1992'),
	(243, 1, 0, -10, 1994, 0, 0, 39, '1993'),
	(243, 1, 0, -10, 1995, 0, 0, 39, '1994'),
	(243, 1, 0, -10, 1996, 0, 0, 39, '1995'),
	(243, 1, 0, -10, 1997, 0, 0, 39, '1996'),
	(243, 1, 0, -10, 1998, 0, 0, 39, '1997'),
	(243, 1, 0, -10, 1999, 0, 0, 39, '1998'),
	(243, 1, 0, -10, 2000, 0, 0, 39, '1999'),
	(243, 1, 0, -10, 2001, 0, 0, 39, '2000'),
	(243, 1, 0, -10, 2002, 0, 0, 39, '2001'),
	(243, 1, 0, -10, 2003, 0, 0, 39, '2002'),
	(243, 1, 0, -10, 2004, 0, 0, 39, '2003'),
	(243, 1, 0, -10, 2005, 0, 0, 39, '2004'),
	(243, 1, 0, -10, 2006, 0, 0, 39, '2005'),
	(243, 1, 0, -10, 2007, 0, 0, 39, '2006'),
	(243, 1, 0, -10, 2008, 0, 0, 39, '2007'),
	(243, 1, 0, -10, 2009, 0, 0, 39, '2008'),
	(243, 1, 0, -10, 2010, 0, 0, 39, '2009'),
	(243, 1, 0, -10, 2011, 0, 0, 39, '2010'),
	(243, 1, 0, -10, 2012, 0, 0, 39, '2011'),
	(243, 1, 0, -10, 2013, 0, 0, 39, '2012'),
	(243, 1, 0, -10, 2014, 0, 0, 39, '2013'),
	(243, 1, 0, -10, 2015, 0, 0, 39, '2014'),
	(243, 1, 0, -10, 2016, 0, 0, 39, '2015'),
	(243, 1, 0, -10, 2017, 0, 0, 39, '2016'),
	(243, 1, 0, -10, 2018, 0, 0, 39, '2017'),
	(243, 1, 0, -10, 2019, 0, 0, 39, '2018'),
	(243, 1, 0, -10, 2020, 0, 0, 39, '2019'),
	(243, 1, 0, -10, 2021, 0, 0, 39, '2020'),
	(243, 1, 0, -10, 2022, 0, 0, 39, '2021'),
	(243, 1, 0, -10, 2023, 0, 0, 39, '2022'),
	(243, 1, 0, -10, 2024, 0, 0, 39, '2023'),
	(243, 1, 0, -10, 2025, 0, 0, 39, '2024'),
	(243, 1, 0, -10, 2026, 0, 0, 39, '2025'),
	(243, 1, 0, -10, 2027, 0, 0, 39, '2026'),
	(243, 1, 0, -10, 2028, 0, 0, 39, '2027'),
	(243, 1, 0, -10, 2029, 0, 0, 39, '2028'),
	(243, 1, 0, -10, 2030, 0, 0, 39, '2029'),
	(243, 1, 0, -10, 2031, 0, 0, 39, '2030'),
	(243, 1, 0, -10, 2032, 0, 0, 39, '2031'),
	(243, 1, 0, -10, 2033, 0, 0, 39, '2032'),
	(243, 1, 0, -10, 2034, 0, 0, 39, '2033'),
	(243, 1, 0, -10, 2035, 0, 0, 39, '2034'),
	(243, 1, 0, -10, 2036, 0, 0, 39, '2035'),
	(243, 1, 0, -10, 2037, 0, 0, 39, '2036'),
	(243, 1, 0, -10, 2038, 0, 0, 39, '2037'),
	(243, 1, 0, -10, 2039, 0, 0, 39, '2038'),
	(243, 1, 0, -10, 2040, 0, 0, 39, '2039'),
	(243, 1, 0, -10, 2041, 0, 0, 39, '2040'),
	(243, 1, 0, -10, 2042, 0, 0, 39, '2041'),
	(243, 1, 0, -10, 2043, 0, 0, 39, '2042'),
	(243, 1, 0, -10, 2044, 0, 0, 39, '2043'),
	(243, 1, 0, -10, 2045, 0, 0, 39, '2044'),
	(243, 1, 0, -10, 2046, 0, 0, 39, '2045'),
	(243, 1, 0, -10, 2047, 0, 0, 39, '2046'),
	(243, 1, 0, -10, 2048, 0, 0, 39, '2047'),
	(243, 1, 0, -9, 1, 0, 0, 39, '0'),
	(243, 1, 0, -9, 2, 0, 0, 39, '1'),
	(243, 1, 0, -9, 3, 0, 0, 39, '2'),
	(243, 1, 0, -9, 4, 0, 0, 39, '3'),
	(243, 1, 0, -9, 5, 0, 0, 39, '4'),
	(243, 1, 0, -9, 6, 0, 0, 39, '5'),
	(243, 1, 0, -9, 7, 0, 0, 39, '6'),
	(243, 1, 0, -9, 8, 0, 0, 39, '7'),
	(243, 1, 0, -9, 9, 0, 0, 39, '8'),
	(243, 1, 0, -9, 10, 0, 0, 39, '9'),
	(243, 1, 0, -9, 11, 0, 0, 39, '10'),
	(243, 1, 0, -9, 12, 0, 0, 39, '11'),
	(243, 1, 0, -9, 13, 0, 0, 39, '12'),
	(243, 1, 0, -9, 14, 0, 0, 39, '13'),
	(243, 1, 0, -9, 15, 0, 0, 39, '14'),
	(243, 1, 0, -9, 16, 0, 0, 39, '15'),
	(243, 1, 0, -9, 17, 0, 0, 39, '16'),
	(243, 1, 0, -9, 18, 0, 0, 39, '17'),
	(243, 1, 0, -9, 19, 0, 0, 39, '18'),
	(243, 1, 0, -9, 20, 0, 0, 39, '19'),
	(243, 1, 0, -9, 21, 0, 0, 39, '20'),
	(243, 1, 0, -9, 22, 0, 0, 39, '21'),
	(243, 1, 0, -9, 23, 0, 0, 39, '22'),
	(243, 1, 0, -9, 24, 0, 0, 39, '23'),
	(243, 1, 0, -9, 25, 0, 0, 39, '24'),
	(243, 1, 0, -9, 26, 0, 0, 39, '25'),
	(243, 1, 0, -9, 27, 0, 0, 39, '26'),
	(243, 1, 0, -9, 28, 0, 0, 39, '27'),
	(243, 1, 0, -9, 29, 0, 0, 39, '28'),
	(243, 1, 0, -9, 30, 0, 0, 39, '29'),
	(243, 1, 0, -9, 31, 0, 0, 39, '30'),
	(243, 1, 0, -9, 32, 0, 0, 39, '31'),
	(243, 1, 0, -9, 33, 0, 0, 39, '32'),
	(243, 1, 0, -9, 34, 0, 0, 39, '33'),
	(243, 1, 0, -9, 35, 0, 0, 39, '34'),
	(243, 1, 0, -9, 36, 0, 0, 39, '35'),
	(243, 1, 0, -9, 37, 0, 0, 39, '36'),
	(243, 1, 0, -9, 38, 0, 0, 39, '37'),
	(243, 1, 0, -9, 39, 0, 0, 39, '38'),
	(243, 1, 0, -9, 40, 0, 0, 39, '39'),
	(243, 1, 0, -9, 41, 0, 0, 39, '40'),
	(243, 1, 0, -9, 42, 0, 0, 39, '41'),
	(243, 1, 0, -9, 43, 0, 0, 39, '42'),
	(243, 1, 0, -9, 44, 0, 0, 39, '43'),
	(243, 1, 0, -9, 45, 0, 0, 39, '44'),
	(243, 1, 0, -9, 46, 0, 0, 39, '45'),
	(243, 1, 0, -9, 47, 0, 0, 39, '46'),
	(243, 1, 0, -9, 48, 0, 0, 39, '47'),
	(243, 1, 0, -9, 49, 0, 0, 39, '48'),
	(243, 1, 0, -9, 50, 0, 0, 39, '49'),
	(243, 1, 0, -9, 51, 0, 0, 39, '50'),
	(243, 1, 0, -9, 52, 0, 0, 39, '51'),
	(243, 1, 0, -9, 53, 0, 0, 39, '52'),
	(243, 1, 0, -9, 54, 0, 0, 39, '53'),
	(243, 1, 0, -9, 55, 0, 0, 39, '54'),
	(243, 1, 0, -9, 56, 0, 0, 39, '55'),
	(243, 1, 0, -9, 57, 0, 0, 39, '56'),
	(243, 1, 0, -9, 58, 0, 0, 39, '57'),
	(243, 1, 0, -9, 59, 0, 0, 39, '58'),
	(243, 1, 0, -9, 60, 0, 0, 39, '59'),
	(243, 1, 0, -9, 61, 0, 0, 39, '60'),
	(243, 1, 0, -9, 62, 0, 0, 39, '61'),
	(243, 1, 0, -9, 63, 0, 0, 39, '62'),
	(243, 1, 0, -9, 64, 0, 0, 39, '63'),
	(243, 1, 0, -9, 65, 0, 0, 39, '64'),
	(243, 1, 0, -9, 66, 0, 0, 39, '65'),
	(243, 1, 0, -9, 67, 0, 0, 39, '66'),
	(243, 1, 0, -9, 68, 0, 0, 39, '67'),
	(243, 1, 0, -9, 69, 0, 0, 39, '68'),
	(243, 1, 0, -9, 70, 0, 0, 39, '69'),
	(243, 1, 0, -9, 71, 0, 0, 39, '70'),
	(243, 1, 0, -9, 72, 0, 0, 39, '71'),
	(243, 1, 0, -9, 73, 0, 0, 39, '72'),
	(243, 1, 0, -9, 74, 0, 0, 39, '73'),
	(243, 1, 0, -9, 75, 0, 0, 39, '74'),
	(243, 1, 0, -9, 76, 0, 0, 39, '75'),
	(243, 1, 0, -9, 77, 0, 0, 39, '76'),
	(243, 1, 0, -9, 78, 0, 0, 39, '77'),
	(243, 1, 0, -9, 79, 0, 0, 39, '78'),
	(243, 1, 0, -9, 80, 0, 0, 39, '79'),
	(243, 1, 0, -9, 81, 0, 0, 39, '80'),
	(243, 1, 0, -9, 82, 0, 0, 39, '81'),
	(243, 1, 0, -9, 83, 0, 0, 39, '82'),
	(243, 1, 0, -9, 84, 0, 0, 39, '83'),
	(243, 1, 0, -9, 85, 0, 0, 39, '84'),
	(243, 1, 0, -9, 86, 0, 0, 39, '85'),
	(243, 1, 0, -9, 87, 0, 0, 39, '86'),
	(243, 1, 0, -9, 88, 0, 0, 39, '87'),
	(243, 1, 0, -9, 89, 0, 0, 39, '88'),
	(243, 1, 0, -9, 90, 0, 0, 39, '89'),
	(243, 1, 0, -9, 91, 0, 0, 39, '90'),
	(243, 1, 0, -9, 92, 0, 0, 39, '91'),
	(243, 1, 0, -9, 93, 0, 0, 39, '92'),
	(243, 1, 0, -9, 94, 0, 0, 39, '93'),
	(243, 1, 0, -9, 95, 0, 0, 39, '94'),
	(243, 1, 0, -9, 96, 0, 0, 39, '95'),
	(243, 1, 0, -9, 97, 0, 0, 39, '96'),
	(243, 1, 0, -9, 98, 0, 0, 39, '97'),
	(243, 1, 0, -9, 99, 0, 0, 39, '98'),
	(243, 1, 0, -9, 100, 0, 0, 39, '99'),
	(243, 1, 0, -9, 101, 0, 0, 39, '100'),
	(243, 1, 0, -9, 102, 0, 0, 39, '101'),
	(243, 1, 0, -9, 103, 0, 0, 39, '102'),
	(243, 1, 0, -9, 104, 0, 0, 39, '103'),
	(243, 1, 0, -9, 105, 0, 0, 39, '104'),
	(243, 1, 0, -9, 106, 0, 0, 39, '105'),
	(243, 1, 0, -9, 107, 0, 0, 39, '106'),
	(243, 1, 0, -9, 108, 0, 0, 39, '107'),
	(243, 1, 0, -9, 109, 0, 0, 39, '108'),
	(243, 1, 0, -9, 110, 0, 0, 39, '109'),
	(243, 1, 0, -9, 111, 0, 0, 39, '110'),
	(243, 1, 0, -9, 112, 0, 0, 39, '111'),
	(243, 1, 0, -9, 113, 0, 0, 39, '112'),
	(243, 1, 0, -9, 114, 0, 0, 39, '113'),
	(243, 1, 0, -9, 115, 0, 0, 39, '114'),
	(243, 1, 0, -9, 116, 0, 0, 39, '115'),
	(243, 1, 0, -9, 117, 0, 0, 39, '116'),
	(243, 1, 0, -9, 118, 0, 0, 39, '117'),
	(243, 1, 0, -9, 119, 0, 0, 39, '118'),
	(243, 1, 0, -9, 120, 0, 0, 39, '119'),
	(243, 1, 0, -9, 121, 0, 0, 39, '120'),
	(243, 1, 0, -9, 122, 0, 0, 39, '121'),
	(243, 1, 0, -9, 123, 0, 0, 39, '122'),
	(243, 1, 0, -9, 124, 0, 0, 39, '123'),
	(243, 1, 0, -9, 125, 0, 0, 39, '124'),
	(243, 1, 0, -9, 126, 0, 0, 39, '125'),
	(243, 1, 0, -9, 127, 0, 0, 39, '126'),
	(243, 1, 0, -9, 128, 0, 0, 39, '127'),
	(243, 1, 0, -9, 129, 0, 0, 39, '128'),
	(243, 1, 0, -9, 130, 0, 0, 39, '129'),
	(243, 1, 0, -9, 131, 0, 0, 39, '130'),
	(243, 1, 0, -9, 132, 0, 0, 39, '131'),
	(243, 1, 0, -9, 133, 0, 0, 39, '132'),
	(243, 1, 0, -9, 134, 0, 0, 39, '133'),
	(243, 1, 0, -9, 135, 0, 0, 39, '134'),
	(243, 1, 0, -9, 136, 0, 0, 39, '135'),
	(243, 1, 0, -9, 137, 0, 0, 39, '136'),
	(243, 1, 0, -9, 138, 0, 0, 39, '137'),
	(243, 1, 0, -9, 139, 0, 0, 39, '138'),
	(243, 1, 0, -9, 140, 0, 0, 39, '139'),
	(243, 1, 0, -9, 141, 0, 0, 39, '140'),
	(243, 1, 0, -9, 142, 0, 0, 39, '141'),
	(243, 1, 0, -9, 143, 0, 0, 39, '142'),
	(243, 1, 0, -9, 144, 0, 0, 39, '143'),
	(243, 1, 0, -9, 145, 0, 0, 39, '144'),
	(243, 1, 0, -9, 146, 0, 0, 39, '145'),
	(243, 1, 0, -9, 147, 0, 0, 39, '146'),
	(243, 1, 0, -9, 148, 0, 0, 39, '147'),
	(243, 1, 0, -9, 149, 0, 0, 39, '148'),
	(243, 1, 0, -9, 150, 0, 0, 39, '149'),
	(243, 1, 0, -9, 151, 0, 0, 39, '150'),
	(243, 1, 0, -9, 152, 0, 0, 39, '151'),
	(243, 1, 0, -9, 153, 0, 0, 39, '152'),
	(243, 1, 0, -9, 154, 0, 0, 39, '153'),
	(243, 1, 0, -9, 155, 0, 0, 39, '154'),
	(243, 1, 0, -9, 156, 0, 0, 39, '155'),
	(243, 1, 0, -9, 157, 0, 0, 39, '156'),
	(243, 1, 0, -9, 158, 0, 0, 39, '157'),
	(243, 1, 0, -9, 159, 0, 0, 39, '158'),
	(243, 1, 0, -9, 160, 0, 0, 39, '159'),
	(243, 1, 0, -9, 161, 0, 0, 39, '160'),
	(243, 1, 0, -9, 162, 0, 0, 39, '161'),
	(243, 1, 0, -9, 163, 0, 0, 39, '162'),
	(243, 1, 0, -9, 164, 0, 0, 39, '163'),
	(243, 1, 0, -9, 165, 0, 0, 39, '164'),
	(243, 1, 0, -9, 166, 0, 0, 39, '165'),
	(243, 1, 0, -9, 167, 0, 0, 39, '166'),
	(243, 1, 0, -9, 168, 0, 0, 39, '167'),
	(243, 1, 0, -9, 169, 0, 0, 39, '168'),
	(243, 1, 0, -9, 170, 0, 0, 39, '169'),
	(243, 1, 0, -9, 171, 0, 0, 39, '170'),
	(243, 1, 0, -9, 172, 0, 0, 39, '171'),
	(243, 1, 0, -9, 173, 0, 0, 39, '172'),
	(243, 1, 0, -9, 174, 0, 0, 39, '173'),
	(243, 1, 0, -9, 175, 0, 0, 39, '174'),
	(243, 1, 0, -9, 176, 0, 0, 39, '175'),
	(243, 1, 0, -9, 177, 0, 0, 39, '176'),
	(243, 1, 0, -9, 178, 0, 0, 39, '177'),
	(243, 1, 0, -9, 179, 0, 0, 39, '178'),
	(243, 1, 0, -9, 180, 0, 0, 39, '179'),
	(243, 1, 0, -9, 181, 0, 0, 39, '180'),
	(243, 1, 0, -9, 182, 0, 0, 39, '181'),
	(243, 1, 0, -9, 183, 0, 0, 39, '182'),
	(243, 1, 0, -9, 184, 0, 0, 39, '183'),
	(243, 1, 0, -9, 185, 0, 0, 39, '184'),
	(243, 1, 0, -9, 186, 0, 0, 39, '185'),
	(243, 1, 0, -9, 187, 0, 0, 39, '186'),
	(243, 1, 0, -9, 188, 0, 0, 39, '187'),
	(243, 1, 0, -9, 189, 0, 0, 39, '188'),
	(243, 1, 0, -9, 190, 0, 0, 39, '189'),
	(243, 1, 0, -9, 191, 0, 0, 39, '190'),
	(243, 1, 0, -9, 192, 0, 0, 39, '191'),
	(243, 1, 0, -9, 193, 0, 0, 39, '192'),
	(243, 1, 0, -9, 194, 0, 0, 39, '193'),
	(243, 1, 0, -9, 195, 0, 0, 39, '194'),
	(243, 1, 0, -9, 196, 0, 0, 39, '195'),
	(243, 1, 0, -9, 197, 0, 0, 39, '196'),
	(243, 1, 0, -9, 198, 0, 0, 39, '197'),
	(243, 1, 0, -9, 199, 0, 0, 39, '198'),
	(243, 1, 0, -9, 200, 0, 0, 39, '199'),
	(243, 1, 0, -9, 201, 0, 0, 39, '200'),
	(243, 1, 0, -9, 202, 0, 0, 39, '201'),
	(243, 1, 0, -9, 203, 0, 0, 39, '202'),
	(243, 1, 0, -9, 204, 0, 0, 39, '203'),
	(243, 1, 0, -9, 205, 0, 0, 39, '204'),
	(243, 1, 0, -9, 206, 0, 0, 39, '205'),
	(243, 1, 0, -9, 207, 0, 0, 39, '206'),
	(243, 1, 0, -9, 208, 0, 0, 39, '207'),
	(243, 1, 0, -9, 209, 0, 0, 39, '208'),
	(243, 1, 0, -9, 210, 0, 0, 39, '209'),
	(243, 1, 0, -9, 211, 0, 0, 39, '210'),
	(243, 1, 0, -9, 212, 0, 0, 39, '211'),
	(243, 1, 0, -9, 213, 0, 0, 39, '212'),
	(243, 1, 0, -9, 214, 0, 0, 39, '213'),
	(243, 1, 0, -9, 215, 0, 0, 39, '214'),
	(243, 1, 0, -9, 216, 0, 0, 39, '215'),
	(243, 1, 0, -9, 217, 0, 0, 39, '216'),
	(243, 1, 0, -9, 218, 0, 0, 39, '217'),
	(243, 1, 0, -9, 219, 0, 0, 39, '218'),
	(243, 1, 0, -9, 220, 0, 0, 39, '219'),
	(243, 1, 0, -9, 221, 0, 0, 39, '220'),
	(243, 1, 0, -9, 222, 0, 0, 39, '221'),
	(243, 1, 0, -9, 223, 0, 0, 39, '222'),
	(243, 1, 0, -9, 224, 0, 0, 39, '223'),
	(243, 1, 0, -9, 225, 0, 0, 39, '224'),
	(243, 1, 0, -9, 226, 0, 0, 39, '225'),
	(243, 1, 0, -9, 227, 0, 0, 39, '226'),
	(243, 1, 0, -9, 228, 0, 0, 39, '227'),
	(243, 1, 0, -9, 229, 0, 0, 39, '228'),
	(243, 1, 0, -9, 230, 0, 0, 39, '229'),
	(243, 1, 0, -9, 231, 0, 0, 39, '230'),
	(243, 1, 0, -9, 232, 0, 0, 39, '231'),
	(243, 1, 0, -9, 233, 0, 0, 39, '232'),
	(243, 1, 0, -9, 234, 0, 0, 39, '233'),
	(243, 1, 0, -9, 235, 0, 0, 39, '234'),
	(243, 1, 0, -9, 236, 0, 0, 39, '235'),
	(243, 1, 0, -9, 237, 0, 0, 39, '236'),
	(243, 1, 0, -9, 238, 0, 0, 39, '237'),
	(243, 1, 0, -9, 239, 0, 0, 39, '238'),
	(243, 1, 0, -9, 240, 0, 0, 39, '239'),
	(243, 1, 0, -9, 241, 0, 0, 39, '240'),
	(243, 1, 0, -9, 242, 0, 0, 39, '241'),
	(243, 1, 0, -9, 243, 0, 0, 39, '242'),
	(243, 1, 0, -9, 244, 0, 0, 39, '243'),
	(243, 1, 0, -9, 245, 0, 0, 39, '244'),
	(243, 1, 0, -9, 246, 0, 0, 39, '245'),
	(243, 1, 0, -9, 247, 0, 0, 39, '246'),
	(243, 1, 0, -9, 248, 0, 0, 39, '247'),
	(243, 1, 0, -9, 249, 0, 0, 39, '248'),
	(243, 1, 0, -9, 250, 0, 0, 39, '249'),
	(243, 1, 0, -9, 251, 0, 0, 39, '250'),
	(243, 1, 0, -9, 252, 0, 0, 39, '251'),
	(243, 1, 0, -9, 253, 0, 0, 39, '252'),
	(243, 1, 0, -9, 254, 0, 0, 39, '253'),
	(243, 1, 0, -9, 255, 0, 0, 39, '254'),
	(243, 1, 0, -9, 256, 0, 0, 39, '255'),
	(243, 1, 0, -9, 257, 0, 0, 39, '256'),
	(243, 1, 0, -9, 258, 0, 0, 39, '257'),
	(243, 1, 0, -9, 259, 0, 0, 39, '258'),
	(243, 1, 0, -9, 260, 0, 0, 39, '259'),
	(243, 1, 0, -9, 261, 0, 0, 39, '260'),
	(243, 1, 0, -9, 262, 0, 0, 39, '261'),
	(243, 1, 0, -9, 263, 0, 0, 39, '262'),
	(243, 1, 0, -9, 264, 0, 0, 39, '263'),
	(243, 1, 0, -9, 265, 0, 0, 39, '264'),
	(243, 1, 0, -9, 266, 0, 0, 39, '265'),
	(243, 1, 0, -9, 267, 0, 0, 39, '266'),
	(243, 1, 0, -9, 268, 0, 0, 39, '267'),
	(243, 1, 0, -9, 269, 0, 0, 39, '268'),
	(243, 1, 0, -9, 270, 0, 0, 39, '269'),
	(243, 1, 0, -9, 271, 0, 0, 39, '270'),
	(243, 1, 0, -9, 272, 0, 0, 39, '271'),
	(243, 1, 0, -9, 273, 0, 0, 39, '272'),
	(243, 1, 0, -9, 274, 0, 0, 39, '273'),
	(243, 1, 0, -9, 275, 0, 0, 39, '274'),
	(243, 1, 0, -9, 276, 0, 0, 39, '275'),
	(243, 1, 0, -9, 277, 0, 0, 39, '276'),
	(243, 1, 0, -9, 278, 0, 0, 39, '277'),
	(243, 1, 0, -9, 279, 0, 0, 39, '278'),
	(243, 1, 0, -9, 280, 0, 0, 39, '279'),
	(243, 1, 0, -9, 281, 0, 0, 39, '280'),
	(243, 1, 0, -9, 282, 0, 0, 39, '281'),
	(243, 1, 0, -9, 283, 0, 0, 39, '282'),
	(243, 1, 0, -9, 284, 0, 0, 39, '283'),
	(243, 1, 0, -9, 285, 0, 0, 39, '284'),
	(243, 1, 0, -9, 286, 0, 0, 39, '285'),
	(243, 1, 0, -9, 287, 0, 0, 39, '286'),
	(243, 1, 0, -9, 288, 0, 0, 39, '287'),
	(243, 1, 0, -9, 289, 0, 0, 39, '288'),
	(243, 1, 0, -9, 290, 0, 0, 39, '289'),
	(243, 1, 0, -9, 291, 0, 0, 39, '290'),
	(243, 1, 0, -9, 292, 0, 0, 39, '291'),
	(243, 1, 0, -9, 293, 0, 0, 39, '292'),
	(243, 1, 0, -9, 294, 0, 0, 39, '293'),
	(243, 1, 0, -9, 295, 0, 0, 39, '294'),
	(243, 1, 0, -9, 296, 0, 0, 39, '295'),
	(243, 1, 0, -9, 297, 0, 0, 39, '296'),
	(243, 1, 0, -9, 298, 0, 0, 39, '297'),
	(243, 1, 0, -9, 299, 0, 0, 39, '298'),
	(243, 1, 0, -9, 300, 0, 0, 39, '299'),
	(243, 1, 0, -9, 301, 0, 0, 39, '300'),
	(243, 1, 0, -9, 302, 0, 0, 39, '301'),
	(243, 1, 0, -9, 303, 0, 0, 39, '302'),
	(243, 1, 0, -9, 304, 0, 0, 39, '303'),
	(243, 1, 0, -9, 305, 0, 0, 39, '304'),
	(243, 1, 0, -9, 306, 0, 0, 39, '305'),
	(243, 1, 0, -9, 307, 0, 0, 39, '306'),
	(243, 1, 0, -9, 308, 0, 0, 39, '307'),
	(243, 1, 0, -9, 309, 0, 0, 39, '308'),
	(243, 1, 0, -9, 310, 0, 0, 39, '309'),
	(243, 1, 0, -9, 311, 0, 0, 39, '310'),
	(243, 1, 0, -9, 312, 0, 0, 39, '311'),
	(243, 1, 0, -9, 313, 0, 0, 39, '312'),
	(243, 1, 0, -9, 314, 0, 0, 39, '313'),
	(243, 1, 0, -9, 315, 0, 0, 39, '314'),
	(243, 1, 0, -9, 316, 0, 0, 39, '315'),
	(243, 1, 0, -9, 317, 0, 0, 39, '316'),
	(243, 1, 0, -9, 318, 0, 0, 39, '317'),
	(243, 1, 0, -9, 319, 0, 0, 39, '318'),
	(243, 1, 0, -9, 320, 0, 0, 39, '319'),
	(243, 1, 0, -9, 321, 0, 0, 39, '320'),
	(243, 1, 0, -9, 322, 0, 0, 39, '321'),
	(243, 1, 0, -9, 323, 0, 0, 39, '322'),
	(243, 1, 0, -9, 324, 0, 0, 39, '323'),
	(243, 1, 0, -9, 325, 0, 0, 39, '324'),
	(243, 1, 0, -9, 326, 0, 0, 39, '325'),
	(243, 1, 0, -9, 327, 0, 0, 39, '326'),
	(243, 1, 0, -9, 328, 0, 0, 39, '327'),
	(243, 1, 0, -9, 329, 0, 0, 39, '328'),
	(243, 1, 0, -9, 330, 0, 0, 39, '329'),
	(243, 1, 0, -9, 331, 0, 0, 39, '330'),
	(243, 1, 0, -9, 332, 0, 0, 39, '331'),
	(243, 1, 0, -9, 333, 0, 0, 39, '332'),
	(243, 1, 0, -9, 334, 0, 0, 39, '333'),
	(243, 1, 0, -9, 335, 0, 0, 39, '334'),
	(243, 1, 0, -9, 336, 0, 0, 39, '335'),
	(243, 1, 0, -9, 337, 0, 0, 39, '336'),
	(243, 1, 0, -9, 338, 0, 0, 39, '337'),
	(243, 1, 0, -9, 339, 0, 0, 39, '338'),
	(243, 1, 0, -9, 340, 0, 0, 39, '339'),
	(243, 1, 0, -9, 341, 0, 0, 39, '340'),
	(243, 1, 0, -9, 342, 0, 0, 39, '341'),
	(243, 1, 0, -9, 343, 0, 0, 39, '342'),
	(243, 1, 0, -9, 344, 0, 0, 39, '343'),
	(243, 1, 0, -9, 345, 0, 0, 39, '344'),
	(243, 1, 0, -9, 346, 0, 0, 39, '345'),
	(243, 1, 0, -9, 347, 0, 0, 39, '346'),
	(243, 1, 0, -9, 348, 0, 0, 39, '347'),
	(243, 1, 0, -9, 349, 0, 0, 39, '348'),
	(243, 1, 0, -9, 350, 0, 0, 39, '349'),
	(243, 1, 0, -9, 351, 0, 0, 39, '350'),
	(243, 1, 0, -9, 352, 0, 0, 39, '351'),
	(243, 1, 0, -9, 353, 0, 0, 39, '352'),
	(243, 1, 0, -9, 354, 0, 0, 39, '353'),
	(243, 1, 0, -9, 355, 0, 0, 39, '354'),
	(243, 1, 0, -9, 356, 0, 0, 39, '355'),
	(243, 1, 0, -9, 357, 0, 0, 39, '356'),
	(243, 1, 0, -9, 358, 0, 0, 39, '357'),
	(243, 1, 0, -9, 359, 0, 0, 39, '358'),
	(243, 1, 0, -9, 360, 0, 0, 39, '359'),
	(243, 1, 0, -9, 361, 0, 0, 39, '360'),
	(243, 1, 0, -9, 362, 0, 0, 39, '361'),
	(243, 1, 0, -9, 363, 0, 0, 39, '362'),
	(243, 1, 0, -9, 364, 0, 0, 39, '363'),
	(243, 1, 0, -9, 365, 0, 0, 39, '364'),
	(243, 1, 0, -9, 366, 0, 0, 39, '365'),
	(243, 1, 0, -9, 367, 0, 0, 39, '366'),
	(243, 1, 0, -9, 368, 0, 0, 39, '367'),
	(243, 1, 0, -9, 369, 0, 0, 39, '368'),
	(243, 1, 0, -9, 370, 0, 0, 39, '369'),
	(243, 1, 0, -9, 371, 0, 0, 39, '370'),
	(243, 1, 0, -9, 372, 0, 0, 39, '371'),
	(243, 1, 0, -9, 373, 0, 0, 39, '372'),
	(243, 1, 0, -9, 374, 0, 0, 39, '373'),
	(243, 1, 0, -9, 375, 0, 0, 39, '374'),
	(243, 1, 0, -9, 376, 0, 0, 39, '375'),
	(243, 1, 0, -9, 377, 0, 0, 39, '376'),
	(243, 1, 0, -9, 378, 0, 0, 39, '377'),
	(243, 1, 0, -9, 379, 0, 0, 39, '378'),
	(243, 1, 0, -9, 380, 0, 0, 39, '379'),
	(243, 1, 0, -9, 381, 0, 0, 39, '380'),
	(243, 1, 0, -9, 382, 0, 0, 39, '381'),
	(243, 1, 0, -9, 383, 0, 0, 39, '382'),
	(243, 1, 0, -9, 384, 0, 0, 39, '383'),
	(243, 1, 0, -9, 385, 0, 0, 39, '384'),
	(243, 1, 0, -9, 386, 0, 0, 39, '385'),
	(243, 1, 0, -9, 387, 0, 0, 39, '386'),
	(243, 1, 0, -9, 388, 0, 0, 39, '387'),
	(243, 1, 0, -9, 389, 0, 0, 39, '388'),
	(243, 1, 0, -9, 390, 0, 0, 39, '389'),
	(243, 1, 0, -9, 391, 0, 0, 39, '390'),
	(243, 1, 0, -9, 392, 0, 0, 39, '391'),
	(243, 1, 0, -9, 393, 0, 0, 39, '392'),
	(243, 1, 0, -9, 394, 0, 0, 39, '393'),
	(243, 1, 0, -9, 395, 0, 0, 39, '394'),
	(243, 1, 0, -9, 396, 0, 0, 39, '395'),
	(243, 1, 0, -9, 397, 0, 0, 39, '396'),
	(243, 1, 0, -9, 398, 0, 0, 39, '397'),
	(243, 1, 0, -9, 399, 0, 0, 39, '398'),
	(243, 1, 0, -9, 400, 0, 0, 39, '399'),
	(243, 1, 0, -9, 401, 0, 0, 39, '400'),
	(243, 1, 0, -9, 402, 0, 0, 39, '401'),
	(243, 1, 0, -9, 403, 0, 0, 39, '402'),
	(243, 1, 0, -9, 404, 0, 0, 39, '403'),
	(243, 1, 0, -9, 405, 0, 0, 39, '404'),
	(243, 1, 0, -9, 406, 0, 0, 39, '405'),
	(243, 1, 0, -9, 407, 0, 0, 39, '406'),
	(243, 1, 0, -9, 408, 0, 0, 39, '407'),
	(243, 1, 0, -9, 409, 0, 0, 39, '408'),
	(243, 1, 0, -9, 410, 0, 0, 39, '409'),
	(243, 1, 0, -9, 411, 0, 0, 39, '410'),
	(243, 1, 0, -9, 412, 0, 0, 39, '411'),
	(243, 1, 0, -9, 413, 0, 0, 39, '412'),
	(243, 1, 0, -9, 414, 0, 0, 39, '413'),
	(243, 1, 0, -9, 415, 0, 0, 39, '414'),
	(243, 1, 0, -9, 416, 0, 0, 39, '415'),
	(243, 1, 0, -9, 417, 0, 0, 39, '416'),
	(243, 1, 0, -9, 418, 0, 0, 39, '417'),
	(243, 1, 0, -9, 419, 0, 0, 39, '418'),
	(243, 1, 0, -9, 420, 0, 0, 39, '419'),
	(243, 1, 0, -9, 421, 0, 0, 39, '420'),
	(243, 1, 0, -9, 422, 0, 0, 39, '421'),
	(243, 1, 0, -9, 423, 0, 0, 39, '422'),
	(243, 1, 0, -9, 424, 0, 0, 39, '423'),
	(243, 1, 0, -9, 425, 0, 0, 39, '424'),
	(243, 1, 0, -9, 426, 0, 0, 39, '425'),
	(243, 1, 0, -9, 427, 0, 0, 39, '426'),
	(243, 1, 0, -9, 428, 0, 0, 39, '427'),
	(243, 1, 0, -9, 429, 0, 0, 39, '428'),
	(243, 1, 0, -9, 430, 0, 0, 39, '429'),
	(243, 1, 0, -9, 431, 0, 0, 39, '430'),
	(243, 1, 0, -9, 432, 0, 0, 39, '431'),
	(243, 1, 0, -9, 433, 0, 0, 39, '432'),
	(243, 1, 0, -9, 434, 0, 0, 39, '433'),
	(243, 1, 0, -9, 435, 0, 0, 39, '434'),
	(243, 1, 0, -9, 436, 0, 0, 39, '435'),
	(243, 1, 0, -9, 437, 0, 0, 39, '436'),
	(243, 1, 0, -9, 438, 0, 0, 39, '437'),
	(243, 1, 0, -9, 439, 0, 0, 39, '438'),
	(243, 1, 0, -9, 440, 0, 0, 39, '439'),
	(243, 1, 0, -9, 441, 0, 0, 39, '440'),
	(243, 1, 0, -9, 442, 0, 0, 39, '441'),
	(243, 1, 0, -9, 443, 0, 0, 39, '442'),
	(243, 1, 0, -9, 444, 0, 0, 39, '443'),
	(243, 1, 0, -9, 445, 0, 0, 39, '444'),
	(243, 1, 0, -9, 446, 0, 0, 39, '445'),
	(243, 1, 0, -9, 447, 0, 0, 39, '446'),
	(243, 1, 0, -9, 448, 0, 0, 39, '447'),
	(243, 1, 0, -9, 449, 0, 0, 39, '448'),
	(243, 1, 0, -9, 450, 0, 0, 39, '449'),
	(243, 1, 0, -9, 451, 0, 0, 39, '450'),
	(243, 1, 0, -9, 452, 0, 0, 39, '451'),
	(243, 1, 0, -9, 453, 0, 0, 39, '452'),
	(243, 1, 0, -9, 454, 0, 0, 39, '453'),
	(243, 1, 0, -9, 455, 0, 0, 39, '454'),
	(243, 1, 0, -9, 456, 0, 0, 39, '455'),
	(243, 1, 0, -9, 457, 0, 0, 39, '456'),
	(243, 1, 0, -9, 458, 0, 0, 39, '457'),
	(243, 1, 0, -9, 459, 0, 0, 39, '458'),
	(243, 1, 0, -9, 460, 0, 0, 39, '459'),
	(243, 1, 0, -9, 461, 0, 0, 39, '460'),
	(243, 1, 0, -9, 462, 0, 0, 39, '461'),
	(243, 1, 0, -9, 463, 0, 0, 39, '462'),
	(243, 1, 0, -9, 464, 0, 0, 39, '463'),
	(243, 1, 0, -9, 465, 0, 0, 39, '464'),
	(243, 1, 0, -9, 466, 0, 0, 39, '465'),
	(243, 1, 0, -9, 467, 0, 0, 39, '466'),
	(243, 1, 0, -9, 468, 0, 0, 39, '467'),
	(243, 1, 0, -9, 469, 0, 0, 39, '468'),
	(243, 1, 0, -9, 470, 0, 0, 39, '469'),
	(243, 1, 0, -9, 471, 0, 0, 39, '470'),
	(243, 1, 0, -9, 472, 0, 0, 39, '471'),
	(243, 1, 0, -9, 473, 0, 0, 39, '472'),
	(243, 1, 0, -9, 474, 0, 0, 39, '473'),
	(243, 1, 0, -9, 475, 0, 0, 39, '474'),
	(243, 1, 0, -9, 476, 0, 0, 39, '475'),
	(243, 1, 0, -9, 477, 0, 0, 39, '476'),
	(243, 1, 0, -9, 478, 0, 0, 39, '477'),
	(243, 1, 0, -9, 479, 0, 0, 39, '478'),
	(243, 1, 0, -9, 480, 0, 0, 39, '479'),
	(243, 1, 0, -9, 481, 0, 0, 39, '480'),
	(243, 1, 0, -9, 482, 0, 0, 39, '481'),
	(243, 1, 0, -9, 483, 0, 0, 39, '482'),
	(243, 1, 0, -9, 484, 0, 0, 39, '483'),
	(243, 1, 0, -9, 485, 0, 0, 39, '484'),
	(243, 1, 0, -9, 486, 0, 0, 39, '485'),
	(243, 1, 0, -9, 487, 0, 0, 39, '486'),
	(243, 1, 0, -9, 488, 0, 0, 39, '487'),
	(243, 1, 0, -9, 489, 0, 0, 39, '488'),
	(243, 1, 0, -9, 490, 0, 0, 39, '489'),
	(243, 1, 0, -9, 491, 0, 0, 39, '490'),
	(243, 1, 0, -9, 492, 0, 0, 39, '491'),
	(243, 1, 0, -9, 493, 0, 0, 39, '492'),
	(243, 1, 0, -9, 494, 0, 0, 39, '493'),
	(243, 1, 0, -9, 495, 0, 0, 39, '494'),
	(243, 1, 0, -9, 496, 0, 0, 39, '495'),
	(243, 1, 0, -9, 497, 0, 0, 39, '496'),
	(243, 1, 0, -9, 498, 0, 0, 39, '497'),
	(243, 1, 0, -9, 499, 0, 0, 39, '498'),
	(243, 1, 0, -9, 500, 0, 0, 39, '499'),
	(243, 1, 0, -9, 501, 0, 0, 39, '500'),
	(243, 1, 0, -9, 502, 0, 0, 39, '501'),
	(243, 1, 0, -9, 503, 0, 0, 39, '502'),
	(243, 1, 0, -9, 504, 0, 0, 39, '503'),
	(243, 1, 0, -9, 505, 0, 0, 39, '504'),
	(243, 1, 0, -9, 506, 0, 0, 39, '505'),
	(243, 1, 0, -9, 507, 0, 0, 39, '506'),
	(243, 1, 0, -9, 508, 0, 0, 39, '507'),
	(243, 1, 0, -9, 509, 0, 0, 39, '508'),
	(243, 1, 0, -9, 510, 0, 0, 39, '509'),
	(243, 1, 0, -9, 511, 0, 0, 39, '510'),
	(243, 1, 0, -9, 512, 0, 0, 39, '511'),
	(243, 1, 0, -9, 513, 0, 0, 39, '512'),
	(243, 1, 0, -9, 514, 0, 0, 39, '513'),
	(243, 1, 0, -9, 515, 0, 0, 39, '514'),
	(243, 1, 0, -9, 516, 0, 0, 39, '515'),
	(243, 1, 0, -9, 517, 0, 0, 39, '516'),
	(243, 1, 0, -9, 518, 0, 0, 39, '517'),
	(243, 1, 0, -9, 519, 0, 0, 39, '518'),
	(243, 1, 0, -9, 520, 0, 0, 39, '519'),
	(243, 1, 0, -9, 521, 0, 0, 39, '520'),
	(243, 1, 0, -9, 522, 0, 0, 39, '521'),
	(243, 1, 0, -9, 523, 0, 0, 39, '522'),
	(243, 1, 0, -9, 524, 0, 0, 39, '523'),
	(243, 1, 0, -9, 525, 0, 0, 39, '524'),
	(243, 1, 0, -9, 526, 0, 0, 39, '525'),
	(243, 1, 0, -9, 527, 0, 0, 39, '526'),
	(243, 1, 0, -9, 528, 0, 0, 39, '527'),
	(243, 1, 0, -9, 529, 0, 0, 39, '528'),
	(243, 1, 0, -9, 530, 0, 0, 39, '529'),
	(243, 1, 0, -9, 531, 0, 0, 39, '530'),
	(243, 1, 0, -9, 532, 0, 0, 39, '531'),
	(243, 1, 0, -9, 533, 0, 0, 39, '532'),
	(243, 1, 0, -9, 534, 0, 0, 39, '533'),
	(243, 1, 0, -9, 535, 0, 0, 39, '534'),
	(243, 1, 0, -9, 536, 0, 0, 39, '535'),
	(243, 1, 0, -9, 537, 0, 0, 39, '536'),
	(243, 1, 0, -9, 538, 0, 0, 39, '537'),
	(243, 1, 0, -9, 539, 0, 0, 39, '538'),
	(243, 1, 0, -9, 540, 0, 0, 39, '539'),
	(243, 1, 0, -9, 541, 0, 0, 39, '540'),
	(243, 1, 0, -9, 542, 0, 0, 39, '541'),
	(243, 1, 0, -9, 543, 0, 0, 39, '542'),
	(243, 1, 0, -9, 544, 0, 0, 39, '543'),
	(243, 1, 0, -9, 545, 0, 0, 39, '544'),
	(243, 1, 0, -9, 546, 0, 0, 39, '545'),
	(243, 1, 0, -9, 547, 0, 0, 39, '546'),
	(243, 1, 0, -9, 548, 0, 0, 39, '547'),
	(243, 1, 0, -9, 549, 0, 0, 39, '548'),
	(243, 1, 0, -9, 550, 0, 0, 39, '549'),
	(243, 1, 0, -9, 551, 0, 0, 39, '550'),
	(243, 1, 0, -9, 552, 0, 0, 39, '551'),
	(243, 1, 0, -9, 553, 0, 0, 39, '552'),
	(243, 1, 0, -9, 554, 0, 0, 39, '553'),
	(243, 1, 0, -9, 555, 0, 0, 39, '554'),
	(243, 1, 0, -9, 556, 0, 0, 39, '555'),
	(243, 1, 0, -9, 557, 0, 0, 39, '556'),
	(243, 1, 0, -9, 558, 0, 0, 39, '557'),
	(243, 1, 0, -9, 559, 0, 0, 39, '558'),
	(243, 1, 0, -9, 560, 0, 0, 39, '559'),
	(243, 1, 0, -9, 561, 0, 0, 39, '560'),
	(243, 1, 0, -9, 562, 0, 0, 39, '561'),
	(243, 1, 0, -9, 563, 0, 0, 39, '562'),
	(243, 1, 0, -9, 564, 0, 0, 39, '563'),
	(243, 1, 0, -9, 565, 0, 0, 39, '564'),
	(243, 1, 0, -9, 566, 0, 0, 39, '565'),
	(243, 1, 0, -9, 567, 0, 0, 39, '566'),
	(243, 1, 0, -9, 568, 0, 0, 39, '567'),
	(243, 1, 0, -9, 569, 0, 0, 39, '568'),
	(243, 1, 0, -9, 570, 0, 0, 39, '569'),
	(243, 1, 0, -9, 571, 0, 0, 39, '570'),
	(243, 1, 0, -9, 572, 0, 0, 39, '571'),
	(243, 1, 0, -9, 573, 0, 0, 39, '572'),
	(243, 1, 0, -9, 574, 0, 0, 39, '573'),
	(243, 1, 0, -9, 575, 0, 0, 39, '574'),
	(243, 1, 0, -9, 576, 0, 0, 39, '575'),
	(243, 1, 0, -9, 577, 0, 0, 39, '576'),
	(243, 1, 0, -9, 578, 0, 0, 39, '577'),
	(243, 1, 0, -9, 579, 0, 0, 39, '578'),
	(243, 1, 0, -9, 580, 0, 0, 39, '579'),
	(243, 1, 0, -9, 581, 0, 0, 39, '580'),
	(243, 1, 0, -9, 582, 0, 0, 39, '581'),
	(243, 1, 0, -9, 583, 0, 0, 39, '582'),
	(243, 1, 0, -9, 584, 0, 0, 39, '583'),
	(243, 1, 0, -9, 585, 0, 0, 39, '584'),
	(243, 1, 0, -9, 586, 0, 0, 39, '585'),
	(243, 1, 0, -9, 587, 0, 0, 39, '586'),
	(243, 1, 0, -9, 588, 0, 0, 39, '587'),
	(243, 1, 0, -9, 589, 0, 0, 39, '588'),
	(243, 1, 0, -9, 590, 0, 0, 39, '589'),
	(243, 1, 0, -9, 591, 0, 0, 39, '590'),
	(243, 1, 0, -9, 592, 0, 0, 39, '591'),
	(243, 1, 0, -9, 593, 0, 0, 39, '592'),
	(243, 1, 0, -9, 594, 0, 0, 39, '593'),
	(243, 1, 0, -9, 595, 0, 0, 39, '594'),
	(243, 1, 0, -9, 596, 0, 0, 39, '595'),
	(243, 1, 0, -9, 597, 0, 0, 39, '596'),
	(243, 1, 0, -9, 598, 0, 0, 39, '597'),
	(243, 1, 0, -9, 599, 0, 0, 39, '598'),
	(243, 1, 0, -9, 600, 0, 0, 39, '599'),
	(243, 1, 0, -9, 601, 0, 0, 39, '600'),
	(243, 1, 0, -9, 602, 0, 0, 39, '601'),
	(243, 1, 0, -9, 603, 0, 0, 39, '602'),
	(243, 1, 0, -9, 604, 0, 0, 39, '603'),
	(243, 1, 0, -9, 605, 0, 0, 39, '604'),
	(243, 1, 0, -9, 606, 0, 0, 39, '605'),
	(243, 1, 0, -9, 607, 0, 0, 39, '606'),
	(243, 1, 0, -9, 608, 0, 0, 39, '607'),
	(243, 1, 0, -9, 609, 0, 0, 39, '608'),
	(243, 1, 0, -9, 610, 0, 0, 39, '609'),
	(243, 1, 0, -9, 611, 0, 0, 39, '610'),
	(243, 1, 0, -9, 612, 0, 0, 39, '611'),
	(243, 1, 0, -9, 613, 0, 0, 39, '612'),
	(243, 1, 0, -9, 614, 0, 0, 39, '613'),
	(243, 1, 0, -9, 615, 0, 0, 39, '614'),
	(243, 1, 0, -9, 616, 0, 0, 39, '615'),
	(243, 1, 0, -9, 617, 0, 0, 39, '616'),
	(243, 1, 0, -9, 618, 0, 0, 39, '617'),
	(243, 1, 0, -9, 619, 0, 0, 39, '618'),
	(243, 1, 0, -9, 620, 0, 0, 39, '619'),
	(243, 1, 0, -9, 621, 0, 0, 39, '620'),
	(243, 1, 0, -9, 622, 0, 0, 39, '621'),
	(243, 1, 0, -9, 623, 0, 0, 39, '622'),
	(243, 1, 0, -9, 624, 0, 0, 39, '623'),
	(243, 1, 0, -9, 625, 0, 0, 39, '624'),
	(243, 1, 0, -9, 626, 0, 0, 39, '625'),
	(243, 1, 0, -9, 627, 0, 0, 39, '626'),
	(243, 1, 0, -9, 628, 0, 0, 39, '627'),
	(243, 1, 0, -9, 629, 0, 0, 39, '628'),
	(243, 1, 0, -9, 630, 0, 0, 39, '629'),
	(243, 1, 0, -9, 631, 0, 0, 39, '630'),
	(243, 1, 0, -9, 632, 0, 0, 39, '631'),
	(243, 1, 0, -9, 633, 0, 0, 39, '632'),
	(243, 1, 0, -9, 634, 0, 0, 39, '633'),
	(243, 1, 0, -9, 635, 0, 0, 39, '634'),
	(243, 1, 0, -9, 636, 0, 0, 39, '635'),
	(243, 1, 0, -9, 637, 0, 0, 39, '636'),
	(243, 1, 0, -9, 638, 0, 0, 39, '637'),
	(243, 1, 0, -9, 639, 0, 0, 39, '638'),
	(243, 1, 0, -9, 640, 0, 0, 39, '639'),
	(243, 1, 0, -9, 641, 0, 0, 39, '640'),
	(243, 1, 0, -9, 642, 0, 0, 39, '641'),
	(243, 1, 0, -9, 643, 0, 0, 39, '642'),
	(243, 1, 0, -9, 644, 0, 0, 39, '643'),
	(243, 1, 0, -9, 645, 0, 0, 39, '644'),
	(243, 1, 0, -9, 646, 0, 0, 39, '645'),
	(243, 1, 0, -9, 647, 0, 0, 39, '646'),
	(243, 1, 0, -9, 648, 0, 0, 39, '647'),
	(243, 1, 0, -9, 649, 0, 0, 39, '648'),
	(243, 1, 0, -9, 650, 0, 0, 39, '649'),
	(243, 1, 0, -9, 651, 0, 0, 39, '650'),
	(243, 1, 0, -9, 652, 0, 0, 39, '651'),
	(243, 1, 0, -9, 653, 0, 0, 39, '652'),
	(243, 1, 0, -9, 654, 0, 0, 39, '653'),
	(243, 1, 0, -9, 655, 0, 0, 39, '654'),
	(243, 1, 0, -9, 656, 0, 0, 39, '655'),
	(243, 1, 0, -9, 657, 0, 0, 39, '656'),
	(243, 1, 0, -9, 658, 0, 0, 39, '657'),
	(243, 1, 0, -9, 659, 0, 0, 39, '658'),
	(243, 1, 0, -9, 660, 0, 0, 39, '659'),
	(243, 1, 0, -9, 661, 0, 0, 39, '660'),
	(243, 1, 0, -9, 662, 0, 0, 39, '661'),
	(243, 1, 0, -9, 663, 0, 0, 39, '662'),
	(243, 1, 0, -9, 664, 0, 0, 39, '663'),
	(243, 1, 0, -9, 665, 0, 0, 39, '664'),
	(243, 1, 0, -9, 666, 0, 0, 39, '665'),
	(243, 1, 0, -9, 667, 0, 0, 39, '666'),
	(243, 1, 0, -9, 668, 0, 0, 39, '667'),
	(243, 1, 0, -9, 669, 0, 0, 39, '668'),
	(243, 1, 0, -9, 670, 0, 0, 39, '669'),
	(243, 1, 0, -9, 671, 0, 0, 39, '670'),
	(243, 1, 0, -9, 672, 0, 0, 39, '671'),
	(243, 1, 0, -9, 673, 0, 0, 39, '672'),
	(243, 1, 0, -9, 674, 0, 0, 39, '673'),
	(243, 1, 0, -9, 675, 0, 0, 39, '674'),
	(243, 1, 0, -9, 676, 0, 0, 39, '675'),
	(243, 1, 0, -9, 677, 0, 0, 39, '676'),
	(243, 1, 0, -9, 678, 0, 0, 39, '677'),
	(243, 1, 0, -9, 679, 0, 0, 39, '678'),
	(243, 1, 0, -9, 680, 0, 0, 39, '679'),
	(243, 1, 0, -9, 681, 0, 0, 39, '680'),
	(243, 1, 0, -9, 682, 0, 0, 39, '681'),
	(243, 1, 0, -9, 683, 0, 0, 39, '682'),
	(243, 1, 0, -9, 684, 0, 0, 39, '683'),
	(243, 1, 0, -9, 685, 0, 0, 39, '684'),
	(243, 1, 0, -9, 686, 0, 0, 39, '685'),
	(243, 1, 0, -9, 687, 0, 0, 39, '686'),
	(243, 1, 0, -9, 688, 0, 0, 39, '687'),
	(243, 1, 0, -9, 689, 0, 0, 39, '688'),
	(243, 1, 0, -9, 690, 0, 0, 39, '689'),
	(243, 1, 0, -9, 691, 0, 0, 39, '690'),
	(243, 1, 0, -9, 692, 0, 0, 39, '691'),
	(243, 1, 0, -9, 693, 0, 0, 39, '692'),
	(243, 1, 0, -9, 694, 0, 0, 39, '693'),
	(243, 1, 0, -9, 695, 0, 0, 39, '694'),
	(243, 1, 0, -9, 696, 0, 0, 39, '695'),
	(243, 1, 0, -9, 697, 0, 0, 39, '696'),
	(243, 1, 0, -9, 698, 0, 0, 39, '697'),
	(243, 1, 0, -9, 699, 0, 0, 39, '698'),
	(243, 1, 0, -9, 700, 0, 0, 39, '699'),
	(243, 1, 0, -9, 701, 0, 0, 39, '700'),
	(243, 1, 0, -9, 702, 0, 0, 39, '701'),
	(243, 1, 0, -9, 703, 0, 0, 39, '702'),
	(243, 1, 0, -9, 704, 0, 0, 39, '703'),
	(243, 1, 0, -9, 705, 0, 0, 39, '704'),
	(243, 1, 0, -9, 706, 0, 0, 39, '705'),
	(243, 1, 0, -9, 707, 0, 0, 39, '706'),
	(243, 1, 0, -9, 708, 0, 0, 39, '707'),
	(243, 1, 0, -9, 709, 0, 0, 39, '708'),
	(243, 1, 0, -9, 710, 0, 0, 39, '709'),
	(243, 1, 0, -9, 711, 0, 0, 39, '710'),
	(243, 1, 0, -9, 712, 0, 0, 39, '711'),
	(243, 1, 0, -9, 713, 0, 0, 39, '712'),
	(243, 1, 0, -9, 714, 0, 0, 39, '713'),
	(243, 1, 0, -9, 715, 0, 0, 39, '714'),
	(243, 1, 0, -9, 716, 0, 0, 39, '715'),
	(243, 1, 0, -9, 717, 0, 0, 39, '716'),
	(243, 1, 0, -9, 718, 0, 0, 39, '717'),
	(243, 1, 0, -9, 719, 0, 0, 39, '718'),
	(243, 1, 0, -9, 720, 0, 0, 39, '719'),
	(243, 1, 0, -9, 721, 0, 0, 39, '720'),
	(243, 1, 0, -9, 722, 0, 0, 39, '721'),
	(243, 1, 0, -9, 723, 0, 0, 39, '722'),
	(243, 1, 0, -9, 724, 0, 0, 39, '723'),
	(243, 1, 0, -9, 725, 0, 0, 39, '724'),
	(243, 1, 0, -9, 726, 0, 0, 39, '725'),
	(243, 1, 0, -9, 727, 0, 0, 39, '726'),
	(243, 1, 0, -9, 728, 0, 0, 39, '727'),
	(243, 1, 0, -9, 729, 0, 0, 39, '728'),
	(243, 1, 0, -9, 730, 0, 0, 39, '729'),
	(243, 1, 0, -9, 731, 0, 0, 39, '730'),
	(243, 1, 0, -9, 732, 0, 0, 39, '731'),
	(243, 1, 0, -9, 733, 0, 0, 39, '732'),
	(243, 1, 0, -9, 734, 0, 0, 39, '733'),
	(243, 1, 0, -9, 735, 0, 0, 39, '734'),
	(243, 1, 0, -9, 736, 0, 0, 39, '735'),
	(243, 1, 0, -9, 737, 0, 0, 39, '736'),
	(243, 1, 0, -9, 738, 0, 0, 39, '737'),
	(243, 1, 0, -9, 739, 0, 0, 39, '738'),
	(243, 1, 0, -9, 740, 0, 0, 39, '739'),
	(243, 1, 0, -9, 741, 0, 0, 39, '740'),
	(243, 1, 0, -9, 742, 0, 0, 39, '741'),
	(243, 1, 0, -9, 743, 0, 0, 39, '742'),
	(243, 1, 0, -9, 744, 0, 0, 39, '743'),
	(243, 1, 0, -9, 745, 0, 0, 39, '744'),
	(243, 1, 0, -9, 746, 0, 0, 39, '745'),
	(243, 1, 0, -9, 747, 0, 0, 39, '746'),
	(243, 1, 0, -9, 748, 0, 0, 39, '747'),
	(243, 1, 0, -9, 749, 0, 0, 39, '748'),
	(243, 1, 0, -9, 750, 0, 0, 39, '749'),
	(243, 1, 0, -9, 751, 0, 0, 39, '750'),
	(243, 1, 0, -9, 752, 0, 0, 39, '751'),
	(243, 1, 0, -9, 753, 0, 0, 39, '752'),
	(243, 1, 0, -9, 754, 0, 0, 39, '753'),
	(243, 1, 0, -9, 755, 0, 0, 39, '754'),
	(243, 1, 0, -9, 756, 0, 0, 39, '755'),
	(243, 1, 0, -9, 757, 0, 0, 39, '756'),
	(243, 1, 0, -9, 758, 0, 0, 39, '757'),
	(243, 1, 0, -9, 759, 0, 0, 39, '758'),
	(243, 1, 0, -9, 760, 0, 0, 39, '759'),
	(243, 1, 0, -9, 761, 0, 0, 39, '760'),
	(243, 1, 0, -9, 762, 0, 0, 39, '761'),
	(243, 1, 0, -9, 763, 0, 0, 39, '762'),
	(243, 1, 0, -9, 764, 0, 0, 39, '763'),
	(243, 1, 0, -9, 765, 0, 0, 39, '764'),
	(243, 1, 0, -9, 766, 0, 0, 39, '765'),
	(243, 1, 0, -9, 767, 0, 0, 39, '766'),
	(243, 1, 0, -9, 768, 0, 0, 39, '767'),
	(243, 1, 0, -9, 769, 0, 0, 39, '768'),
	(243, 1, 0, -9, 770, 0, 0, 39, '769'),
	(243, 1, 0, -9, 771, 0, 0, 39, '770'),
	(243, 1, 0, -9, 772, 0, 0, 39, '771'),
	(243, 1, 0, -9, 773, 0, 0, 39, '772'),
	(243, 1, 0, -9, 774, 0, 0, 39, '773'),
	(243, 1, 0, -9, 775, 0, 0, 39, '774'),
	(243, 1, 0, -9, 776, 0, 0, 39, '775'),
	(243, 1, 0, -9, 777, 0, 0, 39, '776'),
	(243, 1, 0, -9, 778, 0, 0, 39, '777'),
	(243, 1, 0, -9, 779, 0, 0, 39, '778'),
	(243, 1, 0, -9, 780, 0, 0, 39, '779'),
	(243, 1, 0, -9, 781, 0, 0, 39, '780'),
	(243, 1, 0, -9, 782, 0, 0, 39, '781'),
	(243, 1, 0, -9, 783, 0, 0, 39, '782'),
	(243, 1, 0, -9, 784, 0, 0, 39, '783'),
	(243, 1, 0, -9, 785, 0, 0, 39, '784'),
	(243, 1, 0, -9, 786, 0, 0, 39, '785'),
	(243, 1, 0, -9, 787, 0, 0, 39, '786'),
	(243, 1, 0, -9, 788, 0, 0, 39, '787'),
	(243, 1, 0, -9, 789, 0, 0, 39, '788'),
	(243, 1, 0, -9, 790, 0, 0, 39, '789'),
	(243, 1, 0, -9, 791, 0, 0, 39, '790'),
	(243, 1, 0, -9, 792, 0, 0, 39, '791'),
	(243, 1, 0, -9, 793, 0, 0, 39, '792'),
	(243, 1, 0, -9, 794, 0, 0, 39, '793'),
	(243, 1, 0, -9, 795, 0, 0, 39, '794'),
	(243, 1, 0, -9, 796, 0, 0, 39, '795'),
	(243, 1, 0, -9, 797, 0, 0, 39, '796'),
	(243, 1, 0, -9, 798, 0, 0, 39, '797'),
	(243, 1, 0, -9, 799, 0, 0, 39, '798'),
	(243, 1, 0, -9, 800, 0, 0, 39, '799'),
	(243, 1, 0, -9, 801, 0, 0, 39, '800'),
	(243, 1, 0, -9, 802, 0, 0, 39, '801'),
	(243, 1, 0, -9, 803, 0, 0, 39, '802'),
	(243, 1, 0, -9, 804, 0, 0, 39, '803'),
	(243, 1, 0, -9, 805, 0, 0, 39, '804'),
	(243, 1, 0, -9, 806, 0, 0, 39, '805'),
	(243, 1, 0, -9, 807, 0, 0, 39, '806'),
	(243, 1, 0, -9, 808, 0, 0, 39, '807'),
	(243, 1, 0, -9, 809, 0, 0, 39, '808'),
	(243, 1, 0, -9, 810, 0, 0, 39, '809'),
	(243, 1, 0, -9, 811, 0, 0, 39, '810'),
	(243, 1, 0, -9, 812, 0, 0, 39, '811'),
	(243, 1, 0, -9, 813, 0, 0, 39, '812'),
	(243, 1, 0, -9, 814, 0, 0, 39, '813'),
	(243, 1, 0, -9, 815, 0, 0, 39, '814'),
	(243, 1, 0, -9, 816, 0, 0, 39, '815'),
	(243, 1, 0, -9, 817, 0, 0, 39, '816'),
	(243, 1, 0, -9, 818, 0, 0, 39, '817'),
	(243, 1, 0, -9, 819, 0, 0, 39, '818'),
	(243, 1, 0, -9, 820, 0, 0, 39, '819'),
	(243, 1, 0, -9, 821, 0, 0, 39, '820'),
	(243, 1, 0, -9, 822, 0, 0, 39, '821'),
	(243, 1, 0, -9, 823, 0, 0, 39, '822'),
	(243, 1, 0, -9, 824, 0, 0, 39, '823'),
	(243, 1, 0, -9, 825, 0, 0, 39, '824'),
	(243, 1, 0, -9, 826, 0, 0, 39, '825'),
	(243, 1, 0, -9, 827, 0, 0, 39, '826'),
	(243, 1, 0, -9, 828, 0, 0, 39, '827'),
	(243, 1, 0, -9, 829, 0, 0, 39, '828'),
	(243, 1, 0, -9, 830, 0, 0, 39, '829'),
	(243, 1, 0, -9, 831, 0, 0, 39, '830'),
	(243, 1, 0, -9, 832, 0, 0, 39, '831'),
	(243, 1, 0, -9, 833, 0, 0, 39, '832'),
	(243, 1, 0, -9, 834, 0, 0, 39, '833'),
	(243, 1, 0, -9, 835, 0, 0, 39, '834'),
	(243, 1, 0, -9, 836, 0, 0, 39, '835'),
	(243, 1, 0, -9, 837, 0, 0, 39, '836'),
	(243, 1, 0, -9, 838, 0, 0, 39, '837'),
	(243, 1, 0, -9, 839, 0, 0, 39, '838'),
	(243, 1, 0, -9, 840, 0, 0, 39, '839'),
	(243, 1, 0, -9, 841, 0, 0, 39, '840'),
	(243, 1, 0, -9, 842, 0, 0, 39, '841'),
	(243, 1, 0, -9, 843, 0, 0, 39, '842'),
	(243, 1, 0, -9, 844, 0, 0, 39, '843'),
	(243, 1, 0, -9, 845, 0, 0, 39, '844'),
	(243, 1, 0, -9, 846, 0, 0, 39, '845'),
	(243, 1, 0, -9, 847, 0, 0, 39, '846'),
	(243, 1, 0, -9, 848, 0, 0, 39, '847'),
	(243, 1, 0, -9, 849, 0, 0, 39, '848'),
	(243, 1, 0, -9, 850, 0, 0, 39, '849'),
	(243, 1, 0, -9, 851, 0, 0, 39, '850'),
	(243, 1, 0, -9, 852, 0, 0, 39, '851'),
	(243, 1, 0, -9, 853, 0, 0, 39, '852'),
	(243, 1, 0, -9, 854, 0, 0, 39, '853'),
	(243, 1, 0, -9, 855, 0, 0, 39, '854'),
	(243, 1, 0, -9, 856, 0, 0, 39, '855'),
	(243, 1, 0, -9, 857, 0, 0, 39, '856'),
	(243, 1, 0, -9, 858, 0, 0, 39, '857'),
	(243, 1, 0, -9, 859, 0, 0, 39, '858'),
	(243, 1, 0, -9, 860, 0, 0, 39, '859'),
	(243, 1, 0, -9, 861, 0, 0, 39, '860'),
	(243, 1, 0, -9, 862, 0, 0, 39, '861'),
	(243, 1, 0, -9, 863, 0, 0, 39, '862'),
	(243, 1, 0, -9, 864, 0, 0, 39, '863'),
	(243, 1, 0, -9, 865, 0, 0, 39, '864'),
	(243, 1, 0, -9, 866, 0, 0, 39, '865'),
	(243, 1, 0, -9, 867, 0, 0, 39, '866'),
	(243, 1, 0, -9, 868, 0, 0, 39, '867'),
	(243, 1, 0, -9, 869, 0, 0, 39, '868'),
	(243, 1, 0, -9, 870, 0, 0, 39, '869'),
	(243, 1, 0, -9, 871, 0, 0, 39, '870'),
	(243, 1, 0, -9, 872, 0, 0, 39, '871'),
	(243, 1, 0, -9, 873, 0, 0, 39, '872'),
	(243, 1, 0, -9, 874, 0, 0, 39, '873'),
	(243, 1, 0, -9, 875, 0, 0, 39, '874'),
	(243, 1, 0, -9, 876, 0, 0, 39, '875'),
	(243, 1, 0, -9, 877, 0, 0, 39, '876'),
	(243, 1, 0, -9, 878, 0, 0, 39, '877'),
	(243, 1, 0, -9, 879, 0, 0, 39, '878'),
	(243, 1, 0, -9, 880, 0, 0, 39, '879'),
	(243, 1, 0, -9, 881, 0, 0, 39, '880'),
	(243, 1, 0, -9, 882, 0, 0, 39, '881'),
	(243, 1, 0, -9, 883, 0, 0, 39, '882'),
	(243, 1, 0, -9, 884, 0, 0, 39, '883'),
	(243, 1, 0, -9, 885, 0, 0, 39, '884'),
	(243, 1, 0, -9, 886, 0, 0, 39, '885'),
	(243, 1, 0, -9, 887, 0, 0, 39, '886'),
	(243, 1, 0, -9, 888, 0, 0, 39, '887'),
	(243, 1, 0, -9, 889, 0, 0, 39, '888'),
	(243, 1, 0, -9, 890, 0, 0, 39, '889'),
	(243, 1, 0, -9, 891, 0, 0, 39, '890'),
	(243, 1, 0, -9, 892, 0, 0, 39, '891'),
	(243, 1, 0, -9, 893, 0, 0, 39, '892'),
	(243, 1, 0, -9, 894, 0, 0, 39, '893'),
	(243, 1, 0, -9, 895, 0, 0, 39, '894'),
	(243, 1, 0, -9, 896, 0, 0, 39, '895'),
	(243, 1, 0, -9, 897, 0, 0, 39, '896'),
	(243, 1, 0, -9, 898, 0, 0, 39, '897'),
	(243, 1, 0, -9, 899, 0, 0, 39, '898'),
	(243, 1, 0, -9, 900, 0, 0, 39, '899'),
	(243, 1, 0, -9, 901, 0, 0, 39, '900'),
	(243, 1, 0, -9, 902, 0, 0, 39, '901'),
	(243, 1, 0, -9, 903, 0, 0, 39, '902'),
	(243, 1, 0, -9, 904, 0, 0, 39, '903'),
	(243, 1, 0, -9, 905, 0, 0, 39, '904'),
	(243, 1, 0, -9, 906, 0, 0, 39, '905'),
	(243, 1, 0, -9, 907, 0, 0, 39, '906'),
	(243, 1, 0, -9, 908, 0, 0, 39, '907'),
	(243, 1, 0, -9, 909, 0, 0, 39, '908'),
	(243, 1, 0, -9, 910, 0, 0, 39, '909'),
	(243, 1, 0, -9, 911, 0, 0, 39, '910'),
	(243, 1, 0, -9, 912, 0, 0, 39, '911'),
	(243, 1, 0, -9, 913, 0, 0, 39, '912'),
	(243, 1, 0, -9, 914, 0, 0, 39, '913'),
	(243, 1, 0, -9, 915, 0, 0, 39, '914'),
	(243, 1, 0, -9, 916, 0, 0, 39, '915'),
	(243, 1, 0, -9, 917, 0, 0, 39, '916'),
	(243, 1, 0, -9, 918, 0, 0, 39, '917'),
	(243, 1, 0, -9, 919, 0, 0, 39, '918'),
	(243, 1, 0, -9, 920, 0, 0, 39, '919'),
	(243, 1, 0, -9, 921, 0, 0, 39, '920'),
	(243, 1, 0, -9, 922, 0, 0, 39, '921'),
	(243, 1, 0, -9, 923, 0, 0, 39, '922'),
	(243, 1, 0, -9, 924, 0, 0, 39, '923'),
	(243, 1, 0, -9, 925, 0, 0, 39, '924'),
	(243, 1, 0, -9, 926, 0, 0, 39, '925'),
	(243, 1, 0, -9, 927, 0, 0, 39, '926'),
	(243, 1, 0, -9, 928, 0, 0, 39, '927'),
	(243, 1, 0, -9, 929, 0, 0, 39, '928'),
	(243, 1, 0, -9, 930, 0, 0, 39, '929'),
	(243, 1, 0, -9, 931, 0, 0, 39, '930'),
	(243, 1, 0, -9, 932, 0, 0, 39, '931'),
	(243, 1, 0, -9, 933, 0, 0, 39, '932'),
	(243, 1, 0, -9, 934, 0, 0, 39, '933'),
	(243, 1, 0, -9, 935, 0, 0, 39, '934'),
	(243, 1, 0, -9, 936, 0, 0, 39, '935'),
	(243, 1, 0, -9, 937, 0, 0, 39, '936'),
	(243, 1, 0, -9, 938, 0, 0, 39, '937'),
	(243, 1, 0, -9, 939, 0, 0, 39, '938'),
	(243, 1, 0, -9, 940, 0, 0, 39, '939'),
	(243, 1, 0, -9, 941, 0, 0, 39, '940'),
	(243, 1, 0, -9, 942, 0, 0, 39, '941'),
	(243, 1, 0, -9, 943, 0, 0, 39, '942'),
	(243, 1, 0, -9, 944, 0, 0, 39, '943'),
	(243, 1, 0, -9, 945, 0, 0, 39, '944'),
	(243, 1, 0, -9, 946, 0, 0, 39, '945'),
	(243, 1, 0, -9, 947, 0, 0, 39, '946'),
	(243, 1, 0, -9, 948, 0, 0, 39, '947'),
	(243, 1, 0, -9, 949, 0, 0, 39, '948'),
	(243, 1, 0, -9, 950, 0, 0, 39, '949'),
	(243, 1, 0, -9, 951, 0, 0, 39, '950'),
	(243, 1, 0, -9, 952, 0, 0, 39, '951'),
	(243, 1, 0, -9, 953, 0, 0, 39, '952'),
	(243, 1, 0, -9, 954, 0, 0, 39, '953'),
	(243, 1, 0, -9, 955, 0, 0, 39, '954'),
	(243, 1, 0, -9, 956, 0, 0, 39, '955'),
	(243, 1, 0, -9, 957, 0, 0, 39, '956'),
	(243, 1, 0, -9, 958, 0, 0, 39, '957'),
	(243, 1, 0, -9, 959, 0, 0, 39, '958'),
	(243, 1, 0, -9, 960, 0, 0, 39, '959'),
	(243, 1, 0, -9, 961, 0, 0, 39, '960'),
	(243, 1, 0, -9, 962, 0, 0, 39, '961'),
	(243, 1, 0, -9, 963, 0, 0, 39, '962'),
	(243, 1, 0, -9, 964, 0, 0, 39, '963'),
	(243, 1, 0, -9, 965, 0, 0, 39, '964'),
	(243, 1, 0, -9, 966, 0, 0, 39, '965'),
	(243, 1, 0, -9, 967, 0, 0, 39, '966'),
	(243, 1, 0, -9, 968, 0, 0, 39, '967'),
	(243, 1, 0, -9, 969, 0, 0, 39, '968'),
	(243, 1, 0, -9, 970, 0, 0, 39, '969'),
	(243, 1, 0, -9, 971, 0, 0, 39, '970'),
	(243, 1, 0, -9, 972, 0, 0, 39, '971'),
	(243, 1, 0, -9, 973, 0, 0, 39, '972'),
	(243, 1, 0, -9, 974, 0, 0, 39, '973'),
	(243, 1, 0, -9, 975, 0, 0, 39, '974'),
	(243, 1, 0, -9, 976, 0, 0, 39, '975'),
	(243, 1, 0, -9, 977, 0, 0, 39, '976'),
	(243, 1, 0, -9, 978, 0, 0, 39, '977'),
	(243, 1, 0, -9, 979, 0, 0, 39, '978'),
	(243, 1, 0, -9, 980, 0, 0, 39, '979'),
	(243, 1, 0, -9, 981, 0, 0, 39, '980'),
	(243, 1, 0, -9, 982, 0, 0, 39, '981'),
	(243, 1, 0, -9, 983, 0, 0, 39, '982'),
	(243, 1, 0, -9, 984, 0, 0, 39, '983'),
	(243, 1, 0, -9, 985, 0, 0, 39, '984'),
	(243, 1, 0, -9, 986, 0, 0, 39, '985'),
	(243, 1, 0, -9, 987, 0, 0, 39, '986'),
	(243, 1, 0, -9, 988, 0, 0, 39, '987'),
	(243, 1, 0, -9, 989, 0, 0, 39, '988'),
	(243, 1, 0, -9, 990, 0, 0, 39, '989'),
	(243, 1, 0, -9, 991, 0, 0, 39, '990'),
	(243, 1, 0, -9, 992, 0, 0, 39, '991'),
	(243, 1, 0, -9, 993, 0, 0, 39, '992'),
	(243, 1, 0, -9, 994, 0, 0, 39, '993'),
	(243, 1, 0, -9, 995, 0, 0, 39, '994'),
	(243, 1, 0, -9, 996, 0, 0, 39, '995'),
	(243, 1, 0, -9, 997, 0, 0, 39, '996'),
	(243, 1, 0, -9, 998, 0, 0, 39, '997'),
	(243, 1, 0, -9, 999, 0, 0, 39, '998'),
	(243, 1, 0, -9, 1000, 0, 0, 39, '999'),
	(243, 1, 0, -9, 1001, 0, 0, 39, '1000'),
	(243, 1, 0, -9, 1002, 0, 0, 39, '1001'),
	(243, 1, 0, -9, 1003, 0, 0, 39, '1002'),
	(243, 1, 0, -9, 1004, 0, 0, 39, '1003'),
	(243, 1, 0, -9, 1005, 0, 0, 39, '1004'),
	(243, 1, 0, -9, 1006, 0, 0, 39, '1005'),
	(243, 1, 0, -9, 1007, 0, 0, 39, '1006'),
	(243, 1, 0, -9, 1008, 0, 0, 39, '1007'),
	(243, 1, 0, -9, 1009, 0, 0, 39, '1008'),
	(243, 1, 0, -9, 1010, 0, 0, 39, '1009'),
	(243, 1, 0, -9, 1011, 0, 0, 39, '1010'),
	(243, 1, 0, -9, 1012, 0, 0, 39, '1011'),
	(243, 1, 0, -9, 1013, 0, 0, 39, '1012'),
	(243, 1, 0, -9, 1014, 0, 0, 39, '1013'),
	(243, 1, 0, -9, 1015, 0, 0, 39, '1014'),
	(243, 1, 0, -9, 1016, 0, 0, 39, '1015'),
	(243, 1, 0, -9, 1017, 0, 0, 39, '1016'),
	(243, 1, 0, -9, 1018, 0, 0, 39, '1017'),
	(243, 1, 0, -9, 1019, 0, 0, 39, '1018'),
	(243, 1, 0, -9, 1020, 0, 0, 39, '1019'),
	(243, 1, 0, -9, 1021, 0, 0, 39, '1020'),
	(243, 1, 0, -9, 1022, 0, 0, 39, '1021'),
	(243, 1, 0, -9, 1023, 0, 0, 39, '1022'),
	(243, 1, 0, -9, 1024, 0, 0, 39, '1023'),
	(243, 1, 0, -9, 1025, 0, 0, 39, '1024'),
	(243, 1, 0, -9, 1026, 0, 0, 39, '1025'),
	(243, 1, 0, -9, 1027, 0, 0, 39, '1026'),
	(243, 1, 0, -9, 1028, 0, 0, 39, '1027'),
	(243, 1, 0, -9, 1029, 0, 0, 39, '1028'),
	(243, 1, 0, -9, 1030, 0, 0, 39, '1029'),
	(243, 1, 0, -9, 1031, 0, 0, 39, '1030'),
	(243, 1, 0, -9, 1032, 0, 0, 39, '1031'),
	(243, 1, 0, -9, 1033, 0, 0, 39, '1032'),
	(243, 1, 0, -9, 1034, 0, 0, 39, '1033'),
	(243, 1, 0, -9, 1035, 0, 0, 39, '1034'),
	(243, 1, 0, -9, 1036, 0, 0, 39, '1035'),
	(243, 1, 0, -9, 1037, 0, 0, 39, '1036'),
	(243, 1, 0, -9, 1038, 0, 0, 39, '1037'),
	(243, 1, 0, -9, 1039, 0, 0, 39, '1038'),
	(243, 1, 0, -9, 1040, 0, 0, 39, '1039'),
	(243, 1, 0, -9, 1041, 0, 0, 39, '1040'),
	(243, 1, 0, -9, 1042, 0, 0, 39, '1041'),
	(243, 1, 0, -9, 1043, 0, 0, 39, '1042'),
	(243, 1, 0, -9, 1044, 0, 0, 39, '1043'),
	(243, 1, 0, -9, 1045, 0, 0, 39, '1044'),
	(243, 1, 0, -9, 1046, 0, 0, 39, '1045'),
	(243, 1, 0, -9, 1047, 0, 0, 39, '1046'),
	(243, 1, 0, -9, 1048, 0, 0, 39, '1047'),
	(243, 1, 0, -9, 1049, 0, 0, 39, '1048'),
	(243, 1, 0, -9, 1050, 0, 0, 39, '1049'),
	(243, 1, 0, -9, 1051, 0, 0, 39, '1050'),
	(243, 1, 0, -9, 1052, 0, 0, 39, '1051'),
	(243, 1, 0, -9, 1053, 0, 0, 39, '1052'),
	(243, 1, 0, -9, 1054, 0, 0, 39, '1053'),
	(243, 1, 0, -9, 1055, 0, 0, 39, '1054'),
	(243, 1, 0, -9, 1056, 0, 0, 39, '1055'),
	(243, 1, 0, -9, 1057, 0, 0, 39, '1056'),
	(243, 1, 0, -9, 1058, 0, 0, 39, '1057'),
	(243, 1, 0, -9, 1059, 0, 0, 39, '1058'),
	(243, 1, 0, -9, 1060, 0, 0, 39, '1059'),
	(243, 1, 0, -9, 1061, 0, 0, 39, '1060'),
	(243, 1, 0, -9, 1062, 0, 0, 39, '1061'),
	(243, 1, 0, -9, 1063, 0, 0, 39, '1062'),
	(243, 1, 0, -9, 1064, 0, 0, 39, '1063'),
	(243, 1, 0, -9, 1065, 0, 0, 39, '1064'),
	(243, 1, 0, -9, 1066, 0, 0, 39, '1065'),
	(243, 1, 0, -9, 1067, 0, 0, 39, '1066'),
	(243, 1, 0, -9, 1068, 0, 0, 39, '1067'),
	(243, 1, 0, -9, 1069, 0, 0, 39, '1068'),
	(243, 1, 0, -9, 1070, 0, 0, 39, '1069'),
	(243, 1, 0, -9, 1071, 0, 0, 39, '1070'),
	(243, 1, 0, -9, 1072, 0, 0, 39, '1071'),
	(243, 1, 0, -9, 1073, 0, 0, 39, '1072'),
	(243, 1, 0, -9, 1074, 0, 0, 39, '1073'),
	(243, 1, 0, -9, 1075, 0, 0, 39, '1074'),
	(243, 1, 0, -9, 1076, 0, 0, 39, '1075'),
	(243, 1, 0, -9, 1077, 0, 0, 39, '1076'),
	(243, 1, 0, -9, 1078, 0, 0, 39, '1077'),
	(243, 1, 0, -9, 1079, 0, 0, 39, '1078'),
	(243, 1, 0, -9, 1080, 0, 0, 39, '1079'),
	(243, 1, 0, -9, 1081, 0, 0, 39, '1080'),
	(243, 1, 0, -9, 1082, 0, 0, 39, '1081'),
	(243, 1, 0, -9, 1083, 0, 0, 39, '1082'),
	(243, 1, 0, -9, 1084, 0, 0, 39, '1083'),
	(243, 1, 0, -9, 1085, 0, 0, 39, '1084'),
	(243, 1, 0, -9, 1086, 0, 0, 39, '1085'),
	(243, 1, 0, -9, 1087, 0, 0, 39, '1086'),
	(243, 1, 0, -9, 1088, 0, 0, 39, '1087'),
	(243, 1, 0, -9, 1089, 0, 0, 39, '1088'),
	(243, 1, 0, -9, 1090, 0, 0, 39, '1089'),
	(243, 1, 0, -9, 1091, 0, 0, 39, '1090'),
	(243, 1, 0, -9, 1092, 0, 0, 39, '1091'),
	(243, 1, 0, -9, 1093, 0, 0, 39, '1092'),
	(243, 1, 0, -9, 1094, 0, 0, 39, '1093'),
	(243, 1, 0, -9, 1095, 0, 0, 39, '1094'),
	(243, 1, 0, -9, 1096, 0, 0, 39, '1095'),
	(243, 1, 0, -9, 1097, 0, 0, 39, '1096'),
	(243, 1, 0, -9, 1098, 0, 0, 39, '1097'),
	(243, 1, 0, -9, 1099, 0, 0, 39, '1098'),
	(243, 1, 0, -9, 1100, 0, 0, 39, '1099'),
	(243, 1, 0, -9, 1101, 0, 0, 39, '1100'),
	(243, 1, 0, -9, 1102, 0, 0, 39, '1101'),
	(243, 1, 0, -9, 1103, 0, 0, 39, '1102'),
	(243, 1, 0, -9, 1104, 0, 0, 39, '1103'),
	(243, 1, 0, -9, 1105, 0, 0, 39, '1104'),
	(243, 1, 0, -9, 1106, 0, 0, 39, '1105'),
	(243, 1, 0, -9, 1107, 0, 0, 39, '1106'),
	(243, 1, 0, -9, 1108, 0, 0, 39, '1107'),
	(243, 1, 0, -9, 1109, 0, 0, 39, '1108'),
	(243, 1, 0, -9, 1110, 0, 0, 39, '1109'),
	(243, 1, 0, -9, 1111, 0, 0, 39, '1110'),
	(243, 1, 0, -9, 1112, 0, 0, 39, '1111'),
	(243, 1, 0, -9, 1113, 0, 0, 39, '1112'),
	(243, 1, 0, -9, 1114, 0, 0, 39, '1113'),
	(243, 1, 0, -9, 1115, 0, 0, 39, '1114'),
	(243, 1, 0, -9, 1116, 0, 0, 39, '1115'),
	(243, 1, 0, -9, 1117, 0, 0, 39, '1116'),
	(243, 1, 0, -9, 1118, 0, 0, 39, '1117'),
	(243, 1, 0, -9, 1119, 0, 0, 39, '1118'),
	(243, 1, 0, -9, 1120, 0, 0, 39, '1119'),
	(243, 1, 0, -9, 1121, 0, 0, 39, '1120'),
	(243, 1, 0, -9, 1122, 0, 0, 39, '1121'),
	(243, 1, 0, -9, 1123, 0, 0, 39, '1122'),
	(243, 1, 0, -9, 1124, 0, 0, 39, '1123'),
	(243, 1, 0, -9, 1125, 0, 0, 39, '1124'),
	(243, 1, 0, -9, 1126, 0, 0, 39, '1125'),
	(243, 1, 0, -9, 1127, 0, 0, 39, '1126'),
	(243, 1, 0, -9, 1128, 0, 0, 39, '1127'),
	(243, 1, 0, -9, 1129, 0, 0, 39, '1128'),
	(243, 1, 0, -9, 1130, 0, 0, 39, '1129'),
	(243, 1, 0, -9, 1131, 0, 0, 39, '1130'),
	(243, 1, 0, -9, 1132, 0, 0, 39, '1131'),
	(243, 1, 0, -9, 1133, 0, 0, 39, '1132'),
	(243, 1, 0, -9, 1134, 0, 0, 39, '1133'),
	(243, 1, 0, -9, 1135, 0, 0, 39, '1134'),
	(243, 1, 0, -9, 1136, 0, 0, 39, '1135'),
	(243, 1, 0, -9, 1137, 0, 0, 39, '1136'),
	(243, 1, 0, -9, 1138, 0, 0, 39, '1137'),
	(243, 1, 0, -9, 1139, 0, 0, 39, '1138'),
	(243, 1, 0, -9, 1140, 0, 0, 39, '1139'),
	(243, 1, 0, -9, 1141, 0, 0, 39, '1140'),
	(243, 1, 0, -9, 1142, 0, 0, 39, '1141'),
	(243, 1, 0, -9, 1143, 0, 0, 39, '1142'),
	(243, 1, 0, -9, 1144, 0, 0, 39, '1143'),
	(243, 1, 0, -9, 1145, 0, 0, 39, '1144'),
	(243, 1, 0, -9, 1146, 0, 0, 39, '1145'),
	(243, 1, 0, -9, 1147, 0, 0, 39, '1146'),
	(243, 1, 0, -9, 1148, 0, 0, 39, '1147'),
	(243, 1, 0, -9, 1149, 0, 0, 39, '1148'),
	(243, 1, 0, -9, 1150, 0, 0, 39, '1149'),
	(243, 1, 0, -9, 1151, 0, 0, 39, '1150'),
	(243, 1, 0, -9, 1152, 0, 0, 39, '1151'),
	(243, 1, 0, -9, 1153, 0, 0, 39, '1152'),
	(243, 1, 0, -9, 1154, 0, 0, 39, '1153'),
	(243, 1, 0, -9, 1155, 0, 0, 39, '1154'),
	(243, 1, 0, -9, 1156, 0, 0, 39, '1155'),
	(243, 1, 0, -9, 1157, 0, 0, 39, '1156'),
	(243, 1, 0, -9, 1158, 0, 0, 39, '1157'),
	(243, 1, 0, -9, 1159, 0, 0, 39, '1158'),
	(243, 1, 0, -9, 1160, 0, 0, 39, '1159'),
	(243, 1, 0, -9, 1161, 0, 0, 39, '1160'),
	(243, 1, 0, -9, 1162, 0, 0, 39, '1161'),
	(243, 1, 0, -9, 1163, 0, 0, 39, '1162'),
	(243, 1, 0, -9, 1164, 0, 0, 39, '1163'),
	(243, 1, 0, -9, 1165, 0, 0, 39, '1164'),
	(243, 1, 0, -9, 1166, 0, 0, 39, '1165'),
	(243, 1, 0, -9, 1167, 0, 0, 39, '1166'),
	(243, 1, 0, -9, 1168, 0, 0, 39, '1167'),
	(243, 1, 0, -9, 1169, 0, 0, 39, '1168'),
	(243, 1, 0, -9, 1170, 0, 0, 39, '1169'),
	(243, 1, 0, -9, 1171, 0, 0, 39, '1170'),
	(243, 1, 0, -9, 1172, 0, 0, 39, '1171'),
	(243, 1, 0, -9, 1173, 0, 0, 39, '1172'),
	(243, 1, 0, -9, 1174, 0, 0, 39, '1173'),
	(243, 1, 0, -9, 1175, 0, 0, 39, '1174'),
	(243, 1, 0, -9, 1176, 0, 0, 39, '1175'),
	(243, 1, 0, -9, 1177, 0, 0, 39, '1176'),
	(243, 1, 0, -9, 1178, 0, 0, 39, '1177'),
	(243, 1, 0, -9, 1179, 0, 0, 39, '1178'),
	(243, 1, 0, -9, 1180, 0, 0, 39, '1179'),
	(243, 1, 0, -9, 1181, 0, 0, 39, '1180'),
	(243, 1, 0, -9, 1182, 0, 0, 39, '1181'),
	(243, 1, 0, -9, 1183, 0, 0, 39, '1182'),
	(243, 1, 0, -9, 1184, 0, 0, 39, '1183'),
	(243, 1, 0, -9, 1185, 0, 0, 39, '1184'),
	(243, 1, 0, -9, 1186, 0, 0, 39, '1185'),
	(243, 1, 0, -9, 1187, 0, 0, 39, '1186'),
	(243, 1, 0, -9, 1188, 0, 0, 39, '1187'),
	(243, 1, 0, -9, 1189, 0, 0, 39, '1188'),
	(243, 1, 0, -9, 1190, 0, 0, 39, '1189'),
	(243, 1, 0, -9, 1191, 0, 0, 39, '1190'),
	(243, 1, 0, -9, 1192, 0, 0, 39, '1191'),
	(243, 1, 0, -9, 1193, 0, 0, 39, '1192'),
	(243, 1, 0, -9, 1194, 0, 0, 39, '1193'),
	(243, 1, 0, -9, 1195, 0, 0, 39, '1194'),
	(243, 1, 0, -9, 1196, 0, 0, 39, '1195'),
	(243, 1, 0, -9, 1197, 0, 0, 39, '1196'),
	(243, 1, 0, -9, 1198, 0, 0, 39, '1197'),
	(243, 1, 0, -9, 1199, 0, 0, 39, '1198'),
	(243, 1, 0, -9, 1200, 0, 0, 39, '1199'),
	(243, 1, 0, -9, 1201, 0, 0, 39, '1200'),
	(243, 1, 0, -9, 1202, 0, 0, 39, '1201'),
	(243, 1, 0, -9, 1203, 0, 0, 39, '1202'),
	(243, 1, 0, -9, 1204, 0, 0, 39, '1203'),
	(243, 1, 0, -9, 1205, 0, 0, 39, '1204'),
	(243, 1, 0, -9, 1206, 0, 0, 39, '1205'),
	(243, 1, 0, -9, 1207, 0, 0, 39, '1206'),
	(243, 1, 0, -9, 1208, 0, 0, 39, '1207'),
	(243, 1, 0, -9, 1209, 0, 0, 39, '1208'),
	(243, 1, 0, -9, 1210, 0, 0, 39, '1209'),
	(243, 1, 0, -9, 1211, 0, 0, 39, '1210'),
	(243, 1, 0, -9, 1212, 0, 0, 39, '1211'),
	(243, 1, 0, -9, 1213, 0, 0, 39, '1212'),
	(243, 1, 0, -9, 1214, 0, 0, 39, '1213'),
	(243, 1, 0, -9, 1215, 0, 0, 39, '1214'),
	(243, 1, 0, -9, 1216, 0, 0, 39, '1215'),
	(243, 1, 0, -9, 1217, 0, 0, 39, '1216'),
	(243, 1, 0, -9, 1218, 0, 0, 39, '1217'),
	(243, 1, 0, -9, 1219, 0, 0, 39, '1218'),
	(243, 1, 0, -9, 1220, 0, 0, 39, '1219'),
	(243, 1, 0, -9, 1221, 0, 0, 39, '1220'),
	(243, 1, 0, -9, 1222, 0, 0, 39, '1221'),
	(243, 1, 0, -9, 1223, 0, 0, 39, '1222'),
	(243, 1, 0, -9, 1224, 0, 0, 39, '1223'),
	(243, 1, 0, -9, 1225, 0, 0, 39, '1224'),
	(243, 1, 0, -9, 1226, 0, 0, 39, '1225'),
	(243, 1, 0, -9, 1227, 0, 0, 39, '1226'),
	(243, 1, 0, -9, 1228, 0, 0, 39, '1227'),
	(243, 1, 0, -9, 1229, 0, 0, 39, '1228'),
	(243, 1, 0, -9, 1230, 0, 0, 39, '1229'),
	(243, 1, 0, -9, 1231, 0, 0, 39, '1230'),
	(243, 1, 0, -9, 1232, 0, 0, 39, '1231'),
	(243, 1, 0, -9, 1233, 0, 0, 39, '1232'),
	(243, 1, 0, -9, 1234, 0, 0, 39, '1233'),
	(243, 1, 0, -9, 1235, 0, 0, 39, '1234'),
	(243, 1, 0, -9, 1236, 0, 0, 39, '1235'),
	(243, 1, 0, -9, 1237, 0, 0, 39, '1236'),
	(243, 1, 0, -9, 1238, 0, 0, 39, '1237'),
	(243, 1, 0, -9, 1239, 0, 0, 39, '1238'),
	(243, 1, 0, -9, 1240, 0, 0, 39, '1239'),
	(243, 1, 0, -9, 1241, 0, 0, 39, '1240'),
	(243, 1, 0, -9, 1242, 0, 0, 39, '1241'),
	(243, 1, 0, -9, 1243, 0, 0, 39, '1242'),
	(243, 1, 0, -9, 1244, 0, 0, 39, '1243'),
	(243, 1, 0, -9, 1245, 0, 0, 39, '1244'),
	(243, 1, 0, -9, 1246, 0, 0, 39, '1245'),
	(243, 1, 0, -9, 1247, 0, 0, 39, '1246'),
	(243, 1, 0, -9, 1248, 0, 0, 39, '1247'),
	(243, 1, 0, -9, 1249, 0, 0, 39, '1248'),
	(243, 1, 0, -9, 1250, 0, 0, 39, '1249'),
	(243, 1, 0, -9, 1251, 0, 0, 39, '1250'),
	(243, 1, 0, -9, 1252, 0, 0, 39, '1251'),
	(243, 1, 0, -9, 1253, 0, 0, 39, '1252'),
	(243, 1, 0, -9, 1254, 0, 0, 39, '1253'),
	(243, 1, 0, -9, 1255, 0, 0, 39, '1254'),
	(243, 1, 0, -9, 1256, 0, 0, 39, '1255'),
	(243, 1, 0, -9, 1257, 0, 0, 39, '1256'),
	(243, 1, 0, -9, 1258, 0, 0, 39, '1257'),
	(243, 1, 0, -9, 1259, 0, 0, 39, '1258'),
	(243, 1, 0, -9, 1260, 0, 0, 39, '1259'),
	(243, 1, 0, -9, 1261, 0, 0, 39, '1260'),
	(243, 1, 0, -9, 1262, 0, 0, 39, '1261'),
	(243, 1, 0, -9, 1263, 0, 0, 39, '1262'),
	(243, 1, 0, -9, 1264, 0, 0, 39, '1263'),
	(243, 1, 0, -9, 1265, 0, 0, 39, '1264'),
	(243, 1, 0, -9, 1266, 0, 0, 39, '1265'),
	(243, 1, 0, -9, 1267, 0, 0, 39, '1266'),
	(243, 1, 0, -9, 1268, 0, 0, 39, '1267'),
	(243, 1, 0, -9, 1269, 0, 0, 39, '1268'),
	(243, 1, 0, -9, 1270, 0, 0, 39, '1269'),
	(243, 1, 0, -9, 1271, 0, 0, 39, '1270'),
	(243, 1, 0, -9, 1272, 0, 0, 39, '1271'),
	(243, 1, 0, -9, 1273, 0, 0, 39, '1272'),
	(243, 1, 0, -9, 1274, 0, 0, 39, '1273'),
	(243, 1, 0, -9, 1275, 0, 0, 39, '1274'),
	(243, 1, 0, -9, 1276, 0, 0, 39, '1275'),
	(243, 1, 0, -9, 1277, 0, 0, 39, '1276'),
	(243, 1, 0, -9, 1278, 0, 0, 39, '1277'),
	(243, 1, 0, -9, 1279, 0, 0, 39, '1278'),
	(243, 1, 0, -9, 1280, 0, 0, 39, '1279'),
	(243, 1, 0, -9, 1281, 0, 0, 39, '1280'),
	(243, 1, 0, -9, 1282, 0, 0, 39, '1281'),
	(243, 1, 0, -9, 1283, 0, 0, 39, '1282'),
	(243, 1, 0, -9, 1284, 0, 0, 39, '1283'),
	(243, 1, 0, -9, 1285, 0, 0, 39, '1284'),
	(243, 1, 0, -9, 1286, 0, 0, 39, '1285'),
	(243, 1, 0, -9, 1287, 0, 0, 39, '1286'),
	(243, 1, 0, -9, 1288, 0, 0, 39, '1287'),
	(243, 1, 0, -9, 1289, 0, 0, 39, '1288'),
	(243, 1, 0, -9, 1290, 0, 0, 39, '1289'),
	(243, 1, 0, -9, 1291, 0, 0, 39, '1290'),
	(243, 1, 0, -9, 1292, 0, 0, 39, '1291'),
	(243, 1, 0, -9, 1293, 0, 0, 39, '1292'),
	(243, 1, 0, -9, 1294, 0, 0, 39, '1293'),
	(243, 1, 0, -9, 1295, 0, 0, 39, '1294'),
	(243, 1, 0, -9, 1296, 0, 0, 39, '1295'),
	(243, 1, 0, -9, 1297, 0, 0, 39, '1296'),
	(243, 1, 0, -9, 1298, 0, 0, 39, '1297'),
	(243, 1, 0, -9, 1299, 0, 0, 39, '1298'),
	(243, 1, 0, -9, 1300, 0, 0, 39, '1299'),
	(243, 1, 0, -9, 1301, 0, 0, 39, '1300'),
	(243, 1, 0, -9, 1302, 0, 0, 39, '1301'),
	(243, 1, 0, -9, 1303, 0, 0, 39, '1302'),
	(243, 1, 0, -9, 1304, 0, 0, 39, '1303'),
	(243, 1, 0, -9, 1305, 0, 0, 39, '1304'),
	(243, 1, 0, -9, 1306, 0, 0, 39, '1305'),
	(243, 1, 0, -9, 1307, 0, 0, 39, '1306'),
	(243, 1, 0, -9, 1308, 0, 0, 39, '1307'),
	(243, 1, 0, -9, 1309, 0, 0, 39, '1308'),
	(243, 1, 0, -9, 1310, 0, 0, 39, '1309'),
	(243, 1, 0, -9, 1311, 0, 0, 39, '1310'),
	(243, 1, 0, -9, 1312, 0, 0, 39, '1311'),
	(243, 1, 0, -9, 1313, 0, 0, 39, '1312'),
	(243, 1, 0, -9, 1314, 0, 0, 39, '1313'),
	(243, 1, 0, -9, 1315, 0, 0, 39, '1314'),
	(243, 1, 0, -9, 1316, 0, 0, 39, '1315'),
	(243, 1, 0, -9, 1317, 0, 0, 39, '1316'),
	(243, 1, 0, -9, 1318, 0, 0, 39, '1317'),
	(243, 1, 0, -9, 1319, 0, 0, 39, '1318'),
	(243, 1, 0, -9, 1320, 0, 0, 39, '1319'),
	(243, 1, 0, -9, 1321, 0, 0, 39, '1320'),
	(243, 1, 0, -9, 1322, 0, 0, 39, '1321'),
	(243, 1, 0, -9, 1323, 0, 0, 39, '1322'),
	(243, 1, 0, -9, 1324, 0, 0, 39, '1323'),
	(243, 1, 0, -9, 1325, 0, 0, 39, '1324'),
	(243, 1, 0, -9, 1326, 0, 0, 39, '1325'),
	(243, 1, 0, -9, 1327, 0, 0, 39, '1326'),
	(243, 1, 0, -9, 1328, 0, 0, 39, '1327'),
	(243, 1, 0, -9, 1329, 0, 0, 39, '1328'),
	(243, 1, 0, -9, 1330, 0, 0, 39, '1329'),
	(243, 1, 0, -9, 1331, 0, 0, 39, '1330'),
	(243, 1, 0, -9, 1332, 0, 0, 39, '1331'),
	(243, 1, 0, -9, 1333, 0, 0, 39, '1332'),
	(243, 1, 0, -9, 1334, 0, 0, 39, '1333'),
	(243, 1, 0, -9, 1335, 0, 0, 39, '1334'),
	(243, 1, 0, -9, 1336, 0, 0, 39, '1335'),
	(243, 1, 0, -9, 1337, 0, 0, 39, '1336'),
	(243, 1, 0, -9, 1338, 0, 0, 39, '1337'),
	(243, 1, 0, -9, 1339, 0, 0, 39, '1338'),
	(243, 1, 0, -9, 1340, 0, 0, 39, '1339'),
	(243, 1, 0, -9, 1341, 0, 0, 39, '1340'),
	(243, 1, 0, -9, 1342, 0, 0, 39, '1341'),
	(243, 1, 0, -9, 1343, 0, 0, 39, '1342'),
	(243, 1, 0, -9, 1344, 0, 0, 39, '1343'),
	(243, 1, 0, -9, 1345, 0, 0, 39, '1344'),
	(243, 1, 0, -9, 1346, 0, 0, 39, '1345'),
	(243, 1, 0, -9, 1347, 0, 0, 39, '1346'),
	(243, 1, 0, -9, 1348, 0, 0, 39, '1347'),
	(243, 1, 0, -9, 1349, 0, 0, 39, '1348'),
	(243, 1, 0, -9, 1350, 0, 0, 39, '1349'),
	(243, 1, 0, -9, 1351, 0, 0, 39, '1350'),
	(243, 1, 0, -9, 1352, 0, 0, 39, '1351'),
	(243, 1, 0, -9, 1353, 0, 0, 39, '1352'),
	(243, 1, 0, -9, 1354, 0, 0, 39, '1353'),
	(243, 1, 0, -9, 1355, 0, 0, 39, '1354'),
	(243, 1, 0, -9, 1356, 0, 0, 39, '1355'),
	(243, 1, 0, -9, 1357, 0, 0, 39, '1356'),
	(243, 1, 0, -9, 1358, 0, 0, 39, '1357'),
	(243, 1, 0, -9, 1359, 0, 0, 39, '1358'),
	(243, 1, 0, -9, 1360, 0, 0, 39, '1359'),
	(243, 1, 0, -9, 1361, 0, 0, 39, '1360'),
	(243, 1, 0, -9, 1362, 0, 0, 39, '1361'),
	(243, 1, 0, -9, 1363, 0, 0, 39, '1362'),
	(243, 1, 0, -9, 1364, 0, 0, 39, '1363'),
	(243, 1, 0, -9, 1365, 0, 0, 39, '1364'),
	(243, 1, 0, -9, 1366, 0, 0, 39, '1365'),
	(243, 1, 0, -9, 1367, 0, 0, 39, '1366'),
	(243, 1, 0, -9, 1368, 0, 0, 39, '1367'),
	(243, 1, 0, -9, 1369, 0, 0, 39, '1368'),
	(243, 1, 0, -9, 1370, 0, 0, 39, '1369'),
	(243, 1, 0, -9, 1371, 0, 0, 39, '1370'),
	(243, 1, 0, -9, 1372, 0, 0, 39, '1371'),
	(243, 1, 0, -9, 1373, 0, 0, 39, '1372'),
	(243, 1, 0, -9, 1374, 0, 0, 39, '1373'),
	(243, 1, 0, -9, 1375, 0, 0, 39, '1374'),
	(243, 1, 0, -9, 1376, 0, 0, 39, '1375'),
	(243, 1, 0, -9, 1377, 0, 0, 39, '1376'),
	(243, 1, 0, -9, 1378, 0, 0, 39, '1377'),
	(243, 1, 0, -9, 1379, 0, 0, 39, '1378'),
	(243, 1, 0, -9, 1380, 0, 0, 39, '1379'),
	(243, 1, 0, -9, 1381, 0, 0, 39, '1380'),
	(243, 1, 0, -9, 1382, 0, 0, 39, '1381'),
	(243, 1, 0, -9, 1383, 0, 0, 39, '1382'),
	(243, 1, 0, -9, 1384, 0, 0, 39, '1383'),
	(243, 1, 0, -9, 1385, 0, 0, 39, '1384'),
	(243, 1, 0, -9, 1386, 0, 0, 39, '1385'),
	(243, 1, 0, -9, 1387, 0, 0, 39, '1386'),
	(243, 1, 0, -9, 1388, 0, 0, 39, '1387'),
	(243, 1, 0, -9, 1389, 0, 0, 39, '1388'),
	(243, 1, 0, -9, 1390, 0, 0, 39, '1389'),
	(243, 1, 0, -9, 1391, 0, 0, 39, '1390'),
	(243, 1, 0, -9, 1392, 0, 0, 39, '1391'),
	(243, 1, 0, -9, 1393, 0, 0, 39, '1392'),
	(243, 1, 0, -9, 1394, 0, 0, 39, '1393'),
	(243, 1, 0, -9, 1395, 0, 0, 39, '1394'),
	(243, 1, 0, -9, 1396, 0, 0, 39, '1395'),
	(243, 1, 0, -9, 1397, 0, 0, 39, '1396'),
	(243, 1, 0, -9, 1398, 0, 0, 39, '1397'),
	(243, 1, 0, -9, 1399, 0, 0, 39, '1398'),
	(243, 1, 0, -9, 1400, 0, 0, 39, '1399'),
	(243, 1, 0, -9, 1401, 0, 0, 39, '1400'),
	(243, 1, 0, -9, 1402, 0, 0, 39, '1401'),
	(243, 1, 0, -9, 1403, 0, 0, 39, '1402'),
	(243, 1, 0, -9, 1404, 0, 0, 39, '1403'),
	(243, 1, 0, -9, 1405, 0, 0, 39, '1404'),
	(243, 1, 0, -9, 1406, 0, 0, 39, '1405'),
	(243, 1, 0, -9, 1407, 0, 0, 39, '1406'),
	(243, 1, 0, -9, 1408, 0, 0, 39, '1407'),
	(243, 1, 0, -9, 1409, 0, 0, 39, '1408'),
	(243, 1, 0, -9, 1410, 0, 0, 39, '1409'),
	(243, 1, 0, -9, 1411, 0, 0, 39, '1410'),
	(243, 1, 0, -9, 1412, 0, 0, 39, '1411'),
	(243, 1, 0, -9, 1413, 0, 0, 39, '1412'),
	(243, 1, 0, -9, 1414, 0, 0, 39, '1413'),
	(243, 1, 0, -9, 1415, 0, 0, 39, '1414'),
	(243, 1, 0, -9, 1416, 0, 0, 39, '1415'),
	(243, 1, 0, -9, 1417, 0, 0, 39, '1416'),
	(243, 1, 0, -9, 1418, 0, 0, 39, '1417'),
	(243, 1, 0, -9, 1419, 0, 0, 39, '1418'),
	(243, 1, 0, -9, 1420, 0, 0, 39, '1419'),
	(243, 1, 0, -9, 1421, 0, 0, 39, '1420'),
	(243, 1, 0, -9, 1422, 0, 0, 39, '1421'),
	(243, 1, 0, -9, 1423, 0, 0, 39, '1422'),
	(243, 1, 0, -9, 1424, 0, 0, 39, '1423'),
	(243, 1, 0, -9, 1425, 0, 0, 39, '1424'),
	(243, 1, 0, -9, 1426, 0, 0, 39, '1425'),
	(243, 1, 0, -9, 1427, 0, 0, 39, '1426'),
	(243, 1, 0, -9, 1428, 0, 0, 39, '1427'),
	(243, 1, 0, -9, 1429, 0, 0, 39, '1428'),
	(243, 1, 0, -9, 1430, 0, 0, 39, '1429'),
	(243, 1, 0, -9, 1431, 0, 0, 39, '1430'),
	(243, 1, 0, -9, 1432, 0, 0, 39, '1431'),
	(243, 1, 0, -9, 1433, 0, 0, 39, '1432'),
	(243, 1, 0, -9, 1434, 0, 0, 39, '1433'),
	(243, 1, 0, -9, 1435, 0, 0, 39, '1434'),
	(243, 1, 0, -9, 1436, 0, 0, 39, '1435'),
	(243, 1, 0, -9, 1437, 0, 0, 39, '1436'),
	(243, 1, 0, -9, 1438, 0, 0, 39, '1437'),
	(243, 1, 0, -9, 1439, 0, 0, 39, '1438'),
	(243, 1, 0, -9, 1440, 0, 0, 39, '1439'),
	(243, 1, 0, -9, 1441, 0, 0, 39, '1440'),
	(243, 1, 0, -9, 1442, 0, 0, 39, '1441'),
	(243, 1, 0, -9, 1443, 0, 0, 39, '1442'),
	(243, 1, 0, -9, 1444, 0, 0, 39, '1443'),
	(243, 1, 0, -9, 1445, 0, 0, 39, '1444'),
	(243, 1, 0, -9, 1446, 0, 0, 39, '1445'),
	(243, 1, 0, -9, 1447, 0, 0, 39, '1446'),
	(243, 1, 0, -9, 1448, 0, 0, 39, '1447'),
	(243, 1, 0, -9, 1449, 0, 0, 39, '1448'),
	(243, 1, 0, -9, 1450, 0, 0, 39, '1449'),
	(243, 1, 0, -9, 1451, 0, 0, 39, '1450'),
	(243, 1, 0, -9, 1452, 0, 0, 39, '1451'),
	(243, 1, 0, -9, 1453, 0, 0, 39, '1452'),
	(243, 1, 0, -9, 1454, 0, 0, 39, '1453'),
	(243, 1, 0, -9, 1455, 0, 0, 39, '1454'),
	(243, 1, 0, -9, 1456, 0, 0, 39, '1455'),
	(243, 1, 0, -9, 1457, 0, 0, 39, '1456'),
	(243, 1, 0, -9, 1458, 0, 0, 39, '1457'),
	(243, 1, 0, -9, 1459, 0, 0, 39, '1458'),
	(243, 1, 0, -9, 1460, 0, 0, 39, '1459'),
	(243, 1, 0, -9, 1461, 0, 0, 39, '1460'),
	(243, 1, 0, -9, 1462, 0, 0, 39, '1461'),
	(243, 1, 0, -9, 1463, 0, 0, 39, '1462'),
	(243, 1, 0, -9, 1464, 0, 0, 39, '1463'),
	(243, 1, 0, -9, 1465, 0, 0, 39, '1464'),
	(243, 1, 0, -9, 1466, 0, 0, 39, '1465'),
	(243, 1, 0, -9, 1467, 0, 0, 39, '1466'),
	(243, 1, 0, -9, 1468, 0, 0, 39, '1467'),
	(243, 1, 0, -9, 1469, 0, 0, 39, '1468'),
	(243, 1, 0, -9, 1470, 0, 0, 39, '1469'),
	(243, 1, 0, -9, 1471, 0, 0, 39, '1470'),
	(243, 1, 0, -9, 1472, 0, 0, 39, '1471'),
	(243, 1, 0, -9, 1473, 0, 0, 39, '1472'),
	(243, 1, 0, -9, 1474, 0, 0, 39, '1473'),
	(243, 1, 0, -9, 1475, 0, 0, 39, '1474'),
	(243, 1, 0, -9, 1476, 0, 0, 39, '1475'),
	(243, 1, 0, -9, 1477, 0, 0, 39, '1476'),
	(243, 1, 0, -9, 1478, 0, 0, 39, '1477'),
	(243, 1, 0, -9, 1479, 0, 0, 39, '1478'),
	(243, 1, 0, -9, 1480, 0, 0, 39, '1479'),
	(243, 1, 0, -9, 1481, 0, 0, 39, '1480'),
	(243, 1, 0, -9, 1482, 0, 0, 39, '1481'),
	(243, 1, 0, -9, 1483, 0, 0, 39, '1482'),
	(243, 1, 0, -9, 1484, 0, 0, 39, '1483'),
	(243, 1, 0, -9, 1485, 0, 0, 39, '1484'),
	(243, 1, 0, -9, 1486, 0, 0, 39, '1485'),
	(243, 1, 0, -9, 1487, 0, 0, 39, '1486'),
	(243, 1, 0, -9, 1488, 0, 0, 39, '1487'),
	(243, 1, 0, -9, 1489, 0, 0, 39, '1488'),
	(243, 1, 0, -9, 1490, 0, 0, 39, '1489'),
	(243, 1, 0, -9, 1491, 0, 0, 39, '1490'),
	(243, 1, 0, -9, 1492, 0, 0, 39, '1491'),
	(243, 1, 0, -9, 1493, 0, 0, 39, '1492'),
	(243, 1, 0, -9, 1494, 0, 0, 39, '1493'),
	(243, 1, 0, -9, 1495, 0, 0, 39, '1494'),
	(243, 1, 0, -9, 1496, 0, 0, 39, '1495'),
	(243, 1, 0, -9, 1497, 0, 0, 39, '1496'),
	(243, 1, 0, -9, 1498, 0, 0, 39, '1497'),
	(243, 1, 0, -9, 1499, 0, 0, 39, '1498'),
	(243, 1, 0, -9, 1500, 0, 0, 39, '1499'),
	(243, 1, 0, -9, 1501, 0, 0, 39, '1500'),
	(243, 1, 0, -9, 1502, 0, 0, 39, '1501'),
	(243, 1, 0, -9, 1503, 0, 0, 39, '1502'),
	(243, 1, 0, -9, 1504, 0, 0, 39, '1503'),
	(243, 1, 0, -9, 1505, 0, 0, 39, '1504'),
	(243, 1, 0, -9, 1506, 0, 0, 39, '1505'),
	(243, 1, 0, -9, 1507, 0, 0, 39, '1506'),
	(243, 1, 0, -9, 1508, 0, 0, 39, '1507'),
	(243, 1, 0, -9, 1509, 0, 0, 39, '1508'),
	(243, 1, 0, -9, 1510, 0, 0, 39, '1509'),
	(243, 1, 0, -9, 1511, 0, 0, 39, '1510'),
	(243, 1, 0, -9, 1512, 0, 0, 39, '1511'),
	(243, 1, 0, -9, 1513, 0, 0, 39, '1512'),
	(243, 1, 0, -9, 1514, 0, 0, 39, '1513'),
	(243, 1, 0, -9, 1515, 0, 0, 39, '1514'),
	(243, 1, 0, -9, 1516, 0, 0, 39, '1515'),
	(243, 1, 0, -9, 1517, 0, 0, 39, '1516'),
	(243, 1, 0, -9, 1518, 0, 0, 39, '1517'),
	(243, 1, 0, -9, 1519, 0, 0, 39, '1518'),
	(243, 1, 0, -9, 1520, 0, 0, 39, '1519'),
	(243, 1, 0, -9, 1521, 0, 0, 39, '1520'),
	(243, 1, 0, -9, 1522, 0, 0, 39, '1521'),
	(243, 1, 0, -9, 1523, 0, 0, 39, '1522'),
	(243, 1, 0, -9, 1524, 0, 0, 39, '1523'),
	(243, 1, 0, -9, 1525, 0, 0, 39, '1524'),
	(243, 1, 0, -9, 1526, 0, 0, 39, '1525'),
	(243, 1, 0, -9, 1527, 0, 0, 39, '1526'),
	(243, 1, 0, -9, 1528, 0, 0, 39, '1527'),
	(243, 1, 0, -9, 1529, 0, 0, 39, '1528'),
	(243, 1, 0, -9, 1530, 0, 0, 39, '1529'),
	(243, 1, 0, -9, 1531, 0, 0, 39, '1530'),
	(243, 1, 0, -9, 1532, 0, 0, 39, '1531'),
	(243, 1, 0, -9, 1533, 0, 0, 39, '1532'),
	(243, 1, 0, -9, 1534, 0, 0, 39, '1533'),
	(243, 1, 0, -9, 1535, 0, 0, 39, '1534'),
	(243, 1, 0, -9, 1536, 0, 0, 39, '1535'),
	(243, 1, 0, -9, 1537, 0, 0, 39, '1536'),
	(243, 1, 0, -9, 1538, 0, 0, 39, '1537'),
	(243, 1, 0, -9, 1539, 0, 0, 39, '1538'),
	(243, 1, 0, -9, 1540, 0, 0, 39, '1539'),
	(243, 1, 0, -9, 1541, 0, 0, 39, '1540'),
	(243, 1, 0, -9, 1542, 0, 0, 39, '1541'),
	(243, 1, 0, -9, 1543, 0, 0, 39, '1542'),
	(243, 1, 0, -9, 1544, 0, 0, 39, '1543'),
	(243, 1, 0, -9, 1545, 0, 0, 39, '1544'),
	(243, 1, 0, -9, 1546, 0, 0, 39, '1545'),
	(243, 1, 0, -9, 1547, 0, 0, 39, '1546'),
	(243, 1, 0, -9, 1548, 0, 0, 39, '1547'),
	(243, 1, 0, -9, 1549, 0, 0, 39, '1548'),
	(243, 1, 0, -9, 1550, 0, 0, 39, '1549'),
	(243, 1, 0, -9, 1551, 0, 0, 39, '1550'),
	(243, 1, 0, -9, 1552, 0, 0, 39, '1551'),
	(243, 1, 0, -9, 1553, 0, 0, 39, '1552'),
	(243, 1, 0, -9, 1554, 0, 0, 39, '1553'),
	(243, 1, 0, -9, 1555, 0, 0, 39, '1554'),
	(243, 1, 0, -9, 1556, 0, 0, 39, '1555'),
	(243, 1, 0, -9, 1557, 0, 0, 39, '1556'),
	(243, 1, 0, -9, 1558, 0, 0, 39, '1557'),
	(243, 1, 0, -9, 1559, 0, 0, 39, '1558'),
	(243, 1, 0, -9, 1560, 0, 0, 39, '1559'),
	(243, 1, 0, -9, 1561, 0, 0, 39, '1560'),
	(243, 1, 0, -9, 1562, 0, 0, 39, '1561'),
	(243, 1, 0, -9, 1563, 0, 0, 39, '1562'),
	(243, 1, 0, -9, 1564, 0, 0, 39, '1563'),
	(243, 1, 0, -9, 1565, 0, 0, 39, '1564'),
	(243, 1, 0, -9, 1566, 0, 0, 39, '1565'),
	(243, 1, 0, -9, 1567, 0, 0, 39, '1566'),
	(243, 1, 0, -9, 1568, 0, 0, 39, '1567'),
	(243, 1, 0, -9, 1569, 0, 0, 39, '1568'),
	(243, 1, 0, -9, 1570, 0, 0, 39, '1569'),
	(243, 1, 0, -9, 1571, 0, 0, 39, '1570'),
	(243, 1, 0, -9, 1572, 0, 0, 39, '1571'),
	(243, 1, 0, -9, 1573, 0, 0, 39, '1572'),
	(243, 1, 0, -9, 1574, 0, 0, 39, '1573'),
	(243, 1, 0, -9, 1575, 0, 0, 39, '1574'),
	(243, 1, 0, -9, 1576, 0, 0, 39, '1575'),
	(243, 1, 0, -9, 1577, 0, 0, 39, '1576'),
	(243, 1, 0, -9, 1578, 0, 0, 39, '1577'),
	(243, 1, 0, -9, 1579, 0, 0, 39, '1578'),
	(243, 1, 0, -9, 1580, 0, 0, 39, '1579'),
	(243, 1, 0, -9, 1581, 0, 0, 39, '1580'),
	(243, 1, 0, -9, 1582, 0, 0, 39, '1581'),
	(243, 1, 0, -9, 1583, 0, 0, 39, '1582'),
	(243, 1, 0, -9, 1584, 0, 0, 39, '1583'),
	(243, 1, 0, -9, 1585, 0, 0, 39, '1584'),
	(243, 1, 0, -9, 1586, 0, 0, 39, '1585'),
	(243, 1, 0, -9, 1587, 0, 0, 39, '1586'),
	(243, 1, 0, -9, 1588, 0, 0, 39, '1587'),
	(243, 1, 0, -9, 1589, 0, 0, 39, '1588'),
	(243, 1, 0, -9, 1590, 0, 0, 39, '1589'),
	(243, 1, 0, -9, 1591, 0, 0, 39, '1590'),
	(243, 1, 0, -9, 1592, 0, 0, 39, '1591'),
	(243, 1, 0, -9, 1593, 0, 0, 39, '1592'),
	(243, 1, 0, -9, 1594, 0, 0, 39, '1593'),
	(243, 1, 0, -9, 1595, 0, 0, 39, '1594'),
	(243, 1, 0, -9, 1596, 0, 0, 39, '1595'),
	(243, 1, 0, -9, 1597, 0, 0, 39, '1596'),
	(243, 1, 0, -9, 1598, 0, 0, 39, '1597'),
	(243, 1, 0, -9, 1599, 0, 0, 39, '1598'),
	(243, 1, 0, -9, 1600, 0, 0, 39, '1599'),
	(243, 1, 0, -9, 1601, 0, 0, 39, '1600'),
	(243, 1, 0, -9, 1602, 0, 0, 39, '1601'),
	(243, 1, 0, -9, 1603, 0, 0, 39, '1602'),
	(243, 1, 0, -9, 1604, 0, 0, 39, '1603'),
	(243, 1, 0, -9, 1605, 0, 0, 39, '1604'),
	(243, 1, 0, -9, 1606, 0, 0, 39, '1605'),
	(243, 1, 0, -9, 1607, 0, 0, 39, '1606'),
	(243, 1, 0, -9, 1608, 0, 0, 39, '1607'),
	(243, 1, 0, -9, 1609, 0, 0, 39, '1608'),
	(243, 1, 0, -9, 1610, 0, 0, 39, '1609'),
	(243, 1, 0, -9, 1611, 0, 0, 39, '1610'),
	(243, 1, 0, -9, 1612, 0, 0, 39, '1611'),
	(243, 1, 0, -9, 1613, 0, 0, 39, '1612'),
	(243, 1, 0, -9, 1614, 0, 0, 39, '1613'),
	(243, 1, 0, -9, 1615, 0, 0, 39, '1614'),
	(243, 1, 0, -9, 1616, 0, 0, 39, '1615'),
	(243, 1, 0, -9, 1617, 0, 0, 39, '1616'),
	(243, 1, 0, -9, 1618, 0, 0, 39, '1617'),
	(243, 1, 0, -9, 1619, 0, 0, 39, '1618'),
	(243, 1, 0, -9, 1620, 0, 0, 39, '1619'),
	(243, 1, 0, -9, 1621, 0, 0, 39, '1620'),
	(243, 1, 0, -9, 1622, 0, 0, 39, '1621'),
	(243, 1, 0, -9, 1623, 0, 0, 39, '1622'),
	(243, 1, 0, -9, 1624, 0, 0, 39, '1623'),
	(243, 1, 0, -9, 1625, 0, 0, 39, '1624'),
	(243, 1, 0, -9, 1626, 0, 0, 39, '1625'),
	(243, 1, 0, -9, 1627, 0, 0, 39, '1626'),
	(243, 1, 0, -9, 1628, 0, 0, 39, '1627'),
	(243, 1, 0, -9, 1629, 0, 0, 39, '1628'),
	(243, 1, 0, -9, 1630, 0, 0, 39, '1629'),
	(243, 1, 0, -9, 1631, 0, 0, 39, '1630'),
	(243, 1, 0, -9, 1632, 0, 0, 39, '1631'),
	(243, 1, 0, -9, 1633, 0, 0, 39, '1632'),
	(243, 1, 0, -9, 1634, 0, 0, 39, '1633'),
	(243, 1, 0, -9, 1635, 0, 0, 39, '1634'),
	(243, 1, 0, -9, 1636, 0, 0, 39, '1635'),
	(243, 1, 0, -9, 1637, 0, 0, 39, '1636'),
	(243, 1, 0, -9, 1638, 0, 0, 39, '1637'),
	(243, 1, 0, -9, 1639, 0, 0, 39, '1638'),
	(243, 1, 0, -9, 1640, 0, 0, 39, '1639'),
	(243, 1, 0, -9, 1641, 0, 0, 39, '1640'),
	(243, 1, 0, -9, 1642, 0, 0, 39, '1641'),
	(243, 1, 0, -9, 1643, 0, 0, 39, '1642'),
	(243, 1, 0, -9, 1644, 0, 0, 39, '1643'),
	(243, 1, 0, -9, 1645, 0, 0, 39, '1644'),
	(243, 1, 0, -9, 1646, 0, 0, 39, '1645'),
	(243, 1, 0, -9, 1647, 0, 0, 39, '1646'),
	(243, 1, 0, -9, 1648, 0, 0, 39, '1647'),
	(243, 1, 0, -9, 1649, 0, 0, 39, '1648'),
	(243, 1, 0, -9, 1650, 0, 0, 39, '1649'),
	(243, 1, 0, -9, 1651, 0, 0, 39, '1650'),
	(243, 1, 0, -9, 1652, 0, 0, 39, '1651'),
	(243, 1, 0, -9, 1653, 0, 0, 39, '1652'),
	(243, 1, 0, -9, 1654, 0, 0, 39, '1653'),
	(243, 1, 0, -9, 1655, 0, 0, 39, '1654'),
	(243, 1, 0, -9, 1656, 0, 0, 39, '1655'),
	(243, 1, 0, -9, 1657, 0, 0, 39, '1656'),
	(243, 1, 0, -9, 1658, 0, 0, 39, '1657'),
	(243, 1, 0, -9, 1659, 0, 0, 39, '1658'),
	(243, 1, 0, -9, 1660, 0, 0, 39, '1659'),
	(243, 1, 0, -9, 1661, 0, 0, 39, '1660'),
	(243, 1, 0, -9, 1662, 0, 0, 39, '1661'),
	(243, 1, 0, -9, 1663, 0, 0, 39, '1662'),
	(243, 1, 0, -9, 1664, 0, 0, 39, '1663'),
	(243, 1, 0, -9, 1665, 0, 0, 39, '1664'),
	(243, 1, 0, -9, 1666, 0, 0, 39, '1665'),
	(243, 1, 0, -9, 1667, 0, 0, 39, '1666'),
	(243, 1, 0, -9, 1668, 0, 0, 39, '1667'),
	(243, 1, 0, -9, 1669, 0, 0, 39, '1668'),
	(243, 1, 0, -9, 1670, 0, 0, 39, '1669'),
	(243, 1, 0, -9, 1671, 0, 0, 39, '1670'),
	(243, 1, 0, -9, 1672, 0, 0, 39, '1671'),
	(243, 1, 0, -9, 1673, 0, 0, 39, '1672'),
	(243, 1, 0, -9, 1674, 0, 0, 39, '1673'),
	(243, 1, 0, -9, 1675, 0, 0, 39, '1674'),
	(243, 1, 0, -9, 1676, 0, 0, 39, '1675'),
	(243, 1, 0, -9, 1677, 0, 0, 39, '1676'),
	(243, 1, 0, -9, 1678, 0, 0, 39, '1677'),
	(243, 1, 0, -9, 1679, 0, 0, 39, '1678'),
	(243, 1, 0, -9, 1680, 0, 0, 39, '1679'),
	(243, 1, 0, -9, 1681, 0, 0, 39, '1680'),
	(243, 1, 0, -9, 1682, 0, 0, 39, '1681'),
	(243, 1, 0, -9, 1683, 0, 0, 39, '1682'),
	(243, 1, 0, -9, 1684, 0, 0, 39, '1683'),
	(243, 1, 0, -9, 1685, 0, 0, 39, '1684'),
	(243, 1, 0, -9, 1686, 0, 0, 39, '1685'),
	(243, 1, 0, -9, 1687, 0, 0, 39, '1686'),
	(243, 1, 0, -9, 1688, 0, 0, 39, '1687'),
	(243, 1, 0, -9, 1689, 0, 0, 39, '1688'),
	(243, 1, 0, -9, 1690, 0, 0, 39, '1689'),
	(243, 1, 0, -9, 1691, 0, 0, 39, '1690'),
	(243, 1, 0, -9, 1692, 0, 0, 39, '1691'),
	(243, 1, 0, -9, 1693, 0, 0, 39, '1692'),
	(243, 1, 0, -9, 1694, 0, 0, 39, '1693'),
	(243, 1, 0, -9, 1695, 0, 0, 39, '1694'),
	(243, 1, 0, -9, 1696, 0, 0, 39, '1695'),
	(243, 1, 0, -9, 1697, 0, 0, 39, '1696'),
	(243, 1, 0, -9, 1698, 0, 0, 39, '1697'),
	(243, 1, 0, -9, 1699, 0, 0, 39, '1698'),
	(243, 1, 0, -9, 1700, 0, 0, 39, '1699'),
	(243, 1, 0, -9, 1701, 0, 0, 39, '1700'),
	(243, 1, 0, -9, 1702, 0, 0, 39, '1701'),
	(243, 1, 0, -9, 1703, 0, 0, 39, '1702'),
	(243, 1, 0, -9, 1704, 0, 0, 39, '1703'),
	(243, 1, 0, -9, 1705, 0, 0, 39, '1704'),
	(243, 1, 0, -9, 1706, 0, 0, 39, '1705'),
	(243, 1, 0, -9, 1707, 0, 0, 39, '1706'),
	(243, 1, 0, -9, 1708, 0, 0, 39, '1707'),
	(243, 1, 0, -9, 1709, 0, 0, 39, '1708'),
	(243, 1, 0, -9, 1710, 0, 0, 39, '1709'),
	(243, 1, 0, -9, 1711, 0, 0, 39, '1710'),
	(243, 1, 0, -9, 1712, 0, 0, 39, '1711'),
	(243, 1, 0, -9, 1713, 0, 0, 39, '1712'),
	(243, 1, 0, -9, 1714, 0, 0, 39, '1713'),
	(243, 1, 0, -9, 1715, 0, 0, 39, '1714'),
	(243, 1, 0, -9, 1716, 0, 0, 39, '1715'),
	(243, 1, 0, -9, 1717, 0, 0, 39, '1716'),
	(243, 1, 0, -9, 1718, 0, 0, 39, '1717'),
	(243, 1, 0, -9, 1719, 0, 0, 39, '1718'),
	(243, 1, 0, -9, 1720, 0, 0, 39, '1719'),
	(243, 1, 0, -9, 1721, 0, 0, 39, '1720'),
	(243, 1, 0, -9, 1722, 0, 0, 39, '1721'),
	(243, 1, 0, -9, 1723, 0, 0, 39, '1722'),
	(243, 1, 0, -9, 1724, 0, 0, 39, '1723'),
	(243, 1, 0, -9, 1725, 0, 0, 39, '1724'),
	(243, 1, 0, -9, 1726, 0, 0, 39, '1725'),
	(243, 1, 0, -9, 1727, 0, 0, 39, '1726'),
	(243, 1, 0, -9, 1728, 0, 0, 39, '1727'),
	(243, 1, 0, -9, 1729, 0, 0, 39, '1728'),
	(243, 1, 0, -9, 1730, 0, 0, 39, '1729'),
	(243, 1, 0, -9, 1731, 0, 0, 39, '1730'),
	(243, 1, 0, -9, 1732, 0, 0, 39, '1731'),
	(243, 1, 0, -9, 1733, 0, 0, 39, '1732'),
	(243, 1, 0, -9, 1734, 0, 0, 39, '1733'),
	(243, 1, 0, -9, 1735, 0, 0, 39, '1734'),
	(243, 1, 0, -9, 1736, 0, 0, 39, '1735'),
	(243, 1, 0, -9, 1737, 0, 0, 39, '1736'),
	(243, 1, 0, -9, 1738, 0, 0, 39, '1737'),
	(243, 1, 0, -9, 1739, 0, 0, 39, '1738'),
	(243, 1, 0, -9, 1740, 0, 0, 39, '1739'),
	(243, 1, 0, -9, 1741, 0, 0, 39, '1740'),
	(243, 1, 0, -9, 1742, 0, 0, 39, '1741'),
	(243, 1, 0, -9, 1743, 0, 0, 39, '1742'),
	(243, 1, 0, -9, 1744, 0, 0, 39, '1743'),
	(243, 1, 0, -9, 1745, 0, 0, 39, '1744'),
	(243, 1, 0, -9, 1746, 0, 0, 39, '1745'),
	(243, 1, 0, -9, 1747, 0, 0, 39, '1746'),
	(243, 1, 0, -9, 1748, 0, 0, 39, '1747'),
	(243, 1, 0, -9, 1749, 0, 0, 39, '1748'),
	(243, 1, 0, -9, 1750, 0, 0, 39, '1749'),
	(243, 1, 0, -9, 1751, 0, 0, 39, '1750'),
	(243, 1, 0, -9, 1752, 0, 0, 39, '1751'),
	(243, 1, 0, -9, 1753, 0, 0, 39, '1752'),
	(243, 1, 0, -9, 1754, 0, 0, 39, '1753'),
	(243, 1, 0, -9, 1755, 0, 0, 39, '1754'),
	(243, 1, 0, -9, 1756, 0, 0, 39, '1755'),
	(243, 1, 0, -9, 1757, 0, 0, 39, '1756'),
	(243, 1, 0, -9, 1758, 0, 0, 39, '1757'),
	(243, 1, 0, -9, 1759, 0, 0, 39, '1758'),
	(243, 1, 0, -9, 1760, 0, 0, 39, '1759'),
	(243, 1, 0, -9, 1761, 0, 0, 39, '1760'),
	(243, 1, 0, -9, 1762, 0, 0, 39, '1761'),
	(243, 1, 0, -9, 1763, 0, 0, 39, '1762'),
	(243, 1, 0, -9, 1764, 0, 0, 39, '1763'),
	(243, 1, 0, -9, 1765, 0, 0, 39, '1764'),
	(243, 1, 0, -9, 1766, 0, 0, 39, '1765'),
	(243, 1, 0, -9, 1767, 0, 0, 39, '1766'),
	(243, 1, 0, -9, 1768, 0, 0, 39, '1767'),
	(243, 1, 0, -9, 1769, 0, 0, 39, '1768'),
	(243, 1, 0, -9, 1770, 0, 0, 39, '1769'),
	(243, 1, 0, -9, 1771, 0, 0, 39, '1770'),
	(243, 1, 0, -9, 1772, 0, 0, 39, '1771'),
	(243, 1, 0, -9, 1773, 0, 0, 39, '1772'),
	(243, 1, 0, -9, 1774, 0, 0, 39, '1773'),
	(243, 1, 0, -9, 1775, 0, 0, 39, '1774'),
	(243, 1, 0, -9, 1776, 0, 0, 39, '1775'),
	(243, 1, 0, -9, 1777, 0, 0, 39, '1776'),
	(243, 1, 0, -9, 1778, 0, 0, 39, '1777'),
	(243, 1, 0, -9, 1779, 0, 0, 39, '1778'),
	(243, 1, 0, -9, 1780, 0, 0, 39, '1779'),
	(243, 1, 0, -9, 1781, 0, 0, 39, '1780'),
	(243, 1, 0, -9, 1782, 0, 0, 39, '1781'),
	(243, 1, 0, -9, 1783, 0, 0, 39, '1782'),
	(243, 1, 0, -9, 1784, 0, 0, 39, '1783'),
	(243, 1, 0, -9, 1785, 0, 0, 39, '1784'),
	(243, 1, 0, -9, 1786, 0, 0, 39, '1785'),
	(243, 1, 0, -9, 1787, 0, 0, 39, '1786'),
	(243, 1, 0, -9, 1788, 0, 0, 39, '1787'),
	(243, 1, 0, -9, 1789, 0, 0, 39, '1788'),
	(243, 1, 0, -9, 1790, 0, 0, 39, '1789'),
	(243, 1, 0, -9, 1791, 0, 0, 39, '1790'),
	(243, 1, 0, -9, 1792, 0, 0, 39, '1791'),
	(243, 1, 0, -9, 1793, 0, 0, 39, '1792'),
	(243, 1, 0, -9, 1794, 0, 0, 39, '1793'),
	(243, 1, 0, -9, 1795, 0, 0, 39, '1794'),
	(243, 1, 0, -9, 1796, 0, 0, 39, '1795'),
	(243, 1, 0, -9, 1797, 0, 0, 39, '1796'),
	(243, 1, 0, -9, 1798, 0, 0, 39, '1797'),
	(243, 1, 0, -9, 1799, 0, 0, 39, '1798'),
	(243, 1, 0, -9, 1800, 0, 0, 39, '1799'),
	(243, 1, 0, -9, 1801, 0, 0, 39, '1800'),
	(243, 1, 0, -9, 1802, 0, 0, 39, '1801'),
	(243, 1, 0, -9, 1803, 0, 0, 39, '1802'),
	(243, 1, 0, -9, 1804, 0, 0, 39, '1803'),
	(243, 1, 0, -9, 1805, 0, 0, 39, '1804'),
	(243, 1, 0, -9, 1806, 0, 0, 39, '1805'),
	(243, 1, 0, -9, 1807, 0, 0, 39, '1806'),
	(243, 1, 0, -9, 1808, 0, 0, 39, '1807'),
	(243, 1, 0, -9, 1809, 0, 0, 39, '1808'),
	(243, 1, 0, -9, 1810, 0, 0, 39, '1809'),
	(243, 1, 0, -9, 1811, 0, 0, 39, '1810'),
	(243, 1, 0, -9, 1812, 0, 0, 39, '1811'),
	(243, 1, 0, -9, 1813, 0, 0, 39, '1812'),
	(243, 1, 0, -9, 1814, 0, 0, 39, '1813'),
	(243, 1, 0, -9, 1815, 0, 0, 39, '1814'),
	(243, 1, 0, -9, 1816, 0, 0, 39, '1815'),
	(243, 1, 0, -9, 1817, 0, 0, 39, '1816'),
	(243, 1, 0, -9, 1818, 0, 0, 39, '1817'),
	(243, 1, 0, -9, 1819, 0, 0, 39, '1818'),
	(243, 1, 0, -9, 1820, 0, 0, 39, '1819'),
	(243, 1, 0, -9, 1821, 0, 0, 39, '1820'),
	(243, 1, 0, -9, 1822, 0, 0, 39, '1821'),
	(243, 1, 0, -9, 1823, 0, 0, 39, '1822'),
	(243, 1, 0, -9, 1824, 0, 0, 39, '1823'),
	(243, 1, 0, -9, 1825, 0, 0, 39, '1824'),
	(243, 1, 0, -9, 1826, 0, 0, 39, '1825'),
	(243, 1, 0, -9, 1827, 0, 0, 39, '1826'),
	(243, 1, 0, -9, 1828, 0, 0, 39, '1827'),
	(243, 1, 0, -9, 1829, 0, 0, 39, '1828'),
	(243, 1, 0, -9, 1830, 0, 0, 39, '1829'),
	(243, 1, 0, -9, 1831, 0, 0, 39, '1830'),
	(243, 1, 0, -9, 1832, 0, 0, 39, '1831'),
	(243, 1, 0, -9, 1833, 0, 0, 39, '1832'),
	(243, 1, 0, -9, 1834, 0, 0, 39, '1833'),
	(243, 1, 0, -9, 1835, 0, 0, 39, '1834'),
	(243, 1, 0, -9, 1836, 0, 0, 39, '1835'),
	(243, 1, 0, -9, 1837, 0, 0, 39, '1836'),
	(243, 1, 0, -9, 1838, 0, 0, 39, '1837'),
	(243, 1, 0, -9, 1839, 0, 0, 39, '1838'),
	(243, 1, 0, -9, 1840, 0, 0, 39, '1839'),
	(243, 1, 0, -9, 1841, 0, 0, 39, '1840'),
	(243, 1, 0, -9, 1842, 0, 0, 39, '1841'),
	(243, 1, 0, -9, 1843, 0, 0, 39, '1842'),
	(243, 1, 0, -9, 1844, 0, 0, 39, '1843'),
	(243, 1, 0, -9, 1845, 0, 0, 39, '1844'),
	(243, 1, 0, -9, 1846, 0, 0, 39, '1845'),
	(243, 1, 0, -9, 1847, 0, 0, 39, '1846'),
	(243, 1, 0, -9, 1848, 0, 0, 39, '1847'),
	(243, 1, 0, -9, 1849, 0, 0, 39, '1848'),
	(243, 1, 0, -9, 1850, 0, 0, 39, '1849'),
	(243, 1, 0, -9, 1851, 0, 0, 39, '1850'),
	(243, 1, 0, -9, 1852, 0, 0, 39, '1851'),
	(243, 1, 0, -9, 1853, 0, 0, 39, '1852'),
	(243, 1, 0, -9, 1854, 0, 0, 39, '1853'),
	(243, 1, 0, -9, 1855, 0, 0, 39, '1854'),
	(243, 1, 0, -9, 1856, 0, 0, 39, '1855'),
	(243, 1, 0, -9, 1857, 0, 0, 39, '1856'),
	(243, 1, 0, -9, 1858, 0, 0, 39, '1857'),
	(243, 1, 0, -9, 1859, 0, 0, 39, '1858'),
	(243, 1, 0, -9, 1860, 0, 0, 39, '1859'),
	(243, 1, 0, -9, 1861, 0, 0, 39, '1860'),
	(243, 1, 0, -9, 1862, 0, 0, 39, '1861'),
	(243, 1, 0, -9, 1863, 0, 0, 39, '1862'),
	(243, 1, 0, -9, 1864, 0, 0, 39, '1863'),
	(243, 1, 0, -9, 1865, 0, 0, 39, '1864'),
	(243, 1, 0, -9, 1866, 0, 0, 39, '1865'),
	(243, 1, 0, -9, 1867, 0, 0, 39, '1866'),
	(243, 1, 0, -9, 1868, 0, 0, 39, '1867'),
	(243, 1, 0, -9, 1869, 0, 0, 39, '1868'),
	(243, 1, 0, -9, 1870, 0, 0, 39, '1869'),
	(243, 1, 0, -9, 1871, 0, 0, 39, '1870'),
	(243, 1, 0, -9, 1872, 0, 0, 39, '1871'),
	(243, 1, 0, -9, 1873, 0, 0, 39, '1872'),
	(243, 1, 0, -9, 1874, 0, 0, 39, '1873'),
	(243, 1, 0, -9, 1875, 0, 0, 39, '1874'),
	(243, 1, 0, -9, 1876, 0, 0, 39, '1875'),
	(243, 1, 0, -9, 1877, 0, 0, 39, '1876'),
	(243, 1, 0, -9, 1878, 0, 0, 39, '1877'),
	(243, 1, 0, -9, 1879, 0, 0, 39, '1878'),
	(243, 1, 0, -9, 1880, 0, 0, 39, '1879'),
	(243, 1, 0, -9, 1881, 0, 0, 39, '1880'),
	(243, 1, 0, -9, 1882, 0, 0, 39, '1881'),
	(243, 1, 0, -9, 1883, 0, 0, 39, '1882'),
	(243, 1, 0, -9, 1884, 0, 0, 39, '1883'),
	(243, 1, 0, -9, 1885, 0, 0, 39, '1884'),
	(243, 1, 0, -9, 1886, 0, 0, 39, '1885'),
	(243, 1, 0, -9, 1887, 0, 0, 39, '1886'),
	(243, 1, 0, -9, 1888, 0, 0, 39, '1887'),
	(243, 1, 0, -9, 1889, 0, 0, 39, '1888'),
	(243, 1, 0, -9, 1890, 0, 0, 39, '1889'),
	(243, 1, 0, -9, 1891, 0, 0, 39, '1890'),
	(243, 1, 0, -9, 1892, 0, 0, 39, '1891'),
	(243, 1, 0, -9, 1893, 0, 0, 39, '1892'),
	(243, 1, 0, -9, 1894, 0, 0, 39, '1893'),
	(243, 1, 0, -9, 1895, 0, 0, 39, '1894'),
	(243, 1, 0, -9, 1896, 0, 0, 39, '1895'),
	(243, 1, 0, -9, 1897, 0, 0, 39, '1896'),
	(243, 1, 0, -9, 1898, 0, 0, 39, '1897'),
	(243, 1, 0, -9, 1899, 0, 0, 39, '1898'),
	(243, 1, 0, -9, 1900, 0, 0, 39, '1899'),
	(243, 1, 0, -9, 1901, 0, 0, 39, '1900'),
	(243, 1, 0, -9, 1902, 0, 0, 39, '1901'),
	(243, 1, 0, -9, 1903, 0, 0, 39, '1902'),
	(243, 1, 0, -9, 1904, 0, 0, 39, '1903'),
	(243, 1, 0, -9, 1905, 0, 0, 39, '1904'),
	(243, 1, 0, -9, 1906, 0, 0, 39, '1905'),
	(243, 1, 0, -9, 1907, 0, 0, 39, '1906'),
	(243, 1, 0, -9, 1908, 0, 0, 39, '1907'),
	(243, 1, 0, -9, 1909, 0, 0, 39, '1908'),
	(243, 1, 0, -9, 1910, 0, 0, 39, '1909'),
	(243, 1, 0, -9, 1911, 0, 0, 39, '1910'),
	(243, 1, 0, -9, 1912, 0, 0, 39, '1911'),
	(243, 1, 0, -9, 1913, 0, 0, 39, '1912'),
	(243, 1, 0, -9, 1914, 0, 0, 39, '1913'),
	(243, 1, 0, -9, 1915, 0, 0, 39, '1914'),
	(243, 1, 0, -9, 1916, 0, 0, 39, '1915'),
	(243, 1, 0, -9, 1917, 0, 0, 39, '1916'),
	(243, 1, 0, -9, 1918, 0, 0, 39, '1917'),
	(243, 1, 0, -9, 1919, 0, 0, 39, '1918'),
	(243, 1, 0, -9, 1920, 0, 0, 39, '1919'),
	(243, 1, 0, -9, 1921, 0, 0, 39, '1920'),
	(243, 1, 0, -9, 1922, 0, 0, 39, '1921'),
	(243, 1, 0, -9, 1923, 0, 0, 39, '1922'),
	(243, 1, 0, -9, 1924, 0, 0, 39, '1923'),
	(243, 1, 0, -9, 1925, 0, 0, 39, '1924'),
	(243, 1, 0, -9, 1926, 0, 0, 39, '1925'),
	(243, 1, 0, -9, 1927, 0, 0, 39, '1926'),
	(243, 1, 0, -9, 1928, 0, 0, 39, '1927'),
	(243, 1, 0, -9, 1929, 0, 0, 39, '1928'),
	(243, 1, 0, -9, 1930, 0, 0, 39, '1929'),
	(243, 1, 0, -9, 1931, 0, 0, 39, '1930'),
	(243, 1, 0, -9, 1932, 0, 0, 39, '1931'),
	(243, 1, 0, -9, 1933, 0, 0, 39, '1932'),
	(243, 1, 0, -9, 1934, 0, 0, 39, '1933'),
	(243, 1, 0, -9, 1935, 0, 0, 39, '1934'),
	(243, 1, 0, -9, 1936, 0, 0, 39, '1935'),
	(243, 1, 0, -9, 1937, 0, 0, 39, '1936'),
	(243, 1, 0, -9, 1938, 0, 0, 39, '1937'),
	(243, 1, 0, -9, 1939, 0, 0, 39, '1938'),
	(243, 1, 0, -9, 1940, 0, 0, 39, '1939'),
	(243, 1, 0, -9, 1941, 0, 0, 39, '1940'),
	(243, 1, 0, -9, 1942, 0, 0, 39, '1941'),
	(243, 1, 0, -9, 1943, 0, 0, 39, '1942'),
	(243, 1, 0, -9, 1944, 0, 0, 39, '1943'),
	(243, 1, 0, -9, 1945, 0, 0, 39, '1944'),
	(243, 1, 0, -9, 1946, 0, 0, 39, '1945'),
	(243, 1, 0, -9, 1947, 0, 0, 39, '1946'),
	(243, 1, 0, -9, 1948, 0, 0, 39, '1947'),
	(243, 1, 0, -9, 1949, 0, 0, 39, '1948'),
	(243, 1, 0, -9, 1950, 0, 0, 39, '1949'),
	(243, 1, 0, -9, 1951, 0, 0, 39, '1950'),
	(243, 1, 0, -9, 1952, 0, 0, 39, '1951'),
	(243, 1, 0, -9, 1953, 0, 0, 39, '1952'),
	(243, 1, 0, -9, 1954, 0, 0, 39, '1953'),
	(243, 1, 0, -9, 1955, 0, 0, 39, '1954'),
	(243, 1, 0, -9, 1956, 0, 0, 39, '1955'),
	(243, 1, 0, -9, 1957, 0, 0, 39, '1956'),
	(243, 1, 0, -9, 1958, 0, 0, 39, '1957'),
	(243, 1, 0, -9, 1959, 0, 0, 39, '1958'),
	(243, 1, 0, -9, 1960, 0, 0, 39, '1959'),
	(243, 1, 0, -9, 1961, 0, 0, 39, '1960'),
	(243, 1, 0, -9, 1962, 0, 0, 39, '1961'),
	(243, 1, 0, -9, 1963, 0, 0, 39, '1962'),
	(243, 1, 0, -9, 1964, 0, 0, 39, '1963'),
	(243, 1, 0, -9, 1965, 0, 0, 39, '1964'),
	(243, 1, 0, -9, 1966, 0, 0, 39, '1965'),
	(243, 1, 0, -9, 1967, 0, 0, 39, '1966'),
	(243, 1, 0, -9, 1968, 0, 0, 39, '1967'),
	(243, 1, 0, -9, 1969, 0, 0, 39, '1968'),
	(243, 1, 0, -9, 1970, 0, 0, 39, '1969'),
	(243, 1, 0, -9, 1971, 0, 0, 39, '1970'),
	(243, 1, 0, -9, 1972, 0, 0, 39, '1971'),
	(243, 1, 0, -9, 1973, 0, 0, 39, '1972'),
	(243, 1, 0, -9, 1974, 0, 0, 39, '1973'),
	(243, 1, 0, -9, 1975, 0, 0, 39, '1974'),
	(243, 1, 0, -9, 1976, 0, 0, 39, '1975'),
	(243, 1, 0, -9, 1977, 0, 0, 39, '1976'),
	(243, 1, 0, -9, 1978, 0, 0, 39, '1977'),
	(243, 1, 0, -9, 1979, 0, 0, 39, '1978'),
	(243, 1, 0, -9, 1980, 0, 0, 39, '1979'),
	(243, 1, 0, -9, 1981, 0, 0, 39, '1980'),
	(243, 1, 0, -9, 1982, 0, 0, 39, '1981'),
	(243, 1, 0, -9, 1983, 0, 0, 39, '1982'),
	(243, 1, 0, -9, 1984, 0, 0, 39, '1983'),
	(243, 1, 0, -9, 1985, 0, 0, 39, '1984'),
	(243, 1, 0, -9, 1986, 0, 0, 39, '1985'),
	(243, 1, 0, -9, 1987, 0, 0, 39, '1986'),
	(243, 1, 0, -9, 1988, 0, 0, 39, '1987'),
	(243, 1, 0, -9, 1989, 0, 0, 39, '1988'),
	(243, 1, 0, -9, 1990, 0, 0, 39, '1989'),
	(243, 1, 0, -9, 1991, 0, 0, 39, '1990'),
	(243, 1, 0, -9, 1992, 0, 0, 39, '1991'),
	(243, 1, 0, -9, 1993, 0, 0, 39, '1992'),
	(243, 1, 0, -9, 1994, 0, 0, 39, '1993'),
	(243, 1, 0, -9, 1995, 0, 0, 39, '1994'),
	(243, 1, 0, -9, 1996, 0, 0, 39, '1995'),
	(243, 1, 0, -9, 1997, 0, 0, 39, '1996'),
	(243, 1, 0, -9, 1998, 0, 0, 39, '1997'),
	(243, 1, 0, -9, 1999, 0, 0, 39, '1998'),
	(243, 1, 0, -9, 2000, 0, 0, 39, '1999'),
	(243, 1, 0, -9, 2001, 0, 0, 39, '2000'),
	(243, 1, 0, -9, 2002, 0, 0, 39, '2001'),
	(243, 1, 0, -9, 2003, 0, 0, 39, '2002'),
	(243, 1, 0, -9, 2004, 0, 0, 39, '2003'),
	(243, 1, 0, -9, 2005, 0, 0, 39, '2004'),
	(243, 1, 0, -9, 2006, 0, 0, 39, '2005'),
	(243, 1, 0, -9, 2007, 0, 0, 39, '2006'),
	(243, 1, 0, -9, 2008, 0, 0, 39, '2007'),
	(243, 1, 0, -9, 2009, 0, 0, 39, '2008'),
	(243, 1, 0, -9, 2010, 0, 0, 39, '2009'),
	(243, 1, 0, -9, 2011, 0, 0, 39, '2010'),
	(243, 1, 0, -9, 2012, 0, 0, 39, '2011'),
	(243, 1, 0, -9, 2013, 0, 0, 39, '2012'),
	(243, 1, 0, -9, 2014, 0, 0, 39, '2013'),
	(243, 1, 0, -9, 2015, 0, 0, 39, '2014'),
	(243, 1, 0, -9, 2016, 0, 0, 39, '2015'),
	(243, 1, 0, -9, 2017, 0, 0, 39, '2016'),
	(243, 1, 0, -9, 2018, 0, 0, 39, '2017'),
	(243, 1, 0, -9, 2019, 0, 0, 39, '2018'),
	(243, 1, 0, -9, 2020, 0, 0, 39, '2019'),
	(243, 1, 0, -9, 2021, 0, 0, 39, '2020'),
	(243, 1, 0, -9, 2022, 0, 0, 39, '2021'),
	(243, 1, 0, -9, 2023, 0, 0, 39, '2022'),
	(243, 1, 0, -9, 2024, 0, 0, 39, '2023'),
	(243, 1, 0, -9, 2025, 0, 0, 39, '2024'),
	(243, 1, 0, -9, 2026, 0, 0, 39, '2025'),
	(243, 1, 0, -9, 2027, 0, 0, 39, '2026'),
	(243, 1, 0, -9, 2028, 0, 0, 39, '2027'),
	(243, 1, 0, -9, 2029, 0, 0, 39, '2028'),
	(243, 1, 0, -9, 2030, 0, 0, 39, '2029'),
	(243, 1, 0, -9, 2031, 0, 0, 39, '2030'),
	(243, 1, 0, -9, 2032, 0, 0, 39, '2031'),
	(243, 1, 0, -9, 2033, 0, 0, 39, '2032'),
	(243, 1, 0, -9, 2034, 0, 0, 39, '2033'),
	(243, 1, 0, -9, 2035, 0, 0, 39, '2034'),
	(243, 1, 0, -9, 2036, 0, 0, 39, '2035'),
	(243, 1, 0, -9, 2037, 0, 0, 39, '2036'),
	(243, 1, 0, -9, 2038, 0, 0, 39, '2037'),
	(243, 1, 0, -9, 2039, 0, 0, 39, '2038'),
	(243, 1, 0, -9, 2040, 0, 0, 39, '2039'),
	(243, 1, 0, -9, 2041, 0, 0, 39, '2040'),
	(243, 1, 0, -9, 2042, 0, 0, 39, '2041'),
	(243, 1, 0, -9, 2043, 0, 0, 39, '2042'),
	(243, 1, 0, -9, 2044, 0, 0, 39, '2043'),
	(243, 1, 0, -9, 2045, 0, 0, 39, '2044'),
	(243, 1, 0, -9, 2046, 0, 0, 39, '2045'),
	(243, 1, 0, -9, 2047, 0, 0, 39, '2046'),
	(243, 1, 0, -9, 2048, 0, 0, 39, '2047'),
	(337, 1, 1, -50496, 1, 0, 0, 12, '1.0.99.1.0.255'),
	(337, 1, 1, -50496, 2, 0, 0, 12, '0.0.99.2.0.255'),
	(337, 1, 1, -50495, 1, 0, 0, 12, '1.0.99.1.0.255'),
	(337, 1, 1, -50495, 2, 0, 0, 12, '0.0.99.2.0.255'),
	(337, 1, 1, -50494, 1, 0, 0, 12, '1.0.99.1.0.255'),
	(337, 1, 1, -50494, 2, 0, 0, 12, '0.0.99.2.0.255'),
	(337, 1, 1, -50493, 1, 0, 0, 12, '1.0.99.1.0.255'),
	(337, 1, 1, -50493, 2, 0, 0, 12, '0.0.99.2.0.255'),
	(337, 1, 1, -50491, 1, 0, 0, 12, '1.0.99.1.0.255'),
	(337, 1, 1, -50491, 2, 0, 0, 12, '0.0.99.2.0.255'),
	(337, 1, 1, -50304, 1, 0, 0, 12, '1.0.99.1.0.255'),
	(337, 1, 1, -50304, 2, 0, 0, 12, '0.0.99.2.0.255'),
	(370, 1, 1, -50921, 1, 0, 0, 12, '1.0.98.1.0.255'),
	(370, 1, 1, -50921, 2, 0, 0, 12, '1.0.98.1.1.255'),
	(370, 1, 1, -50921, 3, 0, 0, 12, '1.0.98.1.2.255'),
	(370, 1, 1, -50921, 4, 0, 0, 12, '1.0.98.1.3.255'),
	(370, 1, 1, -50921, 5, 0, 0, 12, '1.0.98.2.0.255'),
	(370, 1, 1, -50921, 6, 0, 0, 12, '1.0.98.2.1.255'),
	(370, 1, 1, -50921, 7, 0, 0, 12, '1.0.98.2.2.255'),
	(370, 1, 1, -50921, 8, 0, 0, 12, '1.0.98.2.3.255'),
	(370, 1, 1, -50921, 9, 0, 0, 12, '1.0.99.1.0.255'),
	(370, 1, 1, -50921, 10, 0, 0, 12, '1.0.99.1.1.255'),
	(370, 1, 1, -50921, 11, 0, 0, 12, '1.0.99.1.2.255'),
	(370, 1, 1, -50921, 12, 0, 0, 12, '1.0.99.1.3.255'),
	(370, 1, 1, -50920, 1, 0, 0, 12, '1.0.98.1.0.255'),
	(370, 1, 1, -50920, 2, 0, 0, 12, '1.0.98.1.1.255'),
	(370, 1, 1, -50920, 3, 0, 0, 12, '1.0.98.1.2.255'),
	(370, 1, 1, -50920, 4, 0, 0, 12, '1.0.98.1.3.255'),
	(370, 1, 1, -50920, 5, 0, 0, 12, '1.0.98.2.0.255'),
	(370, 1, 1, -50920, 6, 0, 0, 12, '1.0.98.2.1.255'),
	(370, 1, 1, -50920, 7, 0, 0, 12, '1.0.98.2.2.255'),
	(370, 1, 1, -50920, 8, 0, 0, 12, '1.0.98.2.3.255'),
	(370, 1, 1, -50920, 9, 0, 0, 12, '1.0.99.1.0.255'),
	(370, 1, 1, -50920, 10, 0, 0, 12, '1.0.99.1.1.255'),
	(370, 1, 1, -50920, 11, 0, 0, 12, '1.0.99.1.2.255'),
	(370, 1, 1, -50920, 12, 0, 0, 12, '1.0.99.1.3.255'),
	(370, 1, 1, -50919, 1, 0, 0, 12, '1.0.98.1.0.255'),
	(370, 1, 1, -50919, 2, 0, 0, 12, '1.0.98.1.1.255'),
	(370, 1, 1, -50919, 3, 0, 0, 12, '1.0.98.1.2.255'),
	(370, 1, 1, -50919, 4, 0, 0, 12, '1.0.98.1.3.255'),
	(370, 1, 1, -50919, 5, 0, 0, 12, '1.0.98.2.0.255'),
	(370, 1, 1, -50919, 6, 0, 0, 12, '1.0.98.2.1.255'),
	(370, 1, 1, -50919, 7, 0, 0, 12, '1.0.98.2.2.255'),
	(370, 1, 1, -50919, 8, 0, 0, 12, '1.0.98.2.3.255'),
	(370, 1, 1, -50919, 9, 0, 0, 12, '1.0.99.1.0.255'),
	(370, 1, 1, -50919, 10, 0, 0, 12, '1.0.99.1.1.255'),
	(370, 1, 1, -50919, 11, 0, 0, 12, '1.0.99.1.2.255'),
	(370, 1, 1, -50919, 12, 0, 0, 12, '1.0.99.1.3.255'),
	(370, 1, 1, -50918, 1, 0, 0, 12, '1.0.98.1.0.255'),
	(370, 1, 1, -50918, 2, 0, 0, 12, '1.0.98.1.1.255'),
	(370, 1, 1, -50918, 3, 0, 0, 12, '1.0.98.1.2.255'),
	(370, 1, 1, -50918, 4, 0, 0, 12, '1.0.98.1.3.255'),
	(370, 1, 1, -50918, 5, 0, 0, 12, '1.0.98.2.0.255'),
	(370, 1, 1, -50918, 6, 0, 0, 12, '1.0.98.2.1.255'),
	(370, 1, 1, -50918, 7, 0, 0, 12, '1.0.98.2.2.255'),
	(370, 1, 1, -50918, 8, 0, 0, 12, '1.0.98.2.3.255'),
	(370, 1, 1, -50918, 9, 0, 0, 12, '1.0.99.1.0.255'),
	(370, 1, 1, -50918, 10, 0, 0, 12, '1.0.99.1.1.255'),
	(370, 1, 1, -50918, 11, 0, 0, 12, '1.0.99.1.2.255'),
	(370, 1, 1, -50918, 12, 0, 0, 12, '1.0.99.1.3.255'),
	(370, 1, 1, -50304, 1, 0, 0, 12, '1.0.98.1.0.255'),
	(370, 1, 1, -50304, 2, 0, 0, 12, '1.0.98.1.1.255'),
	(370, 1, 1, -50304, 3, 0, 0, 12, '1.0.98.1.2.255'),
	(370, 1, 1, -50304, 4, 0, 0, 12, '1.0.98.1.3.255'),
	(370, 1, 1, -50304, 5, 0, 0, 12, '1.0.98.2.0.255'),
	(370, 1, 1, -50304, 6, 0, 0, 12, '1.0.98.2.1.255'),
	(370, 1, 1, -50304, 7, 0, 0, 12, '1.0.98.2.2.255'),
	(370, 1, 1, -50304, 8, 0, 0, 12, '1.0.98.2.3.255'),
	(370, 1, 1, -50304, 9, 0, 0, 12, '1.0.99.1.0.255'),
	(370, 1, 1, -50304, 10, 0, 0, 12, '1.0.99.1.1.255'),
	(370, 1, 1, -50304, 11, 0, 0, 12, '1.0.99.1.2.255'),
	(370, 1, 1, -50304, 12, 0, 0, 12, '1.0.99.1.3.255'),
	(371, 1, 1, -50921, 1, 0, 0, 12, '1.0.98.1.0.255'),
	(371, 1, 1, -50921, 2, 0, 0, 12, '1.0.98.2.0.255'),
	(371, 1, 1, -50921, 3, 0, 0, 12, '1.0.99.1.0.255'),
	(371, 1, 1, -50920, 1, 0, 0, 12, '1.0.98.1.0.255'),
	(371, 1, 1, -50920, 2, 0, 0, 12, '1.0.98.2.0.255'),
	(371, 1, 1, -50920, 3, 0, 0, 12, '1.0.99.1.0.255'),
	(371, 1, 1, -50919, 1, 0, 0, 12, '1.0.98.1.0.255'),
	(371, 1, 1, -50919, 2, 0, 0, 12, '1.0.98.2.0.255'),
	(371, 1, 1, -50919, 3, 0, 0, 12, '1.0.99.1.0.255'),
	(371, 1, 1, -50918, 1, 0, 0, 12, '1.0.98.1.0.255'),
	(371, 1, 1, -50918, 2, 0, 0, 12, '1.0.98.2.0.255'),
	(371, 1, 1, -50918, 3, 0, 0, 12, '1.0.99.1.0.255'),
	(371, 1, 1, -50304, 1, 0, 0, 12, '1.0.98.1.0.255'),
	(371, 1, 1, -50304, 2, 0, 0, 12, '1.0.98.2.0.255'),
	(371, 1, 1, -50304, 3, 0, 0, 12, '1.0.99.1.0.255'),
	(372, 1, 1, -50921, 1, 0, 0, 12, '1.0.98.1.0.255'),
	(372, 1, 1, -50921, 2, 0, 0, 12, '1.0.98.1.1.255'),
	(372, 1, 1, -50921, 3, 0, 0, 12, '1.0.98.1.2.255'),
	(372, 1, 1, -50921, 4, 0, 0, 12, '1.0.98.1.3.255'),
	(372, 1, 1, -50921, 5, 0, 0, 12, '1.0.98.2.0.255'),
	(372, 1, 1, -50921, 6, 0, 0, 12, '1.0.98.2.1.255'),
	(372, 1, 1, -50921, 7, 0, 0, 12, '1.0.98.2.2.255'),
	(372, 1, 1, -50921, 8, 0, 0, 12, '1.0.98.2.3.255'),
	(372, 1, 1, -50921, 9, 0, 0, 12, '1.0.99.1.0.255'),
	(372, 1, 1, -50921, 10, 0, 0, 12, '1.0.99.1.1.255'),
	(372, 1, 1, -50921, 11, 0, 0, 12, '1.0.99.1.2.255'),
	(372, 1, 1, -50921, 12, 0, 0, 12, '1.0.99.1.3.255'),
	(372, 1, 1, -50920, 1, 0, 0, 12, '1.0.98.1.0.255'),
	(372, 1, 1, -50920, 2, 0, 0, 12, '1.0.98.1.1.255'),
	(372, 1, 1, -50920, 3, 0, 0, 12, '1.0.98.1.2.255'),
	(372, 1, 1, -50920, 4, 0, 0, 12, '1.0.98.1.3.255'),
	(372, 1, 1, -50920, 5, 0, 0, 12, '1.0.98.2.0.255'),
	(372, 1, 1, -50920, 6, 0, 0, 12, '1.0.98.2.1.255'),
	(372, 1, 1, -50920, 7, 0, 0, 12, '1.0.98.2.2.255'),
	(372, 1, 1, -50920, 8, 0, 0, 12, '1.0.98.2.3.255'),
	(372, 1, 1, -50920, 9, 0, 0, 12, '1.0.99.1.0.255'),
	(372, 1, 1, -50920, 10, 0, 0, 12, '1.0.99.1.1.255'),
	(372, 1, 1, -50920, 11, 0, 0, 12, '1.0.99.1.2.255'),
	(372, 1, 1, -50920, 12, 0, 0, 12, '1.0.99.1.3.255'),
	(372, 1, 1, -50919, 1, 0, 0, 12, '1.0.98.1.0.255'),
	(372, 1, 1, -50919, 2, 0, 0, 12, '1.0.98.1.1.255'),
	(372, 1, 1, -50919, 3, 0, 0, 12, '1.0.98.1.2.255'),
	(372, 1, 1, -50919, 4, 0, 0, 12, '1.0.98.1.3.255'),
	(372, 1, 1, -50919, 5, 0, 0, 12, '1.0.98.2.0.255'),
	(372, 1, 1, -50919, 6, 0, 0, 12, '1.0.98.2.1.255'),
	(372, 1, 1, -50919, 7, 0, 0, 12, '1.0.98.2.2.255'),
	(372, 1, 1, -50919, 8, 0, 0, 12, '1.0.98.2.3.255'),
	(372, 1, 1, -50919, 9, 0, 0, 12, '1.0.99.1.0.255'),
	(372, 1, 1, -50919, 10, 0, 0, 12, '1.0.99.1.1.255'),
	(372, 1, 1, -50919, 11, 0, 0, 12, '1.0.99.1.2.255'),
	(372, 1, 1, -50919, 12, 0, 0, 12, '1.0.99.1.3.255'),
	(372, 1, 1, -50918, 1, 0, 0, 12, '1.0.98.1.0.255'),
	(372, 1, 1, -50918, 2, 0, 0, 12, '1.0.98.1.1.255'),
	(372, 1, 1, -50918, 3, 0, 0, 12, '1.0.98.1.2.255'),
	(372, 1, 1, -50918, 4, 0, 0, 12, '1.0.98.1.3.255'),
	(372, 1, 1, -50918, 5, 0, 0, 12, '1.0.98.2.0.255'),
	(372, 1, 1, -50918, 6, 0, 0, 12, '1.0.98.2.1.255'),
	(372, 1, 1, -50918, 7, 0, 0, 12, '1.0.98.2.2.255'),
	(372, 1, 1, -50918, 8, 0, 0, 12, '1.0.98.2.3.255'),
	(372, 1, 1, -50918, 9, 0, 0, 12, '1.0.99.1.0.255'),
	(372, 1, 1, -50918, 10, 0, 0, 12, '1.0.99.1.1.255'),
	(372, 1, 1, -50918, 11, 0, 0, 12, '1.0.99.1.2.255'),
	(372, 1, 1, -50918, 12, 0, 0, 12, '1.0.99.1.3.255'),
	(372, 1, 1, -50304, 1, 0, 0, 12, '1.0.98.1.0.255'),
	(372, 1, 1, -50304, 2, 0, 0, 12, '1.0.98.1.1.255'),
	(372, 1, 1, -50304, 3, 0, 0, 12, '1.0.98.1.2.255'),
	(372, 1, 1, -50304, 4, 0, 0, 12, '1.0.98.1.3.255'),
	(372, 1, 1, -50304, 5, 0, 0, 12, '1.0.98.2.0.255'),
	(372, 1, 1, -50304, 6, 0, 0, 12, '1.0.98.2.1.255'),
	(372, 1, 1, -50304, 7, 0, 0, 12, '1.0.98.2.2.255'),
	(372, 1, 1, -50304, 8, 0, 0, 12, '1.0.98.2.3.255'),
	(372, 1, 1, -50304, 9, 0, 0, 12, '1.0.99.1.0.255'),
	(372, 1, 1, -50304, 10, 0, 0, 12, '1.0.99.1.1.255'),
	(372, 1, 1, -50304, 11, 0, 0, 12, '1.0.99.1.2.255'),
	(372, 1, 1, -50304, 12, 0, 0, 12, '1.0.99.1.3.255'),
	(377, 1, 0, -50925, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50925, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50925, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50925, 4, 0, 0, 39, '3'),
	(377, 1, 0, -50925, 5, 0, 0, 39, '4'),
	(377, 1, 0, -50925, 6, 0, 0, 39, '5'),
	(377, 1, 0, -50925, 7, 0, 0, 39, '6'),
	(377, 1, 0, -50925, 8, 0, 0, 39, '7'),
	(377, 1, 0, -50925, 9, 0, 0, 39, '8'),
	(377, 1, 0, -50925, 10, 0, 0, 39, '9'),
	(377, 1, 0, -50925, 11, 0, 0, 39, '10'),
	(377, 1, 0, -50925, 12, 0, 0, 39, '11'),
	(377, 1, 0, -50925, 13, 0, 0, 39, '12'),
	(377, 1, 0, -50925, 14, 0, 0, 39, '13'),
	(377, 1, 0, -50925, 15, 0, 0, 39, '14'),
	(377, 1, 0, -50925, 16, 0, 0, 39, '15'),
	(377, 1, 0, -50925, 17, 0, 0, 39, '16'),
	(377, 1, 0, -50925, 18, 0, 0, 39, '17'),
	(377, 1, 0, -50925, 19, 0, 0, 39, '18'),
	(377, 1, 0, -50925, 20, 0, 0, 39, '19'),
	(377, 1, 0, -50925, 21, 0, 0, 39, '20'),
	(377, 1, 0, -50925, 22, 0, 0, 39, '21'),
	(377, 1, 0, -50925, 23, 0, 0, 39, '22'),
	(377, 1, 0, -50925, 24, 0, 0, 39, '23'),
	(377, 1, 0, -50925, 25, 0, 0, 39, '24'),
	(377, 1, 0, -50925, 26, 0, 0, 39, '25'),
	(377, 1, 0, -50925, 27, 0, 0, 39, '26'),
	(377, 1, 0, -50925, 28, 0, 0, 39, '27'),
	(377, 1, 0, -50925, 29, 0, 0, 39, '28'),
	(377, 1, 0, -50925, 30, 0, 0, 39, '29'),
	(377, 1, 0, -50925, 31, 0, 0, 39, '30'),
	(377, 1, 0, -50925, 32, 0, 0, 39, '31'),
	(377, 1, 0, -50925, 33, 0, 0, 39, '32'),
	(377, 1, 0, -50925, 34, 0, 0, 39, '33'),
	(377, 1, 0, -50925, 35, 0, 0, 39, '34'),
	(377, 1, 0, -50925, 36, 0, 0, 39, '35'),
	(377, 1, 0, -50925, 37, 0, 0, 39, '36'),
	(377, 1, 0, -50925, 38, 0, 0, 39, '37'),
	(377, 1, 0, -50925, 39, 0, 0, 39, '38'),
	(377, 1, 0, -50925, 40, 0, 0, 39, '39'),
	(377, 1, 0, -50925, 41, 0, 0, 39, '40'),
	(377, 1, 0, -50925, 42, 0, 0, 39, '41'),
	(377, 1, 0, -50925, 43, 0, 0, 39, '42'),
	(377, 1, 0, -50925, 44, 0, 0, 39, '43'),
	(377, 1, 0, -50925, 45, 0, 0, 39, '44'),
	(377, 1, 0, -50925, 46, 0, 0, 39, '45'),
	(377, 1, 0, -50925, 47, 0, 0, 39, '46'),
	(377, 1, 0, -50925, 48, 0, 0, 39, '47'),
	(377, 1, 0, -50925, 49, 0, 0, 39, '48'),
	(377, 1, 0, -50925, 50, 0, 0, 39, '49'),
	(377, 1, 0, -50925, 51, 0, 0, 39, '50'),
	(377, 1, 0, -50925, 52, 0, 0, 39, '51'),
	(377, 1, 0, -50925, 53, 0, 0, 39, '52'),
	(377, 1, 0, -50925, 54, 0, 0, 39, '53'),
	(377, 1, 0, -50925, 55, 0, 0, 39, '54'),
	(377, 1, 0, -50925, 56, 0, 0, 39, '55'),
	(377, 1, 0, -50925, 57, 0, 0, 39, '56'),
	(377, 1, 0, -50925, 58, 0, 0, 39, '57'),
	(377, 1, 0, -50925, 59, 0, 0, 39, '58'),
	(377, 1, 0, -50925, 60, 0, 0, 39, '59'),
	(377, 1, 0, -50925, 61, 0, 0, 39, '60'),
	(377, 1, 0, -50925, 62, 0, 0, 39, '61'),
	(377, 1, 0, -50925, 63, 0, 0, 39, '62'),
	(377, 1, 0, -50925, 64, 0, 0, 39, '63'),
	(377, 1, 0, -50925, 65, 0, 0, 39, '64'),
	(377, 1, 0, -50925, 66, 0, 0, 39, '65'),
	(377, 1, 0, -50925, 67, 0, 0, 39, '66'),
	(377, 1, 0, -50925, 68, 0, 0, 39, '67'),
	(377, 1, 0, -50925, 69, 0, 0, 39, '68'),
	(377, 1, 0, -50925, 70, 0, 0, 39, '69'),
	(377, 1, 0, -50925, 71, 0, 0, 39, '70'),
	(377, 1, 0, -50925, 72, 0, 0, 39, '71'),
	(377, 1, 0, -50925, 73, 0, 0, 39, '72'),
	(377, 1, 0, -50925, 74, 0, 0, 39, '73'),
	(377, 1, 0, -50925, 75, 0, 0, 39, '74'),
	(377, 1, 0, -50925, 76, 0, 0, 39, '75'),
	(377, 1, 0, -50925, 77, 0, 0, 39, '76'),
	(377, 1, 0, -50925, 78, 0, 0, 39, '77'),
	(377, 1, 0, -50925, 79, 0, 0, 39, '78'),
	(377, 1, 0, -50925, 80, 0, 0, 39, '79'),
	(377, 1, 0, -50925, 81, 0, 0, 39, '80'),
	(377, 1, 0, -50925, 82, 0, 0, 39, '81'),
	(377, 1, 0, -50925, 83, 0, 0, 39, '82'),
	(377, 1, 0, -50925, 84, 0, 0, 39, '83'),
	(377, 1, 0, -50925, 85, 0, 0, 39, '84'),
	(377, 1, 0, -50925, 86, 0, 0, 39, '85'),
	(377, 1, 0, -50925, 87, 0, 0, 39, '86'),
	(377, 1, 0, -50925, 88, 0, 0, 39, '87'),
	(377, 1, 0, -50925, 89, 0, 0, 39, '88'),
	(377, 1, 0, -50925, 90, 0, 0, 39, '89'),
	(377, 1, 0, -50925, 91, 0, 0, 39, '90'),
	(377, 1, 0, -50925, 92, 0, 0, 39, '91'),
	(377, 1, 0, -50925, 93, 0, 0, 39, '92'),
	(377, 1, 0, -50925, 94, 0, 0, 39, '93'),
	(377, 1, 0, -50925, 95, 0, 0, 39, '94'),
	(377, 1, 0, -50925, 96, 0, 0, 39, '95'),
	(377, 1, 0, -50925, 97, 0, 0, 39, '96'),
	(377, 1, 0, -50925, 98, 0, 0, 39, '97'),
	(377, 1, 0, -50925, 99, 0, 0, 39, '98'),
	(377, 1, 0, -50925, 100, 0, 0, 39, '99'),
	(377, 1, 0, -50925, 101, 0, 0, 39, '100'),
	(377, 1, 0, -50925, 102, 0, 0, 39, '101'),
	(377, 1, 0, -50925, 103, 0, 0, 39, '102'),
	(377, 1, 0, -50925, 104, 0, 0, 39, '103'),
	(377, 1, 0, -50925, 105, 0, 0, 39, '104'),
	(377, 1, 0, -50925, 106, 0, 0, 39, '105'),
	(377, 1, 0, -50925, 107, 0, 0, 39, '106'),
	(377, 1, 0, -50925, 108, 0, 0, 39, '107'),
	(377, 1, 0, -50925, 109, 0, 0, 39, '108'),
	(377, 1, 0, -50925, 110, 0, 0, 39, '109'),
	(377, 1, 0, -50925, 111, 0, 0, 39, '110'),
	(377, 1, 0, -50925, 112, 0, 0, 39, '111'),
	(377, 1, 0, -50925, 113, 0, 0, 39, '112'),
	(377, 1, 0, -50925, 114, 0, 0, 39, '113'),
	(377, 1, 0, -50925, 115, 0, 0, 39, '114'),
	(377, 1, 0, -50925, 116, 0, 0, 39, '115'),
	(377, 1, 0, -50925, 117, 0, 0, 39, '116'),
	(377, 1, 0, -50925, 118, 0, 0, 39, '117'),
	(377, 1, 0, -50925, 119, 0, 0, 39, '118'),
	(377, 1, 0, -50925, 120, 0, 0, 39, '119'),
	(377, 1, 0, -50925, 121, 0, 0, 39, '120'),
	(377, 1, 0, -50925, 122, 0, 0, 39, '121'),
	(377, 1, 0, -50925, 123, 0, 0, 39, '122'),
	(377, 1, 0, -50925, 124, 0, 0, 39, '123'),
	(377, 1, 0, -50925, 125, 0, 0, 39, '124'),
	(377, 1, 0, -50925, 126, 0, 0, 39, '125'),
	(377, 1, 0, -50925, 127, 0, 0, 39, '126'),
	(377, 1, 0, -50925, 128, 0, 0, 39, '127'),
	(377, 1, 0, -50925, 129, 0, 0, 39, '128'),
	(377, 1, 0, -50925, 130, 0, 0, 39, '129'),
	(377, 1, 0, -50925, 131, 0, 0, 39, '130'),
	(377, 1, 0, -50925, 132, 0, 0, 39, '131'),
	(377, 1, 0, -50925, 133, 0, 0, 39, '132'),
	(377, 1, 0, -50925, 134, 0, 0, 39, '133'),
	(377, 1, 0, -50925, 135, 0, 0, 39, '134'),
	(377, 1, 0, -50925, 136, 0, 0, 39, '135'),
	(377, 1, 0, -50925, 137, 0, 0, 39, '136'),
	(377, 1, 0, -50925, 138, 0, 0, 39, '137'),
	(377, 1, 0, -50925, 139, 0, 0, 39, '138'),
	(377, 1, 0, -50925, 140, 0, 0, 39, '139'),
	(377, 1, 0, -50925, 141, 0, 0, 39, '140'),
	(377, 1, 0, -50925, 142, 0, 0, 39, '141'),
	(377, 1, 0, -50925, 143, 0, 0, 39, '142'),
	(377, 1, 0, -50925, 144, 0, 0, 39, '143'),
	(377, 1, 0, -50925, 145, 0, 0, 39, '144'),
	(377, 1, 0, -50925, 146, 0, 0, 39, '145'),
	(377, 1, 0, -50925, 147, 0, 0, 39, '146'),
	(377, 1, 0, -50925, 148, 0, 0, 39, '147'),
	(377, 1, 0, -50925, 149, 0, 0, 39, '148'),
	(377, 1, 0, -50925, 150, 0, 0, 39, '149'),
	(377, 1, 0, -50925, 151, 0, 0, 39, '150'),
	(377, 1, 0, -50925, 152, 0, 0, 39, '151'),
	(377, 1, 0, -50925, 153, 0, 0, 39, '152'),
	(377, 1, 0, -50925, 154, 0, 0, 39, '153'),
	(377, 1, 0, -50925, 155, 0, 0, 39, '154'),
	(377, 1, 0, -50925, 156, 0, 0, 39, '155'),
	(377, 1, 0, -50925, 157, 0, 0, 39, '156'),
	(377, 1, 0, -50925, 158, 0, 0, 39, '157'),
	(377, 1, 0, -50925, 159, 0, 0, 39, '158'),
	(377, 1, 0, -50925, 160, 0, 0, 39, '159'),
	(377, 1, 0, -50925, 161, 0, 0, 39, '160'),
	(377, 1, 0, -50925, 162, 0, 0, 39, '161'),
	(377, 1, 0, -50925, 163, 0, 0, 39, '162'),
	(377, 1, 0, -50925, 164, 0, 0, 39, '163'),
	(377, 1, 0, -50925, 165, 0, 0, 39, '164'),
	(377, 1, 0, -50925, 166, 0, 0, 39, '165'),
	(377, 1, 0, -50925, 167, 0, 0, 39, '166'),
	(377, 1, 0, -50925, 168, 0, 0, 39, '167'),
	(377, 1, 0, -50925, 169, 0, 0, 39, '168'),
	(377, 1, 0, -50925, 170, 0, 0, 39, '169'),
	(377, 1, 0, -50925, 171, 0, 0, 39, '170'),
	(377, 1, 0, -50925, 172, 0, 0, 39, '171'),
	(377, 1, 0, -50925, 173, 0, 0, 39, '172'),
	(377, 1, 0, -50925, 174, 0, 0, 39, '173'),
	(377, 1, 0, -50925, 175, 0, 0, 39, '174'),
	(377, 1, 0, -50925, 176, 0, 0, 39, '175'),
	(377, 1, 0, -50925, 177, 0, 0, 39, '176'),
	(377, 1, 0, -50925, 178, 0, 0, 39, '177'),
	(377, 1, 0, -50925, 179, 0, 0, 39, '178'),
	(377, 1, 0, -50925, 180, 0, 0, 39, '179'),
	(377, 1, 0, -50925, 181, 0, 0, 39, '180'),
	(377, 1, 0, -50925, 182, 0, 0, 39, '181'),
	(377, 1, 0, -50925, 183, 0, 0, 39, '182'),
	(377, 1, 0, -50925, 184, 0, 0, 39, '183'),
	(377, 1, 0, -50925, 185, 0, 0, 39, '184'),
	(377, 1, 0, -50925, 186, 0, 0, 39, '185'),
	(377, 1, 0, -50925, 187, 0, 0, 39, '186'),
	(377, 1, 0, -50925, 188, 0, 0, 39, '187'),
	(377, 1, 0, -50925, 189, 0, 0, 39, '188'),
	(377, 1, 0, -50925, 190, 0, 0, 39, '189'),
	(377, 1, 0, -50925, 191, 0, 0, 39, '190'),
	(377, 1, 0, -50925, 192, 0, 0, 39, '191'),
	(377, 1, 0, -50925, 193, 0, 0, 39, '192'),
	(377, 1, 0, -50925, 194, 0, 0, 39, '193'),
	(377, 1, 0, -50925, 195, 0, 0, 39, '194'),
	(377, 1, 0, -50925, 196, 0, 0, 39, '195'),
	(377, 1, 0, -50925, 197, 0, 0, 39, '196'),
	(377, 1, 0, -50925, 198, 0, 0, 39, '197'),
	(377, 1, 0, -50925, 199, 0, 0, 39, '198'),
	(377, 1, 0, -50925, 200, 0, 0, 39, '199'),
	(377, 1, 0, -50925, 201, 0, 0, 39, '200'),
	(377, 1, 0, -50925, 202, 0, 0, 39, '201'),
	(377, 1, 0, -50925, 203, 0, 0, 39, '202'),
	(377, 1, 0, -50925, 204, 0, 0, 39, '203'),
	(377, 1, 0, -50925, 205, 0, 0, 39, '204'),
	(377, 1, 0, -50925, 206, 0, 0, 39, '205'),
	(377, 1, 0, -50925, 207, 0, 0, 39, '206'),
	(377, 1, 0, -50925, 208, 0, 0, 39, '207'),
	(377, 1, 0, -50925, 209, 0, 0, 39, '208'),
	(377, 1, 0, -50925, 210, 0, 0, 39, '209'),
	(377, 1, 0, -50925, 211, 0, 0, 39, '210'),
	(377, 1, 0, -50925, 212, 0, 0, 39, '211'),
	(377, 1, 0, -50925, 213, 0, 0, 39, '212'),
	(377, 1, 0, -50925, 214, 0, 0, 39, '213'),
	(377, 1, 0, -50925, 215, 0, 0, 39, '214'),
	(377, 1, 0, -50925, 216, 0, 0, 39, '215'),
	(377, 1, 0, -50925, 217, 0, 0, 39, '216'),
	(377, 1, 0, -50925, 218, 0, 0, 39, '217'),
	(377, 1, 0, -50925, 219, 0, 0, 39, '218'),
	(377, 1, 0, -50925, 220, 0, 0, 39, '219'),
	(377, 1, 0, -50925, 221, 0, 0, 39, '220'),
	(377, 1, 0, -50925, 222, 0, 0, 39, '221'),
	(377, 1, 0, -50925, 223, 0, 0, 39, '222'),
	(377, 1, 0, -50925, 224, 0, 0, 39, '223'),
	(377, 1, 0, -50925, 225, 0, 0, 39, '224'),
	(377, 1, 0, -50925, 226, 0, 0, 39, '225'),
	(377, 1, 0, -50925, 227, 0, 0, 39, '226'),
	(377, 1, 0, -50925, 228, 0, 0, 39, '227'),
	(377, 1, 0, -50925, 229, 0, 0, 39, '228'),
	(377, 1, 0, -50925, 230, 0, 0, 39, '229'),
	(377, 1, 0, -50925, 231, 0, 0, 39, '230'),
	(377, 1, 0, -50925, 232, 0, 0, 39, '231'),
	(377, 1, 0, -50925, 233, 0, 0, 39, '232'),
	(377, 1, 0, -50925, 234, 0, 0, 39, '233'),
	(377, 1, 0, -50925, 235, 0, 0, 39, '234'),
	(377, 1, 0, -50925, 236, 0, 0, 39, '235'),
	(377, 1, 0, -50925, 237, 0, 0, 39, '236'),
	(377, 1, 0, -50925, 238, 0, 0, 39, '237'),
	(377, 1, 0, -50925, 239, 0, 0, 39, '238'),
	(377, 1, 0, -50925, 240, 0, 0, 39, '239'),
	(377, 1, 0, -50925, 241, 0, 0, 39, '240'),
	(377, 1, 0, -50925, 242, 0, 0, 39, '241'),
	(377, 1, 0, -50925, 243, 0, 0, 39, '242'),
	(377, 1, 0, -50925, 244, 0, 0, 39, '243'),
	(377, 1, 0, -50925, 245, 0, 0, 39, '244'),
	(377, 1, 0, -50925, 246, 0, 0, 39, '245'),
	(377, 1, 0, -50925, 247, 0, 0, 39, '246'),
	(377, 1, 0, -50925, 248, 0, 0, 39, '247'),
	(377, 1, 0, -50925, 249, 0, 0, 39, '248'),
	(377, 1, 0, -50925, 250, 0, 0, 39, '249'),
	(377, 1, 0, -50925, 251, 0, 0, 39, '250'),
	(377, 1, 0, -50925, 252, 0, 0, 39, '251'),
	(377, 1, 0, -50925, 253, 0, 0, 39, '252'),
	(377, 1, 0, -50925, 254, 0, 0, 39, '253'),
	(377, 1, 0, -50925, 255, 0, 0, 39, '254'),
	(377, 1, 0, -50925, 256, 0, 0, 39, '255'),
	(377, 1, 0, -50925, 257, 0, 0, 39, '256'),
	(377, 1, 0, -50925, 258, 0, 0, 39, '257'),
	(377, 1, 0, -50925, 259, 0, 0, 39, '258'),
	(377, 1, 0, -50925, 260, 0, 0, 39, '259'),
	(377, 1, 0, -50925, 261, 0, 0, 39, '260'),
	(377, 1, 0, -50925, 262, 0, 0, 39, '261'),
	(377, 1, 0, -50925, 263, 0, 0, 39, '262'),
	(377, 1, 0, -50925, 264, 0, 0, 39, '263'),
	(377, 1, 0, -50925, 265, 0, 0, 39, '264'),
	(377, 1, 0, -50925, 266, 0, 0, 39, '265'),
	(377, 1, 0, -50925, 267, 0, 0, 39, '266'),
	(377, 1, 0, -50925, 268, 0, 0, 39, '267'),
	(377, 1, 0, -50925, 269, 0, 0, 39, '268'),
	(377, 1, 0, -50925, 270, 0, 0, 39, '269'),
	(377, 1, 0, -50925, 271, 0, 0, 39, '270'),
	(377, 1, 0, -50925, 272, 0, 0, 39, '271'),
	(377, 1, 0, -50925, 273, 0, 0, 39, '272'),
	(377, 1, 0, -50925, 274, 0, 0, 39, '273'),
	(377, 1, 0, -50925, 275, 0, 0, 39, '274'),
	(377, 1, 0, -50925, 276, 0, 0, 39, '275'),
	(377, 1, 0, -50925, 277, 0, 0, 39, '276'),
	(377, 1, 0, -50925, 278, 0, 0, 39, '277'),
	(377, 1, 0, -50925, 279, 0, 0, 39, '278'),
	(377, 1, 0, -50925, 280, 0, 0, 39, '279'),
	(377, 1, 0, -50925, 281, 0, 0, 39, '280'),
	(377, 1, 0, -50925, 282, 0, 0, 39, '281'),
	(377, 1, 0, -50925, 283, 0, 0, 39, '282'),
	(377, 1, 0, -50925, 284, 0, 0, 39, '283'),
	(377, 1, 0, -50925, 285, 0, 0, 39, '284'),
	(377, 1, 0, -50925, 286, 0, 0, 39, '285'),
	(377, 1, 0, -50925, 287, 0, 0, 39, '286'),
	(377, 1, 0, -50925, 288, 0, 0, 39, '287'),
	(377, 1, 0, -50925, 289, 0, 0, 39, '288'),
	(377, 1, 0, -50925, 290, 0, 0, 39, '289'),
	(377, 1, 0, -50925, 291, 0, 0, 39, '290'),
	(377, 1, 0, -50925, 292, 0, 0, 39, '291'),
	(377, 1, 0, -50925, 293, 0, 0, 39, '292'),
	(377, 1, 0, -50925, 294, 0, 0, 39, '293'),
	(377, 1, 0, -50925, 295, 0, 0, 39, '294'),
	(377, 1, 0, -50925, 296, 0, 0, 39, '295'),
	(377, 1, 0, -50925, 297, 0, 0, 39, '296'),
	(377, 1, 0, -50925, 298, 0, 0, 39, '297'),
	(377, 1, 0, -50925, 299, 0, 0, 39, '298'),
	(377, 1, 0, -50925, 300, 0, 0, 39, '299'),
	(377, 1, 0, -50925, 301, 0, 0, 39, '300'),
	(377, 1, 0, -50925, 302, 0, 0, 39, '301'),
	(377, 1, 0, -50925, 303, 0, 0, 39, '302'),
	(377, 1, 0, -50925, 304, 0, 0, 39, '303'),
	(377, 1, 0, -50925, 305, 0, 0, 39, '304'),
	(377, 1, 0, -50925, 306, 0, 0, 39, '305'),
	(377, 1, 0, -50925, 307, 0, 0, 39, '306'),
	(377, 1, 0, -50925, 308, 0, 0, 39, '307'),
	(377, 1, 0, -50925, 309, 0, 0, 39, '308'),
	(377, 1, 0, -50925, 310, 0, 0, 39, '309'),
	(377, 1, 0, -50925, 311, 0, 0, 39, '310'),
	(377, 1, 0, -50925, 312, 0, 0, 39, '311'),
	(377, 1, 0, -50925, 313, 0, 0, 39, '312'),
	(377, 1, 0, -50925, 314, 0, 0, 39, '313'),
	(377, 1, 0, -50925, 315, 0, 0, 39, '314'),
	(377, 1, 0, -50925, 316, 0, 0, 39, '315'),
	(377, 1, 0, -50925, 317, 0, 0, 39, '316'),
	(377, 1, 0, -50925, 318, 0, 0, 39, '317'),
	(377, 1, 0, -50925, 319, 0, 0, 39, '318'),
	(377, 1, 0, -50925, 320, 0, 0, 39, '319'),
	(377, 1, 0, -50925, 321, 0, 0, 39, '320'),
	(377, 1, 0, -50925, 322, 0, 0, 39, '321'),
	(377, 1, 0, -50925, 323, 0, 0, 39, '322'),
	(377, 1, 0, -50925, 324, 0, 0, 39, '323'),
	(377, 1, 0, -50925, 325, 0, 0, 39, '324'),
	(377, 1, 0, -50925, 326, 0, 0, 39, '325'),
	(377, 1, 0, -50925, 327, 0, 0, 39, '326'),
	(377, 1, 0, -50925, 328, 0, 0, 39, '327'),
	(377, 1, 0, -50925, 329, 0, 0, 39, '328'),
	(377, 1, 0, -50925, 330, 0, 0, 39, '329'),
	(377, 1, 0, -50925, 331, 0, 0, 39, '330'),
	(377, 1, 0, -50925, 332, 0, 0, 39, '331'),
	(377, 1, 0, -50925, 333, 0, 0, 39, '332'),
	(377, 1, 0, -50925, 334, 0, 0, 39, '333'),
	(377, 1, 0, -50925, 335, 0, 0, 39, '334'),
	(377, 1, 0, -50925, 336, 0, 0, 39, '335'),
	(377, 1, 0, -50925, 337, 0, 0, 39, '336'),
	(377, 1, 0, -50925, 338, 0, 0, 39, '337'),
	(377, 1, 0, -50925, 339, 0, 0, 39, '338'),
	(377, 1, 0, -50925, 340, 0, 0, 39, '339'),
	(377, 1, 0, -50925, 341, 0, 0, 39, '340'),
	(377, 1, 0, -50925, 342, 0, 0, 39, '341'),
	(377, 1, 0, -50925, 343, 0, 0, 39, '342'),
	(377, 1, 0, -50925, 344, 0, 0, 39, '343'),
	(377, 1, 0, -50925, 345, 0, 0, 39, '344'),
	(377, 1, 0, -50925, 346, 0, 0, 39, '345'),
	(377, 1, 0, -50925, 347, 0, 0, 39, '346'),
	(377, 1, 0, -50925, 348, 0, 0, 39, '347'),
	(377, 1, 0, -50925, 349, 0, 0, 39, '348'),
	(377, 1, 0, -50925, 350, 0, 0, 39, '349'),
	(377, 1, 0, -50925, 351, 0, 0, 39, '350'),
	(377, 1, 0, -50925, 352, 0, 0, 39, '351'),
	(377, 1, 0, -50925, 353, 0, 0, 39, '352'),
	(377, 1, 0, -50925, 354, 0, 0, 39, '353'),
	(377, 1, 0, -50925, 355, 0, 0, 39, '354'),
	(377, 1, 0, -50925, 356, 0, 0, 39, '355'),
	(377, 1, 0, -50925, 357, 0, 0, 39, '356'),
	(377, 1, 0, -50925, 358, 0, 0, 39, '357'),
	(377, 1, 0, -50925, 359, 0, 0, 39, '358'),
	(377, 1, 0, -50925, 360, 0, 0, 39, '359'),
	(377, 1, 0, -50925, 361, 0, 0, 39, '360'),
	(377, 1, 0, -50925, 362, 0, 0, 39, '361'),
	(377, 1, 0, -50925, 363, 0, 0, 39, '362'),
	(377, 1, 0, -50925, 364, 0, 0, 39, '363'),
	(377, 1, 0, -50925, 365, 0, 0, 39, '364'),
	(377, 1, 0, -50925, 366, 0, 0, 39, '365'),
	(377, 1, 0, -50925, 367, 0, 0, 39, '366'),
	(377, 1, 0, -50925, 368, 0, 0, 39, '367'),
	(377, 1, 0, -50925, 369, 0, 0, 39, '368'),
	(377, 1, 0, -50925, 370, 0, 0, 39, '369'),
	(377, 1, 0, -50925, 371, 0, 0, 39, '370'),
	(377, 1, 0, -50925, 372, 0, 0, 39, '371'),
	(377, 1, 0, -50925, 373, 0, 0, 39, '372'),
	(377, 1, 0, -50925, 374, 0, 0, 39, '373'),
	(377, 1, 0, -50925, 375, 0, 0, 39, '374'),
	(377, 1, 0, -50925, 376, 0, 0, 39, '375'),
	(377, 1, 0, -50925, 377, 0, 0, 39, '376'),
	(377, 1, 0, -50925, 378, 0, 0, 39, '377'),
	(377, 1, 0, -50925, 379, 0, 0, 39, '378'),
	(377, 1, 0, -50925, 380, 0, 0, 39, '379'),
	(377, 1, 0, -50925, 381, 0, 0, 39, '380'),
	(377, 1, 0, -50925, 382, 0, 0, 39, '381'),
	(377, 1, 0, -50925, 383, 0, 0, 39, '382'),
	(377, 1, 0, -50925, 384, 0, 0, 39, '383'),
	(377, 1, 0, -50925, 385, 0, 0, 39, '384'),
	(377, 1, 0, -50925, 386, 0, 0, 39, '385'),
	(377, 1, 0, -50925, 387, 0, 0, 39, '386'),
	(377, 1, 0, -50925, 388, 0, 0, 39, '387'),
	(377, 1, 0, -50925, 389, 0, 0, 39, '388'),
	(377, 1, 0, -50925, 390, 0, 0, 39, '389'),
	(377, 1, 0, -50925, 391, 0, 0, 39, '390'),
	(377, 1, 0, -50925, 392, 0, 0, 39, '391'),
	(377, 1, 0, -50925, 393, 0, 0, 39, '392'),
	(377, 1, 0, -50925, 394, 0, 0, 39, '393'),
	(377, 1, 0, -50925, 395, 0, 0, 39, '394'),
	(377, 1, 0, -50925, 396, 0, 0, 39, '395'),
	(377, 1, 0, -50925, 397, 0, 0, 39, '396'),
	(377, 1, 0, -50925, 398, 0, 0, 39, '397'),
	(377, 1, 0, -50925, 399, 0, 0, 39, '398'),
	(377, 1, 0, -50925, 400, 0, 0, 39, '399'),
	(377, 1, 0, -50925, 401, 0, 0, 39, '400'),
	(377, 1, 0, -50925, 402, 0, 0, 39, '401'),
	(377, 1, 0, -50925, 403, 0, 0, 39, '402'),
	(377, 1, 0, -50925, 404, 0, 0, 39, '403'),
	(377, 1, 0, -50925, 405, 0, 0, 39, '404'),
	(377, 1, 0, -50925, 406, 0, 0, 39, '405'),
	(377, 1, 0, -50925, 407, 0, 0, 39, '406'),
	(377, 1, 0, -50925, 408, 0, 0, 39, '407'),
	(377, 1, 0, -50925, 409, 0, 0, 39, '408'),
	(377, 1, 0, -50925, 410, 0, 0, 39, '409'),
	(377, 1, 0, -50925, 411, 0, 0, 39, '410'),
	(377, 1, 0, -50925, 412, 0, 0, 39, '411'),
	(377, 1, 0, -50925, 413, 0, 0, 39, '412'),
	(377, 1, 0, -50925, 414, 0, 0, 39, '413'),
	(377, 1, 0, -50925, 415, 0, 0, 39, '414'),
	(377, 1, 0, -50925, 416, 0, 0, 39, '415'),
	(377, 1, 0, -50925, 417, 0, 0, 39, '416'),
	(377, 1, 0, -50925, 418, 0, 0, 39, '417'),
	(377, 1, 0, -50925, 419, 0, 0, 39, '418'),
	(377, 1, 0, -50925, 420, 0, 0, 39, '419'),
	(377, 1, 0, -50925, 421, 0, 0, 39, '420'),
	(377, 1, 0, -50925, 422, 0, 0, 39, '421'),
	(377, 1, 0, -50925, 423, 0, 0, 39, '422'),
	(377, 1, 0, -50925, 424, 0, 0, 39, '423'),
	(377, 1, 0, -50925, 425, 0, 0, 39, '424'),
	(377, 1, 0, -50925, 426, 0, 0, 39, '425'),
	(377, 1, 0, -50925, 427, 0, 0, 39, '426'),
	(377, 1, 0, -50925, 428, 0, 0, 39, '427'),
	(377, 1, 0, -50925, 429, 0, 0, 39, '428'),
	(377, 1, 0, -50925, 430, 0, 0, 39, '429'),
	(377, 1, 0, -50925, 431, 0, 0, 39, '430'),
	(377, 1, 0, -50925, 432, 0, 0, 39, '431'),
	(377, 1, 0, -50925, 433, 0, 0, 39, '432'),
	(377, 1, 0, -50925, 434, 0, 0, 39, '433'),
	(377, 1, 0, -50925, 435, 0, 0, 39, '434'),
	(377, 1, 0, -50925, 436, 0, 0, 39, '435'),
	(377, 1, 0, -50925, 437, 0, 0, 39, '436'),
	(377, 1, 0, -50925, 438, 0, 0, 39, '437'),
	(377, 1, 0, -50925, 439, 0, 0, 39, '438'),
	(377, 1, 0, -50925, 440, 0, 0, 39, '439'),
	(377, 1, 0, -50925, 441, 0, 0, 39, '440'),
	(377, 1, 0, -50925, 442, 0, 0, 39, '441'),
	(377, 1, 0, -50925, 443, 0, 0, 39, '442'),
	(377, 1, 0, -50925, 444, 0, 0, 39, '443'),
	(377, 1, 0, -50925, 445, 0, 0, 39, '444'),
	(377, 1, 0, -50925, 446, 0, 0, 39, '445'),
	(377, 1, 0, -50925, 447, 0, 0, 39, '446'),
	(377, 1, 0, -50925, 448, 0, 0, 39, '447'),
	(377, 1, 0, -50925, 449, 0, 0, 39, '448'),
	(377, 1, 0, -50925, 450, 0, 0, 39, '449'),
	(377, 1, 0, -50925, 451, 0, 0, 39, '450'),
	(377, 1, 0, -50925, 452, 0, 0, 39, '451'),
	(377, 1, 0, -50925, 453, 0, 0, 39, '452'),
	(377, 1, 0, -50925, 454, 0, 0, 39, '453'),
	(377, 1, 0, -50925, 455, 0, 0, 39, '454'),
	(377, 1, 0, -50925, 456, 0, 0, 39, '455'),
	(377, 1, 0, -50925, 457, 0, 0, 39, '456'),
	(377, 1, 0, -50925, 458, 0, 0, 39, '457'),
	(377, 1, 0, -50925, 459, 0, 0, 39, '458'),
	(377, 1, 0, -50925, 460, 0, 0, 39, '459'),
	(377, 1, 0, -50925, 461, 0, 0, 39, '460'),
	(377, 1, 0, -50925, 462, 0, 0, 39, '461'),
	(377, 1, 0, -50925, 463, 0, 0, 39, '462'),
	(377, 1, 0, -50925, 464, 0, 0, 39, '463'),
	(377, 1, 0, -50925, 465, 0, 0, 39, '464'),
	(377, 1, 0, -50925, 466, 0, 0, 39, '465'),
	(377, 1, 0, -50925, 467, 0, 0, 39, '466'),
	(377, 1, 0, -50925, 468, 0, 0, 39, '467'),
	(377, 1, 0, -50925, 469, 0, 0, 39, '468'),
	(377, 1, 0, -50925, 470, 0, 0, 39, '469'),
	(377, 1, 0, -50925, 471, 0, 0, 39, '470'),
	(377, 1, 0, -50925, 472, 0, 0, 39, '471'),
	(377, 1, 0, -50925, 473, 0, 0, 39, '472'),
	(377, 1, 0, -50925, 474, 0, 0, 39, '473'),
	(377, 1, 0, -50925, 475, 0, 0, 39, '474'),
	(377, 1, 0, -50925, 476, 0, 0, 39, '475'),
	(377, 1, 0, -50925, 477, 0, 0, 39, '476'),
	(377, 1, 0, -50925, 478, 0, 0, 39, '477'),
	(377, 1, 0, -50925, 479, 0, 0, 39, '478'),
	(377, 1, 0, -50925, 480, 0, 0, 39, '479'),
	(377, 1, 0, -50925, 481, 0, 0, 39, '480'),
	(377, 1, 0, -50925, 482, 0, 0, 39, '481'),
	(377, 1, 0, -50925, 483, 0, 0, 39, '482'),
	(377, 1, 0, -50925, 484, 0, 0, 39, '483'),
	(377, 1, 0, -50925, 485, 0, 0, 39, '484'),
	(377, 1, 0, -50925, 486, 0, 0, 39, '485'),
	(377, 1, 0, -50925, 487, 0, 0, 39, '486'),
	(377, 1, 0, -50925, 488, 0, 0, 39, '487'),
	(377, 1, 0, -50925, 489, 0, 0, 39, '488'),
	(377, 1, 0, -50925, 490, 0, 0, 39, '489'),
	(377, 1, 0, -50925, 491, 0, 0, 39, '490'),
	(377, 1, 0, -50925, 492, 0, 0, 39, '491'),
	(377, 1, 0, -50925, 493, 0, 0, 39, '492'),
	(377, 1, 0, -50925, 494, 0, 0, 39, '493'),
	(377, 1, 0, -50925, 495, 0, 0, 39, '494'),
	(377, 1, 0, -50925, 496, 0, 0, 39, '495'),
	(377, 1, 0, -50925, 497, 0, 0, 39, '496'),
	(377, 1, 0, -50925, 498, 0, 0, 39, '497'),
	(377, 1, 0, -50925, 499, 0, 0, 39, '498'),
	(377, 1, 0, -50925, 500, 0, 0, 39, '499'),
	(377, 1, 0, -50925, 501, 0, 0, 39, '500'),
	(377, 1, 0, -50925, 502, 0, 0, 39, '501'),
	(377, 1, 0, -50925, 503, 0, 0, 39, '502'),
	(377, 1, 0, -50925, 504, 0, 0, 39, '503'),
	(377, 1, 0, -50925, 505, 0, 0, 39, '504'),
	(377, 1, 0, -50925, 506, 0, 0, 39, '505'),
	(377, 1, 0, -50925, 507, 0, 0, 39, '506'),
	(377, 1, 0, -50925, 508, 0, 0, 39, '507'),
	(377, 1, 0, -50925, 509, 0, 0, 39, '508'),
	(377, 1, 0, -50925, 510, 0, 0, 39, '509'),
	(377, 1, 0, -50925, 511, 0, 0, 39, '510'),
	(377, 1, 0, -50925, 512, 0, 0, 39, '511'),
	(377, 1, 0, -50925, 513, 0, 0, 39, '512'),
	(377, 1, 0, -50925, 514, 0, 0, 39, '513'),
	(377, 1, 0, -50925, 515, 0, 0, 39, '514'),
	(377, 1, 0, -50925, 516, 0, 0, 39, '515'),
	(377, 1, 0, -50925, 517, 0, 0, 39, '516'),
	(377, 1, 0, -50925, 518, 0, 0, 39, '517'),
	(377, 1, 0, -50925, 519, 0, 0, 39, '518'),
	(377, 1, 0, -50925, 520, 0, 0, 39, '519'),
	(377, 1, 0, -50925, 521, 0, 0, 39, '520'),
	(377, 1, 0, -50925, 522, 0, 0, 39, '521'),
	(377, 1, 0, -50925, 523, 0, 0, 39, '522'),
	(377, 1, 0, -50925, 524, 0, 0, 39, '523'),
	(377, 1, 0, -50925, 525, 0, 0, 39, '524'),
	(377, 1, 0, -50925, 526, 0, 0, 39, '525'),
	(377, 1, 0, -50925, 527, 0, 0, 39, '526'),
	(377, 1, 0, -50925, 528, 0, 0, 39, '527'),
	(377, 1, 0, -50925, 529, 0, 0, 39, '528'),
	(377, 1, 0, -50925, 530, 0, 0, 39, '529'),
	(377, 1, 0, -50925, 531, 0, 0, 39, '530'),
	(377, 1, 0, -50925, 532, 0, 0, 39, '531'),
	(377, 1, 0, -50925, 533, 0, 0, 39, '532'),
	(377, 1, 0, -50925, 534, 0, 0, 39, '533'),
	(377, 1, 0, -50925, 535, 0, 0, 39, '534'),
	(377, 1, 0, -50925, 536, 0, 0, 39, '535'),
	(377, 1, 0, -50925, 537, 0, 0, 39, '536'),
	(377, 1, 0, -50925, 538, 0, 0, 39, '537'),
	(377, 1, 0, -50925, 539, 0, 0, 39, '538'),
	(377, 1, 0, -50925, 540, 0, 0, 39, '539'),
	(377, 1, 0, -50925, 541, 0, 0, 39, '540'),
	(377, 1, 0, -50925, 542, 0, 0, 39, '541'),
	(377, 1, 0, -50925, 543, 0, 0, 39, '542'),
	(377, 1, 0, -50925, 544, 0, 0, 39, '543'),
	(377, 1, 0, -50925, 545, 0, 0, 39, '544'),
	(377, 1, 0, -50925, 546, 0, 0, 39, '545'),
	(377, 1, 0, -50925, 547, 0, 0, 39, '546'),
	(377, 1, 0, -50925, 548, 0, 0, 39, '547'),
	(377, 1, 0, -50925, 549, 0, 0, 39, '548'),
	(377, 1, 0, -50925, 550, 0, 0, 39, '549'),
	(377, 1, 0, -50925, 551, 0, 0, 39, '550'),
	(377, 1, 0, -50925, 552, 0, 0, 39, '551'),
	(377, 1, 0, -50925, 553, 0, 0, 39, '552'),
	(377, 1, 0, -50925, 554, 0, 0, 39, '553'),
	(377, 1, 0, -50925, 555, 0, 0, 39, '554'),
	(377, 1, 0, -50925, 556, 0, 0, 39, '555'),
	(377, 1, 0, -50925, 557, 0, 0, 39, '556'),
	(377, 1, 0, -50925, 558, 0, 0, 39, '557'),
	(377, 1, 0, -50925, 559, 0, 0, 39, '558'),
	(377, 1, 0, -50925, 560, 0, 0, 39, '559'),
	(377, 1, 0, -50925, 561, 0, 0, 39, '560'),
	(377, 1, 0, -50925, 562, 0, 0, 39, '561'),
	(377, 1, 0, -50925, 563, 0, 0, 39, '562'),
	(377, 1, 0, -50925, 564, 0, 0, 39, '563'),
	(377, 1, 0, -50925, 565, 0, 0, 39, '564'),
	(377, 1, 0, -50925, 566, 0, 0, 39, '565'),
	(377, 1, 0, -50925, 567, 0, 0, 39, '566'),
	(377, 1, 0, -50925, 568, 0, 0, 39, '567'),
	(377, 1, 0, -50925, 569, 0, 0, 39, '568'),
	(377, 1, 0, -50925, 570, 0, 0, 39, '569'),
	(377, 1, 0, -50925, 571, 0, 0, 39, '570'),
	(377, 1, 0, -50925, 572, 0, 0, 39, '571'),
	(377, 1, 0, -50925, 573, 0, 0, 39, '572'),
	(377, 1, 0, -50925, 574, 0, 0, 39, '573'),
	(377, 1, 0, -50925, 575, 0, 0, 39, '574'),
	(377, 1, 0, -50925, 576, 0, 0, 39, '575'),
	(377, 1, 0, -50925, 577, 0, 0, 39, '576'),
	(377, 1, 0, -50925, 578, 0, 0, 39, '577'),
	(377, 1, 0, -50925, 579, 0, 0, 39, '578'),
	(377, 1, 0, -50925, 580, 0, 0, 39, '579'),
	(377, 1, 0, -50925, 581, 0, 0, 39, '580'),
	(377, 1, 0, -50925, 582, 0, 0, 39, '581'),
	(377, 1, 0, -50925, 583, 0, 0, 39, '582'),
	(377, 1, 0, -50925, 584, 0, 0, 39, '583'),
	(377, 1, 0, -50925, 585, 0, 0, 39, '584'),
	(377, 1, 0, -50925, 586, 0, 0, 39, '585'),
	(377, 1, 0, -50925, 587, 0, 0, 39, '586'),
	(377, 1, 0, -50925, 588, 0, 0, 39, '587'),
	(377, 1, 0, -50925, 589, 0, 0, 39, '588'),
	(377, 1, 0, -50925, 590, 0, 0, 39, '589'),
	(377, 1, 0, -50925, 591, 0, 0, 39, '590'),
	(377, 1, 0, -50925, 592, 0, 0, 39, '591'),
	(377, 1, 0, -50925, 593, 0, 0, 39, '592'),
	(377, 1, 0, -50925, 594, 0, 0, 39, '593'),
	(377, 1, 0, -50925, 595, 0, 0, 39, '594'),
	(377, 1, 0, -50925, 596, 0, 0, 39, '595'),
	(377, 1, 0, -50925, 597, 0, 0, 39, '596'),
	(377, 1, 0, -50925, 598, 0, 0, 39, '597'),
	(377, 1, 0, -50925, 599, 0, 0, 39, '598'),
	(377, 1, 0, -50925, 600, 0, 0, 39, '599'),
	(377, 1, 0, -50925, 601, 0, 0, 39, '600'),
	(377, 1, 0, -50925, 602, 0, 0, 39, '601'),
	(377, 1, 0, -50925, 603, 0, 0, 39, '602'),
	(377, 1, 0, -50925, 604, 0, 0, 39, '603'),
	(377, 1, 0, -50925, 605, 0, 0, 39, '604'),
	(377, 1, 0, -50925, 606, 0, 0, 39, '605'),
	(377, 1, 0, -50925, 607, 0, 0, 39, '606'),
	(377, 1, 0, -50925, 608, 0, 0, 39, '607'),
	(377, 1, 0, -50925, 609, 0, 0, 39, '608'),
	(377, 1, 0, -50925, 610, 0, 0, 39, '609'),
	(377, 1, 0, -50925, 611, 0, 0, 39, '610'),
	(377, 1, 0, -50925, 612, 0, 0, 39, '611'),
	(377, 1, 0, -50925, 613, 0, 0, 39, '612'),
	(377, 1, 0, -50925, 614, 0, 0, 39, '613'),
	(377, 1, 0, -50925, 615, 0, 0, 39, '614'),
	(377, 1, 0, -50925, 616, 0, 0, 39, '615'),
	(377, 1, 0, -50925, 617, 0, 0, 39, '616'),
	(377, 1, 0, -50925, 618, 0, 0, 39, '617'),
	(377, 1, 0, -50925, 619, 0, 0, 39, '618'),
	(377, 1, 0, -50925, 620, 0, 0, 39, '619'),
	(377, 1, 0, -50925, 621, 0, 0, 39, '620'),
	(377, 1, 0, -50925, 622, 0, 0, 39, '621'),
	(377, 1, 0, -50925, 623, 0, 0, 39, '622'),
	(377, 1, 0, -50925, 624, 0, 0, 39, '623'),
	(377, 1, 0, -50925, 625, 0, 0, 39, '624'),
	(377, 1, 0, -50925, 626, 0, 0, 39, '625'),
	(377, 1, 0, -50925, 627, 0, 0, 39, '626'),
	(377, 1, 0, -50925, 628, 0, 0, 39, '627'),
	(377, 1, 0, -50925, 629, 0, 0, 39, '628'),
	(377, 1, 0, -50925, 630, 0, 0, 39, '629'),
	(377, 1, 0, -50925, 631, 0, 0, 39, '630'),
	(377, 1, 0, -50925, 632, 0, 0, 39, '631'),
	(377, 1, 0, -50925, 633, 0, 0, 39, '632'),
	(377, 1, 0, -50925, 634, 0, 0, 39, '633'),
	(377, 1, 0, -50925, 635, 0, 0, 39, '634'),
	(377, 1, 0, -50925, 636, 0, 0, 39, '635'),
	(377, 1, 0, -50925, 637, 0, 0, 39, '636'),
	(377, 1, 0, -50925, 638, 0, 0, 39, '637'),
	(377, 1, 0, -50925, 639, 0, 0, 39, '638'),
	(377, 1, 0, -50925, 640, 0, 0, 39, '639'),
	(377, 1, 0, -50925, 641, 0, 0, 39, '640'),
	(377, 1, 0, -50925, 642, 0, 0, 39, '641'),
	(377, 1, 0, -50925, 643, 0, 0, 39, '642'),
	(377, 1, 0, -50925, 644, 0, 0, 39, '643'),
	(377, 1, 0, -50925, 645, 0, 0, 39, '644'),
	(377, 1, 0, -50925, 646, 0, 0, 39, '645'),
	(377, 1, 0, -50925, 647, 0, 0, 39, '646'),
	(377, 1, 0, -50925, 648, 0, 0, 39, '647'),
	(377, 1, 0, -50925, 649, 0, 0, 39, '648'),
	(377, 1, 0, -50925, 650, 0, 0, 39, '649'),
	(377, 1, 0, -50925, 651, 0, 0, 39, '650'),
	(377, 1, 0, -50925, 652, 0, 0, 39, '651'),
	(377, 1, 0, -50925, 653, 0, 0, 39, '652'),
	(377, 1, 0, -50925, 654, 0, 0, 39, '653'),
	(377, 1, 0, -50925, 655, 0, 0, 39, '654'),
	(377, 1, 0, -50925, 656, 0, 0, 39, '655'),
	(377, 1, 0, -50925, 657, 0, 0, 39, '656'),
	(377, 1, 0, -50925, 658, 0, 0, 39, '657'),
	(377, 1, 0, -50925, 659, 0, 0, 39, '658'),
	(377, 1, 0, -50925, 660, 0, 0, 39, '659'),
	(377, 1, 0, -50925, 661, 0, 0, 39, '660'),
	(377, 1, 0, -50925, 662, 0, 0, 39, '661'),
	(377, 1, 0, -50925, 663, 0, 0, 39, '662'),
	(377, 1, 0, -50925, 664, 0, 0, 39, '663'),
	(377, 1, 0, -50925, 665, 0, 0, 39, '664'),
	(377, 1, 0, -50925, 666, 0, 0, 39, '665'),
	(377, 1, 0, -50925, 667, 0, 0, 39, '666'),
	(377, 1, 0, -50925, 668, 0, 0, 39, '667'),
	(377, 1, 0, -50925, 669, 0, 0, 39, '668'),
	(377, 1, 0, -50925, 670, 0, 0, 39, '669'),
	(377, 1, 0, -50925, 671, 0, 0, 39, '670'),
	(377, 1, 0, -50925, 672, 0, 0, 39, '671'),
	(377, 1, 0, -50925, 673, 0, 0, 39, '672'),
	(377, 1, 0, -50925, 674, 0, 0, 39, '673'),
	(377, 1, 0, -50925, 675, 0, 0, 39, '674'),
	(377, 1, 0, -50925, 676, 0, 0, 39, '675'),
	(377, 1, 0, -50925, 677, 0, 0, 39, '676'),
	(377, 1, 0, -50925, 678, 0, 0, 39, '677'),
	(377, 1, 0, -50925, 679, 0, 0, 39, '678'),
	(377, 1, 0, -50925, 680, 0, 0, 39, '679'),
	(377, 1, 0, -50925, 681, 0, 0, 39, '680'),
	(377, 1, 0, -50925, 682, 0, 0, 39, '681'),
	(377, 1, 0, -50925, 683, 0, 0, 39, '682'),
	(377, 1, 0, -50925, 684, 0, 0, 39, '683'),
	(377, 1, 0, -50925, 685, 0, 0, 39, '684'),
	(377, 1, 0, -50925, 686, 0, 0, 39, '685'),
	(377, 1, 0, -50925, 687, 0, 0, 39, '686'),
	(377, 1, 0, -50925, 688, 0, 0, 39, '687'),
	(377, 1, 0, -50925, 689, 0, 0, 39, '688'),
	(377, 1, 0, -50925, 690, 0, 0, 39, '689'),
	(377, 1, 0, -50925, 691, 0, 0, 39, '690'),
	(377, 1, 0, -50925, 692, 0, 0, 39, '691'),
	(377, 1, 0, -50925, 693, 0, 0, 39, '692'),
	(377, 1, 0, -50925, 694, 0, 0, 39, '693'),
	(377, 1, 0, -50925, 695, 0, 0, 39, '694'),
	(377, 1, 0, -50925, 696, 0, 0, 39, '695'),
	(377, 1, 0, -50925, 697, 0, 0, 39, '696'),
	(377, 1, 0, -50925, 698, 0, 0, 39, '697'),
	(377, 1, 0, -50925, 699, 0, 0, 39, '698'),
	(377, 1, 0, -50925, 700, 0, 0, 39, '699'),
	(377, 1, 0, -50925, 701, 0, 0, 39, '700'),
	(377, 1, 0, -50925, 702, 0, 0, 39, '701'),
	(377, 1, 0, -50925, 703, 0, 0, 39, '702'),
	(377, 1, 0, -50925, 704, 0, 0, 39, '703'),
	(377, 1, 0, -50925, 705, 0, 0, 39, '704'),
	(377, 1, 0, -50925, 706, 0, 0, 39, '705'),
	(377, 1, 0, -50925, 707, 0, 0, 39, '706'),
	(377, 1, 0, -50925, 708, 0, 0, 39, '707'),
	(377, 1, 0, -50925, 709, 0, 0, 39, '708'),
	(377, 1, 0, -50925, 710, 0, 0, 39, '709'),
	(377, 1, 0, -50925, 711, 0, 0, 39, '710'),
	(377, 1, 0, -50925, 712, 0, 0, 39, '711'),
	(377, 1, 0, -50925, 713, 0, 0, 39, '712'),
	(377, 1, 0, -50925, 714, 0, 0, 39, '713'),
	(377, 1, 0, -50925, 715, 0, 0, 39, '714'),
	(377, 1, 0, -50925, 716, 0, 0, 39, '715'),
	(377, 1, 0, -50925, 717, 0, 0, 39, '716'),
	(377, 1, 0, -50925, 718, 0, 0, 39, '717'),
	(377, 1, 0, -50925, 719, 0, 0, 39, '718'),
	(377, 1, 0, -50925, 720, 0, 0, 39, '719'),
	(377, 1, 0, -50925, 721, 0, 0, 39, '720'),
	(377, 1, 0, -50925, 722, 0, 0, 39, '721'),
	(377, 1, 0, -50925, 723, 0, 0, 39, '722'),
	(377, 1, 0, -50925, 724, 0, 0, 39, '723'),
	(377, 1, 0, -50925, 725, 0, 0, 39, '724'),
	(377, 1, 0, -50925, 726, 0, 0, 39, '725'),
	(377, 1, 0, -50925, 727, 0, 0, 39, '726'),
	(377, 1, 0, -50925, 728, 0, 0, 39, '727'),
	(377, 1, 0, -50925, 729, 0, 0, 39, '728'),
	(377, 1, 0, -50925, 730, 0, 0, 39, '729'),
	(377, 1, 0, -50925, 731, 0, 0, 39, '730'),
	(377, 1, 0, -50925, 732, 0, 0, 39, '731'),
	(377, 1, 0, -50925, 733, 0, 0, 39, '732'),
	(377, 1, 0, -50925, 734, 0, 0, 39, '733'),
	(377, 1, 0, -50925, 735, 0, 0, 39, '734'),
	(377, 1, 0, -50925, 736, 0, 0, 39, '735'),
	(377, 1, 0, -50925, 737, 0, 0, 39, '736'),
	(377, 1, 0, -50925, 738, 0, 0, 39, '737'),
	(377, 1, 0, -50925, 739, 0, 0, 39, '738'),
	(377, 1, 0, -50925, 740, 0, 0, 39, '739'),
	(377, 1, 0, -50925, 741, 0, 0, 39, '740'),
	(377, 1, 0, -50925, 742, 0, 0, 39, '741'),
	(377, 1, 0, -50925, 743, 0, 0, 39, '742'),
	(377, 1, 0, -50925, 744, 0, 0, 39, '743'),
	(377, 1, 0, -50925, 745, 0, 0, 39, '744'),
	(377, 1, 0, -50925, 746, 0, 0, 39, '745'),
	(377, 1, 0, -50925, 747, 0, 0, 39, '746'),
	(377, 1, 0, -50925, 748, 0, 0, 39, '747'),
	(377, 1, 0, -50925, 749, 0, 0, 39, '748'),
	(377, 1, 0, -50925, 750, 0, 0, 39, '749'),
	(377, 1, 0, -50925, 751, 0, 0, 39, '750'),
	(377, 1, 0, -50925, 752, 0, 0, 39, '751'),
	(377, 1, 0, -50925, 753, 0, 0, 39, '752'),
	(377, 1, 0, -50925, 754, 0, 0, 39, '753'),
	(377, 1, 0, -50925, 755, 0, 0, 39, '754'),
	(377, 1, 0, -50925, 756, 0, 0, 39, '755'),
	(377, 1, 0, -50925, 757, 0, 0, 39, '756'),
	(377, 1, 0, -50925, 758, 0, 0, 39, '757'),
	(377, 1, 0, -50925, 759, 0, 0, 39, '758'),
	(377, 1, 0, -50925, 760, 0, 0, 39, '759'),
	(377, 1, 0, -50925, 761, 0, 0, 39, '760'),
	(377, 1, 0, -50925, 762, 0, 0, 39, '761'),
	(377, 1, 0, -50925, 763, 0, 0, 39, '762'),
	(377, 1, 0, -50925, 764, 0, 0, 39, '763'),
	(377, 1, 0, -50925, 765, 0, 0, 39, '764'),
	(377, 1, 0, -50925, 766, 0, 0, 39, '765'),
	(377, 1, 0, -50925, 767, 0, 0, 39, '766'),
	(377, 1, 0, -50925, 768, 0, 0, 39, '767'),
	(377, 1, 0, -50925, 769, 0, 0, 39, '768'),
	(377, 1, 0, -50925, 770, 0, 0, 39, '769'),
	(377, 1, 0, -50925, 771, 0, 0, 39, '770'),
	(377, 1, 0, -50925, 772, 0, 0, 39, '771'),
	(377, 1, 0, -50925, 773, 0, 0, 39, '772'),
	(377, 1, 0, -50925, 774, 0, 0, 39, '773'),
	(377, 1, 0, -50925, 775, 0, 0, 39, '774'),
	(377, 1, 0, -50925, 776, 0, 0, 39, '775'),
	(377, 1, 0, -50925, 777, 0, 0, 39, '776'),
	(377, 1, 0, -50925, 778, 0, 0, 39, '777'),
	(377, 1, 0, -50925, 779, 0, 0, 39, '778'),
	(377, 1, 0, -50925, 780, 0, 0, 39, '779'),
	(377, 1, 0, -50925, 781, 0, 0, 39, '780'),
	(377, 1, 0, -50925, 782, 0, 0, 39, '781'),
	(377, 1, 0, -50925, 783, 0, 0, 39, '782'),
	(377, 1, 0, -50925, 784, 0, 0, 39, '783'),
	(377, 1, 0, -50925, 785, 0, 0, 39, '784'),
	(377, 1, 0, -50925, 786, 0, 0, 39, '785'),
	(377, 1, 0, -50925, 787, 0, 0, 39, '786'),
	(377, 1, 0, -50925, 788, 0, 0, 39, '787'),
	(377, 1, 0, -50925, 789, 0, 0, 39, '788'),
	(377, 1, 0, -50925, 790, 0, 0, 39, '789'),
	(377, 1, 0, -50925, 791, 0, 0, 39, '790'),
	(377, 1, 0, -50925, 792, 0, 0, 39, '791'),
	(377, 1, 0, -50925, 793, 0, 0, 39, '792'),
	(377, 1, 0, -50925, 794, 0, 0, 39, '793'),
	(377, 1, 0, -50925, 795, 0, 0, 39, '794'),
	(377, 1, 0, -50925, 796, 0, 0, 39, '795'),
	(377, 1, 0, -50925, 797, 0, 0, 39, '796'),
	(377, 1, 0, -50925, 798, 0, 0, 39, '797'),
	(377, 1, 0, -50925, 799, 0, 0, 39, '798'),
	(377, 1, 0, -50925, 800, 0, 0, 39, '799'),
	(377, 1, 0, -50925, 801, 0, 0, 39, '800'),
	(377, 1, 0, -50925, 802, 0, 0, 39, '801'),
	(377, 1, 0, -50925, 803, 0, 0, 39, '802'),
	(377, 1, 0, -50925, 804, 0, 0, 39, '803'),
	(377, 1, 0, -50925, 805, 0, 0, 39, '804'),
	(377, 1, 0, -50925, 806, 0, 0, 39, '805'),
	(377, 1, 0, -50925, 807, 0, 0, 39, '806'),
	(377, 1, 0, -50925, 808, 0, 0, 39, '807'),
	(377, 1, 0, -50925, 809, 0, 0, 39, '808'),
	(377, 1, 0, -50925, 810, 0, 0, 39, '809'),
	(377, 1, 0, -50925, 811, 0, 0, 39, '810'),
	(377, 1, 0, -50925, 812, 0, 0, 39, '811'),
	(377, 1, 0, -50925, 813, 0, 0, 39, '812'),
	(377, 1, 0, -50925, 814, 0, 0, 39, '813'),
	(377, 1, 0, -50925, 815, 0, 0, 39, '814'),
	(377, 1, 0, -50925, 816, 0, 0, 39, '815'),
	(377, 1, 0, -50925, 817, 0, 0, 39, '816'),
	(377, 1, 0, -50925, 818, 0, 0, 39, '817'),
	(377, 1, 0, -50925, 819, 0, 0, 39, '818'),
	(377, 1, 0, -50925, 820, 0, 0, 39, '819'),
	(377, 1, 0, -50925, 821, 0, 0, 39, '820'),
	(377, 1, 0, -50925, 822, 0, 0, 39, '821'),
	(377, 1, 0, -50925, 823, 0, 0, 39, '822'),
	(377, 1, 0, -50925, 824, 0, 0, 39, '823'),
	(377, 1, 0, -50925, 825, 0, 0, 39, '824'),
	(377, 1, 0, -50925, 826, 0, 0, 39, '825'),
	(377, 1, 0, -50925, 827, 0, 0, 39, '826'),
	(377, 1, 0, -50925, 828, 0, 0, 39, '827'),
	(377, 1, 0, -50925, 829, 0, 0, 39, '828'),
	(377, 1, 0, -50925, 830, 0, 0, 39, '829'),
	(377, 1, 0, -50925, 831, 0, 0, 39, '830'),
	(377, 1, 0, -50925, 832, 0, 0, 39, '831'),
	(377, 1, 0, -50925, 833, 0, 0, 39, '832'),
	(377, 1, 0, -50925, 834, 0, 0, 39, '833'),
	(377, 1, 0, -50925, 835, 0, 0, 39, '834'),
	(377, 1, 0, -50925, 836, 0, 0, 39, '835'),
	(377, 1, 0, -50925, 837, 0, 0, 39, '836'),
	(377, 1, 0, -50925, 838, 0, 0, 39, '837'),
	(377, 1, 0, -50925, 839, 0, 0, 39, '838'),
	(377, 1, 0, -50925, 840, 0, 0, 39, '839'),
	(377, 1, 0, -50925, 841, 0, 0, 39, '840'),
	(377, 1, 0, -50925, 842, 0, 0, 39, '841'),
	(377, 1, 0, -50925, 843, 0, 0, 39, '842'),
	(377, 1, 0, -50925, 844, 0, 0, 39, '843'),
	(377, 1, 0, -50925, 845, 0, 0, 39, '844'),
	(377, 1, 0, -50925, 846, 0, 0, 39, '845'),
	(377, 1, 0, -50925, 847, 0, 0, 39, '846'),
	(377, 1, 0, -50925, 848, 0, 0, 39, '847'),
	(377, 1, 0, -50925, 849, 0, 0, 39, '848'),
	(377, 1, 0, -50925, 850, 0, 0, 39, '849'),
	(377, 1, 0, -50925, 851, 0, 0, 39, '850'),
	(377, 1, 0, -50925, 852, 0, 0, 39, '851'),
	(377, 1, 0, -50925, 853, 0, 0, 39, '852'),
	(377, 1, 0, -50925, 854, 0, 0, 39, '853'),
	(377, 1, 0, -50925, 855, 0, 0, 39, '854'),
	(377, 1, 0, -50925, 856, 0, 0, 39, '855'),
	(377, 1, 0, -50925, 857, 0, 0, 39, '856'),
	(377, 1, 0, -50925, 858, 0, 0, 39, '857'),
	(377, 1, 0, -50925, 859, 0, 0, 39, '858'),
	(377, 1, 0, -50925, 860, 0, 0, 39, '859'),
	(377, 1, 0, -50925, 861, 0, 0, 39, '860'),
	(377, 1, 0, -50925, 862, 0, 0, 39, '861'),
	(377, 1, 0, -50925, 863, 0, 0, 39, '862'),
	(377, 1, 0, -50925, 864, 0, 0, 39, '863'),
	(377, 1, 0, -50925, 865, 0, 0, 39, '864'),
	(377, 1, 0, -50925, 866, 0, 0, 39, '865'),
	(377, 1, 0, -50925, 867, 0, 0, 39, '866'),
	(377, 1, 0, -50925, 868, 0, 0, 39, '867'),
	(377, 1, 0, -50925, 869, 0, 0, 39, '868'),
	(377, 1, 0, -50925, 870, 0, 0, 39, '869'),
	(377, 1, 0, -50925, 871, 0, 0, 39, '870'),
	(377, 1, 0, -50925, 872, 0, 0, 39, '871'),
	(377, 1, 0, -50925, 873, 0, 0, 39, '872'),
	(377, 1, 0, -50925, 874, 0, 0, 39, '873'),
	(377, 1, 0, -50925, 875, 0, 0, 39, '874'),
	(377, 1, 0, -50925, 876, 0, 0, 39, '875'),
	(377, 1, 0, -50925, 877, 0, 0, 39, '876'),
	(377, 1, 0, -50925, 878, 0, 0, 39, '877'),
	(377, 1, 0, -50925, 879, 0, 0, 39, '878'),
	(377, 1, 0, -50925, 880, 0, 0, 39, '879'),
	(377, 1, 0, -50925, 881, 0, 0, 39, '880'),
	(377, 1, 0, -50925, 882, 0, 0, 39, '881'),
	(377, 1, 0, -50925, 883, 0, 0, 39, '882'),
	(377, 1, 0, -50925, 884, 0, 0, 39, '883'),
	(377, 1, 0, -50925, 885, 0, 0, 39, '884'),
	(377, 1, 0, -50925, 886, 0, 0, 39, '885'),
	(377, 1, 0, -50925, 887, 0, 0, 39, '886'),
	(377, 1, 0, -50925, 888, 0, 0, 39, '887'),
	(377, 1, 0, -50925, 889, 0, 0, 39, '888'),
	(377, 1, 0, -50925, 890, 0, 0, 39, '889'),
	(377, 1, 0, -50925, 891, 0, 0, 39, '890'),
	(377, 1, 0, -50925, 892, 0, 0, 39, '891'),
	(377, 1, 0, -50925, 893, 0, 0, 39, '892'),
	(377, 1, 0, -50925, 894, 0, 0, 39, '893'),
	(377, 1, 0, -50925, 895, 0, 0, 39, '894'),
	(377, 1, 0, -50925, 896, 0, 0, 39, '895'),
	(377, 1, 0, -50925, 897, 0, 0, 39, '896'),
	(377, 1, 0, -50925, 898, 0, 0, 39, '897'),
	(377, 1, 0, -50925, 899, 0, 0, 39, '898'),
	(377, 1, 0, -50925, 900, 0, 0, 39, '899'),
	(377, 1, 0, -50925, 901, 0, 0, 39, '900'),
	(377, 1, 0, -50925, 902, 0, 0, 39, '901'),
	(377, 1, 0, -50925, 903, 0, 0, 39, '902'),
	(377, 1, 0, -50925, 904, 0, 0, 39, '903'),
	(377, 1, 0, -50925, 905, 0, 0, 39, '904'),
	(377, 1, 0, -50925, 906, 0, 0, 39, '905'),
	(377, 1, 0, -50925, 907, 0, 0, 39, '906'),
	(377, 1, 0, -50925, 908, 0, 0, 39, '907'),
	(377, 1, 0, -50925, 909, 0, 0, 39, '908'),
	(377, 1, 0, -50925, 910, 0, 0, 39, '909'),
	(377, 1, 0, -50925, 911, 0, 0, 39, '910'),
	(377, 1, 0, -50925, 912, 0, 0, 39, '911'),
	(377, 1, 0, -50925, 913, 0, 0, 39, '912'),
	(377, 1, 0, -50925, 914, 0, 0, 39, '913'),
	(377, 1, 0, -50925, 915, 0, 0, 39, '914'),
	(377, 1, 0, -50925, 916, 0, 0, 39, '915'),
	(377, 1, 0, -50925, 917, 0, 0, 39, '916'),
	(377, 1, 0, -50925, 918, 0, 0, 39, '917'),
	(377, 1, 0, -50925, 919, 0, 0, 39, '918'),
	(377, 1, 0, -50925, 920, 0, 0, 39, '919'),
	(377, 1, 0, -50925, 921, 0, 0, 39, '920'),
	(377, 1, 0, -50925, 922, 0, 0, 39, '921'),
	(377, 1, 0, -50925, 923, 0, 0, 39, '922'),
	(377, 1, 0, -50925, 924, 0, 0, 39, '923'),
	(377, 1, 0, -50925, 925, 0, 0, 39, '924'),
	(377, 1, 0, -50925, 926, 0, 0, 39, '925'),
	(377, 1, 0, -50925, 927, 0, 0, 39, '926'),
	(377, 1, 0, -50925, 928, 0, 0, 39, '927'),
	(377, 1, 0, -50925, 929, 0, 0, 39, '928'),
	(377, 1, 0, -50925, 930, 0, 0, 39, '929'),
	(377, 1, 0, -50925, 931, 0, 0, 39, '930'),
	(377, 1, 0, -50925, 932, 0, 0, 39, '931'),
	(377, 1, 0, -50925, 933, 0, 0, 39, '932'),
	(377, 1, 0, -50925, 934, 0, 0, 39, '933'),
	(377, 1, 0, -50925, 935, 0, 0, 39, '934'),
	(377, 1, 0, -50925, 936, 0, 0, 39, '935'),
	(377, 1, 0, -50925, 937, 0, 0, 39, '936'),
	(377, 1, 0, -50925, 938, 0, 0, 39, '937'),
	(377, 1, 0, -50925, 939, 0, 0, 39, '938'),
	(377, 1, 0, -50925, 940, 0, 0, 39, '939'),
	(377, 1, 0, -50925, 941, 0, 0, 39, '940'),
	(377, 1, 0, -50925, 942, 0, 0, 39, '941'),
	(377, 1, 0, -50925, 943, 0, 0, 39, '942'),
	(377, 1, 0, -50925, 944, 0, 0, 39, '943'),
	(377, 1, 0, -50925, 945, 0, 0, 39, '944'),
	(377, 1, 0, -50925, 946, 0, 0, 39, '945'),
	(377, 1, 0, -50925, 947, 0, 0, 39, '946'),
	(377, 1, 0, -50925, 948, 0, 0, 39, '947'),
	(377, 1, 0, -50925, 949, 0, 0, 39, '948'),
	(377, 1, 0, -50925, 950, 0, 0, 39, '949'),
	(377, 1, 0, -50925, 951, 0, 0, 39, '950'),
	(377, 1, 0, -50925, 952, 0, 0, 39, '951'),
	(377, 1, 0, -50925, 953, 0, 0, 39, '952'),
	(377, 1, 0, -50925, 954, 0, 0, 39, '953'),
	(377, 1, 0, -50925, 955, 0, 0, 39, '954'),
	(377, 1, 0, -50925, 956, 0, 0, 39, '955'),
	(377, 1, 0, -50925, 957, 0, 0, 39, '956'),
	(377, 1, 0, -50925, 958, 0, 0, 39, '957'),
	(377, 1, 0, -50925, 959, 0, 0, 39, '958'),
	(377, 1, 0, -50925, 960, 0, 0, 39, '959'),
	(377, 1, 0, -50925, 961, 0, 0, 39, '960'),
	(377, 1, 0, -50925, 962, 0, 0, 39, '961'),
	(377, 1, 0, -50925, 963, 0, 0, 39, '962'),
	(377, 1, 0, -50925, 964, 0, 0, 39, '963'),
	(377, 1, 0, -50925, 965, 0, 0, 39, '964'),
	(377, 1, 0, -50925, 966, 0, 0, 39, '965'),
	(377, 1, 0, -50925, 967, 0, 0, 39, '966'),
	(377, 1, 0, -50925, 968, 0, 0, 39, '967'),
	(377, 1, 0, -50925, 969, 0, 0, 39, '968'),
	(377, 1, 0, -50925, 970, 0, 0, 39, '969'),
	(377, 1, 0, -50925, 971, 0, 0, 39, '970'),
	(377, 1, 0, -50925, 972, 0, 0, 39, '971'),
	(377, 1, 0, -50925, 973, 0, 0, 39, '972'),
	(377, 1, 0, -50925, 974, 0, 0, 39, '973'),
	(377, 1, 0, -50925, 975, 0, 0, 39, '974'),
	(377, 1, 0, -50925, 976, 0, 0, 39, '975'),
	(377, 1, 0, -50925, 977, 0, 0, 39, '976'),
	(377, 1, 0, -50925, 978, 0, 0, 39, '977'),
	(377, 1, 0, -50925, 979, 0, 0, 39, '978'),
	(377, 1, 0, -50925, 980, 0, 0, 39, '979'),
	(377, 1, 0, -50925, 981, 0, 0, 39, '980'),
	(377, 1, 0, -50925, 982, 0, 0, 39, '981'),
	(377, 1, 0, -50925, 983, 0, 0, 39, '982'),
	(377, 1, 0, -50925, 984, 0, 0, 39, '983'),
	(377, 1, 0, -50925, 985, 0, 0, 39, '984'),
	(377, 1, 0, -50925, 986, 0, 0, 39, '985'),
	(377, 1, 0, -50925, 987, 0, 0, 39, '986'),
	(377, 1, 0, -50925, 988, 0, 0, 39, '987'),
	(377, 1, 0, -50925, 989, 0, 0, 39, '988'),
	(377, 1, 0, -50925, 990, 0, 0, 39, '989'),
	(377, 1, 0, -50925, 991, 0, 0, 39, '990'),
	(377, 1, 0, -50925, 992, 0, 0, 39, '991'),
	(377, 1, 0, -50925, 993, 0, 0, 39, '992'),
	(377, 1, 0, -50925, 994, 0, 0, 39, '993'),
	(377, 1, 0, -50925, 995, 0, 0, 39, '994'),
	(377, 1, 0, -50925, 996, 0, 0, 39, '995'),
	(377, 1, 0, -50925, 997, 0, 0, 39, '996'),
	(377, 1, 0, -50925, 998, 0, 0, 39, '997'),
	(377, 1, 0, -50925, 999, 0, 0, 39, '998'),
	(377, 1, 0, -50925, 1000, 0, 0, 39, '999'),
	(377, 1, 0, -50925, 1001, 0, 0, 39, '1000'),
	(377, 1, 0, -50925, 1002, 0, 0, 39, '1001'),
	(377, 1, 0, -50925, 1003, 0, 0, 39, '1002'),
	(377, 1, 0, -50925, 1004, 0, 0, 39, '1003'),
	(377, 1, 0, -50925, 1005, 0, 0, 39, '1004'),
	(377, 1, 0, -50925, 1006, 0, 0, 39, '1005'),
	(377, 1, 0, -50925, 1007, 0, 0, 39, '1006'),
	(377, 1, 0, -50925, 1008, 0, 0, 39, '1007'),
	(377, 1, 0, -50925, 1009, 0, 0, 39, '1008'),
	(377, 1, 0, -50925, 1010, 0, 0, 39, '1009'),
	(377, 1, 0, -50925, 1011, 0, 0, 39, '1010'),
	(377, 1, 0, -50925, 1012, 0, 0, 39, '1011'),
	(377, 1, 0, -50925, 1013, 0, 0, 39, '1012'),
	(377, 1, 0, -50925, 1014, 0, 0, 39, '1013'),
	(377, 1, 0, -50925, 1015, 0, 0, 39, '1014'),
	(377, 1, 0, -50925, 1016, 0, 0, 39, '1015'),
	(377, 1, 0, -50925, 1017, 0, 0, 39, '1016'),
	(377, 1, 0, -50925, 1018, 0, 0, 39, '1017'),
	(377, 1, 0, -50925, 1019, 0, 0, 39, '1018'),
	(377, 1, 0, -50925, 1020, 0, 0, 39, '1019'),
	(377, 1, 0, -50925, 1021, 0, 0, 39, '1020'),
	(377, 1, 0, -50925, 1022, 0, 0, 39, '1021'),
	(377, 1, 0, -50925, 1023, 0, 0, 39, '1022'),
	(377, 1, 0, -50925, 1024, 0, 0, 39, '1023'),
	(377, 1, 0, -50925, 1025, 0, 0, 39, '1024'),
	(377, 1, 0, -50925, 1026, 0, 0, 39, '1025'),
	(377, 1, 0, -50925, 1027, 0, 0, 39, '1026'),
	(377, 1, 0, -50925, 1028, 0, 0, 39, '1027'),
	(377, 1, 0, -50925, 1029, 0, 0, 39, '1028'),
	(377, 1, 0, -50925, 1030, 0, 0, 39, '1029'),
	(377, 1, 0, -50925, 1031, 0, 0, 39, '1030'),
	(377, 1, 0, -50925, 1032, 0, 0, 39, '1031'),
	(377, 1, 0, -50925, 1033, 0, 0, 39, '1032'),
	(377, 1, 0, -50925, 1034, 0, 0, 39, '1033'),
	(377, 1, 0, -50925, 1035, 0, 0, 39, '1034'),
	(377, 1, 0, -50925, 1036, 0, 0, 39, '1035'),
	(377, 1, 0, -50925, 1037, 0, 0, 39, '1036'),
	(377, 1, 0, -50925, 1038, 0, 0, 39, '1037'),
	(377, 1, 0, -50925, 1039, 0, 0, 39, '1038'),
	(377, 1, 0, -50925, 1040, 0, 0, 39, '1039'),
	(377, 1, 0, -50925, 1041, 0, 0, 39, '1040'),
	(377, 1, 0, -50925, 1042, 0, 0, 39, '1041'),
	(377, 1, 0, -50925, 1043, 0, 0, 39, '1042'),
	(377, 1, 0, -50925, 1044, 0, 0, 39, '1043'),
	(377, 1, 0, -50925, 1045, 0, 0, 39, '1044'),
	(377, 1, 0, -50925, 1046, 0, 0, 39, '1045'),
	(377, 1, 0, -50925, 1047, 0, 0, 39, '1046'),
	(377, 1, 0, -50925, 1048, 0, 0, 39, '1047'),
	(377, 1, 0, -50925, 1049, 0, 0, 39, '1048'),
	(377, 1, 0, -50925, 1050, 0, 0, 39, '1049'),
	(377, 1, 0, -50925, 1051, 0, 0, 39, '1050'),
	(377, 1, 0, -50925, 1052, 0, 0, 39, '1051'),
	(377, 1, 0, -50925, 1053, 0, 0, 39, '1052'),
	(377, 1, 0, -50925, 1054, 0, 0, 39, '1053'),
	(377, 1, 0, -50925, 1055, 0, 0, 39, '1054'),
	(377, 1, 0, -50925, 1056, 0, 0, 39, '1055'),
	(377, 1, 0, -50925, 1057, 0, 0, 39, '1056'),
	(377, 1, 0, -50925, 1058, 0, 0, 39, '1057'),
	(377, 1, 0, -50925, 1059, 0, 0, 39, '1058'),
	(377, 1, 0, -50925, 1060, 0, 0, 39, '1059'),
	(377, 1, 0, -50925, 1061, 0, 0, 39, '1060'),
	(377, 1, 0, -50925, 1062, 0, 0, 39, '1061'),
	(377, 1, 0, -50925, 1063, 0, 0, 39, '1062'),
	(377, 1, 0, -50925, 1064, 0, 0, 39, '1063'),
	(377, 1, 0, -50925, 1065, 0, 0, 39, '1064'),
	(377, 1, 0, -50925, 1066, 0, 0, 39, '1065'),
	(377, 1, 0, -50925, 1067, 0, 0, 39, '1066'),
	(377, 1, 0, -50925, 1068, 0, 0, 39, '1067'),
	(377, 1, 0, -50925, 1069, 0, 0, 39, '1068'),
	(377, 1, 0, -50925, 1070, 0, 0, 39, '1069'),
	(377, 1, 0, -50925, 1071, 0, 0, 39, '1070'),
	(377, 1, 0, -50925, 1072, 0, 0, 39, '1071'),
	(377, 1, 0, -50925, 1073, 0, 0, 39, '1072'),
	(377, 1, 0, -50925, 1074, 0, 0, 39, '1073'),
	(377, 1, 0, -50925, 1075, 0, 0, 39, '1074'),
	(377, 1, 0, -50925, 1076, 0, 0, 39, '1075'),
	(377, 1, 0, -50925, 1077, 0, 0, 39, '1076'),
	(377, 1, 0, -50925, 1078, 0, 0, 39, '1077'),
	(377, 1, 0, -50925, 1079, 0, 0, 39, '1078'),
	(377, 1, 0, -50925, 1080, 0, 0, 39, '1079'),
	(377, 1, 0, -50925, 1081, 0, 0, 39, '1080'),
	(377, 1, 0, -50925, 1082, 0, 0, 39, '1081'),
	(377, 1, 0, -50925, 1083, 0, 0, 39, '1082'),
	(377, 1, 0, -50925, 1084, 0, 0, 39, '1083'),
	(377, 1, 0, -50925, 1085, 0, 0, 39, '1084'),
	(377, 1, 0, -50925, 1086, 0, 0, 39, '1085'),
	(377, 1, 0, -50925, 1087, 0, 0, 39, '1086'),
	(377, 1, 0, -50925, 1088, 0, 0, 39, '1087'),
	(377, 1, 0, -50925, 1089, 0, 0, 39, '1088'),
	(377, 1, 0, -50925, 1090, 0, 0, 39, '1089'),
	(377, 1, 0, -50925, 1091, 0, 0, 39, '1090'),
	(377, 1, 0, -50925, 1092, 0, 0, 39, '1091'),
	(377, 1, 0, -50925, 1093, 0, 0, 39, '1092'),
	(377, 1, 0, -50925, 1094, 0, 0, 39, '1093'),
	(377, 1, 0, -50925, 1095, 0, 0, 39, '1094'),
	(377, 1, 0, -50925, 1096, 0, 0, 39, '1095'),
	(377, 1, 0, -50925, 1097, 0, 0, 39, '1096'),
	(377, 1, 0, -50925, 1098, 0, 0, 39, '1097'),
	(377, 1, 0, -50925, 1099, 0, 0, 39, '1098'),
	(377, 1, 0, -50925, 1100, 0, 0, 39, '1099'),
	(377, 1, 0, -50925, 1101, 0, 0, 39, '1100'),
	(377, 1, 0, -50925, 1102, 0, 0, 39, '1101'),
	(377, 1, 0, -50925, 1103, 0, 0, 39, '1102'),
	(377, 1, 0, -50925, 1104, 0, 0, 39, '1103'),
	(377, 1, 0, -50925, 1105, 0, 0, 39, '1104'),
	(377, 1, 0, -50925, 1106, 0, 0, 39, '1105'),
	(377, 1, 0, -50925, 1107, 0, 0, 39, '1106'),
	(377, 1, 0, -50925, 1108, 0, 0, 39, '1107'),
	(377, 1, 0, -50925, 1109, 0, 0, 39, '1108'),
	(377, 1, 0, -50925, 1110, 0, 0, 39, '1109'),
	(377, 1, 0, -50925, 1111, 0, 0, 39, '1110'),
	(377, 1, 0, -50925, 1112, 0, 0, 39, '1111'),
	(377, 1, 0, -50925, 1113, 0, 0, 39, '1112'),
	(377, 1, 0, -50925, 1114, 0, 0, 39, '1113'),
	(377, 1, 0, -50925, 1115, 0, 0, 39, '1114'),
	(377, 1, 0, -50925, 1116, 0, 0, 39, '1115'),
	(377, 1, 0, -50925, 1117, 0, 0, 39, '1116'),
	(377, 1, 0, -50925, 1118, 0, 0, 39, '1117'),
	(377, 1, 0, -50925, 1119, 0, 0, 39, '1118'),
	(377, 1, 0, -50925, 1120, 0, 0, 39, '1119'),
	(377, 1, 0, -50925, 1121, 0, 0, 39, '1120'),
	(377, 1, 0, -50925, 1122, 0, 0, 39, '1121'),
	(377, 1, 0, -50925, 1123, 0, 0, 39, '1122'),
	(377, 1, 0, -50925, 1124, 0, 0, 39, '1123'),
	(377, 1, 0, -50925, 1125, 0, 0, 39, '1124'),
	(377, 1, 0, -50925, 1126, 0, 0, 39, '1125'),
	(377, 1, 0, -50925, 1127, 0, 0, 39, '1126'),
	(377, 1, 0, -50925, 1128, 0, 0, 39, '1127'),
	(377, 1, 0, -50925, 1129, 0, 0, 39, '1128'),
	(377, 1, 0, -50925, 1130, 0, 0, 39, '1129'),
	(377, 1, 0, -50925, 1131, 0, 0, 39, '1130'),
	(377, 1, 0, -50925, 1132, 0, 0, 39, '1131'),
	(377, 1, 0, -50925, 1133, 0, 0, 39, '1132'),
	(377, 1, 0, -50925, 1134, 0, 0, 39, '1133'),
	(377, 1, 0, -50925, 1135, 0, 0, 39, '1134'),
	(377, 1, 0, -50925, 1136, 0, 0, 39, '1135'),
	(377, 1, 0, -50925, 1137, 0, 0, 39, '1136'),
	(377, 1, 0, -50925, 1138, 0, 0, 39, '1137'),
	(377, 1, 0, -50925, 1139, 0, 0, 39, '1138'),
	(377, 1, 0, -50925, 1140, 0, 0, 39, '1139'),
	(377, 1, 0, -50925, 1141, 0, 0, 39, '1140'),
	(377, 1, 0, -50925, 1142, 0, 0, 39, '1141'),
	(377, 1, 0, -50925, 1143, 0, 0, 39, '1142'),
	(377, 1, 0, -50925, 1144, 0, 0, 39, '1143'),
	(377, 1, 0, -50925, 1145, 0, 0, 39, '1144'),
	(377, 1, 0, -50925, 1146, 0, 0, 39, '1145'),
	(377, 1, 0, -50925, 1147, 0, 0, 39, '1146'),
	(377, 1, 0, -50925, 1148, 0, 0, 39, '1147'),
	(377, 1, 0, -50925, 1149, 0, 0, 39, '1148'),
	(377, 1, 0, -50925, 1150, 0, 0, 39, '1149'),
	(377, 1, 0, -50925, 1151, 0, 0, 39, '1150'),
	(377, 1, 0, -50925, 1152, 0, 0, 39, '1151'),
	(377, 1, 0, -50925, 1153, 0, 0, 39, '1152'),
	(377, 1, 0, -50925, 1154, 0, 0, 39, '1153'),
	(377, 1, 0, -50925, 1155, 0, 0, 39, '1154'),
	(377, 1, 0, -50925, 1156, 0, 0, 39, '1155'),
	(377, 1, 0, -50925, 1157, 0, 0, 39, '1156'),
	(377, 1, 0, -50925, 1158, 0, 0, 39, '1157'),
	(377, 1, 0, -50925, 1159, 0, 0, 39, '1158'),
	(377, 1, 0, -50925, 1160, 0, 0, 39, '1159'),
	(377, 1, 0, -50925, 1161, 0, 0, 39, '1160'),
	(377, 1, 0, -50925, 1162, 0, 0, 39, '1161'),
	(377, 1, 0, -50925, 1163, 0, 0, 39, '1162'),
	(377, 1, 0, -50925, 1164, 0, 0, 39, '1163'),
	(377, 1, 0, -50925, 1165, 0, 0, 39, '1164'),
	(377, 1, 0, -50925, 1166, 0, 0, 39, '1165'),
	(377, 1, 0, -50925, 1167, 0, 0, 39, '1166'),
	(377, 1, 0, -50925, 1168, 0, 0, 39, '1167'),
	(377, 1, 0, -50925, 1169, 0, 0, 39, '1168'),
	(377, 1, 0, -50925, 1170, 0, 0, 39, '1169'),
	(377, 1, 0, -50925, 1171, 0, 0, 39, '1170'),
	(377, 1, 0, -50925, 1172, 0, 0, 39, '1171'),
	(377, 1, 0, -50925, 1173, 0, 0, 39, '1172'),
	(377, 1, 0, -50925, 1174, 0, 0, 39, '1173'),
	(377, 1, 0, -50925, 1175, 0, 0, 39, '1174'),
	(377, 1, 0, -50925, 1176, 0, 0, 39, '1175'),
	(377, 1, 0, -50925, 1177, 0, 0, 39, '1176'),
	(377, 1, 0, -50925, 1178, 0, 0, 39, '1177'),
	(377, 1, 0, -50925, 1179, 0, 0, 39, '1178'),
	(377, 1, 0, -50925, 1180, 0, 0, 39, '1179'),
	(377, 1, 0, -50925, 1181, 0, 0, 39, '1180'),
	(377, 1, 0, -50925, 1182, 0, 0, 39, '1181'),
	(377, 1, 0, -50925, 1183, 0, 0, 39, '1182'),
	(377, 1, 0, -50925, 1184, 0, 0, 39, '1183'),
	(377, 1, 0, -50925, 1185, 0, 0, 39, '1184'),
	(377, 1, 0, -50925, 1186, 0, 0, 39, '1185'),
	(377, 1, 0, -50925, 1187, 0, 0, 39, '1186'),
	(377, 1, 0, -50925, 1188, 0, 0, 39, '1187'),
	(377, 1, 0, -50925, 1189, 0, 0, 39, '1188'),
	(377, 1, 0, -50925, 1190, 0, 0, 39, '1189'),
	(377, 1, 0, -50925, 1191, 0, 0, 39, '1190'),
	(377, 1, 0, -50925, 1192, 0, 0, 39, '1191'),
	(377, 1, 0, -50925, 1193, 0, 0, 39, '1192'),
	(377, 1, 0, -50925, 1194, 0, 0, 39, '1193'),
	(377, 1, 0, -50925, 1195, 0, 0, 39, '1194'),
	(377, 1, 0, -50925, 1196, 0, 0, 39, '1195'),
	(377, 1, 0, -50925, 1197, 0, 0, 39, '1196'),
	(377, 1, 0, -50925, 1198, 0, 0, 39, '1197'),
	(377, 1, 0, -50925, 1199, 0, 0, 39, '1198'),
	(377, 1, 0, -50925, 1200, 0, 0, 39, '1199'),
	(377, 1, 0, -50925, 1201, 0, 0, 39, '1200'),
	(377, 1, 0, -50925, 1202, 0, 0, 39, '1201'),
	(377, 1, 0, -50925, 1203, 0, 0, 39, '1202'),
	(377, 1, 0, -50925, 1204, 0, 0, 39, '1203'),
	(377, 1, 0, -50925, 1205, 0, 0, 39, '1204'),
	(377, 1, 0, -50925, 1206, 0, 0, 39, '1205'),
	(377, 1, 0, -50925, 1207, 0, 0, 39, '1206'),
	(377, 1, 0, -50925, 1208, 0, 0, 39, '1207'),
	(377, 1, 0, -50925, 1209, 0, 0, 39, '1208'),
	(377, 1, 0, -50925, 1210, 0, 0, 39, '1209'),
	(377, 1, 0, -50925, 1211, 0, 0, 39, '1210'),
	(377, 1, 0, -50925, 1212, 0, 0, 39, '1211'),
	(377, 1, 0, -50925, 1213, 0, 0, 39, '1212'),
	(377, 1, 0, -50925, 1214, 0, 0, 39, '1213'),
	(377, 1, 0, -50925, 1215, 0, 0, 39, '1214'),
	(377, 1, 0, -50925, 1216, 0, 0, 39, '1215'),
	(377, 1, 0, -50925, 1217, 0, 0, 39, '1216'),
	(377, 1, 0, -50925, 1218, 0, 0, 39, '1217'),
	(377, 1, 0, -50925, 1219, 0, 0, 39, '1218'),
	(377, 1, 0, -50925, 1220, 0, 0, 39, '1219'),
	(377, 1, 0, -50925, 1221, 0, 0, 39, '1220'),
	(377, 1, 0, -50925, 1222, 0, 0, 39, '1221'),
	(377, 1, 0, -50925, 1223, 0, 0, 39, '1222'),
	(377, 1, 0, -50925, 1224, 0, 0, 39, '1223'),
	(377, 1, 0, -50925, 1225, 0, 0, 39, '1224'),
	(377, 1, 0, -50925, 1226, 0, 0, 39, '1225'),
	(377, 1, 0, -50925, 1227, 0, 0, 39, '1226'),
	(377, 1, 0, -50925, 1228, 0, 0, 39, '1227'),
	(377, 1, 0, -50925, 1229, 0, 0, 39, '1228'),
	(377, 1, 0, -50925, 1230, 0, 0, 39, '1229'),
	(377, 1, 0, -50925, 1231, 0, 0, 39, '1230'),
	(377, 1, 0, -50925, 1232, 0, 0, 39, '1231'),
	(377, 1, 0, -50925, 1233, 0, 0, 39, '1232'),
	(377, 1, 0, -50925, 1234, 0, 0, 39, '1233'),
	(377, 1, 0, -50925, 1235, 0, 0, 39, '1234'),
	(377, 1, 0, -50925, 1236, 0, 0, 39, '1235'),
	(377, 1, 0, -50925, 1237, 0, 0, 39, '1236'),
	(377, 1, 0, -50925, 1238, 0, 0, 39, '1237'),
	(377, 1, 0, -50925, 1239, 0, 0, 39, '1238'),
	(377, 1, 0, -50925, 1240, 0, 0, 39, '1239'),
	(377, 1, 0, -50925, 1241, 0, 0, 39, '1240'),
	(377, 1, 0, -50925, 1242, 0, 0, 39, '1241'),
	(377, 1, 0, -50925, 1243, 0, 0, 39, '1242'),
	(377, 1, 0, -50925, 1244, 0, 0, 39, '1243'),
	(377, 1, 0, -50925, 1245, 0, 0, 39, '1244'),
	(377, 1, 0, -50925, 1246, 0, 0, 39, '1245'),
	(377, 1, 0, -50925, 1247, 0, 0, 39, '1246'),
	(377, 1, 0, -50925, 1248, 0, 0, 39, '1247'),
	(377, 1, 0, -50925, 1249, 0, 0, 39, '1248'),
	(377, 1, 0, -50925, 1250, 0, 0, 39, '1249'),
	(377, 1, 0, -50925, 1251, 0, 0, 39, '1250'),
	(377, 1, 0, -50925, 1252, 0, 0, 39, '1251'),
	(377, 1, 0, -50925, 1253, 0, 0, 39, '1252'),
	(377, 1, 0, -50925, 1254, 0, 0, 39, '1253'),
	(377, 1, 0, -50925, 1255, 0, 0, 39, '1254'),
	(377, 1, 0, -50925, 1256, 0, 0, 39, '1255'),
	(377, 1, 0, -50925, 1257, 0, 0, 39, '1256'),
	(377, 1, 0, -50925, 1258, 0, 0, 39, '1257'),
	(377, 1, 0, -50925, 1259, 0, 0, 39, '1258'),
	(377, 1, 0, -50925, 1260, 0, 0, 39, '1259'),
	(377, 1, 0, -50925, 1261, 0, 0, 39, '1260'),
	(377, 1, 0, -50925, 1262, 0, 0, 39, '1261'),
	(377, 1, 0, -50925, 1263, 0, 0, 39, '1262'),
	(377, 1, 0, -50925, 1264, 0, 0, 39, '1263'),
	(377, 1, 0, -50925, 1265, 0, 0, 39, '1264'),
	(377, 1, 0, -50925, 1266, 0, 0, 39, '1265'),
	(377, 1, 0, -50925, 1267, 0, 0, 39, '1266'),
	(377, 1, 0, -50925, 1268, 0, 0, 39, '1267'),
	(377, 1, 0, -50925, 1269, 0, 0, 39, '1268'),
	(377, 1, 0, -50925, 1270, 0, 0, 39, '1269'),
	(377, 1, 0, -50925, 1271, 0, 0, 39, '1270'),
	(377, 1, 0, -50925, 1272, 0, 0, 39, '1271'),
	(377, 1, 0, -50925, 1273, 0, 0, 39, '1272'),
	(377, 1, 0, -50925, 1274, 0, 0, 39, '1273'),
	(377, 1, 0, -50925, 1275, 0, 0, 39, '1274'),
	(377, 1, 0, -50925, 1276, 0, 0, 39, '1275'),
	(377, 1, 0, -50925, 1277, 0, 0, 39, '1276'),
	(377, 1, 0, -50925, 1278, 0, 0, 39, '1277'),
	(377, 1, 0, -50925, 1279, 0, 0, 39, '1278'),
	(377, 1, 0, -50925, 1280, 0, 0, 39, '1279'),
	(377, 1, 0, -50925, 1281, 0, 0, 39, '1280'),
	(377, 1, 0, -50925, 1282, 0, 0, 39, '1281'),
	(377, 1, 0, -50925, 1283, 0, 0, 39, '1282'),
	(377, 1, 0, -50925, 1284, 0, 0, 39, '1283'),
	(377, 1, 0, -50925, 1285, 0, 0, 39, '1284'),
	(377, 1, 0, -50925, 1286, 0, 0, 39, '1285'),
	(377, 1, 0, -50925, 1287, 0, 0, 39, '1286'),
	(377, 1, 0, -50925, 1288, 0, 0, 39, '1287'),
	(377, 1, 0, -50925, 1289, 0, 0, 39, '1288'),
	(377, 1, 0, -50925, 1290, 0, 0, 39, '1289'),
	(377, 1, 0, -50925, 1291, 0, 0, 39, '1290'),
	(377, 1, 0, -50925, 1292, 0, 0, 39, '1291'),
	(377, 1, 0, -50925, 1293, 0, 0, 39, '1292'),
	(377, 1, 0, -50925, 1294, 0, 0, 39, '1293'),
	(377, 1, 0, -50925, 1295, 0, 0, 39, '1294'),
	(377, 1, 0, -50925, 1296, 0, 0, 39, '1295'),
	(377, 1, 0, -50925, 1297, 0, 0, 39, '1296'),
	(377, 1, 0, -50925, 1298, 0, 0, 39, '1297'),
	(377, 1, 0, -50925, 1299, 0, 0, 39, '1298'),
	(377, 1, 0, -50925, 1300, 0, 0, 39, '1299'),
	(377, 1, 0, -50925, 1301, 0, 0, 39, '1300'),
	(377, 1, 0, -50925, 1302, 0, 0, 39, '1301'),
	(377, 1, 0, -50925, 1303, 0, 0, 39, '1302'),
	(377, 1, 0, -50925, 1304, 0, 0, 39, '1303'),
	(377, 1, 0, -50925, 1305, 0, 0, 39, '1304'),
	(377, 1, 0, -50925, 1306, 0, 0, 39, '1305'),
	(377, 1, 0, -50925, 1307, 0, 0, 39, '1306'),
	(377, 1, 0, -50925, 1308, 0, 0, 39, '1307'),
	(377, 1, 0, -50925, 1309, 0, 0, 39, '1308'),
	(377, 1, 0, -50925, 1310, 0, 0, 39, '1309'),
	(377, 1, 0, -50925, 1311, 0, 0, 39, '1310'),
	(377, 1, 0, -50925, 1312, 0, 0, 39, '1311'),
	(377, 1, 0, -50925, 1313, 0, 0, 39, '1312'),
	(377, 1, 0, -50925, 1314, 0, 0, 39, '1313'),
	(377, 1, 0, -50925, 1315, 0, 0, 39, '1314'),
	(377, 1, 0, -50925, 1316, 0, 0, 39, '1315'),
	(377, 1, 0, -50925, 1317, 0, 0, 39, '1316'),
	(377, 1, 0, -50925, 1318, 0, 0, 39, '1317'),
	(377, 1, 0, -50925, 1319, 0, 0, 39, '1318'),
	(377, 1, 0, -50925, 1320, 0, 0, 39, '1319'),
	(377, 1, 0, -50925, 1321, 0, 0, 39, '1320'),
	(377, 1, 0, -50925, 1322, 0, 0, 39, '1321'),
	(377, 1, 0, -50925, 1323, 0, 0, 39, '1322'),
	(377, 1, 0, -50925, 1324, 0, 0, 39, '1323'),
	(377, 1, 0, -50925, 1325, 0, 0, 39, '1324'),
	(377, 1, 0, -50925, 1326, 0, 0, 39, '1325'),
	(377, 1, 0, -50925, 1327, 0, 0, 39, '1326'),
	(377, 1, 0, -50925, 1328, 0, 0, 39, '1327'),
	(377, 1, 0, -50925, 1329, 0, 0, 39, '1328'),
	(377, 1, 0, -50925, 1330, 0, 0, 39, '1329'),
	(377, 1, 0, -50925, 1331, 0, 0, 39, '1330'),
	(377, 1, 0, -50925, 1332, 0, 0, 39, '1331'),
	(377, 1, 0, -50925, 1333, 0, 0, 39, '1332'),
	(377, 1, 0, -50925, 1334, 0, 0, 39, '1333'),
	(377, 1, 0, -50925, 1335, 0, 0, 39, '1334'),
	(377, 1, 0, -50925, 1336, 0, 0, 39, '1335'),
	(377, 1, 0, -50925, 1337, 0, 0, 39, '1336'),
	(377, 1, 0, -50925, 1338, 0, 0, 39, '1337'),
	(377, 1, 0, -50925, 1339, 0, 0, 39, '1338'),
	(377, 1, 0, -50925, 1340, 0, 0, 39, '1339'),
	(377, 1, 0, -50925, 1341, 0, 0, 39, '1340'),
	(377, 1, 0, -50925, 1342, 0, 0, 39, '1341'),
	(377, 1, 0, -50925, 1343, 0, 0, 39, '1342'),
	(377, 1, 0, -50925, 1344, 0, 0, 39, '1343'),
	(377, 1, 0, -50925, 1345, 0, 0, 39, '1344'),
	(377, 1, 0, -50925, 1346, 0, 0, 39, '1345'),
	(377, 1, 0, -50925, 1347, 0, 0, 39, '1346'),
	(377, 1, 0, -50925, 1348, 0, 0, 39, '1347'),
	(377, 1, 0, -50925, 1349, 0, 0, 39, '1348'),
	(377, 1, 0, -50925, 1350, 0, 0, 39, '1349'),
	(377, 1, 0, -50925, 1351, 0, 0, 39, '1350'),
	(377, 1, 0, -50925, 1352, 0, 0, 39, '1351'),
	(377, 1, 0, -50925, 1353, 0, 0, 39, '1352'),
	(377, 1, 0, -50925, 1354, 0, 0, 39, '1353'),
	(377, 1, 0, -50925, 1355, 0, 0, 39, '1354'),
	(377, 1, 0, -50925, 1356, 0, 0, 39, '1355'),
	(377, 1, 0, -50925, 1357, 0, 0, 39, '1356'),
	(377, 1, 0, -50925, 1358, 0, 0, 39, '1357'),
	(377, 1, 0, -50925, 1359, 0, 0, 39, '1358'),
	(377, 1, 0, -50925, 1360, 0, 0, 39, '1359'),
	(377, 1, 0, -50925, 1361, 0, 0, 39, '1360'),
	(377, 1, 0, -50925, 1362, 0, 0, 39, '1361'),
	(377, 1, 0, -50925, 1363, 0, 0, 39, '1362'),
	(377, 1, 0, -50925, 1364, 0, 0, 39, '1363'),
	(377, 1, 0, -50925, 1365, 0, 0, 39, '1364'),
	(377, 1, 0, -50925, 1366, 0, 0, 39, '1365'),
	(377, 1, 0, -50925, 1367, 0, 0, 39, '1366'),
	(377, 1, 0, -50925, 1368, 0, 0, 39, '1367'),
	(377, 1, 0, -50925, 1369, 0, 0, 39, '1368'),
	(377, 1, 0, -50925, 1370, 0, 0, 39, '1369'),
	(377, 1, 0, -50925, 1371, 0, 0, 39, '1370'),
	(377, 1, 0, -50925, 1372, 0, 0, 39, '1371'),
	(377, 1, 0, -50925, 1373, 0, 0, 39, '1372'),
	(377, 1, 0, -50925, 1374, 0, 0, 39, '1373'),
	(377, 1, 0, -50925, 1375, 0, 0, 39, '1374'),
	(377, 1, 0, -50925, 1376, 0, 0, 39, '1375'),
	(377, 1, 0, -50925, 1377, 0, 0, 39, '1376'),
	(377, 1, 0, -50925, 1378, 0, 0, 39, '1377'),
	(377, 1, 0, -50925, 1379, 0, 0, 39, '1378'),
	(377, 1, 0, -50925, 1380, 0, 0, 39, '1379'),
	(377, 1, 0, -50925, 1381, 0, 0, 39, '1380'),
	(377, 1, 0, -50925, 1382, 0, 0, 39, '1381'),
	(377, 1, 0, -50925, 1383, 0, 0, 39, '1382'),
	(377, 1, 0, -50925, 1384, 0, 0, 39, '1383'),
	(377, 1, 0, -50925, 1385, 0, 0, 39, '1384'),
	(377, 1, 0, -50925, 1386, 0, 0, 39, '1385'),
	(377, 1, 0, -50925, 1387, 0, 0, 39, '1386'),
	(377, 1, 0, -50925, 1388, 0, 0, 39, '1387'),
	(377, 1, 0, -50925, 1389, 0, 0, 39, '1388'),
	(377, 1, 0, -50925, 1390, 0, 0, 39, '1389'),
	(377, 1, 0, -50925, 1391, 0, 0, 39, '1390'),
	(377, 1, 0, -50925, 1392, 0, 0, 39, '1391'),
	(377, 1, 0, -50925, 1393, 0, 0, 39, '1392'),
	(377, 1, 0, -50925, 1394, 0, 0, 39, '1393'),
	(377, 1, 0, -50925, 1395, 0, 0, 39, '1394'),
	(377, 1, 0, -50925, 1396, 0, 0, 39, '1395'),
	(377, 1, 0, -50925, 1397, 0, 0, 39, '1396'),
	(377, 1, 0, -50925, 1398, 0, 0, 39, '1397'),
	(377, 1, 0, -50925, 1399, 0, 0, 39, '1398'),
	(377, 1, 0, -50925, 1400, 0, 0, 39, '1399'),
	(377, 1, 0, -50925, 1401, 0, 0, 39, '1400'),
	(377, 1, 0, -50925, 1402, 0, 0, 39, '1401'),
	(377, 1, 0, -50925, 1403, 0, 0, 39, '1402'),
	(377, 1, 0, -50925, 1404, 0, 0, 39, '1403'),
	(377, 1, 0, -50925, 1405, 0, 0, 39, '1404'),
	(377, 1, 0, -50925, 1406, 0, 0, 39, '1405'),
	(377, 1, 0, -50925, 1407, 0, 0, 39, '1406'),
	(377, 1, 0, -50925, 1408, 0, 0, 39, '1407'),
	(377, 1, 0, -50925, 1409, 0, 0, 39, '1408'),
	(377, 1, 0, -50925, 1410, 0, 0, 39, '1409'),
	(377, 1, 0, -50925, 1411, 0, 0, 39, '1410'),
	(377, 1, 0, -50925, 1412, 0, 0, 39, '1411'),
	(377, 1, 0, -50925, 1413, 0, 0, 39, '1412'),
	(377, 1, 0, -50925, 1414, 0, 0, 39, '1413'),
	(377, 1, 0, -50925, 1415, 0, 0, 39, '1414'),
	(377, 1, 0, -50925, 1416, 0, 0, 39, '1415'),
	(377, 1, 0, -50925, 1417, 0, 0, 39, '1416'),
	(377, 1, 0, -50925, 1418, 0, 0, 39, '1417'),
	(377, 1, 0, -50925, 1419, 0, 0, 39, '1418'),
	(377, 1, 0, -50925, 1420, 0, 0, 39, '1419'),
	(377, 1, 0, -50925, 1421, 0, 0, 39, '1420'),
	(377, 1, 0, -50925, 1422, 0, 0, 39, '1421'),
	(377, 1, 0, -50925, 1423, 0, 0, 39, '1422'),
	(377, 1, 0, -50925, 1424, 0, 0, 39, '1423'),
	(377, 1, 0, -50925, 1425, 0, 0, 39, '1424'),
	(377, 1, 0, -50925, 1426, 0, 0, 39, '1425'),
	(377, 1, 0, -50925, 1427, 0, 0, 39, '1426'),
	(377, 1, 0, -50925, 1428, 0, 0, 39, '1427'),
	(377, 1, 0, -50925, 1429, 0, 0, 39, '1428'),
	(377, 1, 0, -50925, 1430, 0, 0, 39, '1429'),
	(377, 1, 0, -50925, 1431, 0, 0, 39, '1430'),
	(377, 1, 0, -50925, 1432, 0, 0, 39, '1431'),
	(377, 1, 0, -50925, 1433, 0, 0, 39, '1432'),
	(377, 1, 0, -50925, 1434, 0, 0, 39, '1433'),
	(377, 1, 0, -50925, 1435, 0, 0, 39, '1434'),
	(377, 1, 0, -50925, 1436, 0, 0, 39, '1435'),
	(377, 1, 0, -50925, 1437, 0, 0, 39, '1436'),
	(377, 1, 0, -50925, 1438, 0, 0, 39, '1437'),
	(377, 1, 0, -50925, 1439, 0, 0, 39, '1438'),
	(377, 1, 0, -50925, 1440, 0, 0, 39, '1439'),
	(377, 1, 0, -50925, 1441, 0, 0, 39, '1440'),
	(377, 1, 0, -50925, 1442, 0, 0, 39, '1441'),
	(377, 1, 0, -50925, 1443, 0, 0, 39, '1442'),
	(377, 1, 0, -50925, 1444, 0, 0, 39, '1443'),
	(377, 1, 0, -50925, 1445, 0, 0, 39, '1444'),
	(377, 1, 0, -50925, 1446, 0, 0, 39, '1445'),
	(377, 1, 0, -50925, 1447, 0, 0, 39, '1446'),
	(377, 1, 0, -50925, 1448, 0, 0, 39, '1447'),
	(377, 1, 0, -50925, 1449, 0, 0, 39, '1448'),
	(377, 1, 0, -50925, 1450, 0, 0, 39, '1449'),
	(377, 1, 0, -50925, 1451, 0, 0, 39, '1450'),
	(377, 1, 0, -50925, 1452, 0, 0, 39, '1451'),
	(377, 1, 0, -50925, 1453, 0, 0, 39, '1452'),
	(377, 1, 0, -50925, 1454, 0, 0, 39, '1453'),
	(377, 1, 0, -50925, 1455, 0, 0, 39, '1454'),
	(377, 1, 0, -50925, 1456, 0, 0, 39, '1455'),
	(377, 1, 0, -50925, 1457, 0, 0, 39, '1456'),
	(377, 1, 0, -50925, 1458, 0, 0, 39, '1457'),
	(377, 1, 0, -50925, 1459, 0, 0, 39, '1458'),
	(377, 1, 0, -50925, 1460, 0, 0, 39, '1459'),
	(377, 1, 0, -50925, 1461, 0, 0, 39, '1460'),
	(377, 1, 0, -50925, 1462, 0, 0, 39, '1461'),
	(377, 1, 0, -50925, 1463, 0, 0, 39, '1462'),
	(377, 1, 0, -50925, 1464, 0, 0, 39, '1463'),
	(377, 1, 0, -50925, 1465, 0, 0, 39, '1464'),
	(377, 1, 0, -50925, 1466, 0, 0, 39, '1465'),
	(377, 1, 0, -50925, 1467, 0, 0, 39, '1466'),
	(377, 1, 0, -50925, 1468, 0, 0, 39, '1467'),
	(377, 1, 0, -50925, 1469, 0, 0, 39, '1468'),
	(377, 1, 0, -50925, 1470, 0, 0, 39, '1469'),
	(377, 1, 0, -50925, 1471, 0, 0, 39, '1470'),
	(377, 1, 0, -50925, 1472, 0, 0, 39, '1471'),
	(377, 1, 0, -50925, 1473, 0, 0, 39, '1472'),
	(377, 1, 0, -50925, 1474, 0, 0, 39, '1473'),
	(377, 1, 0, -50925, 1475, 0, 0, 39, '1474'),
	(377, 1, 0, -50925, 1476, 0, 0, 39, '1475'),
	(377, 1, 0, -50925, 1477, 0, 0, 39, '1476'),
	(377, 1, 0, -50925, 1478, 0, 0, 39, '1477'),
	(377, 1, 0, -50925, 1479, 0, 0, 39, '1478'),
	(377, 1, 0, -50925, 1480, 0, 0, 39, '1479'),
	(377, 1, 0, -50925, 1481, 0, 0, 39, '1480'),
	(377, 1, 0, -50925, 1482, 0, 0, 39, '1481'),
	(377, 1, 0, -50925, 1483, 0, 0, 39, '1482'),
	(377, 1, 0, -50925, 1484, 0, 0, 39, '1483'),
	(377, 1, 0, -50925, 1485, 0, 0, 39, '1484'),
	(377, 1, 0, -50925, 1486, 0, 0, 39, '1485'),
	(377, 1, 0, -50925, 1487, 0, 0, 39, '1486'),
	(377, 1, 0, -50925, 1488, 0, 0, 39, '1487'),
	(377, 1, 0, -50925, 1489, 0, 0, 39, '1488'),
	(377, 1, 0, -50925, 1490, 0, 0, 39, '1489'),
	(377, 1, 0, -50925, 1491, 0, 0, 39, '1490'),
	(377, 1, 0, -50925, 1492, 0, 0, 39, '1491'),
	(377, 1, 0, -50925, 1493, 0, 0, 39, '1492'),
	(377, 1, 0, -50925, 1494, 0, 0, 39, '1493'),
	(377, 1, 0, -50925, 1495, 0, 0, 39, '1494'),
	(377, 1, 0, -50925, 1496, 0, 0, 39, '1495'),
	(377, 1, 0, -50925, 1497, 0, 0, 39, '1496'),
	(377, 1, 0, -50925, 1498, 0, 0, 39, '1497'),
	(377, 1, 0, -50925, 1499, 0, 0, 39, '1498'),
	(377, 1, 0, -50925, 1500, 0, 0, 39, '1499'),
	(377, 1, 0, -50925, 1501, 0, 0, 39, '1500'),
	(377, 1, 0, -50925, 1502, 0, 0, 39, '1501'),
	(377, 1, 0, -50925, 1503, 0, 0, 39, '1502'),
	(377, 1, 0, -50925, 1504, 0, 0, 39, '1503'),
	(377, 1, 0, -50925, 1505, 0, 0, 39, '1504'),
	(377, 1, 0, -50925, 1506, 0, 0, 39, '1505'),
	(377, 1, 0, -50925, 1507, 0, 0, 39, '1506'),
	(377, 1, 0, -50925, 1508, 0, 0, 39, '1507'),
	(377, 1, 0, -50925, 1509, 0, 0, 39, '1508'),
	(377, 1, 0, -50925, 1510, 0, 0, 39, '1509'),
	(377, 1, 0, -50925, 1511, 0, 0, 39, '1510'),
	(377, 1, 0, -50925, 1512, 0, 0, 39, '1511'),
	(377, 1, 0, -50925, 1513, 0, 0, 39, '1512'),
	(377, 1, 0, -50925, 1514, 0, 0, 39, '1513'),
	(377, 1, 0, -50925, 1515, 0, 0, 39, '1514'),
	(377, 1, 0, -50925, 1516, 0, 0, 39, '1515'),
	(377, 1, 0, -50925, 1517, 0, 0, 39, '1516'),
	(377, 1, 0, -50925, 1518, 0, 0, 39, '1517'),
	(377, 1, 0, -50925, 1519, 0, 0, 39, '1518'),
	(377, 1, 0, -50925, 1520, 0, 0, 39, '1519'),
	(377, 1, 0, -50925, 1521, 0, 0, 39, '1520'),
	(377, 1, 0, -50925, 1522, 0, 0, 39, '1521'),
	(377, 1, 0, -50925, 1523, 0, 0, 39, '1522'),
	(377, 1, 0, -50925, 1524, 0, 0, 39, '1523'),
	(377, 1, 0, -50925, 1525, 0, 0, 39, '1524'),
	(377, 1, 0, -50925, 1526, 0, 0, 39, '1525'),
	(377, 1, 0, -50925, 1527, 0, 0, 39, '1526'),
	(377, 1, 0, -50925, 1528, 0, 0, 39, '1527'),
	(377, 1, 0, -50925, 1529, 0, 0, 39, '1528'),
	(377, 1, 0, -50925, 1530, 0, 0, 39, '1529'),
	(377, 1, 0, -50925, 1531, 0, 0, 39, '1530'),
	(377, 1, 0, -50925, 1532, 0, 0, 39, '1531'),
	(377, 1, 0, -50925, 1533, 0, 0, 39, '1532'),
	(377, 1, 0, -50925, 1534, 0, 0, 39, '1533'),
	(377, 1, 0, -50925, 1535, 0, 0, 39, '1534'),
	(377, 1, 0, -50925, 1536, 0, 0, 39, '1535'),
	(377, 1, 0, -50925, 1537, 0, 0, 39, '1536'),
	(377, 1, 0, -50925, 1538, 0, 0, 39, '1537'),
	(377, 1, 0, -50925, 1539, 0, 0, 39, '1538'),
	(377, 1, 0, -50925, 1540, 0, 0, 39, '1539'),
	(377, 1, 0, -50925, 1541, 0, 0, 39, '1540'),
	(377, 1, 0, -50925, 1542, 0, 0, 39, '1541'),
	(377, 1, 0, -50925, 1543, 0, 0, 39, '1542'),
	(377, 1, 0, -50925, 1544, 0, 0, 39, '1543'),
	(377, 1, 0, -50925, 1545, 0, 0, 39, '1544'),
	(377, 1, 0, -50925, 1546, 0, 0, 39, '1545'),
	(377, 1, 0, -50925, 1547, 0, 0, 39, '1546'),
	(377, 1, 0, -50925, 1548, 0, 0, 39, '1547'),
	(377, 1, 0, -50925, 1549, 0, 0, 39, '1548'),
	(377, 1, 0, -50925, 1550, 0, 0, 39, '1549'),
	(377, 1, 0, -50925, 1551, 0, 0, 39, '1550'),
	(377, 1, 0, -50925, 1552, 0, 0, 39, '1551'),
	(377, 1, 0, -50925, 1553, 0, 0, 39, '1552'),
	(377, 1, 0, -50925, 1554, 0, 0, 39, '1553'),
	(377, 1, 0, -50925, 1555, 0, 0, 39, '1554'),
	(377, 1, 0, -50925, 1556, 0, 0, 39, '1555'),
	(377, 1, 0, -50925, 1557, 0, 0, 39, '1556'),
	(377, 1, 0, -50925, 1558, 0, 0, 39, '1557'),
	(377, 1, 0, -50925, 1559, 0, 0, 39, '1558'),
	(377, 1, 0, -50925, 1560, 0, 0, 39, '1559'),
	(377, 1, 0, -50925, 1561, 0, 0, 39, '1560'),
	(377, 1, 0, -50925, 1562, 0, 0, 39, '1561'),
	(377, 1, 0, -50925, 1563, 0, 0, 39, '1562'),
	(377, 1, 0, -50925, 1564, 0, 0, 39, '1563'),
	(377, 1, 0, -50925, 1565, 0, 0, 39, '1564'),
	(377, 1, 0, -50925, 1566, 0, 0, 39, '1565'),
	(377, 1, 0, -50925, 1567, 0, 0, 39, '1566'),
	(377, 1, 0, -50925, 1568, 0, 0, 39, '1567'),
	(377, 1, 0, -50925, 1569, 0, 0, 39, '1568'),
	(377, 1, 0, -50925, 1570, 0, 0, 39, '1569'),
	(377, 1, 0, -50925, 1571, 0, 0, 39, '1570'),
	(377, 1, 0, -50925, 1572, 0, 0, 39, '1571'),
	(377, 1, 0, -50925, 1573, 0, 0, 39, '1572'),
	(377, 1, 0, -50925, 1574, 0, 0, 39, '1573'),
	(377, 1, 0, -50925, 1575, 0, 0, 39, '1574'),
	(377, 1, 0, -50925, 1576, 0, 0, 39, '1575'),
	(377, 1, 0, -50925, 1577, 0, 0, 39, '1576'),
	(377, 1, 0, -50925, 1578, 0, 0, 39, '1577'),
	(377, 1, 0, -50925, 1579, 0, 0, 39, '1578'),
	(377, 1, 0, -50925, 1580, 0, 0, 39, '1579'),
	(377, 1, 0, -50925, 1581, 0, 0, 39, '1580'),
	(377, 1, 0, -50925, 1582, 0, 0, 39, '1581'),
	(377, 1, 0, -50925, 1583, 0, 0, 39, '1582'),
	(377, 1, 0, -50925, 1584, 0, 0, 39, '1583'),
	(377, 1, 0, -50925, 1585, 0, 0, 39, '1584'),
	(377, 1, 0, -50925, 1586, 0, 0, 39, '1585'),
	(377, 1, 0, -50925, 1587, 0, 0, 39, '1586'),
	(377, 1, 0, -50925, 1588, 0, 0, 39, '1587'),
	(377, 1, 0, -50925, 1589, 0, 0, 39, '1588'),
	(377, 1, 0, -50925, 1590, 0, 0, 39, '1589'),
	(377, 1, 0, -50925, 1591, 0, 0, 39, '1590'),
	(377, 1, 0, -50925, 1592, 0, 0, 39, '1591'),
	(377, 1, 0, -50925, 1593, 0, 0, 39, '1592'),
	(377, 1, 0, -50925, 1594, 0, 0, 39, '1593'),
	(377, 1, 0, -50925, 1595, 0, 0, 39, '1594'),
	(377, 1, 0, -50925, 1596, 0, 0, 39, '1595'),
	(377, 1, 0, -50925, 1597, 0, 0, 39, '1596'),
	(377, 1, 0, -50925, 1598, 0, 0, 39, '1597'),
	(377, 1, 0, -50925, 1599, 0, 0, 39, '1598'),
	(377, 1, 0, -50925, 1600, 0, 0, 39, '1599'),
	(377, 1, 0, -50925, 1601, 0, 0, 39, '1600'),
	(377, 1, 0, -50925, 1602, 0, 0, 39, '1601'),
	(377, 1, 0, -50925, 1603, 0, 0, 39, '1602'),
	(377, 1, 0, -50925, 1604, 0, 0, 39, '1603'),
	(377, 1, 0, -50925, 1605, 0, 0, 39, '1604'),
	(377, 1, 0, -50925, 1606, 0, 0, 39, '1605'),
	(377, 1, 0, -50925, 1607, 0, 0, 39, '1606'),
	(377, 1, 0, -50925, 1608, 0, 0, 39, '1607'),
	(377, 1, 0, -50925, 1609, 0, 0, 39, '1608'),
	(377, 1, 0, -50925, 1610, 0, 0, 39, '1609'),
	(377, 1, 0, -50925, 1611, 0, 0, 39, '1610'),
	(377, 1, 0, -50925, 1612, 0, 0, 39, '1611'),
	(377, 1, 0, -50925, 1613, 0, 0, 39, '1612'),
	(377, 1, 0, -50925, 1614, 0, 0, 39, '1613'),
	(377, 1, 0, -50925, 1615, 0, 0, 39, '1614'),
	(377, 1, 0, -50925, 1616, 0, 0, 39, '1615'),
	(377, 1, 0, -50925, 1617, 0, 0, 39, '1616'),
	(377, 1, 0, -50925, 1618, 0, 0, 39, '1617'),
	(377, 1, 0, -50925, 1619, 0, 0, 39, '1618'),
	(377, 1, 0, -50925, 1620, 0, 0, 39, '1619'),
	(377, 1, 0, -50925, 1621, 0, 0, 39, '1620'),
	(377, 1, 0, -50925, 1622, 0, 0, 39, '1621'),
	(377, 1, 0, -50925, 1623, 0, 0, 39, '1622'),
	(377, 1, 0, -50925, 1624, 0, 0, 39, '1623'),
	(377, 1, 0, -50925, 1625, 0, 0, 39, '1624'),
	(377, 1, 0, -50925, 1626, 0, 0, 39, '1625'),
	(377, 1, 0, -50925, 1627, 0, 0, 39, '1626'),
	(377, 1, 0, -50925, 1628, 0, 0, 39, '1627'),
	(377, 1, 0, -50925, 1629, 0, 0, 39, '1628'),
	(377, 1, 0, -50925, 1630, 0, 0, 39, '1629'),
	(377, 1, 0, -50925, 1631, 0, 0, 39, '1630'),
	(377, 1, 0, -50925, 1632, 0, 0, 39, '1631'),
	(377, 1, 0, -50925, 1633, 0, 0, 39, '1632'),
	(377, 1, 0, -50925, 1634, 0, 0, 39, '1633'),
	(377, 1, 0, -50925, 1635, 0, 0, 39, '1634'),
	(377, 1, 0, -50925, 1636, 0, 0, 39, '1635'),
	(377, 1, 0, -50925, 1637, 0, 0, 39, '1636'),
	(377, 1, 0, -50925, 1638, 0, 0, 39, '1637'),
	(377, 1, 0, -50925, 1639, 0, 0, 39, '1638'),
	(377, 1, 0, -50925, 1640, 0, 0, 39, '1639'),
	(377, 1, 0, -50925, 1641, 0, 0, 39, '1640'),
	(377, 1, 0, -50925, 1642, 0, 0, 39, '1641'),
	(377, 1, 0, -50925, 1643, 0, 0, 39, '1642'),
	(377, 1, 0, -50925, 1644, 0, 0, 39, '1643'),
	(377, 1, 0, -50925, 1645, 0, 0, 39, '1644'),
	(377, 1, 0, -50925, 1646, 0, 0, 39, '1645'),
	(377, 1, 0, -50925, 1647, 0, 0, 39, '1646'),
	(377, 1, 0, -50925, 1648, 0, 0, 39, '1647'),
	(377, 1, 0, -50925, 1649, 0, 0, 39, '1648'),
	(377, 1, 0, -50925, 1650, 0, 0, 39, '1649'),
	(377, 1, 0, -50925, 1651, 0, 0, 39, '1650'),
	(377, 1, 0, -50925, 1652, 0, 0, 39, '1651'),
	(377, 1, 0, -50925, 1653, 0, 0, 39, '1652'),
	(377, 1, 0, -50925, 1654, 0, 0, 39, '1653'),
	(377, 1, 0, -50925, 1655, 0, 0, 39, '1654'),
	(377, 1, 0, -50925, 1656, 0, 0, 39, '1655'),
	(377, 1, 0, -50925, 1657, 0, 0, 39, '1656'),
	(377, 1, 0, -50925, 1658, 0, 0, 39, '1657'),
	(377, 1, 0, -50925, 1659, 0, 0, 39, '1658'),
	(377, 1, 0, -50925, 1660, 0, 0, 39, '1659'),
	(377, 1, 0, -50925, 1661, 0, 0, 39, '1660'),
	(377, 1, 0, -50925, 1662, 0, 0, 39, '1661'),
	(377, 1, 0, -50925, 1663, 0, 0, 39, '1662'),
	(377, 1, 0, -50925, 1664, 0, 0, 39, '1663'),
	(377, 1, 0, -50925, 1665, 0, 0, 39, '1664'),
	(377, 1, 0, -50925, 1666, 0, 0, 39, '1665'),
	(377, 1, 0, -50925, 1667, 0, 0, 39, '1666'),
	(377, 1, 0, -50925, 1668, 0, 0, 39, '1667'),
	(377, 1, 0, -50925, 1669, 0, 0, 39, '1668'),
	(377, 1, 0, -50925, 1670, 0, 0, 39, '1669'),
	(377, 1, 0, -50925, 1671, 0, 0, 39, '1670'),
	(377, 1, 0, -50925, 1672, 0, 0, 39, '1671'),
	(377, 1, 0, -50925, 1673, 0, 0, 39, '1672'),
	(377, 1, 0, -50925, 1674, 0, 0, 39, '1673'),
	(377, 1, 0, -50925, 1675, 0, 0, 39, '1674'),
	(377, 1, 0, -50925, 1676, 0, 0, 39, '1675'),
	(377, 1, 0, -50925, 1677, 0, 0, 39, '1676'),
	(377, 1, 0, -50925, 1678, 0, 0, 39, '1677'),
	(377, 1, 0, -50925, 1679, 0, 0, 39, '1678'),
	(377, 1, 0, -50925, 1680, 0, 0, 39, '1679'),
	(377, 1, 0, -50925, 1681, 0, 0, 39, '1680'),
	(377, 1, 0, -50925, 1682, 0, 0, 39, '1681'),
	(377, 1, 0, -50925, 1683, 0, 0, 39, '1682'),
	(377, 1, 0, -50925, 1684, 0, 0, 39, '1683'),
	(377, 1, 0, -50925, 1685, 0, 0, 39, '1684'),
	(377, 1, 0, -50925, 1686, 0, 0, 39, '1685'),
	(377, 1, 0, -50925, 1687, 0, 0, 39, '1686'),
	(377, 1, 0, -50925, 1688, 0, 0, 39, '1687'),
	(377, 1, 0, -50925, 1689, 0, 0, 39, '1688'),
	(377, 1, 0, -50925, 1690, 0, 0, 39, '1689'),
	(377, 1, 0, -50925, 1691, 0, 0, 39, '1690'),
	(377, 1, 0, -50925, 1692, 0, 0, 39, '1691'),
	(377, 1, 0, -50925, 1693, 0, 0, 39, '1692'),
	(377, 1, 0, -50925, 1694, 0, 0, 39, '1693'),
	(377, 1, 0, -50925, 1695, 0, 0, 39, '1694'),
	(377, 1, 0, -50925, 1696, 0, 0, 39, '1695'),
	(377, 1, 0, -50925, 1697, 0, 0, 39, '1696'),
	(377, 1, 0, -50925, 1698, 0, 0, 39, '1697'),
	(377, 1, 0, -50925, 1699, 0, 0, 39, '1698'),
	(377, 1, 0, -50925, 1700, 0, 0, 39, '1699'),
	(377, 1, 0, -50925, 1701, 0, 0, 39, '1700'),
	(377, 1, 0, -50925, 1702, 0, 0, 39, '1701'),
	(377, 1, 0, -50925, 1703, 0, 0, 39, '1702'),
	(377, 1, 0, -50925, 1704, 0, 0, 39, '1703'),
	(377, 1, 0, -50925, 1705, 0, 0, 39, '1704'),
	(377, 1, 0, -50925, 1706, 0, 0, 39, '1705'),
	(377, 1, 0, -50925, 1707, 0, 0, 39, '1706'),
	(377, 1, 0, -50925, 1708, 0, 0, 39, '1707'),
	(377, 1, 0, -50925, 1709, 0, 0, 39, '1708'),
	(377, 1, 0, -50925, 1710, 0, 0, 39, '1709'),
	(377, 1, 0, -50925, 1711, 0, 0, 39, '1710'),
	(377, 1, 0, -50925, 1712, 0, 0, 39, '1711'),
	(377, 1, 0, -50925, 1713, 0, 0, 39, '1712'),
	(377, 1, 0, -50925, 1714, 0, 0, 39, '1713'),
	(377, 1, 0, -50925, 1715, 0, 0, 39, '1714'),
	(377, 1, 0, -50925, 1716, 0, 0, 39, '1715'),
	(377, 1, 0, -50925, 1717, 0, 0, 39, '1716'),
	(377, 1, 0, -50925, 1718, 0, 0, 39, '1717'),
	(377, 1, 0, -50925, 1719, 0, 0, 39, '1718'),
	(377, 1, 0, -50925, 1720, 0, 0, 39, '1719'),
	(377, 1, 0, -50925, 1721, 0, 0, 39, '1720'),
	(377, 1, 0, -50925, 1722, 0, 0, 39, '1721'),
	(377, 1, 0, -50925, 1723, 0, 0, 39, '1722'),
	(377, 1, 0, -50925, 1724, 0, 0, 39, '1723'),
	(377, 1, 0, -50925, 1725, 0, 0, 39, '1724'),
	(377, 1, 0, -50925, 1726, 0, 0, 39, '1725'),
	(377, 1, 0, -50925, 1727, 0, 0, 39, '1726'),
	(377, 1, 0, -50925, 1728, 0, 0, 39, '1727'),
	(377, 1, 0, -50925, 1729, 0, 0, 39, '1728'),
	(377, 1, 0, -50925, 1730, 0, 0, 39, '1729'),
	(377, 1, 0, -50925, 1731, 0, 0, 39, '1730'),
	(377, 1, 0, -50925, 1732, 0, 0, 39, '1731'),
	(377, 1, 0, -50925, 1733, 0, 0, 39, '1732'),
	(377, 1, 0, -50925, 1734, 0, 0, 39, '1733'),
	(377, 1, 0, -50925, 1735, 0, 0, 39, '1734'),
	(377, 1, 0, -50925, 1736, 0, 0, 39, '1735'),
	(377, 1, 0, -50925, 1737, 0, 0, 39, '1736'),
	(377, 1, 0, -50925, 1738, 0, 0, 39, '1737'),
	(377, 1, 0, -50925, 1739, 0, 0, 39, '1738'),
	(377, 1, 0, -50925, 1740, 0, 0, 39, '1739'),
	(377, 1, 0, -50925, 1741, 0, 0, 39, '1740'),
	(377, 1, 0, -50925, 1742, 0, 0, 39, '1741'),
	(377, 1, 0, -50925, 1743, 0, 0, 39, '1742'),
	(377, 1, 0, -50925, 1744, 0, 0, 39, '1743'),
	(377, 1, 0, -50925, 1745, 0, 0, 39, '1744'),
	(377, 1, 0, -50925, 1746, 0, 0, 39, '1745'),
	(377, 1, 0, -50925, 1747, 0, 0, 39, '1746'),
	(377, 1, 0, -50925, 1748, 0, 0, 39, '1747'),
	(377, 1, 0, -50925, 1749, 0, 0, 39, '1748'),
	(377, 1, 0, -50925, 1750, 0, 0, 39, '1749'),
	(377, 1, 0, -50925, 1751, 0, 0, 39, '1750'),
	(377, 1, 0, -50925, 1752, 0, 0, 39, '1751'),
	(377, 1, 0, -50925, 1753, 0, 0, 39, '1752'),
	(377, 1, 0, -50925, 1754, 0, 0, 39, '1753'),
	(377, 1, 0, -50925, 1755, 0, 0, 39, '1754'),
	(377, 1, 0, -50925, 1756, 0, 0, 39, '1755'),
	(377, 1, 0, -50925, 1757, 0, 0, 39, '1756'),
	(377, 1, 0, -50925, 1758, 0, 0, 39, '1757'),
	(377, 1, 0, -50925, 1759, 0, 0, 39, '1758'),
	(377, 1, 0, -50925, 1760, 0, 0, 39, '1759'),
	(377, 1, 0, -50925, 1761, 0, 0, 39, '1760'),
	(377, 1, 0, -50925, 1762, 0, 0, 39, '1761'),
	(377, 1, 0, -50925, 1763, 0, 0, 39, '1762'),
	(377, 1, 0, -50925, 1764, 0, 0, 39, '1763'),
	(377, 1, 0, -50925, 1765, 0, 0, 39, '1764'),
	(377, 1, 0, -50925, 1766, 0, 0, 39, '1765'),
	(377, 1, 0, -50925, 1767, 0, 0, 39, '1766'),
	(377, 1, 0, -50925, 1768, 0, 0, 39, '1767'),
	(377, 1, 0, -50925, 1769, 0, 0, 39, '1768'),
	(377, 1, 0, -50925, 1770, 0, 0, 39, '1769'),
	(377, 1, 0, -50925, 1771, 0, 0, 39, '1770'),
	(377, 1, 0, -50925, 1772, 0, 0, 39, '1771'),
	(377, 1, 0, -50925, 1773, 0, 0, 39, '1772'),
	(377, 1, 0, -50925, 1774, 0, 0, 39, '1773'),
	(377, 1, 0, -50925, 1775, 0, 0, 39, '1774'),
	(377, 1, 0, -50925, 1776, 0, 0, 39, '1775'),
	(377, 1, 0, -50925, 1777, 0, 0, 39, '1776'),
	(377, 1, 0, -50925, 1778, 0, 0, 39, '1777'),
	(377, 1, 0, -50925, 1779, 0, 0, 39, '1778'),
	(377, 1, 0, -50925, 1780, 0, 0, 39, '1779'),
	(377, 1, 0, -50925, 1781, 0, 0, 39, '1780'),
	(377, 1, 0, -50925, 1782, 0, 0, 39, '1781'),
	(377, 1, 0, -50925, 1783, 0, 0, 39, '1782'),
	(377, 1, 0, -50925, 1784, 0, 0, 39, '1783'),
	(377, 1, 0, -50925, 1785, 0, 0, 39, '1784'),
	(377, 1, 0, -50925, 1786, 0, 0, 39, '1785'),
	(377, 1, 0, -50925, 1787, 0, 0, 39, '1786'),
	(377, 1, 0, -50925, 1788, 0, 0, 39, '1787'),
	(377, 1, 0, -50925, 1789, 0, 0, 39, '1788'),
	(377, 1, 0, -50925, 1790, 0, 0, 39, '1789'),
	(377, 1, 0, -50925, 1791, 0, 0, 39, '1790'),
	(377, 1, 0, -50925, 1792, 0, 0, 39, '1791'),
	(377, 1, 0, -50925, 1793, 0, 0, 39, '1792'),
	(377, 1, 0, -50925, 1794, 0, 0, 39, '1793'),
	(377, 1, 0, -50925, 1795, 0, 0, 39, '1794'),
	(377, 1, 0, -50925, 1796, 0, 0, 39, '1795'),
	(377, 1, 0, -50925, 1797, 0, 0, 39, '1796'),
	(377, 1, 0, -50925, 1798, 0, 0, 39, '1797'),
	(377, 1, 0, -50925, 1799, 0, 0, 39, '1798'),
	(377, 1, 0, -50925, 1800, 0, 0, 39, '1799'),
	(377, 1, 0, -50925, 1801, 0, 0, 39, '1800'),
	(377, 1, 0, -50925, 1802, 0, 0, 39, '1801'),
	(377, 1, 0, -50925, 1803, 0, 0, 39, '1802'),
	(377, 1, 0, -50925, 1804, 0, 0, 39, '1803'),
	(377, 1, 0, -50925, 1805, 0, 0, 39, '1804'),
	(377, 1, 0, -50925, 1806, 0, 0, 39, '1805'),
	(377, 1, 0, -50925, 1807, 0, 0, 39, '1806'),
	(377, 1, 0, -50925, 1808, 0, 0, 39, '1807'),
	(377, 1, 0, -50925, 1809, 0, 0, 39, '1808'),
	(377, 1, 0, -50925, 1810, 0, 0, 39, '1809'),
	(377, 1, 0, -50925, 1811, 0, 0, 39, '1810'),
	(377, 1, 0, -50925, 1812, 0, 0, 39, '1811'),
	(377, 1, 0, -50925, 1813, 0, 0, 39, '1812'),
	(377, 1, 0, -50925, 1814, 0, 0, 39, '1813'),
	(377, 1, 0, -50925, 1815, 0, 0, 39, '1814'),
	(377, 1, 0, -50925, 1816, 0, 0, 39, '1815'),
	(377, 1, 0, -50925, 1817, 0, 0, 39, '1816'),
	(377, 1, 0, -50925, 1818, 0, 0, 39, '1817'),
	(377, 1, 0, -50925, 1819, 0, 0, 39, '1818'),
	(377, 1, 0, -50925, 1820, 0, 0, 39, '1819'),
	(377, 1, 0, -50925, 1821, 0, 0, 39, '1820'),
	(377, 1, 0, -50925, 1822, 0, 0, 39, '1821'),
	(377, 1, 0, -50925, 1823, 0, 0, 39, '1822'),
	(377, 1, 0, -50925, 1824, 0, 0, 39, '1823'),
	(377, 1, 0, -50925, 1825, 0, 0, 39, '1824'),
	(377, 1, 0, -50925, 1826, 0, 0, 39, '1825'),
	(377, 1, 0, -50925, 1827, 0, 0, 39, '1826'),
	(377, 1, 0, -50925, 1828, 0, 0, 39, '1827'),
	(377, 1, 0, -50925, 1829, 0, 0, 39, '1828'),
	(377, 1, 0, -50925, 1830, 0, 0, 39, '1829'),
	(377, 1, 0, -50925, 1831, 0, 0, 39, '1830'),
	(377, 1, 0, -50925, 1832, 0, 0, 39, '1831'),
	(377, 1, 0, -50925, 1833, 0, 0, 39, '1832'),
	(377, 1, 0, -50925, 1834, 0, 0, 39, '1833'),
	(377, 1, 0, -50925, 1835, 0, 0, 39, '1834'),
	(377, 1, 0, -50925, 1836, 0, 0, 39, '1835'),
	(377, 1, 0, -50925, 1837, 0, 0, 39, '1836'),
	(377, 1, 0, -50925, 1838, 0, 0, 39, '1837'),
	(377, 1, 0, -50925, 1839, 0, 0, 39, '1838'),
	(377, 1, 0, -50925, 1840, 0, 0, 39, '1839'),
	(377, 1, 0, -50925, 1841, 0, 0, 39, '1840'),
	(377, 1, 0, -50925, 1842, 0, 0, 39, '1841'),
	(377, 1, 0, -50925, 1843, 0, 0, 39, '1842'),
	(377, 1, 0, -50925, 1844, 0, 0, 39, '1843'),
	(377, 1, 0, -50925, 1845, 0, 0, 39, '1844'),
	(377, 1, 0, -50925, 1846, 0, 0, 39, '1845'),
	(377, 1, 0, -50925, 1847, 0, 0, 39, '1846'),
	(377, 1, 0, -50925, 1848, 0, 0, 39, '1847'),
	(377, 1, 0, -50925, 1849, 0, 0, 39, '1848'),
	(377, 1, 0, -50925, 1850, 0, 0, 39, '1849'),
	(377, 1, 0, -50925, 1851, 0, 0, 39, '1850'),
	(377, 1, 0, -50925, 1852, 0, 0, 39, '1851'),
	(377, 1, 0, -50925, 1853, 0, 0, 39, '1852'),
	(377, 1, 0, -50925, 1854, 0, 0, 39, '1853'),
	(377, 1, 0, -50925, 1855, 0, 0, 39, '1854'),
	(377, 1, 0, -50925, 1856, 0, 0, 39, '1855'),
	(377, 1, 0, -50925, 1857, 0, 0, 39, '1856'),
	(377, 1, 0, -50925, 1858, 0, 0, 39, '1857'),
	(377, 1, 0, -50925, 1859, 0, 0, 39, '1858'),
	(377, 1, 0, -50925, 1860, 0, 0, 39, '1859'),
	(377, 1, 0, -50925, 1861, 0, 0, 39, '1860'),
	(377, 1, 0, -50925, 1862, 0, 0, 39, '1861'),
	(377, 1, 0, -50925, 1863, 0, 0, 39, '1862'),
	(377, 1, 0, -50925, 1864, 0, 0, 39, '1863'),
	(377, 1, 0, -50925, 1865, 0, 0, 39, '1864'),
	(377, 1, 0, -50925, 1866, 0, 0, 39, '1865'),
	(377, 1, 0, -50925, 1867, 0, 0, 39, '1866'),
	(377, 1, 0, -50925, 1868, 0, 0, 39, '1867'),
	(377, 1, 0, -50925, 1869, 0, 0, 39, '1868'),
	(377, 1, 0, -50925, 1870, 0, 0, 39, '1869'),
	(377, 1, 0, -50925, 1871, 0, 0, 39, '1870'),
	(377, 1, 0, -50925, 1872, 0, 0, 39, '1871'),
	(377, 1, 0, -50925, 1873, 0, 0, 39, '1872'),
	(377, 1, 0, -50925, 1874, 0, 0, 39, '1873'),
	(377, 1, 0, -50925, 1875, 0, 0, 39, '1874'),
	(377, 1, 0, -50925, 1876, 0, 0, 39, '1875'),
	(377, 1, 0, -50925, 1877, 0, 0, 39, '1876'),
	(377, 1, 0, -50925, 1878, 0, 0, 39, '1877'),
	(377, 1, 0, -50925, 1879, 0, 0, 39, '1878'),
	(377, 1, 0, -50925, 1880, 0, 0, 39, '1879'),
	(377, 1, 0, -50925, 1881, 0, 0, 39, '1880'),
	(377, 1, 0, -50925, 1882, 0, 0, 39, '1881'),
	(377, 1, 0, -50925, 1883, 0, 0, 39, '1882'),
	(377, 1, 0, -50925, 1884, 0, 0, 39, '1883'),
	(377, 1, 0, -50925, 1885, 0, 0, 39, '1884'),
	(377, 1, 0, -50925, 1886, 0, 0, 39, '1885'),
	(377, 1, 0, -50925, 1887, 0, 0, 39, '1886'),
	(377, 1, 0, -50925, 1888, 0, 0, 39, '1887'),
	(377, 1, 0, -50925, 1889, 0, 0, 39, '1888'),
	(377, 1, 0, -50925, 1890, 0, 0, 39, '1889'),
	(377, 1, 0, -50925, 1891, 0, 0, 39, '1890'),
	(377, 1, 0, -50925, 1892, 0, 0, 39, '1891'),
	(377, 1, 0, -50925, 1893, 0, 0, 39, '1892'),
	(377, 1, 0, -50925, 1894, 0, 0, 39, '1893'),
	(377, 1, 0, -50925, 1895, 0, 0, 39, '1894'),
	(377, 1, 0, -50925, 1896, 0, 0, 39, '1895'),
	(377, 1, 0, -50925, 1897, 0, 0, 39, '1896'),
	(377, 1, 0, -50925, 1898, 0, 0, 39, '1897'),
	(377, 1, 0, -50925, 1899, 0, 0, 39, '1898'),
	(377, 1, 0, -50925, 1900, 0, 0, 39, '1899'),
	(377, 1, 0, -50925, 1901, 0, 0, 39, '1900'),
	(377, 1, 0, -50925, 1902, 0, 0, 39, '1901'),
	(377, 1, 0, -50925, 1903, 0, 0, 39, '1902'),
	(377, 1, 0, -50925, 1904, 0, 0, 39, '1903'),
	(377, 1, 0, -50925, 1905, 0, 0, 39, '1904'),
	(377, 1, 0, -50925, 1906, 0, 0, 39, '1905'),
	(377, 1, 0, -50925, 1907, 0, 0, 39, '1906'),
	(377, 1, 0, -50925, 1908, 0, 0, 39, '1907'),
	(377, 1, 0, -50925, 1909, 0, 0, 39, '1908'),
	(377, 1, 0, -50925, 1910, 0, 0, 39, '1909'),
	(377, 1, 0, -50925, 1911, 0, 0, 39, '1910'),
	(377, 1, 0, -50925, 1912, 0, 0, 39, '1911'),
	(377, 1, 0, -50925, 1913, 0, 0, 39, '1912'),
	(377, 1, 0, -50925, 1914, 0, 0, 39, '1913'),
	(377, 1, 0, -50925, 1915, 0, 0, 39, '1914'),
	(377, 1, 0, -50925, 1916, 0, 0, 39, '1915'),
	(377, 1, 0, -50925, 1917, 0, 0, 39, '1916'),
	(377, 1, 0, -50925, 1918, 0, 0, 39, '1917'),
	(377, 1, 0, -50925, 1919, 0, 0, 39, '1918'),
	(377, 1, 0, -50925, 1920, 0, 0, 39, '1919'),
	(377, 1, 0, -50925, 1921, 0, 0, 39, '1920'),
	(377, 1, 0, -50925, 1922, 0, 0, 39, '1921'),
	(377, 1, 0, -50925, 1923, 0, 0, 39, '1922'),
	(377, 1, 0, -50925, 1924, 0, 0, 39, '1923'),
	(377, 1, 0, -50925, 1925, 0, 0, 39, '1924'),
	(377, 1, 0, -50925, 1926, 0, 0, 39, '1925'),
	(377, 1, 0, -50925, 1927, 0, 0, 39, '1926'),
	(377, 1, 0, -50925, 1928, 0, 0, 39, '1927'),
	(377, 1, 0, -50925, 1929, 0, 0, 39, '1928'),
	(377, 1, 0, -50925, 1930, 0, 0, 39, '1929'),
	(377, 1, 0, -50925, 1931, 0, 0, 39, '1930'),
	(377, 1, 0, -50925, 1932, 0, 0, 39, '1931'),
	(377, 1, 0, -50925, 1933, 0, 0, 39, '1932'),
	(377, 1, 0, -50925, 1934, 0, 0, 39, '1933'),
	(377, 1, 0, -50925, 1935, 0, 0, 39, '1934'),
	(377, 1, 0, -50925, 1936, 0, 0, 39, '1935'),
	(377, 1, 0, -50925, 1937, 0, 0, 39, '1936'),
	(377, 1, 0, -50925, 1938, 0, 0, 39, '1937'),
	(377, 1, 0, -50925, 1939, 0, 0, 39, '1938'),
	(377, 1, 0, -50925, 1940, 0, 0, 39, '1939'),
	(377, 1, 0, -50925, 1941, 0, 0, 39, '1940'),
	(377, 1, 0, -50925, 1942, 0, 0, 39, '1941'),
	(377, 1, 0, -50925, 1943, 0, 0, 39, '1942'),
	(377, 1, 0, -50925, 1944, 0, 0, 39, '1943'),
	(377, 1, 0, -50925, 1945, 0, 0, 39, '1944'),
	(377, 1, 0, -50925, 1946, 0, 0, 39, '1945'),
	(377, 1, 0, -50925, 1947, 0, 0, 39, '1946'),
	(377, 1, 0, -50925, 1948, 0, 0, 39, '1947'),
	(377, 1, 0, -50925, 1949, 0, 0, 39, '1948'),
	(377, 1, 0, -50925, 1950, 0, 0, 39, '1949'),
	(377, 1, 0, -50925, 1951, 0, 0, 39, '1950'),
	(377, 1, 0, -50925, 1952, 0, 0, 39, '1951'),
	(377, 1, 0, -50925, 1953, 0, 0, 39, '1952'),
	(377, 1, 0, -50925, 1954, 0, 0, 39, '1953'),
	(377, 1, 0, -50925, 1955, 0, 0, 39, '1954'),
	(377, 1, 0, -50925, 1956, 0, 0, 39, '1955'),
	(377, 1, 0, -50925, 1957, 0, 0, 39, '1956'),
	(377, 1, 0, -50925, 1958, 0, 0, 39, '1957'),
	(377, 1, 0, -50925, 1959, 0, 0, 39, '1958'),
	(377, 1, 0, -50925, 1960, 0, 0, 39, '1959'),
	(377, 1, 0, -50925, 1961, 0, 0, 39, '1960'),
	(377, 1, 0, -50925, 1962, 0, 0, 39, '1961'),
	(377, 1, 0, -50925, 1963, 0, 0, 39, '1962'),
	(377, 1, 0, -50925, 1964, 0, 0, 39, '1963'),
	(377, 1, 0, -50925, 1965, 0, 0, 39, '1964'),
	(377, 1, 0, -50925, 1966, 0, 0, 39, '1965'),
	(377, 1, 0, -50925, 1967, 0, 0, 39, '1966'),
	(377, 1, 0, -50925, 1968, 0, 0, 39, '1967'),
	(377, 1, 0, -50925, 1969, 0, 0, 39, '1968'),
	(377, 1, 0, -50925, 1970, 0, 0, 39, '1969'),
	(377, 1, 0, -50925, 1971, 0, 0, 39, '1970'),
	(377, 1, 0, -50925, 1972, 0, 0, 39, '1971'),
	(377, 1, 0, -50925, 1973, 0, 0, 39, '1972'),
	(377, 1, 0, -50925, 1974, 0, 0, 39, '1973'),
	(377, 1, 0, -50925, 1975, 0, 0, 39, '1974'),
	(377, 1, 0, -50925, 1976, 0, 0, 39, '1975'),
	(377, 1, 0, -50925, 1977, 0, 0, 39, '1976'),
	(377, 1, 0, -50925, 1978, 0, 0, 39, '1977'),
	(377, 1, 0, -50925, 1979, 0, 0, 39, '1978'),
	(377, 1, 0, -50925, 1980, 0, 0, 39, '1979'),
	(377, 1, 0, -50925, 1981, 0, 0, 39, '1980'),
	(377, 1, 0, -50925, 1982, 0, 0, 39, '1981'),
	(377, 1, 0, -50925, 1983, 0, 0, 39, '1982'),
	(377, 1, 0, -50925, 1984, 0, 0, 39, '1983'),
	(377, 1, 0, -50925, 1985, 0, 0, 39, '1984'),
	(377, 1, 0, -50925, 1986, 0, 0, 39, '1985'),
	(377, 1, 0, -50925, 1987, 0, 0, 39, '1986'),
	(377, 1, 0, -50925, 1988, 0, 0, 39, '1987'),
	(377, 1, 0, -50925, 1989, 0, 0, 39, '1988'),
	(377, 1, 0, -50925, 1990, 0, 0, 39, '1989'),
	(377, 1, 0, -50925, 1991, 0, 0, 39, '1990'),
	(377, 1, 0, -50925, 1992, 0, 0, 39, '1991'),
	(377, 1, 0, -50925, 1993, 0, 0, 39, '1992'),
	(377, 1, 0, -50925, 1994, 0, 0, 39, '1993'),
	(377, 1, 0, -50925, 1995, 0, 0, 39, '1994'),
	(377, 1, 0, -50925, 1996, 0, 0, 39, '1995'),
	(377, 1, 0, -50925, 1997, 0, 0, 39, '1996'),
	(377, 1, 0, -50925, 1998, 0, 0, 39, '1997'),
	(377, 1, 0, -50925, 1999, 0, 0, 39, '1998'),
	(377, 1, 0, -50925, 2000, 0, 0, 39, '1999'),
	(377, 1, 0, -50925, 2001, 0, 0, 39, '2000'),
	(377, 1, 0, -50925, 2002, 0, 0, 39, '2001'),
	(377, 1, 0, -50925, 2003, 0, 0, 39, '2002'),
	(377, 1, 0, -50925, 2004, 0, 0, 39, '2003'),
	(377, 1, 0, -50925, 2005, 0, 0, 39, '2004'),
	(377, 1, 0, -50925, 2006, 0, 0, 39, '2005'),
	(377, 1, 0, -50925, 2007, 0, 0, 39, '2006'),
	(377, 1, 0, -50925, 2008, 0, 0, 39, '2007'),
	(377, 1, 0, -50925, 2009, 0, 0, 39, '2008'),
	(377, 1, 0, -50925, 2010, 0, 0, 39, '2009'),
	(377, 1, 0, -50925, 2011, 0, 0, 39, '2010'),
	(377, 1, 0, -50925, 2012, 0, 0, 39, '2011'),
	(377, 1, 0, -50925, 2013, 0, 0, 39, '2012'),
	(377, 1, 0, -50925, 2014, 0, 0, 39, '2013'),
	(377, 1, 0, -50925, 2015, 0, 0, 39, '2014'),
	(377, 1, 0, -50925, 2016, 0, 0, 39, '2015'),
	(377, 1, 0, -50925, 2017, 0, 0, 39, '2016'),
	(377, 1, 0, -50925, 2018, 0, 0, 39, '2017'),
	(377, 1, 0, -50925, 2019, 0, 0, 39, '2018'),
	(377, 1, 0, -50925, 2020, 0, 0, 39, '2019'),
	(377, 1, 0, -50925, 2021, 0, 0, 39, '2020'),
	(377, 1, 0, -50925, 2022, 0, 0, 39, '2021'),
	(377, 1, 0, -50925, 2023, 0, 0, 39, '2022'),
	(377, 1, 0, -50925, 2024, 0, 0, 39, '2023'),
	(377, 1, 0, -50925, 2025, 0, 0, 39, '2024'),
	(377, 1, 0, -50925, 2026, 0, 0, 39, '2025'),
	(377, 1, 0, -50925, 2027, 0, 0, 39, '2026'),
	(377, 1, 0, -50925, 2028, 0, 0, 39, '2027'),
	(377, 1, 0, -50925, 2029, 0, 0, 39, '2028'),
	(377, 1, 0, -50925, 2030, 0, 0, 39, '2029'),
	(377, 1, 0, -50925, 2031, 0, 0, 39, '2030'),
	(377, 1, 0, -50925, 2032, 0, 0, 39, '2031'),
	(377, 1, 0, -50925, 2033, 0, 0, 39, '2032'),
	(377, 1, 0, -50925, 2034, 0, 0, 39, '2033'),
	(377, 1, 0, -50925, 2035, 0, 0, 39, '2034'),
	(377, 1, 0, -50925, 2036, 0, 0, 39, '2035'),
	(377, 1, 0, -50925, 2037, 0, 0, 39, '2036'),
	(377, 1, 0, -50925, 2038, 0, 0, 39, '2037'),
	(377, 1, 0, -50925, 2039, 0, 0, 39, '2038'),
	(377, 1, 0, -50925, 2040, 0, 0, 39, '2039'),
	(377, 1, 0, -50925, 2041, 0, 0, 39, '2040'),
	(377, 1, 0, -50925, 2042, 0, 0, 39, '2041'),
	(377, 1, 0, -50925, 2043, 0, 0, 39, '2042'),
	(377, 1, 0, -50925, 2044, 0, 0, 39, '2043'),
	(377, 1, 0, -50925, 2045, 0, 0, 39, '2044'),
	(377, 1, 0, -50925, 2046, 0, 0, 39, '2045'),
	(377, 1, 0, -50925, 2047, 0, 0, 39, '2046'),
	(377, 1, 0, -50925, 2048, 0, 0, 39, '2047'),
	(377, 1, 0, -50925, 2049, 0, 0, 39, '2048'),
	(377, 1, 0, -50925, 2050, 0, 0, 39, '2049'),
	(377, 1, 0, -50925, 2051, 0, 0, 39, '2050'),
	(377, 1, 0, -50925, 2052, 0, 0, 39, '2051'),
	(377, 1, 0, -50925, 2053, 0, 0, 39, '2052'),
	(377, 1, 0, -50925, 2054, 0, 0, 39, '2053'),
	(377, 1, 0, -50925, 2055, 0, 0, 39, '2054'),
	(377, 1, 0, -50925, 2056, 0, 0, 39, '2055'),
	(377, 1, 0, -50925, 2057, 0, 0, 39, '2056'),
	(377, 1, 0, -50925, 2058, 0, 0, 39, '2057'),
	(377, 1, 0, -50925, 2059, 0, 0, 39, '2058'),
	(377, 1, 0, -50925, 2060, 0, 0, 39, '2059'),
	(377, 1, 0, -50925, 2061, 0, 0, 39, '2060'),
	(377, 1, 0, -50925, 2062, 0, 0, 39, '2061'),
	(377, 1, 0, -50925, 2063, 0, 0, 39, '2062'),
	(377, 1, 0, -50925, 2064, 0, 0, 39, '2063'),
	(377, 1, 0, -50925, 2065, 0, 0, 39, '2064'),
	(377, 1, 0, -50925, 2066, 0, 0, 39, '2065'),
	(377, 1, 0, -50925, 2067, 0, 0, 39, '2066'),
	(377, 1, 0, -50925, 2068, 0, 0, 39, '2067'),
	(377, 1, 0, -50925, 2069, 0, 0, 39, '2068'),
	(377, 1, 0, -50925, 2070, 0, 0, 39, '2069'),
	(377, 1, 0, -50925, 2071, 0, 0, 39, '2070'),
	(377, 1, 0, -50925, 2072, 0, 0, 39, '2071'),
	(377, 1, 0, -50925, 2073, 0, 0, 39, '2072'),
	(377, 1, 0, -50925, 2074, 0, 0, 39, '2073'),
	(377, 1, 0, -50925, 2075, 0, 0, 39, '2074'),
	(377, 1, 0, -50925, 2076, 0, 0, 39, '2075'),
	(377, 1, 0, -50925, 2077, 0, 0, 39, '2076'),
	(377, 1, 0, -50925, 2078, 0, 0, 39, '2077'),
	(377, 1, 0, -50925, 2079, 0, 0, 39, '2078'),
	(377, 1, 0, -50925, 2080, 0, 0, 39, '2079'),
	(377, 1, 0, -50925, 2081, 0, 0, 39, '2080'),
	(377, 1, 0, -50925, 2082, 0, 0, 39, '2081'),
	(377, 1, 0, -50925, 2083, 0, 0, 39, '2082'),
	(377, 1, 0, -50925, 2084, 0, 0, 39, '2083'),
	(377, 1, 0, -50925, 2085, 0, 0, 39, '2084'),
	(377, 1, 0, -50925, 2086, 0, 0, 39, '2085'),
	(377, 1, 0, -50925, 2087, 0, 0, 39, '2086'),
	(377, 1, 0, -50925, 2088, 0, 0, 39, '2087'),
	(377, 1, 0, -50925, 2089, 0, 0, 39, '2088'),
	(377, 1, 0, -50925, 2090, 0, 0, 39, '2089'),
	(377, 1, 0, -50925, 2091, 0, 0, 39, '2090'),
	(377, 1, 0, -50925, 2092, 0, 0, 39, '2091'),
	(377, 1, 0, -50925, 2093, 0, 0, 39, '2092'),
	(377, 1, 0, -50925, 2094, 0, 0, 39, '2093'),
	(377, 1, 0, -50925, 2095, 0, 0, 39, '2094'),
	(377, 1, 0, -50925, 2096, 0, 0, 39, '2095'),
	(377, 1, 0, -50925, 2097, 0, 0, 39, '2096'),
	(377, 1, 0, -50925, 2098, 0, 0, 39, '2097'),
	(377, 1, 0, -50925, 2099, 0, 0, 39, '2098'),
	(377, 1, 0, -50925, 2100, 0, 0, 39, '2099'),
	(377, 1, 0, -50925, 2101, 0, 0, 39, '2100'),
	(377, 1, 0, -50925, 2102, 0, 0, 39, '2101'),
	(377, 1, 0, -50925, 2103, 0, 0, 39, '2102'),
	(377, 1, 0, -50925, 2104, 0, 0, 39, '2103'),
	(377, 1, 0, -50925, 2105, 0, 0, 39, '2104'),
	(377, 1, 0, -50925, 2106, 0, 0, 39, '2105'),
	(377, 1, 0, -50925, 2107, 0, 0, 39, '2106'),
	(377, 1, 0, -50925, 2108, 0, 0, 39, '2107'),
	(377, 1, 0, -50925, 2109, 0, 0, 39, '2108'),
	(377, 1, 0, -50925, 2110, 0, 0, 39, '2109'),
	(377, 1, 0, -50925, 2111, 0, 0, 39, '2110'),
	(377, 1, 0, -50925, 2112, 0, 0, 39, '2111'),
	(377, 1, 0, -50925, 2113, 0, 0, 39, '2112'),
	(377, 1, 0, -50925, 2114, 0, 0, 39, '2113'),
	(377, 1, 0, -50925, 2115, 0, 0, 39, '2114'),
	(377, 1, 0, -50925, 2116, 0, 0, 39, '2115'),
	(377, 1, 0, -50925, 2117, 0, 0, 39, '2116'),
	(377, 1, 0, -50925, 2118, 0, 0, 39, '2117'),
	(377, 1, 0, -50925, 2119, 0, 0, 39, '2118'),
	(377, 1, 0, -50925, 2120, 0, 0, 39, '2119'),
	(377, 1, 0, -50925, 2121, 0, 0, 39, '2120'),
	(377, 1, 0, -50925, 2122, 0, 0, 39, '2121'),
	(377, 1, 0, -50925, 2123, 0, 0, 39, '2122'),
	(377, 1, 0, -50925, 2124, 0, 0, 39, '2123'),
	(377, 1, 0, -50925, 2125, 0, 0, 39, '2124'),
	(377, 1, 0, -50925, 2126, 0, 0, 39, '2125'),
	(377, 1, 0, -50925, 2127, 0, 0, 39, '2126'),
	(377, 1, 0, -50925, 2128, 0, 0, 39, '2127'),
	(377, 1, 0, -50925, 2129, 0, 0, 39, '2128'),
	(377, 1, 0, -50925, 2130, 0, 0, 39, '2129'),
	(377, 1, 0, -50925, 2131, 0, 0, 39, '2130'),
	(377, 1, 0, -50925, 2132, 0, 0, 39, '2131'),
	(377, 1, 0, -50925, 2133, 0, 0, 39, '2132'),
	(377, 1, 0, -50925, 2134, 0, 0, 39, '2133'),
	(377, 1, 0, -50925, 2135, 0, 0, 39, '2134'),
	(377, 1, 0, -50925, 2136, 0, 0, 39, '2135'),
	(377, 1, 0, -50925, 2137, 0, 0, 39, '2136'),
	(377, 1, 0, -50925, 2138, 0, 0, 39, '2137'),
	(377, 1, 0, -50925, 2139, 0, 0, 39, '2138'),
	(377, 1, 0, -50925, 2140, 0, 0, 39, '2139'),
	(377, 1, 0, -50925, 2141, 0, 0, 39, '2140'),
	(377, 1, 0, -50925, 2142, 0, 0, 39, '2141'),
	(377, 1, 0, -50925, 2143, 0, 0, 39, '2142'),
	(377, 1, 0, -50925, 2144, 0, 0, 39, '2143'),
	(377, 1, 0, -50925, 2145, 0, 0, 39, '2144'),
	(377, 1, 0, -50925, 2146, 0, 0, 39, '2145'),
	(377, 1, 0, -50925, 2147, 0, 0, 39, '2146'),
	(377, 1, 0, -50925, 2148, 0, 0, 39, '2147'),
	(377, 1, 0, -50925, 2149, 0, 0, 39, '2148'),
	(377, 1, 0, -50925, 2150, 0, 0, 39, '2149'),
	(377, 1, 0, -50925, 2151, 0, 0, 39, '2150'),
	(377, 1, 0, -50925, 2152, 0, 0, 39, '2151'),
	(377, 1, 0, -50925, 2153, 0, 0, 39, '2152'),
	(377, 1, 0, -50925, 2154, 0, 0, 39, '2153'),
	(377, 1, 0, -50925, 2155, 0, 0, 39, '2154'),
	(377, 1, 0, -50925, 2156, 0, 0, 39, '2155'),
	(377, 1, 0, -50925, 2157, 0, 0, 39, '2156'),
	(377, 1, 0, -50925, 2158, 0, 0, 39, '2157'),
	(377, 1, 0, -50925, 2159, 0, 0, 39, '2158'),
	(377, 1, 0, -50925, 2160, 0, 0, 39, '2159'),
	(377, 1, 0, -50925, 2161, 0, 0, 39, '2160'),
	(377, 1, 0, -50925, 2162, 0, 0, 39, '2161'),
	(377, 1, 0, -50925, 2163, 0, 0, 39, '2162'),
	(377, 1, 0, -50925, 2164, 0, 0, 39, '2163'),
	(377, 1, 0, -50925, 2165, 0, 0, 39, '2164'),
	(377, 1, 0, -50925, 2166, 0, 0, 39, '2165'),
	(377, 1, 0, -50925, 2167, 0, 0, 39, '2166'),
	(377, 1, 0, -50925, 2168, 0, 0, 39, '2167'),
	(377, 1, 0, -50925, 2169, 0, 0, 39, '2168'),
	(377, 1, 0, -50925, 2170, 0, 0, 39, '2169'),
	(377, 1, 0, -50925, 2171, 0, 0, 39, '2170'),
	(377, 1, 0, -50925, 2172, 0, 0, 39, '2171'),
	(377, 1, 0, -50925, 2173, 0, 0, 39, '2172'),
	(377, 1, 0, -50925, 2174, 0, 0, 39, '2173'),
	(377, 1, 0, -50925, 2175, 0, 0, 39, '2174'),
	(377, 1, 0, -50925, 2176, 0, 0, 39, '2175'),
	(377, 1, 0, -50925, 2177, 0, 0, 39, '2176'),
	(377, 1, 0, -50925, 2178, 0, 0, 39, '2177'),
	(377, 1, 0, -50925, 2179, 0, 0, 39, '2178'),
	(377, 1, 0, -50925, 2180, 0, 0, 39, '2179'),
	(377, 1, 0, -50925, 2181, 0, 0, 39, '2180'),
	(377, 1, 0, -50925, 2182, 0, 0, 39, '2181'),
	(377, 1, 0, -50925, 2183, 0, 0, 39, '2182'),
	(377, 1, 0, -50925, 2184, 0, 0, 39, '2183'),
	(377, 1, 0, -50925, 2185, 0, 0, 39, '2184'),
	(377, 1, 0, -50925, 2186, 0, 0, 39, '2185'),
	(377, 1, 0, -50925, 2187, 0, 0, 39, '2186'),
	(377, 1, 0, -50925, 2188, 0, 0, 39, '2187'),
	(377, 1, 0, -50925, 2189, 0, 0, 39, '2188'),
	(377, 1, 0, -50925, 2190, 0, 0, 39, '2189'),
	(377, 1, 0, -50925, 2191, 0, 0, 39, '2190'),
	(377, 1, 0, -50925, 2192, 0, 0, 39, '2191'),
	(377, 1, 0, -50925, 2193, 0, 0, 39, '2192'),
	(377, 1, 0, -50925, 2194, 0, 0, 39, '2193'),
	(377, 1, 0, -50925, 2195, 0, 0, 39, '2194'),
	(377, 1, 0, -50925, 2196, 0, 0, 39, '2195'),
	(377, 1, 0, -50925, 2197, 0, 0, 39, '2196'),
	(377, 1, 0, -50925, 2198, 0, 0, 39, '2197'),
	(377, 1, 0, -50925, 2199, 0, 0, 39, '2198'),
	(377, 1, 0, -50925, 2200, 0, 0, 39, '2199'),
	(377, 1, 0, -50925, 2201, 0, 0, 39, '2200'),
	(377, 1, 0, -50925, 2202, 0, 0, 39, '2201'),
	(377, 1, 0, -50925, 2203, 0, 0, 39, '2202'),
	(377, 1, 0, -50925, 2204, 0, 0, 39, '2203'),
	(377, 1, 0, -50925, 2205, 0, 0, 39, '2204'),
	(377, 1, 0, -50925, 2206, 0, 0, 39, '2205'),
	(377, 1, 0, -50925, 2207, 0, 0, 39, '2206'),
	(377, 1, 0, -50925, 2208, 0, 0, 39, '2207'),
	(377, 1, 0, -50925, 2209, 0, 0, 39, '2208'),
	(377, 1, 0, -50925, 2210, 0, 0, 39, '2209'),
	(377, 1, 0, -50925, 2211, 0, 0, 39, '2210'),
	(377, 1, 0, -50925, 2212, 0, 0, 39, '2211'),
	(377, 1, 0, -50925, 2213, 0, 0, 39, '2212'),
	(377, 1, 0, -50925, 2214, 0, 0, 39, '2213'),
	(377, 1, 0, -50925, 2215, 0, 0, 39, '2214'),
	(377, 1, 0, -50925, 2216, 0, 0, 39, '2215'),
	(377, 1, 0, -50925, 2217, 0, 0, 39, '2216'),
	(377, 1, 0, -50925, 2218, 0, 0, 39, '2217'),
	(377, 1, 0, -50925, 2219, 0, 0, 39, '2218'),
	(377, 1, 0, -50925, 2220, 0, 0, 39, '2219'),
	(377, 1, 0, -50925, 2221, 0, 0, 39, '2220'),
	(377, 1, 0, -50925, 2222, 0, 0, 39, '2221'),
	(377, 1, 0, -50925, 2223, 0, 0, 39, '2222'),
	(377, 1, 0, -50925, 2224, 0, 0, 39, '2223'),
	(377, 1, 0, -50925, 2225, 0, 0, 39, '2224'),
	(377, 1, 0, -50925, 2226, 0, 0, 39, '2225'),
	(377, 1, 0, -50925, 2227, 0, 0, 39, '2226'),
	(377, 1, 0, -50925, 2228, 0, 0, 39, '2227'),
	(377, 1, 0, -50925, 2229, 0, 0, 39, '2228'),
	(377, 1, 0, -50925, 2230, 0, 0, 39, '2229'),
	(377, 1, 0, -50925, 2231, 0, 0, 39, '2230'),
	(377, 1, 0, -50925, 2232, 0, 0, 39, '2231'),
	(377, 1, 0, -50925, 2233, 0, 0, 39, '2232'),
	(377, 1, 0, -50925, 2234, 0, 0, 39, '2233'),
	(377, 1, 0, -50925, 2235, 0, 0, 39, '2234'),
	(377, 1, 0, -50925, 2236, 0, 0, 39, '2235'),
	(377, 1, 0, -50925, 2237, 0, 0, 39, '2236'),
	(377, 1, 0, -50925, 2238, 0, 0, 39, '2237'),
	(377, 1, 0, -50925, 2239, 0, 0, 39, '2238'),
	(377, 1, 0, -50925, 2240, 0, 0, 39, '2239'),
	(377, 1, 0, -50925, 2241, 0, 0, 39, '2240'),
	(377, 1, 0, -50925, 2242, 0, 0, 39, '2241'),
	(377, 1, 0, -50925, 2243, 0, 0, 39, '2242'),
	(377, 1, 0, -50925, 2244, 0, 0, 39, '2243'),
	(377, 1, 0, -50925, 2245, 0, 0, 39, '2244'),
	(377, 1, 0, -50925, 2246, 0, 0, 39, '2245'),
	(377, 1, 0, -50925, 2247, 0, 0, 39, '2246'),
	(377, 1, 0, -50925, 2248, 0, 0, 39, '2247'),
	(377, 1, 0, -50925, 2249, 0, 0, 39, '2248'),
	(377, 1, 0, -50925, 2250, 0, 0, 39, '2249'),
	(377, 1, 0, -50925, 2251, 0, 0, 39, '2250'),
	(377, 1, 0, -50925, 2252, 0, 0, 39, '2251'),
	(377, 1, 0, -50925, 2253, 0, 0, 39, '2252'),
	(377, 1, 0, -50925, 2254, 0, 0, 39, '2253'),
	(377, 1, 0, -50925, 2255, 0, 0, 39, '2254'),
	(377, 1, 0, -50925, 2256, 0, 0, 39, '2255'),
	(377, 1, 0, -50925, 2257, 0, 0, 39, '2256'),
	(377, 1, 0, -50925, 2258, 0, 0, 39, '2257'),
	(377, 1, 0, -50925, 2259, 0, 0, 39, '2258'),
	(377, 1, 0, -50925, 2260, 0, 0, 39, '2259'),
	(377, 1, 0, -50925, 2261, 0, 0, 39, '2260'),
	(377, 1, 0, -50925, 2262, 0, 0, 39, '2261'),
	(377, 1, 0, -50925, 2263, 0, 0, 39, '2262'),
	(377, 1, 0, -50925, 2264, 0, 0, 39, '2263'),
	(377, 1, 0, -50925, 2265, 0, 0, 39, '2264'),
	(377, 1, 0, -50925, 2266, 0, 0, 39, '2265'),
	(377, 1, 0, -50925, 2267, 0, 0, 39, '2266'),
	(377, 1, 0, -50925, 2268, 0, 0, 39, '2267'),
	(377, 1, 0, -50925, 2269, 0, 0, 39, '2268'),
	(377, 1, 0, -50925, 2270, 0, 0, 39, '2269'),
	(377, 1, 0, -50925, 2271, 0, 0, 39, '2270'),
	(377, 1, 0, -50925, 2272, 0, 0, 39, '2271'),
	(377, 1, 0, -50925, 2273, 0, 0, 39, '2272'),
	(377, 1, 0, -50925, 2274, 0, 0, 39, '2273'),
	(377, 1, 0, -50925, 2275, 0, 0, 39, '2274'),
	(377, 1, 0, -50925, 2276, 0, 0, 39, '2275'),
	(377, 1, 0, -50925, 2277, 0, 0, 39, '2276'),
	(377, 1, 0, -50925, 2278, 0, 0, 39, '2277'),
	(377, 1, 0, -50925, 2279, 0, 0, 39, '2278'),
	(377, 1, 0, -50925, 2280, 0, 0, 39, '2279'),
	(377, 1, 0, -50925, 2281, 0, 0, 39, '2280'),
	(377, 1, 0, -50925, 2282, 0, 0, 39, '2281'),
	(377, 1, 0, -50925, 2283, 0, 0, 39, '2282'),
	(377, 1, 0, -50925, 2284, 0, 0, 39, '2283'),
	(377, 1, 0, -50925, 2285, 0, 0, 39, '2284'),
	(377, 1, 0, -50925, 2286, 0, 0, 39, '2285'),
	(377, 1, 0, -50925, 2287, 0, 0, 39, '2286'),
	(377, 1, 0, -50925, 2288, 0, 0, 39, '2287'),
	(377, 1, 0, -50925, 2289, 0, 0, 39, '2288'),
	(377, 1, 0, -50925, 2290, 0, 0, 39, '2289'),
	(377, 1, 0, -50925, 2291, 0, 0, 39, '2290'),
	(377, 1, 0, -50925, 2292, 0, 0, 39, '2291'),
	(377, 1, 0, -50925, 2293, 0, 0, 39, '2292'),
	(377, 1, 0, -50925, 2294, 0, 0, 39, '2293'),
	(377, 1, 0, -50925, 2295, 0, 0, 39, '2294'),
	(377, 1, 0, -50925, 2296, 0, 0, 39, '2295'),
	(377, 1, 0, -50925, 2297, 0, 0, 39, '2296'),
	(377, 1, 0, -50925, 2298, 0, 0, 39, '2297'),
	(377, 1, 0, -50925, 2299, 0, 0, 39, '2298'),
	(377, 1, 0, -50925, 2300, 0, 0, 39, '2299'),
	(377, 1, 0, -50925, 2301, 0, 0, 39, '2300'),
	(377, 1, 0, -50925, 2302, 0, 0, 39, '2301'),
	(377, 1, 0, -50925, 2303, 0, 0, 39, '2302'),
	(377, 1, 0, -50925, 2304, 0, 0, 39, '2303'),
	(377, 1, 0, -50925, 2305, 0, 0, 39, '2304'),
	(377, 1, 0, -50925, 2306, 0, 0, 39, '2305'),
	(377, 1, 0, -50925, 2307, 0, 0, 39, '2306'),
	(377, 1, 0, -50925, 2308, 0, 0, 39, '2307'),
	(377, 1, 0, -50925, 2309, 0, 0, 39, '2308'),
	(377, 1, 0, -50925, 2310, 0, 0, 39, '2309'),
	(377, 1, 0, -50925, 2311, 0, 0, 39, '2310'),
	(377, 1, 0, -50925, 2312, 0, 0, 39, '2311'),
	(377, 1, 0, -50925, 2313, 0, 0, 39, '2312'),
	(377, 1, 0, -50925, 2314, 0, 0, 39, '2313'),
	(377, 1, 0, -50925, 2315, 0, 0, 39, '2314'),
	(377, 1, 0, -50925, 2316, 0, 0, 39, '2315'),
	(377, 1, 0, -50925, 2317, 0, 0, 39, '2316'),
	(377, 1, 0, -50925, 2318, 0, 0, 39, '2317'),
	(377, 1, 0, -50925, 2319, 0, 0, 39, '2318'),
	(377, 1, 0, -50925, 2320, 0, 0, 39, '2319'),
	(377, 1, 0, -50925, 2321, 0, 0, 39, '2320'),
	(377, 1, 0, -50925, 2322, 0, 0, 39, '2321'),
	(377, 1, 0, -50925, 2323, 0, 0, 39, '2322'),
	(377, 1, 0, -50925, 2324, 0, 0, 39, '2323'),
	(377, 1, 0, -50925, 2325, 0, 0, 39, '2324'),
	(377, 1, 0, -50925, 2326, 0, 0, 39, '2325'),
	(377, 1, 0, -50925, 2327, 0, 0, 39, '2326'),
	(377, 1, 0, -50925, 2328, 0, 0, 39, '2327'),
	(377, 1, 0, -50925, 2329, 0, 0, 39, '2328'),
	(377, 1, 0, -50925, 2330, 0, 0, 39, '2329'),
	(377, 1, 0, -50925, 2331, 0, 0, 39, '2330'),
	(377, 1, 0, -50925, 2332, 0, 0, 39, '2331'),
	(377, 1, 0, -50925, 2333, 0, 0, 39, '2332'),
	(377, 1, 0, -50925, 2334, 0, 0, 39, '2333'),
	(377, 1, 0, -50925, 2335, 0, 0, 39, '2334'),
	(377, 1, 0, -50925, 2336, 0, 0, 39, '2335'),
	(377, 1, 0, -50925, 2337, 0, 0, 39, '2336'),
	(377, 1, 0, -50925, 2338, 0, 0, 39, '2337'),
	(377, 1, 0, -50925, 2339, 0, 0, 39, '2338'),
	(377, 1, 0, -50925, 2340, 0, 0, 39, '2339'),
	(377, 1, 0, -50925, 2341, 0, 0, 39, '2340'),
	(377, 1, 0, -50925, 2342, 0, 0, 39, '2341'),
	(377, 1, 0, -50925, 2343, 0, 0, 39, '2342'),
	(377, 1, 0, -50925, 2344, 0, 0, 39, '2343'),
	(377, 1, 0, -50925, 2345, 0, 0, 39, '2344'),
	(377, 1, 0, -50925, 2346, 0, 0, 39, '2345'),
	(377, 1, 0, -50925, 2347, 0, 0, 39, '2346'),
	(377, 1, 0, -50925, 2348, 0, 0, 39, '2347'),
	(377, 1, 0, -50925, 2349, 0, 0, 39, '2348'),
	(377, 1, 0, -50925, 2350, 0, 0, 39, '2349'),
	(377, 1, 0, -50925, 2351, 0, 0, 39, '2350'),
	(377, 1, 0, -50925, 2352, 0, 0, 39, '2351'),
	(377, 1, 0, -50925, 2353, 0, 0, 39, '2352'),
	(377, 1, 0, -50925, 2354, 0, 0, 39, '2353'),
	(377, 1, 0, -50925, 2355, 0, 0, 39, '2354'),
	(377, 1, 0, -50925, 2356, 0, 0, 39, '2355'),
	(377, 1, 0, -50925, 2357, 0, 0, 39, '2356'),
	(377, 1, 0, -50925, 2358, 0, 0, 39, '2357'),
	(377, 1, 0, -50925, 2359, 0, 0, 39, '2358'),
	(377, 1, 0, -50925, 2360, 0, 0, 39, '2359'),
	(377, 1, 0, -50925, 2361, 0, 0, 39, '2360'),
	(377, 1, 0, -50925, 2362, 0, 0, 39, '2361'),
	(377, 1, 0, -50925, 2363, 0, 0, 39, '2362'),
	(377, 1, 0, -50925, 2364, 0, 0, 39, '2363'),
	(377, 1, 0, -50925, 2365, 0, 0, 39, '2364'),
	(377, 1, 0, -50925, 2366, 0, 0, 39, '2365'),
	(377, 1, 0, -50925, 2367, 0, 0, 39, '2366'),
	(377, 1, 0, -50925, 2368, 0, 0, 39, '2367'),
	(377, 1, 0, -50925, 2369, 0, 0, 39, '2368'),
	(377, 1, 0, -50925, 2370, 0, 0, 39, '2369'),
	(377, 1, 0, -50925, 2371, 0, 0, 39, '2370'),
	(377, 1, 0, -50925, 2372, 0, 0, 39, '2371'),
	(377, 1, 0, -50925, 2373, 0, 0, 39, '2372'),
	(377, 1, 0, -50925, 2374, 0, 0, 39, '2373'),
	(377, 1, 0, -50925, 2375, 0, 0, 39, '2374'),
	(377, 1, 0, -50925, 2376, 0, 0, 39, '2375'),
	(377, 1, 0, -50925, 2377, 0, 0, 39, '2376'),
	(377, 1, 0, -50925, 2378, 0, 0, 39, '2377'),
	(377, 1, 0, -50925, 2379, 0, 0, 39, '2378'),
	(377, 1, 0, -50925, 2380, 0, 0, 39, '2379'),
	(377, 1, 0, -50925, 2381, 0, 0, 39, '2380'),
	(377, 1, 0, -50925, 2382, 0, 0, 39, '2381'),
	(377, 1, 0, -50925, 2383, 0, 0, 39, '2382'),
	(377, 1, 0, -50925, 2384, 0, 0, 39, '2383'),
	(377, 1, 0, -50925, 2385, 0, 0, 39, '2384'),
	(377, 1, 0, -50925, 2386, 0, 0, 39, '2385'),
	(377, 1, 0, -50925, 2387, 0, 0, 39, '2386'),
	(377, 1, 0, -50925, 2388, 0, 0, 39, '2387'),
	(377, 1, 0, -50925, 2389, 0, 0, 39, '2388'),
	(377, 1, 0, -50925, 2390, 0, 0, 39, '2389'),
	(377, 1, 0, -50925, 2391, 0, 0, 39, '2390'),
	(377, 1, 0, -50925, 2392, 0, 0, 39, '2391'),
	(377, 1, 0, -50925, 2393, 0, 0, 39, '2392'),
	(377, 1, 0, -50925, 2394, 0, 0, 39, '2393'),
	(377, 1, 0, -50925, 2395, 0, 0, 39, '2394'),
	(377, 1, 0, -50925, 2396, 0, 0, 39, '2395'),
	(377, 1, 0, -50925, 2397, 0, 0, 39, '2396'),
	(377, 1, 0, -50925, 2398, 0, 0, 39, '2397'),
	(377, 1, 0, -50925, 2399, 0, 0, 39, '2398'),
	(377, 1, 0, -50925, 2400, 0, 0, 39, '2399'),
	(377, 1, 0, -50925, 2401, 0, 0, 39, '2400'),
	(377, 1, 0, -50925, 2402, 0, 0, 39, '2401'),
	(377, 1, 0, -50925, 2403, 0, 0, 39, '2402'),
	(377, 1, 0, -50925, 2404, 0, 0, 39, '2403'),
	(377, 1, 0, -50925, 2405, 0, 0, 39, '2404'),
	(377, 1, 0, -50925, 2406, 0, 0, 39, '2405'),
	(377, 1, 0, -50925, 2407, 0, 0, 39, '2406'),
	(377, 1, 0, -50925, 2408, 0, 0, 39, '2407'),
	(377, 1, 0, -50925, 2409, 0, 0, 39, '2408'),
	(377, 1, 0, -50925, 2410, 0, 0, 39, '2409'),
	(377, 1, 0, -50925, 2411, 0, 0, 39, '2410'),
	(377, 1, 0, -50925, 2412, 0, 0, 39, '2411'),
	(377, 1, 0, -50925, 2413, 0, 0, 39, '2412'),
	(377, 1, 0, -50925, 2414, 0, 0, 39, '2413'),
	(377, 1, 0, -50925, 2415, 0, 0, 39, '2414'),
	(377, 1, 0, -50925, 2416, 0, 0, 39, '2415'),
	(377, 1, 0, -50925, 2417, 0, 0, 39, '2416'),
	(377, 1, 0, -50925, 2418, 0, 0, 39, '2417'),
	(377, 1, 0, -50925, 2419, 0, 0, 39, '2418'),
	(377, 1, 0, -50925, 2420, 0, 0, 39, '2419'),
	(377, 1, 0, -50925, 2421, 0, 0, 39, '2420'),
	(377, 1, 0, -50925, 2422, 0, 0, 39, '2421'),
	(377, 1, 0, -50925, 2423, 0, 0, 39, '2422'),
	(377, 1, 0, -50925, 2424, 0, 0, 39, '2423'),
	(377, 1, 0, -50925, 2425, 0, 0, 39, '2424'),
	(377, 1, 0, -50925, 2426, 0, 0, 39, '2425'),
	(377, 1, 0, -50925, 2427, 0, 0, 39, '2426'),
	(377, 1, 0, -50925, 2428, 0, 0, 39, '2427'),
	(377, 1, 0, -50925, 2429, 0, 0, 39, '2428'),
	(377, 1, 0, -50925, 2430, 0, 0, 39, '2429'),
	(377, 1, 0, -50925, 2431, 0, 0, 39, '2430'),
	(377, 1, 0, -50925, 2432, 0, 0, 39, '2431'),
	(377, 1, 0, -50925, 2433, 0, 0, 39, '2432'),
	(377, 1, 0, -50925, 2434, 0, 0, 39, '2433'),
	(377, 1, 0, -50925, 2435, 0, 0, 39, '2434'),
	(377, 1, 0, -50925, 2436, 0, 0, 39, '2435'),
	(377, 1, 0, -50925, 2437, 0, 0, 39, '2436'),
	(377, 1, 0, -50925, 2438, 0, 0, 39, '2437'),
	(377, 1, 0, -50925, 2439, 0, 0, 39, '2438'),
	(377, 1, 0, -50925, 2440, 0, 0, 39, '2439'),
	(377, 1, 0, -50925, 2441, 0, 0, 39, '2440'),
	(377, 1, 0, -50925, 2442, 0, 0, 39, '2441'),
	(377, 1, 0, -50925, 2443, 0, 0, 39, '2442'),
	(377, 1, 0, -50925, 2444, 0, 0, 39, '2443'),
	(377, 1, 0, -50925, 2445, 0, 0, 39, '2444'),
	(377, 1, 0, -50925, 2446, 0, 0, 39, '2445'),
	(377, 1, 0, -50925, 2447, 0, 0, 39, '2446'),
	(377, 1, 0, -50925, 2448, 0, 0, 39, '2447'),
	(377, 1, 0, -50925, 2449, 0, 0, 39, '2448'),
	(377, 1, 0, -50925, 2450, 0, 0, 39, '2449'),
	(377, 1, 0, -50925, 2451, 0, 0, 39, '2450'),
	(377, 1, 0, -50925, 2452, 0, 0, 39, '2451'),
	(377, 1, 0, -50925, 2453, 0, 0, 39, '2452'),
	(377, 1, 0, -50925, 2454, 0, 0, 39, '2453'),
	(377, 1, 0, -50925, 2455, 0, 0, 39, '2454'),
	(377, 1, 0, -50925, 2456, 0, 0, 39, '2455'),
	(377, 1, 0, -50925, 2457, 0, 0, 39, '2456'),
	(377, 1, 0, -50925, 2458, 0, 0, 39, '2457'),
	(377, 1, 0, -50925, 2459, 0, 0, 39, '2458'),
	(377, 1, 0, -50925, 2460, 0, 0, 39, '2459'),
	(377, 1, 0, -50925, 2461, 0, 0, 39, '2460'),
	(377, 1, 0, -50925, 2462, 0, 0, 39, '2461'),
	(377, 1, 0, -50925, 2463, 0, 0, 39, '2462'),
	(377, 1, 0, -50925, 2464, 0, 0, 39, '2463'),
	(377, 1, 0, -50925, 2465, 0, 0, 39, '2464'),
	(377, 1, 0, -50925, 2466, 0, 0, 39, '2465'),
	(377, 1, 0, -50925, 2467, 0, 0, 39, '2466'),
	(377, 1, 0, -50925, 2468, 0, 0, 39, '2467'),
	(377, 1, 0, -50925, 2469, 0, 0, 39, '2468'),
	(377, 1, 0, -50925, 2470, 0, 0, 39, '2469'),
	(377, 1, 0, -50925, 2471, 0, 0, 39, '2470'),
	(377, 1, 0, -50925, 2472, 0, 0, 39, '2471'),
	(377, 1, 0, -50925, 2473, 0, 0, 39, '2472'),
	(377, 1, 0, -50925, 2474, 0, 0, 39, '2473'),
	(377, 1, 0, -50925, 2475, 0, 0, 39, '2474'),
	(377, 1, 0, -50925, 2476, 0, 0, 39, '2475'),
	(377, 1, 0, -50925, 2477, 0, 0, 39, '2476'),
	(377, 1, 0, -50925, 2478, 0, 0, 39, '2477'),
	(377, 1, 0, -50925, 2479, 0, 0, 39, '2478'),
	(377, 1, 0, -50925, 2480, 0, 0, 39, '2479'),
	(377, 1, 0, -50925, 2481, 0, 0, 39, '2480'),
	(377, 1, 0, -50925, 2482, 0, 0, 39, '2481'),
	(377, 1, 0, -50925, 2483, 0, 0, 39, '2482'),
	(377, 1, 0, -50925, 2484, 0, 0, 39, '2483'),
	(377, 1, 0, -50925, 2485, 0, 0, 39, '2484'),
	(377, 1, 0, -50925, 2486, 0, 0, 39, '2485'),
	(377, 1, 0, -50925, 2487, 0, 0, 39, '2486'),
	(377, 1, 0, -50925, 2488, 0, 0, 39, '2487'),
	(377, 1, 0, -50925, 2489, 0, 0, 39, '2488'),
	(377, 1, 0, -50925, 2490, 0, 0, 39, '2489'),
	(377, 1, 0, -50925, 2491, 0, 0, 39, '2490'),
	(377, 1, 0, -50925, 2492, 0, 0, 39, '2491'),
	(377, 1, 0, -50925, 2493, 0, 0, 39, '2492'),
	(377, 1, 0, -50925, 2494, 0, 0, 39, '2493'),
	(377, 1, 0, -50925, 2495, 0, 0, 39, '2494'),
	(377, 1, 0, -50925, 2496, 0, 0, 39, '2495'),
	(377, 1, 0, -50925, 2497, 0, 0, 39, '2496'),
	(377, 1, 0, -50925, 2498, 0, 0, 39, '2497'),
	(377, 1, 0, -50925, 2499, 0, 0, 39, '2498'),
	(377, 1, 0, -50925, 2500, 0, 0, 39, '2499'),
	(377, 1, 0, -50925, 2501, 0, 0, 39, '2500'),
	(377, 1, 0, -50925, 2502, 0, 0, 39, '2501'),
	(377, 1, 0, -50925, 2503, 0, 0, 39, '2502'),
	(377, 1, 0, -50925, 2504, 0, 0, 39, '2503'),
	(377, 1, 0, -50925, 2505, 0, 0, 39, '2504'),
	(377, 1, 0, -50925, 2506, 0, 0, 39, '2505'),
	(377, 1, 0, -50925, 2507, 0, 0, 39, '2506'),
	(377, 1, 0, -50925, 2508, 0, 0, 39, '2507'),
	(377, 1, 0, -50925, 2509, 0, 0, 39, '2508'),
	(377, 1, 0, -50925, 2510, 0, 0, 39, '2509'),
	(377, 1, 0, -50925, 2511, 0, 0, 39, '2510'),
	(377, 1, 0, -50925, 2512, 0, 0, 39, '2511'),
	(377, 1, 0, -50925, 2513, 0, 0, 39, '2512'),
	(377, 1, 0, -50925, 2514, 0, 0, 39, '2513'),
	(377, 1, 0, -50925, 2515, 0, 0, 39, '2514'),
	(377, 1, 0, -50925, 2516, 0, 0, 39, '2515'),
	(377, 1, 0, -50925, 2517, 0, 0, 39, '2516'),
	(377, 1, 0, -50925, 2518, 0, 0, 39, '2517'),
	(377, 1, 0, -50925, 2519, 0, 0, 39, '2518'),
	(377, 1, 0, -50925, 2520, 0, 0, 39, '2519'),
	(377, 1, 0, -50925, 2521, 0, 0, 39, '2520'),
	(377, 1, 0, -50925, 2522, 0, 0, 39, '2521'),
	(377, 1, 0, -50925, 2523, 0, 0, 39, '2522'),
	(377, 1, 0, -50925, 2524, 0, 0, 39, '2523'),
	(377, 1, 0, -50925, 2525, 0, 0, 39, '2524'),
	(377, 1, 0, -50925, 2526, 0, 0, 39, '2525'),
	(377, 1, 0, -50925, 2527, 0, 0, 39, '2526'),
	(377, 1, 0, -50925, 2528, 0, 0, 39, '2527'),
	(377, 1, 0, -50925, 2529, 0, 0, 39, '2528'),
	(377, 1, 0, -50925, 2530, 0, 0, 39, '2529'),
	(377, 1, 0, -50925, 2531, 0, 0, 39, '2530'),
	(377, 1, 0, -50925, 2532, 0, 0, 39, '2531'),
	(377, 1, 0, -50925, 2533, 0, 0, 39, '2532'),
	(377, 1, 0, -50925, 2534, 0, 0, 39, '2533'),
	(377, 1, 0, -50925, 2535, 0, 0, 39, '2534'),
	(377, 1, 0, -50925, 2536, 0, 0, 39, '2535'),
	(377, 1, 0, -50925, 2537, 0, 0, 39, '2536'),
	(377, 1, 0, -50925, 2538, 0, 0, 39, '2537'),
	(377, 1, 0, -50925, 2539, 0, 0, 39, '2538'),
	(377, 1, 0, -50925, 2540, 0, 0, 39, '2539'),
	(377, 1, 0, -50925, 2541, 0, 0, 39, '2540'),
	(377, 1, 0, -50925, 2542, 0, 0, 39, '2541'),
	(377, 1, 0, -50925, 2543, 0, 0, 39, '2542'),
	(377, 1, 0, -50925, 2544, 0, 0, 39, '2543'),
	(377, 1, 0, -50925, 2545, 0, 0, 39, '2544'),
	(377, 1, 0, -50925, 2546, 0, 0, 39, '2545'),
	(377, 1, 0, -50925, 2547, 0, 0, 39, '2546'),
	(377, 1, 0, -50925, 2548, 0, 0, 39, '2547'),
	(377, 1, 0, -50925, 2549, 0, 0, 39, '2548'),
	(377, 1, 0, -50925, 2550, 0, 0, 39, '2549'),
	(377, 1, 0, -50925, 2551, 0, 0, 39, '2550'),
	(377, 1, 0, -50925, 2552, 0, 0, 39, '2551'),
	(377, 1, 0, -50925, 2553, 0, 0, 39, '2552'),
	(377, 1, 0, -50925, 2554, 0, 0, 39, '2553'),
	(377, 1, 0, -50925, 2555, 0, 0, 39, '2554'),
	(377, 1, 0, -50925, 2556, 0, 0, 39, '2555'),
	(377, 1, 0, -50925, 2557, 0, 0, 39, '2556'),
	(377, 1, 0, -50925, 2558, 0, 0, 39, '2557'),
	(377, 1, 0, -50925, 2559, 0, 0, 39, '2558'),
	(377, 1, 0, -50925, 2560, 0, 0, 39, '2559'),
	(377, 1, 0, -50925, 2561, 0, 0, 39, '2560'),
	(377, 1, 0, -50925, 2562, 0, 0, 39, '2561'),
	(377, 1, 0, -50925, 2563, 0, 0, 39, '2562'),
	(377, 1, 0, -50925, 2564, 0, 0, 39, '2563'),
	(377, 1, 0, -50925, 2565, 0, 0, 39, '2564'),
	(377, 1, 0, -50925, 2566, 0, 0, 39, '2565'),
	(377, 1, 0, -50925, 2567, 0, 0, 39, '2566'),
	(377, 1, 0, -50925, 2568, 0, 0, 39, '2567'),
	(377, 1, 0, -50925, 2569, 0, 0, 39, '2568'),
	(377, 1, 0, -50925, 2570, 0, 0, 39, '2569'),
	(377, 1, 0, -50925, 2571, 0, 0, 39, '2570'),
	(377, 1, 0, -50925, 2572, 0, 0, 39, '2571'),
	(377, 1, 0, -50925, 2573, 0, 0, 39, '2572'),
	(377, 1, 0, -50925, 2574, 0, 0, 39, '2573'),
	(377, 1, 0, -50925, 2575, 0, 0, 39, '2574'),
	(377, 1, 0, -50925, 2576, 0, 0, 39, '2575'),
	(377, 1, 0, -50925, 2577, 0, 0, 39, '2576'),
	(377, 1, 0, -50925, 2578, 0, 0, 39, '2577'),
	(377, 1, 0, -50925, 2579, 0, 0, 39, '2578'),
	(377, 1, 0, -50925, 2580, 0, 0, 39, '2579'),
	(377, 1, 0, -50925, 2581, 0, 0, 39, '2580'),
	(377, 1, 0, -50925, 2582, 0, 0, 39, '2581'),
	(377, 1, 0, -50925, 2583, 0, 0, 39, '2582'),
	(377, 1, 0, -50925, 2584, 0, 0, 39, '2583'),
	(377, 1, 0, -50925, 2585, 0, 0, 39, '2584'),
	(377, 1, 0, -50925, 2586, 0, 0, 39, '2585'),
	(377, 1, 0, -50925, 2587, 0, 0, 39, '2586'),
	(377, 1, 0, -50925, 2588, 0, 0, 39, '2587'),
	(377, 1, 0, -50925, 2589, 0, 0, 39, '2588'),
	(377, 1, 0, -50925, 2590, 0, 0, 39, '2589'),
	(377, 1, 0, -50925, 2591, 0, 0, 39, '2590'),
	(377, 1, 0, -50925, 2592, 0, 0, 39, '2591'),
	(377, 1, 0, -50925, 2593, 0, 0, 39, '2592'),
	(377, 1, 0, -50925, 2594, 0, 0, 39, '2593'),
	(377, 1, 0, -50925, 2595, 0, 0, 39, '2594'),
	(377, 1, 0, -50925, 2596, 0, 0, 39, '2595'),
	(377, 1, 0, -50925, 2597, 0, 0, 39, '2596'),
	(377, 1, 0, -50925, 2598, 0, 0, 39, '2597'),
	(377, 1, 0, -50925, 2599, 0, 0, 39, '2598'),
	(377, 1, 0, -50925, 2600, 0, 0, 39, '2599'),
	(377, 1, 0, -50925, 2601, 0, 0, 39, '2600'),
	(377, 1, 0, -50925, 2602, 0, 0, 39, '2601'),
	(377, 1, 0, -50925, 2603, 0, 0, 39, '2602'),
	(377, 1, 0, -50925, 2604, 0, 0, 39, '2603'),
	(377, 1, 0, -50925, 2605, 0, 0, 39, '2604'),
	(377, 1, 0, -50925, 2606, 0, 0, 39, '2605'),
	(377, 1, 0, -50925, 2607, 0, 0, 39, '2606'),
	(377, 1, 0, -50925, 2608, 0, 0, 39, '2607'),
	(377, 1, 0, -50925, 2609, 0, 0, 39, '2608'),
	(377, 1, 0, -50925, 2610, 0, 0, 39, '2609'),
	(377, 1, 0, -50925, 2611, 0, 0, 39, '2610'),
	(377, 1, 0, -50925, 2612, 0, 0, 39, '2611'),
	(377, 1, 0, -50925, 2613, 0, 0, 39, '2612'),
	(377, 1, 0, -50925, 2614, 0, 0, 39, '2613'),
	(377, 1, 0, -50925, 2615, 0, 0, 39, '2614'),
	(377, 1, 0, -50925, 2616, 0, 0, 39, '2615'),
	(377, 1, 0, -50925, 2617, 0, 0, 39, '2616'),
	(377, 1, 0, -50925, 2618, 0, 0, 39, '2617'),
	(377, 1, 0, -50925, 2619, 0, 0, 39, '2618'),
	(377, 1, 0, -50925, 2620, 0, 0, 39, '2619'),
	(377, 1, 0, -50925, 2621, 0, 0, 39, '2620'),
	(377, 1, 0, -50925, 2622, 0, 0, 39, '2621'),
	(377, 1, 0, -50925, 2623, 0, 0, 39, '2622'),
	(377, 1, 0, -50925, 2624, 0, 0, 39, '2623'),
	(377, 1, 0, -50925, 2625, 0, 0, 39, '2624'),
	(377, 1, 0, -50925, 2626, 0, 0, 39, '2625'),
	(377, 1, 0, -50925, 2627, 0, 0, 39, '2626'),
	(377, 1, 0, -50925, 2628, 0, 0, 39, '2627'),
	(377, 1, 0, -50925, 2629, 0, 0, 39, '2628'),
	(377, 1, 0, -50925, 2630, 0, 0, 39, '2629'),
	(377, 1, 0, -50925, 2631, 0, 0, 39, '2630'),
	(377, 1, 0, -50925, 2632, 0, 0, 39, '2631'),
	(377, 1, 0, -50925, 2633, 0, 0, 39, '2632'),
	(377, 1, 0, -50925, 2634, 0, 0, 39, '2633'),
	(377, 1, 0, -50925, 2635, 0, 0, 39, '2634'),
	(377, 1, 0, -50925, 2636, 0, 0, 39, '2635'),
	(377, 1, 0, -50925, 2637, 0, 0, 39, '2636'),
	(377, 1, 0, -50925, 2638, 0, 0, 39, '2637'),
	(377, 1, 0, -50925, 2639, 0, 0, 39, '2638'),
	(377, 1, 0, -50925, 2640, 0, 0, 39, '2639'),
	(377, 1, 0, -50925, 2641, 0, 0, 39, '2640'),
	(377, 1, 0, -50925, 2642, 0, 0, 39, '2641'),
	(377, 1, 0, -50925, 2643, 0, 0, 39, '2642'),
	(377, 1, 0, -50925, 2644, 0, 0, 39, '2643'),
	(377, 1, 0, -50925, 2645, 0, 0, 39, '2644'),
	(377, 1, 0, -50925, 2646, 0, 0, 39, '2645'),
	(377, 1, 0, -50925, 2647, 0, 0, 39, '2646'),
	(377, 1, 0, -50925, 2648, 0, 0, 39, '2647'),
	(377, 1, 0, -50925, 2649, 0, 0, 39, '2648'),
	(377, 1, 0, -50925, 2650, 0, 0, 39, '2649'),
	(377, 1, 0, -50925, 2651, 0, 0, 39, '2650'),
	(377, 1, 0, -50925, 2652, 0, 0, 39, '2651'),
	(377, 1, 0, -50925, 2653, 0, 0, 39, '2652'),
	(377, 1, 0, -50925, 2654, 0, 0, 39, '2653'),
	(377, 1, 0, -50925, 2655, 0, 0, 39, '2654'),
	(377, 1, 0, -50925, 2656, 0, 0, 39, '2655'),
	(377, 1, 0, -50925, 2657, 0, 0, 39, '2656'),
	(377, 1, 0, -50925, 2658, 0, 0, 39, '2657'),
	(377, 1, 0, -50925, 2659, 0, 0, 39, '2658'),
	(377, 1, 0, -50925, 2660, 0, 0, 39, '2659'),
	(377, 1, 0, -50925, 2661, 0, 0, 39, '2660'),
	(377, 1, 0, -50925, 2662, 0, 0, 39, '2661'),
	(377, 1, 0, -50925, 2663, 0, 0, 39, '2662'),
	(377, 1, 0, -50925, 2664, 0, 0, 39, '2663'),
	(377, 1, 0, -50925, 2665, 0, 0, 39, '2664'),
	(377, 1, 0, -50925, 2666, 0, 0, 39, '2665'),
	(377, 1, 0, -50925, 2667, 0, 0, 39, '2666'),
	(377, 1, 0, -50925, 2668, 0, 0, 39, '2667'),
	(377, 1, 0, -50925, 2669, 0, 0, 39, '2668'),
	(377, 1, 0, -50925, 2670, 0, 0, 39, '2669'),
	(377, 1, 0, -50925, 2671, 0, 0, 39, '2670'),
	(377, 1, 0, -50925, 2672, 0, 0, 39, '2671'),
	(377, 1, 0, -50925, 2673, 0, 0, 39, '2672'),
	(377, 1, 0, -50925, 2674, 0, 0, 39, '2673'),
	(377, 1, 0, -50925, 2675, 0, 0, 39, '2674'),
	(377, 1, 0, -50925, 2676, 0, 0, 39, '2675'),
	(377, 1, 0, -50925, 2677, 0, 0, 39, '2676'),
	(377, 1, 0, -50925, 2678, 0, 0, 39, '2677'),
	(377, 1, 0, -50925, 2679, 0, 0, 39, '2678'),
	(377, 1, 0, -50925, 2680, 0, 0, 39, '2679'),
	(377, 1, 0, -50925, 2681, 0, 0, 39, '2680'),
	(377, 1, 0, -50925, 2682, 0, 0, 39, '2681'),
	(377, 1, 0, -50925, 2683, 0, 0, 39, '2682'),
	(377, 1, 0, -50925, 2684, 0, 0, 39, '2683'),
	(377, 1, 0, -50925, 2685, 0, 0, 39, '2684'),
	(377, 1, 0, -50925, 2686, 0, 0, 39, '2685'),
	(377, 1, 0, -50925, 2687, 0, 0, 39, '2686'),
	(377, 1, 0, -50925, 2688, 0, 0, 39, '2687'),
	(377, 1, 0, -50925, 2689, 0, 0, 39, '2688'),
	(377, 1, 0, -50925, 2690, 0, 0, 39, '2689'),
	(377, 1, 0, -50925, 2691, 0, 0, 39, '2690'),
	(377, 1, 0, -50925, 2692, 0, 0, 39, '2691'),
	(377, 1, 0, -50925, 2693, 0, 0, 39, '2692'),
	(377, 1, 0, -50925, 2694, 0, 0, 39, '2693'),
	(377, 1, 0, -50925, 2695, 0, 0, 39, '2694'),
	(377, 1, 0, -50925, 2696, 0, 0, 39, '2695'),
	(377, 1, 0, -50925, 2697, 0, 0, 39, '2696'),
	(377, 1, 0, -50925, 2698, 0, 0, 39, '2697'),
	(377, 1, 0, -50925, 2699, 0, 0, 39, '2698'),
	(377, 1, 0, -50925, 2700, 0, 0, 39, '2699'),
	(377, 1, 0, -50925, 2701, 0, 0, 39, '2700'),
	(377, 1, 0, -50925, 2702, 0, 0, 39, '2701'),
	(377, 1, 0, -50925, 2703, 0, 0, 39, '2702'),
	(377, 1, 0, -50925, 2704, 0, 0, 39, '2703'),
	(377, 1, 0, -50925, 2705, 0, 0, 39, '2704'),
	(377, 1, 0, -50925, 2706, 0, 0, 39, '2705'),
	(377, 1, 0, -50925, 2707, 0, 0, 39, '2706'),
	(377, 1, 0, -50925, 2708, 0, 0, 39, '2707'),
	(377, 1, 0, -50925, 2709, 0, 0, 39, '2708'),
	(377, 1, 0, -50925, 2710, 0, 0, 39, '2709'),
	(377, 1, 0, -50925, 2711, 0, 0, 39, '2710'),
	(377, 1, 0, -50925, 2712, 0, 0, 39, '2711'),
	(377, 1, 0, -50925, 2713, 0, 0, 39, '2712'),
	(377, 1, 0, -50925, 2714, 0, 0, 39, '2713'),
	(377, 1, 0, -50925, 2715, 0, 0, 39, '2714'),
	(377, 1, 0, -50925, 2716, 0, 0, 39, '2715'),
	(377, 1, 0, -50925, 2717, 0, 0, 39, '2716'),
	(377, 1, 0, -50925, 2718, 0, 0, 39, '2717'),
	(377, 1, 0, -50925, 2719, 0, 0, 39, '2718'),
	(377, 1, 0, -50925, 2720, 0, 0, 39, '2719'),
	(377, 1, 0, -50925, 2721, 0, 0, 39, '2720'),
	(377, 1, 0, -50925, 2722, 0, 0, 39, '2721'),
	(377, 1, 0, -50925, 2723, 0, 0, 39, '2722'),
	(377, 1, 0, -50925, 2724, 0, 0, 39, '2723'),
	(377, 1, 0, -50925, 2725, 0, 0, 39, '2724'),
	(377, 1, 0, -50925, 2726, 0, 0, 39, '2725'),
	(377, 1, 0, -50925, 2727, 0, 0, 39, '2726'),
	(377, 1, 0, -50925, 2728, 0, 0, 39, '2727'),
	(377, 1, 0, -50925, 2729, 0, 0, 39, '2728'),
	(377, 1, 0, -50925, 2730, 0, 0, 39, '2729'),
	(377, 1, 0, -50925, 2731, 0, 0, 39, '2730'),
	(377, 1, 0, -50925, 2732, 0, 0, 39, '2731'),
	(377, 1, 0, -50925, 2733, 0, 0, 39, '2732'),
	(377, 1, 0, -50925, 2734, 0, 0, 39, '2733'),
	(377, 1, 0, -50925, 2735, 0, 0, 39, '2734'),
	(377, 1, 0, -50925, 2736, 0, 0, 39, '2735'),
	(377, 1, 0, -50925, 2737, 0, 0, 39, '2736'),
	(377, 1, 0, -50925, 2738, 0, 0, 39, '2737'),
	(377, 1, 0, -50925, 2739, 0, 0, 39, '2738'),
	(377, 1, 0, -50925, 2740, 0, 0, 39, '2739'),
	(377, 1, 0, -50925, 2741, 0, 0, 39, '2740'),
	(377, 1, 0, -50925, 2742, 0, 0, 39, '2741'),
	(377, 1, 0, -50925, 2743, 0, 0, 39, '2742'),
	(377, 1, 0, -50925, 2744, 0, 0, 39, '2743'),
	(377, 1, 0, -50925, 2745, 0, 0, 39, '2744'),
	(377, 1, 0, -50925, 2746, 0, 0, 39, '2745'),
	(377, 1, 0, -50925, 2747, 0, 0, 39, '2746'),
	(377, 1, 0, -50925, 2748, 0, 0, 39, '2747'),
	(377, 1, 0, -50925, 2749, 0, 0, 39, '2748'),
	(377, 1, 0, -50925, 2750, 0, 0, 39, '2749'),
	(377, 1, 0, -50925, 2751, 0, 0, 39, '2750'),
	(377, 1, 0, -50925, 2752, 0, 0, 39, '2751'),
	(377, 1, 0, -50925, 2753, 0, 0, 39, '2752'),
	(377, 1, 0, -50925, 2754, 0, 0, 39, '2753'),
	(377, 1, 0, -50925, 2755, 0, 0, 39, '2754'),
	(377, 1, 0, -50925, 2756, 0, 0, 39, '2755'),
	(377, 1, 0, -50925, 2757, 0, 0, 39, '2756'),
	(377, 1, 0, -50925, 2758, 0, 0, 39, '2757'),
	(377, 1, 0, -50925, 2759, 0, 0, 39, '2758'),
	(377, 1, 0, -50925, 2760, 0, 0, 39, '2759'),
	(377, 1, 0, -50925, 2761, 0, 0, 39, '2760'),
	(377, 1, 0, -50925, 2762, 0, 0, 39, '2761'),
	(377, 1, 0, -50925, 2763, 0, 0, 39, '2762'),
	(377, 1, 0, -50925, 2764, 0, 0, 39, '2763'),
	(377, 1, 0, -50925, 2765, 0, 0, 39, '2764'),
	(377, 1, 0, -50925, 2766, 0, 0, 39, '2765'),
	(377, 1, 0, -50925, 2767, 0, 0, 39, '2766'),
	(377, 1, 0, -50925, 2768, 0, 0, 39, '2767'),
	(377, 1, 0, -50925, 2769, 0, 0, 39, '2768'),
	(377, 1, 0, -50925, 2770, 0, 0, 39, '2769'),
	(377, 1, 0, -50925, 2771, 0, 0, 39, '2770'),
	(377, 1, 0, -50925, 2772, 0, 0, 39, '2771'),
	(377, 1, 0, -50925, 2773, 0, 0, 39, '2772'),
	(377, 1, 0, -50925, 2774, 0, 0, 39, '2773'),
	(377, 1, 0, -50925, 2775, 0, 0, 39, '2774'),
	(377, 1, 0, -50925, 2776, 0, 0, 39, '2775'),
	(377, 1, 0, -50925, 2777, 0, 0, 39, '2776'),
	(377, 1, 0, -50925, 2778, 0, 0, 39, '2777'),
	(377, 1, 0, -50925, 2779, 0, 0, 39, '2778'),
	(377, 1, 0, -50925, 2780, 0, 0, 39, '2779'),
	(377, 1, 0, -50925, 2781, 0, 0, 39, '2780'),
	(377, 1, 0, -50925, 2782, 0, 0, 39, '2781'),
	(377, 1, 0, -50925, 2783, 0, 0, 39, '2782'),
	(377, 1, 0, -50925, 2784, 0, 0, 39, '2783'),
	(377, 1, 0, -50925, 2785, 0, 0, 39, '2784'),
	(377, 1, 0, -50925, 2786, 0, 0, 39, '2785'),
	(377, 1, 0, -50925, 2787, 0, 0, 39, '2786'),
	(377, 1, 0, -50925, 2788, 0, 0, 39, '2787'),
	(377, 1, 0, -50925, 2789, 0, 0, 39, '2788'),
	(377, 1, 0, -50925, 2790, 0, 0, 39, '2789'),
	(377, 1, 0, -50925, 2791, 0, 0, 39, '2790'),
	(377, 1, 0, -50925, 2792, 0, 0, 39, '2791'),
	(377, 1, 0, -50925, 2793, 0, 0, 39, '2792'),
	(377, 1, 0, -50925, 2794, 0, 0, 39, '2793'),
	(377, 1, 0, -50925, 2795, 0, 0, 39, '2794'),
	(377, 1, 0, -50925, 2796, 0, 0, 39, '2795'),
	(377, 1, 0, -50925, 2797, 0, 0, 39, '2796'),
	(377, 1, 0, -50925, 2798, 0, 0, 39, '2797'),
	(377, 1, 0, -50925, 2799, 0, 0, 39, '2798'),
	(377, 1, 0, -50925, 2800, 0, 0, 39, '2799'),
	(377, 1, 0, -50925, 2801, 0, 0, 39, '2800'),
	(377, 1, 0, -50925, 2802, 0, 0, 39, '2801'),
	(377, 1, 0, -50925, 2803, 0, 0, 39, '2802'),
	(377, 1, 0, -50925, 2804, 0, 0, 39, '2803'),
	(377, 1, 0, -50925, 2805, 0, 0, 39, '2804'),
	(377, 1, 0, -50925, 2806, 0, 0, 39, '2805'),
	(377, 1, 0, -50925, 2807, 0, 0, 39, '2806'),
	(377, 1, 0, -50925, 2808, 0, 0, 39, '2807'),
	(377, 1, 0, -50925, 2809, 0, 0, 39, '2808'),
	(377, 1, 0, -50925, 2810, 0, 0, 39, '2809'),
	(377, 1, 0, -50925, 2811, 0, 0, 39, '2810'),
	(377, 1, 0, -50925, 2812, 0, 0, 39, '2811'),
	(377, 1, 0, -50925, 2813, 0, 0, 39, '2812'),
	(377, 1, 0, -50925, 2814, 0, 0, 39, '2813'),
	(377, 1, 0, -50925, 2815, 0, 0, 39, '2814'),
	(377, 1, 0, -50925, 2816, 0, 0, 39, '2815'),
	(377, 1, 0, -50925, 2817, 0, 0, 39, '2816'),
	(377, 1, 0, -50925, 2818, 0, 0, 39, '2817'),
	(377, 1, 0, -50925, 2819, 0, 0, 39, '2818'),
	(377, 1, 0, -50925, 2820, 0, 0, 39, '2819'),
	(377, 1, 0, -50925, 2821, 0, 0, 39, '2820'),
	(377, 1, 0, -50925, 2822, 0, 0, 39, '2821'),
	(377, 1, 0, -50925, 2823, 0, 0, 39, '2822'),
	(377, 1, 0, -50925, 2824, 0, 0, 39, '2823'),
	(377, 1, 0, -50925, 2825, 0, 0, 39, '2824'),
	(377, 1, 0, -50925, 2826, 0, 0, 39, '2825'),
	(377, 1, 0, -50925, 2827, 0, 0, 39, '2826'),
	(377, 1, 0, -50925, 2828, 0, 0, 39, '2827'),
	(377, 1, 0, -50925, 2829, 0, 0, 39, '2828'),
	(377, 1, 0, -50925, 2830, 0, 0, 39, '2829'),
	(377, 1, 0, -50925, 2831, 0, 0, 39, '2830'),
	(377, 1, 0, -50925, 2832, 0, 0, 39, '2831'),
	(377, 1, 0, -50925, 2833, 0, 0, 39, '2832'),
	(377, 1, 0, -50925, 2834, 0, 0, 39, '2833'),
	(377, 1, 0, -50925, 2835, 0, 0, 39, '2834'),
	(377, 1, 0, -50925, 2836, 0, 0, 39, '2835'),
	(377, 1, 0, -50925, 2837, 0, 0, 39, '2836'),
	(377, 1, 0, -50925, 2838, 0, 0, 39, '2837'),
	(377, 1, 0, -50925, 2839, 0, 0, 39, '2838'),
	(377, 1, 0, -50925, 2840, 0, 0, 39, '2839'),
	(377, 1, 0, -50925, 2841, 0, 0, 39, '2840'),
	(377, 1, 0, -50925, 2842, 0, 0, 39, '2841'),
	(377, 1, 0, -50925, 2843, 0, 0, 39, '2842'),
	(377, 1, 0, -50925, 2844, 0, 0, 39, '2843'),
	(377, 1, 0, -50925, 2845, 0, 0, 39, '2844'),
	(377, 1, 0, -50925, 2846, 0, 0, 39, '2845'),
	(377, 1, 0, -50925, 2847, 0, 0, 39, '2846'),
	(377, 1, 0, -50925, 2848, 0, 0, 39, '2847'),
	(377, 1, 0, -50925, 2849, 0, 0, 39, '2848'),
	(377, 1, 0, -50925, 2850, 0, 0, 39, '2849'),
	(377, 1, 0, -50925, 2851, 0, 0, 39, '2850'),
	(377, 1, 0, -50925, 2852, 0, 0, 39, '2851'),
	(377, 1, 0, -50925, 2853, 0, 0, 39, '2852'),
	(377, 1, 0, -50925, 2854, 0, 0, 39, '2853'),
	(377, 1, 0, -50925, 2855, 0, 0, 39, '2854'),
	(377, 1, 0, -50925, 2856, 0, 0, 39, '2855'),
	(377, 1, 0, -50925, 2857, 0, 0, 39, '2856'),
	(377, 1, 0, -50925, 2858, 0, 0, 39, '2857'),
	(377, 1, 0, -50925, 2859, 0, 0, 39, '2858'),
	(377, 1, 0, -50925, 2860, 0, 0, 39, '2859'),
	(377, 1, 0, -50925, 2861, 0, 0, 39, '2860'),
	(377, 1, 0, -50925, 2862, 0, 0, 39, '2861'),
	(377, 1, 0, -50925, 2863, 0, 0, 39, '2862'),
	(377, 1, 0, -50925, 2864, 0, 0, 39, '2863'),
	(377, 1, 0, -50925, 2865, 0, 0, 39, '2864'),
	(377, 1, 0, -50925, 2866, 0, 0, 39, '2865'),
	(377, 1, 0, -50925, 2867, 0, 0, 39, '2866'),
	(377, 1, 0, -50925, 2868, 0, 0, 39, '2867'),
	(377, 1, 0, -50925, 2869, 0, 0, 39, '2868'),
	(377, 1, 0, -50925, 2870, 0, 0, 39, '2869'),
	(377, 1, 0, -50925, 2871, 0, 0, 39, '2870'),
	(377, 1, 0, -50925, 2872, 0, 0, 39, '2871'),
	(377, 1, 0, -50925, 2873, 0, 0, 39, '2872'),
	(377, 1, 0, -50925, 2874, 0, 0, 39, '2873'),
	(377, 1, 0, -50925, 2875, 0, 0, 39, '2874'),
	(377, 1, 0, -50925, 2876, 0, 0, 39, '2875'),
	(377, 1, 0, -50925, 2877, 0, 0, 39, '2876'),
	(377, 1, 0, -50925, 2878, 0, 0, 39, '2877'),
	(377, 1, 0, -50925, 2879, 0, 0, 39, '2878'),
	(377, 1, 0, -50925, 2880, 0, 0, 39, '2879'),
	(377, 1, 0, -50925, 2881, 0, 0, 39, '2880'),
	(377, 1, 0, -50925, 2882, 0, 0, 39, '2881'),
	(377, 1, 0, -50925, 2883, 0, 0, 39, '2882'),
	(377, 1, 0, -50925, 2884, 0, 0, 39, '2883'),
	(377, 1, 0, -50925, 2885, 0, 0, 39, '2884'),
	(377, 1, 0, -50925, 2886, 0, 0, 39, '2885'),
	(377, 1, 0, -50925, 2887, 0, 0, 39, '2886'),
	(377, 1, 0, -50925, 2888, 0, 0, 39, '2887'),
	(377, 1, 0, -50925, 2889, 0, 0, 39, '2888'),
	(377, 1, 0, -50925, 2890, 0, 0, 39, '2889'),
	(377, 1, 0, -50925, 2891, 0, 0, 39, '2890'),
	(377, 1, 0, -50925, 2892, 0, 0, 39, '2891'),
	(377, 1, 0, -50925, 2893, 0, 0, 39, '2892'),
	(377, 1, 0, -50925, 2894, 0, 0, 39, '2893'),
	(377, 1, 0, -50925, 2895, 0, 0, 39, '2894'),
	(377, 1, 0, -50925, 2896, 0, 0, 39, '2895'),
	(377, 1, 0, -50925, 2897, 0, 0, 39, '2896'),
	(377, 1, 0, -50925, 2898, 0, 0, 39, '2897'),
	(377, 1, 0, -50925, 2899, 0, 0, 39, '2898'),
	(377, 1, 0, -50925, 2900, 0, 0, 39, '2899'),
	(377, 1, 0, -50925, 2901, 0, 0, 39, '2900'),
	(377, 1, 0, -50925, 2902, 0, 0, 39, '2901'),
	(377, 1, 0, -50925, 2903, 0, 0, 39, '2902'),
	(377, 1, 0, -50925, 2904, 0, 0, 39, '2903'),
	(377, 1, 0, -50925, 2905, 0, 0, 39, '2904'),
	(377, 1, 0, -50925, 2906, 0, 0, 39, '2905'),
	(377, 1, 0, -50925, 2907, 0, 0, 39, '2906'),
	(377, 1, 0, -50925, 2908, 0, 0, 39, '2907'),
	(377, 1, 0, -50925, 2909, 0, 0, 39, '2908'),
	(377, 1, 0, -50925, 2910, 0, 0, 39, '2909'),
	(377, 1, 0, -50925, 2911, 0, 0, 39, '2910'),
	(377, 1, 0, -50925, 2912, 0, 0, 39, '2911'),
	(377, 1, 0, -50925, 2913, 0, 0, 39, '2912'),
	(377, 1, 0, -50925, 2914, 0, 0, 39, '2913'),
	(377, 1, 0, -50925, 2915, 0, 0, 39, '2914'),
	(377, 1, 0, -50925, 2916, 0, 0, 39, '2915'),
	(377, 1, 0, -50925, 2917, 0, 0, 39, '2916'),
	(377, 1, 0, -50925, 2918, 0, 0, 39, '2917'),
	(377, 1, 0, -50925, 2919, 0, 0, 39, '2918'),
	(377, 1, 0, -50925, 2920, 0, 0, 39, '2919'),
	(377, 1, 0, -50925, 2921, 0, 0, 39, '2920'),
	(377, 1, 0, -50925, 2922, 0, 0, 39, '2921'),
	(377, 1, 0, -50925, 2923, 0, 0, 39, '2922'),
	(377, 1, 0, -50925, 2924, 0, 0, 39, '2923'),
	(377, 1, 0, -50925, 2925, 0, 0, 39, '2924'),
	(377, 1, 0, -50925, 2926, 0, 0, 39, '2925'),
	(377, 1, 0, -50925, 2927, 0, 0, 39, '2926'),
	(377, 1, 0, -50925, 2928, 0, 0, 39, '2927'),
	(377, 1, 0, -50925, 2929, 0, 0, 39, '2928'),
	(377, 1, 0, -50925, 2930, 0, 0, 39, '2929'),
	(377, 1, 0, -50925, 2931, 0, 0, 39, '2930'),
	(377, 1, 0, -50925, 2932, 0, 0, 39, '2931'),
	(377, 1, 0, -50925, 2933, 0, 0, 39, '2932'),
	(377, 1, 0, -50925, 2934, 0, 0, 39, '2933'),
	(377, 1, 0, -50925, 2935, 0, 0, 39, '2934'),
	(377, 1, 0, -50925, 2936, 0, 0, 39, '2935'),
	(377, 1, 0, -50925, 2937, 0, 0, 39, '2936'),
	(377, 1, 0, -50925, 2938, 0, 0, 39, '2937'),
	(377, 1, 0, -50925, 2939, 0, 0, 39, '2938'),
	(377, 1, 0, -50925, 2940, 0, 0, 39, '2939'),
	(377, 1, 0, -50925, 2941, 0, 0, 39, '2940'),
	(377, 1, 0, -50925, 2942, 0, 0, 39, '2941'),
	(377, 1, 0, -50925, 2943, 0, 0, 39, '2942'),
	(377, 1, 0, -50925, 2944, 0, 0, 39, '2943'),
	(377, 1, 0, -50925, 2945, 0, 0, 39, '2944'),
	(377, 1, 0, -50925, 2946, 0, 0, 39, '2945'),
	(377, 1, 0, -50925, 2947, 0, 0, 39, '2946'),
	(377, 1, 0, -50925, 2948, 0, 0, 39, '2947'),
	(377, 1, 0, -50925, 2949, 0, 0, 39, '2948'),
	(377, 1, 0, -50925, 2950, 0, 0, 39, '2949'),
	(377, 1, 0, -50925, 2951, 0, 0, 39, '2950'),
	(377, 1, 0, -50925, 2952, 0, 0, 39, '2951'),
	(377, 1, 0, -50925, 2953, 0, 0, 39, '2952'),
	(377, 1, 0, -50925, 2954, 0, 0, 39, '2953'),
	(377, 1, 0, -50925, 2955, 0, 0, 39, '2954'),
	(377, 1, 0, -50925, 2956, 0, 0, 39, '2955'),
	(377, 1, 0, -50925, 2957, 0, 0, 39, '2956'),
	(377, 1, 0, -50925, 2958, 0, 0, 39, '2957'),
	(377, 1, 0, -50925, 2959, 0, 0, 39, '2958'),
	(377, 1, 0, -50925, 2960, 0, 0, 39, '2959'),
	(377, 1, 0, -50925, 2961, 0, 0, 39, '2960'),
	(377, 1, 0, -50925, 2962, 0, 0, 39, '2961'),
	(377, 1, 0, -50925, 2963, 0, 0, 39, '2962'),
	(377, 1, 0, -50925, 2964, 0, 0, 39, '2963'),
	(377, 1, 0, -50925, 2965, 0, 0, 39, '2964'),
	(377, 1, 0, -50925, 2966, 0, 0, 39, '2965'),
	(377, 1, 0, -50925, 2967, 0, 0, 39, '2966'),
	(377, 1, 0, -50925, 2968, 0, 0, 39, '2967'),
	(377, 1, 0, -50925, 2969, 0, 0, 39, '2968'),
	(377, 1, 0, -50925, 2970, 0, 0, 39, '2969'),
	(377, 1, 0, -50925, 2971, 0, 0, 39, '2970'),
	(377, 1, 0, -50925, 2972, 0, 0, 39, '2971'),
	(377, 1, 0, -50925, 2973, 0, 0, 39, '2972'),
	(377, 1, 0, -50925, 2974, 0, 0, 39, '2973'),
	(377, 1, 0, -50925, 2975, 0, 0, 39, '2974'),
	(377, 1, 0, -50925, 2976, 0, 0, 39, '2975'),
	(377, 1, 0, -50925, 2977, 0, 0, 39, '2976'),
	(377, 1, 0, -50925, 2978, 0, 0, 39, '2977'),
	(377, 1, 0, -50925, 2979, 0, 0, 39, '2978'),
	(377, 1, 0, -50925, 2980, 0, 0, 39, '2979'),
	(377, 1, 0, -50925, 2981, 0, 0, 39, '2980'),
	(377, 1, 0, -50925, 2982, 0, 0, 39, '2981'),
	(377, 1, 0, -50925, 2983, 0, 0, 39, '2982'),
	(377, 1, 0, -50925, 2984, 0, 0, 39, '2983'),
	(377, 1, 0, -50925, 2985, 0, 0, 39, '2984'),
	(377, 1, 0, -50925, 2986, 0, 0, 39, '2985'),
	(377, 1, 0, -50925, 2987, 0, 0, 39, '2986'),
	(377, 1, 0, -50925, 2988, 0, 0, 39, '2987'),
	(377, 1, 0, -50925, 2989, 0, 0, 39, '2988'),
	(377, 1, 0, -50925, 2990, 0, 0, 39, '2989'),
	(377, 1, 0, -50925, 2991, 0, 0, 39, '2990'),
	(377, 1, 0, -50925, 2992, 0, 0, 39, '2991'),
	(377, 1, 0, -50925, 2993, 0, 0, 39, '2992'),
	(377, 1, 0, -50925, 2994, 0, 0, 39, '2993'),
	(377, 1, 0, -50925, 2995, 0, 0, 39, '2994'),
	(377, 1, 0, -50925, 2996, 0, 0, 39, '2995'),
	(377, 1, 0, -50925, 2997, 0, 0, 39, '2996'),
	(377, 1, 0, -50925, 2998, 0, 0, 39, '2997'),
	(377, 1, 0, -50925, 2999, 0, 0, 39, '2998'),
	(377, 1, 0, -50925, 3000, 0, 0, 39, '2999'),
	(377, 1, 0, -50925, 3001, 0, 0, 39, '3000'),
	(377, 1, 0, -50925, 3002, 0, 0, 39, '3001'),
	(377, 1, 0, -50925, 3003, 0, 0, 39, '3002'),
	(377, 1, 0, -50925, 3004, 0, 0, 39, '3003'),
	(377, 1, 0, -50925, 3005, 0, 0, 39, '3004'),
	(377, 1, 0, -50925, 3006, 0, 0, 39, '3005'),
	(377, 1, 0, -50925, 3007, 0, 0, 39, '3006'),
	(377, 1, 0, -50925, 3008, 0, 0, 39, '3007'),
	(377, 1, 0, -50925, 3009, 0, 0, 39, '3008'),
	(377, 1, 0, -50925, 3010, 0, 0, 39, '3009'),
	(377, 1, 0, -50925, 3011, 0, 0, 39, '3010'),
	(377, 1, 0, -50925, 3012, 0, 0, 39, '3011'),
	(377, 1, 0, -50925, 3013, 0, 0, 39, '3012'),
	(377, 1, 0, -50925, 3014, 0, 0, 39, '3013'),
	(377, 1, 0, -50925, 3015, 0, 0, 39, '3014'),
	(377, 1, 0, -50925, 3016, 0, 0, 39, '3015'),
	(377, 1, 0, -50925, 3017, 0, 0, 39, '3016'),
	(377, 1, 0, -50925, 3018, 0, 0, 39, '3017'),
	(377, 1, 0, -50925, 3019, 0, 0, 39, '3018'),
	(377, 1, 0, -50925, 3020, 0, 0, 39, '3019'),
	(377, 1, 0, -50925, 3021, 0, 0, 39, '3020'),
	(377, 1, 0, -50925, 3022, 0, 0, 39, '3021'),
	(377, 1, 0, -50925, 3023, 0, 0, 39, '3022'),
	(377, 1, 0, -50925, 3024, 0, 0, 39, '3023'),
	(377, 1, 0, -50925, 3025, 0, 0, 39, '3024'),
	(377, 1, 0, -50925, 3026, 0, 0, 39, '3025'),
	(377, 1, 0, -50925, 3027, 0, 0, 39, '3026'),
	(377, 1, 0, -50925, 3028, 0, 0, 39, '3027'),
	(377, 1, 0, -50925, 3029, 0, 0, 39, '3028'),
	(377, 1, 0, -50925, 3030, 0, 0, 39, '3029'),
	(377, 1, 0, -50925, 3031, 0, 0, 39, '3030'),
	(377, 1, 0, -50925, 3032, 0, 0, 39, '3031'),
	(377, 1, 0, -50925, 3033, 0, 0, 39, '3032'),
	(377, 1, 0, -50925, 3034, 0, 0, 39, '3033'),
	(377, 1, 0, -50925, 3035, 0, 0, 39, '3034'),
	(377, 1, 0, -50925, 3036, 0, 0, 39, '3035'),
	(377, 1, 0, -50925, 3037, 0, 0, 39, '3036'),
	(377, 1, 0, -50925, 3038, 0, 0, 39, '3037'),
	(377, 1, 0, -50925, 3039, 0, 0, 39, '3038'),
	(377, 1, 0, -50925, 3040, 0, 0, 39, '3039'),
	(377, 1, 0, -50925, 3041, 0, 0, 39, '3040'),
	(377, 1, 0, -50925, 3042, 0, 0, 39, '3041'),
	(377, 1, 0, -50925, 3043, 0, 0, 39, '3042'),
	(377, 1, 0, -50925, 3044, 0, 0, 39, '3043'),
	(377, 1, 0, -50925, 3045, 0, 0, 39, '3044'),
	(377, 1, 0, -50925, 3046, 0, 0, 39, '3045'),
	(377, 1, 0, -50925, 3047, 0, 0, 39, '3046'),
	(377, 1, 0, -50925, 3048, 0, 0, 39, '3047'),
	(377, 1, 0, -50925, 3049, 0, 0, 39, '3048'),
	(377, 1, 0, -50925, 3050, 0, 0, 39, '3049'),
	(377, 1, 0, -50925, 3051, 0, 0, 39, '3050'),
	(377, 1, 0, -50925, 3052, 0, 0, 39, '3051'),
	(377, 1, 0, -50925, 3053, 0, 0, 39, '3052'),
	(377, 1, 0, -50925, 3054, 0, 0, 39, '3053'),
	(377, 1, 0, -50925, 3055, 0, 0, 39, '3054'),
	(377, 1, 0, -50925, 3056, 0, 0, 39, '3055'),
	(377, 1, 0, -50925, 3057, 0, 0, 39, '3056'),
	(377, 1, 0, -50925, 3058, 0, 0, 39, '3057'),
	(377, 1, 0, -50925, 3059, 0, 0, 39, '3058'),
	(377, 1, 0, -50925, 3060, 0, 0, 39, '3059'),
	(377, 1, 0, -50925, 3061, 0, 0, 39, '3060'),
	(377, 1, 0, -50925, 3062, 0, 0, 39, '3061'),
	(377, 1, 0, -50925, 3063, 0, 0, 39, '3062'),
	(377, 1, 0, -50925, 3064, 0, 0, 39, '3063'),
	(377, 1, 0, -50925, 3065, 0, 0, 39, '3064'),
	(377, 1, 0, -50925, 3066, 0, 0, 39, '3065'),
	(377, 1, 0, -50925, 3067, 0, 0, 39, '3066'),
	(377, 1, 0, -50925, 3068, 0, 0, 39, '3067'),
	(377, 1, 0, -50925, 3069, 0, 0, 39, '3068'),
	(377, 1, 0, -50925, 3070, 0, 0, 39, '3069'),
	(377, 1, 0, -50925, 3071, 0, 0, 39, '3070'),
	(377, 1, 0, -50925, 3072, 0, 0, 39, '3071'),
	(377, 1, 0, -50925, 3073, 0, 0, 39, '3072'),
	(377, 1, 0, -50925, 3074, 0, 0, 39, '3073'),
	(377, 1, 0, -50925, 3075, 0, 0, 39, '3074'),
	(377, 1, 0, -50925, 3076, 0, 0, 39, '3075'),
	(377, 1, 0, -50925, 3077, 0, 0, 39, '3076'),
	(377, 1, 0, -50925, 3078, 0, 0, 39, '3077'),
	(377, 1, 0, -50925, 3079, 0, 0, 39, '3078'),
	(377, 1, 0, -50925, 3080, 0, 0, 39, '3079'),
	(377, 1, 0, -50925, 3081, 0, 0, 39, '3080'),
	(377, 1, 0, -50925, 3082, 0, 0, 39, '3081'),
	(377, 1, 0, -50925, 3083, 0, 0, 39, '3082'),
	(377, 1, 0, -50925, 3084, 0, 0, 39, '3083'),
	(377, 1, 0, -50925, 3085, 0, 0, 39, '3084'),
	(377, 1, 0, -50925, 3086, 0, 0, 39, '3085'),
	(377, 1, 0, -50925, 3087, 0, 0, 39, '3086'),
	(377, 1, 0, -50925, 3088, 0, 0, 39, '3087'),
	(377, 1, 0, -50925, 3089, 0, 0, 39, '3088'),
	(377, 1, 0, -50925, 3090, 0, 0, 39, '3089'),
	(377, 1, 0, -50925, 3091, 0, 0, 39, '3090'),
	(377, 1, 0, -50925, 3092, 0, 0, 39, '3091'),
	(377, 1, 0, -50925, 3093, 0, 0, 39, '3092'),
	(377, 1, 0, -50925, 3094, 0, 0, 39, '3093'),
	(377, 1, 0, -50925, 3095, 0, 0, 39, '3094'),
	(377, 1, 0, -50925, 3096, 0, 0, 39, '3095'),
	(377, 1, 0, -50925, 3097, 0, 0, 39, '3096'),
	(377, 1, 0, -50925, 3098, 0, 0, 39, '3097'),
	(377, 1, 0, -50925, 3099, 0, 0, 39, '3098'),
	(377, 1, 0, -50925, 3100, 0, 0, 39, '3099'),
	(377, 1, 0, -50925, 3101, 0, 0, 39, '3100'),
	(377, 1, 0, -50925, 3102, 0, 0, 39, '3101'),
	(377, 1, 0, -50925, 3103, 0, 0, 39, '3102'),
	(377, 1, 0, -50925, 3104, 0, 0, 39, '3103'),
	(377, 1, 0, -50925, 3105, 0, 0, 39, '3104'),
	(377, 1, 0, -50925, 3106, 0, 0, 39, '3105'),
	(377, 1, 0, -50925, 3107, 0, 0, 39, '3106'),
	(377, 1, 0, -50925, 3108, 0, 0, 39, '3107'),
	(377, 1, 0, -50925, 3109, 0, 0, 39, '3108'),
	(377, 1, 0, -50925, 3110, 0, 0, 39, '3109'),
	(377, 1, 0, -50925, 3111, 0, 0, 39, '3110'),
	(377, 1, 0, -50925, 3112, 0, 0, 39, '3111'),
	(377, 1, 0, -50925, 3113, 0, 0, 39, '3112'),
	(377, 1, 0, -50925, 3114, 0, 0, 39, '3113'),
	(377, 1, 0, -50925, 3115, 0, 0, 39, '3114'),
	(377, 1, 0, -50925, 3116, 0, 0, 39, '3115'),
	(377, 1, 0, -50925, 3117, 0, 0, 39, '3116'),
	(377, 1, 0, -50925, 3118, 0, 0, 39, '3117'),
	(377, 1, 0, -50925, 3119, 0, 0, 39, '3118'),
	(377, 1, 0, -50925, 3120, 0, 0, 39, '3119'),
	(377, 1, 0, -50925, 3121, 0, 0, 39, '3120'),
	(377, 1, 0, -50925, 3122, 0, 0, 39, '3121'),
	(377, 1, 0, -50925, 3123, 0, 0, 39, '3122'),
	(377, 1, 0, -50925, 3124, 0, 0, 39, '3123'),
	(377, 1, 0, -50925, 3125, 0, 0, 39, '3124'),
	(377, 1, 0, -50925, 3126, 0, 0, 39, '3125'),
	(377, 1, 0, -50925, 3127, 0, 0, 39, '3126'),
	(377, 1, 0, -50925, 3128, 0, 0, 39, '3127'),
	(377, 1, 0, -50925, 3129, 0, 0, 39, '3128'),
	(377, 1, 0, -50925, 3130, 0, 0, 39, '3129'),
	(377, 1, 0, -50925, 3131, 0, 0, 39, '3130'),
	(377, 1, 0, -50925, 3132, 0, 0, 39, '3131'),
	(377, 1, 0, -50925, 3133, 0, 0, 39, '3132'),
	(377, 1, 0, -50925, 3134, 0, 0, 39, '3133'),
	(377, 1, 0, -50925, 3135, 0, 0, 39, '3134'),
	(377, 1, 0, -50925, 3136, 0, 0, 39, '3135'),
	(377, 1, 0, -50925, 3137, 0, 0, 39, '3136'),
	(377, 1, 0, -50925, 3138, 0, 0, 39, '3137'),
	(377, 1, 0, -50925, 3139, 0, 0, 39, '3138'),
	(377, 1, 0, -50925, 3140, 0, 0, 39, '3139'),
	(377, 1, 0, -50925, 3141, 0, 0, 39, '3140'),
	(377, 1, 0, -50925, 3142, 0, 0, 39, '3141'),
	(377, 1, 0, -50925, 3143, 0, 0, 39, '3142'),
	(377, 1, 0, -50925, 3144, 0, 0, 39, '3143'),
	(377, 1, 0, -50925, 3145, 0, 0, 39, '3144'),
	(377, 1, 0, -50925, 3146, 0, 0, 39, '3145'),
	(377, 1, 0, -50925, 3147, 0, 0, 39, '3146'),
	(377, 1, 0, -50925, 3148, 0, 0, 39, '3147'),
	(377, 1, 0, -50925, 3149, 0, 0, 39, '3148'),
	(377, 1, 0, -50925, 3150, 0, 0, 39, '3149'),
	(377, 1, 0, -50925, 3151, 0, 0, 39, '3150'),
	(377, 1, 0, -50925, 3152, 0, 0, 39, '3151'),
	(377, 1, 0, -50925, 3153, 0, 0, 39, '3152'),
	(377, 1, 0, -50925, 3154, 0, 0, 39, '3153'),
	(377, 1, 0, -50925, 3155, 0, 0, 39, '3154'),
	(377, 1, 0, -50925, 3156, 0, 0, 39, '3155'),
	(377, 1, 0, -50925, 3157, 0, 0, 39, '3156'),
	(377, 1, 0, -50925, 3158, 0, 0, 39, '3157'),
	(377, 1, 0, -50925, 3159, 0, 0, 39, '3158'),
	(377, 1, 0, -50925, 3160, 0, 0, 39, '3159'),
	(377, 1, 0, -50925, 3161, 0, 0, 39, '3160'),
	(377, 1, 0, -50925, 3162, 0, 0, 39, '3161'),
	(377, 1, 0, -50925, 3163, 0, 0, 39, '3162'),
	(377, 1, 0, -50925, 3164, 0, 0, 39, '3163'),
	(377, 1, 0, -50925, 3165, 0, 0, 39, '3164'),
	(377, 1, 0, -50925, 3166, 0, 0, 39, '3165'),
	(377, 1, 0, -50925, 3167, 0, 0, 39, '3166'),
	(377, 1, 0, -50925, 3168, 0, 0, 39, '3167'),
	(377, 1, 0, -50925, 3169, 0, 0, 39, '3168'),
	(377, 1, 0, -50925, 3170, 0, 0, 39, '3169'),
	(377, 1, 0, -50925, 3171, 0, 0, 39, '3170'),
	(377, 1, 0, -50925, 3172, 0, 0, 39, '3171'),
	(377, 1, 0, -50925, 3173, 0, 0, 39, '3172'),
	(377, 1, 0, -50925, 3174, 0, 0, 39, '3173'),
	(377, 1, 0, -50925, 3175, 0, 0, 39, '3174'),
	(377, 1, 0, -50925, 3176, 0, 0, 39, '3175'),
	(377, 1, 0, -50925, 3177, 0, 0, 39, '3176'),
	(377, 1, 0, -50925, 3178, 0, 0, 39, '3177'),
	(377, 1, 0, -50925, 3179, 0, 0, 39, '3178'),
	(377, 1, 0, -50925, 3180, 0, 0, 39, '3179'),
	(377, 1, 0, -50925, 3181, 0, 0, 39, '3180'),
	(377, 1, 0, -50925, 3182, 0, 0, 39, '3181'),
	(377, 1, 0, -50925, 3183, 0, 0, 39, '3182'),
	(377, 1, 0, -50925, 3184, 0, 0, 39, '3183'),
	(377, 1, 0, -50925, 3185, 0, 0, 39, '3184'),
	(377, 1, 0, -50925, 3186, 0, 0, 39, '3185'),
	(377, 1, 0, -50925, 3187, 0, 0, 39, '3186'),
	(377, 1, 0, -50925, 3188, 0, 0, 39, '3187'),
	(377, 1, 0, -50925, 3189, 0, 0, 39, '3188'),
	(377, 1, 0, -50925, 3190, 0, 0, 39, '3189'),
	(377, 1, 0, -50925, 3191, 0, 0, 39, '3190'),
	(377, 1, 0, -50925, 3192, 0, 0, 39, '3191'),
	(377, 1, 0, -50925, 3193, 0, 0, 39, '3192'),
	(377, 1, 0, -50925, 3194, 0, 0, 39, '3193'),
	(377, 1, 0, -50925, 3195, 0, 0, 39, '3194'),
	(377, 1, 0, -50925, 3196, 0, 0, 39, '3195'),
	(377, 1, 0, -50925, 3197, 0, 0, 39, '3196'),
	(377, 1, 0, -50925, 3198, 0, 0, 39, '3197'),
	(377, 1, 0, -50925, 3199, 0, 0, 39, '3198'),
	(377, 1, 0, -50925, 3200, 0, 0, 39, '3199'),
	(377, 1, 0, -50925, 3201, 0, 0, 39, '3200'),
	(377, 1, 0, -50925, 3202, 0, 0, 39, '3201'),
	(377, 1, 0, -50925, 3203, 0, 0, 39, '3202'),
	(377, 1, 0, -50925, 3204, 0, 0, 39, '3203'),
	(377, 1, 0, -50925, 3205, 0, 0, 39, '3204'),
	(377, 1, 0, -50925, 3206, 0, 0, 39, '3205'),
	(377, 1, 0, -50925, 3207, 0, 0, 39, '3206'),
	(377, 1, 0, -50925, 3208, 0, 0, 39, '3207'),
	(377, 1, 0, -50925, 3209, 0, 0, 39, '3208'),
	(377, 1, 0, -50925, 3210, 0, 0, 39, '3209'),
	(377, 1, 0, -50925, 3211, 0, 0, 39, '3210'),
	(377, 1, 0, -50925, 3212, 0, 0, 39, '3211'),
	(377, 1, 0, -50925, 3213, 0, 0, 39, '3212'),
	(377, 1, 0, -50925, 3214, 0, 0, 39, '3213'),
	(377, 1, 0, -50925, 3215, 0, 0, 39, '3214'),
	(377, 1, 0, -50925, 3216, 0, 0, 39, '3215'),
	(377, 1, 0, -50925, 3217, 0, 0, 39, '3216'),
	(377, 1, 0, -50925, 3218, 0, 0, 39, '3217'),
	(377, 1, 0, -50925, 3219, 0, 0, 39, '3218'),
	(377, 1, 0, -50925, 3220, 0, 0, 39, '3219'),
	(377, 1, 0, -50925, 3221, 0, 0, 39, '3220'),
	(377, 1, 0, -50925, 3222, 0, 0, 39, '3221'),
	(377, 1, 0, -50925, 3223, 0, 0, 39, '3222'),
	(377, 1, 0, -50925, 3224, 0, 0, 39, '3223'),
	(377, 1, 0, -50925, 3225, 0, 0, 39, '3224'),
	(377, 1, 0, -50925, 3226, 0, 0, 39, '3225'),
	(377, 1, 0, -50925, 3227, 0, 0, 39, '3226'),
	(377, 1, 0, -50925, 3228, 0, 0, 39, '3227'),
	(377, 1, 0, -50925, 3229, 0, 0, 39, '3228'),
	(377, 1, 0, -50925, 3230, 0, 0, 39, '3229'),
	(377, 1, 0, -50925, 3231, 0, 0, 39, '3230'),
	(377, 1, 0, -50925, 3232, 0, 0, 39, '3231'),
	(377, 1, 0, -50925, 3233, 0, 0, 39, '3232'),
	(377, 1, 0, -50925, 3234, 0, 0, 39, '3233'),
	(377, 1, 0, -50925, 3235, 0, 0, 39, '3234'),
	(377, 1, 0, -50925, 3236, 0, 0, 39, '3235'),
	(377, 1, 0, -50925, 3237, 0, 0, 39, '3236'),
	(377, 1, 0, -50925, 3238, 0, 0, 39, '3237'),
	(377, 1, 0, -50925, 3239, 0, 0, 39, '3238'),
	(377, 1, 0, -50925, 3240, 0, 0, 39, '3239'),
	(377, 1, 0, -50925, 3241, 0, 0, 39, '3240'),
	(377, 1, 0, -50925, 3242, 0, 0, 39, '3241'),
	(377, 1, 0, -50925, 3243, 0, 0, 39, '3242'),
	(377, 1, 0, -50925, 3244, 0, 0, 39, '3243'),
	(377, 1, 0, -50925, 3245, 0, 0, 39, '3244'),
	(377, 1, 0, -50925, 3246, 0, 0, 39, '3245'),
	(377, 1, 0, -50925, 3247, 0, 0, 39, '3246'),
	(377, 1, 0, -50925, 3248, 0, 0, 39, '3247'),
	(377, 1, 0, -50925, 3249, 0, 0, 39, '3248'),
	(377, 1, 0, -50925, 3250, 0, 0, 39, '3249'),
	(377, 1, 0, -50925, 3251, 0, 0, 39, '3250'),
	(377, 1, 0, -50925, 3252, 0, 0, 39, '3251'),
	(377, 1, 0, -50925, 3253, 0, 0, 39, '3252'),
	(377, 1, 0, -50925, 3254, 0, 0, 39, '3253'),
	(377, 1, 0, -50925, 3255, 0, 0, 39, '3254'),
	(377, 1, 0, -50925, 3256, 0, 0, 39, '3255'),
	(377, 1, 0, -50925, 3257, 0, 0, 39, '3256'),
	(377, 1, 0, -50925, 3258, 0, 0, 39, '3257'),
	(377, 1, 0, -50925, 3259, 0, 0, 39, '3258'),
	(377, 1, 0, -50925, 3260, 0, 0, 39, '3259'),
	(377, 1, 0, -50925, 3261, 0, 0, 39, '3260'),
	(377, 1, 0, -50925, 3262, 0, 0, 39, '3261'),
	(377, 1, 0, -50925, 3263, 0, 0, 39, '3262'),
	(377, 1, 0, -50925, 3264, 0, 0, 39, '3263'),
	(377, 1, 0, -50925, 3265, 0, 0, 39, '3264'),
	(377, 1, 0, -50925, 3266, 0, 0, 39, '3265'),
	(377, 1, 0, -50925, 3267, 0, 0, 39, '3266'),
	(377, 1, 0, -50925, 3268, 0, 0, 39, '3267'),
	(377, 1, 0, -50925, 3269, 0, 0, 39, '3268'),
	(377, 1, 0, -50925, 3270, 0, 0, 39, '3269'),
	(377, 1, 0, -50925, 3271, 0, 0, 39, '3270'),
	(377, 1, 0, -50925, 3272, 0, 0, 39, '3271'),
	(377, 1, 0, -50925, 3273, 0, 0, 39, '3272'),
	(377, 1, 0, -50925, 3274, 0, 0, 39, '3273'),
	(377, 1, 0, -50925, 3275, 0, 0, 39, '3274'),
	(377, 1, 0, -50925, 3276, 0, 0, 39, '3275'),
	(377, 1, 0, -50925, 3277, 0, 0, 39, '3276'),
	(377, 1, 0, -50925, 3278, 0, 0, 39, '3277'),
	(377, 1, 0, -50925, 3279, 0, 0, 39, '3278'),
	(377, 1, 0, -50925, 3280, 0, 0, 39, '3279'),
	(377, 1, 0, -50925, 3281, 0, 0, 39, '3280'),
	(377, 1, 0, -50925, 3282, 0, 0, 39, '3281'),
	(377, 1, 0, -50925, 3283, 0, 0, 39, '3282'),
	(377, 1, 0, -50925, 3284, 0, 0, 39, '3283'),
	(377, 1, 0, -50925, 3285, 0, 0, 39, '3284'),
	(377, 1, 0, -50925, 3286, 0, 0, 39, '3285'),
	(377, 1, 0, -50925, 3287, 0, 0, 39, '3286'),
	(377, 1, 0, -50925, 3288, 0, 0, 39, '3287'),
	(377, 1, 0, -50925, 3289, 0, 0, 39, '3288'),
	(377, 1, 0, -50925, 3290, 0, 0, 39, '3289'),
	(377, 1, 0, -50925, 3291, 0, 0, 39, '3290'),
	(377, 1, 0, -50925, 3292, 0, 0, 39, '3291'),
	(377, 1, 0, -50925, 3293, 0, 0, 39, '3292'),
	(377, 1, 0, -50925, 3294, 0, 0, 39, '3293'),
	(377, 1, 0, -50925, 3295, 0, 0, 39, '3294'),
	(377, 1, 0, -50925, 3296, 0, 0, 39, '3295'),
	(377, 1, 0, -50925, 3297, 0, 0, 39, '3296'),
	(377, 1, 0, -50925, 3298, 0, 0, 39, '3297'),
	(377, 1, 0, -50925, 3299, 0, 0, 39, '3298'),
	(377, 1, 0, -50925, 3300, 0, 0, 39, '3299'),
	(377, 1, 0, -50925, 3301, 0, 0, 39, '3300'),
	(377, 1, 0, -50925, 3302, 0, 0, 39, '3301'),
	(377, 1, 0, -50925, 3303, 0, 0, 39, '3302'),
	(377, 1, 0, -50925, 3304, 0, 0, 39, '3303'),
	(377, 1, 0, -50925, 3305, 0, 0, 39, '3304'),
	(377, 1, 0, -50925, 3306, 0, 0, 39, '3305'),
	(377, 1, 0, -50925, 3307, 0, 0, 39, '3306'),
	(377, 1, 0, -50925, 3308, 0, 0, 39, '3307'),
	(377, 1, 0, -50925, 3309, 0, 0, 39, '3308'),
	(377, 1, 0, -50925, 3310, 0, 0, 39, '3309'),
	(377, 1, 0, -50925, 3311, 0, 0, 39, '3310'),
	(377, 1, 0, -50925, 3312, 0, 0, 39, '3311'),
	(377, 1, 0, -50925, 3313, 0, 0, 39, '3312'),
	(377, 1, 0, -50925, 3314, 0, 0, 39, '3313'),
	(377, 1, 0, -50925, 3315, 0, 0, 39, '3314'),
	(377, 1, 0, -50925, 3316, 0, 0, 39, '3315'),
	(377, 1, 0, -50925, 3317, 0, 0, 39, '3316'),
	(377, 1, 0, -50925, 3318, 0, 0, 39, '3317'),
	(377, 1, 0, -50925, 3319, 0, 0, 39, '3318'),
	(377, 1, 0, -50925, 3320, 0, 0, 39, '3319'),
	(377, 1, 0, -50925, 3321, 0, 0, 39, '3320'),
	(377, 1, 0, -50925, 3322, 0, 0, 39, '3321'),
	(377, 1, 0, -50925, 3323, 0, 0, 39, '3322'),
	(377, 1, 0, -50925, 3324, 0, 0, 39, '3323'),
	(377, 1, 0, -50925, 3325, 0, 0, 39, '3324'),
	(377, 1, 0, -50925, 3326, 0, 0, 39, '3325'),
	(377, 1, 0, -50925, 3327, 0, 0, 39, '3326'),
	(377, 1, 0, -50925, 3328, 0, 0, 39, '3327'),
	(377, 1, 0, -50925, 3329, 0, 0, 39, '3328'),
	(377, 1, 0, -50925, 3330, 0, 0, 39, '3329'),
	(377, 1, 0, -50925, 3331, 0, 0, 39, '3330'),
	(377, 1, 0, -50925, 3332, 0, 0, 39, '3331'),
	(377, 1, 0, -50925, 3333, 0, 0, 39, '3332'),
	(377, 1, 0, -50925, 3334, 0, 0, 39, '3333'),
	(377, 1, 0, -50925, 3335, 0, 0, 39, '3334'),
	(377, 1, 0, -50925, 3336, 0, 0, 39, '3335'),
	(377, 1, 0, -50925, 3337, 0, 0, 39, '3336'),
	(377, 1, 0, -50925, 3338, 0, 0, 39, '3337'),
	(377, 1, 0, -50925, 3339, 0, 0, 39, '3338'),
	(377, 1, 0, -50925, 3340, 0, 0, 39, '3339'),
	(377, 1, 0, -50925, 3341, 0, 0, 39, '3340'),
	(377, 1, 0, -50925, 3342, 0, 0, 39, '3341'),
	(377, 1, 0, -50925, 3343, 0, 0, 39, '3342'),
	(377, 1, 0, -50925, 3344, 0, 0, 39, '3343'),
	(377, 1, 0, -50925, 3345, 0, 0, 39, '3344'),
	(377, 1, 0, -50925, 3346, 0, 0, 39, '3345'),
	(377, 1, 0, -50925, 3347, 0, 0, 39, '3346'),
	(377, 1, 0, -50925, 3348, 0, 0, 39, '3347'),
	(377, 1, 0, -50925, 3349, 0, 0, 39, '3348'),
	(377, 1, 0, -50925, 3350, 0, 0, 39, '3349'),
	(377, 1, 0, -50925, 3351, 0, 0, 39, '3350'),
	(377, 1, 0, -50925, 3352, 0, 0, 39, '3351'),
	(377, 1, 0, -50925, 3353, 0, 0, 39, '3352'),
	(377, 1, 0, -50925, 3354, 0, 0, 39, '3353'),
	(377, 1, 0, -50925, 3355, 0, 0, 39, '3354'),
	(377, 1, 0, -50925, 3356, 0, 0, 39, '3355'),
	(377, 1, 0, -50925, 3357, 0, 0, 39, '3356'),
	(377, 1, 0, -50925, 3358, 0, 0, 39, '3357'),
	(377, 1, 0, -50925, 3359, 0, 0, 39, '3358'),
	(377, 1, 0, -50925, 3360, 0, 0, 39, '3359'),
	(377, 1, 0, -50925, 3361, 0, 0, 39, '3360'),
	(377, 1, 0, -50925, 3362, 0, 0, 39, '3361'),
	(377, 1, 0, -50925, 3363, 0, 0, 39, '3362'),
	(377, 1, 0, -50925, 3364, 0, 0, 39, '3363'),
	(377, 1, 0, -50925, 3365, 0, 0, 39, '3364'),
	(377, 1, 0, -50925, 3366, 0, 0, 39, '3365'),
	(377, 1, 0, -50925, 3367, 0, 0, 39, '3366'),
	(377, 1, 0, -50925, 3368, 0, 0, 39, '3367'),
	(377, 1, 0, -50925, 3369, 0, 0, 39, '3368'),
	(377, 1, 0, -50925, 3370, 0, 0, 39, '3369'),
	(377, 1, 0, -50925, 3371, 0, 0, 39, '3370'),
	(377, 1, 0, -50925, 3372, 0, 0, 39, '3371'),
	(377, 1, 0, -50925, 3373, 0, 0, 39, '3372'),
	(377, 1, 0, -50925, 3374, 0, 0, 39, '3373'),
	(377, 1, 0, -50925, 3375, 0, 0, 39, '3374'),
	(377, 1, 0, -50925, 3376, 0, 0, 39, '3375'),
	(377, 1, 0, -50925, 3377, 0, 0, 39, '3376'),
	(377, 1, 0, -50925, 3378, 0, 0, 39, '3377'),
	(377, 1, 0, -50925, 3379, 0, 0, 39, '3378'),
	(377, 1, 0, -50925, 3380, 0, 0, 39, '3379'),
	(377, 1, 0, -50925, 3381, 0, 0, 39, '3380'),
	(377, 1, 0, -50925, 3382, 0, 0, 39, '3381'),
	(377, 1, 0, -50925, 3383, 0, 0, 39, '3382'),
	(377, 1, 0, -50925, 3384, 0, 0, 39, '3383'),
	(377, 1, 0, -50925, 3385, 0, 0, 39, '3384'),
	(377, 1, 0, -50925, 3386, 0, 0, 39, '3385'),
	(377, 1, 0, -50925, 3387, 0, 0, 39, '3386'),
	(377, 1, 0, -50925, 3388, 0, 0, 39, '3387'),
	(377, 1, 0, -50925, 3389, 0, 0, 39, '3388'),
	(377, 1, 0, -50925, 3390, 0, 0, 39, '3389'),
	(377, 1, 0, -50925, 3391, 0, 0, 39, '3390'),
	(377, 1, 0, -50925, 3392, 0, 0, 39, '3391'),
	(377, 1, 0, -50925, 3393, 0, 0, 39, '3392'),
	(377, 1, 0, -50925, 3394, 0, 0, 39, '3393'),
	(377, 1, 0, -50925, 3395, 0, 0, 39, '3394'),
	(377, 1, 0, -50925, 3396, 0, 0, 39, '3395'),
	(377, 1, 0, -50925, 3397, 0, 0, 39, '3396'),
	(377, 1, 0, -50925, 3398, 0, 0, 39, '3397'),
	(377, 1, 0, -50925, 3399, 0, 0, 39, '3398'),
	(377, 1, 0, -50925, 3400, 0, 0, 39, '3399'),
	(377, 1, 0, -50925, 3401, 0, 0, 39, '3400'),
	(377, 1, 0, -50925, 3402, 0, 0, 39, '3401'),
	(377, 1, 0, -50925, 3403, 0, 0, 39, '3402'),
	(377, 1, 0, -50925, 3404, 0, 0, 39, '3403'),
	(377, 1, 0, -50925, 3405, 0, 0, 39, '3404'),
	(377, 1, 0, -50925, 3406, 0, 0, 39, '3405'),
	(377, 1, 0, -50925, 3407, 0, 0, 39, '3406'),
	(377, 1, 0, -50925, 3408, 0, 0, 39, '3407'),
	(377, 1, 0, -50925, 3409, 0, 0, 39, '3408'),
	(377, 1, 0, -50925, 3410, 0, 0, 39, '3409'),
	(377, 1, 0, -50925, 3411, 0, 0, 39, '3410'),
	(377, 1, 0, -50925, 3412, 0, 0, 39, '3411'),
	(377, 1, 0, -50925, 3413, 0, 0, 39, '3412'),
	(377, 1, 0, -50925, 3414, 0, 0, 39, '3413'),
	(377, 1, 0, -50925, 3415, 0, 0, 39, '3414'),
	(377, 1, 0, -50925, 3416, 0, 0, 39, '3415'),
	(377, 1, 0, -50925, 3417, 0, 0, 39, '3416'),
	(377, 1, 0, -50925, 3418, 0, 0, 39, '3417'),
	(377, 1, 0, -50925, 3419, 0, 0, 39, '3418'),
	(377, 1, 0, -50925, 3420, 0, 0, 39, '3419'),
	(377, 1, 0, -50925, 3421, 0, 0, 39, '3420'),
	(377, 1, 0, -50925, 3422, 0, 0, 39, '3421'),
	(377, 1, 0, -50925, 3423, 0, 0, 39, '3422'),
	(377, 1, 0, -50925, 3424, 0, 0, 39, '3423'),
	(377, 1, 0, -50925, 3425, 0, 0, 39, '3424'),
	(377, 1, 0, -50925, 3426, 0, 0, 39, '3425'),
	(377, 1, 0, -50925, 3427, 0, 0, 39, '3426'),
	(377, 1, 0, -50925, 3428, 0, 0, 39, '3427'),
	(377, 1, 0, -50925, 3429, 0, 0, 39, '3428'),
	(377, 1, 0, -50925, 3430, 0, 0, 39, '3429'),
	(377, 1, 0, -50925, 3431, 0, 0, 39, '3430'),
	(377, 1, 0, -50925, 3432, 0, 0, 39, '3431'),
	(377, 1, 0, -50925, 3433, 0, 0, 39, '3432'),
	(377, 1, 0, -50925, 3434, 0, 0, 39, '3433'),
	(377, 1, 0, -50925, 3435, 0, 0, 39, '3434'),
	(377, 1, 0, -50925, 3436, 0, 0, 39, '3435'),
	(377, 1, 0, -50925, 3437, 0, 0, 39, '3436'),
	(377, 1, 0, -50925, 3438, 0, 0, 39, '3437'),
	(377, 1, 0, -50925, 3439, 0, 0, 39, '3438'),
	(377, 1, 0, -50925, 3440, 0, 0, 39, '3439'),
	(377, 1, 0, -50925, 3441, 0, 0, 39, '3440'),
	(377, 1, 0, -50925, 3442, 0, 0, 39, '3441'),
	(377, 1, 0, -50925, 3443, 0, 0, 39, '3442'),
	(377, 1, 0, -50925, 3444, 0, 0, 39, '3443'),
	(377, 1, 0, -50925, 3445, 0, 0, 39, '3444'),
	(377, 1, 0, -50925, 3446, 0, 0, 39, '3445'),
	(377, 1, 0, -50925, 3447, 0, 0, 39, '3446'),
	(377, 1, 0, -50925, 3448, 0, 0, 39, '3447'),
	(377, 1, 0, -50925, 3449, 0, 0, 39, '3448'),
	(377, 1, 0, -50925, 3450, 0, 0, 39, '3449'),
	(377, 1, 0, -50925, 3451, 0, 0, 39, '3450'),
	(377, 1, 0, -50925, 3452, 0, 0, 39, '3451'),
	(377, 1, 0, -50925, 3453, 0, 0, 39, '3452'),
	(377, 1, 0, -50925, 3454, 0, 0, 39, '3453'),
	(377, 1, 0, -50925, 3455, 0, 0, 39, '3454'),
	(377, 1, 0, -50925, 3456, 0, 0, 39, '3455'),
	(377, 1, 0, -50925, 3457, 0, 0, 39, '3456'),
	(377, 1, 0, -50925, 3458, 0, 0, 39, '3457'),
	(377, 1, 0, -50925, 3459, 0, 0, 39, '3458'),
	(377, 1, 0, -50925, 3460, 0, 0, 39, '3459'),
	(377, 1, 0, -50925, 3461, 0, 0, 39, '3460'),
	(377, 1, 0, -50925, 3462, 0, 0, 39, '3461'),
	(377, 1, 0, -50925, 3463, 0, 0, 39, '3462'),
	(377, 1, 0, -50925, 3464, 0, 0, 39, '3463'),
	(377, 1, 0, -50925, 3465, 0, 0, 39, '3464'),
	(377, 1, 0, -50925, 3466, 0, 0, 39, '3465'),
	(377, 1, 0, -50925, 3467, 0, 0, 39, '3466'),
	(377, 1, 0, -50925, 3468, 0, 0, 39, '3467'),
	(377, 1, 0, -50925, 3469, 0, 0, 39, '3468'),
	(377, 1, 0, -50925, 3470, 0, 0, 39, '3469'),
	(377, 1, 0, -50925, 3471, 0, 0, 39, '3470'),
	(377, 1, 0, -50925, 3472, 0, 0, 39, '3471'),
	(377, 1, 0, -50925, 3473, 0, 0, 39, '3472'),
	(377, 1, 0, -50925, 3474, 0, 0, 39, '3473'),
	(377, 1, 0, -50925, 3475, 0, 0, 39, '3474'),
	(377, 1, 0, -50925, 3476, 0, 0, 39, '3475'),
	(377, 1, 0, -50925, 3477, 0, 0, 39, '3476'),
	(377, 1, 0, -50925, 3478, 0, 0, 39, '3477'),
	(377, 1, 0, -50925, 3479, 0, 0, 39, '3478'),
	(377, 1, 0, -50925, 3480, 0, 0, 39, '3479'),
	(377, 1, 0, -50925, 3481, 0, 0, 39, '3480'),
	(377, 1, 0, -50925, 3482, 0, 0, 39, '3481'),
	(377, 1, 0, -50925, 3483, 0, 0, 39, '3482'),
	(377, 1, 0, -50925, 3484, 0, 0, 39, '3483'),
	(377, 1, 0, -50925, 3485, 0, 0, 39, '3484'),
	(377, 1, 0, -50925, 3486, 0, 0, 39, '3485'),
	(377, 1, 0, -50925, 3487, 0, 0, 39, '3486'),
	(377, 1, 0, -50925, 3488, 0, 0, 39, '3487'),
	(377, 1, 0, -50925, 3489, 0, 0, 39, '3488'),
	(377, 1, 0, -50925, 3490, 0, 0, 39, '3489'),
	(377, 1, 0, -50925, 3491, 0, 0, 39, '3490'),
	(377, 1, 0, -50925, 3492, 0, 0, 39, '3491'),
	(377, 1, 0, -50925, 3493, 0, 0, 39, '3492'),
	(377, 1, 0, -50925, 3494, 0, 0, 39, '3493'),
	(377, 1, 0, -50925, 3495, 0, 0, 39, '3494'),
	(377, 1, 0, -50925, 3496, 0, 0, 39, '3495'),
	(377, 1, 0, -50925, 3497, 0, 0, 39, '3496'),
	(377, 1, 0, -50925, 3498, 0, 0, 39, '3497'),
	(377, 1, 0, -50925, 3499, 0, 0, 39, '3498'),
	(377, 1, 0, -50925, 3500, 0, 0, 39, '3499'),
	(377, 1, 0, -50925, 3501, 0, 0, 39, '3500'),
	(377, 1, 0, -50925, 3502, 0, 0, 39, '3501'),
	(377, 1, 0, -50925, 3503, 0, 0, 39, '3502'),
	(377, 1, 0, -50925, 3504, 0, 0, 39, '3503'),
	(377, 1, 0, -50925, 3505, 0, 0, 39, '3504'),
	(377, 1, 0, -50925, 3506, 0, 0, 39, '3505'),
	(377, 1, 0, -50925, 3507, 0, 0, 39, '3506'),
	(377, 1, 0, -50925, 3508, 0, 0, 39, '3507'),
	(377, 1, 0, -50925, 3509, 0, 0, 39, '3508'),
	(377, 1, 0, -50925, 3510, 0, 0, 39, '3509'),
	(377, 1, 0, -50925, 3511, 0, 0, 39, '3510'),
	(377, 1, 0, -50925, 3512, 0, 0, 39, '3511'),
	(377, 1, 0, -50925, 3513, 0, 0, 39, '3512'),
	(377, 1, 0, -50925, 3514, 0, 0, 39, '3513'),
	(377, 1, 0, -50925, 3515, 0, 0, 39, '3514'),
	(377, 1, 0, -50925, 3516, 0, 0, 39, '3515'),
	(377, 1, 0, -50925, 3517, 0, 0, 39, '3516'),
	(377, 1, 0, -50925, 3518, 0, 0, 39, '3517'),
	(377, 1, 0, -50925, 3519, 0, 0, 39, '3518'),
	(377, 1, 0, -50925, 3520, 0, 0, 39, '3519'),
	(377, 1, 0, -50925, 3521, 0, 0, 39, '3520'),
	(377, 1, 0, -50925, 3522, 0, 0, 39, '3521'),
	(377, 1, 0, -50925, 3523, 0, 0, 39, '3522'),
	(377, 1, 0, -50925, 3524, 0, 0, 39, '3523'),
	(377, 1, 0, -50925, 3525, 0, 0, 39, '3524'),
	(377, 1, 0, -50925, 3526, 0, 0, 39, '3525'),
	(377, 1, 0, -50925, 3527, 0, 0, 39, '3526'),
	(377, 1, 0, -50925, 3528, 0, 0, 39, '3527'),
	(377, 1, 0, -50925, 3529, 0, 0, 39, '3528'),
	(377, 1, 0, -50925, 3530, 0, 0, 39, '3529'),
	(377, 1, 0, -50925, 3531, 0, 0, 39, '3530'),
	(377, 1, 0, -50925, 3532, 0, 0, 39, '3531'),
	(377, 1, 0, -50925, 3533, 0, 0, 39, '3532'),
	(377, 1, 0, -50925, 3534, 0, 0, 39, '3533'),
	(377, 1, 0, -50925, 3535, 0, 0, 39, '3534'),
	(377, 1, 0, -50925, 3536, 0, 0, 39, '3535'),
	(377, 1, 0, -50925, 3537, 0, 0, 39, '3536'),
	(377, 1, 0, -50925, 3538, 0, 0, 39, '3537'),
	(377, 1, 0, -50925, 3539, 0, 0, 39, '3538'),
	(377, 1, 0, -50925, 3540, 0, 0, 39, '3539'),
	(377, 1, 0, -50925, 3541, 0, 0, 39, '3540'),
	(377, 1, 0, -50925, 3542, 0, 0, 39, '3541'),
	(377, 1, 0, -50925, 3543, 0, 0, 39, '3542'),
	(377, 1, 0, -50925, 3544, 0, 0, 39, '3543'),
	(377, 1, 0, -50925, 3545, 0, 0, 39, '3544'),
	(377, 1, 0, -50925, 3546, 0, 0, 39, '3545'),
	(377, 1, 0, -50925, 3547, 0, 0, 39, '3546'),
	(377, 1, 0, -50925, 3548, 0, 0, 39, '3547'),
	(377, 1, 0, -50925, 3549, 0, 0, 39, '3548'),
	(377, 1, 0, -50925, 3550, 0, 0, 39, '3549'),
	(377, 1, 0, -50925, 3551, 0, 0, 39, '3550'),
	(377, 1, 0, -50925, 3552, 0, 0, 39, '3551'),
	(377, 1, 0, -50925, 3553, 0, 0, 39, '3552'),
	(377, 1, 0, -50925, 3554, 0, 0, 39, '3553'),
	(377, 1, 0, -50925, 3555, 0, 0, 39, '3554'),
	(377, 1, 0, -50925, 3556, 0, 0, 39, '3555'),
	(377, 1, 0, -50925, 3557, 0, 0, 39, '3556'),
	(377, 1, 0, -50925, 3558, 0, 0, 39, '3557'),
	(377, 1, 0, -50925, 3559, 0, 0, 39, '3558'),
	(377, 1, 0, -50925, 3560, 0, 0, 39, '3559'),
	(377, 1, 0, -50925, 3561, 0, 0, 39, '3560'),
	(377, 1, 0, -50925, 3562, 0, 0, 39, '3561'),
	(377, 1, 0, -50925, 3563, 0, 0, 39, '3562'),
	(377, 1, 0, -50925, 3564, 0, 0, 39, '3563'),
	(377, 1, 0, -50925, 3565, 0, 0, 39, '3564'),
	(377, 1, 0, -50925, 3566, 0, 0, 39, '3565'),
	(377, 1, 0, -50925, 3567, 0, 0, 39, '3566'),
	(377, 1, 0, -50925, 3568, 0, 0, 39, '3567'),
	(377, 1, 0, -50925, 3569, 0, 0, 39, '3568'),
	(377, 1, 0, -50925, 3570, 0, 0, 39, '3569'),
	(377, 1, 0, -50925, 3571, 0, 0, 39, '3570'),
	(377, 1, 0, -50925, 3572, 0, 0, 39, '3571'),
	(377, 1, 0, -50925, 3573, 0, 0, 39, '3572'),
	(377, 1, 0, -50925, 3574, 0, 0, 39, '3573'),
	(377, 1, 0, -50925, 3575, 0, 0, 39, '3574'),
	(377, 1, 0, -50925, 3576, 0, 0, 39, '3575'),
	(377, 1, 0, -50925, 3577, 0, 0, 39, '3576'),
	(377, 1, 0, -50925, 3578, 0, 0, 39, '3577'),
	(377, 1, 0, -50925, 3579, 0, 0, 39, '3578'),
	(377, 1, 0, -50925, 3580, 0, 0, 39, '3579'),
	(377, 1, 0, -50925, 3581, 0, 0, 39, '3580'),
	(377, 1, 0, -50925, 3582, 0, 0, 39, '3581'),
	(377, 1, 0, -50925, 3583, 0, 0, 39, '3582'),
	(377, 1, 0, -50925, 3584, 0, 0, 39, '3583'),
	(377, 1, 0, -50925, 3585, 0, 0, 39, '3584'),
	(377, 1, 0, -50925, 3586, 0, 0, 39, '3585'),
	(377, 1, 0, -50925, 3587, 0, 0, 39, '3586'),
	(377, 1, 0, -50925, 3588, 0, 0, 39, '3587'),
	(377, 1, 0, -50925, 3589, 0, 0, 39, '3588'),
	(377, 1, 0, -50925, 3590, 0, 0, 39, '3589'),
	(377, 1, 0, -50925, 3591, 0, 0, 39, '3590'),
	(377, 1, 0, -50925, 3592, 0, 0, 39, '3591'),
	(377, 1, 0, -50925, 3593, 0, 0, 39, '3592'),
	(377, 1, 0, -50925, 3594, 0, 0, 39, '3593'),
	(377, 1, 0, -50925, 3595, 0, 0, 39, '3594'),
	(377, 1, 0, -50925, 3596, 0, 0, 39, '3595'),
	(377, 1, 0, -50925, 3597, 0, 0, 39, '3596'),
	(377, 1, 0, -50925, 3598, 0, 0, 39, '3597'),
	(377, 1, 0, -50925, 3599, 0, 0, 39, '3598'),
	(377, 1, 0, -50925, 3600, 0, 0, 39, '3599'),
	(377, 1, 0, -50925, 3601, 0, 0, 39, '3600'),
	(377, 1, 0, -50925, 3602, 0, 0, 39, '3601'),
	(377, 1, 0, -50925, 3603, 0, 0, 39, '3602'),
	(377, 1, 0, -50925, 3604, 0, 0, 39, '3603'),
	(377, 1, 0, -50925, 3605, 0, 0, 39, '3604'),
	(377, 1, 0, -50925, 3606, 0, 0, 39, '3605'),
	(377, 1, 0, -50925, 3607, 0, 0, 39, '3606'),
	(377, 1, 0, -50925, 3608, 0, 0, 39, '3607'),
	(377, 1, 0, -50925, 3609, 0, 0, 39, '3608'),
	(377, 1, 0, -50925, 3610, 0, 0, 39, '3609'),
	(377, 1, 0, -50925, 3611, 0, 0, 39, '3610'),
	(377, 1, 0, -50925, 3612, 0, 0, 39, '3611'),
	(377, 1, 0, -50925, 3613, 0, 0, 39, '3612'),
	(377, 1, 0, -50925, 3614, 0, 0, 39, '3613'),
	(377, 1, 0, -50925, 3615, 0, 0, 39, '3614'),
	(377, 1, 0, -50925, 3616, 0, 0, 39, '3615'),
	(377, 1, 0, -50925, 3617, 0, 0, 39, '3616'),
	(377, 1, 0, -50925, 3618, 0, 0, 39, '3617'),
	(377, 1, 0, -50925, 3619, 0, 0, 39, '3618'),
	(377, 1, 0, -50925, 3620, 0, 0, 39, '3619'),
	(377, 1, 0, -50925, 3621, 0, 0, 39, '3620'),
	(377, 1, 0, -50925, 3622, 0, 0, 39, '3621'),
	(377, 1, 0, -50925, 3623, 0, 0, 39, '3622'),
	(377, 1, 0, -50925, 3624, 0, 0, 39, '3623'),
	(377, 1, 0, -50925, 3625, 0, 0, 39, '3624'),
	(377, 1, 0, -50925, 3626, 0, 0, 39, '3625'),
	(377, 1, 0, -50925, 3627, 0, 0, 39, '3626'),
	(377, 1, 0, -50925, 3628, 0, 0, 39, '3627'),
	(377, 1, 0, -50925, 3629, 0, 0, 39, '3628'),
	(377, 1, 0, -50925, 3630, 0, 0, 39, '3629'),
	(377, 1, 0, -50925, 3631, 0, 0, 39, '3630'),
	(377, 1, 0, -50925, 3632, 0, 0, 39, '3631'),
	(377, 1, 0, -50925, 3633, 0, 0, 39, '3632'),
	(377, 1, 0, -50925, 3634, 0, 0, 39, '3633'),
	(377, 1, 0, -50925, 3635, 0, 0, 39, '3634'),
	(377, 1, 0, -50925, 3636, 0, 0, 39, '3635'),
	(377, 1, 0, -50925, 3637, 0, 0, 39, '3636'),
	(377, 1, 0, -50925, 3638, 0, 0, 39, '3637'),
	(377, 1, 0, -50925, 3639, 0, 0, 39, '3638'),
	(377, 1, 0, -50925, 3640, 0, 0, 39, '3639'),
	(377, 1, 0, -50925, 3641, 0, 0, 39, '3640'),
	(377, 1, 0, -50925, 3642, 0, 0, 39, '3641'),
	(377, 1, 0, -50925, 3643, 0, 0, 39, '3642'),
	(377, 1, 0, -50925, 3644, 0, 0, 39, '3643'),
	(377, 1, 0, -50925, 3645, 0, 0, 39, '3644'),
	(377, 1, 0, -50925, 3646, 0, 0, 39, '3645'),
	(377, 1, 0, -50925, 3647, 0, 0, 39, '3646'),
	(377, 1, 0, -50925, 3648, 0, 0, 39, '3647'),
	(377, 1, 0, -50925, 3649, 0, 0, 39, '3648'),
	(377, 1, 0, -50925, 3650, 0, 0, 39, '3649'),
	(377, 1, 0, -50925, 3651, 0, 0, 39, '3650'),
	(377, 1, 0, -50925, 3652, 0, 0, 39, '3651'),
	(377, 1, 0, -50925, 3653, 0, 0, 39, '3652'),
	(377, 1, 0, -50925, 3654, 0, 0, 39, '3653'),
	(377, 1, 0, -50925, 3655, 0, 0, 39, '3654'),
	(377, 1, 0, -50925, 3656, 0, 0, 39, '3655'),
	(377, 1, 0, -50925, 3657, 0, 0, 39, '3656'),
	(377, 1, 0, -50925, 3658, 0, 0, 39, '3657'),
	(377, 1, 0, -50925, 3659, 0, 0, 39, '3658'),
	(377, 1, 0, -50925, 3660, 0, 0, 39, '3659'),
	(377, 1, 0, -50925, 3661, 0, 0, 39, '3660'),
	(377, 1, 0, -50925, 3662, 0, 0, 39, '3661'),
	(377, 1, 0, -50925, 3663, 0, 0, 39, '3662'),
	(377, 1, 0, -50925, 3664, 0, 0, 39, '3663'),
	(377, 1, 0, -50925, 3665, 0, 0, 39, '3664'),
	(377, 1, 0, -50925, 3666, 0, 0, 39, '3665'),
	(377, 1, 0, -50925, 3667, 0, 0, 39, '3666'),
	(377, 1, 0, -50925, 3668, 0, 0, 39, '3667'),
	(377, 1, 0, -50925, 3669, 0, 0, 39, '3668'),
	(377, 1, 0, -50925, 3670, 0, 0, 39, '3669'),
	(377, 1, 0, -50925, 3671, 0, 0, 39, '3670'),
	(377, 1, 0, -50925, 3672, 0, 0, 39, '3671'),
	(377, 1, 0, -50925, 3673, 0, 0, 39, '3672'),
	(377, 1, 0, -50925, 3674, 0, 0, 39, '3673'),
	(377, 1, 0, -50925, 3675, 0, 0, 39, '3674'),
	(377, 1, 0, -50925, 3676, 0, 0, 39, '3675'),
	(377, 1, 0, -50925, 3677, 0, 0, 39, '3676'),
	(377, 1, 0, -50925, 3678, 0, 0, 39, '3677'),
	(377, 1, 0, -50925, 3679, 0, 0, 39, '3678'),
	(377, 1, 0, -50925, 3680, 0, 0, 39, '3679'),
	(377, 1, 0, -50925, 3681, 0, 0, 39, '3680'),
	(377, 1, 0, -50925, 3682, 0, 0, 39, '3681'),
	(377, 1, 0, -50925, 3683, 0, 0, 39, '3682'),
	(377, 1, 0, -50925, 3684, 0, 0, 39, '3683'),
	(377, 1, 0, -50925, 3685, 0, 0, 39, '3684'),
	(377, 1, 0, -50925, 3686, 0, 0, 39, '3685'),
	(377, 1, 0, -50925, 3687, 0, 0, 39, '3686'),
	(377, 1, 0, -50925, 3688, 0, 0, 39, '3687'),
	(377, 1, 0, -50925, 3689, 0, 0, 39, '3688'),
	(377, 1, 0, -50925, 3690, 0, 0, 39, '3689'),
	(377, 1, 0, -50925, 3691, 0, 0, 39, '3690'),
	(377, 1, 0, -50925, 3692, 0, 0, 39, '3691'),
	(377, 1, 0, -50925, 3693, 0, 0, 39, '3692'),
	(377, 1, 0, -50925, 3694, 0, 0, 39, '3693'),
	(377, 1, 0, -50925, 3695, 0, 0, 39, '3694'),
	(377, 1, 0, -50925, 3696, 0, 0, 39, '3695'),
	(377, 1, 0, -50925, 3697, 0, 0, 39, '3696'),
	(377, 1, 0, -50925, 3698, 0, 0, 39, '3697'),
	(377, 1, 0, -50925, 3699, 0, 0, 39, '3698'),
	(377, 1, 0, -50925, 3700, 0, 0, 39, '3699'),
	(377, 1, 0, -50925, 3701, 0, 0, 39, '3700'),
	(377, 1, 0, -50925, 3702, 0, 0, 39, '3701'),
	(377, 1, 0, -50925, 3703, 0, 0, 39, '3702'),
	(377, 1, 0, -50925, 3704, 0, 0, 39, '3703'),
	(377, 1, 0, -50925, 3705, 0, 0, 39, '3704'),
	(377, 1, 0, -50925, 3706, 0, 0, 39, '3705'),
	(377, 1, 0, -50925, 3707, 0, 0, 39, '3706'),
	(377, 1, 0, -50925, 3708, 0, 0, 39, '3707'),
	(377, 1, 0, -50925, 3709, 0, 0, 39, '3708'),
	(377, 1, 0, -50925, 3710, 0, 0, 39, '3709'),
	(377, 1, 0, -50925, 3711, 0, 0, 39, '3710'),
	(377, 1, 0, -50925, 3712, 0, 0, 39, '3711'),
	(377, 1, 0, -50925, 3713, 0, 0, 39, '3712'),
	(377, 1, 0, -50925, 3714, 0, 0, 39, '3713'),
	(377, 1, 0, -50925, 3715, 0, 0, 39, '3714'),
	(377, 1, 0, -50925, 3716, 0, 0, 39, '3715'),
	(377, 1, 0, -50925, 3717, 0, 0, 39, '3716'),
	(377, 1, 0, -50925, 3718, 0, 0, 39, '3717'),
	(377, 1, 0, -50925, 3719, 0, 0, 39, '3718'),
	(377, 1, 0, -50925, 3720, 0, 0, 39, '3719'),
	(377, 1, 0, -50925, 3721, 0, 0, 39, '3720'),
	(377, 1, 0, -50925, 3722, 0, 0, 39, '3721'),
	(377, 1, 0, -50925, 3723, 0, 0, 39, '3722'),
	(377, 1, 0, -50925, 3724, 0, 0, 39, '3723'),
	(377, 1, 0, -50925, 3725, 0, 0, 39, '3724'),
	(377, 1, 0, -50925, 3726, 0, 0, 39, '3725'),
	(377, 1, 0, -50925, 3727, 0, 0, 39, '3726'),
	(377, 1, 0, -50925, 3728, 0, 0, 39, '3727'),
	(377, 1, 0, -50925, 3729, 0, 0, 39, '3728'),
	(377, 1, 0, -50925, 3730, 0, 0, 39, '3729'),
	(377, 1, 0, -50925, 3731, 0, 0, 39, '3730'),
	(377, 1, 0, -50925, 3732, 0, 0, 39, '3731'),
	(377, 1, 0, -50925, 3733, 0, 0, 39, '3732'),
	(377, 1, 0, -50925, 3734, 0, 0, 39, '3733'),
	(377, 1, 0, -50925, 3735, 0, 0, 39, '3734'),
	(377, 1, 0, -50925, 3736, 0, 0, 39, '3735'),
	(377, 1, 0, -50925, 3737, 0, 0, 39, '3736'),
	(377, 1, 0, -50925, 3738, 0, 0, 39, '3737'),
	(377, 1, 0, -50925, 3739, 0, 0, 39, '3738'),
	(377, 1, 0, -50925, 3740, 0, 0, 39, '3739'),
	(377, 1, 0, -50925, 3741, 0, 0, 39, '3740'),
	(377, 1, 0, -50925, 3742, 0, 0, 39, '3741'),
	(377, 1, 0, -50925, 3743, 0, 0, 39, '3742'),
	(377, 1, 0, -50925, 3744, 0, 0, 39, '3743'),
	(377, 1, 0, -50925, 3745, 0, 0, 39, '3744'),
	(377, 1, 0, -50925, 3746, 0, 0, 39, '3745'),
	(377, 1, 0, -50925, 3747, 0, 0, 39, '3746'),
	(377, 1, 0, -50925, 3748, 0, 0, 39, '3747'),
	(377, 1, 0, -50925, 3749, 0, 0, 39, '3748'),
	(377, 1, 0, -50925, 3750, 0, 0, 39, '3749'),
	(377, 1, 0, -50925, 3751, 0, 0, 39, '3750'),
	(377, 1, 0, -50925, 3752, 0, 0, 39, '3751'),
	(377, 1, 0, -50925, 3753, 0, 0, 39, '3752'),
	(377, 1, 0, -50925, 3754, 0, 0, 39, '3753'),
	(377, 1, 0, -50925, 3755, 0, 0, 39, '3754'),
	(377, 1, 0, -50925, 3756, 0, 0, 39, '3755'),
	(377, 1, 0, -50925, 3757, 0, 0, 39, '3756'),
	(377, 1, 0, -50925, 3758, 0, 0, 39, '3757'),
	(377, 1, 0, -50925, 3759, 0, 0, 39, '3758'),
	(377, 1, 0, -50925, 3760, 0, 0, 39, '3759'),
	(377, 1, 0, -50925, 3761, 0, 0, 39, '3760'),
	(377, 1, 0, -50925, 3762, 0, 0, 39, '3761'),
	(377, 1, 0, -50925, 3763, 0, 0, 39, '3762'),
	(377, 1, 0, -50925, 3764, 0, 0, 39, '3763'),
	(377, 1, 0, -50925, 3765, 0, 0, 39, '3764'),
	(377, 1, 0, -50925, 3766, 0, 0, 39, '3765'),
	(377, 1, 0, -50925, 3767, 0, 0, 39, '3766'),
	(377, 1, 0, -50925, 3768, 0, 0, 39, '3767'),
	(377, 1, 0, -50925, 3769, 0, 0, 39, '3768'),
	(377, 1, 0, -50925, 3770, 0, 0, 39, '3769'),
	(377, 1, 0, -50925, 3771, 0, 0, 39, '3770'),
	(377, 1, 0, -50925, 3772, 0, 0, 39, '3771'),
	(377, 1, 0, -50925, 3773, 0, 0, 39, '3772'),
	(377, 1, 0, -50925, 3774, 0, 0, 39, '3773'),
	(377, 1, 0, -50925, 3775, 0, 0, 39, '3774'),
	(377, 1, 0, -50925, 3776, 0, 0, 39, '3775'),
	(377, 1, 0, -50925, 3777, 0, 0, 39, '3776'),
	(377, 1, 0, -50925, 3778, 0, 0, 39, '3777'),
	(377, 1, 0, -50925, 3779, 0, 0, 39, '3778'),
	(377, 1, 0, -50925, 3780, 0, 0, 39, '3779'),
	(377, 1, 0, -50925, 3781, 0, 0, 39, '3780'),
	(377, 1, 0, -50925, 3782, 0, 0, 39, '3781'),
	(377, 1, 0, -50925, 3783, 0, 0, 39, '3782'),
	(377, 1, 0, -50925, 3784, 0, 0, 39, '3783'),
	(377, 1, 0, -50925, 3785, 0, 0, 39, '3784'),
	(377, 1, 0, -50925, 3786, 0, 0, 39, '3785'),
	(377, 1, 0, -50925, 3787, 0, 0, 39, '3786'),
	(377, 1, 0, -50925, 3788, 0, 0, 39, '3787'),
	(377, 1, 0, -50925, 3789, 0, 0, 39, '3788'),
	(377, 1, 0, -50925, 3790, 0, 0, 39, '3789'),
	(377, 1, 0, -50925, 3791, 0, 0, 39, '3790'),
	(377, 1, 0, -50925, 3792, 0, 0, 39, '3791'),
	(377, 1, 0, -50925, 3793, 0, 0, 39, '3792'),
	(377, 1, 0, -50925, 3794, 0, 0, 39, '3793'),
	(377, 1, 0, -50925, 3795, 0, 0, 39, '3794'),
	(377, 1, 0, -50925, 3796, 0, 0, 39, '3795'),
	(377, 1, 0, -50925, 3797, 0, 0, 39, '3796'),
	(377, 1, 0, -50925, 3798, 0, 0, 39, '3797'),
	(377, 1, 0, -50925, 3799, 0, 0, 39, '3798'),
	(377, 1, 0, -50925, 3800, 0, 0, 39, '3799'),
	(377, 1, 0, -50925, 3801, 0, 0, 39, '3800'),
	(377, 1, 0, -50925, 3802, 0, 0, 39, '3801'),
	(377, 1, 0, -50925, 3803, 0, 0, 39, '3802'),
	(377, 1, 0, -50925, 3804, 0, 0, 39, '3803'),
	(377, 1, 0, -50925, 3805, 0, 0, 39, '3804'),
	(377, 1, 0, -50925, 3806, 0, 0, 39, '3805'),
	(377, 1, 0, -50925, 3807, 0, 0, 39, '3806'),
	(377, 1, 0, -50925, 3808, 0, 0, 39, '3807'),
	(377, 1, 0, -50925, 3809, 0, 0, 39, '3808'),
	(377, 1, 0, -50925, 3810, 0, 0, 39, '3809'),
	(377, 1, 0, -50925, 3811, 0, 0, 39, '3810'),
	(377, 1, 0, -50925, 3812, 0, 0, 39, '3811'),
	(377, 1, 0, -50925, 3813, 0, 0, 39, '3812'),
	(377, 1, 0, -50925, 3814, 0, 0, 39, '3813'),
	(377, 1, 0, -50925, 3815, 0, 0, 39, '3814'),
	(377, 1, 0, -50925, 3816, 0, 0, 39, '3815'),
	(377, 1, 0, -50925, 3817, 0, 0, 39, '3816'),
	(377, 1, 0, -50925, 3818, 0, 0, 39, '3817'),
	(377, 1, 0, -50925, 3819, 0, 0, 39, '3818'),
	(377, 1, 0, -50925, 3820, 0, 0, 39, '3819'),
	(377, 1, 0, -50925, 3821, 0, 0, 39, '3820'),
	(377, 1, 0, -50925, 3822, 0, 0, 39, '3821'),
	(377, 1, 0, -50925, 3823, 0, 0, 39, '3822'),
	(377, 1, 0, -50925, 3824, 0, 0, 39, '3823'),
	(377, 1, 0, -50925, 3825, 0, 0, 39, '3824'),
	(377, 1, 0, -50925, 3826, 0, 0, 39, '3825'),
	(377, 1, 0, -50925, 3827, 0, 0, 39, '3826'),
	(377, 1, 0, -50925, 3828, 0, 0, 39, '3827'),
	(377, 1, 0, -50925, 3829, 0, 0, 39, '3828'),
	(377, 1, 0, -50925, 3830, 0, 0, 39, '3829'),
	(377, 1, 0, -50925, 3831, 0, 0, 39, '3830'),
	(377, 1, 0, -50925, 3832, 0, 0, 39, '3831'),
	(377, 1, 0, -50925, 3833, 0, 0, 39, '3832'),
	(377, 1, 0, -50925, 3834, 0, 0, 39, '3833'),
	(377, 1, 0, -50925, 3835, 0, 0, 39, '3834'),
	(377, 1, 0, -50925, 3836, 0, 0, 39, '3835'),
	(377, 1, 0, -50925, 3837, 0, 0, 39, '3836'),
	(377, 1, 0, -50925, 3838, 0, 0, 39, '3837'),
	(377, 1, 0, -50925, 3839, 0, 0, 39, '3838'),
	(377, 1, 0, -50925, 3840, 0, 0, 39, '3839'),
	(377, 1, 0, -50925, 3841, 0, 0, 39, '3840'),
	(377, 1, 0, -50925, 3842, 0, 0, 39, '3841'),
	(377, 1, 0, -50925, 3843, 0, 0, 39, '3842'),
	(377, 1, 0, -50925, 3844, 0, 0, 39, '3843'),
	(377, 1, 0, -50925, 3845, 0, 0, 39, '3844'),
	(377, 1, 0, -50925, 3846, 0, 0, 39, '3845'),
	(377, 1, 0, -50925, 3847, 0, 0, 39, '3846'),
	(377, 1, 0, -50925, 3848, 0, 0, 39, '3847'),
	(377, 1, 0, -50925, 3849, 0, 0, 39, '3848'),
	(377, 1, 0, -50925, 3850, 0, 0, 39, '3849'),
	(377, 1, 0, -50925, 3851, 0, 0, 39, '3850'),
	(377, 1, 0, -50925, 3852, 0, 0, 39, '3851'),
	(377, 1, 0, -50925, 3853, 0, 0, 39, '3852'),
	(377, 1, 0, -50925, 3854, 0, 0, 39, '3853'),
	(377, 1, 0, -50925, 3855, 0, 0, 39, '3854'),
	(377, 1, 0, -50925, 3856, 0, 0, 39, '3855'),
	(377, 1, 0, -50925, 3857, 0, 0, 39, '3856'),
	(377, 1, 0, -50925, 3858, 0, 0, 39, '3857'),
	(377, 1, 0, -50925, 3859, 0, 0, 39, '3858'),
	(377, 1, 0, -50925, 3860, 0, 0, 39, '3859'),
	(377, 1, 0, -50925, 3861, 0, 0, 39, '3860'),
	(377, 1, 0, -50925, 3862, 0, 0, 39, '3861'),
	(377, 1, 0, -50925, 3863, 0, 0, 39, '3862'),
	(377, 1, 0, -50925, 3864, 0, 0, 39, '3863'),
	(377, 1, 0, -50925, 3865, 0, 0, 39, '3864'),
	(377, 1, 0, -50925, 3866, 0, 0, 39, '3865'),
	(377, 1, 0, -50925, 3867, 0, 0, 39, '3866'),
	(377, 1, 0, -50925, 3868, 0, 0, 39, '3867'),
	(377, 1, 0, -50925, 3869, 0, 0, 39, '3868'),
	(377, 1, 0, -50925, 3870, 0, 0, 39, '3869'),
	(377, 1, 0, -50925, 3871, 0, 0, 39, '3870'),
	(377, 1, 0, -50925, 3872, 0, 0, 39, '3871'),
	(377, 1, 0, -50925, 3873, 0, 0, 39, '3872'),
	(377, 1, 0, -50925, 3874, 0, 0, 39, '3873'),
	(377, 1, 0, -50925, 3875, 0, 0, 39, '3874'),
	(377, 1, 0, -50925, 3876, 0, 0, 39, '3875'),
	(377, 1, 0, -50925, 3877, 0, 0, 39, '3876'),
	(377, 1, 0, -50925, 3878, 0, 0, 39, '3877'),
	(377, 1, 0, -50925, 3879, 0, 0, 39, '3878'),
	(377, 1, 0, -50925, 3880, 0, 0, 39, '3879'),
	(377, 1, 0, -50925, 3881, 0, 0, 39, '3880'),
	(377, 1, 0, -50925, 3882, 0, 0, 39, '3881'),
	(377, 1, 0, -50925, 3883, 0, 0, 39, '3882'),
	(377, 1, 0, -50925, 3884, 0, 0, 39, '3883'),
	(377, 1, 0, -50925, 3885, 0, 0, 39, '3884'),
	(377, 1, 0, -50925, 3886, 0, 0, 39, '3885'),
	(377, 1, 0, -50925, 3887, 0, 0, 39, '3886'),
	(377, 1, 0, -50925, 3888, 0, 0, 39, '3887'),
	(377, 1, 0, -50925, 3889, 0, 0, 39, '3888'),
	(377, 1, 0, -50925, 3890, 0, 0, 39, '3889'),
	(377, 1, 0, -50925, 3891, 0, 0, 39, '3890'),
	(377, 1, 0, -50925, 3892, 0, 0, 39, '3891'),
	(377, 1, 0, -50925, 3893, 0, 0, 39, '3892'),
	(377, 1, 0, -50925, 3894, 0, 0, 39, '3893'),
	(377, 1, 0, -50925, 3895, 0, 0, 39, '3894'),
	(377, 1, 0, -50925, 3896, 0, 0, 39, '3895'),
	(377, 1, 0, -50925, 3897, 0, 0, 39, '3896'),
	(377, 1, 0, -50925, 3898, 0, 0, 39, '3897'),
	(377, 1, 0, -50925, 3899, 0, 0, 39, '3898'),
	(377, 1, 0, -50925, 3900, 0, 0, 39, '3899'),
	(377, 1, 0, -50925, 3901, 0, 0, 39, '3900'),
	(377, 1, 0, -50925, 3902, 0, 0, 39, '3901'),
	(377, 1, 0, -50925, 3903, 0, 0, 39, '3902'),
	(377, 1, 0, -50925, 3904, 0, 0, 39, '3903'),
	(377, 1, 0, -50925, 3905, 0, 0, 39, '3904'),
	(377, 1, 0, -50925, 3906, 0, 0, 39, '3905'),
	(377, 1, 0, -50925, 3907, 0, 0, 39, '3906'),
	(377, 1, 0, -50925, 3908, 0, 0, 39, '3907'),
	(377, 1, 0, -50925, 3909, 0, 0, 39, '3908'),
	(377, 1, 0, -50925, 3910, 0, 0, 39, '3909'),
	(377, 1, 0, -50925, 3911, 0, 0, 39, '3910'),
	(377, 1, 0, -50925, 3912, 0, 0, 39, '3911'),
	(377, 1, 0, -50925, 3913, 0, 0, 39, '3912'),
	(377, 1, 0, -50925, 3914, 0, 0, 39, '3913'),
	(377, 1, 0, -50925, 3915, 0, 0, 39, '3914'),
	(377, 1, 0, -50925, 3916, 0, 0, 39, '3915'),
	(377, 1, 0, -50925, 3917, 0, 0, 39, '3916'),
	(377, 1, 0, -50925, 3918, 0, 0, 39, '3917'),
	(377, 1, 0, -50925, 3919, 0, 0, 39, '3918'),
	(377, 1, 0, -50925, 3920, 0, 0, 39, '3919'),
	(377, 1, 0, -50925, 3921, 0, 0, 39, '3920'),
	(377, 1, 0, -50925, 3922, 0, 0, 39, '3921'),
	(377, 1, 0, -50925, 3923, 0, 0, 39, '3922'),
	(377, 1, 0, -50925, 3924, 0, 0, 39, '3923'),
	(377, 1, 0, -50925, 3925, 0, 0, 39, '3924'),
	(377, 1, 0, -50925, 3926, 0, 0, 39, '3925'),
	(377, 1, 0, -50925, 3927, 0, 0, 39, '3926'),
	(377, 1, 0, -50925, 3928, 0, 0, 39, '3927'),
	(377, 1, 0, -50925, 3929, 0, 0, 39, '3928'),
	(377, 1, 0, -50925, 3930, 0, 0, 39, '3929'),
	(377, 1, 0, -50925, 3931, 0, 0, 39, '3930'),
	(377, 1, 0, -50925, 3932, 0, 0, 39, '3931'),
	(377, 1, 0, -50925, 3933, 0, 0, 39, '3932'),
	(377, 1, 0, -50925, 3934, 0, 0, 39, '3933'),
	(377, 1, 0, -50925, 3935, 0, 0, 39, '3934'),
	(377, 1, 0, -50925, 3936, 0, 0, 39, '3935'),
	(377, 1, 0, -50925, 3937, 0, 0, 39, '3936'),
	(377, 1, 0, -50925, 3938, 0, 0, 39, '3937'),
	(377, 1, 0, -50925, 3939, 0, 0, 39, '3938'),
	(377, 1, 0, -50925, 3940, 0, 0, 39, '3939'),
	(377, 1, 0, -50925, 3941, 0, 0, 39, '3940'),
	(377, 1, 0, -50925, 3942, 0, 0, 39, '3941'),
	(377, 1, 0, -50925, 3943, 0, 0, 39, '3942'),
	(377, 1, 0, -50925, 3944, 0, 0, 39, '3943'),
	(377, 1, 0, -50925, 3945, 0, 0, 39, '3944'),
	(377, 1, 0, -50925, 3946, 0, 0, 39, '3945'),
	(377, 1, 0, -50925, 3947, 0, 0, 39, '3946'),
	(377, 1, 0, -50925, 3948, 0, 0, 39, '3947'),
	(377, 1, 0, -50925, 3949, 0, 0, 39, '3948'),
	(377, 1, 0, -50925, 3950, 0, 0, 39, '3949'),
	(377, 1, 0, -50925, 3951, 0, 0, 39, '3950'),
	(377, 1, 0, -50925, 3952, 0, 0, 39, '3951'),
	(377, 1, 0, -50925, 3953, 0, 0, 39, '3952'),
	(377, 1, 0, -50925, 3954, 0, 0, 39, '3953'),
	(377, 1, 0, -50925, 3955, 0, 0, 39, '3954'),
	(377, 1, 0, -50925, 3956, 0, 0, 39, '3955'),
	(377, 1, 0, -50925, 3957, 0, 0, 39, '3956'),
	(377, 1, 0, -50925, 3958, 0, 0, 39, '3957'),
	(377, 1, 0, -50925, 3959, 0, 0, 39, '3958'),
	(377, 1, 0, -50925, 3960, 0, 0, 39, '3959'),
	(377, 1, 0, -50925, 3961, 0, 0, 39, '3960'),
	(377, 1, 0, -50925, 3962, 0, 0, 39, '3961'),
	(377, 1, 0, -50925, 3963, 0, 0, 39, '3962'),
	(377, 1, 0, -50925, 3964, 0, 0, 39, '3963'),
	(377, 1, 0, -50925, 3965, 0, 0, 39, '3964'),
	(377, 1, 0, -50925, 3966, 0, 0, 39, '3965'),
	(377, 1, 0, -50925, 3967, 0, 0, 39, '3966'),
	(377, 1, 0, -50925, 3968, 0, 0, 39, '3967'),
	(377, 1, 0, -50925, 3969, 0, 0, 39, '3968'),
	(377, 1, 0, -50925, 3970, 0, 0, 39, '3969'),
	(377, 1, 0, -50925, 3971, 0, 0, 39, '3970'),
	(377, 1, 0, -50925, 3972, 0, 0, 39, '3971'),
	(377, 1, 0, -50925, 3973, 0, 0, 39, '3972'),
	(377, 1, 0, -50925, 3974, 0, 0, 39, '3973'),
	(377, 1, 0, -50925, 3975, 0, 0, 39, '3974'),
	(377, 1, 0, -50925, 3976, 0, 0, 39, '3975'),
	(377, 1, 0, -50925, 3977, 0, 0, 39, '3976'),
	(377, 1, 0, -50925, 3978, 0, 0, 39, '3977'),
	(377, 1, 0, -50925, 3979, 0, 0, 39, '3978'),
	(377, 1, 0, -50925, 3980, 0, 0, 39, '3979'),
	(377, 1, 0, -50925, 3981, 0, 0, 39, '3980'),
	(377, 1, 0, -50925, 3982, 0, 0, 39, '3981'),
	(377, 1, 0, -50925, 3983, 0, 0, 39, '3982'),
	(377, 1, 0, -50925, 3984, 0, 0, 39, '3983'),
	(377, 1, 0, -50925, 3985, 0, 0, 39, '3984'),
	(377, 1, 0, -50925, 3986, 0, 0, 39, '3985'),
	(377, 1, 0, -50925, 3987, 0, 0, 39, '3986'),
	(377, 1, 0, -50925, 3988, 0, 0, 39, '3987'),
	(377, 1, 0, -50925, 3989, 0, 0, 39, '3988'),
	(377, 1, 0, -50925, 3990, 0, 0, 39, '3989'),
	(377, 1, 0, -50925, 3991, 0, 0, 39, '3990'),
	(377, 1, 0, -50925, 3992, 0, 0, 39, '3991'),
	(377, 1, 0, -50925, 3993, 0, 0, 39, '3992'),
	(377, 1, 0, -50925, 3994, 0, 0, 39, '3993'),
	(377, 1, 0, -50925, 3995, 0, 0, 39, '3994'),
	(377, 1, 0, -50925, 3996, 0, 0, 39, '3995'),
	(377, 1, 0, -50925, 3997, 0, 0, 39, '3996'),
	(377, 1, 0, -50925, 3998, 0, 0, 39, '3997'),
	(377, 1, 0, -50925, 3999, 0, 0, 39, '3998'),
	(377, 1, 0, -50925, 4000, 0, 0, 39, '3999'),
	(377, 1, 0, -50924, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50924, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50924, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50924, 4, 0, 0, 39, '3'),
	(377, 1, 0, -50924, 5, 0, 0, 39, '4'),
	(377, 1, 0, -50924, 6, 0, 0, 39, '5'),
	(377, 1, 0, -50924, 7, 0, 0, 39, '6'),
	(377, 1, 0, -50924, 8, 0, 0, 39, '7'),
	(377, 1, 0, -50924, 9, 0, 0, 39, '8'),
	(377, 1, 0, -50924, 10, 0, 0, 39, '9'),
	(377, 1, 0, -50924, 11, 0, 0, 39, '10'),
	(377, 1, 0, -50924, 12, 0, 0, 39, '11'),
	(377, 1, 0, -50924, 13, 0, 0, 39, '12'),
	(377, 1, 0, -50924, 14, 0, 0, 39, '13'),
	(377, 1, 0, -50924, 15, 0, 0, 39, '14'),
	(377, 1, 0, -50924, 16, 0, 0, 39, '15'),
	(377, 1, 0, -50924, 17, 0, 0, 39, '16'),
	(377, 1, 0, -50924, 18, 0, 0, 39, '17'),
	(377, 1, 0, -50924, 19, 0, 0, 39, '18'),
	(377, 1, 0, -50924, 20, 0, 0, 39, '19'),
	(377, 1, 0, -50924, 21, 0, 0, 39, '20'),
	(377, 1, 0, -50924, 22, 0, 0, 39, '21'),
	(377, 1, 0, -50924, 23, 0, 0, 39, '22'),
	(377, 1, 0, -50924, 24, 0, 0, 39, '23'),
	(377, 1, 0, -50924, 25, 0, 0, 39, '24'),
	(377, 1, 0, -50924, 26, 0, 0, 39, '25'),
	(377, 1, 0, -50924, 27, 0, 0, 39, '26'),
	(377, 1, 0, -50924, 28, 0, 0, 39, '27'),
	(377, 1, 0, -50924, 29, 0, 0, 39, '28'),
	(377, 1, 0, -50924, 30, 0, 0, 39, '29'),
	(377, 1, 0, -50924, 31, 0, 0, 39, '30'),
	(377, 1, 0, -50924, 32, 0, 0, 39, '31'),
	(377, 1, 0, -50924, 33, 0, 0, 39, '32'),
	(377, 1, 0, -50924, 34, 0, 0, 39, '33'),
	(377, 1, 0, -50924, 35, 0, 0, 39, '34'),
	(377, 1, 0, -50924, 36, 0, 0, 39, '35'),
	(377, 1, 0, -50924, 37, 0, 0, 39, '36'),
	(377, 1, 0, -50924, 38, 0, 0, 39, '37'),
	(377, 1, 0, -50924, 39, 0, 0, 39, '38'),
	(377, 1, 0, -50924, 40, 0, 0, 39, '39'),
	(377, 1, 0, -50924, 41, 0, 0, 39, '40'),
	(377, 1, 0, -50924, 42, 0, 0, 39, '41'),
	(377, 1, 0, -50924, 43, 0, 0, 39, '42'),
	(377, 1, 0, -50924, 44, 0, 0, 39, '43'),
	(377, 1, 0, -50924, 45, 0, 0, 39, '44'),
	(377, 1, 0, -50924, 46, 0, 0, 39, '45'),
	(377, 1, 0, -50924, 47, 0, 0, 39, '46'),
	(377, 1, 0, -50924, 48, 0, 0, 39, '47'),
	(377, 1, 0, -50924, 49, 0, 0, 39, '48'),
	(377, 1, 0, -50924, 50, 0, 0, 39, '49'),
	(377, 1, 0, -50924, 51, 0, 0, 39, '50'),
	(377, 1, 0, -50924, 52, 0, 0, 39, '51'),
	(377, 1, 0, -50924, 53, 0, 0, 39, '52'),
	(377, 1, 0, -50924, 54, 0, 0, 39, '53'),
	(377, 1, 0, -50924, 55, 0, 0, 39, '54'),
	(377, 1, 0, -50924, 56, 0, 0, 39, '55'),
	(377, 1, 0, -50924, 57, 0, 0, 39, '56'),
	(377, 1, 0, -50924, 58, 0, 0, 39, '57'),
	(377, 1, 0, -50924, 59, 0, 0, 39, '58'),
	(377, 1, 0, -50924, 60, 0, 0, 39, '59'),
	(377, 1, 0, -50924, 61, 0, 0, 39, '60'),
	(377, 1, 0, -50924, 62, 0, 0, 39, '61'),
	(377, 1, 0, -50924, 63, 0, 0, 39, '62'),
	(377, 1, 0, -50924, 64, 0, 0, 39, '63'),
	(377, 1, 0, -50924, 65, 0, 0, 39, '64'),
	(377, 1, 0, -50924, 66, 0, 0, 39, '65'),
	(377, 1, 0, -50924, 67, 0, 0, 39, '66'),
	(377, 1, 0, -50924, 68, 0, 0, 39, '67'),
	(377, 1, 0, -50924, 69, 0, 0, 39, '68'),
	(377, 1, 0, -50924, 70, 0, 0, 39, '69'),
	(377, 1, 0, -50924, 71, 0, 0, 39, '70'),
	(377, 1, 0, -50924, 72, 0, 0, 39, '71'),
	(377, 1, 0, -50924, 73, 0, 0, 39, '72'),
	(377, 1, 0, -50924, 74, 0, 0, 39, '73'),
	(377, 1, 0, -50924, 75, 0, 0, 39, '74'),
	(377, 1, 0, -50924, 76, 0, 0, 39, '75'),
	(377, 1, 0, -50924, 77, 0, 0, 39, '76'),
	(377, 1, 0, -50924, 78, 0, 0, 39, '77'),
	(377, 1, 0, -50924, 79, 0, 0, 39, '78'),
	(377, 1, 0, -50924, 80, 0, 0, 39, '79'),
	(377, 1, 0, -50924, 81, 0, 0, 39, '80'),
	(377, 1, 0, -50924, 82, 0, 0, 39, '81'),
	(377, 1, 0, -50924, 83, 0, 0, 39, '82'),
	(377, 1, 0, -50924, 84, 0, 0, 39, '83'),
	(377, 1, 0, -50924, 85, 0, 0, 39, '84'),
	(377, 1, 0, -50924, 86, 0, 0, 39, '85'),
	(377, 1, 0, -50924, 87, 0, 0, 39, '86'),
	(377, 1, 0, -50924, 88, 0, 0, 39, '87'),
	(377, 1, 0, -50924, 89, 0, 0, 39, '88'),
	(377, 1, 0, -50924, 90, 0, 0, 39, '89'),
	(377, 1, 0, -50924, 91, 0, 0, 39, '90'),
	(377, 1, 0, -50924, 92, 0, 0, 39, '91'),
	(377, 1, 0, -50924, 93, 0, 0, 39, '92'),
	(377, 1, 0, -50924, 94, 0, 0, 39, '93'),
	(377, 1, 0, -50924, 95, 0, 0, 39, '94'),
	(377, 1, 0, -50924, 96, 0, 0, 39, '95'),
	(377, 1, 0, -50924, 97, 0, 0, 39, '96'),
	(377, 1, 0, -50924, 98, 0, 0, 39, '97'),
	(377, 1, 0, -50924, 99, 0, 0, 39, '98'),
	(377, 1, 0, -50924, 100, 0, 0, 39, '99'),
	(377, 1, 0, -50924, 101, 0, 0, 39, '100'),
	(377, 1, 0, -50924, 102, 0, 0, 39, '101'),
	(377, 1, 0, -50924, 103, 0, 0, 39, '102'),
	(377, 1, 0, -50924, 104, 0, 0, 39, '103'),
	(377, 1, 0, -50924, 105, 0, 0, 39, '104'),
	(377, 1, 0, -50924, 106, 0, 0, 39, '105'),
	(377, 1, 0, -50924, 107, 0, 0, 39, '106'),
	(377, 1, 0, -50924, 108, 0, 0, 39, '107'),
	(377, 1, 0, -50924, 109, 0, 0, 39, '108'),
	(377, 1, 0, -50924, 110, 0, 0, 39, '109'),
	(377, 1, 0, -50924, 111, 0, 0, 39, '110'),
	(377, 1, 0, -50924, 112, 0, 0, 39, '111'),
	(377, 1, 0, -50924, 113, 0, 0, 39, '112'),
	(377, 1, 0, -50924, 114, 0, 0, 39, '113'),
	(377, 1, 0, -50924, 115, 0, 0, 39, '114'),
	(377, 1, 0, -50924, 116, 0, 0, 39, '115'),
	(377, 1, 0, -50924, 117, 0, 0, 39, '116'),
	(377, 1, 0, -50924, 118, 0, 0, 39, '117'),
	(377, 1, 0, -50924, 119, 0, 0, 39, '118'),
	(377, 1, 0, -50924, 120, 0, 0, 39, '119'),
	(377, 1, 0, -50924, 121, 0, 0, 39, '120'),
	(377, 1, 0, -50924, 122, 0, 0, 39, '121'),
	(377, 1, 0, -50924, 123, 0, 0, 39, '122'),
	(377, 1, 0, -50924, 124, 0, 0, 39, '123'),
	(377, 1, 0, -50924, 125, 0, 0, 39, '124'),
	(377, 1, 0, -50924, 126, 0, 0, 39, '125'),
	(377, 1, 0, -50924, 127, 0, 0, 39, '126'),
	(377, 1, 0, -50924, 128, 0, 0, 39, '127'),
	(377, 1, 0, -50924, 129, 0, 0, 39, '128'),
	(377, 1, 0, -50924, 130, 0, 0, 39, '129'),
	(377, 1, 0, -50924, 131, 0, 0, 39, '130'),
	(377, 1, 0, -50924, 132, 0, 0, 39, '131'),
	(377, 1, 0, -50924, 133, 0, 0, 39, '132'),
	(377, 1, 0, -50924, 134, 0, 0, 39, '133'),
	(377, 1, 0, -50924, 135, 0, 0, 39, '134'),
	(377, 1, 0, -50924, 136, 0, 0, 39, '135'),
	(377, 1, 0, -50924, 137, 0, 0, 39, '136'),
	(377, 1, 0, -50924, 138, 0, 0, 39, '137'),
	(377, 1, 0, -50924, 139, 0, 0, 39, '138'),
	(377, 1, 0, -50924, 140, 0, 0, 39, '139'),
	(377, 1, 0, -50924, 141, 0, 0, 39, '140'),
	(377, 1, 0, -50924, 142, 0, 0, 39, '141'),
	(377, 1, 0, -50924, 143, 0, 0, 39, '142'),
	(377, 1, 0, -50924, 144, 0, 0, 39, '143'),
	(377, 1, 0, -50924, 145, 0, 0, 39, '144'),
	(377, 1, 0, -50924, 146, 0, 0, 39, '145'),
	(377, 1, 0, -50924, 147, 0, 0, 39, '146'),
	(377, 1, 0, -50924, 148, 0, 0, 39, '147'),
	(377, 1, 0, -50924, 149, 0, 0, 39, '148'),
	(377, 1, 0, -50924, 150, 0, 0, 39, '149'),
	(377, 1, 0, -50924, 151, 0, 0, 39, '150'),
	(377, 1, 0, -50924, 152, 0, 0, 39, '151'),
	(377, 1, 0, -50924, 153, 0, 0, 39, '152'),
	(377, 1, 0, -50924, 154, 0, 0, 39, '153'),
	(377, 1, 0, -50924, 155, 0, 0, 39, '154'),
	(377, 1, 0, -50924, 156, 0, 0, 39, '155'),
	(377, 1, 0, -50924, 157, 0, 0, 39, '156'),
	(377, 1, 0, -50924, 158, 0, 0, 39, '157'),
	(377, 1, 0, -50924, 159, 0, 0, 39, '158'),
	(377, 1, 0, -50924, 160, 0, 0, 39, '159'),
	(377, 1, 0, -50924, 161, 0, 0, 39, '160'),
	(377, 1, 0, -50924, 162, 0, 0, 39, '161'),
	(377, 1, 0, -50924, 163, 0, 0, 39, '162'),
	(377, 1, 0, -50924, 164, 0, 0, 39, '163'),
	(377, 1, 0, -50924, 165, 0, 0, 39, '164'),
	(377, 1, 0, -50924, 166, 0, 0, 39, '165'),
	(377, 1, 0, -50924, 167, 0, 0, 39, '166'),
	(377, 1, 0, -50924, 168, 0, 0, 39, '167'),
	(377, 1, 0, -50924, 169, 0, 0, 39, '168'),
	(377, 1, 0, -50924, 170, 0, 0, 39, '169'),
	(377, 1, 0, -50924, 171, 0, 0, 39, '170'),
	(377, 1, 0, -50924, 172, 0, 0, 39, '171'),
	(377, 1, 0, -50924, 173, 0, 0, 39, '172'),
	(377, 1, 0, -50924, 174, 0, 0, 39, '173'),
	(377, 1, 0, -50924, 175, 0, 0, 39, '174'),
	(377, 1, 0, -50924, 176, 0, 0, 39, '175'),
	(377, 1, 0, -50924, 177, 0, 0, 39, '176'),
	(377, 1, 0, -50924, 178, 0, 0, 39, '177'),
	(377, 1, 0, -50924, 179, 0, 0, 39, '178'),
	(377, 1, 0, -50924, 180, 0, 0, 39, '179'),
	(377, 1, 0, -50924, 181, 0, 0, 39, '180'),
	(377, 1, 0, -50924, 182, 0, 0, 39, '181'),
	(377, 1, 0, -50924, 183, 0, 0, 39, '182'),
	(377, 1, 0, -50924, 184, 0, 0, 39, '183'),
	(377, 1, 0, -50924, 185, 0, 0, 39, '184'),
	(377, 1, 0, -50924, 186, 0, 0, 39, '185'),
	(377, 1, 0, -50924, 187, 0, 0, 39, '186'),
	(377, 1, 0, -50924, 188, 0, 0, 39, '187'),
	(377, 1, 0, -50924, 189, 0, 0, 39, '188'),
	(377, 1, 0, -50924, 190, 0, 0, 39, '189'),
	(377, 1, 0, -50924, 191, 0, 0, 39, '190'),
	(377, 1, 0, -50924, 192, 0, 0, 39, '191'),
	(377, 1, 0, -50924, 193, 0, 0, 39, '192'),
	(377, 1, 0, -50924, 194, 0, 0, 39, '193'),
	(377, 1, 0, -50924, 195, 0, 0, 39, '194'),
	(377, 1, 0, -50924, 196, 0, 0, 39, '195'),
	(377, 1, 0, -50924, 197, 0, 0, 39, '196'),
	(377, 1, 0, -50924, 198, 0, 0, 39, '197'),
	(377, 1, 0, -50924, 199, 0, 0, 39, '198'),
	(377, 1, 0, -50924, 200, 0, 0, 39, '199'),
	(377, 1, 0, -50924, 201, 0, 0, 39, '200'),
	(377, 1, 0, -50924, 202, 0, 0, 39, '201'),
	(377, 1, 0, -50924, 203, 0, 0, 39, '202'),
	(377, 1, 0, -50924, 204, 0, 0, 39, '203'),
	(377, 1, 0, -50924, 205, 0, 0, 39, '204'),
	(377, 1, 0, -50924, 206, 0, 0, 39, '205'),
	(377, 1, 0, -50924, 207, 0, 0, 39, '206'),
	(377, 1, 0, -50924, 208, 0, 0, 39, '207'),
	(377, 1, 0, -50924, 209, 0, 0, 39, '208'),
	(377, 1, 0, -50924, 210, 0, 0, 39, '209'),
	(377, 1, 0, -50924, 211, 0, 0, 39, '210'),
	(377, 1, 0, -50924, 212, 0, 0, 39, '211'),
	(377, 1, 0, -50924, 213, 0, 0, 39, '212'),
	(377, 1, 0, -50924, 214, 0, 0, 39, '213'),
	(377, 1, 0, -50924, 215, 0, 0, 39, '214'),
	(377, 1, 0, -50924, 216, 0, 0, 39, '215'),
	(377, 1, 0, -50924, 217, 0, 0, 39, '216'),
	(377, 1, 0, -50924, 218, 0, 0, 39, '217'),
	(377, 1, 0, -50924, 219, 0, 0, 39, '218'),
	(377, 1, 0, -50924, 220, 0, 0, 39, '219'),
	(377, 1, 0, -50924, 221, 0, 0, 39, '220'),
	(377, 1, 0, -50924, 222, 0, 0, 39, '221'),
	(377, 1, 0, -50924, 223, 0, 0, 39, '222'),
	(377, 1, 0, -50924, 224, 0, 0, 39, '223'),
	(377, 1, 0, -50924, 225, 0, 0, 39, '224'),
	(377, 1, 0, -50924, 226, 0, 0, 39, '225'),
	(377, 1, 0, -50924, 227, 0, 0, 39, '226'),
	(377, 1, 0, -50924, 228, 0, 0, 39, '227'),
	(377, 1, 0, -50924, 229, 0, 0, 39, '228'),
	(377, 1, 0, -50924, 230, 0, 0, 39, '229'),
	(377, 1, 0, -50924, 231, 0, 0, 39, '230'),
	(377, 1, 0, -50924, 232, 0, 0, 39, '231'),
	(377, 1, 0, -50924, 233, 0, 0, 39, '232'),
	(377, 1, 0, -50924, 234, 0, 0, 39, '233'),
	(377, 1, 0, -50924, 235, 0, 0, 39, '234'),
	(377, 1, 0, -50924, 236, 0, 0, 39, '235'),
	(377, 1, 0, -50924, 237, 0, 0, 39, '236'),
	(377, 1, 0, -50924, 238, 0, 0, 39, '237'),
	(377, 1, 0, -50924, 239, 0, 0, 39, '238'),
	(377, 1, 0, -50924, 240, 0, 0, 39, '239'),
	(377, 1, 0, -50924, 241, 0, 0, 39, '240'),
	(377, 1, 0, -50924, 242, 0, 0, 39, '241'),
	(377, 1, 0, -50924, 243, 0, 0, 39, '242'),
	(377, 1, 0, -50924, 244, 0, 0, 39, '243'),
	(377, 1, 0, -50924, 245, 0, 0, 39, '244'),
	(377, 1, 0, -50924, 246, 0, 0, 39, '245'),
	(377, 1, 0, -50924, 247, 0, 0, 39, '246'),
	(377, 1, 0, -50924, 248, 0, 0, 39, '247'),
	(377, 1, 0, -50924, 249, 0, 0, 39, '248'),
	(377, 1, 0, -50924, 250, 0, 0, 39, '249'),
	(377, 1, 0, -50924, 251, 0, 0, 39, '250'),
	(377, 1, 0, -50924, 252, 0, 0, 39, '251'),
	(377, 1, 0, -50924, 253, 0, 0, 39, '252'),
	(377, 1, 0, -50924, 254, 0, 0, 39, '253'),
	(377, 1, 0, -50924, 255, 0, 0, 39, '254'),
	(377, 1, 0, -50924, 256, 0, 0, 39, '255'),
	(377, 1, 0, -50924, 257, 0, 0, 39, '256'),
	(377, 1, 0, -50924, 258, 0, 0, 39, '257'),
	(377, 1, 0, -50924, 259, 0, 0, 39, '258'),
	(377, 1, 0, -50924, 260, 0, 0, 39, '259'),
	(377, 1, 0, -50924, 261, 0, 0, 39, '260'),
	(377, 1, 0, -50924, 262, 0, 0, 39, '261'),
	(377, 1, 0, -50924, 263, 0, 0, 39, '262'),
	(377, 1, 0, -50924, 264, 0, 0, 39, '263'),
	(377, 1, 0, -50924, 265, 0, 0, 39, '264'),
	(377, 1, 0, -50924, 266, 0, 0, 39, '265'),
	(377, 1, 0, -50924, 267, 0, 0, 39, '266'),
	(377, 1, 0, -50924, 268, 0, 0, 39, '267'),
	(377, 1, 0, -50924, 269, 0, 0, 39, '268'),
	(377, 1, 0, -50924, 270, 0, 0, 39, '269'),
	(377, 1, 0, -50924, 271, 0, 0, 39, '270'),
	(377, 1, 0, -50924, 272, 0, 0, 39, '271'),
	(377, 1, 0, -50924, 273, 0, 0, 39, '272'),
	(377, 1, 0, -50924, 274, 0, 0, 39, '273'),
	(377, 1, 0, -50924, 275, 0, 0, 39, '274'),
	(377, 1, 0, -50924, 276, 0, 0, 39, '275'),
	(377, 1, 0, -50924, 277, 0, 0, 39, '276'),
	(377, 1, 0, -50924, 278, 0, 0, 39, '277'),
	(377, 1, 0, -50924, 279, 0, 0, 39, '278'),
	(377, 1, 0, -50924, 280, 0, 0, 39, '279'),
	(377, 1, 0, -50924, 281, 0, 0, 39, '280'),
	(377, 1, 0, -50924, 282, 0, 0, 39, '281'),
	(377, 1, 0, -50924, 283, 0, 0, 39, '282'),
	(377, 1, 0, -50924, 284, 0, 0, 39, '283'),
	(377, 1, 0, -50924, 285, 0, 0, 39, '284'),
	(377, 1, 0, -50924, 286, 0, 0, 39, '285'),
	(377, 1, 0, -50924, 287, 0, 0, 39, '286'),
	(377, 1, 0, -50924, 288, 0, 0, 39, '287'),
	(377, 1, 0, -50924, 289, 0, 0, 39, '288'),
	(377, 1, 0, -50924, 290, 0, 0, 39, '289'),
	(377, 1, 0, -50924, 291, 0, 0, 39, '290'),
	(377, 1, 0, -50924, 292, 0, 0, 39, '291'),
	(377, 1, 0, -50924, 293, 0, 0, 39, '292'),
	(377, 1, 0, -50924, 294, 0, 0, 39, '293'),
	(377, 1, 0, -50924, 295, 0, 0, 39, '294'),
	(377, 1, 0, -50924, 296, 0, 0, 39, '295'),
	(377, 1, 0, -50924, 297, 0, 0, 39, '296'),
	(377, 1, 0, -50924, 298, 0, 0, 39, '297'),
	(377, 1, 0, -50924, 299, 0, 0, 39, '298'),
	(377, 1, 0, -50924, 300, 0, 0, 39, '299'),
	(377, 1, 0, -50924, 301, 0, 0, 39, '300'),
	(377, 1, 0, -50924, 302, 0, 0, 39, '301'),
	(377, 1, 0, -50924, 303, 0, 0, 39, '302'),
	(377, 1, 0, -50924, 304, 0, 0, 39, '303'),
	(377, 1, 0, -50924, 305, 0, 0, 39, '304'),
	(377, 1, 0, -50924, 306, 0, 0, 39, '305'),
	(377, 1, 0, -50924, 307, 0, 0, 39, '306'),
	(377, 1, 0, -50924, 308, 0, 0, 39, '307'),
	(377, 1, 0, -50924, 309, 0, 0, 39, '308'),
	(377, 1, 0, -50924, 310, 0, 0, 39, '309'),
	(377, 1, 0, -50924, 311, 0, 0, 39, '310'),
	(377, 1, 0, -50924, 312, 0, 0, 39, '311'),
	(377, 1, 0, -50924, 313, 0, 0, 39, '312'),
	(377, 1, 0, -50924, 314, 0, 0, 39, '313'),
	(377, 1, 0, -50924, 315, 0, 0, 39, '314'),
	(377, 1, 0, -50924, 316, 0, 0, 39, '315'),
	(377, 1, 0, -50924, 317, 0, 0, 39, '316'),
	(377, 1, 0, -50924, 318, 0, 0, 39, '317'),
	(377, 1, 0, -50924, 319, 0, 0, 39, '318'),
	(377, 1, 0, -50924, 320, 0, 0, 39, '319'),
	(377, 1, 0, -50924, 321, 0, 0, 39, '320'),
	(377, 1, 0, -50924, 322, 0, 0, 39, '321'),
	(377, 1, 0, -50924, 323, 0, 0, 39, '322'),
	(377, 1, 0, -50924, 324, 0, 0, 39, '323'),
	(377, 1, 0, -50924, 325, 0, 0, 39, '324'),
	(377, 1, 0, -50924, 326, 0, 0, 39, '325'),
	(377, 1, 0, -50924, 327, 0, 0, 39, '326'),
	(377, 1, 0, -50924, 328, 0, 0, 39, '327'),
	(377, 1, 0, -50924, 329, 0, 0, 39, '328'),
	(377, 1, 0, -50924, 330, 0, 0, 39, '329'),
	(377, 1, 0, -50924, 331, 0, 0, 39, '330'),
	(377, 1, 0, -50924, 332, 0, 0, 39, '331'),
	(377, 1, 0, -50924, 333, 0, 0, 39, '332'),
	(377, 1, 0, -50924, 334, 0, 0, 39, '333'),
	(377, 1, 0, -50924, 335, 0, 0, 39, '334'),
	(377, 1, 0, -50924, 336, 0, 0, 39, '335'),
	(377, 1, 0, -50924, 337, 0, 0, 39, '336'),
	(377, 1, 0, -50924, 338, 0, 0, 39, '337'),
	(377, 1, 0, -50924, 339, 0, 0, 39, '338'),
	(377, 1, 0, -50924, 340, 0, 0, 39, '339'),
	(377, 1, 0, -50924, 341, 0, 0, 39, '340'),
	(377, 1, 0, -50924, 342, 0, 0, 39, '341'),
	(377, 1, 0, -50924, 343, 0, 0, 39, '342'),
	(377, 1, 0, -50924, 344, 0, 0, 39, '343'),
	(377, 1, 0, -50924, 345, 0, 0, 39, '344'),
	(377, 1, 0, -50924, 346, 0, 0, 39, '345'),
	(377, 1, 0, -50924, 347, 0, 0, 39, '346'),
	(377, 1, 0, -50924, 348, 0, 0, 39, '347'),
	(377, 1, 0, -50924, 349, 0, 0, 39, '348'),
	(377, 1, 0, -50924, 350, 0, 0, 39, '349'),
	(377, 1, 0, -50924, 351, 0, 0, 39, '350'),
	(377, 1, 0, -50924, 352, 0, 0, 39, '351'),
	(377, 1, 0, -50924, 353, 0, 0, 39, '352'),
	(377, 1, 0, -50924, 354, 0, 0, 39, '353'),
	(377, 1, 0, -50924, 355, 0, 0, 39, '354'),
	(377, 1, 0, -50924, 356, 0, 0, 39, '355'),
	(377, 1, 0, -50924, 357, 0, 0, 39, '356'),
	(377, 1, 0, -50924, 358, 0, 0, 39, '357'),
	(377, 1, 0, -50924, 359, 0, 0, 39, '358'),
	(377, 1, 0, -50924, 360, 0, 0, 39, '359'),
	(377, 1, 0, -50924, 361, 0, 0, 39, '360'),
	(377, 1, 0, -50924, 362, 0, 0, 39, '361'),
	(377, 1, 0, -50924, 363, 0, 0, 39, '362'),
	(377, 1, 0, -50924, 364, 0, 0, 39, '363'),
	(377, 1, 0, -50924, 365, 0, 0, 39, '364'),
	(377, 1, 0, -50924, 366, 0, 0, 39, '365'),
	(377, 1, 0, -50924, 367, 0, 0, 39, '366'),
	(377, 1, 0, -50924, 368, 0, 0, 39, '367'),
	(377, 1, 0, -50924, 369, 0, 0, 39, '368'),
	(377, 1, 0, -50924, 370, 0, 0, 39, '369'),
	(377, 1, 0, -50924, 371, 0, 0, 39, '370'),
	(377, 1, 0, -50924, 372, 0, 0, 39, '371'),
	(377, 1, 0, -50924, 373, 0, 0, 39, '372'),
	(377, 1, 0, -50924, 374, 0, 0, 39, '373'),
	(377, 1, 0, -50924, 375, 0, 0, 39, '374'),
	(377, 1, 0, -50924, 376, 0, 0, 39, '375'),
	(377, 1, 0, -50924, 377, 0, 0, 39, '376'),
	(377, 1, 0, -50924, 378, 0, 0, 39, '377'),
	(377, 1, 0, -50924, 379, 0, 0, 39, '378'),
	(377, 1, 0, -50924, 380, 0, 0, 39, '379'),
	(377, 1, 0, -50924, 381, 0, 0, 39, '380'),
	(377, 1, 0, -50924, 382, 0, 0, 39, '381'),
	(377, 1, 0, -50924, 383, 0, 0, 39, '382'),
	(377, 1, 0, -50924, 384, 0, 0, 39, '383'),
	(377, 1, 0, -50924, 385, 0, 0, 39, '384'),
	(377, 1, 0, -50924, 386, 0, 0, 39, '385'),
	(377, 1, 0, -50924, 387, 0, 0, 39, '386'),
	(377, 1, 0, -50924, 388, 0, 0, 39, '387'),
	(377, 1, 0, -50924, 389, 0, 0, 39, '388'),
	(377, 1, 0, -50924, 390, 0, 0, 39, '389'),
	(377, 1, 0, -50924, 391, 0, 0, 39, '390'),
	(377, 1, 0, -50924, 392, 0, 0, 39, '391'),
	(377, 1, 0, -50924, 393, 0, 0, 39, '392'),
	(377, 1, 0, -50924, 394, 0, 0, 39, '393'),
	(377, 1, 0, -50924, 395, 0, 0, 39, '394'),
	(377, 1, 0, -50924, 396, 0, 0, 39, '395'),
	(377, 1, 0, -50924, 397, 0, 0, 39, '396'),
	(377, 1, 0, -50924, 398, 0, 0, 39, '397'),
	(377, 1, 0, -50924, 399, 0, 0, 39, '398'),
	(377, 1, 0, -50924, 400, 0, 0, 39, '399'),
	(377, 1, 0, -50924, 401, 0, 0, 39, '400'),
	(377, 1, 0, -50924, 402, 0, 0, 39, '401'),
	(377, 1, 0, -50924, 403, 0, 0, 39, '402'),
	(377, 1, 0, -50924, 404, 0, 0, 39, '403'),
	(377, 1, 0, -50924, 405, 0, 0, 39, '404'),
	(377, 1, 0, -50924, 406, 0, 0, 39, '405'),
	(377, 1, 0, -50924, 407, 0, 0, 39, '406'),
	(377, 1, 0, -50924, 408, 0, 0, 39, '407'),
	(377, 1, 0, -50924, 409, 0, 0, 39, '408'),
	(377, 1, 0, -50924, 410, 0, 0, 39, '409'),
	(377, 1, 0, -50924, 411, 0, 0, 39, '410'),
	(377, 1, 0, -50924, 412, 0, 0, 39, '411'),
	(377, 1, 0, -50924, 413, 0, 0, 39, '412'),
	(377, 1, 0, -50924, 414, 0, 0, 39, '413'),
	(377, 1, 0, -50924, 415, 0, 0, 39, '414'),
	(377, 1, 0, -50924, 416, 0, 0, 39, '415'),
	(377, 1, 0, -50924, 417, 0, 0, 39, '416'),
	(377, 1, 0, -50924, 418, 0, 0, 39, '417'),
	(377, 1, 0, -50924, 419, 0, 0, 39, '418'),
	(377, 1, 0, -50924, 420, 0, 0, 39, '419'),
	(377, 1, 0, -50924, 421, 0, 0, 39, '420'),
	(377, 1, 0, -50924, 422, 0, 0, 39, '421'),
	(377, 1, 0, -50924, 423, 0, 0, 39, '422'),
	(377, 1, 0, -50924, 424, 0, 0, 39, '423'),
	(377, 1, 0, -50924, 425, 0, 0, 39, '424'),
	(377, 1, 0, -50924, 426, 0, 0, 39, '425'),
	(377, 1, 0, -50924, 427, 0, 0, 39, '426'),
	(377, 1, 0, -50924, 428, 0, 0, 39, '427'),
	(377, 1, 0, -50924, 429, 0, 0, 39, '428'),
	(377, 1, 0, -50924, 430, 0, 0, 39, '429'),
	(377, 1, 0, -50924, 431, 0, 0, 39, '430'),
	(377, 1, 0, -50924, 432, 0, 0, 39, '431'),
	(377, 1, 0, -50924, 433, 0, 0, 39, '432'),
	(377, 1, 0, -50924, 434, 0, 0, 39, '433'),
	(377, 1, 0, -50924, 435, 0, 0, 39, '434'),
	(377, 1, 0, -50924, 436, 0, 0, 39, '435'),
	(377, 1, 0, -50924, 437, 0, 0, 39, '436'),
	(377, 1, 0, -50924, 438, 0, 0, 39, '437'),
	(377, 1, 0, -50924, 439, 0, 0, 39, '438'),
	(377, 1, 0, -50924, 440, 0, 0, 39, '439'),
	(377, 1, 0, -50924, 441, 0, 0, 39, '440'),
	(377, 1, 0, -50924, 442, 0, 0, 39, '441'),
	(377, 1, 0, -50924, 443, 0, 0, 39, '442'),
	(377, 1, 0, -50924, 444, 0, 0, 39, '443'),
	(377, 1, 0, -50924, 445, 0, 0, 39, '444'),
	(377, 1, 0, -50924, 446, 0, 0, 39, '445'),
	(377, 1, 0, -50924, 447, 0, 0, 39, '446'),
	(377, 1, 0, -50924, 448, 0, 0, 39, '447'),
	(377, 1, 0, -50924, 449, 0, 0, 39, '448'),
	(377, 1, 0, -50924, 450, 0, 0, 39, '449'),
	(377, 1, 0, -50924, 451, 0, 0, 39, '450'),
	(377, 1, 0, -50924, 452, 0, 0, 39, '451'),
	(377, 1, 0, -50924, 453, 0, 0, 39, '452'),
	(377, 1, 0, -50924, 454, 0, 0, 39, '453'),
	(377, 1, 0, -50924, 455, 0, 0, 39, '454'),
	(377, 1, 0, -50924, 456, 0, 0, 39, '455'),
	(377, 1, 0, -50924, 457, 0, 0, 39, '456'),
	(377, 1, 0, -50924, 458, 0, 0, 39, '457'),
	(377, 1, 0, -50924, 459, 0, 0, 39, '458'),
	(377, 1, 0, -50924, 460, 0, 0, 39, '459'),
	(377, 1, 0, -50924, 461, 0, 0, 39, '460'),
	(377, 1, 0, -50924, 462, 0, 0, 39, '461'),
	(377, 1, 0, -50924, 463, 0, 0, 39, '462'),
	(377, 1, 0, -50924, 464, 0, 0, 39, '463'),
	(377, 1, 0, -50924, 465, 0, 0, 39, '464'),
	(377, 1, 0, -50924, 466, 0, 0, 39, '465'),
	(377, 1, 0, -50924, 467, 0, 0, 39, '466'),
	(377, 1, 0, -50924, 468, 0, 0, 39, '467'),
	(377, 1, 0, -50924, 469, 0, 0, 39, '468'),
	(377, 1, 0, -50924, 470, 0, 0, 39, '469'),
	(377, 1, 0, -50924, 471, 0, 0, 39, '470'),
	(377, 1, 0, -50924, 472, 0, 0, 39, '471'),
	(377, 1, 0, -50924, 473, 0, 0, 39, '472'),
	(377, 1, 0, -50924, 474, 0, 0, 39, '473'),
	(377, 1, 0, -50924, 475, 0, 0, 39, '474'),
	(377, 1, 0, -50924, 476, 0, 0, 39, '475'),
	(377, 1, 0, -50924, 477, 0, 0, 39, '476'),
	(377, 1, 0, -50924, 478, 0, 0, 39, '477'),
	(377, 1, 0, -50924, 479, 0, 0, 39, '478'),
	(377, 1, 0, -50924, 480, 0, 0, 39, '479'),
	(377, 1, 0, -50924, 481, 0, 0, 39, '480'),
	(377, 1, 0, -50924, 482, 0, 0, 39, '481'),
	(377, 1, 0, -50924, 483, 0, 0, 39, '482'),
	(377, 1, 0, -50924, 484, 0, 0, 39, '483'),
	(377, 1, 0, -50924, 485, 0, 0, 39, '484'),
	(377, 1, 0, -50924, 486, 0, 0, 39, '485'),
	(377, 1, 0, -50924, 487, 0, 0, 39, '486'),
	(377, 1, 0, -50924, 488, 0, 0, 39, '487'),
	(377, 1, 0, -50924, 489, 0, 0, 39, '488'),
	(377, 1, 0, -50924, 490, 0, 0, 39, '489'),
	(377, 1, 0, -50924, 491, 0, 0, 39, '490'),
	(377, 1, 0, -50924, 492, 0, 0, 39, '491'),
	(377, 1, 0, -50924, 493, 0, 0, 39, '492'),
	(377, 1, 0, -50924, 494, 0, 0, 39, '493'),
	(377, 1, 0, -50924, 495, 0, 0, 39, '494'),
	(377, 1, 0, -50924, 496, 0, 0, 39, '495'),
	(377, 1, 0, -50924, 497, 0, 0, 39, '496'),
	(377, 1, 0, -50924, 498, 0, 0, 39, '497'),
	(377, 1, 0, -50924, 499, 0, 0, 39, '498'),
	(377, 1, 0, -50924, 500, 0, 0, 39, '499'),
	(377, 1, 0, -50924, 501, 0, 0, 39, '500'),
	(377, 1, 0, -50924, 502, 0, 0, 39, '501'),
	(377, 1, 0, -50924, 503, 0, 0, 39, '502'),
	(377, 1, 0, -50924, 504, 0, 0, 39, '503'),
	(377, 1, 0, -50924, 505, 0, 0, 39, '504'),
	(377, 1, 0, -50924, 506, 0, 0, 39, '505'),
	(377, 1, 0, -50924, 507, 0, 0, 39, '506'),
	(377, 1, 0, -50924, 508, 0, 0, 39, '507'),
	(377, 1, 0, -50924, 509, 0, 0, 39, '508'),
	(377, 1, 0, -50924, 510, 0, 0, 39, '509'),
	(377, 1, 0, -50924, 511, 0, 0, 39, '510'),
	(377, 1, 0, -50924, 512, 0, 0, 39, '511'),
	(377, 1, 0, -50924, 513, 0, 0, 39, '512'),
	(377, 1, 0, -50924, 514, 0, 0, 39, '513'),
	(377, 1, 0, -50924, 515, 0, 0, 39, '514'),
	(377, 1, 0, -50924, 516, 0, 0, 39, '515'),
	(377, 1, 0, -50924, 517, 0, 0, 39, '516'),
	(377, 1, 0, -50924, 518, 0, 0, 39, '517'),
	(377, 1, 0, -50924, 519, 0, 0, 39, '518'),
	(377, 1, 0, -50924, 520, 0, 0, 39, '519'),
	(377, 1, 0, -50924, 521, 0, 0, 39, '520'),
	(377, 1, 0, -50924, 522, 0, 0, 39, '521'),
	(377, 1, 0, -50924, 523, 0, 0, 39, '522'),
	(377, 1, 0, -50924, 524, 0, 0, 39, '523'),
	(377, 1, 0, -50924, 525, 0, 0, 39, '524'),
	(377, 1, 0, -50924, 526, 0, 0, 39, '525'),
	(377, 1, 0, -50924, 527, 0, 0, 39, '526'),
	(377, 1, 0, -50924, 528, 0, 0, 39, '527'),
	(377, 1, 0, -50924, 529, 0, 0, 39, '528'),
	(377, 1, 0, -50924, 530, 0, 0, 39, '529'),
	(377, 1, 0, -50924, 531, 0, 0, 39, '530'),
	(377, 1, 0, -50924, 532, 0, 0, 39, '531'),
	(377, 1, 0, -50924, 533, 0, 0, 39, '532'),
	(377, 1, 0, -50924, 534, 0, 0, 39, '533'),
	(377, 1, 0, -50924, 535, 0, 0, 39, '534'),
	(377, 1, 0, -50924, 536, 0, 0, 39, '535'),
	(377, 1, 0, -50924, 537, 0, 0, 39, '536'),
	(377, 1, 0, -50924, 538, 0, 0, 39, '537'),
	(377, 1, 0, -50924, 539, 0, 0, 39, '538'),
	(377, 1, 0, -50924, 540, 0, 0, 39, '539'),
	(377, 1, 0, -50924, 541, 0, 0, 39, '540'),
	(377, 1, 0, -50924, 542, 0, 0, 39, '541'),
	(377, 1, 0, -50924, 543, 0, 0, 39, '542'),
	(377, 1, 0, -50924, 544, 0, 0, 39, '543'),
	(377, 1, 0, -50924, 545, 0, 0, 39, '544'),
	(377, 1, 0, -50924, 546, 0, 0, 39, '545'),
	(377, 1, 0, -50924, 547, 0, 0, 39, '546'),
	(377, 1, 0, -50924, 548, 0, 0, 39, '547'),
	(377, 1, 0, -50924, 549, 0, 0, 39, '548'),
	(377, 1, 0, -50924, 550, 0, 0, 39, '549'),
	(377, 1, 0, -50924, 551, 0, 0, 39, '550'),
	(377, 1, 0, -50924, 552, 0, 0, 39, '551'),
	(377, 1, 0, -50924, 553, 0, 0, 39, '552'),
	(377, 1, 0, -50924, 554, 0, 0, 39, '553'),
	(377, 1, 0, -50924, 555, 0, 0, 39, '554'),
	(377, 1, 0, -50924, 556, 0, 0, 39, '555'),
	(377, 1, 0, -50924, 557, 0, 0, 39, '556'),
	(377, 1, 0, -50924, 558, 0, 0, 39, '557'),
	(377, 1, 0, -50924, 559, 0, 0, 39, '558'),
	(377, 1, 0, -50924, 560, 0, 0, 39, '559'),
	(377, 1, 0, -50924, 561, 0, 0, 39, '560'),
	(377, 1, 0, -50924, 562, 0, 0, 39, '561'),
	(377, 1, 0, -50924, 563, 0, 0, 39, '562'),
	(377, 1, 0, -50924, 564, 0, 0, 39, '563'),
	(377, 1, 0, -50924, 565, 0, 0, 39, '564'),
	(377, 1, 0, -50924, 566, 0, 0, 39, '565'),
	(377, 1, 0, -50924, 567, 0, 0, 39, '566'),
	(377, 1, 0, -50924, 568, 0, 0, 39, '567'),
	(377, 1, 0, -50924, 569, 0, 0, 39, '568'),
	(377, 1, 0, -50924, 570, 0, 0, 39, '569'),
	(377, 1, 0, -50924, 571, 0, 0, 39, '570'),
	(377, 1, 0, -50924, 572, 0, 0, 39, '571'),
	(377, 1, 0, -50924, 573, 0, 0, 39, '572'),
	(377, 1, 0, -50924, 574, 0, 0, 39, '573'),
	(377, 1, 0, -50924, 575, 0, 0, 39, '574'),
	(377, 1, 0, -50924, 576, 0, 0, 39, '575'),
	(377, 1, 0, -50924, 577, 0, 0, 39, '576'),
	(377, 1, 0, -50924, 578, 0, 0, 39, '577'),
	(377, 1, 0, -50924, 579, 0, 0, 39, '578'),
	(377, 1, 0, -50924, 580, 0, 0, 39, '579'),
	(377, 1, 0, -50924, 581, 0, 0, 39, '580'),
	(377, 1, 0, -50924, 582, 0, 0, 39, '581'),
	(377, 1, 0, -50924, 583, 0, 0, 39, '582'),
	(377, 1, 0, -50924, 584, 0, 0, 39, '583'),
	(377, 1, 0, -50924, 585, 0, 0, 39, '584'),
	(377, 1, 0, -50924, 586, 0, 0, 39, '585'),
	(377, 1, 0, -50924, 587, 0, 0, 39, '586'),
	(377, 1, 0, -50924, 588, 0, 0, 39, '587'),
	(377, 1, 0, -50924, 589, 0, 0, 39, '588'),
	(377, 1, 0, -50924, 590, 0, 0, 39, '589'),
	(377, 1, 0, -50924, 591, 0, 0, 39, '590'),
	(377, 1, 0, -50924, 592, 0, 0, 39, '591'),
	(377, 1, 0, -50924, 593, 0, 0, 39, '592'),
	(377, 1, 0, -50924, 594, 0, 0, 39, '593'),
	(377, 1, 0, -50924, 595, 0, 0, 39, '594'),
	(377, 1, 0, -50924, 596, 0, 0, 39, '595'),
	(377, 1, 0, -50924, 597, 0, 0, 39, '596'),
	(377, 1, 0, -50924, 598, 0, 0, 39, '597'),
	(377, 1, 0, -50924, 599, 0, 0, 39, '598'),
	(377, 1, 0, -50924, 600, 0, 0, 39, '599'),
	(377, 1, 0, -50924, 601, 0, 0, 39, '600'),
	(377, 1, 0, -50924, 602, 0, 0, 39, '601'),
	(377, 1, 0, -50924, 603, 0, 0, 39, '602'),
	(377, 1, 0, -50924, 604, 0, 0, 39, '603'),
	(377, 1, 0, -50924, 605, 0, 0, 39, '604'),
	(377, 1, 0, -50924, 606, 0, 0, 39, '605'),
	(377, 1, 0, -50924, 607, 0, 0, 39, '606'),
	(377, 1, 0, -50924, 608, 0, 0, 39, '607'),
	(377, 1, 0, -50924, 609, 0, 0, 39, '608'),
	(377, 1, 0, -50924, 610, 0, 0, 39, '609'),
	(377, 1, 0, -50924, 611, 0, 0, 39, '610'),
	(377, 1, 0, -50924, 612, 0, 0, 39, '611'),
	(377, 1, 0, -50924, 613, 0, 0, 39, '612'),
	(377, 1, 0, -50924, 614, 0, 0, 39, '613'),
	(377, 1, 0, -50924, 615, 0, 0, 39, '614'),
	(377, 1, 0, -50924, 616, 0, 0, 39, '615'),
	(377, 1, 0, -50924, 617, 0, 0, 39, '616'),
	(377, 1, 0, -50924, 618, 0, 0, 39, '617'),
	(377, 1, 0, -50924, 619, 0, 0, 39, '618'),
	(377, 1, 0, -50924, 620, 0, 0, 39, '619'),
	(377, 1, 0, -50924, 621, 0, 0, 39, '620'),
	(377, 1, 0, -50924, 622, 0, 0, 39, '621'),
	(377, 1, 0, -50924, 623, 0, 0, 39, '622'),
	(377, 1, 0, -50924, 624, 0, 0, 39, '623'),
	(377, 1, 0, -50924, 625, 0, 0, 39, '624'),
	(377, 1, 0, -50924, 626, 0, 0, 39, '625'),
	(377, 1, 0, -50924, 627, 0, 0, 39, '626'),
	(377, 1, 0, -50924, 628, 0, 0, 39, '627'),
	(377, 1, 0, -50924, 629, 0, 0, 39, '628'),
	(377, 1, 0, -50924, 630, 0, 0, 39, '629'),
	(377, 1, 0, -50924, 631, 0, 0, 39, '630'),
	(377, 1, 0, -50924, 632, 0, 0, 39, '631'),
	(377, 1, 0, -50924, 633, 0, 0, 39, '632'),
	(377, 1, 0, -50924, 634, 0, 0, 39, '633'),
	(377, 1, 0, -50924, 635, 0, 0, 39, '634'),
	(377, 1, 0, -50924, 636, 0, 0, 39, '635'),
	(377, 1, 0, -50924, 637, 0, 0, 39, '636'),
	(377, 1, 0, -50924, 638, 0, 0, 39, '637'),
	(377, 1, 0, -50924, 639, 0, 0, 39, '638'),
	(377, 1, 0, -50924, 640, 0, 0, 39, '639'),
	(377, 1, 0, -50924, 641, 0, 0, 39, '640'),
	(377, 1, 0, -50924, 642, 0, 0, 39, '641'),
	(377, 1, 0, -50924, 643, 0, 0, 39, '642'),
	(377, 1, 0, -50924, 644, 0, 0, 39, '643'),
	(377, 1, 0, -50924, 645, 0, 0, 39, '644'),
	(377, 1, 0, -50924, 646, 0, 0, 39, '645'),
	(377, 1, 0, -50924, 647, 0, 0, 39, '646'),
	(377, 1, 0, -50924, 648, 0, 0, 39, '647'),
	(377, 1, 0, -50924, 649, 0, 0, 39, '648'),
	(377, 1, 0, -50924, 650, 0, 0, 39, '649'),
	(377, 1, 0, -50924, 651, 0, 0, 39, '650'),
	(377, 1, 0, -50924, 652, 0, 0, 39, '651'),
	(377, 1, 0, -50924, 653, 0, 0, 39, '652'),
	(377, 1, 0, -50924, 654, 0, 0, 39, '653'),
	(377, 1, 0, -50924, 655, 0, 0, 39, '654'),
	(377, 1, 0, -50924, 656, 0, 0, 39, '655'),
	(377, 1, 0, -50924, 657, 0, 0, 39, '656'),
	(377, 1, 0, -50924, 658, 0, 0, 39, '657'),
	(377, 1, 0, -50924, 659, 0, 0, 39, '658'),
	(377, 1, 0, -50924, 660, 0, 0, 39, '659'),
	(377, 1, 0, -50924, 661, 0, 0, 39, '660'),
	(377, 1, 0, -50924, 662, 0, 0, 39, '661'),
	(377, 1, 0, -50924, 663, 0, 0, 39, '662'),
	(377, 1, 0, -50924, 664, 0, 0, 39, '663'),
	(377, 1, 0, -50924, 665, 0, 0, 39, '664'),
	(377, 1, 0, -50924, 666, 0, 0, 39, '665'),
	(377, 1, 0, -50924, 667, 0, 0, 39, '666'),
	(377, 1, 0, -50924, 668, 0, 0, 39, '667'),
	(377, 1, 0, -50924, 669, 0, 0, 39, '668'),
	(377, 1, 0, -50924, 670, 0, 0, 39, '669'),
	(377, 1, 0, -50924, 671, 0, 0, 39, '670'),
	(377, 1, 0, -50924, 672, 0, 0, 39, '671'),
	(377, 1, 0, -50924, 673, 0, 0, 39, '672'),
	(377, 1, 0, -50924, 674, 0, 0, 39, '673'),
	(377, 1, 0, -50924, 675, 0, 0, 39, '674'),
	(377, 1, 0, -50924, 676, 0, 0, 39, '675'),
	(377, 1, 0, -50924, 677, 0, 0, 39, '676'),
	(377, 1, 0, -50924, 678, 0, 0, 39, '677'),
	(377, 1, 0, -50924, 679, 0, 0, 39, '678'),
	(377, 1, 0, -50924, 680, 0, 0, 39, '679'),
	(377, 1, 0, -50924, 681, 0, 0, 39, '680'),
	(377, 1, 0, -50924, 682, 0, 0, 39, '681'),
	(377, 1, 0, -50924, 683, 0, 0, 39, '682'),
	(377, 1, 0, -50924, 684, 0, 0, 39, '683'),
	(377, 1, 0, -50924, 685, 0, 0, 39, '684'),
	(377, 1, 0, -50924, 686, 0, 0, 39, '685'),
	(377, 1, 0, -50924, 687, 0, 0, 39, '686'),
	(377, 1, 0, -50924, 688, 0, 0, 39, '687'),
	(377, 1, 0, -50924, 689, 0, 0, 39, '688'),
	(377, 1, 0, -50924, 690, 0, 0, 39, '689'),
	(377, 1, 0, -50924, 691, 0, 0, 39, '690'),
	(377, 1, 0, -50924, 692, 0, 0, 39, '691'),
	(377, 1, 0, -50924, 693, 0, 0, 39, '692'),
	(377, 1, 0, -50924, 694, 0, 0, 39, '693'),
	(377, 1, 0, -50924, 695, 0, 0, 39, '694'),
	(377, 1, 0, -50924, 696, 0, 0, 39, '695'),
	(377, 1, 0, -50924, 697, 0, 0, 39, '696'),
	(377, 1, 0, -50924, 698, 0, 0, 39, '697'),
	(377, 1, 0, -50924, 699, 0, 0, 39, '698'),
	(377, 1, 0, -50924, 700, 0, 0, 39, '699'),
	(377, 1, 0, -50924, 701, 0, 0, 39, '700'),
	(377, 1, 0, -50924, 702, 0, 0, 39, '701'),
	(377, 1, 0, -50924, 703, 0, 0, 39, '702'),
	(377, 1, 0, -50924, 704, 0, 0, 39, '703'),
	(377, 1, 0, -50924, 705, 0, 0, 39, '704'),
	(377, 1, 0, -50924, 706, 0, 0, 39, '705'),
	(377, 1, 0, -50924, 707, 0, 0, 39, '706'),
	(377, 1, 0, -50924, 708, 0, 0, 39, '707'),
	(377, 1, 0, -50924, 709, 0, 0, 39, '708'),
	(377, 1, 0, -50924, 710, 0, 0, 39, '709'),
	(377, 1, 0, -50924, 711, 0, 0, 39, '710'),
	(377, 1, 0, -50924, 712, 0, 0, 39, '711'),
	(377, 1, 0, -50924, 713, 0, 0, 39, '712'),
	(377, 1, 0, -50924, 714, 0, 0, 39, '713'),
	(377, 1, 0, -50924, 715, 0, 0, 39, '714'),
	(377, 1, 0, -50924, 716, 0, 0, 39, '715'),
	(377, 1, 0, -50924, 717, 0, 0, 39, '716'),
	(377, 1, 0, -50924, 718, 0, 0, 39, '717'),
	(377, 1, 0, -50924, 719, 0, 0, 39, '718'),
	(377, 1, 0, -50924, 720, 0, 0, 39, '719'),
	(377, 1, 0, -50924, 721, 0, 0, 39, '720'),
	(377, 1, 0, -50924, 722, 0, 0, 39, '721'),
	(377, 1, 0, -50924, 723, 0, 0, 39, '722'),
	(377, 1, 0, -50924, 724, 0, 0, 39, '723'),
	(377, 1, 0, -50924, 725, 0, 0, 39, '724'),
	(377, 1, 0, -50924, 726, 0, 0, 39, '725'),
	(377, 1, 0, -50924, 727, 0, 0, 39, '726'),
	(377, 1, 0, -50924, 728, 0, 0, 39, '727'),
	(377, 1, 0, -50924, 729, 0, 0, 39, '728'),
	(377, 1, 0, -50924, 730, 0, 0, 39, '729'),
	(377, 1, 0, -50924, 731, 0, 0, 39, '730'),
	(377, 1, 0, -50924, 732, 0, 0, 39, '731'),
	(377, 1, 0, -50924, 733, 0, 0, 39, '732'),
	(377, 1, 0, -50924, 734, 0, 0, 39, '733'),
	(377, 1, 0, -50924, 735, 0, 0, 39, '734'),
	(377, 1, 0, -50924, 736, 0, 0, 39, '735'),
	(377, 1, 0, -50924, 737, 0, 0, 39, '736'),
	(377, 1, 0, -50924, 738, 0, 0, 39, '737'),
	(377, 1, 0, -50924, 739, 0, 0, 39, '738'),
	(377, 1, 0, -50924, 740, 0, 0, 39, '739'),
	(377, 1, 0, -50924, 741, 0, 0, 39, '740'),
	(377, 1, 0, -50924, 742, 0, 0, 39, '741'),
	(377, 1, 0, -50924, 743, 0, 0, 39, '742'),
	(377, 1, 0, -50924, 744, 0, 0, 39, '743'),
	(377, 1, 0, -50924, 745, 0, 0, 39, '744'),
	(377, 1, 0, -50924, 746, 0, 0, 39, '745'),
	(377, 1, 0, -50924, 747, 0, 0, 39, '746'),
	(377, 1, 0, -50924, 748, 0, 0, 39, '747'),
	(377, 1, 0, -50924, 749, 0, 0, 39, '748'),
	(377, 1, 0, -50924, 750, 0, 0, 39, '749'),
	(377, 1, 0, -50924, 751, 0, 0, 39, '750'),
	(377, 1, 0, -50924, 752, 0, 0, 39, '751'),
	(377, 1, 0, -50924, 753, 0, 0, 39, '752'),
	(377, 1, 0, -50924, 754, 0, 0, 39, '753'),
	(377, 1, 0, -50924, 755, 0, 0, 39, '754'),
	(377, 1, 0, -50924, 756, 0, 0, 39, '755'),
	(377, 1, 0, -50924, 757, 0, 0, 39, '756'),
	(377, 1, 0, -50924, 758, 0, 0, 39, '757'),
	(377, 1, 0, -50924, 759, 0, 0, 39, '758'),
	(377, 1, 0, -50924, 760, 0, 0, 39, '759'),
	(377, 1, 0, -50924, 761, 0, 0, 39, '760'),
	(377, 1, 0, -50924, 762, 0, 0, 39, '761'),
	(377, 1, 0, -50924, 763, 0, 0, 39, '762'),
	(377, 1, 0, -50924, 764, 0, 0, 39, '763'),
	(377, 1, 0, -50924, 765, 0, 0, 39, '764'),
	(377, 1, 0, -50924, 766, 0, 0, 39, '765'),
	(377, 1, 0, -50924, 767, 0, 0, 39, '766'),
	(377, 1, 0, -50924, 768, 0, 0, 39, '767'),
	(377, 1, 0, -50924, 769, 0, 0, 39, '768'),
	(377, 1, 0, -50924, 770, 0, 0, 39, '769'),
	(377, 1, 0, -50924, 771, 0, 0, 39, '770'),
	(377, 1, 0, -50924, 772, 0, 0, 39, '771'),
	(377, 1, 0, -50924, 773, 0, 0, 39, '772'),
	(377, 1, 0, -50924, 774, 0, 0, 39, '773'),
	(377, 1, 0, -50924, 775, 0, 0, 39, '774'),
	(377, 1, 0, -50924, 776, 0, 0, 39, '775'),
	(377, 1, 0, -50924, 777, 0, 0, 39, '776'),
	(377, 1, 0, -50924, 778, 0, 0, 39, '777'),
	(377, 1, 0, -50924, 779, 0, 0, 39, '778'),
	(377, 1, 0, -50924, 780, 0, 0, 39, '779'),
	(377, 1, 0, -50924, 781, 0, 0, 39, '780'),
	(377, 1, 0, -50924, 782, 0, 0, 39, '781'),
	(377, 1, 0, -50924, 783, 0, 0, 39, '782'),
	(377, 1, 0, -50924, 784, 0, 0, 39, '783'),
	(377, 1, 0, -50924, 785, 0, 0, 39, '784'),
	(377, 1, 0, -50924, 786, 0, 0, 39, '785'),
	(377, 1, 0, -50924, 787, 0, 0, 39, '786'),
	(377, 1, 0, -50924, 788, 0, 0, 39, '787'),
	(377, 1, 0, -50924, 789, 0, 0, 39, '788'),
	(377, 1, 0, -50924, 790, 0, 0, 39, '789'),
	(377, 1, 0, -50924, 791, 0, 0, 39, '790'),
	(377, 1, 0, -50924, 792, 0, 0, 39, '791'),
	(377, 1, 0, -50924, 793, 0, 0, 39, '792'),
	(377, 1, 0, -50924, 794, 0, 0, 39, '793'),
	(377, 1, 0, -50924, 795, 0, 0, 39, '794'),
	(377, 1, 0, -50924, 796, 0, 0, 39, '795'),
	(377, 1, 0, -50924, 797, 0, 0, 39, '796'),
	(377, 1, 0, -50924, 798, 0, 0, 39, '797'),
	(377, 1, 0, -50924, 799, 0, 0, 39, '798'),
	(377, 1, 0, -50924, 800, 0, 0, 39, '799'),
	(377, 1, 0, -50924, 801, 0, 0, 39, '800'),
	(377, 1, 0, -50924, 802, 0, 0, 39, '801'),
	(377, 1, 0, -50924, 803, 0, 0, 39, '802'),
	(377, 1, 0, -50924, 804, 0, 0, 39, '803'),
	(377, 1, 0, -50924, 805, 0, 0, 39, '804'),
	(377, 1, 0, -50924, 806, 0, 0, 39, '805'),
	(377, 1, 0, -50924, 807, 0, 0, 39, '806'),
	(377, 1, 0, -50924, 808, 0, 0, 39, '807'),
	(377, 1, 0, -50924, 809, 0, 0, 39, '808'),
	(377, 1, 0, -50924, 810, 0, 0, 39, '809'),
	(377, 1, 0, -50924, 811, 0, 0, 39, '810'),
	(377, 1, 0, -50924, 812, 0, 0, 39, '811'),
	(377, 1, 0, -50924, 813, 0, 0, 39, '812'),
	(377, 1, 0, -50924, 814, 0, 0, 39, '813'),
	(377, 1, 0, -50924, 815, 0, 0, 39, '814'),
	(377, 1, 0, -50924, 816, 0, 0, 39, '815'),
	(377, 1, 0, -50924, 817, 0, 0, 39, '816'),
	(377, 1, 0, -50924, 818, 0, 0, 39, '817'),
	(377, 1, 0, -50924, 819, 0, 0, 39, '818'),
	(377, 1, 0, -50924, 820, 0, 0, 39, '819'),
	(377, 1, 0, -50924, 821, 0, 0, 39, '820'),
	(377, 1, 0, -50924, 822, 0, 0, 39, '821'),
	(377, 1, 0, -50924, 823, 0, 0, 39, '822'),
	(377, 1, 0, -50924, 824, 0, 0, 39, '823'),
	(377, 1, 0, -50924, 825, 0, 0, 39, '824'),
	(377, 1, 0, -50924, 826, 0, 0, 39, '825'),
	(377, 1, 0, -50924, 827, 0, 0, 39, '826'),
	(377, 1, 0, -50924, 828, 0, 0, 39, '827'),
	(377, 1, 0, -50924, 829, 0, 0, 39, '828'),
	(377, 1, 0, -50924, 830, 0, 0, 39, '829'),
	(377, 1, 0, -50924, 831, 0, 0, 39, '830'),
	(377, 1, 0, -50924, 832, 0, 0, 39, '831'),
	(377, 1, 0, -50924, 833, 0, 0, 39, '832'),
	(377, 1, 0, -50924, 834, 0, 0, 39, '833'),
	(377, 1, 0, -50924, 835, 0, 0, 39, '834'),
	(377, 1, 0, -50924, 836, 0, 0, 39, '835'),
	(377, 1, 0, -50924, 837, 0, 0, 39, '836'),
	(377, 1, 0, -50924, 838, 0, 0, 39, '837'),
	(377, 1, 0, -50924, 839, 0, 0, 39, '838'),
	(377, 1, 0, -50924, 840, 0, 0, 39, '839'),
	(377, 1, 0, -50924, 841, 0, 0, 39, '840'),
	(377, 1, 0, -50924, 842, 0, 0, 39, '841'),
	(377, 1, 0, -50924, 843, 0, 0, 39, '842'),
	(377, 1, 0, -50924, 844, 0, 0, 39, '843'),
	(377, 1, 0, -50924, 845, 0, 0, 39, '844'),
	(377, 1, 0, -50924, 846, 0, 0, 39, '845'),
	(377, 1, 0, -50924, 847, 0, 0, 39, '846'),
	(377, 1, 0, -50924, 848, 0, 0, 39, '847'),
	(377, 1, 0, -50924, 849, 0, 0, 39, '848'),
	(377, 1, 0, -50924, 850, 0, 0, 39, '849'),
	(377, 1, 0, -50924, 851, 0, 0, 39, '850'),
	(377, 1, 0, -50924, 852, 0, 0, 39, '851'),
	(377, 1, 0, -50924, 853, 0, 0, 39, '852'),
	(377, 1, 0, -50924, 854, 0, 0, 39, '853'),
	(377, 1, 0, -50924, 855, 0, 0, 39, '854'),
	(377, 1, 0, -50924, 856, 0, 0, 39, '855'),
	(377, 1, 0, -50924, 857, 0, 0, 39, '856'),
	(377, 1, 0, -50924, 858, 0, 0, 39, '857'),
	(377, 1, 0, -50924, 859, 0, 0, 39, '858'),
	(377, 1, 0, -50924, 860, 0, 0, 39, '859'),
	(377, 1, 0, -50924, 861, 0, 0, 39, '860'),
	(377, 1, 0, -50924, 862, 0, 0, 39, '861'),
	(377, 1, 0, -50924, 863, 0, 0, 39, '862'),
	(377, 1, 0, -50924, 864, 0, 0, 39, '863'),
	(377, 1, 0, -50924, 865, 0, 0, 39, '864'),
	(377, 1, 0, -50924, 866, 0, 0, 39, '865'),
	(377, 1, 0, -50924, 867, 0, 0, 39, '866'),
	(377, 1, 0, -50924, 868, 0, 0, 39, '867'),
	(377, 1, 0, -50924, 869, 0, 0, 39, '868'),
	(377, 1, 0, -50924, 870, 0, 0, 39, '869'),
	(377, 1, 0, -50924, 871, 0, 0, 39, '870'),
	(377, 1, 0, -50924, 872, 0, 0, 39, '871'),
	(377, 1, 0, -50924, 873, 0, 0, 39, '872'),
	(377, 1, 0, -50924, 874, 0, 0, 39, '873'),
	(377, 1, 0, -50924, 875, 0, 0, 39, '874'),
	(377, 1, 0, -50924, 876, 0, 0, 39, '875'),
	(377, 1, 0, -50924, 877, 0, 0, 39, '876'),
	(377, 1, 0, -50924, 878, 0, 0, 39, '877'),
	(377, 1, 0, -50924, 879, 0, 0, 39, '878'),
	(377, 1, 0, -50924, 880, 0, 0, 39, '879'),
	(377, 1, 0, -50924, 881, 0, 0, 39, '880'),
	(377, 1, 0, -50924, 882, 0, 0, 39, '881'),
	(377, 1, 0, -50924, 883, 0, 0, 39, '882'),
	(377, 1, 0, -50924, 884, 0, 0, 39, '883'),
	(377, 1, 0, -50924, 885, 0, 0, 39, '884'),
	(377, 1, 0, -50924, 886, 0, 0, 39, '885'),
	(377, 1, 0, -50924, 887, 0, 0, 39, '886'),
	(377, 1, 0, -50924, 888, 0, 0, 39, '887'),
	(377, 1, 0, -50924, 889, 0, 0, 39, '888'),
	(377, 1, 0, -50924, 890, 0, 0, 39, '889'),
	(377, 1, 0, -50924, 891, 0, 0, 39, '890'),
	(377, 1, 0, -50924, 892, 0, 0, 39, '891'),
	(377, 1, 0, -50924, 893, 0, 0, 39, '892'),
	(377, 1, 0, -50924, 894, 0, 0, 39, '893'),
	(377, 1, 0, -50924, 895, 0, 0, 39, '894'),
	(377, 1, 0, -50924, 896, 0, 0, 39, '895'),
	(377, 1, 0, -50924, 897, 0, 0, 39, '896'),
	(377, 1, 0, -50924, 898, 0, 0, 39, '897'),
	(377, 1, 0, -50924, 899, 0, 0, 39, '898'),
	(377, 1, 0, -50924, 900, 0, 0, 39, '899'),
	(377, 1, 0, -50924, 901, 0, 0, 39, '900'),
	(377, 1, 0, -50924, 902, 0, 0, 39, '901'),
	(377, 1, 0, -50924, 903, 0, 0, 39, '902'),
	(377, 1, 0, -50924, 904, 0, 0, 39, '903'),
	(377, 1, 0, -50924, 905, 0, 0, 39, '904'),
	(377, 1, 0, -50924, 906, 0, 0, 39, '905'),
	(377, 1, 0, -50924, 907, 0, 0, 39, '906'),
	(377, 1, 0, -50924, 908, 0, 0, 39, '907'),
	(377, 1, 0, -50924, 909, 0, 0, 39, '908'),
	(377, 1, 0, -50924, 910, 0, 0, 39, '909'),
	(377, 1, 0, -50924, 911, 0, 0, 39, '910'),
	(377, 1, 0, -50924, 912, 0, 0, 39, '911'),
	(377, 1, 0, -50924, 913, 0, 0, 39, '912'),
	(377, 1, 0, -50924, 914, 0, 0, 39, '913'),
	(377, 1, 0, -50924, 915, 0, 0, 39, '914'),
	(377, 1, 0, -50924, 916, 0, 0, 39, '915'),
	(377, 1, 0, -50924, 917, 0, 0, 39, '916'),
	(377, 1, 0, -50924, 918, 0, 0, 39, '917'),
	(377, 1, 0, -50924, 919, 0, 0, 39, '918'),
	(377, 1, 0, -50924, 920, 0, 0, 39, '919'),
	(377, 1, 0, -50924, 921, 0, 0, 39, '920'),
	(377, 1, 0, -50924, 922, 0, 0, 39, '921'),
	(377, 1, 0, -50924, 923, 0, 0, 39, '922'),
	(377, 1, 0, -50924, 924, 0, 0, 39, '923'),
	(377, 1, 0, -50924, 925, 0, 0, 39, '924'),
	(377, 1, 0, -50924, 926, 0, 0, 39, '925'),
	(377, 1, 0, -50924, 927, 0, 0, 39, '926'),
	(377, 1, 0, -50924, 928, 0, 0, 39, '927'),
	(377, 1, 0, -50924, 929, 0, 0, 39, '928'),
	(377, 1, 0, -50924, 930, 0, 0, 39, '929'),
	(377, 1, 0, -50924, 931, 0, 0, 39, '930'),
	(377, 1, 0, -50924, 932, 0, 0, 39, '931'),
	(377, 1, 0, -50924, 933, 0, 0, 39, '932'),
	(377, 1, 0, -50924, 934, 0, 0, 39, '933'),
	(377, 1, 0, -50924, 935, 0, 0, 39, '934'),
	(377, 1, 0, -50924, 936, 0, 0, 39, '935'),
	(377, 1, 0, -50924, 937, 0, 0, 39, '936'),
	(377, 1, 0, -50924, 938, 0, 0, 39, '937'),
	(377, 1, 0, -50924, 939, 0, 0, 39, '938'),
	(377, 1, 0, -50924, 940, 0, 0, 39, '939'),
	(377, 1, 0, -50924, 941, 0, 0, 39, '940'),
	(377, 1, 0, -50924, 942, 0, 0, 39, '941'),
	(377, 1, 0, -50924, 943, 0, 0, 39, '942'),
	(377, 1, 0, -50924, 944, 0, 0, 39, '943'),
	(377, 1, 0, -50924, 945, 0, 0, 39, '944'),
	(377, 1, 0, -50924, 946, 0, 0, 39, '945'),
	(377, 1, 0, -50924, 947, 0, 0, 39, '946'),
	(377, 1, 0, -50924, 948, 0, 0, 39, '947'),
	(377, 1, 0, -50924, 949, 0, 0, 39, '948'),
	(377, 1, 0, -50924, 950, 0, 0, 39, '949'),
	(377, 1, 0, -50924, 951, 0, 0, 39, '950'),
	(377, 1, 0, -50924, 952, 0, 0, 39, '951'),
	(377, 1, 0, -50924, 953, 0, 0, 39, '952'),
	(377, 1, 0, -50924, 954, 0, 0, 39, '953'),
	(377, 1, 0, -50924, 955, 0, 0, 39, '954'),
	(377, 1, 0, -50924, 956, 0, 0, 39, '955'),
	(377, 1, 0, -50924, 957, 0, 0, 39, '956'),
	(377, 1, 0, -50924, 958, 0, 0, 39, '957'),
	(377, 1, 0, -50924, 959, 0, 0, 39, '958'),
	(377, 1, 0, -50924, 960, 0, 0, 39, '959'),
	(377, 1, 0, -50924, 961, 0, 0, 39, '960'),
	(377, 1, 0, -50924, 962, 0, 0, 39, '961'),
	(377, 1, 0, -50924, 963, 0, 0, 39, '962'),
	(377, 1, 0, -50924, 964, 0, 0, 39, '963'),
	(377, 1, 0, -50924, 965, 0, 0, 39, '964'),
	(377, 1, 0, -50924, 966, 0, 0, 39, '965'),
	(377, 1, 0, -50924, 967, 0, 0, 39, '966'),
	(377, 1, 0, -50924, 968, 0, 0, 39, '967'),
	(377, 1, 0, -50924, 969, 0, 0, 39, '968'),
	(377, 1, 0, -50924, 970, 0, 0, 39, '969'),
	(377, 1, 0, -50924, 971, 0, 0, 39, '970'),
	(377, 1, 0, -50924, 972, 0, 0, 39, '971'),
	(377, 1, 0, -50924, 973, 0, 0, 39, '972'),
	(377, 1, 0, -50924, 974, 0, 0, 39, '973'),
	(377, 1, 0, -50924, 975, 0, 0, 39, '974'),
	(377, 1, 0, -50924, 976, 0, 0, 39, '975'),
	(377, 1, 0, -50924, 977, 0, 0, 39, '976'),
	(377, 1, 0, -50924, 978, 0, 0, 39, '977'),
	(377, 1, 0, -50924, 979, 0, 0, 39, '978'),
	(377, 1, 0, -50924, 980, 0, 0, 39, '979'),
	(377, 1, 0, -50924, 981, 0, 0, 39, '980'),
	(377, 1, 0, -50924, 982, 0, 0, 39, '981'),
	(377, 1, 0, -50924, 983, 0, 0, 39, '982'),
	(377, 1, 0, -50924, 984, 0, 0, 39, '983'),
	(377, 1, 0, -50924, 985, 0, 0, 39, '984'),
	(377, 1, 0, -50924, 986, 0, 0, 39, '985'),
	(377, 1, 0, -50924, 987, 0, 0, 39, '986'),
	(377, 1, 0, -50924, 988, 0, 0, 39, '987'),
	(377, 1, 0, -50924, 989, 0, 0, 39, '988'),
	(377, 1, 0, -50924, 990, 0, 0, 39, '989'),
	(377, 1, 0, -50924, 991, 0, 0, 39, '990'),
	(377, 1, 0, -50924, 992, 0, 0, 39, '991'),
	(377, 1, 0, -50924, 993, 0, 0, 39, '992'),
	(377, 1, 0, -50924, 994, 0, 0, 39, '993'),
	(377, 1, 0, -50924, 995, 0, 0, 39, '994'),
	(377, 1, 0, -50924, 996, 0, 0, 39, '995'),
	(377, 1, 0, -50924, 997, 0, 0, 39, '996'),
	(377, 1, 0, -50924, 998, 0, 0, 39, '997'),
	(377, 1, 0, -50924, 999, 0, 0, 39, '998'),
	(377, 1, 0, -50924, 1000, 0, 0, 39, '999'),
	(377, 1, 0, -50924, 1001, 0, 0, 39, '1000'),
	(377, 1, 0, -50924, 1002, 0, 0, 39, '1001'),
	(377, 1, 0, -50924, 1003, 0, 0, 39, '1002'),
	(377, 1, 0, -50924, 1004, 0, 0, 39, '1003'),
	(377, 1, 0, -50924, 1005, 0, 0, 39, '1004'),
	(377, 1, 0, -50924, 1006, 0, 0, 39, '1005'),
	(377, 1, 0, -50924, 1007, 0, 0, 39, '1006'),
	(377, 1, 0, -50924, 1008, 0, 0, 39, '1007'),
	(377, 1, 0, -50924, 1009, 0, 0, 39, '1008'),
	(377, 1, 0, -50924, 1010, 0, 0, 39, '1009'),
	(377, 1, 0, -50924, 1011, 0, 0, 39, '1010'),
	(377, 1, 0, -50924, 1012, 0, 0, 39, '1011'),
	(377, 1, 0, -50924, 1013, 0, 0, 39, '1012'),
	(377, 1, 0, -50924, 1014, 0, 0, 39, '1013'),
	(377, 1, 0, -50924, 1015, 0, 0, 39, '1014'),
	(377, 1, 0, -50924, 1016, 0, 0, 39, '1015'),
	(377, 1, 0, -50924, 1017, 0, 0, 39, '1016'),
	(377, 1, 0, -50924, 1018, 0, 0, 39, '1017'),
	(377, 1, 0, -50924, 1019, 0, 0, 39, '1018'),
	(377, 1, 0, -50924, 1020, 0, 0, 39, '1019'),
	(377, 1, 0, -50924, 1021, 0, 0, 39, '1020'),
	(377, 1, 0, -50924, 1022, 0, 0, 39, '1021'),
	(377, 1, 0, -50924, 1023, 0, 0, 39, '1022'),
	(377, 1, 0, -50924, 1024, 0, 0, 39, '1023'),
	(377, 1, 0, -50924, 1025, 0, 0, 39, '1024'),
	(377, 1, 0, -50924, 1026, 0, 0, 39, '1025'),
	(377, 1, 0, -50924, 1027, 0, 0, 39, '1026'),
	(377, 1, 0, -50924, 1028, 0, 0, 39, '1027'),
	(377, 1, 0, -50924, 1029, 0, 0, 39, '1028'),
	(377, 1, 0, -50924, 1030, 0, 0, 39, '1029'),
	(377, 1, 0, -50924, 1031, 0, 0, 39, '1030'),
	(377, 1, 0, -50924, 1032, 0, 0, 39, '1031'),
	(377, 1, 0, -50924, 1033, 0, 0, 39, '1032'),
	(377, 1, 0, -50924, 1034, 0, 0, 39, '1033'),
	(377, 1, 0, -50924, 1035, 0, 0, 39, '1034'),
	(377, 1, 0, -50924, 1036, 0, 0, 39, '1035'),
	(377, 1, 0, -50924, 1037, 0, 0, 39, '1036'),
	(377, 1, 0, -50924, 1038, 0, 0, 39, '1037'),
	(377, 1, 0, -50924, 1039, 0, 0, 39, '1038'),
	(377, 1, 0, -50924, 1040, 0, 0, 39, '1039'),
	(377, 1, 0, -50924, 1041, 0, 0, 39, '1040'),
	(377, 1, 0, -50924, 1042, 0, 0, 39, '1041'),
	(377, 1, 0, -50924, 1043, 0, 0, 39, '1042'),
	(377, 1, 0, -50924, 1044, 0, 0, 39, '1043'),
	(377, 1, 0, -50924, 1045, 0, 0, 39, '1044'),
	(377, 1, 0, -50924, 1046, 0, 0, 39, '1045'),
	(377, 1, 0, -50924, 1047, 0, 0, 39, '1046'),
	(377, 1, 0, -50924, 1048, 0, 0, 39, '1047'),
	(377, 1, 0, -50924, 1049, 0, 0, 39, '1048'),
	(377, 1, 0, -50924, 1050, 0, 0, 39, '1049'),
	(377, 1, 0, -50924, 1051, 0, 0, 39, '1050'),
	(377, 1, 0, -50924, 1052, 0, 0, 39, '1051'),
	(377, 1, 0, -50924, 1053, 0, 0, 39, '1052'),
	(377, 1, 0, -50924, 1054, 0, 0, 39, '1053'),
	(377, 1, 0, -50924, 1055, 0, 0, 39, '1054'),
	(377, 1, 0, -50924, 1056, 0, 0, 39, '1055'),
	(377, 1, 0, -50924, 1057, 0, 0, 39, '1056'),
	(377, 1, 0, -50924, 1058, 0, 0, 39, '1057'),
	(377, 1, 0, -50924, 1059, 0, 0, 39, '1058'),
	(377, 1, 0, -50924, 1060, 0, 0, 39, '1059'),
	(377, 1, 0, -50924, 1061, 0, 0, 39, '1060'),
	(377, 1, 0, -50924, 1062, 0, 0, 39, '1061'),
	(377, 1, 0, -50924, 1063, 0, 0, 39, '1062'),
	(377, 1, 0, -50924, 1064, 0, 0, 39, '1063'),
	(377, 1, 0, -50924, 1065, 0, 0, 39, '1064'),
	(377, 1, 0, -50924, 1066, 0, 0, 39, '1065'),
	(377, 1, 0, -50924, 1067, 0, 0, 39, '1066'),
	(377, 1, 0, -50924, 1068, 0, 0, 39, '1067'),
	(377, 1, 0, -50924, 1069, 0, 0, 39, '1068'),
	(377, 1, 0, -50924, 1070, 0, 0, 39, '1069'),
	(377, 1, 0, -50924, 1071, 0, 0, 39, '1070'),
	(377, 1, 0, -50924, 1072, 0, 0, 39, '1071'),
	(377, 1, 0, -50924, 1073, 0, 0, 39, '1072'),
	(377, 1, 0, -50924, 1074, 0, 0, 39, '1073'),
	(377, 1, 0, -50924, 1075, 0, 0, 39, '1074'),
	(377, 1, 0, -50924, 1076, 0, 0, 39, '1075'),
	(377, 1, 0, -50924, 1077, 0, 0, 39, '1076'),
	(377, 1, 0, -50924, 1078, 0, 0, 39, '1077'),
	(377, 1, 0, -50924, 1079, 0, 0, 39, '1078'),
	(377, 1, 0, -50924, 1080, 0, 0, 39, '1079'),
	(377, 1, 0, -50924, 1081, 0, 0, 39, '1080'),
	(377, 1, 0, -50924, 1082, 0, 0, 39, '1081'),
	(377, 1, 0, -50924, 1083, 0, 0, 39, '1082'),
	(377, 1, 0, -50924, 1084, 0, 0, 39, '1083'),
	(377, 1, 0, -50924, 1085, 0, 0, 39, '1084'),
	(377, 1, 0, -50924, 1086, 0, 0, 39, '1085'),
	(377, 1, 0, -50924, 1087, 0, 0, 39, '1086'),
	(377, 1, 0, -50924, 1088, 0, 0, 39, '1087'),
	(377, 1, 0, -50924, 1089, 0, 0, 39, '1088'),
	(377, 1, 0, -50924, 1090, 0, 0, 39, '1089'),
	(377, 1, 0, -50924, 1091, 0, 0, 39, '1090'),
	(377, 1, 0, -50924, 1092, 0, 0, 39, '1091'),
	(377, 1, 0, -50924, 1093, 0, 0, 39, '1092'),
	(377, 1, 0, -50924, 1094, 0, 0, 39, '1093'),
	(377, 1, 0, -50924, 1095, 0, 0, 39, '1094'),
	(377, 1, 0, -50924, 1096, 0, 0, 39, '1095'),
	(377, 1, 0, -50924, 1097, 0, 0, 39, '1096'),
	(377, 1, 0, -50924, 1098, 0, 0, 39, '1097'),
	(377, 1, 0, -50924, 1099, 0, 0, 39, '1098'),
	(377, 1, 0, -50924, 1100, 0, 0, 39, '1099'),
	(377, 1, 0, -50924, 1101, 0, 0, 39, '1100'),
	(377, 1, 0, -50924, 1102, 0, 0, 39, '1101'),
	(377, 1, 0, -50924, 1103, 0, 0, 39, '1102'),
	(377, 1, 0, -50924, 1104, 0, 0, 39, '1103'),
	(377, 1, 0, -50924, 1105, 0, 0, 39, '1104'),
	(377, 1, 0, -50924, 1106, 0, 0, 39, '1105'),
	(377, 1, 0, -50924, 1107, 0, 0, 39, '1106'),
	(377, 1, 0, -50924, 1108, 0, 0, 39, '1107'),
	(377, 1, 0, -50924, 1109, 0, 0, 39, '1108'),
	(377, 1, 0, -50924, 1110, 0, 0, 39, '1109'),
	(377, 1, 0, -50924, 1111, 0, 0, 39, '1110'),
	(377, 1, 0, -50924, 1112, 0, 0, 39, '1111'),
	(377, 1, 0, -50924, 1113, 0, 0, 39, '1112'),
	(377, 1, 0, -50924, 1114, 0, 0, 39, '1113'),
	(377, 1, 0, -50924, 1115, 0, 0, 39, '1114'),
	(377, 1, 0, -50924, 1116, 0, 0, 39, '1115'),
	(377, 1, 0, -50924, 1117, 0, 0, 39, '1116'),
	(377, 1, 0, -50924, 1118, 0, 0, 39, '1117'),
	(377, 1, 0, -50924, 1119, 0, 0, 39, '1118'),
	(377, 1, 0, -50924, 1120, 0, 0, 39, '1119'),
	(377, 1, 0, -50924, 1121, 0, 0, 39, '1120'),
	(377, 1, 0, -50924, 1122, 0, 0, 39, '1121'),
	(377, 1, 0, -50924, 1123, 0, 0, 39, '1122'),
	(377, 1, 0, -50924, 1124, 0, 0, 39, '1123'),
	(377, 1, 0, -50924, 1125, 0, 0, 39, '1124'),
	(377, 1, 0, -50924, 1126, 0, 0, 39, '1125'),
	(377, 1, 0, -50924, 1127, 0, 0, 39, '1126'),
	(377, 1, 0, -50924, 1128, 0, 0, 39, '1127'),
	(377, 1, 0, -50924, 1129, 0, 0, 39, '1128'),
	(377, 1, 0, -50924, 1130, 0, 0, 39, '1129'),
	(377, 1, 0, -50924, 1131, 0, 0, 39, '1130'),
	(377, 1, 0, -50924, 1132, 0, 0, 39, '1131'),
	(377, 1, 0, -50924, 1133, 0, 0, 39, '1132'),
	(377, 1, 0, -50924, 1134, 0, 0, 39, '1133'),
	(377, 1, 0, -50924, 1135, 0, 0, 39, '1134'),
	(377, 1, 0, -50924, 1136, 0, 0, 39, '1135'),
	(377, 1, 0, -50924, 1137, 0, 0, 39, '1136'),
	(377, 1, 0, -50924, 1138, 0, 0, 39, '1137'),
	(377, 1, 0, -50924, 1139, 0, 0, 39, '1138'),
	(377, 1, 0, -50924, 1140, 0, 0, 39, '1139'),
	(377, 1, 0, -50924, 1141, 0, 0, 39, '1140'),
	(377, 1, 0, -50924, 1142, 0, 0, 39, '1141'),
	(377, 1, 0, -50924, 1143, 0, 0, 39, '1142'),
	(377, 1, 0, -50924, 1144, 0, 0, 39, '1143'),
	(377, 1, 0, -50924, 1145, 0, 0, 39, '1144'),
	(377, 1, 0, -50924, 1146, 0, 0, 39, '1145'),
	(377, 1, 0, -50924, 1147, 0, 0, 39, '1146'),
	(377, 1, 0, -50924, 1148, 0, 0, 39, '1147'),
	(377, 1, 0, -50924, 1149, 0, 0, 39, '1148'),
	(377, 1, 0, -50924, 1150, 0, 0, 39, '1149'),
	(377, 1, 0, -50924, 1151, 0, 0, 39, '1150'),
	(377, 1, 0, -50924, 1152, 0, 0, 39, '1151'),
	(377, 1, 0, -50924, 1153, 0, 0, 39, '1152'),
	(377, 1, 0, -50924, 1154, 0, 0, 39, '1153'),
	(377, 1, 0, -50924, 1155, 0, 0, 39, '1154'),
	(377, 1, 0, -50924, 1156, 0, 0, 39, '1155'),
	(377, 1, 0, -50924, 1157, 0, 0, 39, '1156'),
	(377, 1, 0, -50924, 1158, 0, 0, 39, '1157'),
	(377, 1, 0, -50924, 1159, 0, 0, 39, '1158'),
	(377, 1, 0, -50924, 1160, 0, 0, 39, '1159'),
	(377, 1, 0, -50924, 1161, 0, 0, 39, '1160'),
	(377, 1, 0, -50924, 1162, 0, 0, 39, '1161'),
	(377, 1, 0, -50924, 1163, 0, 0, 39, '1162'),
	(377, 1, 0, -50924, 1164, 0, 0, 39, '1163'),
	(377, 1, 0, -50924, 1165, 0, 0, 39, '1164'),
	(377, 1, 0, -50924, 1166, 0, 0, 39, '1165'),
	(377, 1, 0, -50924, 1167, 0, 0, 39, '1166'),
	(377, 1, 0, -50924, 1168, 0, 0, 39, '1167'),
	(377, 1, 0, -50924, 1169, 0, 0, 39, '1168'),
	(377, 1, 0, -50924, 1170, 0, 0, 39, '1169'),
	(377, 1, 0, -50924, 1171, 0, 0, 39, '1170'),
	(377, 1, 0, -50924, 1172, 0, 0, 39, '1171'),
	(377, 1, 0, -50924, 1173, 0, 0, 39, '1172'),
	(377, 1, 0, -50924, 1174, 0, 0, 39, '1173'),
	(377, 1, 0, -50924, 1175, 0, 0, 39, '1174'),
	(377, 1, 0, -50924, 1176, 0, 0, 39, '1175'),
	(377, 1, 0, -50924, 1177, 0, 0, 39, '1176'),
	(377, 1, 0, -50924, 1178, 0, 0, 39, '1177'),
	(377, 1, 0, -50924, 1179, 0, 0, 39, '1178'),
	(377, 1, 0, -50924, 1180, 0, 0, 39, '1179'),
	(377, 1, 0, -50924, 1181, 0, 0, 39, '1180'),
	(377, 1, 0, -50924, 1182, 0, 0, 39, '1181'),
	(377, 1, 0, -50924, 1183, 0, 0, 39, '1182'),
	(377, 1, 0, -50924, 1184, 0, 0, 39, '1183'),
	(377, 1, 0, -50924, 1185, 0, 0, 39, '1184'),
	(377, 1, 0, -50924, 1186, 0, 0, 39, '1185'),
	(377, 1, 0, -50924, 1187, 0, 0, 39, '1186'),
	(377, 1, 0, -50924, 1188, 0, 0, 39, '1187'),
	(377, 1, 0, -50924, 1189, 0, 0, 39, '1188'),
	(377, 1, 0, -50924, 1190, 0, 0, 39, '1189'),
	(377, 1, 0, -50924, 1191, 0, 0, 39, '1190'),
	(377, 1, 0, -50924, 1192, 0, 0, 39, '1191'),
	(377, 1, 0, -50924, 1193, 0, 0, 39, '1192'),
	(377, 1, 0, -50924, 1194, 0, 0, 39, '1193'),
	(377, 1, 0, -50924, 1195, 0, 0, 39, '1194'),
	(377, 1, 0, -50924, 1196, 0, 0, 39, '1195'),
	(377, 1, 0, -50924, 1197, 0, 0, 39, '1196'),
	(377, 1, 0, -50924, 1198, 0, 0, 39, '1197'),
	(377, 1, 0, -50924, 1199, 0, 0, 39, '1198'),
	(377, 1, 0, -50924, 1200, 0, 0, 39, '1199'),
	(377, 1, 0, -50924, 1201, 0, 0, 39, '1200'),
	(377, 1, 0, -50924, 1202, 0, 0, 39, '1201'),
	(377, 1, 0, -50924, 1203, 0, 0, 39, '1202'),
	(377, 1, 0, -50924, 1204, 0, 0, 39, '1203'),
	(377, 1, 0, -50924, 1205, 0, 0, 39, '1204'),
	(377, 1, 0, -50924, 1206, 0, 0, 39, '1205'),
	(377, 1, 0, -50924, 1207, 0, 0, 39, '1206'),
	(377, 1, 0, -50924, 1208, 0, 0, 39, '1207'),
	(377, 1, 0, -50924, 1209, 0, 0, 39, '1208'),
	(377, 1, 0, -50924, 1210, 0, 0, 39, '1209'),
	(377, 1, 0, -50924, 1211, 0, 0, 39, '1210'),
	(377, 1, 0, -50924, 1212, 0, 0, 39, '1211'),
	(377, 1, 0, -50924, 1213, 0, 0, 39, '1212'),
	(377, 1, 0, -50924, 1214, 0, 0, 39, '1213'),
	(377, 1, 0, -50924, 1215, 0, 0, 39, '1214'),
	(377, 1, 0, -50924, 1216, 0, 0, 39, '1215'),
	(377, 1, 0, -50924, 1217, 0, 0, 39, '1216'),
	(377, 1, 0, -50924, 1218, 0, 0, 39, '1217'),
	(377, 1, 0, -50924, 1219, 0, 0, 39, '1218'),
	(377, 1, 0, -50924, 1220, 0, 0, 39, '1219'),
	(377, 1, 0, -50924, 1221, 0, 0, 39, '1220'),
	(377, 1, 0, -50924, 1222, 0, 0, 39, '1221'),
	(377, 1, 0, -50924, 1223, 0, 0, 39, '1222'),
	(377, 1, 0, -50924, 1224, 0, 0, 39, '1223'),
	(377, 1, 0, -50924, 1225, 0, 0, 39, '1224'),
	(377, 1, 0, -50924, 1226, 0, 0, 39, '1225'),
	(377, 1, 0, -50924, 1227, 0, 0, 39, '1226'),
	(377, 1, 0, -50924, 1228, 0, 0, 39, '1227'),
	(377, 1, 0, -50924, 1229, 0, 0, 39, '1228'),
	(377, 1, 0, -50924, 1230, 0, 0, 39, '1229'),
	(377, 1, 0, -50924, 1231, 0, 0, 39, '1230'),
	(377, 1, 0, -50924, 1232, 0, 0, 39, '1231'),
	(377, 1, 0, -50924, 1233, 0, 0, 39, '1232'),
	(377, 1, 0, -50924, 1234, 0, 0, 39, '1233'),
	(377, 1, 0, -50924, 1235, 0, 0, 39, '1234'),
	(377, 1, 0, -50924, 1236, 0, 0, 39, '1235'),
	(377, 1, 0, -50924, 1237, 0, 0, 39, '1236'),
	(377, 1, 0, -50924, 1238, 0, 0, 39, '1237'),
	(377, 1, 0, -50924, 1239, 0, 0, 39, '1238'),
	(377, 1, 0, -50924, 1240, 0, 0, 39, '1239'),
	(377, 1, 0, -50924, 1241, 0, 0, 39, '1240'),
	(377, 1, 0, -50924, 1242, 0, 0, 39, '1241'),
	(377, 1, 0, -50924, 1243, 0, 0, 39, '1242'),
	(377, 1, 0, -50924, 1244, 0, 0, 39, '1243'),
	(377, 1, 0, -50924, 1245, 0, 0, 39, '1244'),
	(377, 1, 0, -50924, 1246, 0, 0, 39, '1245'),
	(377, 1, 0, -50924, 1247, 0, 0, 39, '1246'),
	(377, 1, 0, -50924, 1248, 0, 0, 39, '1247'),
	(377, 1, 0, -50924, 1249, 0, 0, 39, '1248'),
	(377, 1, 0, -50924, 1250, 0, 0, 39, '1249'),
	(377, 1, 0, -50924, 1251, 0, 0, 39, '1250'),
	(377, 1, 0, -50924, 1252, 0, 0, 39, '1251'),
	(377, 1, 0, -50924, 1253, 0, 0, 39, '1252'),
	(377, 1, 0, -50924, 1254, 0, 0, 39, '1253'),
	(377, 1, 0, -50924, 1255, 0, 0, 39, '1254'),
	(377, 1, 0, -50924, 1256, 0, 0, 39, '1255'),
	(377, 1, 0, -50924, 1257, 0, 0, 39, '1256'),
	(377, 1, 0, -50924, 1258, 0, 0, 39, '1257'),
	(377, 1, 0, -50924, 1259, 0, 0, 39, '1258'),
	(377, 1, 0, -50924, 1260, 0, 0, 39, '1259'),
	(377, 1, 0, -50924, 1261, 0, 0, 39, '1260'),
	(377, 1, 0, -50924, 1262, 0, 0, 39, '1261'),
	(377, 1, 0, -50924, 1263, 0, 0, 39, '1262'),
	(377, 1, 0, -50924, 1264, 0, 0, 39, '1263'),
	(377, 1, 0, -50924, 1265, 0, 0, 39, '1264'),
	(377, 1, 0, -50924, 1266, 0, 0, 39, '1265'),
	(377, 1, 0, -50924, 1267, 0, 0, 39, '1266'),
	(377, 1, 0, -50924, 1268, 0, 0, 39, '1267'),
	(377, 1, 0, -50924, 1269, 0, 0, 39, '1268'),
	(377, 1, 0, -50924, 1270, 0, 0, 39, '1269'),
	(377, 1, 0, -50924, 1271, 0, 0, 39, '1270'),
	(377, 1, 0, -50924, 1272, 0, 0, 39, '1271'),
	(377, 1, 0, -50924, 1273, 0, 0, 39, '1272'),
	(377, 1, 0, -50924, 1274, 0, 0, 39, '1273'),
	(377, 1, 0, -50924, 1275, 0, 0, 39, '1274'),
	(377, 1, 0, -50924, 1276, 0, 0, 39, '1275'),
	(377, 1, 0, -50924, 1277, 0, 0, 39, '1276'),
	(377, 1, 0, -50924, 1278, 0, 0, 39, '1277'),
	(377, 1, 0, -50924, 1279, 0, 0, 39, '1278'),
	(377, 1, 0, -50924, 1280, 0, 0, 39, '1279'),
	(377, 1, 0, -50924, 1281, 0, 0, 39, '1280'),
	(377, 1, 0, -50924, 1282, 0, 0, 39, '1281'),
	(377, 1, 0, -50924, 1283, 0, 0, 39, '1282'),
	(377, 1, 0, -50924, 1284, 0, 0, 39, '1283'),
	(377, 1, 0, -50924, 1285, 0, 0, 39, '1284'),
	(377, 1, 0, -50924, 1286, 0, 0, 39, '1285'),
	(377, 1, 0, -50924, 1287, 0, 0, 39, '1286'),
	(377, 1, 0, -50924, 1288, 0, 0, 39, '1287'),
	(377, 1, 0, -50924, 1289, 0, 0, 39, '1288'),
	(377, 1, 0, -50924, 1290, 0, 0, 39, '1289'),
	(377, 1, 0, -50924, 1291, 0, 0, 39, '1290'),
	(377, 1, 0, -50924, 1292, 0, 0, 39, '1291'),
	(377, 1, 0, -50924, 1293, 0, 0, 39, '1292'),
	(377, 1, 0, -50924, 1294, 0, 0, 39, '1293'),
	(377, 1, 0, -50924, 1295, 0, 0, 39, '1294'),
	(377, 1, 0, -50924, 1296, 0, 0, 39, '1295'),
	(377, 1, 0, -50924, 1297, 0, 0, 39, '1296'),
	(377, 1, 0, -50924, 1298, 0, 0, 39, '1297'),
	(377, 1, 0, -50924, 1299, 0, 0, 39, '1298'),
	(377, 1, 0, -50924, 1300, 0, 0, 39, '1299'),
	(377, 1, 0, -50924, 1301, 0, 0, 39, '1300'),
	(377, 1, 0, -50924, 1302, 0, 0, 39, '1301'),
	(377, 1, 0, -50924, 1303, 0, 0, 39, '1302'),
	(377, 1, 0, -50924, 1304, 0, 0, 39, '1303'),
	(377, 1, 0, -50924, 1305, 0, 0, 39, '1304'),
	(377, 1, 0, -50924, 1306, 0, 0, 39, '1305'),
	(377, 1, 0, -50924, 1307, 0, 0, 39, '1306'),
	(377, 1, 0, -50924, 1308, 0, 0, 39, '1307'),
	(377, 1, 0, -50924, 1309, 0, 0, 39, '1308'),
	(377, 1, 0, -50924, 1310, 0, 0, 39, '1309'),
	(377, 1, 0, -50924, 1311, 0, 0, 39, '1310'),
	(377, 1, 0, -50924, 1312, 0, 0, 39, '1311'),
	(377, 1, 0, -50924, 1313, 0, 0, 39, '1312'),
	(377, 1, 0, -50924, 1314, 0, 0, 39, '1313'),
	(377, 1, 0, -50924, 1315, 0, 0, 39, '1314'),
	(377, 1, 0, -50924, 1316, 0, 0, 39, '1315'),
	(377, 1, 0, -50924, 1317, 0, 0, 39, '1316'),
	(377, 1, 0, -50924, 1318, 0, 0, 39, '1317'),
	(377, 1, 0, -50924, 1319, 0, 0, 39, '1318'),
	(377, 1, 0, -50924, 1320, 0, 0, 39, '1319'),
	(377, 1, 0, -50924, 1321, 0, 0, 39, '1320'),
	(377, 1, 0, -50924, 1322, 0, 0, 39, '1321'),
	(377, 1, 0, -50924, 1323, 0, 0, 39, '1322'),
	(377, 1, 0, -50924, 1324, 0, 0, 39, '1323'),
	(377, 1, 0, -50924, 1325, 0, 0, 39, '1324'),
	(377, 1, 0, -50924, 1326, 0, 0, 39, '1325'),
	(377, 1, 0, -50924, 1327, 0, 0, 39, '1326'),
	(377, 1, 0, -50924, 1328, 0, 0, 39, '1327'),
	(377, 1, 0, -50924, 1329, 0, 0, 39, '1328'),
	(377, 1, 0, -50924, 1330, 0, 0, 39, '1329'),
	(377, 1, 0, -50924, 1331, 0, 0, 39, '1330'),
	(377, 1, 0, -50924, 1332, 0, 0, 39, '1331'),
	(377, 1, 0, -50924, 1333, 0, 0, 39, '1332'),
	(377, 1, 0, -50924, 1334, 0, 0, 39, '1333'),
	(377, 1, 0, -50924, 1335, 0, 0, 39, '1334'),
	(377, 1, 0, -50924, 1336, 0, 0, 39, '1335'),
	(377, 1, 0, -50924, 1337, 0, 0, 39, '1336'),
	(377, 1, 0, -50924, 1338, 0, 0, 39, '1337'),
	(377, 1, 0, -50924, 1339, 0, 0, 39, '1338'),
	(377, 1, 0, -50924, 1340, 0, 0, 39, '1339'),
	(377, 1, 0, -50924, 1341, 0, 0, 39, '1340'),
	(377, 1, 0, -50924, 1342, 0, 0, 39, '1341'),
	(377, 1, 0, -50924, 1343, 0, 0, 39, '1342'),
	(377, 1, 0, -50924, 1344, 0, 0, 39, '1343'),
	(377, 1, 0, -50924, 1345, 0, 0, 39, '1344'),
	(377, 1, 0, -50924, 1346, 0, 0, 39, '1345'),
	(377, 1, 0, -50924, 1347, 0, 0, 39, '1346'),
	(377, 1, 0, -50924, 1348, 0, 0, 39, '1347'),
	(377, 1, 0, -50924, 1349, 0, 0, 39, '1348'),
	(377, 1, 0, -50924, 1350, 0, 0, 39, '1349'),
	(377, 1, 0, -50924, 1351, 0, 0, 39, '1350'),
	(377, 1, 0, -50924, 1352, 0, 0, 39, '1351'),
	(377, 1, 0, -50924, 1353, 0, 0, 39, '1352'),
	(377, 1, 0, -50924, 1354, 0, 0, 39, '1353'),
	(377, 1, 0, -50924, 1355, 0, 0, 39, '1354'),
	(377, 1, 0, -50924, 1356, 0, 0, 39, '1355'),
	(377, 1, 0, -50924, 1357, 0, 0, 39, '1356'),
	(377, 1, 0, -50924, 1358, 0, 0, 39, '1357'),
	(377, 1, 0, -50924, 1359, 0, 0, 39, '1358'),
	(377, 1, 0, -50924, 1360, 0, 0, 39, '1359'),
	(377, 1, 0, -50924, 1361, 0, 0, 39, '1360'),
	(377, 1, 0, -50924, 1362, 0, 0, 39, '1361'),
	(377, 1, 0, -50924, 1363, 0, 0, 39, '1362'),
	(377, 1, 0, -50924, 1364, 0, 0, 39, '1363'),
	(377, 1, 0, -50924, 1365, 0, 0, 39, '1364'),
	(377, 1, 0, -50924, 1366, 0, 0, 39, '1365'),
	(377, 1, 0, -50924, 1367, 0, 0, 39, '1366'),
	(377, 1, 0, -50924, 1368, 0, 0, 39, '1367'),
	(377, 1, 0, -50924, 1369, 0, 0, 39, '1368'),
	(377, 1, 0, -50924, 1370, 0, 0, 39, '1369'),
	(377, 1, 0, -50924, 1371, 0, 0, 39, '1370'),
	(377, 1, 0, -50924, 1372, 0, 0, 39, '1371'),
	(377, 1, 0, -50924, 1373, 0, 0, 39, '1372'),
	(377, 1, 0, -50924, 1374, 0, 0, 39, '1373'),
	(377, 1, 0, -50924, 1375, 0, 0, 39, '1374'),
	(377, 1, 0, -50924, 1376, 0, 0, 39, '1375'),
	(377, 1, 0, -50924, 1377, 0, 0, 39, '1376'),
	(377, 1, 0, -50924, 1378, 0, 0, 39, '1377'),
	(377, 1, 0, -50924, 1379, 0, 0, 39, '1378'),
	(377, 1, 0, -50924, 1380, 0, 0, 39, '1379'),
	(377, 1, 0, -50924, 1381, 0, 0, 39, '1380'),
	(377, 1, 0, -50924, 1382, 0, 0, 39, '1381'),
	(377, 1, 0, -50924, 1383, 0, 0, 39, '1382'),
	(377, 1, 0, -50924, 1384, 0, 0, 39, '1383'),
	(377, 1, 0, -50924, 1385, 0, 0, 39, '1384'),
	(377, 1, 0, -50924, 1386, 0, 0, 39, '1385'),
	(377, 1, 0, -50924, 1387, 0, 0, 39, '1386'),
	(377, 1, 0, -50924, 1388, 0, 0, 39, '1387'),
	(377, 1, 0, -50924, 1389, 0, 0, 39, '1388'),
	(377, 1, 0, -50924, 1390, 0, 0, 39, '1389'),
	(377, 1, 0, -50924, 1391, 0, 0, 39, '1390'),
	(377, 1, 0, -50924, 1392, 0, 0, 39, '1391'),
	(377, 1, 0, -50924, 1393, 0, 0, 39, '1392'),
	(377, 1, 0, -50924, 1394, 0, 0, 39, '1393'),
	(377, 1, 0, -50924, 1395, 0, 0, 39, '1394'),
	(377, 1, 0, -50924, 1396, 0, 0, 39, '1395'),
	(377, 1, 0, -50924, 1397, 0, 0, 39, '1396'),
	(377, 1, 0, -50924, 1398, 0, 0, 39, '1397'),
	(377, 1, 0, -50924, 1399, 0, 0, 39, '1398'),
	(377, 1, 0, -50924, 1400, 0, 0, 39, '1399'),
	(377, 1, 0, -50924, 1401, 0, 0, 39, '1400'),
	(377, 1, 0, -50924, 1402, 0, 0, 39, '1401'),
	(377, 1, 0, -50924, 1403, 0, 0, 39, '1402'),
	(377, 1, 0, -50924, 1404, 0, 0, 39, '1403'),
	(377, 1, 0, -50924, 1405, 0, 0, 39, '1404'),
	(377, 1, 0, -50924, 1406, 0, 0, 39, '1405'),
	(377, 1, 0, -50924, 1407, 0, 0, 39, '1406'),
	(377, 1, 0, -50924, 1408, 0, 0, 39, '1407'),
	(377, 1, 0, -50924, 1409, 0, 0, 39, '1408'),
	(377, 1, 0, -50924, 1410, 0, 0, 39, '1409'),
	(377, 1, 0, -50924, 1411, 0, 0, 39, '1410'),
	(377, 1, 0, -50924, 1412, 0, 0, 39, '1411'),
	(377, 1, 0, -50924, 1413, 0, 0, 39, '1412'),
	(377, 1, 0, -50924, 1414, 0, 0, 39, '1413'),
	(377, 1, 0, -50924, 1415, 0, 0, 39, '1414'),
	(377, 1, 0, -50924, 1416, 0, 0, 39, '1415'),
	(377, 1, 0, -50924, 1417, 0, 0, 39, '1416'),
	(377, 1, 0, -50924, 1418, 0, 0, 39, '1417'),
	(377, 1, 0, -50924, 1419, 0, 0, 39, '1418'),
	(377, 1, 0, -50924, 1420, 0, 0, 39, '1419'),
	(377, 1, 0, -50924, 1421, 0, 0, 39, '1420'),
	(377, 1, 0, -50924, 1422, 0, 0, 39, '1421'),
	(377, 1, 0, -50924, 1423, 0, 0, 39, '1422'),
	(377, 1, 0, -50924, 1424, 0, 0, 39, '1423'),
	(377, 1, 0, -50924, 1425, 0, 0, 39, '1424'),
	(377, 1, 0, -50924, 1426, 0, 0, 39, '1425'),
	(377, 1, 0, -50924, 1427, 0, 0, 39, '1426'),
	(377, 1, 0, -50924, 1428, 0, 0, 39, '1427'),
	(377, 1, 0, -50924, 1429, 0, 0, 39, '1428'),
	(377, 1, 0, -50924, 1430, 0, 0, 39, '1429'),
	(377, 1, 0, -50924, 1431, 0, 0, 39, '1430'),
	(377, 1, 0, -50924, 1432, 0, 0, 39, '1431'),
	(377, 1, 0, -50924, 1433, 0, 0, 39, '1432'),
	(377, 1, 0, -50924, 1434, 0, 0, 39, '1433'),
	(377, 1, 0, -50924, 1435, 0, 0, 39, '1434'),
	(377, 1, 0, -50924, 1436, 0, 0, 39, '1435'),
	(377, 1, 0, -50924, 1437, 0, 0, 39, '1436'),
	(377, 1, 0, -50924, 1438, 0, 0, 39, '1437'),
	(377, 1, 0, -50924, 1439, 0, 0, 39, '1438'),
	(377, 1, 0, -50924, 1440, 0, 0, 39, '1439'),
	(377, 1, 0, -50924, 1441, 0, 0, 39, '1440'),
	(377, 1, 0, -50924, 1442, 0, 0, 39, '1441'),
	(377, 1, 0, -50924, 1443, 0, 0, 39, '1442'),
	(377, 1, 0, -50924, 1444, 0, 0, 39, '1443'),
	(377, 1, 0, -50924, 1445, 0, 0, 39, '1444'),
	(377, 1, 0, -50924, 1446, 0, 0, 39, '1445'),
	(377, 1, 0, -50924, 1447, 0, 0, 39, '1446'),
	(377, 1, 0, -50924, 1448, 0, 0, 39, '1447'),
	(377, 1, 0, -50924, 1449, 0, 0, 39, '1448'),
	(377, 1, 0, -50924, 1450, 0, 0, 39, '1449'),
	(377, 1, 0, -50924, 1451, 0, 0, 39, '1450'),
	(377, 1, 0, -50924, 1452, 0, 0, 39, '1451'),
	(377, 1, 0, -50924, 1453, 0, 0, 39, '1452'),
	(377, 1, 0, -50924, 1454, 0, 0, 39, '1453'),
	(377, 1, 0, -50924, 1455, 0, 0, 39, '1454'),
	(377, 1, 0, -50924, 1456, 0, 0, 39, '1455'),
	(377, 1, 0, -50924, 1457, 0, 0, 39, '1456'),
	(377, 1, 0, -50924, 1458, 0, 0, 39, '1457'),
	(377, 1, 0, -50924, 1459, 0, 0, 39, '1458'),
	(377, 1, 0, -50924, 1460, 0, 0, 39, '1459'),
	(377, 1, 0, -50924, 1461, 0, 0, 39, '1460'),
	(377, 1, 0, -50924, 1462, 0, 0, 39, '1461'),
	(377, 1, 0, -50924, 1463, 0, 0, 39, '1462'),
	(377, 1, 0, -50924, 1464, 0, 0, 39, '1463'),
	(377, 1, 0, -50924, 1465, 0, 0, 39, '1464'),
	(377, 1, 0, -50924, 1466, 0, 0, 39, '1465'),
	(377, 1, 0, -50924, 1467, 0, 0, 39, '1466'),
	(377, 1, 0, -50924, 1468, 0, 0, 39, '1467'),
	(377, 1, 0, -50924, 1469, 0, 0, 39, '1468'),
	(377, 1, 0, -50924, 1470, 0, 0, 39, '1469'),
	(377, 1, 0, -50924, 1471, 0, 0, 39, '1470'),
	(377, 1, 0, -50924, 1472, 0, 0, 39, '1471'),
	(377, 1, 0, -50924, 1473, 0, 0, 39, '1472'),
	(377, 1, 0, -50924, 1474, 0, 0, 39, '1473'),
	(377, 1, 0, -50924, 1475, 0, 0, 39, '1474'),
	(377, 1, 0, -50924, 1476, 0, 0, 39, '1475'),
	(377, 1, 0, -50924, 1477, 0, 0, 39, '1476'),
	(377, 1, 0, -50924, 1478, 0, 0, 39, '1477'),
	(377, 1, 0, -50924, 1479, 0, 0, 39, '1478'),
	(377, 1, 0, -50924, 1480, 0, 0, 39, '1479'),
	(377, 1, 0, -50924, 1481, 0, 0, 39, '1480'),
	(377, 1, 0, -50924, 1482, 0, 0, 39, '1481'),
	(377, 1, 0, -50924, 1483, 0, 0, 39, '1482'),
	(377, 1, 0, -50924, 1484, 0, 0, 39, '1483'),
	(377, 1, 0, -50924, 1485, 0, 0, 39, '1484'),
	(377, 1, 0, -50924, 1486, 0, 0, 39, '1485'),
	(377, 1, 0, -50924, 1487, 0, 0, 39, '1486'),
	(377, 1, 0, -50924, 1488, 0, 0, 39, '1487'),
	(377, 1, 0, -50924, 1489, 0, 0, 39, '1488'),
	(377, 1, 0, -50924, 1490, 0, 0, 39, '1489'),
	(377, 1, 0, -50924, 1491, 0, 0, 39, '1490'),
	(377, 1, 0, -50924, 1492, 0, 0, 39, '1491'),
	(377, 1, 0, -50924, 1493, 0, 0, 39, '1492'),
	(377, 1, 0, -50924, 1494, 0, 0, 39, '1493'),
	(377, 1, 0, -50924, 1495, 0, 0, 39, '1494'),
	(377, 1, 0, -50924, 1496, 0, 0, 39, '1495'),
	(377, 1, 0, -50924, 1497, 0, 0, 39, '1496'),
	(377, 1, 0, -50924, 1498, 0, 0, 39, '1497'),
	(377, 1, 0, -50924, 1499, 0, 0, 39, '1498'),
	(377, 1, 0, -50924, 1500, 0, 0, 39, '1499'),
	(377, 1, 0, -50924, 1501, 0, 0, 39, '1500'),
	(377, 1, 0, -50924, 1502, 0, 0, 39, '1501'),
	(377, 1, 0, -50924, 1503, 0, 0, 39, '1502'),
	(377, 1, 0, -50924, 1504, 0, 0, 39, '1503'),
	(377, 1, 0, -50924, 1505, 0, 0, 39, '1504'),
	(377, 1, 0, -50924, 1506, 0, 0, 39, '1505'),
	(377, 1, 0, -50924, 1507, 0, 0, 39, '1506'),
	(377, 1, 0, -50924, 1508, 0, 0, 39, '1507'),
	(377, 1, 0, -50924, 1509, 0, 0, 39, '1508'),
	(377, 1, 0, -50924, 1510, 0, 0, 39, '1509'),
	(377, 1, 0, -50924, 1511, 0, 0, 39, '1510'),
	(377, 1, 0, -50924, 1512, 0, 0, 39, '1511'),
	(377, 1, 0, -50924, 1513, 0, 0, 39, '1512'),
	(377, 1, 0, -50924, 1514, 0, 0, 39, '1513'),
	(377, 1, 0, -50924, 1515, 0, 0, 39, '1514'),
	(377, 1, 0, -50924, 1516, 0, 0, 39, '1515'),
	(377, 1, 0, -50924, 1517, 0, 0, 39, '1516'),
	(377, 1, 0, -50924, 1518, 0, 0, 39, '1517'),
	(377, 1, 0, -50924, 1519, 0, 0, 39, '1518'),
	(377, 1, 0, -50924, 1520, 0, 0, 39, '1519'),
	(377, 1, 0, -50924, 1521, 0, 0, 39, '1520'),
	(377, 1, 0, -50924, 1522, 0, 0, 39, '1521'),
	(377, 1, 0, -50924, 1523, 0, 0, 39, '1522'),
	(377, 1, 0, -50924, 1524, 0, 0, 39, '1523'),
	(377, 1, 0, -50924, 1525, 0, 0, 39, '1524'),
	(377, 1, 0, -50924, 1526, 0, 0, 39, '1525'),
	(377, 1, 0, -50924, 1527, 0, 0, 39, '1526'),
	(377, 1, 0, -50924, 1528, 0, 0, 39, '1527'),
	(377, 1, 0, -50924, 1529, 0, 0, 39, '1528'),
	(377, 1, 0, -50924, 1530, 0, 0, 39, '1529'),
	(377, 1, 0, -50924, 1531, 0, 0, 39, '1530'),
	(377, 1, 0, -50924, 1532, 0, 0, 39, '1531'),
	(377, 1, 0, -50924, 1533, 0, 0, 39, '1532'),
	(377, 1, 0, -50924, 1534, 0, 0, 39, '1533'),
	(377, 1, 0, -50924, 1535, 0, 0, 39, '1534'),
	(377, 1, 0, -50924, 1536, 0, 0, 39, '1535'),
	(377, 1, 0, -50924, 1537, 0, 0, 39, '1536'),
	(377, 1, 0, -50924, 1538, 0, 0, 39, '1537'),
	(377, 1, 0, -50924, 1539, 0, 0, 39, '1538'),
	(377, 1, 0, -50924, 1540, 0, 0, 39, '1539'),
	(377, 1, 0, -50924, 1541, 0, 0, 39, '1540'),
	(377, 1, 0, -50924, 1542, 0, 0, 39, '1541'),
	(377, 1, 0, -50924, 1543, 0, 0, 39, '1542'),
	(377, 1, 0, -50924, 1544, 0, 0, 39, '1543'),
	(377, 1, 0, -50924, 1545, 0, 0, 39, '1544'),
	(377, 1, 0, -50924, 1546, 0, 0, 39, '1545'),
	(377, 1, 0, -50924, 1547, 0, 0, 39, '1546'),
	(377, 1, 0, -50924, 1548, 0, 0, 39, '1547'),
	(377, 1, 0, -50924, 1549, 0, 0, 39, '1548'),
	(377, 1, 0, -50924, 1550, 0, 0, 39, '1549'),
	(377, 1, 0, -50924, 1551, 0, 0, 39, '1550'),
	(377, 1, 0, -50924, 1552, 0, 0, 39, '1551'),
	(377, 1, 0, -50924, 1553, 0, 0, 39, '1552'),
	(377, 1, 0, -50924, 1554, 0, 0, 39, '1553'),
	(377, 1, 0, -50924, 1555, 0, 0, 39, '1554'),
	(377, 1, 0, -50924, 1556, 0, 0, 39, '1555'),
	(377, 1, 0, -50924, 1557, 0, 0, 39, '1556'),
	(377, 1, 0, -50924, 1558, 0, 0, 39, '1557'),
	(377, 1, 0, -50924, 1559, 0, 0, 39, '1558'),
	(377, 1, 0, -50924, 1560, 0, 0, 39, '1559'),
	(377, 1, 0, -50924, 1561, 0, 0, 39, '1560'),
	(377, 1, 0, -50924, 1562, 0, 0, 39, '1561'),
	(377, 1, 0, -50924, 1563, 0, 0, 39, '1562'),
	(377, 1, 0, -50924, 1564, 0, 0, 39, '1563'),
	(377, 1, 0, -50924, 1565, 0, 0, 39, '1564'),
	(377, 1, 0, -50924, 1566, 0, 0, 39, '1565'),
	(377, 1, 0, -50924, 1567, 0, 0, 39, '1566'),
	(377, 1, 0, -50924, 1568, 0, 0, 39, '1567'),
	(377, 1, 0, -50924, 1569, 0, 0, 39, '1568'),
	(377, 1, 0, -50924, 1570, 0, 0, 39, '1569'),
	(377, 1, 0, -50924, 1571, 0, 0, 39, '1570'),
	(377, 1, 0, -50924, 1572, 0, 0, 39, '1571'),
	(377, 1, 0, -50924, 1573, 0, 0, 39, '1572'),
	(377, 1, 0, -50924, 1574, 0, 0, 39, '1573'),
	(377, 1, 0, -50924, 1575, 0, 0, 39, '1574'),
	(377, 1, 0, -50924, 1576, 0, 0, 39, '1575'),
	(377, 1, 0, -50924, 1577, 0, 0, 39, '1576'),
	(377, 1, 0, -50924, 1578, 0, 0, 39, '1577'),
	(377, 1, 0, -50924, 1579, 0, 0, 39, '1578'),
	(377, 1, 0, -50924, 1580, 0, 0, 39, '1579'),
	(377, 1, 0, -50924, 1581, 0, 0, 39, '1580'),
	(377, 1, 0, -50924, 1582, 0, 0, 39, '1581'),
	(377, 1, 0, -50924, 1583, 0, 0, 39, '1582'),
	(377, 1, 0, -50924, 1584, 0, 0, 39, '1583'),
	(377, 1, 0, -50924, 1585, 0, 0, 39, '1584'),
	(377, 1, 0, -50924, 1586, 0, 0, 39, '1585'),
	(377, 1, 0, -50924, 1587, 0, 0, 39, '1586'),
	(377, 1, 0, -50924, 1588, 0, 0, 39, '1587'),
	(377, 1, 0, -50924, 1589, 0, 0, 39, '1588'),
	(377, 1, 0, -50924, 1590, 0, 0, 39, '1589'),
	(377, 1, 0, -50924, 1591, 0, 0, 39, '1590'),
	(377, 1, 0, -50924, 1592, 0, 0, 39, '1591'),
	(377, 1, 0, -50924, 1593, 0, 0, 39, '1592'),
	(377, 1, 0, -50924, 1594, 0, 0, 39, '1593'),
	(377, 1, 0, -50924, 1595, 0, 0, 39, '1594'),
	(377, 1, 0, -50924, 1596, 0, 0, 39, '1595'),
	(377, 1, 0, -50924, 1597, 0, 0, 39, '1596'),
	(377, 1, 0, -50924, 1598, 0, 0, 39, '1597'),
	(377, 1, 0, -50924, 1599, 0, 0, 39, '1598'),
	(377, 1, 0, -50924, 1600, 0, 0, 39, '1599'),
	(377, 1, 0, -50924, 1601, 0, 0, 39, '1600'),
	(377, 1, 0, -50924, 1602, 0, 0, 39, '1601'),
	(377, 1, 0, -50924, 1603, 0, 0, 39, '1602'),
	(377, 1, 0, -50924, 1604, 0, 0, 39, '1603'),
	(377, 1, 0, -50924, 1605, 0, 0, 39, '1604'),
	(377, 1, 0, -50924, 1606, 0, 0, 39, '1605'),
	(377, 1, 0, -50924, 1607, 0, 0, 39, '1606'),
	(377, 1, 0, -50924, 1608, 0, 0, 39, '1607'),
	(377, 1, 0, -50924, 1609, 0, 0, 39, '1608'),
	(377, 1, 0, -50924, 1610, 0, 0, 39, '1609'),
	(377, 1, 0, -50924, 1611, 0, 0, 39, '1610'),
	(377, 1, 0, -50924, 1612, 0, 0, 39, '1611'),
	(377, 1, 0, -50924, 1613, 0, 0, 39, '1612'),
	(377, 1, 0, -50924, 1614, 0, 0, 39, '1613'),
	(377, 1, 0, -50924, 1615, 0, 0, 39, '1614'),
	(377, 1, 0, -50924, 1616, 0, 0, 39, '1615'),
	(377, 1, 0, -50924, 1617, 0, 0, 39, '1616'),
	(377, 1, 0, -50924, 1618, 0, 0, 39, '1617'),
	(377, 1, 0, -50924, 1619, 0, 0, 39, '1618'),
	(377, 1, 0, -50924, 1620, 0, 0, 39, '1619'),
	(377, 1, 0, -50924, 1621, 0, 0, 39, '1620'),
	(377, 1, 0, -50924, 1622, 0, 0, 39, '1621'),
	(377, 1, 0, -50924, 1623, 0, 0, 39, '1622'),
	(377, 1, 0, -50924, 1624, 0, 0, 39, '1623'),
	(377, 1, 0, -50924, 1625, 0, 0, 39, '1624'),
	(377, 1, 0, -50924, 1626, 0, 0, 39, '1625'),
	(377, 1, 0, -50924, 1627, 0, 0, 39, '1626'),
	(377, 1, 0, -50924, 1628, 0, 0, 39, '1627'),
	(377, 1, 0, -50924, 1629, 0, 0, 39, '1628'),
	(377, 1, 0, -50924, 1630, 0, 0, 39, '1629'),
	(377, 1, 0, -50924, 1631, 0, 0, 39, '1630'),
	(377, 1, 0, -50924, 1632, 0, 0, 39, '1631'),
	(377, 1, 0, -50924, 1633, 0, 0, 39, '1632'),
	(377, 1, 0, -50924, 1634, 0, 0, 39, '1633'),
	(377, 1, 0, -50924, 1635, 0, 0, 39, '1634'),
	(377, 1, 0, -50924, 1636, 0, 0, 39, '1635'),
	(377, 1, 0, -50924, 1637, 0, 0, 39, '1636'),
	(377, 1, 0, -50924, 1638, 0, 0, 39, '1637'),
	(377, 1, 0, -50924, 1639, 0, 0, 39, '1638'),
	(377, 1, 0, -50924, 1640, 0, 0, 39, '1639'),
	(377, 1, 0, -50924, 1641, 0, 0, 39, '1640'),
	(377, 1, 0, -50924, 1642, 0, 0, 39, '1641'),
	(377, 1, 0, -50924, 1643, 0, 0, 39, '1642'),
	(377, 1, 0, -50924, 1644, 0, 0, 39, '1643'),
	(377, 1, 0, -50924, 1645, 0, 0, 39, '1644'),
	(377, 1, 0, -50924, 1646, 0, 0, 39, '1645'),
	(377, 1, 0, -50924, 1647, 0, 0, 39, '1646'),
	(377, 1, 0, -50924, 1648, 0, 0, 39, '1647'),
	(377, 1, 0, -50924, 1649, 0, 0, 39, '1648'),
	(377, 1, 0, -50924, 1650, 0, 0, 39, '1649'),
	(377, 1, 0, -50924, 1651, 0, 0, 39, '1650'),
	(377, 1, 0, -50924, 1652, 0, 0, 39, '1651'),
	(377, 1, 0, -50924, 1653, 0, 0, 39, '1652'),
	(377, 1, 0, -50924, 1654, 0, 0, 39, '1653'),
	(377, 1, 0, -50924, 1655, 0, 0, 39, '1654'),
	(377, 1, 0, -50924, 1656, 0, 0, 39, '1655'),
	(377, 1, 0, -50924, 1657, 0, 0, 39, '1656'),
	(377, 1, 0, -50924, 1658, 0, 0, 39, '1657'),
	(377, 1, 0, -50924, 1659, 0, 0, 39, '1658'),
	(377, 1, 0, -50924, 1660, 0, 0, 39, '1659'),
	(377, 1, 0, -50924, 1661, 0, 0, 39, '1660'),
	(377, 1, 0, -50924, 1662, 0, 0, 39, '1661'),
	(377, 1, 0, -50924, 1663, 0, 0, 39, '1662'),
	(377, 1, 0, -50924, 1664, 0, 0, 39, '1663'),
	(377, 1, 0, -50924, 1665, 0, 0, 39, '1664'),
	(377, 1, 0, -50924, 1666, 0, 0, 39, '1665'),
	(377, 1, 0, -50924, 1667, 0, 0, 39, '1666'),
	(377, 1, 0, -50924, 1668, 0, 0, 39, '1667'),
	(377, 1, 0, -50924, 1669, 0, 0, 39, '1668'),
	(377, 1, 0, -50924, 1670, 0, 0, 39, '1669'),
	(377, 1, 0, -50924, 1671, 0, 0, 39, '1670'),
	(377, 1, 0, -50924, 1672, 0, 0, 39, '1671'),
	(377, 1, 0, -50924, 1673, 0, 0, 39, '1672'),
	(377, 1, 0, -50924, 1674, 0, 0, 39, '1673'),
	(377, 1, 0, -50924, 1675, 0, 0, 39, '1674'),
	(377, 1, 0, -50924, 1676, 0, 0, 39, '1675'),
	(377, 1, 0, -50924, 1677, 0, 0, 39, '1676'),
	(377, 1, 0, -50924, 1678, 0, 0, 39, '1677'),
	(377, 1, 0, -50924, 1679, 0, 0, 39, '1678'),
	(377, 1, 0, -50924, 1680, 0, 0, 39, '1679'),
	(377, 1, 0, -50924, 1681, 0, 0, 39, '1680'),
	(377, 1, 0, -50924, 1682, 0, 0, 39, '1681'),
	(377, 1, 0, -50924, 1683, 0, 0, 39, '1682'),
	(377, 1, 0, -50924, 1684, 0, 0, 39, '1683'),
	(377, 1, 0, -50924, 1685, 0, 0, 39, '1684'),
	(377, 1, 0, -50924, 1686, 0, 0, 39, '1685'),
	(377, 1, 0, -50924, 1687, 0, 0, 39, '1686'),
	(377, 1, 0, -50924, 1688, 0, 0, 39, '1687'),
	(377, 1, 0, -50924, 1689, 0, 0, 39, '1688'),
	(377, 1, 0, -50924, 1690, 0, 0, 39, '1689'),
	(377, 1, 0, -50924, 1691, 0, 0, 39, '1690'),
	(377, 1, 0, -50924, 1692, 0, 0, 39, '1691'),
	(377, 1, 0, -50924, 1693, 0, 0, 39, '1692'),
	(377, 1, 0, -50924, 1694, 0, 0, 39, '1693'),
	(377, 1, 0, -50924, 1695, 0, 0, 39, '1694'),
	(377, 1, 0, -50924, 1696, 0, 0, 39, '1695'),
	(377, 1, 0, -50924, 1697, 0, 0, 39, '1696'),
	(377, 1, 0, -50924, 1698, 0, 0, 39, '1697'),
	(377, 1, 0, -50924, 1699, 0, 0, 39, '1698'),
	(377, 1, 0, -50924, 1700, 0, 0, 39, '1699'),
	(377, 1, 0, -50924, 1701, 0, 0, 39, '1700'),
	(377, 1, 0, -50924, 1702, 0, 0, 39, '1701'),
	(377, 1, 0, -50924, 1703, 0, 0, 39, '1702'),
	(377, 1, 0, -50924, 1704, 0, 0, 39, '1703'),
	(377, 1, 0, -50924, 1705, 0, 0, 39, '1704'),
	(377, 1, 0, -50924, 1706, 0, 0, 39, '1705'),
	(377, 1, 0, -50924, 1707, 0, 0, 39, '1706'),
	(377, 1, 0, -50924, 1708, 0, 0, 39, '1707'),
	(377, 1, 0, -50924, 1709, 0, 0, 39, '1708'),
	(377, 1, 0, -50924, 1710, 0, 0, 39, '1709'),
	(377, 1, 0, -50924, 1711, 0, 0, 39, '1710'),
	(377, 1, 0, -50924, 1712, 0, 0, 39, '1711'),
	(377, 1, 0, -50924, 1713, 0, 0, 39, '1712'),
	(377, 1, 0, -50924, 1714, 0, 0, 39, '1713'),
	(377, 1, 0, -50924, 1715, 0, 0, 39, '1714'),
	(377, 1, 0, -50924, 1716, 0, 0, 39, '1715'),
	(377, 1, 0, -50924, 1717, 0, 0, 39, '1716'),
	(377, 1, 0, -50924, 1718, 0, 0, 39, '1717'),
	(377, 1, 0, -50924, 1719, 0, 0, 39, '1718'),
	(377, 1, 0, -50924, 1720, 0, 0, 39, '1719'),
	(377, 1, 0, -50924, 1721, 0, 0, 39, '1720'),
	(377, 1, 0, -50924, 1722, 0, 0, 39, '1721'),
	(377, 1, 0, -50924, 1723, 0, 0, 39, '1722'),
	(377, 1, 0, -50924, 1724, 0, 0, 39, '1723'),
	(377, 1, 0, -50924, 1725, 0, 0, 39, '1724'),
	(377, 1, 0, -50924, 1726, 0, 0, 39, '1725'),
	(377, 1, 0, -50924, 1727, 0, 0, 39, '1726'),
	(377, 1, 0, -50924, 1728, 0, 0, 39, '1727'),
	(377, 1, 0, -50924, 1729, 0, 0, 39, '1728'),
	(377, 1, 0, -50924, 1730, 0, 0, 39, '1729'),
	(377, 1, 0, -50924, 1731, 0, 0, 39, '1730'),
	(377, 1, 0, -50924, 1732, 0, 0, 39, '1731'),
	(377, 1, 0, -50924, 1733, 0, 0, 39, '1732'),
	(377, 1, 0, -50924, 1734, 0, 0, 39, '1733'),
	(377, 1, 0, -50924, 1735, 0, 0, 39, '1734'),
	(377, 1, 0, -50924, 1736, 0, 0, 39, '1735'),
	(377, 1, 0, -50924, 1737, 0, 0, 39, '1736'),
	(377, 1, 0, -50924, 1738, 0, 0, 39, '1737'),
	(377, 1, 0, -50924, 1739, 0, 0, 39, '1738'),
	(377, 1, 0, -50924, 1740, 0, 0, 39, '1739'),
	(377, 1, 0, -50924, 1741, 0, 0, 39, '1740'),
	(377, 1, 0, -50924, 1742, 0, 0, 39, '1741'),
	(377, 1, 0, -50924, 1743, 0, 0, 39, '1742'),
	(377, 1, 0, -50924, 1744, 0, 0, 39, '1743'),
	(377, 1, 0, -50924, 1745, 0, 0, 39, '1744'),
	(377, 1, 0, -50924, 1746, 0, 0, 39, '1745'),
	(377, 1, 0, -50924, 1747, 0, 0, 39, '1746'),
	(377, 1, 0, -50924, 1748, 0, 0, 39, '1747'),
	(377, 1, 0, -50924, 1749, 0, 0, 39, '1748'),
	(377, 1, 0, -50924, 1750, 0, 0, 39, '1749'),
	(377, 1, 0, -50924, 1751, 0, 0, 39, '1750'),
	(377, 1, 0, -50924, 1752, 0, 0, 39, '1751'),
	(377, 1, 0, -50924, 1753, 0, 0, 39, '1752'),
	(377, 1, 0, -50924, 1754, 0, 0, 39, '1753'),
	(377, 1, 0, -50924, 1755, 0, 0, 39, '1754'),
	(377, 1, 0, -50924, 1756, 0, 0, 39, '1755'),
	(377, 1, 0, -50924, 1757, 0, 0, 39, '1756'),
	(377, 1, 0, -50924, 1758, 0, 0, 39, '1757'),
	(377, 1, 0, -50924, 1759, 0, 0, 39, '1758'),
	(377, 1, 0, -50924, 1760, 0, 0, 39, '1759'),
	(377, 1, 0, -50924, 1761, 0, 0, 39, '1760'),
	(377, 1, 0, -50924, 1762, 0, 0, 39, '1761'),
	(377, 1, 0, -50924, 1763, 0, 0, 39, '1762'),
	(377, 1, 0, -50924, 1764, 0, 0, 39, '1763'),
	(377, 1, 0, -50924, 1765, 0, 0, 39, '1764'),
	(377, 1, 0, -50924, 1766, 0, 0, 39, '1765'),
	(377, 1, 0, -50924, 1767, 0, 0, 39, '1766'),
	(377, 1, 0, -50924, 1768, 0, 0, 39, '1767'),
	(377, 1, 0, -50924, 1769, 0, 0, 39, '1768'),
	(377, 1, 0, -50924, 1770, 0, 0, 39, '1769'),
	(377, 1, 0, -50924, 1771, 0, 0, 39, '1770'),
	(377, 1, 0, -50924, 1772, 0, 0, 39, '1771'),
	(377, 1, 0, -50924, 1773, 0, 0, 39, '1772'),
	(377, 1, 0, -50924, 1774, 0, 0, 39, '1773'),
	(377, 1, 0, -50924, 1775, 0, 0, 39, '1774'),
	(377, 1, 0, -50924, 1776, 0, 0, 39, '1775'),
	(377, 1, 0, -50924, 1777, 0, 0, 39, '1776'),
	(377, 1, 0, -50924, 1778, 0, 0, 39, '1777'),
	(377, 1, 0, -50924, 1779, 0, 0, 39, '1778'),
	(377, 1, 0, -50924, 1780, 0, 0, 39, '1779'),
	(377, 1, 0, -50924, 1781, 0, 0, 39, '1780'),
	(377, 1, 0, -50924, 1782, 0, 0, 39, '1781'),
	(377, 1, 0, -50924, 1783, 0, 0, 39, '1782'),
	(377, 1, 0, -50924, 1784, 0, 0, 39, '1783'),
	(377, 1, 0, -50924, 1785, 0, 0, 39, '1784'),
	(377, 1, 0, -50924, 1786, 0, 0, 39, '1785'),
	(377, 1, 0, -50924, 1787, 0, 0, 39, '1786'),
	(377, 1, 0, -50924, 1788, 0, 0, 39, '1787'),
	(377, 1, 0, -50924, 1789, 0, 0, 39, '1788'),
	(377, 1, 0, -50924, 1790, 0, 0, 39, '1789'),
	(377, 1, 0, -50924, 1791, 0, 0, 39, '1790'),
	(377, 1, 0, -50924, 1792, 0, 0, 39, '1791'),
	(377, 1, 0, -50924, 1793, 0, 0, 39, '1792'),
	(377, 1, 0, -50924, 1794, 0, 0, 39, '1793'),
	(377, 1, 0, -50924, 1795, 0, 0, 39, '1794'),
	(377, 1, 0, -50924, 1796, 0, 0, 39, '1795'),
	(377, 1, 0, -50924, 1797, 0, 0, 39, '1796'),
	(377, 1, 0, -50924, 1798, 0, 0, 39, '1797'),
	(377, 1, 0, -50924, 1799, 0, 0, 39, '1798'),
	(377, 1, 0, -50924, 1800, 0, 0, 39, '1799'),
	(377, 1, 0, -50924, 1801, 0, 0, 39, '1800'),
	(377, 1, 0, -50924, 1802, 0, 0, 39, '1801'),
	(377, 1, 0, -50924, 1803, 0, 0, 39, '1802'),
	(377, 1, 0, -50924, 1804, 0, 0, 39, '1803'),
	(377, 1, 0, -50924, 1805, 0, 0, 39, '1804'),
	(377, 1, 0, -50924, 1806, 0, 0, 39, '1805'),
	(377, 1, 0, -50924, 1807, 0, 0, 39, '1806'),
	(377, 1, 0, -50924, 1808, 0, 0, 39, '1807'),
	(377, 1, 0, -50924, 1809, 0, 0, 39, '1808'),
	(377, 1, 0, -50924, 1810, 0, 0, 39, '1809'),
	(377, 1, 0, -50924, 1811, 0, 0, 39, '1810'),
	(377, 1, 0, -50924, 1812, 0, 0, 39, '1811'),
	(377, 1, 0, -50924, 1813, 0, 0, 39, '1812'),
	(377, 1, 0, -50924, 1814, 0, 0, 39, '1813'),
	(377, 1, 0, -50924, 1815, 0, 0, 39, '1814'),
	(377, 1, 0, -50924, 1816, 0, 0, 39, '1815'),
	(377, 1, 0, -50924, 1817, 0, 0, 39, '1816'),
	(377, 1, 0, -50924, 1818, 0, 0, 39, '1817'),
	(377, 1, 0, -50924, 1819, 0, 0, 39, '1818'),
	(377, 1, 0, -50924, 1820, 0, 0, 39, '1819'),
	(377, 1, 0, -50924, 1821, 0, 0, 39, '1820'),
	(377, 1, 0, -50924, 1822, 0, 0, 39, '1821'),
	(377, 1, 0, -50924, 1823, 0, 0, 39, '1822'),
	(377, 1, 0, -50924, 1824, 0, 0, 39, '1823'),
	(377, 1, 0, -50924, 1825, 0, 0, 39, '1824'),
	(377, 1, 0, -50924, 1826, 0, 0, 39, '1825'),
	(377, 1, 0, -50924, 1827, 0, 0, 39, '1826'),
	(377, 1, 0, -50924, 1828, 0, 0, 39, '1827'),
	(377, 1, 0, -50924, 1829, 0, 0, 39, '1828'),
	(377, 1, 0, -50924, 1830, 0, 0, 39, '1829'),
	(377, 1, 0, -50924, 1831, 0, 0, 39, '1830'),
	(377, 1, 0, -50924, 1832, 0, 0, 39, '1831'),
	(377, 1, 0, -50924, 1833, 0, 0, 39, '1832'),
	(377, 1, 0, -50924, 1834, 0, 0, 39, '1833'),
	(377, 1, 0, -50924, 1835, 0, 0, 39, '1834'),
	(377, 1, 0, -50924, 1836, 0, 0, 39, '1835'),
	(377, 1, 0, -50924, 1837, 0, 0, 39, '1836'),
	(377, 1, 0, -50924, 1838, 0, 0, 39, '1837'),
	(377, 1, 0, -50924, 1839, 0, 0, 39, '1838'),
	(377, 1, 0, -50924, 1840, 0, 0, 39, '1839'),
	(377, 1, 0, -50924, 1841, 0, 0, 39, '1840'),
	(377, 1, 0, -50924, 1842, 0, 0, 39, '1841'),
	(377, 1, 0, -50924, 1843, 0, 0, 39, '1842'),
	(377, 1, 0, -50924, 1844, 0, 0, 39, '1843'),
	(377, 1, 0, -50924, 1845, 0, 0, 39, '1844'),
	(377, 1, 0, -50924, 1846, 0, 0, 39, '1845'),
	(377, 1, 0, -50924, 1847, 0, 0, 39, '1846'),
	(377, 1, 0, -50924, 1848, 0, 0, 39, '1847'),
	(377, 1, 0, -50924, 1849, 0, 0, 39, '1848'),
	(377, 1, 0, -50924, 1850, 0, 0, 39, '1849'),
	(377, 1, 0, -50924, 1851, 0, 0, 39, '1850'),
	(377, 1, 0, -50924, 1852, 0, 0, 39, '1851'),
	(377, 1, 0, -50924, 1853, 0, 0, 39, '1852'),
	(377, 1, 0, -50924, 1854, 0, 0, 39, '1853'),
	(377, 1, 0, -50924, 1855, 0, 0, 39, '1854'),
	(377, 1, 0, -50924, 1856, 0, 0, 39, '1855'),
	(377, 1, 0, -50924, 1857, 0, 0, 39, '1856'),
	(377, 1, 0, -50924, 1858, 0, 0, 39, '1857'),
	(377, 1, 0, -50924, 1859, 0, 0, 39, '1858'),
	(377, 1, 0, -50924, 1860, 0, 0, 39, '1859'),
	(377, 1, 0, -50924, 1861, 0, 0, 39, '1860'),
	(377, 1, 0, -50924, 1862, 0, 0, 39, '1861'),
	(377, 1, 0, -50924, 1863, 0, 0, 39, '1862'),
	(377, 1, 0, -50924, 1864, 0, 0, 39, '1863'),
	(377, 1, 0, -50924, 1865, 0, 0, 39, '1864'),
	(377, 1, 0, -50924, 1866, 0, 0, 39, '1865'),
	(377, 1, 0, -50924, 1867, 0, 0, 39, '1866'),
	(377, 1, 0, -50924, 1868, 0, 0, 39, '1867'),
	(377, 1, 0, -50924, 1869, 0, 0, 39, '1868'),
	(377, 1, 0, -50924, 1870, 0, 0, 39, '1869'),
	(377, 1, 0, -50924, 1871, 0, 0, 39, '1870'),
	(377, 1, 0, -50924, 1872, 0, 0, 39, '1871'),
	(377, 1, 0, -50924, 1873, 0, 0, 39, '1872'),
	(377, 1, 0, -50924, 1874, 0, 0, 39, '1873'),
	(377, 1, 0, -50924, 1875, 0, 0, 39, '1874'),
	(377, 1, 0, -50924, 1876, 0, 0, 39, '1875'),
	(377, 1, 0, -50924, 1877, 0, 0, 39, '1876'),
	(377, 1, 0, -50924, 1878, 0, 0, 39, '1877'),
	(377, 1, 0, -50924, 1879, 0, 0, 39, '1878'),
	(377, 1, 0, -50924, 1880, 0, 0, 39, '1879'),
	(377, 1, 0, -50924, 1881, 0, 0, 39, '1880'),
	(377, 1, 0, -50924, 1882, 0, 0, 39, '1881'),
	(377, 1, 0, -50924, 1883, 0, 0, 39, '1882'),
	(377, 1, 0, -50924, 1884, 0, 0, 39, '1883'),
	(377, 1, 0, -50924, 1885, 0, 0, 39, '1884'),
	(377, 1, 0, -50924, 1886, 0, 0, 39, '1885'),
	(377, 1, 0, -50924, 1887, 0, 0, 39, '1886'),
	(377, 1, 0, -50924, 1888, 0, 0, 39, '1887'),
	(377, 1, 0, -50924, 1889, 0, 0, 39, '1888'),
	(377, 1, 0, -50924, 1890, 0, 0, 39, '1889'),
	(377, 1, 0, -50924, 1891, 0, 0, 39, '1890'),
	(377, 1, 0, -50924, 1892, 0, 0, 39, '1891'),
	(377, 1, 0, -50924, 1893, 0, 0, 39, '1892'),
	(377, 1, 0, -50924, 1894, 0, 0, 39, '1893'),
	(377, 1, 0, -50924, 1895, 0, 0, 39, '1894'),
	(377, 1, 0, -50924, 1896, 0, 0, 39, '1895'),
	(377, 1, 0, -50924, 1897, 0, 0, 39, '1896'),
	(377, 1, 0, -50924, 1898, 0, 0, 39, '1897'),
	(377, 1, 0, -50924, 1899, 0, 0, 39, '1898'),
	(377, 1, 0, -50924, 1900, 0, 0, 39, '1899'),
	(377, 1, 0, -50924, 1901, 0, 0, 39, '1900'),
	(377, 1, 0, -50924, 1902, 0, 0, 39, '1901'),
	(377, 1, 0, -50924, 1903, 0, 0, 39, '1902'),
	(377, 1, 0, -50924, 1904, 0, 0, 39, '1903'),
	(377, 1, 0, -50924, 1905, 0, 0, 39, '1904'),
	(377, 1, 0, -50924, 1906, 0, 0, 39, '1905'),
	(377, 1, 0, -50924, 1907, 0, 0, 39, '1906'),
	(377, 1, 0, -50924, 1908, 0, 0, 39, '1907'),
	(377, 1, 0, -50924, 1909, 0, 0, 39, '1908'),
	(377, 1, 0, -50924, 1910, 0, 0, 39, '1909'),
	(377, 1, 0, -50924, 1911, 0, 0, 39, '1910'),
	(377, 1, 0, -50924, 1912, 0, 0, 39, '1911'),
	(377, 1, 0, -50924, 1913, 0, 0, 39, '1912'),
	(377, 1, 0, -50924, 1914, 0, 0, 39, '1913'),
	(377, 1, 0, -50924, 1915, 0, 0, 39, '1914'),
	(377, 1, 0, -50924, 1916, 0, 0, 39, '1915'),
	(377, 1, 0, -50924, 1917, 0, 0, 39, '1916'),
	(377, 1, 0, -50924, 1918, 0, 0, 39, '1917'),
	(377, 1, 0, -50924, 1919, 0, 0, 39, '1918'),
	(377, 1, 0, -50924, 1920, 0, 0, 39, '1919'),
	(377, 1, 0, -50924, 1921, 0, 0, 39, '1920'),
	(377, 1, 0, -50924, 1922, 0, 0, 39, '1921'),
	(377, 1, 0, -50924, 1923, 0, 0, 39, '1922'),
	(377, 1, 0, -50924, 1924, 0, 0, 39, '1923'),
	(377, 1, 0, -50924, 1925, 0, 0, 39, '1924'),
	(377, 1, 0, -50924, 1926, 0, 0, 39, '1925'),
	(377, 1, 0, -50924, 1927, 0, 0, 39, '1926'),
	(377, 1, 0, -50924, 1928, 0, 0, 39, '1927'),
	(377, 1, 0, -50924, 1929, 0, 0, 39, '1928'),
	(377, 1, 0, -50924, 1930, 0, 0, 39, '1929'),
	(377, 1, 0, -50924, 1931, 0, 0, 39, '1930'),
	(377, 1, 0, -50924, 1932, 0, 0, 39, '1931'),
	(377, 1, 0, -50924, 1933, 0, 0, 39, '1932'),
	(377, 1, 0, -50924, 1934, 0, 0, 39, '1933'),
	(377, 1, 0, -50924, 1935, 0, 0, 39, '1934'),
	(377, 1, 0, -50924, 1936, 0, 0, 39, '1935'),
	(377, 1, 0, -50924, 1937, 0, 0, 39, '1936'),
	(377, 1, 0, -50924, 1938, 0, 0, 39, '1937'),
	(377, 1, 0, -50924, 1939, 0, 0, 39, '1938'),
	(377, 1, 0, -50924, 1940, 0, 0, 39, '1939'),
	(377, 1, 0, -50924, 1941, 0, 0, 39, '1940'),
	(377, 1, 0, -50924, 1942, 0, 0, 39, '1941'),
	(377, 1, 0, -50924, 1943, 0, 0, 39, '1942'),
	(377, 1, 0, -50924, 1944, 0, 0, 39, '1943'),
	(377, 1, 0, -50924, 1945, 0, 0, 39, '1944'),
	(377, 1, 0, -50924, 1946, 0, 0, 39, '1945'),
	(377, 1, 0, -50924, 1947, 0, 0, 39, '1946'),
	(377, 1, 0, -50924, 1948, 0, 0, 39, '1947'),
	(377, 1, 0, -50924, 1949, 0, 0, 39, '1948'),
	(377, 1, 0, -50924, 1950, 0, 0, 39, '1949'),
	(377, 1, 0, -50924, 1951, 0, 0, 39, '1950'),
	(377, 1, 0, -50924, 1952, 0, 0, 39, '1951'),
	(377, 1, 0, -50924, 1953, 0, 0, 39, '1952'),
	(377, 1, 0, -50924, 1954, 0, 0, 39, '1953'),
	(377, 1, 0, -50924, 1955, 0, 0, 39, '1954'),
	(377, 1, 0, -50924, 1956, 0, 0, 39, '1955'),
	(377, 1, 0, -50924, 1957, 0, 0, 39, '1956'),
	(377, 1, 0, -50924, 1958, 0, 0, 39, '1957'),
	(377, 1, 0, -50924, 1959, 0, 0, 39, '1958'),
	(377, 1, 0, -50924, 1960, 0, 0, 39, '1959'),
	(377, 1, 0, -50924, 1961, 0, 0, 39, '1960'),
	(377, 1, 0, -50924, 1962, 0, 0, 39, '1961'),
	(377, 1, 0, -50924, 1963, 0, 0, 39, '1962'),
	(377, 1, 0, -50924, 1964, 0, 0, 39, '1963'),
	(377, 1, 0, -50924, 1965, 0, 0, 39, '1964'),
	(377, 1, 0, -50924, 1966, 0, 0, 39, '1965'),
	(377, 1, 0, -50924, 1967, 0, 0, 39, '1966'),
	(377, 1, 0, -50924, 1968, 0, 0, 39, '1967'),
	(377, 1, 0, -50924, 1969, 0, 0, 39, '1968'),
	(377, 1, 0, -50924, 1970, 0, 0, 39, '1969'),
	(377, 1, 0, -50924, 1971, 0, 0, 39, '1970'),
	(377, 1, 0, -50924, 1972, 0, 0, 39, '1971'),
	(377, 1, 0, -50924, 1973, 0, 0, 39, '1972'),
	(377, 1, 0, -50924, 1974, 0, 0, 39, '1973'),
	(377, 1, 0, -50924, 1975, 0, 0, 39, '1974'),
	(377, 1, 0, -50924, 1976, 0, 0, 39, '1975'),
	(377, 1, 0, -50924, 1977, 0, 0, 39, '1976'),
	(377, 1, 0, -50924, 1978, 0, 0, 39, '1977'),
	(377, 1, 0, -50924, 1979, 0, 0, 39, '1978'),
	(377, 1, 0, -50924, 1980, 0, 0, 39, '1979'),
	(377, 1, 0, -50924, 1981, 0, 0, 39, '1980'),
	(377, 1, 0, -50924, 1982, 0, 0, 39, '1981'),
	(377, 1, 0, -50924, 1983, 0, 0, 39, '1982'),
	(377, 1, 0, -50924, 1984, 0, 0, 39, '1983'),
	(377, 1, 0, -50924, 1985, 0, 0, 39, '1984'),
	(377, 1, 0, -50924, 1986, 0, 0, 39, '1985'),
	(377, 1, 0, -50924, 1987, 0, 0, 39, '1986'),
	(377, 1, 0, -50924, 1988, 0, 0, 39, '1987'),
	(377, 1, 0, -50924, 1989, 0, 0, 39, '1988'),
	(377, 1, 0, -50924, 1990, 0, 0, 39, '1989'),
	(377, 1, 0, -50924, 1991, 0, 0, 39, '1990'),
	(377, 1, 0, -50924, 1992, 0, 0, 39, '1991'),
	(377, 1, 0, -50924, 1993, 0, 0, 39, '1992'),
	(377, 1, 0, -50924, 1994, 0, 0, 39, '1993'),
	(377, 1, 0, -50924, 1995, 0, 0, 39, '1994'),
	(377, 1, 0, -50924, 1996, 0, 0, 39, '1995'),
	(377, 1, 0, -50924, 1997, 0, 0, 39, '1996'),
	(377, 1, 0, -50924, 1998, 0, 0, 39, '1997'),
	(377, 1, 0, -50924, 1999, 0, 0, 39, '1998'),
	(377, 1, 0, -50924, 2000, 0, 0, 39, '1999'),
	(377, 1, 0, -50924, 2001, 0, 0, 39, '2000'),
	(377, 1, 0, -50924, 2002, 0, 0, 39, '2001'),
	(377, 1, 0, -50924, 2003, 0, 0, 39, '2002'),
	(377, 1, 0, -50924, 2004, 0, 0, 39, '2003'),
	(377, 1, 0, -50924, 2005, 0, 0, 39, '2004'),
	(377, 1, 0, -50924, 2006, 0, 0, 39, '2005'),
	(377, 1, 0, -50924, 2007, 0, 0, 39, '2006'),
	(377, 1, 0, -50924, 2008, 0, 0, 39, '2007'),
	(377, 1, 0, -50924, 2009, 0, 0, 39, '2008'),
	(377, 1, 0, -50924, 2010, 0, 0, 39, '2009'),
	(377, 1, 0, -50924, 2011, 0, 0, 39, '2010'),
	(377, 1, 0, -50924, 2012, 0, 0, 39, '2011'),
	(377, 1, 0, -50924, 2013, 0, 0, 39, '2012'),
	(377, 1, 0, -50924, 2014, 0, 0, 39, '2013'),
	(377, 1, 0, -50924, 2015, 0, 0, 39, '2014'),
	(377, 1, 0, -50924, 2016, 0, 0, 39, '2015'),
	(377, 1, 0, -50924, 2017, 0, 0, 39, '2016'),
	(377, 1, 0, -50924, 2018, 0, 0, 39, '2017'),
	(377, 1, 0, -50924, 2019, 0, 0, 39, '2018'),
	(377, 1, 0, -50924, 2020, 0, 0, 39, '2019'),
	(377, 1, 0, -50924, 2021, 0, 0, 39, '2020'),
	(377, 1, 0, -50924, 2022, 0, 0, 39, '2021'),
	(377, 1, 0, -50924, 2023, 0, 0, 39, '2022'),
	(377, 1, 0, -50924, 2024, 0, 0, 39, '2023'),
	(377, 1, 0, -50924, 2025, 0, 0, 39, '2024'),
	(377, 1, 0, -50924, 2026, 0, 0, 39, '2025'),
	(377, 1, 0, -50924, 2027, 0, 0, 39, '2026'),
	(377, 1, 0, -50924, 2028, 0, 0, 39, '2027'),
	(377, 1, 0, -50924, 2029, 0, 0, 39, '2028'),
	(377, 1, 0, -50924, 2030, 0, 0, 39, '2029'),
	(377, 1, 0, -50924, 2031, 0, 0, 39, '2030'),
	(377, 1, 0, -50924, 2032, 0, 0, 39, '2031'),
	(377, 1, 0, -50924, 2033, 0, 0, 39, '2032'),
	(377, 1, 0, -50924, 2034, 0, 0, 39, '2033'),
	(377, 1, 0, -50924, 2035, 0, 0, 39, '2034'),
	(377, 1, 0, -50924, 2036, 0, 0, 39, '2035'),
	(377, 1, 0, -50924, 2037, 0, 0, 39, '2036'),
	(377, 1, 0, -50924, 2038, 0, 0, 39, '2037'),
	(377, 1, 0, -50924, 2039, 0, 0, 39, '2038'),
	(377, 1, 0, -50924, 2040, 0, 0, 39, '2039'),
	(377, 1, 0, -50924, 2041, 0, 0, 39, '2040'),
	(377, 1, 0, -50924, 2042, 0, 0, 39, '2041'),
	(377, 1, 0, -50924, 2043, 0, 0, 39, '2042'),
	(377, 1, 0, -50924, 2044, 0, 0, 39, '2043'),
	(377, 1, 0, -50924, 2045, 0, 0, 39, '2044'),
	(377, 1, 0, -50924, 2046, 0, 0, 39, '2045'),
	(377, 1, 0, -50924, 2047, 0, 0, 39, '2046'),
	(377, 1, 0, -50924, 2048, 0, 0, 39, '2047'),
	(377, 1, 0, -50924, 2049, 0, 0, 39, '2048'),
	(377, 1, 0, -50924, 2050, 0, 0, 39, '2049'),
	(377, 1, 0, -50924, 2051, 0, 0, 39, '2050'),
	(377, 1, 0, -50924, 2052, 0, 0, 39, '2051'),
	(377, 1, 0, -50924, 2053, 0, 0, 39, '2052'),
	(377, 1, 0, -50924, 2054, 0, 0, 39, '2053'),
	(377, 1, 0, -50924, 2055, 0, 0, 39, '2054'),
	(377, 1, 0, -50924, 2056, 0, 0, 39, '2055'),
	(377, 1, 0, -50924, 2057, 0, 0, 39, '2056'),
	(377, 1, 0, -50924, 2058, 0, 0, 39, '2057'),
	(377, 1, 0, -50924, 2059, 0, 0, 39, '2058'),
	(377, 1, 0, -50924, 2060, 0, 0, 39, '2059'),
	(377, 1, 0, -50924, 2061, 0, 0, 39, '2060'),
	(377, 1, 0, -50924, 2062, 0, 0, 39, '2061'),
	(377, 1, 0, -50924, 2063, 0, 0, 39, '2062'),
	(377, 1, 0, -50924, 2064, 0, 0, 39, '2063'),
	(377, 1, 0, -50924, 2065, 0, 0, 39, '2064'),
	(377, 1, 0, -50924, 2066, 0, 0, 39, '2065'),
	(377, 1, 0, -50924, 2067, 0, 0, 39, '2066'),
	(377, 1, 0, -50924, 2068, 0, 0, 39, '2067'),
	(377, 1, 0, -50924, 2069, 0, 0, 39, '2068'),
	(377, 1, 0, -50924, 2070, 0, 0, 39, '2069'),
	(377, 1, 0, -50924, 2071, 0, 0, 39, '2070'),
	(377, 1, 0, -50924, 2072, 0, 0, 39, '2071'),
	(377, 1, 0, -50924, 2073, 0, 0, 39, '2072'),
	(377, 1, 0, -50924, 2074, 0, 0, 39, '2073'),
	(377, 1, 0, -50924, 2075, 0, 0, 39, '2074'),
	(377, 1, 0, -50924, 2076, 0, 0, 39, '2075'),
	(377, 1, 0, -50924, 2077, 0, 0, 39, '2076'),
	(377, 1, 0, -50924, 2078, 0, 0, 39, '2077'),
	(377, 1, 0, -50924, 2079, 0, 0, 39, '2078'),
	(377, 1, 0, -50924, 2080, 0, 0, 39, '2079'),
	(377, 1, 0, -50924, 2081, 0, 0, 39, '2080'),
	(377, 1, 0, -50924, 2082, 0, 0, 39, '2081'),
	(377, 1, 0, -50924, 2083, 0, 0, 39, '2082'),
	(377, 1, 0, -50924, 2084, 0, 0, 39, '2083'),
	(377, 1, 0, -50924, 2085, 0, 0, 39, '2084'),
	(377, 1, 0, -50924, 2086, 0, 0, 39, '2085'),
	(377, 1, 0, -50924, 2087, 0, 0, 39, '2086'),
	(377, 1, 0, -50924, 2088, 0, 0, 39, '2087'),
	(377, 1, 0, -50924, 2089, 0, 0, 39, '2088'),
	(377, 1, 0, -50924, 2090, 0, 0, 39, '2089'),
	(377, 1, 0, -50924, 2091, 0, 0, 39, '2090'),
	(377, 1, 0, -50924, 2092, 0, 0, 39, '2091'),
	(377, 1, 0, -50924, 2093, 0, 0, 39, '2092'),
	(377, 1, 0, -50924, 2094, 0, 0, 39, '2093'),
	(377, 1, 0, -50924, 2095, 0, 0, 39, '2094'),
	(377, 1, 0, -50924, 2096, 0, 0, 39, '2095'),
	(377, 1, 0, -50924, 2097, 0, 0, 39, '2096'),
	(377, 1, 0, -50924, 2098, 0, 0, 39, '2097'),
	(377, 1, 0, -50924, 2099, 0, 0, 39, '2098'),
	(377, 1, 0, -50924, 2100, 0, 0, 39, '2099'),
	(377, 1, 0, -50924, 2101, 0, 0, 39, '2100'),
	(377, 1, 0, -50924, 2102, 0, 0, 39, '2101'),
	(377, 1, 0, -50924, 2103, 0, 0, 39, '2102'),
	(377, 1, 0, -50924, 2104, 0, 0, 39, '2103'),
	(377, 1, 0, -50924, 2105, 0, 0, 39, '2104'),
	(377, 1, 0, -50924, 2106, 0, 0, 39, '2105'),
	(377, 1, 0, -50924, 2107, 0, 0, 39, '2106'),
	(377, 1, 0, -50924, 2108, 0, 0, 39, '2107'),
	(377, 1, 0, -50924, 2109, 0, 0, 39, '2108'),
	(377, 1, 0, -50924, 2110, 0, 0, 39, '2109'),
	(377, 1, 0, -50924, 2111, 0, 0, 39, '2110'),
	(377, 1, 0, -50924, 2112, 0, 0, 39, '2111'),
	(377, 1, 0, -50924, 2113, 0, 0, 39, '2112'),
	(377, 1, 0, -50924, 2114, 0, 0, 39, '2113'),
	(377, 1, 0, -50924, 2115, 0, 0, 39, '2114'),
	(377, 1, 0, -50924, 2116, 0, 0, 39, '2115'),
	(377, 1, 0, -50924, 2117, 0, 0, 39, '2116'),
	(377, 1, 0, -50924, 2118, 0, 0, 39, '2117'),
	(377, 1, 0, -50924, 2119, 0, 0, 39, '2118'),
	(377, 1, 0, -50924, 2120, 0, 0, 39, '2119'),
	(377, 1, 0, -50924, 2121, 0, 0, 39, '2120'),
	(377, 1, 0, -50924, 2122, 0, 0, 39, '2121'),
	(377, 1, 0, -50924, 2123, 0, 0, 39, '2122'),
	(377, 1, 0, -50924, 2124, 0, 0, 39, '2123'),
	(377, 1, 0, -50924, 2125, 0, 0, 39, '2124'),
	(377, 1, 0, -50924, 2126, 0, 0, 39, '2125'),
	(377, 1, 0, -50924, 2127, 0, 0, 39, '2126'),
	(377, 1, 0, -50924, 2128, 0, 0, 39, '2127'),
	(377, 1, 0, -50924, 2129, 0, 0, 39, '2128'),
	(377, 1, 0, -50924, 2130, 0, 0, 39, '2129'),
	(377, 1, 0, -50924, 2131, 0, 0, 39, '2130'),
	(377, 1, 0, -50924, 2132, 0, 0, 39, '2131'),
	(377, 1, 0, -50924, 2133, 0, 0, 39, '2132'),
	(377, 1, 0, -50924, 2134, 0, 0, 39, '2133'),
	(377, 1, 0, -50924, 2135, 0, 0, 39, '2134'),
	(377, 1, 0, -50924, 2136, 0, 0, 39, '2135'),
	(377, 1, 0, -50924, 2137, 0, 0, 39, '2136'),
	(377, 1, 0, -50924, 2138, 0, 0, 39, '2137'),
	(377, 1, 0, -50924, 2139, 0, 0, 39, '2138'),
	(377, 1, 0, -50924, 2140, 0, 0, 39, '2139'),
	(377, 1, 0, -50924, 2141, 0, 0, 39, '2140'),
	(377, 1, 0, -50924, 2142, 0, 0, 39, '2141'),
	(377, 1, 0, -50924, 2143, 0, 0, 39, '2142'),
	(377, 1, 0, -50924, 2144, 0, 0, 39, '2143'),
	(377, 1, 0, -50924, 2145, 0, 0, 39, '2144'),
	(377, 1, 0, -50924, 2146, 0, 0, 39, '2145'),
	(377, 1, 0, -50924, 2147, 0, 0, 39, '2146'),
	(377, 1, 0, -50924, 2148, 0, 0, 39, '2147'),
	(377, 1, 0, -50924, 2149, 0, 0, 39, '2148'),
	(377, 1, 0, -50924, 2150, 0, 0, 39, '2149'),
	(377, 1, 0, -50924, 2151, 0, 0, 39, '2150'),
	(377, 1, 0, -50924, 2152, 0, 0, 39, '2151'),
	(377, 1, 0, -50924, 2153, 0, 0, 39, '2152'),
	(377, 1, 0, -50924, 2154, 0, 0, 39, '2153'),
	(377, 1, 0, -50924, 2155, 0, 0, 39, '2154'),
	(377, 1, 0, -50924, 2156, 0, 0, 39, '2155'),
	(377, 1, 0, -50924, 2157, 0, 0, 39, '2156'),
	(377, 1, 0, -50924, 2158, 0, 0, 39, '2157'),
	(377, 1, 0, -50924, 2159, 0, 0, 39, '2158'),
	(377, 1, 0, -50924, 2160, 0, 0, 39, '2159'),
	(377, 1, 0, -50924, 2161, 0, 0, 39, '2160'),
	(377, 1, 0, -50924, 2162, 0, 0, 39, '2161'),
	(377, 1, 0, -50924, 2163, 0, 0, 39, '2162'),
	(377, 1, 0, -50924, 2164, 0, 0, 39, '2163'),
	(377, 1, 0, -50924, 2165, 0, 0, 39, '2164'),
	(377, 1, 0, -50924, 2166, 0, 0, 39, '2165'),
	(377, 1, 0, -50924, 2167, 0, 0, 39, '2166'),
	(377, 1, 0, -50924, 2168, 0, 0, 39, '2167'),
	(377, 1, 0, -50924, 2169, 0, 0, 39, '2168'),
	(377, 1, 0, -50924, 2170, 0, 0, 39, '2169'),
	(377, 1, 0, -50924, 2171, 0, 0, 39, '2170'),
	(377, 1, 0, -50924, 2172, 0, 0, 39, '2171'),
	(377, 1, 0, -50924, 2173, 0, 0, 39, '2172'),
	(377, 1, 0, -50924, 2174, 0, 0, 39, '2173'),
	(377, 1, 0, -50924, 2175, 0, 0, 39, '2174'),
	(377, 1, 0, -50924, 2176, 0, 0, 39, '2175'),
	(377, 1, 0, -50924, 2177, 0, 0, 39, '2176'),
	(377, 1, 0, -50924, 2178, 0, 0, 39, '2177'),
	(377, 1, 0, -50924, 2179, 0, 0, 39, '2178'),
	(377, 1, 0, -50924, 2180, 0, 0, 39, '2179'),
	(377, 1, 0, -50924, 2181, 0, 0, 39, '2180'),
	(377, 1, 0, -50924, 2182, 0, 0, 39, '2181'),
	(377, 1, 0, -50924, 2183, 0, 0, 39, '2182'),
	(377, 1, 0, -50924, 2184, 0, 0, 39, '2183'),
	(377, 1, 0, -50924, 2185, 0, 0, 39, '2184'),
	(377, 1, 0, -50924, 2186, 0, 0, 39, '2185'),
	(377, 1, 0, -50924, 2187, 0, 0, 39, '2186'),
	(377, 1, 0, -50924, 2188, 0, 0, 39, '2187'),
	(377, 1, 0, -50924, 2189, 0, 0, 39, '2188'),
	(377, 1, 0, -50924, 2190, 0, 0, 39, '2189'),
	(377, 1, 0, -50924, 2191, 0, 0, 39, '2190'),
	(377, 1, 0, -50924, 2192, 0, 0, 39, '2191'),
	(377, 1, 0, -50924, 2193, 0, 0, 39, '2192'),
	(377, 1, 0, -50924, 2194, 0, 0, 39, '2193'),
	(377, 1, 0, -50924, 2195, 0, 0, 39, '2194'),
	(377, 1, 0, -50924, 2196, 0, 0, 39, '2195'),
	(377, 1, 0, -50924, 2197, 0, 0, 39, '2196'),
	(377, 1, 0, -50924, 2198, 0, 0, 39, '2197'),
	(377, 1, 0, -50924, 2199, 0, 0, 39, '2198'),
	(377, 1, 0, -50924, 2200, 0, 0, 39, '2199'),
	(377, 1, 0, -50924, 2201, 0, 0, 39, '2200'),
	(377, 1, 0, -50924, 2202, 0, 0, 39, '2201'),
	(377, 1, 0, -50924, 2203, 0, 0, 39, '2202'),
	(377, 1, 0, -50924, 2204, 0, 0, 39, '2203'),
	(377, 1, 0, -50924, 2205, 0, 0, 39, '2204'),
	(377, 1, 0, -50924, 2206, 0, 0, 39, '2205'),
	(377, 1, 0, -50924, 2207, 0, 0, 39, '2206'),
	(377, 1, 0, -50924, 2208, 0, 0, 39, '2207'),
	(377, 1, 0, -50924, 2209, 0, 0, 39, '2208'),
	(377, 1, 0, -50924, 2210, 0, 0, 39, '2209'),
	(377, 1, 0, -50924, 2211, 0, 0, 39, '2210'),
	(377, 1, 0, -50924, 2212, 0, 0, 39, '2211'),
	(377, 1, 0, -50924, 2213, 0, 0, 39, '2212'),
	(377, 1, 0, -50924, 2214, 0, 0, 39, '2213'),
	(377, 1, 0, -50924, 2215, 0, 0, 39, '2214'),
	(377, 1, 0, -50924, 2216, 0, 0, 39, '2215'),
	(377, 1, 0, -50924, 2217, 0, 0, 39, '2216'),
	(377, 1, 0, -50924, 2218, 0, 0, 39, '2217'),
	(377, 1, 0, -50924, 2219, 0, 0, 39, '2218'),
	(377, 1, 0, -50924, 2220, 0, 0, 39, '2219'),
	(377, 1, 0, -50924, 2221, 0, 0, 39, '2220'),
	(377, 1, 0, -50924, 2222, 0, 0, 39, '2221'),
	(377, 1, 0, -50924, 2223, 0, 0, 39, '2222'),
	(377, 1, 0, -50924, 2224, 0, 0, 39, '2223'),
	(377, 1, 0, -50924, 2225, 0, 0, 39, '2224'),
	(377, 1, 0, -50924, 2226, 0, 0, 39, '2225'),
	(377, 1, 0, -50924, 2227, 0, 0, 39, '2226'),
	(377, 1, 0, -50924, 2228, 0, 0, 39, '2227'),
	(377, 1, 0, -50924, 2229, 0, 0, 39, '2228'),
	(377, 1, 0, -50924, 2230, 0, 0, 39, '2229'),
	(377, 1, 0, -50924, 2231, 0, 0, 39, '2230'),
	(377, 1, 0, -50924, 2232, 0, 0, 39, '2231'),
	(377, 1, 0, -50924, 2233, 0, 0, 39, '2232'),
	(377, 1, 0, -50924, 2234, 0, 0, 39, '2233'),
	(377, 1, 0, -50924, 2235, 0, 0, 39, '2234'),
	(377, 1, 0, -50924, 2236, 0, 0, 39, '2235'),
	(377, 1, 0, -50924, 2237, 0, 0, 39, '2236'),
	(377, 1, 0, -50924, 2238, 0, 0, 39, '2237'),
	(377, 1, 0, -50924, 2239, 0, 0, 39, '2238'),
	(377, 1, 0, -50924, 2240, 0, 0, 39, '2239'),
	(377, 1, 0, -50924, 2241, 0, 0, 39, '2240'),
	(377, 1, 0, -50924, 2242, 0, 0, 39, '2241'),
	(377, 1, 0, -50924, 2243, 0, 0, 39, '2242'),
	(377, 1, 0, -50924, 2244, 0, 0, 39, '2243'),
	(377, 1, 0, -50924, 2245, 0, 0, 39, '2244'),
	(377, 1, 0, -50924, 2246, 0, 0, 39, '2245'),
	(377, 1, 0, -50924, 2247, 0, 0, 39, '2246'),
	(377, 1, 0, -50924, 2248, 0, 0, 39, '2247'),
	(377, 1, 0, -50924, 2249, 0, 0, 39, '2248'),
	(377, 1, 0, -50924, 2250, 0, 0, 39, '2249'),
	(377, 1, 0, -50924, 2251, 0, 0, 39, '2250'),
	(377, 1, 0, -50924, 2252, 0, 0, 39, '2251'),
	(377, 1, 0, -50924, 2253, 0, 0, 39, '2252'),
	(377, 1, 0, -50924, 2254, 0, 0, 39, '2253'),
	(377, 1, 0, -50924, 2255, 0, 0, 39, '2254'),
	(377, 1, 0, -50924, 2256, 0, 0, 39, '2255'),
	(377, 1, 0, -50924, 2257, 0, 0, 39, '2256'),
	(377, 1, 0, -50924, 2258, 0, 0, 39, '2257'),
	(377, 1, 0, -50924, 2259, 0, 0, 39, '2258'),
	(377, 1, 0, -50924, 2260, 0, 0, 39, '2259'),
	(377, 1, 0, -50924, 2261, 0, 0, 39, '2260'),
	(377, 1, 0, -50924, 2262, 0, 0, 39, '2261'),
	(377, 1, 0, -50924, 2263, 0, 0, 39, '2262'),
	(377, 1, 0, -50924, 2264, 0, 0, 39, '2263'),
	(377, 1, 0, -50924, 2265, 0, 0, 39, '2264'),
	(377, 1, 0, -50924, 2266, 0, 0, 39, '2265'),
	(377, 1, 0, -50924, 2267, 0, 0, 39, '2266'),
	(377, 1, 0, -50924, 2268, 0, 0, 39, '2267'),
	(377, 1, 0, -50924, 2269, 0, 0, 39, '2268'),
	(377, 1, 0, -50924, 2270, 0, 0, 39, '2269'),
	(377, 1, 0, -50924, 2271, 0, 0, 39, '2270'),
	(377, 1, 0, -50924, 2272, 0, 0, 39, '2271'),
	(377, 1, 0, -50924, 2273, 0, 0, 39, '2272'),
	(377, 1, 0, -50924, 2274, 0, 0, 39, '2273'),
	(377, 1, 0, -50924, 2275, 0, 0, 39, '2274'),
	(377, 1, 0, -50924, 2276, 0, 0, 39, '2275'),
	(377, 1, 0, -50924, 2277, 0, 0, 39, '2276'),
	(377, 1, 0, -50924, 2278, 0, 0, 39, '2277'),
	(377, 1, 0, -50924, 2279, 0, 0, 39, '2278'),
	(377, 1, 0, -50924, 2280, 0, 0, 39, '2279'),
	(377, 1, 0, -50924, 2281, 0, 0, 39, '2280'),
	(377, 1, 0, -50924, 2282, 0, 0, 39, '2281'),
	(377, 1, 0, -50924, 2283, 0, 0, 39, '2282'),
	(377, 1, 0, -50924, 2284, 0, 0, 39, '2283'),
	(377, 1, 0, -50924, 2285, 0, 0, 39, '2284'),
	(377, 1, 0, -50924, 2286, 0, 0, 39, '2285'),
	(377, 1, 0, -50924, 2287, 0, 0, 39, '2286'),
	(377, 1, 0, -50924, 2288, 0, 0, 39, '2287'),
	(377, 1, 0, -50924, 2289, 0, 0, 39, '2288'),
	(377, 1, 0, -50924, 2290, 0, 0, 39, '2289'),
	(377, 1, 0, -50924, 2291, 0, 0, 39, '2290'),
	(377, 1, 0, -50924, 2292, 0, 0, 39, '2291'),
	(377, 1, 0, -50924, 2293, 0, 0, 39, '2292'),
	(377, 1, 0, -50924, 2294, 0, 0, 39, '2293'),
	(377, 1, 0, -50924, 2295, 0, 0, 39, '2294'),
	(377, 1, 0, -50924, 2296, 0, 0, 39, '2295'),
	(377, 1, 0, -50924, 2297, 0, 0, 39, '2296'),
	(377, 1, 0, -50924, 2298, 0, 0, 39, '2297'),
	(377, 1, 0, -50924, 2299, 0, 0, 39, '2298'),
	(377, 1, 0, -50924, 2300, 0, 0, 39, '2299'),
	(377, 1, 0, -50924, 2301, 0, 0, 39, '2300'),
	(377, 1, 0, -50924, 2302, 0, 0, 39, '2301'),
	(377, 1, 0, -50924, 2303, 0, 0, 39, '2302'),
	(377, 1, 0, -50924, 2304, 0, 0, 39, '2303'),
	(377, 1, 0, -50924, 2305, 0, 0, 39, '2304'),
	(377, 1, 0, -50924, 2306, 0, 0, 39, '2305'),
	(377, 1, 0, -50924, 2307, 0, 0, 39, '2306'),
	(377, 1, 0, -50924, 2308, 0, 0, 39, '2307'),
	(377, 1, 0, -50924, 2309, 0, 0, 39, '2308'),
	(377, 1, 0, -50924, 2310, 0, 0, 39, '2309'),
	(377, 1, 0, -50924, 2311, 0, 0, 39, '2310'),
	(377, 1, 0, -50924, 2312, 0, 0, 39, '2311'),
	(377, 1, 0, -50924, 2313, 0, 0, 39, '2312'),
	(377, 1, 0, -50924, 2314, 0, 0, 39, '2313'),
	(377, 1, 0, -50924, 2315, 0, 0, 39, '2314'),
	(377, 1, 0, -50924, 2316, 0, 0, 39, '2315'),
	(377, 1, 0, -50924, 2317, 0, 0, 39, '2316'),
	(377, 1, 0, -50924, 2318, 0, 0, 39, '2317'),
	(377, 1, 0, -50924, 2319, 0, 0, 39, '2318'),
	(377, 1, 0, -50924, 2320, 0, 0, 39, '2319'),
	(377, 1, 0, -50924, 2321, 0, 0, 39, '2320'),
	(377, 1, 0, -50924, 2322, 0, 0, 39, '2321'),
	(377, 1, 0, -50924, 2323, 0, 0, 39, '2322'),
	(377, 1, 0, -50924, 2324, 0, 0, 39, '2323'),
	(377, 1, 0, -50924, 2325, 0, 0, 39, '2324'),
	(377, 1, 0, -50924, 2326, 0, 0, 39, '2325'),
	(377, 1, 0, -50924, 2327, 0, 0, 39, '2326'),
	(377, 1, 0, -50924, 2328, 0, 0, 39, '2327'),
	(377, 1, 0, -50924, 2329, 0, 0, 39, '2328'),
	(377, 1, 0, -50924, 2330, 0, 0, 39, '2329'),
	(377, 1, 0, -50924, 2331, 0, 0, 39, '2330'),
	(377, 1, 0, -50924, 2332, 0, 0, 39, '2331'),
	(377, 1, 0, -50924, 2333, 0, 0, 39, '2332'),
	(377, 1, 0, -50924, 2334, 0, 0, 39, '2333'),
	(377, 1, 0, -50924, 2335, 0, 0, 39, '2334'),
	(377, 1, 0, -50924, 2336, 0, 0, 39, '2335'),
	(377, 1, 0, -50924, 2337, 0, 0, 39, '2336'),
	(377, 1, 0, -50924, 2338, 0, 0, 39, '2337'),
	(377, 1, 0, -50924, 2339, 0, 0, 39, '2338'),
	(377, 1, 0, -50924, 2340, 0, 0, 39, '2339'),
	(377, 1, 0, -50924, 2341, 0, 0, 39, '2340'),
	(377, 1, 0, -50924, 2342, 0, 0, 39, '2341'),
	(377, 1, 0, -50924, 2343, 0, 0, 39, '2342'),
	(377, 1, 0, -50924, 2344, 0, 0, 39, '2343'),
	(377, 1, 0, -50924, 2345, 0, 0, 39, '2344'),
	(377, 1, 0, -50924, 2346, 0, 0, 39, '2345'),
	(377, 1, 0, -50924, 2347, 0, 0, 39, '2346'),
	(377, 1, 0, -50924, 2348, 0, 0, 39, '2347'),
	(377, 1, 0, -50924, 2349, 0, 0, 39, '2348'),
	(377, 1, 0, -50924, 2350, 0, 0, 39, '2349'),
	(377, 1, 0, -50924, 2351, 0, 0, 39, '2350'),
	(377, 1, 0, -50924, 2352, 0, 0, 39, '2351'),
	(377, 1, 0, -50924, 2353, 0, 0, 39, '2352'),
	(377, 1, 0, -50924, 2354, 0, 0, 39, '2353'),
	(377, 1, 0, -50924, 2355, 0, 0, 39, '2354'),
	(377, 1, 0, -50924, 2356, 0, 0, 39, '2355'),
	(377, 1, 0, -50924, 2357, 0, 0, 39, '2356'),
	(377, 1, 0, -50924, 2358, 0, 0, 39, '2357'),
	(377, 1, 0, -50924, 2359, 0, 0, 39, '2358'),
	(377, 1, 0, -50924, 2360, 0, 0, 39, '2359'),
	(377, 1, 0, -50924, 2361, 0, 0, 39, '2360'),
	(377, 1, 0, -50924, 2362, 0, 0, 39, '2361'),
	(377, 1, 0, -50924, 2363, 0, 0, 39, '2362'),
	(377, 1, 0, -50924, 2364, 0, 0, 39, '2363'),
	(377, 1, 0, -50924, 2365, 0, 0, 39, '2364'),
	(377, 1, 0, -50924, 2366, 0, 0, 39, '2365'),
	(377, 1, 0, -50924, 2367, 0, 0, 39, '2366'),
	(377, 1, 0, -50924, 2368, 0, 0, 39, '2367'),
	(377, 1, 0, -50924, 2369, 0, 0, 39, '2368'),
	(377, 1, 0, -50924, 2370, 0, 0, 39, '2369'),
	(377, 1, 0, -50924, 2371, 0, 0, 39, '2370'),
	(377, 1, 0, -50924, 2372, 0, 0, 39, '2371'),
	(377, 1, 0, -50924, 2373, 0, 0, 39, '2372'),
	(377, 1, 0, -50924, 2374, 0, 0, 39, '2373'),
	(377, 1, 0, -50924, 2375, 0, 0, 39, '2374'),
	(377, 1, 0, -50924, 2376, 0, 0, 39, '2375'),
	(377, 1, 0, -50924, 2377, 0, 0, 39, '2376'),
	(377, 1, 0, -50924, 2378, 0, 0, 39, '2377'),
	(377, 1, 0, -50924, 2379, 0, 0, 39, '2378'),
	(377, 1, 0, -50924, 2380, 0, 0, 39, '2379'),
	(377, 1, 0, -50924, 2381, 0, 0, 39, '2380'),
	(377, 1, 0, -50924, 2382, 0, 0, 39, '2381'),
	(377, 1, 0, -50924, 2383, 0, 0, 39, '2382'),
	(377, 1, 0, -50924, 2384, 0, 0, 39, '2383'),
	(377, 1, 0, -50924, 2385, 0, 0, 39, '2384'),
	(377, 1, 0, -50924, 2386, 0, 0, 39, '2385'),
	(377, 1, 0, -50924, 2387, 0, 0, 39, '2386'),
	(377, 1, 0, -50924, 2388, 0, 0, 39, '2387'),
	(377, 1, 0, -50924, 2389, 0, 0, 39, '2388'),
	(377, 1, 0, -50924, 2390, 0, 0, 39, '2389'),
	(377, 1, 0, -50924, 2391, 0, 0, 39, '2390'),
	(377, 1, 0, -50924, 2392, 0, 0, 39, '2391'),
	(377, 1, 0, -50924, 2393, 0, 0, 39, '2392'),
	(377, 1, 0, -50924, 2394, 0, 0, 39, '2393'),
	(377, 1, 0, -50924, 2395, 0, 0, 39, '2394'),
	(377, 1, 0, -50924, 2396, 0, 0, 39, '2395'),
	(377, 1, 0, -50924, 2397, 0, 0, 39, '2396'),
	(377, 1, 0, -50924, 2398, 0, 0, 39, '2397'),
	(377, 1, 0, -50924, 2399, 0, 0, 39, '2398'),
	(377, 1, 0, -50924, 2400, 0, 0, 39, '2399'),
	(377, 1, 0, -50924, 2401, 0, 0, 39, '2400'),
	(377, 1, 0, -50924, 2402, 0, 0, 39, '2401'),
	(377, 1, 0, -50924, 2403, 0, 0, 39, '2402'),
	(377, 1, 0, -50924, 2404, 0, 0, 39, '2403'),
	(377, 1, 0, -50924, 2405, 0, 0, 39, '2404'),
	(377, 1, 0, -50924, 2406, 0, 0, 39, '2405'),
	(377, 1, 0, -50924, 2407, 0, 0, 39, '2406'),
	(377, 1, 0, -50924, 2408, 0, 0, 39, '2407'),
	(377, 1, 0, -50924, 2409, 0, 0, 39, '2408'),
	(377, 1, 0, -50924, 2410, 0, 0, 39, '2409'),
	(377, 1, 0, -50924, 2411, 0, 0, 39, '2410'),
	(377, 1, 0, -50924, 2412, 0, 0, 39, '2411'),
	(377, 1, 0, -50924, 2413, 0, 0, 39, '2412'),
	(377, 1, 0, -50924, 2414, 0, 0, 39, '2413'),
	(377, 1, 0, -50924, 2415, 0, 0, 39, '2414'),
	(377, 1, 0, -50924, 2416, 0, 0, 39, '2415'),
	(377, 1, 0, -50924, 2417, 0, 0, 39, '2416'),
	(377, 1, 0, -50924, 2418, 0, 0, 39, '2417'),
	(377, 1, 0, -50924, 2419, 0, 0, 39, '2418'),
	(377, 1, 0, -50924, 2420, 0, 0, 39, '2419'),
	(377, 1, 0, -50924, 2421, 0, 0, 39, '2420'),
	(377, 1, 0, -50924, 2422, 0, 0, 39, '2421'),
	(377, 1, 0, -50924, 2423, 0, 0, 39, '2422'),
	(377, 1, 0, -50924, 2424, 0, 0, 39, '2423'),
	(377, 1, 0, -50924, 2425, 0, 0, 39, '2424'),
	(377, 1, 0, -50924, 2426, 0, 0, 39, '2425'),
	(377, 1, 0, -50924, 2427, 0, 0, 39, '2426'),
	(377, 1, 0, -50924, 2428, 0, 0, 39, '2427'),
	(377, 1, 0, -50924, 2429, 0, 0, 39, '2428'),
	(377, 1, 0, -50924, 2430, 0, 0, 39, '2429'),
	(377, 1, 0, -50924, 2431, 0, 0, 39, '2430'),
	(377, 1, 0, -50924, 2432, 0, 0, 39, '2431'),
	(377, 1, 0, -50924, 2433, 0, 0, 39, '2432'),
	(377, 1, 0, -50924, 2434, 0, 0, 39, '2433'),
	(377, 1, 0, -50924, 2435, 0, 0, 39, '2434'),
	(377, 1, 0, -50924, 2436, 0, 0, 39, '2435'),
	(377, 1, 0, -50924, 2437, 0, 0, 39, '2436'),
	(377, 1, 0, -50924, 2438, 0, 0, 39, '2437'),
	(377, 1, 0, -50924, 2439, 0, 0, 39, '2438'),
	(377, 1, 0, -50924, 2440, 0, 0, 39, '2439'),
	(377, 1, 0, -50924, 2441, 0, 0, 39, '2440'),
	(377, 1, 0, -50924, 2442, 0, 0, 39, '2441'),
	(377, 1, 0, -50924, 2443, 0, 0, 39, '2442'),
	(377, 1, 0, -50924, 2444, 0, 0, 39, '2443'),
	(377, 1, 0, -50924, 2445, 0, 0, 39, '2444'),
	(377, 1, 0, -50924, 2446, 0, 0, 39, '2445'),
	(377, 1, 0, -50924, 2447, 0, 0, 39, '2446'),
	(377, 1, 0, -50924, 2448, 0, 0, 39, '2447'),
	(377, 1, 0, -50924, 2449, 0, 0, 39, '2448'),
	(377, 1, 0, -50924, 2450, 0, 0, 39, '2449'),
	(377, 1, 0, -50924, 2451, 0, 0, 39, '2450'),
	(377, 1, 0, -50924, 2452, 0, 0, 39, '2451'),
	(377, 1, 0, -50924, 2453, 0, 0, 39, '2452'),
	(377, 1, 0, -50924, 2454, 0, 0, 39, '2453'),
	(377, 1, 0, -50924, 2455, 0, 0, 39, '2454'),
	(377, 1, 0, -50924, 2456, 0, 0, 39, '2455'),
	(377, 1, 0, -50924, 2457, 0, 0, 39, '2456'),
	(377, 1, 0, -50924, 2458, 0, 0, 39, '2457'),
	(377, 1, 0, -50924, 2459, 0, 0, 39, '2458'),
	(377, 1, 0, -50924, 2460, 0, 0, 39, '2459'),
	(377, 1, 0, -50924, 2461, 0, 0, 39, '2460'),
	(377, 1, 0, -50924, 2462, 0, 0, 39, '2461'),
	(377, 1, 0, -50924, 2463, 0, 0, 39, '2462'),
	(377, 1, 0, -50924, 2464, 0, 0, 39, '2463'),
	(377, 1, 0, -50924, 2465, 0, 0, 39, '2464'),
	(377, 1, 0, -50924, 2466, 0, 0, 39, '2465'),
	(377, 1, 0, -50924, 2467, 0, 0, 39, '2466'),
	(377, 1, 0, -50924, 2468, 0, 0, 39, '2467'),
	(377, 1, 0, -50924, 2469, 0, 0, 39, '2468'),
	(377, 1, 0, -50924, 2470, 0, 0, 39, '2469'),
	(377, 1, 0, -50924, 2471, 0, 0, 39, '2470'),
	(377, 1, 0, -50924, 2472, 0, 0, 39, '2471'),
	(377, 1, 0, -50924, 2473, 0, 0, 39, '2472'),
	(377, 1, 0, -50924, 2474, 0, 0, 39, '2473'),
	(377, 1, 0, -50924, 2475, 0, 0, 39, '2474'),
	(377, 1, 0, -50924, 2476, 0, 0, 39, '2475'),
	(377, 1, 0, -50924, 2477, 0, 0, 39, '2476'),
	(377, 1, 0, -50924, 2478, 0, 0, 39, '2477'),
	(377, 1, 0, -50924, 2479, 0, 0, 39, '2478'),
	(377, 1, 0, -50924, 2480, 0, 0, 39, '2479'),
	(377, 1, 0, -50924, 2481, 0, 0, 39, '2480'),
	(377, 1, 0, -50924, 2482, 0, 0, 39, '2481'),
	(377, 1, 0, -50924, 2483, 0, 0, 39, '2482'),
	(377, 1, 0, -50924, 2484, 0, 0, 39, '2483'),
	(377, 1, 0, -50924, 2485, 0, 0, 39, '2484'),
	(377, 1, 0, -50924, 2486, 0, 0, 39, '2485'),
	(377, 1, 0, -50924, 2487, 0, 0, 39, '2486'),
	(377, 1, 0, -50924, 2488, 0, 0, 39, '2487'),
	(377, 1, 0, -50924, 2489, 0, 0, 39, '2488'),
	(377, 1, 0, -50924, 2490, 0, 0, 39, '2489'),
	(377, 1, 0, -50924, 2491, 0, 0, 39, '2490'),
	(377, 1, 0, -50924, 2492, 0, 0, 39, '2491'),
	(377, 1, 0, -50924, 2493, 0, 0, 39, '2492'),
	(377, 1, 0, -50924, 2494, 0, 0, 39, '2493'),
	(377, 1, 0, -50924, 2495, 0, 0, 39, '2494'),
	(377, 1, 0, -50924, 2496, 0, 0, 39, '2495'),
	(377, 1, 0, -50924, 2497, 0, 0, 39, '2496'),
	(377, 1, 0, -50924, 2498, 0, 0, 39, '2497'),
	(377, 1, 0, -50924, 2499, 0, 0, 39, '2498'),
	(377, 1, 0, -50924, 2500, 0, 0, 39, '2499'),
	(377, 1, 0, -50924, 2501, 0, 0, 39, '2500'),
	(377, 1, 0, -50924, 2502, 0, 0, 39, '2501'),
	(377, 1, 0, -50924, 2503, 0, 0, 39, '2502'),
	(377, 1, 0, -50924, 2504, 0, 0, 39, '2503'),
	(377, 1, 0, -50924, 2505, 0, 0, 39, '2504'),
	(377, 1, 0, -50924, 2506, 0, 0, 39, '2505'),
	(377, 1, 0, -50924, 2507, 0, 0, 39, '2506'),
	(377, 1, 0, -50924, 2508, 0, 0, 39, '2507'),
	(377, 1, 0, -50924, 2509, 0, 0, 39, '2508'),
	(377, 1, 0, -50924, 2510, 0, 0, 39, '2509'),
	(377, 1, 0, -50924, 2511, 0, 0, 39, '2510'),
	(377, 1, 0, -50924, 2512, 0, 0, 39, '2511'),
	(377, 1, 0, -50924, 2513, 0, 0, 39, '2512'),
	(377, 1, 0, -50924, 2514, 0, 0, 39, '2513'),
	(377, 1, 0, -50924, 2515, 0, 0, 39, '2514'),
	(377, 1, 0, -50924, 2516, 0, 0, 39, '2515'),
	(377, 1, 0, -50924, 2517, 0, 0, 39, '2516'),
	(377, 1, 0, -50924, 2518, 0, 0, 39, '2517'),
	(377, 1, 0, -50924, 2519, 0, 0, 39, '2518'),
	(377, 1, 0, -50924, 2520, 0, 0, 39, '2519'),
	(377, 1, 0, -50924, 2521, 0, 0, 39, '2520'),
	(377, 1, 0, -50924, 2522, 0, 0, 39, '2521'),
	(377, 1, 0, -50924, 2523, 0, 0, 39, '2522'),
	(377, 1, 0, -50924, 2524, 0, 0, 39, '2523'),
	(377, 1, 0, -50924, 2525, 0, 0, 39, '2524'),
	(377, 1, 0, -50924, 2526, 0, 0, 39, '2525'),
	(377, 1, 0, -50924, 2527, 0, 0, 39, '2526'),
	(377, 1, 0, -50924, 2528, 0, 0, 39, '2527'),
	(377, 1, 0, -50924, 2529, 0, 0, 39, '2528'),
	(377, 1, 0, -50924, 2530, 0, 0, 39, '2529'),
	(377, 1, 0, -50924, 2531, 0, 0, 39, '2530'),
	(377, 1, 0, -50924, 2532, 0, 0, 39, '2531'),
	(377, 1, 0, -50924, 2533, 0, 0, 39, '2532'),
	(377, 1, 0, -50924, 2534, 0, 0, 39, '2533'),
	(377, 1, 0, -50924, 2535, 0, 0, 39, '2534'),
	(377, 1, 0, -50924, 2536, 0, 0, 39, '2535'),
	(377, 1, 0, -50924, 2537, 0, 0, 39, '2536'),
	(377, 1, 0, -50924, 2538, 0, 0, 39, '2537'),
	(377, 1, 0, -50924, 2539, 0, 0, 39, '2538'),
	(377, 1, 0, -50924, 2540, 0, 0, 39, '2539'),
	(377, 1, 0, -50924, 2541, 0, 0, 39, '2540'),
	(377, 1, 0, -50924, 2542, 0, 0, 39, '2541'),
	(377, 1, 0, -50924, 2543, 0, 0, 39, '2542'),
	(377, 1, 0, -50924, 2544, 0, 0, 39, '2543'),
	(377, 1, 0, -50924, 2545, 0, 0, 39, '2544'),
	(377, 1, 0, -50924, 2546, 0, 0, 39, '2545'),
	(377, 1, 0, -50924, 2547, 0, 0, 39, '2546'),
	(377, 1, 0, -50924, 2548, 0, 0, 39, '2547'),
	(377, 1, 0, -50924, 2549, 0, 0, 39, '2548'),
	(377, 1, 0, -50924, 2550, 0, 0, 39, '2549'),
	(377, 1, 0, -50924, 2551, 0, 0, 39, '2550'),
	(377, 1, 0, -50924, 2552, 0, 0, 39, '2551'),
	(377, 1, 0, -50924, 2553, 0, 0, 39, '2552'),
	(377, 1, 0, -50924, 2554, 0, 0, 39, '2553'),
	(377, 1, 0, -50924, 2555, 0, 0, 39, '2554'),
	(377, 1, 0, -50924, 2556, 0, 0, 39, '2555'),
	(377, 1, 0, -50924, 2557, 0, 0, 39, '2556'),
	(377, 1, 0, -50924, 2558, 0, 0, 39, '2557'),
	(377, 1, 0, -50924, 2559, 0, 0, 39, '2558'),
	(377, 1, 0, -50924, 2560, 0, 0, 39, '2559'),
	(377, 1, 0, -50924, 2561, 0, 0, 39, '2560'),
	(377, 1, 0, -50924, 2562, 0, 0, 39, '2561'),
	(377, 1, 0, -50924, 2563, 0, 0, 39, '2562'),
	(377, 1, 0, -50924, 2564, 0, 0, 39, '2563'),
	(377, 1, 0, -50924, 2565, 0, 0, 39, '2564'),
	(377, 1, 0, -50924, 2566, 0, 0, 39, '2565'),
	(377, 1, 0, -50924, 2567, 0, 0, 39, '2566'),
	(377, 1, 0, -50924, 2568, 0, 0, 39, '2567'),
	(377, 1, 0, -50924, 2569, 0, 0, 39, '2568'),
	(377, 1, 0, -50924, 2570, 0, 0, 39, '2569'),
	(377, 1, 0, -50924, 2571, 0, 0, 39, '2570'),
	(377, 1, 0, -50924, 2572, 0, 0, 39, '2571'),
	(377, 1, 0, -50924, 2573, 0, 0, 39, '2572'),
	(377, 1, 0, -50924, 2574, 0, 0, 39, '2573'),
	(377, 1, 0, -50924, 2575, 0, 0, 39, '2574'),
	(377, 1, 0, -50924, 2576, 0, 0, 39, '2575'),
	(377, 1, 0, -50924, 2577, 0, 0, 39, '2576'),
	(377, 1, 0, -50924, 2578, 0, 0, 39, '2577'),
	(377, 1, 0, -50924, 2579, 0, 0, 39, '2578'),
	(377, 1, 0, -50924, 2580, 0, 0, 39, '2579'),
	(377, 1, 0, -50924, 2581, 0, 0, 39, '2580'),
	(377, 1, 0, -50924, 2582, 0, 0, 39, '2581'),
	(377, 1, 0, -50924, 2583, 0, 0, 39, '2582'),
	(377, 1, 0, -50924, 2584, 0, 0, 39, '2583'),
	(377, 1, 0, -50924, 2585, 0, 0, 39, '2584'),
	(377, 1, 0, -50924, 2586, 0, 0, 39, '2585'),
	(377, 1, 0, -50924, 2587, 0, 0, 39, '2586'),
	(377, 1, 0, -50924, 2588, 0, 0, 39, '2587'),
	(377, 1, 0, -50924, 2589, 0, 0, 39, '2588'),
	(377, 1, 0, -50924, 2590, 0, 0, 39, '2589'),
	(377, 1, 0, -50924, 2591, 0, 0, 39, '2590'),
	(377, 1, 0, -50924, 2592, 0, 0, 39, '2591'),
	(377, 1, 0, -50924, 2593, 0, 0, 39, '2592'),
	(377, 1, 0, -50924, 2594, 0, 0, 39, '2593'),
	(377, 1, 0, -50924, 2595, 0, 0, 39, '2594'),
	(377, 1, 0, -50924, 2596, 0, 0, 39, '2595'),
	(377, 1, 0, -50924, 2597, 0, 0, 39, '2596'),
	(377, 1, 0, -50924, 2598, 0, 0, 39, '2597'),
	(377, 1, 0, -50924, 2599, 0, 0, 39, '2598'),
	(377, 1, 0, -50924, 2600, 0, 0, 39, '2599'),
	(377, 1, 0, -50924, 2601, 0, 0, 39, '2600'),
	(377, 1, 0, -50924, 2602, 0, 0, 39, '2601'),
	(377, 1, 0, -50924, 2603, 0, 0, 39, '2602'),
	(377, 1, 0, -50924, 2604, 0, 0, 39, '2603'),
	(377, 1, 0, -50924, 2605, 0, 0, 39, '2604'),
	(377, 1, 0, -50924, 2606, 0, 0, 39, '2605'),
	(377, 1, 0, -50924, 2607, 0, 0, 39, '2606'),
	(377, 1, 0, -50924, 2608, 0, 0, 39, '2607'),
	(377, 1, 0, -50924, 2609, 0, 0, 39, '2608'),
	(377, 1, 0, -50924, 2610, 0, 0, 39, '2609'),
	(377, 1, 0, -50924, 2611, 0, 0, 39, '2610'),
	(377, 1, 0, -50924, 2612, 0, 0, 39, '2611'),
	(377, 1, 0, -50924, 2613, 0, 0, 39, '2612'),
	(377, 1, 0, -50924, 2614, 0, 0, 39, '2613'),
	(377, 1, 0, -50924, 2615, 0, 0, 39, '2614'),
	(377, 1, 0, -50924, 2616, 0, 0, 39, '2615'),
	(377, 1, 0, -50924, 2617, 0, 0, 39, '2616'),
	(377, 1, 0, -50924, 2618, 0, 0, 39, '2617'),
	(377, 1, 0, -50924, 2619, 0, 0, 39, '2618'),
	(377, 1, 0, -50924, 2620, 0, 0, 39, '2619'),
	(377, 1, 0, -50924, 2621, 0, 0, 39, '2620'),
	(377, 1, 0, -50924, 2622, 0, 0, 39, '2621'),
	(377, 1, 0, -50924, 2623, 0, 0, 39, '2622'),
	(377, 1, 0, -50924, 2624, 0, 0, 39, '2623'),
	(377, 1, 0, -50924, 2625, 0, 0, 39, '2624'),
	(377, 1, 0, -50924, 2626, 0, 0, 39, '2625'),
	(377, 1, 0, -50924, 2627, 0, 0, 39, '2626'),
	(377, 1, 0, -50924, 2628, 0, 0, 39, '2627'),
	(377, 1, 0, -50924, 2629, 0, 0, 39, '2628'),
	(377, 1, 0, -50924, 2630, 0, 0, 39, '2629'),
	(377, 1, 0, -50924, 2631, 0, 0, 39, '2630'),
	(377, 1, 0, -50924, 2632, 0, 0, 39, '2631'),
	(377, 1, 0, -50924, 2633, 0, 0, 39, '2632'),
	(377, 1, 0, -50924, 2634, 0, 0, 39, '2633'),
	(377, 1, 0, -50924, 2635, 0, 0, 39, '2634'),
	(377, 1, 0, -50924, 2636, 0, 0, 39, '2635'),
	(377, 1, 0, -50924, 2637, 0, 0, 39, '2636'),
	(377, 1, 0, -50924, 2638, 0, 0, 39, '2637'),
	(377, 1, 0, -50924, 2639, 0, 0, 39, '2638'),
	(377, 1, 0, -50924, 2640, 0, 0, 39, '2639'),
	(377, 1, 0, -50924, 2641, 0, 0, 39, '2640'),
	(377, 1, 0, -50924, 2642, 0, 0, 39, '2641'),
	(377, 1, 0, -50924, 2643, 0, 0, 39, '2642'),
	(377, 1, 0, -50924, 2644, 0, 0, 39, '2643'),
	(377, 1, 0, -50924, 2645, 0, 0, 39, '2644'),
	(377, 1, 0, -50924, 2646, 0, 0, 39, '2645'),
	(377, 1, 0, -50924, 2647, 0, 0, 39, '2646'),
	(377, 1, 0, -50924, 2648, 0, 0, 39, '2647'),
	(377, 1, 0, -50924, 2649, 0, 0, 39, '2648'),
	(377, 1, 0, -50924, 2650, 0, 0, 39, '2649'),
	(377, 1, 0, -50924, 2651, 0, 0, 39, '2650'),
	(377, 1, 0, -50924, 2652, 0, 0, 39, '2651'),
	(377, 1, 0, -50924, 2653, 0, 0, 39, '2652'),
	(377, 1, 0, -50924, 2654, 0, 0, 39, '2653'),
	(377, 1, 0, -50924, 2655, 0, 0, 39, '2654'),
	(377, 1, 0, -50924, 2656, 0, 0, 39, '2655'),
	(377, 1, 0, -50924, 2657, 0, 0, 39, '2656'),
	(377, 1, 0, -50924, 2658, 0, 0, 39, '2657'),
	(377, 1, 0, -50924, 2659, 0, 0, 39, '2658'),
	(377, 1, 0, -50924, 2660, 0, 0, 39, '2659'),
	(377, 1, 0, -50924, 2661, 0, 0, 39, '2660'),
	(377, 1, 0, -50924, 2662, 0, 0, 39, '2661'),
	(377, 1, 0, -50924, 2663, 0, 0, 39, '2662'),
	(377, 1, 0, -50924, 2664, 0, 0, 39, '2663'),
	(377, 1, 0, -50924, 2665, 0, 0, 39, '2664'),
	(377, 1, 0, -50924, 2666, 0, 0, 39, '2665'),
	(377, 1, 0, -50924, 2667, 0, 0, 39, '2666'),
	(377, 1, 0, -50924, 2668, 0, 0, 39, '2667'),
	(377, 1, 0, -50924, 2669, 0, 0, 39, '2668'),
	(377, 1, 0, -50924, 2670, 0, 0, 39, '2669'),
	(377, 1, 0, -50924, 2671, 0, 0, 39, '2670'),
	(377, 1, 0, -50924, 2672, 0, 0, 39, '2671'),
	(377, 1, 0, -50924, 2673, 0, 0, 39, '2672'),
	(377, 1, 0, -50924, 2674, 0, 0, 39, '2673'),
	(377, 1, 0, -50924, 2675, 0, 0, 39, '2674'),
	(377, 1, 0, -50924, 2676, 0, 0, 39, '2675'),
	(377, 1, 0, -50924, 2677, 0, 0, 39, '2676'),
	(377, 1, 0, -50924, 2678, 0, 0, 39, '2677'),
	(377, 1, 0, -50924, 2679, 0, 0, 39, '2678'),
	(377, 1, 0, -50924, 2680, 0, 0, 39, '2679'),
	(377, 1, 0, -50924, 2681, 0, 0, 39, '2680'),
	(377, 1, 0, -50924, 2682, 0, 0, 39, '2681'),
	(377, 1, 0, -50924, 2683, 0, 0, 39, '2682'),
	(377, 1, 0, -50924, 2684, 0, 0, 39, '2683'),
	(377, 1, 0, -50924, 2685, 0, 0, 39, '2684'),
	(377, 1, 0, -50924, 2686, 0, 0, 39, '2685'),
	(377, 1, 0, -50924, 2687, 0, 0, 39, '2686'),
	(377, 1, 0, -50924, 2688, 0, 0, 39, '2687'),
	(377, 1, 0, -50924, 2689, 0, 0, 39, '2688'),
	(377, 1, 0, -50924, 2690, 0, 0, 39, '2689'),
	(377, 1, 0, -50924, 2691, 0, 0, 39, '2690'),
	(377, 1, 0, -50924, 2692, 0, 0, 39, '2691'),
	(377, 1, 0, -50924, 2693, 0, 0, 39, '2692'),
	(377, 1, 0, -50924, 2694, 0, 0, 39, '2693'),
	(377, 1, 0, -50924, 2695, 0, 0, 39, '2694'),
	(377, 1, 0, -50924, 2696, 0, 0, 39, '2695'),
	(377, 1, 0, -50924, 2697, 0, 0, 39, '2696'),
	(377, 1, 0, -50924, 2698, 0, 0, 39, '2697'),
	(377, 1, 0, -50924, 2699, 0, 0, 39, '2698'),
	(377, 1, 0, -50924, 2700, 0, 0, 39, '2699'),
	(377, 1, 0, -50924, 2701, 0, 0, 39, '2700'),
	(377, 1, 0, -50924, 2702, 0, 0, 39, '2701'),
	(377, 1, 0, -50924, 2703, 0, 0, 39, '2702'),
	(377, 1, 0, -50924, 2704, 0, 0, 39, '2703'),
	(377, 1, 0, -50924, 2705, 0, 0, 39, '2704'),
	(377, 1, 0, -50924, 2706, 0, 0, 39, '2705'),
	(377, 1, 0, -50924, 2707, 0, 0, 39, '2706'),
	(377, 1, 0, -50924, 2708, 0, 0, 39, '2707'),
	(377, 1, 0, -50924, 2709, 0, 0, 39, '2708'),
	(377, 1, 0, -50924, 2710, 0, 0, 39, '2709'),
	(377, 1, 0, -50924, 2711, 0, 0, 39, '2710'),
	(377, 1, 0, -50924, 2712, 0, 0, 39, '2711'),
	(377, 1, 0, -50924, 2713, 0, 0, 39, '2712'),
	(377, 1, 0, -50924, 2714, 0, 0, 39, '2713'),
	(377, 1, 0, -50924, 2715, 0, 0, 39, '2714'),
	(377, 1, 0, -50924, 2716, 0, 0, 39, '2715'),
	(377, 1, 0, -50924, 2717, 0, 0, 39, '2716'),
	(377, 1, 0, -50924, 2718, 0, 0, 39, '2717'),
	(377, 1, 0, -50924, 2719, 0, 0, 39, '2718'),
	(377, 1, 0, -50924, 2720, 0, 0, 39, '2719'),
	(377, 1, 0, -50924, 2721, 0, 0, 39, '2720'),
	(377, 1, 0, -50924, 2722, 0, 0, 39, '2721'),
	(377, 1, 0, -50924, 2723, 0, 0, 39, '2722'),
	(377, 1, 0, -50924, 2724, 0, 0, 39, '2723'),
	(377, 1, 0, -50924, 2725, 0, 0, 39, '2724'),
	(377, 1, 0, -50924, 2726, 0, 0, 39, '2725'),
	(377, 1, 0, -50924, 2727, 0, 0, 39, '2726'),
	(377, 1, 0, -50924, 2728, 0, 0, 39, '2727'),
	(377, 1, 0, -50924, 2729, 0, 0, 39, '2728'),
	(377, 1, 0, -50924, 2730, 0, 0, 39, '2729'),
	(377, 1, 0, -50924, 2731, 0, 0, 39, '2730'),
	(377, 1, 0, -50924, 2732, 0, 0, 39, '2731'),
	(377, 1, 0, -50924, 2733, 0, 0, 39, '2732'),
	(377, 1, 0, -50924, 2734, 0, 0, 39, '2733'),
	(377, 1, 0, -50924, 2735, 0, 0, 39, '2734'),
	(377, 1, 0, -50924, 2736, 0, 0, 39, '2735'),
	(377, 1, 0, -50924, 2737, 0, 0, 39, '2736'),
	(377, 1, 0, -50924, 2738, 0, 0, 39, '2737'),
	(377, 1, 0, -50924, 2739, 0, 0, 39, '2738'),
	(377, 1, 0, -50924, 2740, 0, 0, 39, '2739'),
	(377, 1, 0, -50924, 2741, 0, 0, 39, '2740'),
	(377, 1, 0, -50924, 2742, 0, 0, 39, '2741'),
	(377, 1, 0, -50924, 2743, 0, 0, 39, '2742'),
	(377, 1, 0, -50924, 2744, 0, 0, 39, '2743'),
	(377, 1, 0, -50924, 2745, 0, 0, 39, '2744'),
	(377, 1, 0, -50924, 2746, 0, 0, 39, '2745'),
	(377, 1, 0, -50924, 2747, 0, 0, 39, '2746'),
	(377, 1, 0, -50924, 2748, 0, 0, 39, '2747'),
	(377, 1, 0, -50924, 2749, 0, 0, 39, '2748'),
	(377, 1, 0, -50924, 2750, 0, 0, 39, '2749'),
	(377, 1, 0, -50924, 2751, 0, 0, 39, '2750'),
	(377, 1, 0, -50924, 2752, 0, 0, 39, '2751'),
	(377, 1, 0, -50924, 2753, 0, 0, 39, '2752'),
	(377, 1, 0, -50924, 2754, 0, 0, 39, '2753'),
	(377, 1, 0, -50924, 2755, 0, 0, 39, '2754'),
	(377, 1, 0, -50924, 2756, 0, 0, 39, '2755'),
	(377, 1, 0, -50924, 2757, 0, 0, 39, '2756'),
	(377, 1, 0, -50924, 2758, 0, 0, 39, '2757'),
	(377, 1, 0, -50924, 2759, 0, 0, 39, '2758'),
	(377, 1, 0, -50924, 2760, 0, 0, 39, '2759'),
	(377, 1, 0, -50924, 2761, 0, 0, 39, '2760'),
	(377, 1, 0, -50924, 2762, 0, 0, 39, '2761'),
	(377, 1, 0, -50924, 2763, 0, 0, 39, '2762'),
	(377, 1, 0, -50924, 2764, 0, 0, 39, '2763'),
	(377, 1, 0, -50924, 2765, 0, 0, 39, '2764'),
	(377, 1, 0, -50924, 2766, 0, 0, 39, '2765'),
	(377, 1, 0, -50924, 2767, 0, 0, 39, '2766'),
	(377, 1, 0, -50924, 2768, 0, 0, 39, '2767'),
	(377, 1, 0, -50924, 2769, 0, 0, 39, '2768'),
	(377, 1, 0, -50924, 2770, 0, 0, 39, '2769'),
	(377, 1, 0, -50924, 2771, 0, 0, 39, '2770'),
	(377, 1, 0, -50924, 2772, 0, 0, 39, '2771'),
	(377, 1, 0, -50924, 2773, 0, 0, 39, '2772'),
	(377, 1, 0, -50924, 2774, 0, 0, 39, '2773'),
	(377, 1, 0, -50924, 2775, 0, 0, 39, '2774'),
	(377, 1, 0, -50924, 2776, 0, 0, 39, '2775'),
	(377, 1, 0, -50924, 2777, 0, 0, 39, '2776'),
	(377, 1, 0, -50924, 2778, 0, 0, 39, '2777'),
	(377, 1, 0, -50924, 2779, 0, 0, 39, '2778'),
	(377, 1, 0, -50924, 2780, 0, 0, 39, '2779'),
	(377, 1, 0, -50924, 2781, 0, 0, 39, '2780'),
	(377, 1, 0, -50924, 2782, 0, 0, 39, '2781'),
	(377, 1, 0, -50924, 2783, 0, 0, 39, '2782'),
	(377, 1, 0, -50924, 2784, 0, 0, 39, '2783'),
	(377, 1, 0, -50924, 2785, 0, 0, 39, '2784'),
	(377, 1, 0, -50924, 2786, 0, 0, 39, '2785'),
	(377, 1, 0, -50924, 2787, 0, 0, 39, '2786'),
	(377, 1, 0, -50924, 2788, 0, 0, 39, '2787'),
	(377, 1, 0, -50924, 2789, 0, 0, 39, '2788'),
	(377, 1, 0, -50924, 2790, 0, 0, 39, '2789'),
	(377, 1, 0, -50924, 2791, 0, 0, 39, '2790'),
	(377, 1, 0, -50924, 2792, 0, 0, 39, '2791'),
	(377, 1, 0, -50924, 2793, 0, 0, 39, '2792'),
	(377, 1, 0, -50924, 2794, 0, 0, 39, '2793'),
	(377, 1, 0, -50924, 2795, 0, 0, 39, '2794'),
	(377, 1, 0, -50924, 2796, 0, 0, 39, '2795'),
	(377, 1, 0, -50924, 2797, 0, 0, 39, '2796'),
	(377, 1, 0, -50924, 2798, 0, 0, 39, '2797'),
	(377, 1, 0, -50924, 2799, 0, 0, 39, '2798'),
	(377, 1, 0, -50924, 2800, 0, 0, 39, '2799'),
	(377, 1, 0, -50924, 2801, 0, 0, 39, '2800'),
	(377, 1, 0, -50924, 2802, 0, 0, 39, '2801'),
	(377, 1, 0, -50924, 2803, 0, 0, 39, '2802'),
	(377, 1, 0, -50924, 2804, 0, 0, 39, '2803'),
	(377, 1, 0, -50924, 2805, 0, 0, 39, '2804'),
	(377, 1, 0, -50924, 2806, 0, 0, 39, '2805'),
	(377, 1, 0, -50924, 2807, 0, 0, 39, '2806'),
	(377, 1, 0, -50924, 2808, 0, 0, 39, '2807'),
	(377, 1, 0, -50924, 2809, 0, 0, 39, '2808'),
	(377, 1, 0, -50924, 2810, 0, 0, 39, '2809'),
	(377, 1, 0, -50924, 2811, 0, 0, 39, '2810'),
	(377, 1, 0, -50924, 2812, 0, 0, 39, '2811'),
	(377, 1, 0, -50924, 2813, 0, 0, 39, '2812'),
	(377, 1, 0, -50924, 2814, 0, 0, 39, '2813'),
	(377, 1, 0, -50924, 2815, 0, 0, 39, '2814'),
	(377, 1, 0, -50924, 2816, 0, 0, 39, '2815'),
	(377, 1, 0, -50924, 2817, 0, 0, 39, '2816'),
	(377, 1, 0, -50924, 2818, 0, 0, 39, '2817'),
	(377, 1, 0, -50924, 2819, 0, 0, 39, '2818'),
	(377, 1, 0, -50924, 2820, 0, 0, 39, '2819'),
	(377, 1, 0, -50924, 2821, 0, 0, 39, '2820'),
	(377, 1, 0, -50924, 2822, 0, 0, 39, '2821'),
	(377, 1, 0, -50924, 2823, 0, 0, 39, '2822'),
	(377, 1, 0, -50924, 2824, 0, 0, 39, '2823'),
	(377, 1, 0, -50924, 2825, 0, 0, 39, '2824'),
	(377, 1, 0, -50924, 2826, 0, 0, 39, '2825'),
	(377, 1, 0, -50924, 2827, 0, 0, 39, '2826'),
	(377, 1, 0, -50924, 2828, 0, 0, 39, '2827'),
	(377, 1, 0, -50924, 2829, 0, 0, 39, '2828'),
	(377, 1, 0, -50924, 2830, 0, 0, 39, '2829'),
	(377, 1, 0, -50924, 2831, 0, 0, 39, '2830'),
	(377, 1, 0, -50924, 2832, 0, 0, 39, '2831'),
	(377, 1, 0, -50924, 2833, 0, 0, 39, '2832'),
	(377, 1, 0, -50924, 2834, 0, 0, 39, '2833'),
	(377, 1, 0, -50924, 2835, 0, 0, 39, '2834'),
	(377, 1, 0, -50924, 2836, 0, 0, 39, '2835'),
	(377, 1, 0, -50924, 2837, 0, 0, 39, '2836'),
	(377, 1, 0, -50924, 2838, 0, 0, 39, '2837'),
	(377, 1, 0, -50924, 2839, 0, 0, 39, '2838'),
	(377, 1, 0, -50924, 2840, 0, 0, 39, '2839'),
	(377, 1, 0, -50924, 2841, 0, 0, 39, '2840'),
	(377, 1, 0, -50924, 2842, 0, 0, 39, '2841'),
	(377, 1, 0, -50924, 2843, 0, 0, 39, '2842'),
	(377, 1, 0, -50924, 2844, 0, 0, 39, '2843'),
	(377, 1, 0, -50924, 2845, 0, 0, 39, '2844'),
	(377, 1, 0, -50924, 2846, 0, 0, 39, '2845'),
	(377, 1, 0, -50924, 2847, 0, 0, 39, '2846'),
	(377, 1, 0, -50924, 2848, 0, 0, 39, '2847'),
	(377, 1, 0, -50924, 2849, 0, 0, 39, '2848'),
	(377, 1, 0, -50924, 2850, 0, 0, 39, '2849'),
	(377, 1, 0, -50924, 2851, 0, 0, 39, '2850'),
	(377, 1, 0, -50924, 2852, 0, 0, 39, '2851'),
	(377, 1, 0, -50924, 2853, 0, 0, 39, '2852'),
	(377, 1, 0, -50924, 2854, 0, 0, 39, '2853'),
	(377, 1, 0, -50924, 2855, 0, 0, 39, '2854'),
	(377, 1, 0, -50924, 2856, 0, 0, 39, '2855'),
	(377, 1, 0, -50924, 2857, 0, 0, 39, '2856'),
	(377, 1, 0, -50924, 2858, 0, 0, 39, '2857'),
	(377, 1, 0, -50924, 2859, 0, 0, 39, '2858'),
	(377, 1, 0, -50924, 2860, 0, 0, 39, '2859'),
	(377, 1, 0, -50924, 2861, 0, 0, 39, '2860'),
	(377, 1, 0, -50924, 2862, 0, 0, 39, '2861'),
	(377, 1, 0, -50924, 2863, 0, 0, 39, '2862'),
	(377, 1, 0, -50924, 2864, 0, 0, 39, '2863'),
	(377, 1, 0, -50924, 2865, 0, 0, 39, '2864'),
	(377, 1, 0, -50924, 2866, 0, 0, 39, '2865'),
	(377, 1, 0, -50924, 2867, 0, 0, 39, '2866'),
	(377, 1, 0, -50924, 2868, 0, 0, 39, '2867'),
	(377, 1, 0, -50924, 2869, 0, 0, 39, '2868'),
	(377, 1, 0, -50924, 2870, 0, 0, 39, '2869'),
	(377, 1, 0, -50924, 2871, 0, 0, 39, '2870'),
	(377, 1, 0, -50924, 2872, 0, 0, 39, '2871'),
	(377, 1, 0, -50924, 2873, 0, 0, 39, '2872'),
	(377, 1, 0, -50924, 2874, 0, 0, 39, '2873'),
	(377, 1, 0, -50924, 2875, 0, 0, 39, '2874'),
	(377, 1, 0, -50924, 2876, 0, 0, 39, '2875'),
	(377, 1, 0, -50924, 2877, 0, 0, 39, '2876'),
	(377, 1, 0, -50924, 2878, 0, 0, 39, '2877'),
	(377, 1, 0, -50924, 2879, 0, 0, 39, '2878'),
	(377, 1, 0, -50924, 2880, 0, 0, 39, '2879'),
	(377, 1, 0, -50924, 2881, 0, 0, 39, '2880'),
	(377, 1, 0, -50924, 2882, 0, 0, 39, '2881'),
	(377, 1, 0, -50924, 2883, 0, 0, 39, '2882'),
	(377, 1, 0, -50924, 2884, 0, 0, 39, '2883'),
	(377, 1, 0, -50924, 2885, 0, 0, 39, '2884'),
	(377, 1, 0, -50924, 2886, 0, 0, 39, '2885'),
	(377, 1, 0, -50924, 2887, 0, 0, 39, '2886'),
	(377, 1, 0, -50924, 2888, 0, 0, 39, '2887'),
	(377, 1, 0, -50924, 2889, 0, 0, 39, '2888'),
	(377, 1, 0, -50924, 2890, 0, 0, 39, '2889'),
	(377, 1, 0, -50924, 2891, 0, 0, 39, '2890'),
	(377, 1, 0, -50924, 2892, 0, 0, 39, '2891'),
	(377, 1, 0, -50924, 2893, 0, 0, 39, '2892'),
	(377, 1, 0, -50924, 2894, 0, 0, 39, '2893'),
	(377, 1, 0, -50924, 2895, 0, 0, 39, '2894'),
	(377, 1, 0, -50924, 2896, 0, 0, 39, '2895'),
	(377, 1, 0, -50924, 2897, 0, 0, 39, '2896'),
	(377, 1, 0, -50924, 2898, 0, 0, 39, '2897'),
	(377, 1, 0, -50924, 2899, 0, 0, 39, '2898'),
	(377, 1, 0, -50924, 2900, 0, 0, 39, '2899'),
	(377, 1, 0, -50924, 2901, 0, 0, 39, '2900'),
	(377, 1, 0, -50924, 2902, 0, 0, 39, '2901'),
	(377, 1, 0, -50924, 2903, 0, 0, 39, '2902'),
	(377, 1, 0, -50924, 2904, 0, 0, 39, '2903'),
	(377, 1, 0, -50924, 2905, 0, 0, 39, '2904'),
	(377, 1, 0, -50924, 2906, 0, 0, 39, '2905'),
	(377, 1, 0, -50924, 2907, 0, 0, 39, '2906'),
	(377, 1, 0, -50924, 2908, 0, 0, 39, '2907'),
	(377, 1, 0, -50924, 2909, 0, 0, 39, '2908'),
	(377, 1, 0, -50924, 2910, 0, 0, 39, '2909'),
	(377, 1, 0, -50924, 2911, 0, 0, 39, '2910'),
	(377, 1, 0, -50924, 2912, 0, 0, 39, '2911'),
	(377, 1, 0, -50924, 2913, 0, 0, 39, '2912'),
	(377, 1, 0, -50924, 2914, 0, 0, 39, '2913'),
	(377, 1, 0, -50924, 2915, 0, 0, 39, '2914'),
	(377, 1, 0, -50924, 2916, 0, 0, 39, '2915'),
	(377, 1, 0, -50924, 2917, 0, 0, 39, '2916'),
	(377, 1, 0, -50924, 2918, 0, 0, 39, '2917'),
	(377, 1, 0, -50924, 2919, 0, 0, 39, '2918'),
	(377, 1, 0, -50924, 2920, 0, 0, 39, '2919'),
	(377, 1, 0, -50924, 2921, 0, 0, 39, '2920'),
	(377, 1, 0, -50924, 2922, 0, 0, 39, '2921'),
	(377, 1, 0, -50924, 2923, 0, 0, 39, '2922'),
	(377, 1, 0, -50924, 2924, 0, 0, 39, '2923'),
	(377, 1, 0, -50924, 2925, 0, 0, 39, '2924'),
	(377, 1, 0, -50924, 2926, 0, 0, 39, '2925'),
	(377, 1, 0, -50924, 2927, 0, 0, 39, '2926'),
	(377, 1, 0, -50924, 2928, 0, 0, 39, '2927'),
	(377, 1, 0, -50924, 2929, 0, 0, 39, '2928'),
	(377, 1, 0, -50924, 2930, 0, 0, 39, '2929'),
	(377, 1, 0, -50924, 2931, 0, 0, 39, '2930'),
	(377, 1, 0, -50924, 2932, 0, 0, 39, '2931'),
	(377, 1, 0, -50924, 2933, 0, 0, 39, '2932'),
	(377, 1, 0, -50924, 2934, 0, 0, 39, '2933'),
	(377, 1, 0, -50924, 2935, 0, 0, 39, '2934'),
	(377, 1, 0, -50924, 2936, 0, 0, 39, '2935'),
	(377, 1, 0, -50924, 2937, 0, 0, 39, '2936'),
	(377, 1, 0, -50924, 2938, 0, 0, 39, '2937'),
	(377, 1, 0, -50924, 2939, 0, 0, 39, '2938'),
	(377, 1, 0, -50924, 2940, 0, 0, 39, '2939'),
	(377, 1, 0, -50924, 2941, 0, 0, 39, '2940'),
	(377, 1, 0, -50924, 2942, 0, 0, 39, '2941'),
	(377, 1, 0, -50924, 2943, 0, 0, 39, '2942'),
	(377, 1, 0, -50924, 2944, 0, 0, 39, '2943'),
	(377, 1, 0, -50924, 2945, 0, 0, 39, '2944'),
	(377, 1, 0, -50924, 2946, 0, 0, 39, '2945'),
	(377, 1, 0, -50924, 2947, 0, 0, 39, '2946'),
	(377, 1, 0, -50924, 2948, 0, 0, 39, '2947'),
	(377, 1, 0, -50924, 2949, 0, 0, 39, '2948'),
	(377, 1, 0, -50924, 2950, 0, 0, 39, '2949'),
	(377, 1, 0, -50924, 2951, 0, 0, 39, '2950'),
	(377, 1, 0, -50924, 2952, 0, 0, 39, '2951'),
	(377, 1, 0, -50924, 2953, 0, 0, 39, '2952'),
	(377, 1, 0, -50924, 2954, 0, 0, 39, '2953'),
	(377, 1, 0, -50924, 2955, 0, 0, 39, '2954'),
	(377, 1, 0, -50924, 2956, 0, 0, 39, '2955'),
	(377, 1, 0, -50924, 2957, 0, 0, 39, '2956'),
	(377, 1, 0, -50924, 2958, 0, 0, 39, '2957'),
	(377, 1, 0, -50924, 2959, 0, 0, 39, '2958'),
	(377, 1, 0, -50924, 2960, 0, 0, 39, '2959'),
	(377, 1, 0, -50924, 2961, 0, 0, 39, '2960'),
	(377, 1, 0, -50924, 2962, 0, 0, 39, '2961'),
	(377, 1, 0, -50924, 2963, 0, 0, 39, '2962'),
	(377, 1, 0, -50924, 2964, 0, 0, 39, '2963'),
	(377, 1, 0, -50924, 2965, 0, 0, 39, '2964'),
	(377, 1, 0, -50924, 2966, 0, 0, 39, '2965'),
	(377, 1, 0, -50924, 2967, 0, 0, 39, '2966'),
	(377, 1, 0, -50924, 2968, 0, 0, 39, '2967'),
	(377, 1, 0, -50924, 2969, 0, 0, 39, '2968'),
	(377, 1, 0, -50924, 2970, 0, 0, 39, '2969'),
	(377, 1, 0, -50924, 2971, 0, 0, 39, '2970'),
	(377, 1, 0, -50924, 2972, 0, 0, 39, '2971'),
	(377, 1, 0, -50924, 2973, 0, 0, 39, '2972'),
	(377, 1, 0, -50924, 2974, 0, 0, 39, '2973'),
	(377, 1, 0, -50924, 2975, 0, 0, 39, '2974'),
	(377, 1, 0, -50924, 2976, 0, 0, 39, '2975'),
	(377, 1, 0, -50924, 2977, 0, 0, 39, '2976'),
	(377, 1, 0, -50924, 2978, 0, 0, 39, '2977'),
	(377, 1, 0, -50924, 2979, 0, 0, 39, '2978'),
	(377, 1, 0, -50924, 2980, 0, 0, 39, '2979'),
	(377, 1, 0, -50924, 2981, 0, 0, 39, '2980'),
	(377, 1, 0, -50924, 2982, 0, 0, 39, '2981'),
	(377, 1, 0, -50924, 2983, 0, 0, 39, '2982'),
	(377, 1, 0, -50924, 2984, 0, 0, 39, '2983'),
	(377, 1, 0, -50924, 2985, 0, 0, 39, '2984'),
	(377, 1, 0, -50924, 2986, 0, 0, 39, '2985'),
	(377, 1, 0, -50924, 2987, 0, 0, 39, '2986'),
	(377, 1, 0, -50924, 2988, 0, 0, 39, '2987'),
	(377, 1, 0, -50924, 2989, 0, 0, 39, '2988'),
	(377, 1, 0, -50924, 2990, 0, 0, 39, '2989'),
	(377, 1, 0, -50924, 2991, 0, 0, 39, '2990'),
	(377, 1, 0, -50924, 2992, 0, 0, 39, '2991'),
	(377, 1, 0, -50924, 2993, 0, 0, 39, '2992'),
	(377, 1, 0, -50924, 2994, 0, 0, 39, '2993'),
	(377, 1, 0, -50924, 2995, 0, 0, 39, '2994'),
	(377, 1, 0, -50924, 2996, 0, 0, 39, '2995'),
	(377, 1, 0, -50924, 2997, 0, 0, 39, '2996'),
	(377, 1, 0, -50924, 2998, 0, 0, 39, '2997'),
	(377, 1, 0, -50924, 2999, 0, 0, 39, '2998'),
	(377, 1, 0, -50924, 3000, 0, 0, 39, '2999'),
	(377, 1, 0, -50924, 3001, 0, 0, 39, '3000'),
	(377, 1, 0, -50924, 3002, 0, 0, 39, '3001'),
	(377, 1, 0, -50924, 3003, 0, 0, 39, '3002'),
	(377, 1, 0, -50924, 3004, 0, 0, 39, '3003'),
	(377, 1, 0, -50924, 3005, 0, 0, 39, '3004'),
	(377, 1, 0, -50924, 3006, 0, 0, 39, '3005'),
	(377, 1, 0, -50924, 3007, 0, 0, 39, '3006'),
	(377, 1, 0, -50924, 3008, 0, 0, 39, '3007'),
	(377, 1, 0, -50924, 3009, 0, 0, 39, '3008'),
	(377, 1, 0, -50924, 3010, 0, 0, 39, '3009'),
	(377, 1, 0, -50924, 3011, 0, 0, 39, '3010'),
	(377, 1, 0, -50924, 3012, 0, 0, 39, '3011'),
	(377, 1, 0, -50924, 3013, 0, 0, 39, '3012'),
	(377, 1, 0, -50924, 3014, 0, 0, 39, '3013'),
	(377, 1, 0, -50924, 3015, 0, 0, 39, '3014'),
	(377, 1, 0, -50924, 3016, 0, 0, 39, '3015'),
	(377, 1, 0, -50924, 3017, 0, 0, 39, '3016'),
	(377, 1, 0, -50924, 3018, 0, 0, 39, '3017'),
	(377, 1, 0, -50924, 3019, 0, 0, 39, '3018'),
	(377, 1, 0, -50924, 3020, 0, 0, 39, '3019'),
	(377, 1, 0, -50924, 3021, 0, 0, 39, '3020'),
	(377, 1, 0, -50924, 3022, 0, 0, 39, '3021'),
	(377, 1, 0, -50924, 3023, 0, 0, 39, '3022'),
	(377, 1, 0, -50924, 3024, 0, 0, 39, '3023'),
	(377, 1, 0, -50924, 3025, 0, 0, 39, '3024'),
	(377, 1, 0, -50924, 3026, 0, 0, 39, '3025'),
	(377, 1, 0, -50924, 3027, 0, 0, 39, '3026'),
	(377, 1, 0, -50924, 3028, 0, 0, 39, '3027'),
	(377, 1, 0, -50924, 3029, 0, 0, 39, '3028'),
	(377, 1, 0, -50924, 3030, 0, 0, 39, '3029'),
	(377, 1, 0, -50924, 3031, 0, 0, 39, '3030'),
	(377, 1, 0, -50924, 3032, 0, 0, 39, '3031'),
	(377, 1, 0, -50924, 3033, 0, 0, 39, '3032'),
	(377, 1, 0, -50924, 3034, 0, 0, 39, '3033'),
	(377, 1, 0, -50924, 3035, 0, 0, 39, '3034'),
	(377, 1, 0, -50924, 3036, 0, 0, 39, '3035'),
	(377, 1, 0, -50924, 3037, 0, 0, 39, '3036'),
	(377, 1, 0, -50924, 3038, 0, 0, 39, '3037'),
	(377, 1, 0, -50924, 3039, 0, 0, 39, '3038'),
	(377, 1, 0, -50924, 3040, 0, 0, 39, '3039'),
	(377, 1, 0, -50924, 3041, 0, 0, 39, '3040'),
	(377, 1, 0, -50924, 3042, 0, 0, 39, '3041'),
	(377, 1, 0, -50924, 3043, 0, 0, 39, '3042'),
	(377, 1, 0, -50924, 3044, 0, 0, 39, '3043'),
	(377, 1, 0, -50924, 3045, 0, 0, 39, '3044'),
	(377, 1, 0, -50924, 3046, 0, 0, 39, '3045'),
	(377, 1, 0, -50924, 3047, 0, 0, 39, '3046'),
	(377, 1, 0, -50924, 3048, 0, 0, 39, '3047'),
	(377, 1, 0, -50924, 3049, 0, 0, 39, '3048'),
	(377, 1, 0, -50924, 3050, 0, 0, 39, '3049'),
	(377, 1, 0, -50924, 3051, 0, 0, 39, '3050'),
	(377, 1, 0, -50924, 3052, 0, 0, 39, '3051'),
	(377, 1, 0, -50924, 3053, 0, 0, 39, '3052'),
	(377, 1, 0, -50924, 3054, 0, 0, 39, '3053'),
	(377, 1, 0, -50924, 3055, 0, 0, 39, '3054'),
	(377, 1, 0, -50924, 3056, 0, 0, 39, '3055'),
	(377, 1, 0, -50924, 3057, 0, 0, 39, '3056'),
	(377, 1, 0, -50924, 3058, 0, 0, 39, '3057'),
	(377, 1, 0, -50924, 3059, 0, 0, 39, '3058'),
	(377, 1, 0, -50924, 3060, 0, 0, 39, '3059'),
	(377, 1, 0, -50924, 3061, 0, 0, 39, '3060'),
	(377, 1, 0, -50924, 3062, 0, 0, 39, '3061'),
	(377, 1, 0, -50924, 3063, 0, 0, 39, '3062'),
	(377, 1, 0, -50924, 3064, 0, 0, 39, '3063'),
	(377, 1, 0, -50924, 3065, 0, 0, 39, '3064'),
	(377, 1, 0, -50924, 3066, 0, 0, 39, '3065'),
	(377, 1, 0, -50924, 3067, 0, 0, 39, '3066'),
	(377, 1, 0, -50924, 3068, 0, 0, 39, '3067'),
	(377, 1, 0, -50924, 3069, 0, 0, 39, '3068'),
	(377, 1, 0, -50924, 3070, 0, 0, 39, '3069'),
	(377, 1, 0, -50924, 3071, 0, 0, 39, '3070'),
	(377, 1, 0, -50924, 3072, 0, 0, 39, '3071'),
	(377, 1, 0, -50924, 3073, 0, 0, 39, '3072'),
	(377, 1, 0, -50924, 3074, 0, 0, 39, '3073'),
	(377, 1, 0, -50924, 3075, 0, 0, 39, '3074'),
	(377, 1, 0, -50924, 3076, 0, 0, 39, '3075'),
	(377, 1, 0, -50924, 3077, 0, 0, 39, '3076'),
	(377, 1, 0, -50924, 3078, 0, 0, 39, '3077'),
	(377, 1, 0, -50924, 3079, 0, 0, 39, '3078'),
	(377, 1, 0, -50924, 3080, 0, 0, 39, '3079'),
	(377, 1, 0, -50924, 3081, 0, 0, 39, '3080'),
	(377, 1, 0, -50924, 3082, 0, 0, 39, '3081'),
	(377, 1, 0, -50924, 3083, 0, 0, 39, '3082'),
	(377, 1, 0, -50924, 3084, 0, 0, 39, '3083'),
	(377, 1, 0, -50924, 3085, 0, 0, 39, '3084'),
	(377, 1, 0, -50924, 3086, 0, 0, 39, '3085'),
	(377, 1, 0, -50924, 3087, 0, 0, 39, '3086'),
	(377, 1, 0, -50924, 3088, 0, 0, 39, '3087'),
	(377, 1, 0, -50924, 3089, 0, 0, 39, '3088'),
	(377, 1, 0, -50924, 3090, 0, 0, 39, '3089'),
	(377, 1, 0, -50924, 3091, 0, 0, 39, '3090'),
	(377, 1, 0, -50924, 3092, 0, 0, 39, '3091'),
	(377, 1, 0, -50924, 3093, 0, 0, 39, '3092'),
	(377, 1, 0, -50924, 3094, 0, 0, 39, '3093'),
	(377, 1, 0, -50924, 3095, 0, 0, 39, '3094'),
	(377, 1, 0, -50924, 3096, 0, 0, 39, '3095'),
	(377, 1, 0, -50924, 3097, 0, 0, 39, '3096'),
	(377, 1, 0, -50924, 3098, 0, 0, 39, '3097'),
	(377, 1, 0, -50924, 3099, 0, 0, 39, '3098'),
	(377, 1, 0, -50924, 3100, 0, 0, 39, '3099'),
	(377, 1, 0, -50924, 3101, 0, 0, 39, '3100'),
	(377, 1, 0, -50924, 3102, 0, 0, 39, '3101'),
	(377, 1, 0, -50924, 3103, 0, 0, 39, '3102'),
	(377, 1, 0, -50924, 3104, 0, 0, 39, '3103'),
	(377, 1, 0, -50924, 3105, 0, 0, 39, '3104'),
	(377, 1, 0, -50924, 3106, 0, 0, 39, '3105'),
	(377, 1, 0, -50924, 3107, 0, 0, 39, '3106'),
	(377, 1, 0, -50924, 3108, 0, 0, 39, '3107'),
	(377, 1, 0, -50924, 3109, 0, 0, 39, '3108'),
	(377, 1, 0, -50924, 3110, 0, 0, 39, '3109'),
	(377, 1, 0, -50924, 3111, 0, 0, 39, '3110'),
	(377, 1, 0, -50924, 3112, 0, 0, 39, '3111'),
	(377, 1, 0, -50924, 3113, 0, 0, 39, '3112'),
	(377, 1, 0, -50924, 3114, 0, 0, 39, '3113'),
	(377, 1, 0, -50924, 3115, 0, 0, 39, '3114'),
	(377, 1, 0, -50924, 3116, 0, 0, 39, '3115'),
	(377, 1, 0, -50924, 3117, 0, 0, 39, '3116'),
	(377, 1, 0, -50924, 3118, 0, 0, 39, '3117'),
	(377, 1, 0, -50924, 3119, 0, 0, 39, '3118'),
	(377, 1, 0, -50924, 3120, 0, 0, 39, '3119'),
	(377, 1, 0, -50924, 3121, 0, 0, 39, '3120'),
	(377, 1, 0, -50924, 3122, 0, 0, 39, '3121'),
	(377, 1, 0, -50924, 3123, 0, 0, 39, '3122'),
	(377, 1, 0, -50924, 3124, 0, 0, 39, '3123'),
	(377, 1, 0, -50924, 3125, 0, 0, 39, '3124'),
	(377, 1, 0, -50924, 3126, 0, 0, 39, '3125'),
	(377, 1, 0, -50924, 3127, 0, 0, 39, '3126'),
	(377, 1, 0, -50924, 3128, 0, 0, 39, '3127'),
	(377, 1, 0, -50924, 3129, 0, 0, 39, '3128'),
	(377, 1, 0, -50924, 3130, 0, 0, 39, '3129'),
	(377, 1, 0, -50924, 3131, 0, 0, 39, '3130'),
	(377, 1, 0, -50924, 3132, 0, 0, 39, '3131'),
	(377, 1, 0, -50924, 3133, 0, 0, 39, '3132'),
	(377, 1, 0, -50924, 3134, 0, 0, 39, '3133'),
	(377, 1, 0, -50924, 3135, 0, 0, 39, '3134'),
	(377, 1, 0, -50924, 3136, 0, 0, 39, '3135'),
	(377, 1, 0, -50924, 3137, 0, 0, 39, '3136'),
	(377, 1, 0, -50924, 3138, 0, 0, 39, '3137'),
	(377, 1, 0, -50924, 3139, 0, 0, 39, '3138'),
	(377, 1, 0, -50924, 3140, 0, 0, 39, '3139'),
	(377, 1, 0, -50924, 3141, 0, 0, 39, '3140'),
	(377, 1, 0, -50924, 3142, 0, 0, 39, '3141'),
	(377, 1, 0, -50924, 3143, 0, 0, 39, '3142'),
	(377, 1, 0, -50924, 3144, 0, 0, 39, '3143'),
	(377, 1, 0, -50924, 3145, 0, 0, 39, '3144'),
	(377, 1, 0, -50924, 3146, 0, 0, 39, '3145'),
	(377, 1, 0, -50924, 3147, 0, 0, 39, '3146'),
	(377, 1, 0, -50924, 3148, 0, 0, 39, '3147'),
	(377, 1, 0, -50924, 3149, 0, 0, 39, '3148'),
	(377, 1, 0, -50924, 3150, 0, 0, 39, '3149'),
	(377, 1, 0, -50924, 3151, 0, 0, 39, '3150'),
	(377, 1, 0, -50924, 3152, 0, 0, 39, '3151'),
	(377, 1, 0, -50924, 3153, 0, 0, 39, '3152'),
	(377, 1, 0, -50924, 3154, 0, 0, 39, '3153'),
	(377, 1, 0, -50924, 3155, 0, 0, 39, '3154'),
	(377, 1, 0, -50924, 3156, 0, 0, 39, '3155'),
	(377, 1, 0, -50924, 3157, 0, 0, 39, '3156'),
	(377, 1, 0, -50924, 3158, 0, 0, 39, '3157'),
	(377, 1, 0, -50924, 3159, 0, 0, 39, '3158'),
	(377, 1, 0, -50924, 3160, 0, 0, 39, '3159'),
	(377, 1, 0, -50924, 3161, 0, 0, 39, '3160'),
	(377, 1, 0, -50924, 3162, 0, 0, 39, '3161'),
	(377, 1, 0, -50924, 3163, 0, 0, 39, '3162'),
	(377, 1, 0, -50924, 3164, 0, 0, 39, '3163'),
	(377, 1, 0, -50924, 3165, 0, 0, 39, '3164'),
	(377, 1, 0, -50924, 3166, 0, 0, 39, '3165'),
	(377, 1, 0, -50924, 3167, 0, 0, 39, '3166'),
	(377, 1, 0, -50924, 3168, 0, 0, 39, '3167'),
	(377, 1, 0, -50924, 3169, 0, 0, 39, '3168'),
	(377, 1, 0, -50924, 3170, 0, 0, 39, '3169'),
	(377, 1, 0, -50924, 3171, 0, 0, 39, '3170'),
	(377, 1, 0, -50924, 3172, 0, 0, 39, '3171'),
	(377, 1, 0, -50924, 3173, 0, 0, 39, '3172'),
	(377, 1, 0, -50924, 3174, 0, 0, 39, '3173'),
	(377, 1, 0, -50924, 3175, 0, 0, 39, '3174'),
	(377, 1, 0, -50924, 3176, 0, 0, 39, '3175'),
	(377, 1, 0, -50924, 3177, 0, 0, 39, '3176'),
	(377, 1, 0, -50924, 3178, 0, 0, 39, '3177'),
	(377, 1, 0, -50924, 3179, 0, 0, 39, '3178'),
	(377, 1, 0, -50924, 3180, 0, 0, 39, '3179'),
	(377, 1, 0, -50924, 3181, 0, 0, 39, '3180'),
	(377, 1, 0, -50924, 3182, 0, 0, 39, '3181'),
	(377, 1, 0, -50924, 3183, 0, 0, 39, '3182'),
	(377, 1, 0, -50924, 3184, 0, 0, 39, '3183'),
	(377, 1, 0, -50924, 3185, 0, 0, 39, '3184'),
	(377, 1, 0, -50924, 3186, 0, 0, 39, '3185'),
	(377, 1, 0, -50924, 3187, 0, 0, 39, '3186'),
	(377, 1, 0, -50924, 3188, 0, 0, 39, '3187'),
	(377, 1, 0, -50924, 3189, 0, 0, 39, '3188'),
	(377, 1, 0, -50924, 3190, 0, 0, 39, '3189'),
	(377, 1, 0, -50924, 3191, 0, 0, 39, '3190'),
	(377, 1, 0, -50924, 3192, 0, 0, 39, '3191'),
	(377, 1, 0, -50924, 3193, 0, 0, 39, '3192'),
	(377, 1, 0, -50924, 3194, 0, 0, 39, '3193'),
	(377, 1, 0, -50924, 3195, 0, 0, 39, '3194'),
	(377, 1, 0, -50924, 3196, 0, 0, 39, '3195'),
	(377, 1, 0, -50924, 3197, 0, 0, 39, '3196'),
	(377, 1, 0, -50924, 3198, 0, 0, 39, '3197'),
	(377, 1, 0, -50924, 3199, 0, 0, 39, '3198'),
	(377, 1, 0, -50924, 3200, 0, 0, 39, '3199'),
	(377, 1, 0, -50924, 3201, 0, 0, 39, '3200'),
	(377, 1, 0, -50924, 3202, 0, 0, 39, '3201'),
	(377, 1, 0, -50924, 3203, 0, 0, 39, '3202'),
	(377, 1, 0, -50924, 3204, 0, 0, 39, '3203'),
	(377, 1, 0, -50924, 3205, 0, 0, 39, '3204'),
	(377, 1, 0, -50924, 3206, 0, 0, 39, '3205'),
	(377, 1, 0, -50924, 3207, 0, 0, 39, '3206'),
	(377, 1, 0, -50924, 3208, 0, 0, 39, '3207'),
	(377, 1, 0, -50924, 3209, 0, 0, 39, '3208'),
	(377, 1, 0, -50924, 3210, 0, 0, 39, '3209'),
	(377, 1, 0, -50924, 3211, 0, 0, 39, '3210'),
	(377, 1, 0, -50924, 3212, 0, 0, 39, '3211'),
	(377, 1, 0, -50924, 3213, 0, 0, 39, '3212'),
	(377, 1, 0, -50924, 3214, 0, 0, 39, '3213'),
	(377, 1, 0, -50924, 3215, 0, 0, 39, '3214'),
	(377, 1, 0, -50924, 3216, 0, 0, 39, '3215'),
	(377, 1, 0, -50924, 3217, 0, 0, 39, '3216'),
	(377, 1, 0, -50924, 3218, 0, 0, 39, '3217'),
	(377, 1, 0, -50924, 3219, 0, 0, 39, '3218'),
	(377, 1, 0, -50924, 3220, 0, 0, 39, '3219'),
	(377, 1, 0, -50924, 3221, 0, 0, 39, '3220'),
	(377, 1, 0, -50924, 3222, 0, 0, 39, '3221'),
	(377, 1, 0, -50924, 3223, 0, 0, 39, '3222'),
	(377, 1, 0, -50924, 3224, 0, 0, 39, '3223'),
	(377, 1, 0, -50924, 3225, 0, 0, 39, '3224'),
	(377, 1, 0, -50924, 3226, 0, 0, 39, '3225'),
	(377, 1, 0, -50924, 3227, 0, 0, 39, '3226'),
	(377, 1, 0, -50924, 3228, 0, 0, 39, '3227'),
	(377, 1, 0, -50924, 3229, 0, 0, 39, '3228'),
	(377, 1, 0, -50924, 3230, 0, 0, 39, '3229'),
	(377, 1, 0, -50924, 3231, 0, 0, 39, '3230'),
	(377, 1, 0, -50924, 3232, 0, 0, 39, '3231'),
	(377, 1, 0, -50924, 3233, 0, 0, 39, '3232'),
	(377, 1, 0, -50924, 3234, 0, 0, 39, '3233'),
	(377, 1, 0, -50924, 3235, 0, 0, 39, '3234'),
	(377, 1, 0, -50924, 3236, 0, 0, 39, '3235'),
	(377, 1, 0, -50924, 3237, 0, 0, 39, '3236'),
	(377, 1, 0, -50924, 3238, 0, 0, 39, '3237'),
	(377, 1, 0, -50924, 3239, 0, 0, 39, '3238'),
	(377, 1, 0, -50924, 3240, 0, 0, 39, '3239'),
	(377, 1, 0, -50924, 3241, 0, 0, 39, '3240'),
	(377, 1, 0, -50924, 3242, 0, 0, 39, '3241'),
	(377, 1, 0, -50924, 3243, 0, 0, 39, '3242'),
	(377, 1, 0, -50924, 3244, 0, 0, 39, '3243'),
	(377, 1, 0, -50924, 3245, 0, 0, 39, '3244'),
	(377, 1, 0, -50924, 3246, 0, 0, 39, '3245'),
	(377, 1, 0, -50924, 3247, 0, 0, 39, '3246'),
	(377, 1, 0, -50924, 3248, 0, 0, 39, '3247'),
	(377, 1, 0, -50924, 3249, 0, 0, 39, '3248'),
	(377, 1, 0, -50924, 3250, 0, 0, 39, '3249'),
	(377, 1, 0, -50924, 3251, 0, 0, 39, '3250'),
	(377, 1, 0, -50924, 3252, 0, 0, 39, '3251'),
	(377, 1, 0, -50924, 3253, 0, 0, 39, '3252'),
	(377, 1, 0, -50924, 3254, 0, 0, 39, '3253'),
	(377, 1, 0, -50924, 3255, 0, 0, 39, '3254'),
	(377, 1, 0, -50924, 3256, 0, 0, 39, '3255'),
	(377, 1, 0, -50924, 3257, 0, 0, 39, '3256'),
	(377, 1, 0, -50924, 3258, 0, 0, 39, '3257'),
	(377, 1, 0, -50924, 3259, 0, 0, 39, '3258'),
	(377, 1, 0, -50924, 3260, 0, 0, 39, '3259'),
	(377, 1, 0, -50924, 3261, 0, 0, 39, '3260'),
	(377, 1, 0, -50924, 3262, 0, 0, 39, '3261'),
	(377, 1, 0, -50924, 3263, 0, 0, 39, '3262'),
	(377, 1, 0, -50924, 3264, 0, 0, 39, '3263'),
	(377, 1, 0, -50924, 3265, 0, 0, 39, '3264'),
	(377, 1, 0, -50924, 3266, 0, 0, 39, '3265'),
	(377, 1, 0, -50924, 3267, 0, 0, 39, '3266'),
	(377, 1, 0, -50924, 3268, 0, 0, 39, '3267'),
	(377, 1, 0, -50924, 3269, 0, 0, 39, '3268'),
	(377, 1, 0, -50924, 3270, 0, 0, 39, '3269'),
	(377, 1, 0, -50924, 3271, 0, 0, 39, '3270'),
	(377, 1, 0, -50924, 3272, 0, 0, 39, '3271'),
	(377, 1, 0, -50924, 3273, 0, 0, 39, '3272'),
	(377, 1, 0, -50924, 3274, 0, 0, 39, '3273'),
	(377, 1, 0, -50924, 3275, 0, 0, 39, '3274'),
	(377, 1, 0, -50924, 3276, 0, 0, 39, '3275'),
	(377, 1, 0, -50924, 3277, 0, 0, 39, '3276'),
	(377, 1, 0, -50924, 3278, 0, 0, 39, '3277'),
	(377, 1, 0, -50924, 3279, 0, 0, 39, '3278'),
	(377, 1, 0, -50924, 3280, 0, 0, 39, '3279'),
	(377, 1, 0, -50924, 3281, 0, 0, 39, '3280'),
	(377, 1, 0, -50924, 3282, 0, 0, 39, '3281'),
	(377, 1, 0, -50924, 3283, 0, 0, 39, '3282'),
	(377, 1, 0, -50924, 3284, 0, 0, 39, '3283'),
	(377, 1, 0, -50924, 3285, 0, 0, 39, '3284'),
	(377, 1, 0, -50924, 3286, 0, 0, 39, '3285'),
	(377, 1, 0, -50924, 3287, 0, 0, 39, '3286'),
	(377, 1, 0, -50924, 3288, 0, 0, 39, '3287'),
	(377, 1, 0, -50924, 3289, 0, 0, 39, '3288'),
	(377, 1, 0, -50924, 3290, 0, 0, 39, '3289'),
	(377, 1, 0, -50924, 3291, 0, 0, 39, '3290'),
	(377, 1, 0, -50924, 3292, 0, 0, 39, '3291'),
	(377, 1, 0, -50924, 3293, 0, 0, 39, '3292'),
	(377, 1, 0, -50924, 3294, 0, 0, 39, '3293'),
	(377, 1, 0, -50924, 3295, 0, 0, 39, '3294'),
	(377, 1, 0, -50924, 3296, 0, 0, 39, '3295'),
	(377, 1, 0, -50924, 3297, 0, 0, 39, '3296'),
	(377, 1, 0, -50924, 3298, 0, 0, 39, '3297'),
	(377, 1, 0, -50924, 3299, 0, 0, 39, '3298'),
	(377, 1, 0, -50924, 3300, 0, 0, 39, '3299'),
	(377, 1, 0, -50924, 3301, 0, 0, 39, '3300'),
	(377, 1, 0, -50924, 3302, 0, 0, 39, '3301'),
	(377, 1, 0, -50924, 3303, 0, 0, 39, '3302'),
	(377, 1, 0, -50924, 3304, 0, 0, 39, '3303'),
	(377, 1, 0, -50924, 3305, 0, 0, 39, '3304'),
	(377, 1, 0, -50924, 3306, 0, 0, 39, '3305'),
	(377, 1, 0, -50924, 3307, 0, 0, 39, '3306'),
	(377, 1, 0, -50924, 3308, 0, 0, 39, '3307'),
	(377, 1, 0, -50924, 3309, 0, 0, 39, '3308'),
	(377, 1, 0, -50924, 3310, 0, 0, 39, '3309'),
	(377, 1, 0, -50924, 3311, 0, 0, 39, '3310'),
	(377, 1, 0, -50924, 3312, 0, 0, 39, '3311'),
	(377, 1, 0, -50924, 3313, 0, 0, 39, '3312'),
	(377, 1, 0, -50924, 3314, 0, 0, 39, '3313'),
	(377, 1, 0, -50924, 3315, 0, 0, 39, '3314'),
	(377, 1, 0, -50924, 3316, 0, 0, 39, '3315'),
	(377, 1, 0, -50924, 3317, 0, 0, 39, '3316'),
	(377, 1, 0, -50924, 3318, 0, 0, 39, '3317'),
	(377, 1, 0, -50924, 3319, 0, 0, 39, '3318'),
	(377, 1, 0, -50924, 3320, 0, 0, 39, '3319'),
	(377, 1, 0, -50924, 3321, 0, 0, 39, '3320'),
	(377, 1, 0, -50924, 3322, 0, 0, 39, '3321'),
	(377, 1, 0, -50924, 3323, 0, 0, 39, '3322'),
	(377, 1, 0, -50924, 3324, 0, 0, 39, '3323'),
	(377, 1, 0, -50924, 3325, 0, 0, 39, '3324'),
	(377, 1, 0, -50924, 3326, 0, 0, 39, '3325'),
	(377, 1, 0, -50924, 3327, 0, 0, 39, '3326'),
	(377, 1, 0, -50924, 3328, 0, 0, 39, '3327'),
	(377, 1, 0, -50924, 3329, 0, 0, 39, '3328'),
	(377, 1, 0, -50924, 3330, 0, 0, 39, '3329'),
	(377, 1, 0, -50924, 3331, 0, 0, 39, '3330'),
	(377, 1, 0, -50924, 3332, 0, 0, 39, '3331'),
	(377, 1, 0, -50924, 3333, 0, 0, 39, '3332'),
	(377, 1, 0, -50924, 3334, 0, 0, 39, '3333'),
	(377, 1, 0, -50924, 3335, 0, 0, 39, '3334'),
	(377, 1, 0, -50924, 3336, 0, 0, 39, '3335'),
	(377, 1, 0, -50924, 3337, 0, 0, 39, '3336'),
	(377, 1, 0, -50924, 3338, 0, 0, 39, '3337'),
	(377, 1, 0, -50924, 3339, 0, 0, 39, '3338'),
	(377, 1, 0, -50924, 3340, 0, 0, 39, '3339'),
	(377, 1, 0, -50924, 3341, 0, 0, 39, '3340'),
	(377, 1, 0, -50924, 3342, 0, 0, 39, '3341'),
	(377, 1, 0, -50924, 3343, 0, 0, 39, '3342'),
	(377, 1, 0, -50924, 3344, 0, 0, 39, '3343'),
	(377, 1, 0, -50924, 3345, 0, 0, 39, '3344'),
	(377, 1, 0, -50924, 3346, 0, 0, 39, '3345'),
	(377, 1, 0, -50924, 3347, 0, 0, 39, '3346'),
	(377, 1, 0, -50924, 3348, 0, 0, 39, '3347'),
	(377, 1, 0, -50924, 3349, 0, 0, 39, '3348'),
	(377, 1, 0, -50924, 3350, 0, 0, 39, '3349'),
	(377, 1, 0, -50924, 3351, 0, 0, 39, '3350'),
	(377, 1, 0, -50924, 3352, 0, 0, 39, '3351'),
	(377, 1, 0, -50924, 3353, 0, 0, 39, '3352'),
	(377, 1, 0, -50924, 3354, 0, 0, 39, '3353'),
	(377, 1, 0, -50924, 3355, 0, 0, 39, '3354'),
	(377, 1, 0, -50924, 3356, 0, 0, 39, '3355'),
	(377, 1, 0, -50924, 3357, 0, 0, 39, '3356'),
	(377, 1, 0, -50924, 3358, 0, 0, 39, '3357'),
	(377, 1, 0, -50924, 3359, 0, 0, 39, '3358'),
	(377, 1, 0, -50924, 3360, 0, 0, 39, '3359'),
	(377, 1, 0, -50924, 3361, 0, 0, 39, '3360'),
	(377, 1, 0, -50924, 3362, 0, 0, 39, '3361'),
	(377, 1, 0, -50924, 3363, 0, 0, 39, '3362'),
	(377, 1, 0, -50924, 3364, 0, 0, 39, '3363'),
	(377, 1, 0, -50924, 3365, 0, 0, 39, '3364'),
	(377, 1, 0, -50924, 3366, 0, 0, 39, '3365'),
	(377, 1, 0, -50924, 3367, 0, 0, 39, '3366'),
	(377, 1, 0, -50924, 3368, 0, 0, 39, '3367'),
	(377, 1, 0, -50924, 3369, 0, 0, 39, '3368'),
	(377, 1, 0, -50924, 3370, 0, 0, 39, '3369'),
	(377, 1, 0, -50924, 3371, 0, 0, 39, '3370'),
	(377, 1, 0, -50924, 3372, 0, 0, 39, '3371'),
	(377, 1, 0, -50924, 3373, 0, 0, 39, '3372'),
	(377, 1, 0, -50924, 3374, 0, 0, 39, '3373'),
	(377, 1, 0, -50924, 3375, 0, 0, 39, '3374'),
	(377, 1, 0, -50924, 3376, 0, 0, 39, '3375'),
	(377, 1, 0, -50924, 3377, 0, 0, 39, '3376'),
	(377, 1, 0, -50924, 3378, 0, 0, 39, '3377'),
	(377, 1, 0, -50924, 3379, 0, 0, 39, '3378'),
	(377, 1, 0, -50924, 3380, 0, 0, 39, '3379'),
	(377, 1, 0, -50924, 3381, 0, 0, 39, '3380'),
	(377, 1, 0, -50924, 3382, 0, 0, 39, '3381'),
	(377, 1, 0, -50924, 3383, 0, 0, 39, '3382'),
	(377, 1, 0, -50924, 3384, 0, 0, 39, '3383'),
	(377, 1, 0, -50924, 3385, 0, 0, 39, '3384'),
	(377, 1, 0, -50924, 3386, 0, 0, 39, '3385'),
	(377, 1, 0, -50924, 3387, 0, 0, 39, '3386'),
	(377, 1, 0, -50924, 3388, 0, 0, 39, '3387'),
	(377, 1, 0, -50924, 3389, 0, 0, 39, '3388'),
	(377, 1, 0, -50924, 3390, 0, 0, 39, '3389'),
	(377, 1, 0, -50924, 3391, 0, 0, 39, '3390'),
	(377, 1, 0, -50924, 3392, 0, 0, 39, '3391'),
	(377, 1, 0, -50924, 3393, 0, 0, 39, '3392'),
	(377, 1, 0, -50924, 3394, 0, 0, 39, '3393'),
	(377, 1, 0, -50924, 3395, 0, 0, 39, '3394'),
	(377, 1, 0, -50924, 3396, 0, 0, 39, '3395'),
	(377, 1, 0, -50924, 3397, 0, 0, 39, '3396'),
	(377, 1, 0, -50924, 3398, 0, 0, 39, '3397'),
	(377, 1, 0, -50924, 3399, 0, 0, 39, '3398'),
	(377, 1, 0, -50924, 3400, 0, 0, 39, '3399'),
	(377, 1, 0, -50924, 3401, 0, 0, 39, '3400'),
	(377, 1, 0, -50924, 3402, 0, 0, 39, '3401'),
	(377, 1, 0, -50924, 3403, 0, 0, 39, '3402'),
	(377, 1, 0, -50924, 3404, 0, 0, 39, '3403'),
	(377, 1, 0, -50924, 3405, 0, 0, 39, '3404'),
	(377, 1, 0, -50924, 3406, 0, 0, 39, '3405'),
	(377, 1, 0, -50924, 3407, 0, 0, 39, '3406'),
	(377, 1, 0, -50924, 3408, 0, 0, 39, '3407'),
	(377, 1, 0, -50924, 3409, 0, 0, 39, '3408'),
	(377, 1, 0, -50924, 3410, 0, 0, 39, '3409'),
	(377, 1, 0, -50924, 3411, 0, 0, 39, '3410'),
	(377, 1, 0, -50924, 3412, 0, 0, 39, '3411'),
	(377, 1, 0, -50924, 3413, 0, 0, 39, '3412'),
	(377, 1, 0, -50924, 3414, 0, 0, 39, '3413'),
	(377, 1, 0, -50924, 3415, 0, 0, 39, '3414'),
	(377, 1, 0, -50924, 3416, 0, 0, 39, '3415'),
	(377, 1, 0, -50924, 3417, 0, 0, 39, '3416'),
	(377, 1, 0, -50924, 3418, 0, 0, 39, '3417'),
	(377, 1, 0, -50924, 3419, 0, 0, 39, '3418'),
	(377, 1, 0, -50924, 3420, 0, 0, 39, '3419'),
	(377, 1, 0, -50924, 3421, 0, 0, 39, '3420'),
	(377, 1, 0, -50924, 3422, 0, 0, 39, '3421'),
	(377, 1, 0, -50924, 3423, 0, 0, 39, '3422'),
	(377, 1, 0, -50924, 3424, 0, 0, 39, '3423'),
	(377, 1, 0, -50924, 3425, 0, 0, 39, '3424'),
	(377, 1, 0, -50924, 3426, 0, 0, 39, '3425'),
	(377, 1, 0, -50924, 3427, 0, 0, 39, '3426'),
	(377, 1, 0, -50924, 3428, 0, 0, 39, '3427'),
	(377, 1, 0, -50924, 3429, 0, 0, 39, '3428'),
	(377, 1, 0, -50924, 3430, 0, 0, 39, '3429'),
	(377, 1, 0, -50924, 3431, 0, 0, 39, '3430'),
	(377, 1, 0, -50924, 3432, 0, 0, 39, '3431'),
	(377, 1, 0, -50924, 3433, 0, 0, 39, '3432'),
	(377, 1, 0, -50924, 3434, 0, 0, 39, '3433'),
	(377, 1, 0, -50924, 3435, 0, 0, 39, '3434'),
	(377, 1, 0, -50924, 3436, 0, 0, 39, '3435'),
	(377, 1, 0, -50924, 3437, 0, 0, 39, '3436'),
	(377, 1, 0, -50924, 3438, 0, 0, 39, '3437'),
	(377, 1, 0, -50924, 3439, 0, 0, 39, '3438'),
	(377, 1, 0, -50924, 3440, 0, 0, 39, '3439'),
	(377, 1, 0, -50924, 3441, 0, 0, 39, '3440'),
	(377, 1, 0, -50924, 3442, 0, 0, 39, '3441'),
	(377, 1, 0, -50924, 3443, 0, 0, 39, '3442'),
	(377, 1, 0, -50924, 3444, 0, 0, 39, '3443'),
	(377, 1, 0, -50924, 3445, 0, 0, 39, '3444'),
	(377, 1, 0, -50924, 3446, 0, 0, 39, '3445'),
	(377, 1, 0, -50924, 3447, 0, 0, 39, '3446'),
	(377, 1, 0, -50924, 3448, 0, 0, 39, '3447'),
	(377, 1, 0, -50924, 3449, 0, 0, 39, '3448'),
	(377, 1, 0, -50924, 3450, 0, 0, 39, '3449'),
	(377, 1, 0, -50924, 3451, 0, 0, 39, '3450'),
	(377, 1, 0, -50924, 3452, 0, 0, 39, '3451'),
	(377, 1, 0, -50924, 3453, 0, 0, 39, '3452'),
	(377, 1, 0, -50924, 3454, 0, 0, 39, '3453'),
	(377, 1, 0, -50924, 3455, 0, 0, 39, '3454'),
	(377, 1, 0, -50924, 3456, 0, 0, 39, '3455'),
	(377, 1, 0, -50924, 3457, 0, 0, 39, '3456'),
	(377, 1, 0, -50924, 3458, 0, 0, 39, '3457'),
	(377, 1, 0, -50924, 3459, 0, 0, 39, '3458'),
	(377, 1, 0, -50924, 3460, 0, 0, 39, '3459'),
	(377, 1, 0, -50924, 3461, 0, 0, 39, '3460'),
	(377, 1, 0, -50924, 3462, 0, 0, 39, '3461'),
	(377, 1, 0, -50924, 3463, 0, 0, 39, '3462'),
	(377, 1, 0, -50924, 3464, 0, 0, 39, '3463'),
	(377, 1, 0, -50924, 3465, 0, 0, 39, '3464'),
	(377, 1, 0, -50924, 3466, 0, 0, 39, '3465'),
	(377, 1, 0, -50924, 3467, 0, 0, 39, '3466'),
	(377, 1, 0, -50924, 3468, 0, 0, 39, '3467'),
	(377, 1, 0, -50924, 3469, 0, 0, 39, '3468'),
	(377, 1, 0, -50924, 3470, 0, 0, 39, '3469'),
	(377, 1, 0, -50924, 3471, 0, 0, 39, '3470'),
	(377, 1, 0, -50924, 3472, 0, 0, 39, '3471'),
	(377, 1, 0, -50924, 3473, 0, 0, 39, '3472'),
	(377, 1, 0, -50924, 3474, 0, 0, 39, '3473'),
	(377, 1, 0, -50924, 3475, 0, 0, 39, '3474'),
	(377, 1, 0, -50924, 3476, 0, 0, 39, '3475'),
	(377, 1, 0, -50924, 3477, 0, 0, 39, '3476'),
	(377, 1, 0, -50924, 3478, 0, 0, 39, '3477'),
	(377, 1, 0, -50924, 3479, 0, 0, 39, '3478'),
	(377, 1, 0, -50924, 3480, 0, 0, 39, '3479'),
	(377, 1, 0, -50924, 3481, 0, 0, 39, '3480'),
	(377, 1, 0, -50924, 3482, 0, 0, 39, '3481'),
	(377, 1, 0, -50924, 3483, 0, 0, 39, '3482'),
	(377, 1, 0, -50924, 3484, 0, 0, 39, '3483'),
	(377, 1, 0, -50924, 3485, 0, 0, 39, '3484'),
	(377, 1, 0, -50924, 3486, 0, 0, 39, '3485'),
	(377, 1, 0, -50924, 3487, 0, 0, 39, '3486'),
	(377, 1, 0, -50924, 3488, 0, 0, 39, '3487'),
	(377, 1, 0, -50924, 3489, 0, 0, 39, '3488'),
	(377, 1, 0, -50924, 3490, 0, 0, 39, '3489'),
	(377, 1, 0, -50924, 3491, 0, 0, 39, '3490'),
	(377, 1, 0, -50924, 3492, 0, 0, 39, '3491'),
	(377, 1, 0, -50924, 3493, 0, 0, 39, '3492'),
	(377, 1, 0, -50924, 3494, 0, 0, 39, '3493'),
	(377, 1, 0, -50924, 3495, 0, 0, 39, '3494'),
	(377, 1, 0, -50924, 3496, 0, 0, 39, '3495'),
	(377, 1, 0, -50924, 3497, 0, 0, 39, '3496'),
	(377, 1, 0, -50924, 3498, 0, 0, 39, '3497'),
	(377, 1, 0, -50924, 3499, 0, 0, 39, '3498'),
	(377, 1, 0, -50924, 3500, 0, 0, 39, '3499'),
	(377, 1, 0, -50924, 3501, 0, 0, 39, '3500'),
	(377, 1, 0, -50924, 3502, 0, 0, 39, '3501'),
	(377, 1, 0, -50924, 3503, 0, 0, 39, '3502'),
	(377, 1, 0, -50924, 3504, 0, 0, 39, '3503'),
	(377, 1, 0, -50924, 3505, 0, 0, 39, '3504'),
	(377, 1, 0, -50924, 3506, 0, 0, 39, '3505'),
	(377, 1, 0, -50924, 3507, 0, 0, 39, '3506'),
	(377, 1, 0, -50924, 3508, 0, 0, 39, '3507'),
	(377, 1, 0, -50924, 3509, 0, 0, 39, '3508'),
	(377, 1, 0, -50924, 3510, 0, 0, 39, '3509'),
	(377, 1, 0, -50924, 3511, 0, 0, 39, '3510'),
	(377, 1, 0, -50924, 3512, 0, 0, 39, '3511'),
	(377, 1, 0, -50924, 3513, 0, 0, 39, '3512'),
	(377, 1, 0, -50924, 3514, 0, 0, 39, '3513'),
	(377, 1, 0, -50924, 3515, 0, 0, 39, '3514'),
	(377, 1, 0, -50924, 3516, 0, 0, 39, '3515'),
	(377, 1, 0, -50924, 3517, 0, 0, 39, '3516'),
	(377, 1, 0, -50924, 3518, 0, 0, 39, '3517'),
	(377, 1, 0, -50924, 3519, 0, 0, 39, '3518'),
	(377, 1, 0, -50924, 3520, 0, 0, 39, '3519'),
	(377, 1, 0, -50924, 3521, 0, 0, 39, '3520'),
	(377, 1, 0, -50924, 3522, 0, 0, 39, '3521'),
	(377, 1, 0, -50924, 3523, 0, 0, 39, '3522'),
	(377, 1, 0, -50924, 3524, 0, 0, 39, '3523'),
	(377, 1, 0, -50924, 3525, 0, 0, 39, '3524'),
	(377, 1, 0, -50924, 3526, 0, 0, 39, '3525'),
	(377, 1, 0, -50924, 3527, 0, 0, 39, '3526'),
	(377, 1, 0, -50924, 3528, 0, 0, 39, '3527'),
	(377, 1, 0, -50924, 3529, 0, 0, 39, '3528'),
	(377, 1, 0, -50924, 3530, 0, 0, 39, '3529'),
	(377, 1, 0, -50924, 3531, 0, 0, 39, '3530'),
	(377, 1, 0, -50924, 3532, 0, 0, 39, '3531'),
	(377, 1, 0, -50924, 3533, 0, 0, 39, '3532'),
	(377, 1, 0, -50924, 3534, 0, 0, 39, '3533'),
	(377, 1, 0, -50924, 3535, 0, 0, 39, '3534'),
	(377, 1, 0, -50924, 3536, 0, 0, 39, '3535'),
	(377, 1, 0, -50924, 3537, 0, 0, 39, '3536'),
	(377, 1, 0, -50924, 3538, 0, 0, 39, '3537'),
	(377, 1, 0, -50924, 3539, 0, 0, 39, '3538'),
	(377, 1, 0, -50924, 3540, 0, 0, 39, '3539'),
	(377, 1, 0, -50924, 3541, 0, 0, 39, '3540'),
	(377, 1, 0, -50924, 3542, 0, 0, 39, '3541'),
	(377, 1, 0, -50924, 3543, 0, 0, 39, '3542'),
	(377, 1, 0, -50924, 3544, 0, 0, 39, '3543'),
	(377, 1, 0, -50924, 3545, 0, 0, 39, '3544'),
	(377, 1, 0, -50924, 3546, 0, 0, 39, '3545'),
	(377, 1, 0, -50924, 3547, 0, 0, 39, '3546'),
	(377, 1, 0, -50924, 3548, 0, 0, 39, '3547'),
	(377, 1, 0, -50924, 3549, 0, 0, 39, '3548'),
	(377, 1, 0, -50924, 3550, 0, 0, 39, '3549'),
	(377, 1, 0, -50924, 3551, 0, 0, 39, '3550'),
	(377, 1, 0, -50924, 3552, 0, 0, 39, '3551'),
	(377, 1, 0, -50924, 3553, 0, 0, 39, '3552'),
	(377, 1, 0, -50924, 3554, 0, 0, 39, '3553'),
	(377, 1, 0, -50924, 3555, 0, 0, 39, '3554'),
	(377, 1, 0, -50924, 3556, 0, 0, 39, '3555'),
	(377, 1, 0, -50924, 3557, 0, 0, 39, '3556'),
	(377, 1, 0, -50924, 3558, 0, 0, 39, '3557'),
	(377, 1, 0, -50924, 3559, 0, 0, 39, '3558'),
	(377, 1, 0, -50924, 3560, 0, 0, 39, '3559'),
	(377, 1, 0, -50924, 3561, 0, 0, 39, '3560'),
	(377, 1, 0, -50924, 3562, 0, 0, 39, '3561'),
	(377, 1, 0, -50924, 3563, 0, 0, 39, '3562'),
	(377, 1, 0, -50924, 3564, 0, 0, 39, '3563'),
	(377, 1, 0, -50924, 3565, 0, 0, 39, '3564'),
	(377, 1, 0, -50924, 3566, 0, 0, 39, '3565'),
	(377, 1, 0, -50924, 3567, 0, 0, 39, '3566'),
	(377, 1, 0, -50924, 3568, 0, 0, 39, '3567'),
	(377, 1, 0, -50924, 3569, 0, 0, 39, '3568'),
	(377, 1, 0, -50924, 3570, 0, 0, 39, '3569'),
	(377, 1, 0, -50924, 3571, 0, 0, 39, '3570'),
	(377, 1, 0, -50924, 3572, 0, 0, 39, '3571'),
	(377, 1, 0, -50924, 3573, 0, 0, 39, '3572'),
	(377, 1, 0, -50924, 3574, 0, 0, 39, '3573'),
	(377, 1, 0, -50924, 3575, 0, 0, 39, '3574'),
	(377, 1, 0, -50924, 3576, 0, 0, 39, '3575'),
	(377, 1, 0, -50924, 3577, 0, 0, 39, '3576'),
	(377, 1, 0, -50924, 3578, 0, 0, 39, '3577'),
	(377, 1, 0, -50924, 3579, 0, 0, 39, '3578'),
	(377, 1, 0, -50924, 3580, 0, 0, 39, '3579'),
	(377, 1, 0, -50924, 3581, 0, 0, 39, '3580'),
	(377, 1, 0, -50924, 3582, 0, 0, 39, '3581'),
	(377, 1, 0, -50924, 3583, 0, 0, 39, '3582'),
	(377, 1, 0, -50924, 3584, 0, 0, 39, '3583'),
	(377, 1, 0, -50924, 3585, 0, 0, 39, '3584'),
	(377, 1, 0, -50924, 3586, 0, 0, 39, '3585'),
	(377, 1, 0, -50924, 3587, 0, 0, 39, '3586'),
	(377, 1, 0, -50924, 3588, 0, 0, 39, '3587'),
	(377, 1, 0, -50924, 3589, 0, 0, 39, '3588'),
	(377, 1, 0, -50924, 3590, 0, 0, 39, '3589'),
	(377, 1, 0, -50924, 3591, 0, 0, 39, '3590'),
	(377, 1, 0, -50924, 3592, 0, 0, 39, '3591'),
	(377, 1, 0, -50924, 3593, 0, 0, 39, '3592'),
	(377, 1, 0, -50924, 3594, 0, 0, 39, '3593'),
	(377, 1, 0, -50924, 3595, 0, 0, 39, '3594'),
	(377, 1, 0, -50924, 3596, 0, 0, 39, '3595'),
	(377, 1, 0, -50924, 3597, 0, 0, 39, '3596'),
	(377, 1, 0, -50924, 3598, 0, 0, 39, '3597'),
	(377, 1, 0, -50924, 3599, 0, 0, 39, '3598'),
	(377, 1, 0, -50924, 3600, 0, 0, 39, '3599'),
	(377, 1, 0, -50924, 3601, 0, 0, 39, '3600'),
	(377, 1, 0, -50924, 3602, 0, 0, 39, '3601'),
	(377, 1, 0, -50924, 3603, 0, 0, 39, '3602'),
	(377, 1, 0, -50924, 3604, 0, 0, 39, '3603'),
	(377, 1, 0, -50924, 3605, 0, 0, 39, '3604'),
	(377, 1, 0, -50924, 3606, 0, 0, 39, '3605'),
	(377, 1, 0, -50924, 3607, 0, 0, 39, '3606'),
	(377, 1, 0, -50924, 3608, 0, 0, 39, '3607'),
	(377, 1, 0, -50924, 3609, 0, 0, 39, '3608'),
	(377, 1, 0, -50924, 3610, 0, 0, 39, '3609'),
	(377, 1, 0, -50924, 3611, 0, 0, 39, '3610'),
	(377, 1, 0, -50924, 3612, 0, 0, 39, '3611'),
	(377, 1, 0, -50924, 3613, 0, 0, 39, '3612'),
	(377, 1, 0, -50924, 3614, 0, 0, 39, '3613'),
	(377, 1, 0, -50924, 3615, 0, 0, 39, '3614'),
	(377, 1, 0, -50924, 3616, 0, 0, 39, '3615'),
	(377, 1, 0, -50924, 3617, 0, 0, 39, '3616'),
	(377, 1, 0, -50924, 3618, 0, 0, 39, '3617'),
	(377, 1, 0, -50924, 3619, 0, 0, 39, '3618'),
	(377, 1, 0, -50924, 3620, 0, 0, 39, '3619'),
	(377, 1, 0, -50924, 3621, 0, 0, 39, '3620'),
	(377, 1, 0, -50924, 3622, 0, 0, 39, '3621'),
	(377, 1, 0, -50924, 3623, 0, 0, 39, '3622'),
	(377, 1, 0, -50924, 3624, 0, 0, 39, '3623'),
	(377, 1, 0, -50924, 3625, 0, 0, 39, '3624'),
	(377, 1, 0, -50924, 3626, 0, 0, 39, '3625'),
	(377, 1, 0, -50924, 3627, 0, 0, 39, '3626'),
	(377, 1, 0, -50924, 3628, 0, 0, 39, '3627'),
	(377, 1, 0, -50924, 3629, 0, 0, 39, '3628'),
	(377, 1, 0, -50924, 3630, 0, 0, 39, '3629'),
	(377, 1, 0, -50924, 3631, 0, 0, 39, '3630'),
	(377, 1, 0, -50924, 3632, 0, 0, 39, '3631'),
	(377, 1, 0, -50924, 3633, 0, 0, 39, '3632'),
	(377, 1, 0, -50924, 3634, 0, 0, 39, '3633'),
	(377, 1, 0, -50924, 3635, 0, 0, 39, '3634'),
	(377, 1, 0, -50924, 3636, 0, 0, 39, '3635'),
	(377, 1, 0, -50924, 3637, 0, 0, 39, '3636'),
	(377, 1, 0, -50924, 3638, 0, 0, 39, '3637'),
	(377, 1, 0, -50924, 3639, 0, 0, 39, '3638'),
	(377, 1, 0, -50924, 3640, 0, 0, 39, '3639'),
	(377, 1, 0, -50924, 3641, 0, 0, 39, '3640'),
	(377, 1, 0, -50924, 3642, 0, 0, 39, '3641'),
	(377, 1, 0, -50924, 3643, 0, 0, 39, '3642'),
	(377, 1, 0, -50924, 3644, 0, 0, 39, '3643'),
	(377, 1, 0, -50924, 3645, 0, 0, 39, '3644'),
	(377, 1, 0, -50924, 3646, 0, 0, 39, '3645'),
	(377, 1, 0, -50924, 3647, 0, 0, 39, '3646'),
	(377, 1, 0, -50924, 3648, 0, 0, 39, '3647'),
	(377, 1, 0, -50924, 3649, 0, 0, 39, '3648'),
	(377, 1, 0, -50924, 3650, 0, 0, 39, '3649'),
	(377, 1, 0, -50924, 3651, 0, 0, 39, '3650'),
	(377, 1, 0, -50924, 3652, 0, 0, 39, '3651'),
	(377, 1, 0, -50924, 3653, 0, 0, 39, '3652'),
	(377, 1, 0, -50924, 3654, 0, 0, 39, '3653'),
	(377, 1, 0, -50924, 3655, 0, 0, 39, '3654'),
	(377, 1, 0, -50924, 3656, 0, 0, 39, '3655'),
	(377, 1, 0, -50924, 3657, 0, 0, 39, '3656'),
	(377, 1, 0, -50924, 3658, 0, 0, 39, '3657'),
	(377, 1, 0, -50924, 3659, 0, 0, 39, '3658'),
	(377, 1, 0, -50924, 3660, 0, 0, 39, '3659'),
	(377, 1, 0, -50924, 3661, 0, 0, 39, '3660'),
	(377, 1, 0, -50924, 3662, 0, 0, 39, '3661'),
	(377, 1, 0, -50924, 3663, 0, 0, 39, '3662'),
	(377, 1, 0, -50924, 3664, 0, 0, 39, '3663'),
	(377, 1, 0, -50924, 3665, 0, 0, 39, '3664'),
	(377, 1, 0, -50924, 3666, 0, 0, 39, '3665'),
	(377, 1, 0, -50924, 3667, 0, 0, 39, '3666'),
	(377, 1, 0, -50924, 3668, 0, 0, 39, '3667'),
	(377, 1, 0, -50924, 3669, 0, 0, 39, '3668'),
	(377, 1, 0, -50924, 3670, 0, 0, 39, '3669'),
	(377, 1, 0, -50924, 3671, 0, 0, 39, '3670'),
	(377, 1, 0, -50924, 3672, 0, 0, 39, '3671'),
	(377, 1, 0, -50924, 3673, 0, 0, 39, '3672'),
	(377, 1, 0, -50924, 3674, 0, 0, 39, '3673'),
	(377, 1, 0, -50924, 3675, 0, 0, 39, '3674'),
	(377, 1, 0, -50924, 3676, 0, 0, 39, '3675'),
	(377, 1, 0, -50924, 3677, 0, 0, 39, '3676'),
	(377, 1, 0, -50924, 3678, 0, 0, 39, '3677'),
	(377, 1, 0, -50924, 3679, 0, 0, 39, '3678'),
	(377, 1, 0, -50924, 3680, 0, 0, 39, '3679'),
	(377, 1, 0, -50924, 3681, 0, 0, 39, '3680'),
	(377, 1, 0, -50924, 3682, 0, 0, 39, '3681'),
	(377, 1, 0, -50924, 3683, 0, 0, 39, '3682'),
	(377, 1, 0, -50924, 3684, 0, 0, 39, '3683'),
	(377, 1, 0, -50924, 3685, 0, 0, 39, '3684'),
	(377, 1, 0, -50924, 3686, 0, 0, 39, '3685'),
	(377, 1, 0, -50924, 3687, 0, 0, 39, '3686'),
	(377, 1, 0, -50924, 3688, 0, 0, 39, '3687'),
	(377, 1, 0, -50924, 3689, 0, 0, 39, '3688'),
	(377, 1, 0, -50924, 3690, 0, 0, 39, '3689'),
	(377, 1, 0, -50924, 3691, 0, 0, 39, '3690'),
	(377, 1, 0, -50924, 3692, 0, 0, 39, '3691'),
	(377, 1, 0, -50924, 3693, 0, 0, 39, '3692'),
	(377, 1, 0, -50924, 3694, 0, 0, 39, '3693'),
	(377, 1, 0, -50924, 3695, 0, 0, 39, '3694'),
	(377, 1, 0, -50924, 3696, 0, 0, 39, '3695'),
	(377, 1, 0, -50924, 3697, 0, 0, 39, '3696'),
	(377, 1, 0, -50924, 3698, 0, 0, 39, '3697'),
	(377, 1, 0, -50924, 3699, 0, 0, 39, '3698'),
	(377, 1, 0, -50924, 3700, 0, 0, 39, '3699'),
	(377, 1, 0, -50924, 3701, 0, 0, 39, '3700'),
	(377, 1, 0, -50924, 3702, 0, 0, 39, '3701'),
	(377, 1, 0, -50924, 3703, 0, 0, 39, '3702'),
	(377, 1, 0, -50924, 3704, 0, 0, 39, '3703'),
	(377, 1, 0, -50924, 3705, 0, 0, 39, '3704'),
	(377, 1, 0, -50924, 3706, 0, 0, 39, '3705'),
	(377, 1, 0, -50924, 3707, 0, 0, 39, '3706'),
	(377, 1, 0, -50924, 3708, 0, 0, 39, '3707'),
	(377, 1, 0, -50924, 3709, 0, 0, 39, '3708'),
	(377, 1, 0, -50924, 3710, 0, 0, 39, '3709'),
	(377, 1, 0, -50924, 3711, 0, 0, 39, '3710'),
	(377, 1, 0, -50924, 3712, 0, 0, 39, '3711'),
	(377, 1, 0, -50924, 3713, 0, 0, 39, '3712'),
	(377, 1, 0, -50924, 3714, 0, 0, 39, '3713'),
	(377, 1, 0, -50924, 3715, 0, 0, 39, '3714'),
	(377, 1, 0, -50924, 3716, 0, 0, 39, '3715'),
	(377, 1, 0, -50924, 3717, 0, 0, 39, '3716'),
	(377, 1, 0, -50924, 3718, 0, 0, 39, '3717'),
	(377, 1, 0, -50924, 3719, 0, 0, 39, '3718'),
	(377, 1, 0, -50924, 3720, 0, 0, 39, '3719'),
	(377, 1, 0, -50924, 3721, 0, 0, 39, '3720'),
	(377, 1, 0, -50924, 3722, 0, 0, 39, '3721'),
	(377, 1, 0, -50924, 3723, 0, 0, 39, '3722'),
	(377, 1, 0, -50924, 3724, 0, 0, 39, '3723'),
	(377, 1, 0, -50924, 3725, 0, 0, 39, '3724'),
	(377, 1, 0, -50924, 3726, 0, 0, 39, '3725'),
	(377, 1, 0, -50924, 3727, 0, 0, 39, '3726'),
	(377, 1, 0, -50924, 3728, 0, 0, 39, '3727'),
	(377, 1, 0, -50924, 3729, 0, 0, 39, '3728'),
	(377, 1, 0, -50924, 3730, 0, 0, 39, '3729'),
	(377, 1, 0, -50924, 3731, 0, 0, 39, '3730'),
	(377, 1, 0, -50924, 3732, 0, 0, 39, '3731'),
	(377, 1, 0, -50924, 3733, 0, 0, 39, '3732'),
	(377, 1, 0, -50924, 3734, 0, 0, 39, '3733'),
	(377, 1, 0, -50924, 3735, 0, 0, 39, '3734'),
	(377, 1, 0, -50924, 3736, 0, 0, 39, '3735'),
	(377, 1, 0, -50924, 3737, 0, 0, 39, '3736'),
	(377, 1, 0, -50924, 3738, 0, 0, 39, '3737'),
	(377, 1, 0, -50924, 3739, 0, 0, 39, '3738'),
	(377, 1, 0, -50924, 3740, 0, 0, 39, '3739'),
	(377, 1, 0, -50924, 3741, 0, 0, 39, '3740'),
	(377, 1, 0, -50924, 3742, 0, 0, 39, '3741'),
	(377, 1, 0, -50924, 3743, 0, 0, 39, '3742'),
	(377, 1, 0, -50924, 3744, 0, 0, 39, '3743'),
	(377, 1, 0, -50924, 3745, 0, 0, 39, '3744'),
	(377, 1, 0, -50924, 3746, 0, 0, 39, '3745'),
	(377, 1, 0, -50924, 3747, 0, 0, 39, '3746'),
	(377, 1, 0, -50924, 3748, 0, 0, 39, '3747'),
	(377, 1, 0, -50924, 3749, 0, 0, 39, '3748'),
	(377, 1, 0, -50924, 3750, 0, 0, 39, '3749'),
	(377, 1, 0, -50924, 3751, 0, 0, 39, '3750'),
	(377, 1, 0, -50924, 3752, 0, 0, 39, '3751'),
	(377, 1, 0, -50924, 3753, 0, 0, 39, '3752'),
	(377, 1, 0, -50924, 3754, 0, 0, 39, '3753'),
	(377, 1, 0, -50924, 3755, 0, 0, 39, '3754'),
	(377, 1, 0, -50924, 3756, 0, 0, 39, '3755'),
	(377, 1, 0, -50924, 3757, 0, 0, 39, '3756'),
	(377, 1, 0, -50924, 3758, 0, 0, 39, '3757'),
	(377, 1, 0, -50924, 3759, 0, 0, 39, '3758'),
	(377, 1, 0, -50924, 3760, 0, 0, 39, '3759'),
	(377, 1, 0, -50924, 3761, 0, 0, 39, '3760'),
	(377, 1, 0, -50924, 3762, 0, 0, 39, '3761'),
	(377, 1, 0, -50924, 3763, 0, 0, 39, '3762'),
	(377, 1, 0, -50924, 3764, 0, 0, 39, '3763'),
	(377, 1, 0, -50924, 3765, 0, 0, 39, '3764'),
	(377, 1, 0, -50924, 3766, 0, 0, 39, '3765'),
	(377, 1, 0, -50924, 3767, 0, 0, 39, '3766'),
	(377, 1, 0, -50924, 3768, 0, 0, 39, '3767'),
	(377, 1, 0, -50924, 3769, 0, 0, 39, '3768'),
	(377, 1, 0, -50924, 3770, 0, 0, 39, '3769'),
	(377, 1, 0, -50924, 3771, 0, 0, 39, '3770'),
	(377, 1, 0, -50924, 3772, 0, 0, 39, '3771'),
	(377, 1, 0, -50924, 3773, 0, 0, 39, '3772'),
	(377, 1, 0, -50924, 3774, 0, 0, 39, '3773'),
	(377, 1, 0, -50924, 3775, 0, 0, 39, '3774'),
	(377, 1, 0, -50924, 3776, 0, 0, 39, '3775'),
	(377, 1, 0, -50924, 3777, 0, 0, 39, '3776'),
	(377, 1, 0, -50924, 3778, 0, 0, 39, '3777'),
	(377, 1, 0, -50924, 3779, 0, 0, 39, '3778'),
	(377, 1, 0, -50924, 3780, 0, 0, 39, '3779'),
	(377, 1, 0, -50924, 3781, 0, 0, 39, '3780'),
	(377, 1, 0, -50924, 3782, 0, 0, 39, '3781'),
	(377, 1, 0, -50924, 3783, 0, 0, 39, '3782'),
	(377, 1, 0, -50924, 3784, 0, 0, 39, '3783'),
	(377, 1, 0, -50924, 3785, 0, 0, 39, '3784'),
	(377, 1, 0, -50924, 3786, 0, 0, 39, '3785'),
	(377, 1, 0, -50924, 3787, 0, 0, 39, '3786'),
	(377, 1, 0, -50924, 3788, 0, 0, 39, '3787'),
	(377, 1, 0, -50924, 3789, 0, 0, 39, '3788'),
	(377, 1, 0, -50924, 3790, 0, 0, 39, '3789'),
	(377, 1, 0, -50924, 3791, 0, 0, 39, '3790'),
	(377, 1, 0, -50924, 3792, 0, 0, 39, '3791'),
	(377, 1, 0, -50924, 3793, 0, 0, 39, '3792'),
	(377, 1, 0, -50924, 3794, 0, 0, 39, '3793'),
	(377, 1, 0, -50924, 3795, 0, 0, 39, '3794'),
	(377, 1, 0, -50924, 3796, 0, 0, 39, '3795'),
	(377, 1, 0, -50924, 3797, 0, 0, 39, '3796'),
	(377, 1, 0, -50924, 3798, 0, 0, 39, '3797'),
	(377, 1, 0, -50924, 3799, 0, 0, 39, '3798'),
	(377, 1, 0, -50924, 3800, 0, 0, 39, '3799'),
	(377, 1, 0, -50924, 3801, 0, 0, 39, '3800'),
	(377, 1, 0, -50924, 3802, 0, 0, 39, '3801'),
	(377, 1, 0, -50924, 3803, 0, 0, 39, '3802'),
	(377, 1, 0, -50924, 3804, 0, 0, 39, '3803'),
	(377, 1, 0, -50924, 3805, 0, 0, 39, '3804'),
	(377, 1, 0, -50924, 3806, 0, 0, 39, '3805'),
	(377, 1, 0, -50924, 3807, 0, 0, 39, '3806'),
	(377, 1, 0, -50924, 3808, 0, 0, 39, '3807'),
	(377, 1, 0, -50924, 3809, 0, 0, 39, '3808'),
	(377, 1, 0, -50924, 3810, 0, 0, 39, '3809'),
	(377, 1, 0, -50924, 3811, 0, 0, 39, '3810'),
	(377, 1, 0, -50924, 3812, 0, 0, 39, '3811'),
	(377, 1, 0, -50924, 3813, 0, 0, 39, '3812'),
	(377, 1, 0, -50924, 3814, 0, 0, 39, '3813'),
	(377, 1, 0, -50924, 3815, 0, 0, 39, '3814'),
	(377, 1, 0, -50924, 3816, 0, 0, 39, '3815'),
	(377, 1, 0, -50924, 3817, 0, 0, 39, '3816'),
	(377, 1, 0, -50924, 3818, 0, 0, 39, '3817'),
	(377, 1, 0, -50924, 3819, 0, 0, 39, '3818'),
	(377, 1, 0, -50924, 3820, 0, 0, 39, '3819'),
	(377, 1, 0, -50924, 3821, 0, 0, 39, '3820'),
	(377, 1, 0, -50924, 3822, 0, 0, 39, '3821'),
	(377, 1, 0, -50924, 3823, 0, 0, 39, '3822'),
	(377, 1, 0, -50924, 3824, 0, 0, 39, '3823'),
	(377, 1, 0, -50924, 3825, 0, 0, 39, '3824'),
	(377, 1, 0, -50924, 3826, 0, 0, 39, '3825'),
	(377, 1, 0, -50924, 3827, 0, 0, 39, '3826'),
	(377, 1, 0, -50924, 3828, 0, 0, 39, '3827'),
	(377, 1, 0, -50924, 3829, 0, 0, 39, '3828'),
	(377, 1, 0, -50924, 3830, 0, 0, 39, '3829'),
	(377, 1, 0, -50924, 3831, 0, 0, 39, '3830'),
	(377, 1, 0, -50924, 3832, 0, 0, 39, '3831'),
	(377, 1, 0, -50924, 3833, 0, 0, 39, '3832'),
	(377, 1, 0, -50924, 3834, 0, 0, 39, '3833'),
	(377, 1, 0, -50924, 3835, 0, 0, 39, '3834'),
	(377, 1, 0, -50924, 3836, 0, 0, 39, '3835');
INSERT INTO `src_type_mod_withe#opty` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`, `ind1`, `ind2`, `ind3`, `opty_id`, `opty_value`) VALUES
	(377, 1, 0, -50924, 3837, 0, 0, 39, '3836'),
	(377, 1, 0, -50924, 3838, 0, 0, 39, '3837'),
	(377, 1, 0, -50924, 3839, 0, 0, 39, '3838'),
	(377, 1, 0, -50924, 3840, 0, 0, 39, '3839'),
	(377, 1, 0, -50924, 3841, 0, 0, 39, '3840'),
	(377, 1, 0, -50924, 3842, 0, 0, 39, '3841'),
	(377, 1, 0, -50924, 3843, 0, 0, 39, '3842'),
	(377, 1, 0, -50924, 3844, 0, 0, 39, '3843'),
	(377, 1, 0, -50924, 3845, 0, 0, 39, '3844'),
	(377, 1, 0, -50924, 3846, 0, 0, 39, '3845'),
	(377, 1, 0, -50924, 3847, 0, 0, 39, '3846'),
	(377, 1, 0, -50924, 3848, 0, 0, 39, '3847'),
	(377, 1, 0, -50924, 3849, 0, 0, 39, '3848'),
	(377, 1, 0, -50924, 3850, 0, 0, 39, '3849'),
	(377, 1, 0, -50924, 3851, 0, 0, 39, '3850'),
	(377, 1, 0, -50924, 3852, 0, 0, 39, '3851'),
	(377, 1, 0, -50924, 3853, 0, 0, 39, '3852'),
	(377, 1, 0, -50924, 3854, 0, 0, 39, '3853'),
	(377, 1, 0, -50924, 3855, 0, 0, 39, '3854'),
	(377, 1, 0, -50924, 3856, 0, 0, 39, '3855'),
	(377, 1, 0, -50924, 3857, 0, 0, 39, '3856'),
	(377, 1, 0, -50924, 3858, 0, 0, 39, '3857'),
	(377, 1, 0, -50924, 3859, 0, 0, 39, '3858'),
	(377, 1, 0, -50924, 3860, 0, 0, 39, '3859'),
	(377, 1, 0, -50924, 3861, 0, 0, 39, '3860'),
	(377, 1, 0, -50924, 3862, 0, 0, 39, '3861'),
	(377, 1, 0, -50924, 3863, 0, 0, 39, '3862'),
	(377, 1, 0, -50924, 3864, 0, 0, 39, '3863'),
	(377, 1, 0, -50924, 3865, 0, 0, 39, '3864'),
	(377, 1, 0, -50924, 3866, 0, 0, 39, '3865'),
	(377, 1, 0, -50924, 3867, 0, 0, 39, '3866'),
	(377, 1, 0, -50924, 3868, 0, 0, 39, '3867'),
	(377, 1, 0, -50924, 3869, 0, 0, 39, '3868'),
	(377, 1, 0, -50924, 3870, 0, 0, 39, '3869'),
	(377, 1, 0, -50924, 3871, 0, 0, 39, '3870'),
	(377, 1, 0, -50924, 3872, 0, 0, 39, '3871'),
	(377, 1, 0, -50924, 3873, 0, 0, 39, '3872'),
	(377, 1, 0, -50924, 3874, 0, 0, 39, '3873'),
	(377, 1, 0, -50924, 3875, 0, 0, 39, '3874'),
	(377, 1, 0, -50924, 3876, 0, 0, 39, '3875'),
	(377, 1, 0, -50924, 3877, 0, 0, 39, '3876'),
	(377, 1, 0, -50924, 3878, 0, 0, 39, '3877'),
	(377, 1, 0, -50924, 3879, 0, 0, 39, '3878'),
	(377, 1, 0, -50924, 3880, 0, 0, 39, '3879'),
	(377, 1, 0, -50924, 3881, 0, 0, 39, '3880'),
	(377, 1, 0, -50924, 3882, 0, 0, 39, '3881'),
	(377, 1, 0, -50924, 3883, 0, 0, 39, '3882'),
	(377, 1, 0, -50924, 3884, 0, 0, 39, '3883'),
	(377, 1, 0, -50924, 3885, 0, 0, 39, '3884'),
	(377, 1, 0, -50924, 3886, 0, 0, 39, '3885'),
	(377, 1, 0, -50924, 3887, 0, 0, 39, '3886'),
	(377, 1, 0, -50924, 3888, 0, 0, 39, '3887'),
	(377, 1, 0, -50924, 3889, 0, 0, 39, '3888'),
	(377, 1, 0, -50924, 3890, 0, 0, 39, '3889'),
	(377, 1, 0, -50924, 3891, 0, 0, 39, '3890'),
	(377, 1, 0, -50924, 3892, 0, 0, 39, '3891'),
	(377, 1, 0, -50924, 3893, 0, 0, 39, '3892'),
	(377, 1, 0, -50924, 3894, 0, 0, 39, '3893'),
	(377, 1, 0, -50924, 3895, 0, 0, 39, '3894'),
	(377, 1, 0, -50924, 3896, 0, 0, 39, '3895'),
	(377, 1, 0, -50924, 3897, 0, 0, 39, '3896'),
	(377, 1, 0, -50924, 3898, 0, 0, 39, '3897'),
	(377, 1, 0, -50924, 3899, 0, 0, 39, '3898'),
	(377, 1, 0, -50924, 3900, 0, 0, 39, '3899'),
	(377, 1, 0, -50924, 3901, 0, 0, 39, '3900'),
	(377, 1, 0, -50924, 3902, 0, 0, 39, '3901'),
	(377, 1, 0, -50924, 3903, 0, 0, 39, '3902'),
	(377, 1, 0, -50924, 3904, 0, 0, 39, '3903'),
	(377, 1, 0, -50924, 3905, 0, 0, 39, '3904'),
	(377, 1, 0, -50924, 3906, 0, 0, 39, '3905'),
	(377, 1, 0, -50924, 3907, 0, 0, 39, '3906'),
	(377, 1, 0, -50924, 3908, 0, 0, 39, '3907'),
	(377, 1, 0, -50924, 3909, 0, 0, 39, '3908'),
	(377, 1, 0, -50924, 3910, 0, 0, 39, '3909'),
	(377, 1, 0, -50924, 3911, 0, 0, 39, '3910'),
	(377, 1, 0, -50924, 3912, 0, 0, 39, '3911'),
	(377, 1, 0, -50924, 3913, 0, 0, 39, '3912'),
	(377, 1, 0, -50924, 3914, 0, 0, 39, '3913'),
	(377, 1, 0, -50924, 3915, 0, 0, 39, '3914'),
	(377, 1, 0, -50924, 3916, 0, 0, 39, '3915'),
	(377, 1, 0, -50924, 3917, 0, 0, 39, '3916'),
	(377, 1, 0, -50924, 3918, 0, 0, 39, '3917'),
	(377, 1, 0, -50924, 3919, 0, 0, 39, '3918'),
	(377, 1, 0, -50924, 3920, 0, 0, 39, '3919'),
	(377, 1, 0, -50924, 3921, 0, 0, 39, '3920'),
	(377, 1, 0, -50924, 3922, 0, 0, 39, '3921'),
	(377, 1, 0, -50924, 3923, 0, 0, 39, '3922'),
	(377, 1, 0, -50924, 3924, 0, 0, 39, '3923'),
	(377, 1, 0, -50924, 3925, 0, 0, 39, '3924'),
	(377, 1, 0, -50924, 3926, 0, 0, 39, '3925'),
	(377, 1, 0, -50924, 3927, 0, 0, 39, '3926'),
	(377, 1, 0, -50924, 3928, 0, 0, 39, '3927'),
	(377, 1, 0, -50924, 3929, 0, 0, 39, '3928'),
	(377, 1, 0, -50924, 3930, 0, 0, 39, '3929'),
	(377, 1, 0, -50924, 3931, 0, 0, 39, '3930'),
	(377, 1, 0, -50924, 3932, 0, 0, 39, '3931'),
	(377, 1, 0, -50924, 3933, 0, 0, 39, '3932'),
	(377, 1, 0, -50924, 3934, 0, 0, 39, '3933'),
	(377, 1, 0, -50924, 3935, 0, 0, 39, '3934'),
	(377, 1, 0, -50924, 3936, 0, 0, 39, '3935'),
	(377, 1, 0, -50924, 3937, 0, 0, 39, '3936'),
	(377, 1, 0, -50924, 3938, 0, 0, 39, '3937'),
	(377, 1, 0, -50924, 3939, 0, 0, 39, '3938'),
	(377, 1, 0, -50924, 3940, 0, 0, 39, '3939'),
	(377, 1, 0, -50924, 3941, 0, 0, 39, '3940'),
	(377, 1, 0, -50924, 3942, 0, 0, 39, '3941'),
	(377, 1, 0, -50924, 3943, 0, 0, 39, '3942'),
	(377, 1, 0, -50924, 3944, 0, 0, 39, '3943'),
	(377, 1, 0, -50924, 3945, 0, 0, 39, '3944'),
	(377, 1, 0, -50924, 3946, 0, 0, 39, '3945'),
	(377, 1, 0, -50924, 3947, 0, 0, 39, '3946'),
	(377, 1, 0, -50924, 3948, 0, 0, 39, '3947'),
	(377, 1, 0, -50924, 3949, 0, 0, 39, '3948'),
	(377, 1, 0, -50924, 3950, 0, 0, 39, '3949'),
	(377, 1, 0, -50924, 3951, 0, 0, 39, '3950'),
	(377, 1, 0, -50924, 3952, 0, 0, 39, '3951'),
	(377, 1, 0, -50924, 3953, 0, 0, 39, '3952'),
	(377, 1, 0, -50924, 3954, 0, 0, 39, '3953'),
	(377, 1, 0, -50924, 3955, 0, 0, 39, '3954'),
	(377, 1, 0, -50924, 3956, 0, 0, 39, '3955'),
	(377, 1, 0, -50924, 3957, 0, 0, 39, '3956'),
	(377, 1, 0, -50924, 3958, 0, 0, 39, '3957'),
	(377, 1, 0, -50924, 3959, 0, 0, 39, '3958'),
	(377, 1, 0, -50924, 3960, 0, 0, 39, '3959'),
	(377, 1, 0, -50924, 3961, 0, 0, 39, '3960'),
	(377, 1, 0, -50924, 3962, 0, 0, 39, '3961'),
	(377, 1, 0, -50924, 3963, 0, 0, 39, '3962'),
	(377, 1, 0, -50924, 3964, 0, 0, 39, '3963'),
	(377, 1, 0, -50924, 3965, 0, 0, 39, '3964'),
	(377, 1, 0, -50924, 3966, 0, 0, 39, '3965'),
	(377, 1, 0, -50924, 3967, 0, 0, 39, '3966'),
	(377, 1, 0, -50924, 3968, 0, 0, 39, '3967'),
	(377, 1, 0, -50924, 3969, 0, 0, 39, '3968'),
	(377, 1, 0, -50924, 3970, 0, 0, 39, '3969'),
	(377, 1, 0, -50924, 3971, 0, 0, 39, '3970'),
	(377, 1, 0, -50924, 3972, 0, 0, 39, '3971'),
	(377, 1, 0, -50924, 3973, 0, 0, 39, '3972'),
	(377, 1, 0, -50924, 3974, 0, 0, 39, '3973'),
	(377, 1, 0, -50924, 3975, 0, 0, 39, '3974'),
	(377, 1, 0, -50924, 3976, 0, 0, 39, '3975'),
	(377, 1, 0, -50924, 3977, 0, 0, 39, '3976'),
	(377, 1, 0, -50924, 3978, 0, 0, 39, '3977'),
	(377, 1, 0, -50924, 3979, 0, 0, 39, '3978'),
	(377, 1, 0, -50924, 3980, 0, 0, 39, '3979'),
	(377, 1, 0, -50924, 3981, 0, 0, 39, '3980'),
	(377, 1, 0, -50924, 3982, 0, 0, 39, '3981'),
	(377, 1, 0, -50924, 3983, 0, 0, 39, '3982'),
	(377, 1, 0, -50924, 3984, 0, 0, 39, '3983'),
	(377, 1, 0, -50924, 3985, 0, 0, 39, '3984'),
	(377, 1, 0, -50924, 3986, 0, 0, 39, '3985'),
	(377, 1, 0, -50924, 3987, 0, 0, 39, '3986'),
	(377, 1, 0, -50924, 3988, 0, 0, 39, '3987'),
	(377, 1, 0, -50924, 3989, 0, 0, 39, '3988'),
	(377, 1, 0, -50924, 3990, 0, 0, 39, '3989'),
	(377, 1, 0, -50924, 3991, 0, 0, 39, '3990'),
	(377, 1, 0, -50924, 3992, 0, 0, 39, '3991'),
	(377, 1, 0, -50924, 3993, 0, 0, 39, '3992'),
	(377, 1, 0, -50924, 3994, 0, 0, 39, '3993'),
	(377, 1, 0, -50924, 3995, 0, 0, 39, '3994'),
	(377, 1, 0, -50924, 3996, 0, 0, 39, '3995'),
	(377, 1, 0, -50924, 3997, 0, 0, 39, '3996'),
	(377, 1, 0, -50924, 3998, 0, 0, 39, '3997'),
	(377, 1, 0, -50924, 3999, 0, 0, 39, '3998'),
	(377, 1, 0, -50924, 4000, 0, 0, 39, '3999'),
	(377, 1, 0, -50583, 1, 0, 0, 39, '4'),
	(377, 1, 0, -50583, 2, 0, 0, 39, '5'),
	(377, 1, 0, -50553, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50553, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50553, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50553, 4, 0, 0, 39, '3'),
	(377, 1, 0, -50553, 5, 0, 0, 39, '4'),
	(377, 1, 0, -50553, 6, 0, 0, 39, '5'),
	(377, 1, 0, -50553, 7, 0, 0, 39, '6'),
	(377, 1, 0, -50553, 8, 0, 0, 39, '7'),
	(377, 1, 0, -50553, 9, 0, 0, 39, '8'),
	(377, 1, 0, -50553, 10, 0, 0, 39, '9'),
	(377, 1, 0, -50553, 11, 0, 0, 39, '10'),
	(377, 1, 0, -50553, 12, 0, 0, 39, '11'),
	(377, 1, 0, -50553, 13, 0, 0, 39, '12'),
	(377, 1, 0, -50553, 14, 0, 0, 39, '13'),
	(377, 1, 0, -50553, 15, 0, 0, 39, '14'),
	(377, 1, 0, -50553, 16, 0, 0, 39, '15'),
	(377, 1, 0, -50553, 17, 0, 0, 39, '16'),
	(377, 1, 0, -50553, 18, 0, 0, 39, '17'),
	(377, 1, 0, -50553, 19, 0, 0, 39, '18'),
	(377, 1, 0, -50553, 20, 0, 0, 39, '19'),
	(377, 1, 0, -50553, 21, 0, 0, 39, '20'),
	(377, 1, 0, -50553, 22, 0, 0, 39, '21'),
	(377, 1, 0, -50553, 23, 0, 0, 39, '22'),
	(377, 1, 0, -50553, 24, 0, 0, 39, '23'),
	(377, 1, 0, -50553, 25, 0, 0, 39, '24'),
	(377, 1, 0, -50553, 26, 0, 0, 39, '25'),
	(377, 1, 0, -50553, 27, 0, 0, 39, '26'),
	(377, 1, 0, -50553, 28, 0, 0, 39, '27'),
	(377, 1, 0, -50553, 29, 0, 0, 39, '28'),
	(377, 1, 0, -50553, 30, 0, 0, 39, '29'),
	(377, 1, 0, -50553, 31, 0, 0, 39, '30'),
	(377, 1, 0, -50553, 32, 0, 0, 39, '31'),
	(377, 1, 0, -50553, 33, 0, 0, 39, '32'),
	(377, 1, 0, -50553, 34, 0, 0, 39, '33'),
	(377, 1, 0, -50553, 35, 0, 0, 39, '34'),
	(377, 1, 0, -50553, 36, 0, 0, 39, '35'),
	(377, 1, 0, -50553, 37, 0, 0, 39, '36'),
	(377, 1, 0, -50553, 38, 0, 0, 39, '37'),
	(377, 1, 0, -50553, 39, 0, 0, 39, '38'),
	(377, 1, 0, -50553, 40, 0, 0, 39, '39'),
	(377, 1, 0, -50553, 41, 0, 0, 39, '40'),
	(377, 1, 0, -50553, 42, 0, 0, 39, '41'),
	(377, 1, 0, -50553, 43, 0, 0, 39, '42'),
	(377, 1, 0, -50553, 44, 0, 0, 39, '43'),
	(377, 1, 0, -50553, 45, 0, 0, 39, '44'),
	(377, 1, 0, -50553, 46, 0, 0, 39, '45'),
	(377, 1, 0, -50553, 47, 0, 0, 39, '46'),
	(377, 1, 0, -50553, 48, 0, 0, 39, '47'),
	(377, 1, 0, -50553, 49, 0, 0, 39, '48'),
	(377, 1, 0, -50553, 50, 0, 0, 39, '49'),
	(377, 1, 0, -50553, 51, 0, 0, 39, '50'),
	(377, 1, 0, -50553, 52, 0, 0, 39, '51'),
	(377, 1, 0, -50553, 53, 0, 0, 39, '52'),
	(377, 1, 0, -50553, 54, 0, 0, 39, '53'),
	(377, 1, 0, -50553, 55, 0, 0, 39, '54'),
	(377, 1, 0, -50553, 56, 0, 0, 39, '55'),
	(377, 1, 0, -50553, 57, 0, 0, 39, '56'),
	(377, 1, 0, -50553, 58, 0, 0, 39, '57'),
	(377, 1, 0, -50553, 59, 0, 0, 39, '58'),
	(377, 1, 0, -50553, 60, 0, 0, 39, '59'),
	(377, 1, 0, -50553, 61, 0, 0, 39, '60'),
	(377, 1, 0, -50553, 62, 0, 0, 39, '61'),
	(377, 1, 0, -50553, 63, 0, 0, 39, '62'),
	(377, 1, 0, -50553, 64, 0, 0, 39, '63'),
	(377, 1, 0, -50553, 65, 0, 0, 39, '64'),
	(377, 1, 0, -50553, 66, 0, 0, 39, '65'),
	(377, 1, 0, -50553, 67, 0, 0, 39, '66'),
	(377, 1, 0, -50553, 68, 0, 0, 39, '67'),
	(377, 1, 0, -50553, 69, 0, 0, 39, '68'),
	(377, 1, 0, -50553, 70, 0, 0, 39, '69'),
	(377, 1, 0, -50553, 71, 0, 0, 39, '70'),
	(377, 1, 0, -50553, 72, 0, 0, 39, '71'),
	(377, 1, 0, -50553, 73, 0, 0, 39, '72'),
	(377, 1, 0, -50553, 74, 0, 0, 39, '73'),
	(377, 1, 0, -50553, 75, 0, 0, 39, '74'),
	(377, 1, 0, -50553, 76, 0, 0, 39, '75'),
	(377, 1, 0, -50553, 77, 0, 0, 39, '76'),
	(377, 1, 0, -50553, 78, 0, 0, 39, '77'),
	(377, 1, 0, -50553, 79, 0, 0, 39, '78'),
	(377, 1, 0, -50553, 80, 0, 0, 39, '79'),
	(377, 1, 0, -50553, 81, 0, 0, 39, '80'),
	(377, 1, 0, -50553, 82, 0, 0, 39, '81'),
	(377, 1, 0, -50553, 83, 0, 0, 39, '82'),
	(377, 1, 0, -50553, 84, 0, 0, 39, '83'),
	(377, 1, 0, -50553, 85, 0, 0, 39, '84'),
	(377, 1, 0, -50553, 86, 0, 0, 39, '85'),
	(377, 1, 0, -50553, 87, 0, 0, 39, '86'),
	(377, 1, 0, -50553, 88, 0, 0, 39, '87'),
	(377, 1, 0, -50553, 89, 0, 0, 39, '88'),
	(377, 1, 0, -50553, 90, 0, 0, 39, '89'),
	(377, 1, 0, -50553, 91, 0, 0, 39, '90'),
	(377, 1, 0, -50553, 92, 0, 0, 39, '91'),
	(377, 1, 0, -50553, 93, 0, 0, 39, '92'),
	(377, 1, 0, -50553, 94, 0, 0, 39, '93'),
	(377, 1, 0, -50553, 95, 0, 0, 39, '94'),
	(377, 1, 0, -50553, 96, 0, 0, 39, '95'),
	(377, 1, 0, -50553, 97, 0, 0, 39, '96'),
	(377, 1, 0, -50553, 98, 0, 0, 39, '97'),
	(377, 1, 0, -50553, 99, 0, 0, 39, '98'),
	(377, 1, 0, -50553, 100, 0, 0, 39, '99'),
	(377, 1, 0, -50553, 101, 0, 0, 39, '100'),
	(377, 1, 0, -50553, 102, 0, 0, 39, '101'),
	(377, 1, 0, -50553, 103, 0, 0, 39, '102'),
	(377, 1, 0, -50553, 104, 0, 0, 39, '103'),
	(377, 1, 0, -50553, 105, 0, 0, 39, '104'),
	(377, 1, 0, -50553, 106, 0, 0, 39, '105'),
	(377, 1, 0, -50553, 107, 0, 0, 39, '106'),
	(377, 1, 0, -50553, 108, 0, 0, 39, '107'),
	(377, 1, 0, -50553, 109, 0, 0, 39, '108'),
	(377, 1, 0, -50553, 110, 0, 0, 39, '109'),
	(377, 1, 0, -50553, 111, 0, 0, 39, '110'),
	(377, 1, 0, -50553, 112, 0, 0, 39, '111'),
	(377, 1, 0, -50553, 113, 0, 0, 39, '112'),
	(377, 1, 0, -50553, 114, 0, 0, 39, '113'),
	(377, 1, 0, -50553, 115, 0, 0, 39, '114'),
	(377, 1, 0, -50553, 116, 0, 0, 39, '115'),
	(377, 1, 0, -50553, 117, 0, 0, 39, '116'),
	(377, 1, 0, -50553, 118, 0, 0, 39, '117'),
	(377, 1, 0, -50553, 119, 0, 0, 39, '118'),
	(377, 1, 0, -50553, 120, 0, 0, 39, '119'),
	(377, 1, 0, -50553, 121, 0, 0, 39, '120'),
	(377, 1, 0, -50553, 122, 0, 0, 39, '121'),
	(377, 1, 0, -50553, 123, 0, 0, 39, '122'),
	(377, 1, 0, -50553, 124, 0, 0, 39, '123'),
	(377, 1, 0, -50553, 125, 0, 0, 39, '124'),
	(377, 1, 0, -50553, 126, 0, 0, 39, '125'),
	(377, 1, 0, -50553, 127, 0, 0, 39, '126'),
	(377, 1, 0, -50553, 128, 0, 0, 39, '127'),
	(377, 1, 0, -50553, 129, 0, 0, 39, '128'),
	(377, 1, 0, -50553, 130, 0, 0, 39, '129'),
	(377, 1, 0, -50553, 131, 0, 0, 39, '130'),
	(377, 1, 0, -50553, 132, 0, 0, 39, '131'),
	(377, 1, 0, -50553, 133, 0, 0, 39, '132'),
	(377, 1, 0, -50553, 134, 0, 0, 39, '133'),
	(377, 1, 0, -50553, 135, 0, 0, 39, '134'),
	(377, 1, 0, -50553, 136, 0, 0, 39, '135'),
	(377, 1, 0, -50553, 137, 0, 0, 39, '136'),
	(377, 1, 0, -50553, 138, 0, 0, 39, '137'),
	(377, 1, 0, -50553, 139, 0, 0, 39, '138'),
	(377, 1, 0, -50553, 140, 0, 0, 39, '139'),
	(377, 1, 0, -50553, 141, 0, 0, 39, '140'),
	(377, 1, 0, -50553, 142, 0, 0, 39, '141'),
	(377, 1, 0, -50553, 143, 0, 0, 39, '142'),
	(377, 1, 0, -50553, 144, 0, 0, 39, '143'),
	(377, 1, 0, -50553, 145, 0, 0, 39, '144'),
	(377, 1, 0, -50553, 146, 0, 0, 39, '145'),
	(377, 1, 0, -50553, 147, 0, 0, 39, '146'),
	(377, 1, 0, -50553, 148, 0, 0, 39, '147'),
	(377, 1, 0, -50553, 149, 0, 0, 39, '148'),
	(377, 1, 0, -50553, 150, 0, 0, 39, '149'),
	(377, 1, 0, -50553, 151, 0, 0, 39, '150'),
	(377, 1, 0, -50553, 152, 0, 0, 39, '151'),
	(377, 1, 0, -50553, 153, 0, 0, 39, '152'),
	(377, 1, 0, -50553, 154, 0, 0, 39, '153'),
	(377, 1, 0, -50553, 155, 0, 0, 39, '154'),
	(377, 1, 0, -50553, 156, 0, 0, 39, '155'),
	(377, 1, 0, -50553, 157, 0, 0, 39, '156'),
	(377, 1, 0, -50553, 158, 0, 0, 39, '157'),
	(377, 1, 0, -50553, 159, 0, 0, 39, '158'),
	(377, 1, 0, -50553, 160, 0, 0, 39, '159'),
	(377, 1, 0, -50553, 161, 0, 0, 39, '160'),
	(377, 1, 0, -50553, 162, 0, 0, 39, '161'),
	(377, 1, 0, -50553, 163, 0, 0, 39, '162'),
	(377, 1, 0, -50553, 164, 0, 0, 39, '163'),
	(377, 1, 0, -50553, 165, 0, 0, 39, '164'),
	(377, 1, 0, -50553, 166, 0, 0, 39, '165'),
	(377, 1, 0, -50553, 167, 0, 0, 39, '166'),
	(377, 1, 0, -50553, 168, 0, 0, 39, '167'),
	(377, 1, 0, -50553, 169, 0, 0, 39, '168'),
	(377, 1, 0, -50553, 170, 0, 0, 39, '169'),
	(377, 1, 0, -50553, 171, 0, 0, 39, '170'),
	(377, 1, 0, -50553, 172, 0, 0, 39, '171'),
	(377, 1, 0, -50553, 173, 0, 0, 39, '172'),
	(377, 1, 0, -50553, 174, 0, 0, 39, '173'),
	(377, 1, 0, -50553, 175, 0, 0, 39, '174'),
	(377, 1, 0, -50553, 176, 0, 0, 39, '175'),
	(377, 1, 0, -50553, 177, 0, 0, 39, '176'),
	(377, 1, 0, -50553, 178, 0, 0, 39, '177'),
	(377, 1, 0, -50553, 179, 0, 0, 39, '178'),
	(377, 1, 0, -50553, 180, 0, 0, 39, '179'),
	(377, 1, 0, -50553, 181, 0, 0, 39, '180'),
	(377, 1, 0, -50553, 182, 0, 0, 39, '181'),
	(377, 1, 0, -50553, 183, 0, 0, 39, '182'),
	(377, 1, 0, -50553, 184, 0, 0, 39, '183'),
	(377, 1, 0, -50553, 185, 0, 0, 39, '184'),
	(377, 1, 0, -50553, 186, 0, 0, 39, '185'),
	(377, 1, 0, -50553, 187, 0, 0, 39, '186'),
	(377, 1, 0, -50553, 188, 0, 0, 39, '187'),
	(377, 1, 0, -50553, 189, 0, 0, 39, '188'),
	(377, 1, 0, -50553, 190, 0, 0, 39, '189'),
	(377, 1, 0, -50553, 191, 0, 0, 39, '190'),
	(377, 1, 0, -50553, 192, 0, 0, 39, '191'),
	(377, 1, 0, -50553, 193, 0, 0, 39, '192'),
	(377, 1, 0, -50553, 194, 0, 0, 39, '193'),
	(377, 1, 0, -50553, 195, 0, 0, 39, '194'),
	(377, 1, 0, -50553, 196, 0, 0, 39, '195'),
	(377, 1, 0, -50553, 197, 0, 0, 39, '196'),
	(377, 1, 0, -50553, 198, 0, 0, 39, '197'),
	(377, 1, 0, -50553, 199, 0, 0, 39, '198'),
	(377, 1, 0, -50553, 200, 0, 0, 39, '199'),
	(377, 1, 0, -50553, 201, 0, 0, 39, '200'),
	(377, 1, 0, -50553, 202, 0, 0, 39, '201'),
	(377, 1, 0, -50553, 203, 0, 0, 39, '202'),
	(377, 1, 0, -50553, 204, 0, 0, 39, '203'),
	(377, 1, 0, -50553, 205, 0, 0, 39, '204'),
	(377, 1, 0, -50553, 206, 0, 0, 39, '205'),
	(377, 1, 0, -50553, 207, 0, 0, 39, '206'),
	(377, 1, 0, -50553, 208, 0, 0, 39, '207'),
	(377, 1, 0, -50553, 209, 0, 0, 39, '208'),
	(377, 1, 0, -50553, 210, 0, 0, 39, '209'),
	(377, 1, 0, -50553, 211, 0, 0, 39, '210'),
	(377, 1, 0, -50553, 212, 0, 0, 39, '211'),
	(377, 1, 0, -50553, 213, 0, 0, 39, '212'),
	(377, 1, 0, -50553, 214, 0, 0, 39, '213'),
	(377, 1, 0, -50553, 215, 0, 0, 39, '214'),
	(377, 1, 0, -50553, 216, 0, 0, 39, '215'),
	(377, 1, 0, -50553, 217, 0, 0, 39, '216'),
	(377, 1, 0, -50553, 218, 0, 0, 39, '217'),
	(377, 1, 0, -50553, 219, 0, 0, 39, '218'),
	(377, 1, 0, -50553, 220, 0, 0, 39, '219'),
	(377, 1, 0, -50553, 221, 0, 0, 39, '220'),
	(377, 1, 0, -50553, 222, 0, 0, 39, '221'),
	(377, 1, 0, -50553, 223, 0, 0, 39, '222'),
	(377, 1, 0, -50553, 224, 0, 0, 39, '223'),
	(377, 1, 0, -50553, 225, 0, 0, 39, '224'),
	(377, 1, 0, -50553, 226, 0, 0, 39, '225'),
	(377, 1, 0, -50553, 227, 0, 0, 39, '226'),
	(377, 1, 0, -50553, 228, 0, 0, 39, '227'),
	(377, 1, 0, -50553, 229, 0, 0, 39, '228'),
	(377, 1, 0, -50553, 230, 0, 0, 39, '229'),
	(377, 1, 0, -50553, 231, 0, 0, 39, '230'),
	(377, 1, 0, -50553, 232, 0, 0, 39, '231'),
	(377, 1, 0, -50553, 233, 0, 0, 39, '232'),
	(377, 1, 0, -50553, 234, 0, 0, 39, '233'),
	(377, 1, 0, -50553, 235, 0, 0, 39, '234'),
	(377, 1, 0, -50553, 236, 0, 0, 39, '235'),
	(377, 1, 0, -50553, 237, 0, 0, 39, '236'),
	(377, 1, 0, -50553, 238, 0, 0, 39, '237'),
	(377, 1, 0, -50553, 239, 0, 0, 39, '238'),
	(377, 1, 0, -50553, 240, 0, 0, 39, '239'),
	(377, 1, 0, -50553, 241, 0, 0, 39, '240'),
	(377, 1, 0, -50553, 242, 0, 0, 39, '241'),
	(377, 1, 0, -50553, 243, 0, 0, 39, '242'),
	(377, 1, 0, -50553, 244, 0, 0, 39, '243'),
	(377, 1, 0, -50553, 245, 0, 0, 39, '244'),
	(377, 1, 0, -50553, 246, 0, 0, 39, '245'),
	(377, 1, 0, -50553, 247, 0, 0, 39, '246'),
	(377, 1, 0, -50553, 248, 0, 0, 39, '247'),
	(377, 1, 0, -50553, 249, 0, 0, 39, '248'),
	(377, 1, 0, -50553, 250, 0, 0, 39, '249'),
	(377, 1, 0, -50553, 251, 0, 0, 39, '250'),
	(377, 1, 0, -50553, 252, 0, 0, 39, '251'),
	(377, 1, 0, -50553, 253, 0, 0, 39, '252'),
	(377, 1, 0, -50553, 254, 0, 0, 39, '253'),
	(377, 1, 0, -50553, 255, 0, 0, 39, '254'),
	(377, 1, 0, -50553, 256, 0, 0, 39, '255'),
	(377, 1, 0, -50553, 257, 0, 0, 39, '256'),
	(377, 1, 0, -50553, 258, 0, 0, 39, '257'),
	(377, 1, 0, -50553, 259, 0, 0, 39, '258'),
	(377, 1, 0, -50553, 260, 0, 0, 39, '259'),
	(377, 1, 0, -50553, 261, 0, 0, 39, '260'),
	(377, 1, 0, -50553, 262, 0, 0, 39, '261'),
	(377, 1, 0, -50553, 263, 0, 0, 39, '262'),
	(377, 1, 0, -50553, 264, 0, 0, 39, '263'),
	(377, 1, 0, -50553, 265, 0, 0, 39, '264'),
	(377, 1, 0, -50553, 266, 0, 0, 39, '265'),
	(377, 1, 0, -50553, 267, 0, 0, 39, '266'),
	(377, 1, 0, -50553, 268, 0, 0, 39, '267'),
	(377, 1, 0, -50553, 269, 0, 0, 39, '268'),
	(377, 1, 0, -50553, 270, 0, 0, 39, '269'),
	(377, 1, 0, -50553, 271, 0, 0, 39, '270'),
	(377, 1, 0, -50553, 272, 0, 0, 39, '271'),
	(377, 1, 0, -50553, 273, 0, 0, 39, '272'),
	(377, 1, 0, -50553, 274, 0, 0, 39, '273'),
	(377, 1, 0, -50553, 275, 0, 0, 39, '274'),
	(377, 1, 0, -50553, 276, 0, 0, 39, '275'),
	(377, 1, 0, -50553, 277, 0, 0, 39, '276'),
	(377, 1, 0, -50553, 278, 0, 0, 39, '277'),
	(377, 1, 0, -50553, 279, 0, 0, 39, '278'),
	(377, 1, 0, -50553, 280, 0, 0, 39, '279'),
	(377, 1, 0, -50553, 281, 0, 0, 39, '280'),
	(377, 1, 0, -50553, 282, 0, 0, 39, '281'),
	(377, 1, 0, -50553, 283, 0, 0, 39, '282'),
	(377, 1, 0, -50553, 284, 0, 0, 39, '283'),
	(377, 1, 0, -50553, 285, 0, 0, 39, '284'),
	(377, 1, 0, -50553, 286, 0, 0, 39, '285'),
	(377, 1, 0, -50553, 287, 0, 0, 39, '286'),
	(377, 1, 0, -50553, 288, 0, 0, 39, '287'),
	(377, 1, 0, -50553, 289, 0, 0, 39, '288'),
	(377, 1, 0, -50553, 290, 0, 0, 39, '289'),
	(377, 1, 0, -50553, 291, 0, 0, 39, '290'),
	(377, 1, 0, -50553, 292, 0, 0, 39, '291'),
	(377, 1, 0, -50553, 293, 0, 0, 39, '292'),
	(377, 1, 0, -50553, 294, 0, 0, 39, '293'),
	(377, 1, 0, -50553, 295, 0, 0, 39, '294'),
	(377, 1, 0, -50553, 296, 0, 0, 39, '295'),
	(377, 1, 0, -50553, 297, 0, 0, 39, '296'),
	(377, 1, 0, -50553, 298, 0, 0, 39, '297'),
	(377, 1, 0, -50553, 299, 0, 0, 39, '298'),
	(377, 1, 0, -50553, 300, 0, 0, 39, '299'),
	(377, 1, 0, -50553, 301, 0, 0, 39, '300'),
	(377, 1, 0, -50553, 302, 0, 0, 39, '301'),
	(377, 1, 0, -50553, 303, 0, 0, 39, '302'),
	(377, 1, 0, -50553, 304, 0, 0, 39, '303'),
	(377, 1, 0, -50553, 305, 0, 0, 39, '304'),
	(377, 1, 0, -50553, 306, 0, 0, 39, '305'),
	(377, 1, 0, -50553, 307, 0, 0, 39, '306'),
	(377, 1, 0, -50553, 308, 0, 0, 39, '307'),
	(377, 1, 0, -50553, 309, 0, 0, 39, '308'),
	(377, 1, 0, -50553, 310, 0, 0, 39, '309'),
	(377, 1, 0, -50553, 311, 0, 0, 39, '310'),
	(377, 1, 0, -50553, 312, 0, 0, 39, '311'),
	(377, 1, 0, -50553, 313, 0, 0, 39, '312'),
	(377, 1, 0, -50553, 314, 0, 0, 39, '313'),
	(377, 1, 0, -50553, 315, 0, 0, 39, '314'),
	(377, 1, 0, -50553, 316, 0, 0, 39, '315'),
	(377, 1, 0, -50553, 317, 0, 0, 39, '316'),
	(377, 1, 0, -50553, 318, 0, 0, 39, '317'),
	(377, 1, 0, -50553, 319, 0, 0, 39, '318'),
	(377, 1, 0, -50553, 320, 0, 0, 39, '319'),
	(377, 1, 0, -50553, 321, 0, 0, 39, '320'),
	(377, 1, 0, -50553, 322, 0, 0, 39, '321'),
	(377, 1, 0, -50553, 323, 0, 0, 39, '322'),
	(377, 1, 0, -50553, 324, 0, 0, 39, '323'),
	(377, 1, 0, -50553, 325, 0, 0, 39, '324'),
	(377, 1, 0, -50553, 326, 0, 0, 39, '325'),
	(377, 1, 0, -50553, 327, 0, 0, 39, '326'),
	(377, 1, 0, -50553, 328, 0, 0, 39, '327'),
	(377, 1, 0, -50553, 329, 0, 0, 39, '328'),
	(377, 1, 0, -50553, 330, 0, 0, 39, '329'),
	(377, 1, 0, -50553, 331, 0, 0, 39, '330'),
	(377, 1, 0, -50553, 332, 0, 0, 39, '331'),
	(377, 1, 0, -50553, 333, 0, 0, 39, '332'),
	(377, 1, 0, -50553, 334, 0, 0, 39, '333'),
	(377, 1, 0, -50553, 335, 0, 0, 39, '334'),
	(377, 1, 0, -50553, 336, 0, 0, 39, '335'),
	(377, 1, 0, -50553, 337, 0, 0, 39, '336'),
	(377, 1, 0, -50553, 338, 0, 0, 39, '337'),
	(377, 1, 0, -50553, 339, 0, 0, 39, '338'),
	(377, 1, 0, -50553, 340, 0, 0, 39, '339'),
	(377, 1, 0, -50553, 341, 0, 0, 39, '340'),
	(377, 1, 0, -50553, 342, 0, 0, 39, '341'),
	(377, 1, 0, -50553, 343, 0, 0, 39, '342'),
	(377, 1, 0, -50553, 344, 0, 0, 39, '343'),
	(377, 1, 0, -50553, 345, 0, 0, 39, '344'),
	(377, 1, 0, -50553, 346, 0, 0, 39, '345'),
	(377, 1, 0, -50553, 347, 0, 0, 39, '346'),
	(377, 1, 0, -50553, 348, 0, 0, 39, '347'),
	(377, 1, 0, -50553, 349, 0, 0, 39, '348'),
	(377, 1, 0, -50553, 350, 0, 0, 39, '349'),
	(377, 1, 0, -50553, 351, 0, 0, 39, '350'),
	(377, 1, 0, -50553, 352, 0, 0, 39, '351'),
	(377, 1, 0, -50553, 353, 0, 0, 39, '352'),
	(377, 1, 0, -50553, 354, 0, 0, 39, '353'),
	(377, 1, 0, -50553, 355, 0, 0, 39, '354'),
	(377, 1, 0, -50553, 356, 0, 0, 39, '355'),
	(377, 1, 0, -50553, 357, 0, 0, 39, '356'),
	(377, 1, 0, -50553, 358, 0, 0, 39, '357'),
	(377, 1, 0, -50553, 359, 0, 0, 39, '358'),
	(377, 1, 0, -50553, 360, 0, 0, 39, '359'),
	(377, 1, 0, -50553, 361, 0, 0, 39, '360'),
	(377, 1, 0, -50553, 362, 0, 0, 39, '361'),
	(377, 1, 0, -50553, 363, 0, 0, 39, '362'),
	(377, 1, 0, -50553, 364, 0, 0, 39, '363'),
	(377, 1, 0, -50553, 365, 0, 0, 39, '364'),
	(377, 1, 0, -50553, 366, 0, 0, 39, '365'),
	(377, 1, 0, -50553, 367, 0, 0, 39, '366'),
	(377, 1, 0, -50553, 368, 0, 0, 39, '367'),
	(377, 1, 0, -50553, 369, 0, 0, 39, '368'),
	(377, 1, 0, -50553, 370, 0, 0, 39, '369'),
	(377, 1, 0, -50553, 371, 0, 0, 39, '370'),
	(377, 1, 0, -50553, 372, 0, 0, 39, '371'),
	(377, 1, 0, -50553, 373, 0, 0, 39, '372'),
	(377, 1, 0, -50553, 374, 0, 0, 39, '373'),
	(377, 1, 0, -50553, 375, 0, 0, 39, '374'),
	(377, 1, 0, -50553, 376, 0, 0, 39, '375'),
	(377, 1, 0, -50553, 377, 0, 0, 39, '376'),
	(377, 1, 0, -50553, 378, 0, 0, 39, '377'),
	(377, 1, 0, -50553, 379, 0, 0, 39, '378'),
	(377, 1, 0, -50553, 380, 0, 0, 39, '379'),
	(377, 1, 0, -50553, 381, 0, 0, 39, '380'),
	(377, 1, 0, -50553, 382, 0, 0, 39, '381'),
	(377, 1, 0, -50553, 383, 0, 0, 39, '382'),
	(377, 1, 0, -50553, 384, 0, 0, 39, '383'),
	(377, 1, 0, -50553, 385, 0, 0, 39, '384'),
	(377, 1, 0, -50553, 386, 0, 0, 39, '385'),
	(377, 1, 0, -50553, 387, 0, 0, 39, '386'),
	(377, 1, 0, -50553, 388, 0, 0, 39, '387'),
	(377, 1, 0, -50553, 389, 0, 0, 39, '388'),
	(377, 1, 0, -50553, 390, 0, 0, 39, '389'),
	(377, 1, 0, -50553, 391, 0, 0, 39, '390'),
	(377, 1, 0, -50553, 392, 0, 0, 39, '391'),
	(377, 1, 0, -50553, 393, 0, 0, 39, '392'),
	(377, 1, 0, -50553, 394, 0, 0, 39, '393'),
	(377, 1, 0, -50553, 395, 0, 0, 39, '394'),
	(377, 1, 0, -50553, 396, 0, 0, 39, '395'),
	(377, 1, 0, -50553, 397, 0, 0, 39, '396'),
	(377, 1, 0, -50553, 398, 0, 0, 39, '397'),
	(377, 1, 0, -50553, 399, 0, 0, 39, '398'),
	(377, 1, 0, -50553, 400, 0, 0, 39, '399'),
	(377, 1, 0, -50553, 401, 0, 0, 39, '400'),
	(377, 1, 0, -50553, 402, 0, 0, 39, '401'),
	(377, 1, 0, -50553, 403, 0, 0, 39, '402'),
	(377, 1, 0, -50553, 404, 0, 0, 39, '403'),
	(377, 1, 0, -50553, 405, 0, 0, 39, '404'),
	(377, 1, 0, -50553, 406, 0, 0, 39, '405'),
	(377, 1, 0, -50553, 407, 0, 0, 39, '406'),
	(377, 1, 0, -50553, 408, 0, 0, 39, '407'),
	(377, 1, 0, -50553, 409, 0, 0, 39, '408'),
	(377, 1, 0, -50553, 410, 0, 0, 39, '409'),
	(377, 1, 0, -50553, 411, 0, 0, 39, '410'),
	(377, 1, 0, -50553, 412, 0, 0, 39, '411'),
	(377, 1, 0, -50553, 413, 0, 0, 39, '412'),
	(377, 1, 0, -50553, 414, 0, 0, 39, '413'),
	(377, 1, 0, -50553, 415, 0, 0, 39, '414'),
	(377, 1, 0, -50553, 416, 0, 0, 39, '415'),
	(377, 1, 0, -50553, 417, 0, 0, 39, '416'),
	(377, 1, 0, -50553, 418, 0, 0, 39, '417'),
	(377, 1, 0, -50553, 419, 0, 0, 39, '418'),
	(377, 1, 0, -50553, 420, 0, 0, 39, '419'),
	(377, 1, 0, -50553, 421, 0, 0, 39, '420'),
	(377, 1, 0, -50553, 422, 0, 0, 39, '421'),
	(377, 1, 0, -50553, 423, 0, 0, 39, '422'),
	(377, 1, 0, -50553, 424, 0, 0, 39, '423'),
	(377, 1, 0, -50553, 425, 0, 0, 39, '424'),
	(377, 1, 0, -50553, 426, 0, 0, 39, '425'),
	(377, 1, 0, -50553, 427, 0, 0, 39, '426'),
	(377, 1, 0, -50553, 428, 0, 0, 39, '427'),
	(377, 1, 0, -50553, 429, 0, 0, 39, '428'),
	(377, 1, 0, -50553, 430, 0, 0, 39, '429'),
	(377, 1, 0, -50553, 431, 0, 0, 39, '430'),
	(377, 1, 0, -50553, 432, 0, 0, 39, '431'),
	(377, 1, 0, -50553, 433, 0, 0, 39, '432'),
	(377, 1, 0, -50553, 434, 0, 0, 39, '433'),
	(377, 1, 0, -50553, 435, 0, 0, 39, '434'),
	(377, 1, 0, -50553, 436, 0, 0, 39, '435'),
	(377, 1, 0, -50553, 437, 0, 0, 39, '436'),
	(377, 1, 0, -50553, 438, 0, 0, 39, '437'),
	(377, 1, 0, -50553, 439, 0, 0, 39, '438'),
	(377, 1, 0, -50553, 440, 0, 0, 39, '439'),
	(377, 1, 0, -50553, 441, 0, 0, 39, '440'),
	(377, 1, 0, -50553, 442, 0, 0, 39, '441'),
	(377, 1, 0, -50553, 443, 0, 0, 39, '442'),
	(377, 1, 0, -50553, 444, 0, 0, 39, '443'),
	(377, 1, 0, -50553, 445, 0, 0, 39, '444'),
	(377, 1, 0, -50553, 446, 0, 0, 39, '445'),
	(377, 1, 0, -50553, 447, 0, 0, 39, '446'),
	(377, 1, 0, -50553, 448, 0, 0, 39, '447'),
	(377, 1, 0, -50553, 449, 0, 0, 39, '448'),
	(377, 1, 0, -50553, 450, 0, 0, 39, '449'),
	(377, 1, 0, -50553, 451, 0, 0, 39, '450'),
	(377, 1, 0, -50553, 452, 0, 0, 39, '451'),
	(377, 1, 0, -50553, 453, 0, 0, 39, '452'),
	(377, 1, 0, -50553, 454, 0, 0, 39, '453'),
	(377, 1, 0, -50553, 455, 0, 0, 39, '454'),
	(377, 1, 0, -50553, 456, 0, 0, 39, '455'),
	(377, 1, 0, -50553, 457, 0, 0, 39, '456'),
	(377, 1, 0, -50553, 458, 0, 0, 39, '457'),
	(377, 1, 0, -50553, 459, 0, 0, 39, '458'),
	(377, 1, 0, -50553, 460, 0, 0, 39, '459'),
	(377, 1, 0, -50553, 461, 0, 0, 39, '460'),
	(377, 1, 0, -50553, 462, 0, 0, 39, '461'),
	(377, 1, 0, -50553, 463, 0, 0, 39, '462'),
	(377, 1, 0, -50553, 464, 0, 0, 39, '463'),
	(377, 1, 0, -50553, 465, 0, 0, 39, '464'),
	(377, 1, 0, -50553, 466, 0, 0, 39, '465'),
	(377, 1, 0, -50553, 467, 0, 0, 39, '466'),
	(377, 1, 0, -50553, 468, 0, 0, 39, '467'),
	(377, 1, 0, -50553, 469, 0, 0, 39, '468'),
	(377, 1, 0, -50553, 470, 0, 0, 39, '469'),
	(377, 1, 0, -50553, 471, 0, 0, 39, '470'),
	(377, 1, 0, -50553, 472, 0, 0, 39, '471'),
	(377, 1, 0, -50553, 473, 0, 0, 39, '472'),
	(377, 1, 0, -50553, 474, 0, 0, 39, '473'),
	(377, 1, 0, -50553, 475, 0, 0, 39, '474'),
	(377, 1, 0, -50553, 476, 0, 0, 39, '475'),
	(377, 1, 0, -50553, 477, 0, 0, 39, '476'),
	(377, 1, 0, -50553, 478, 0, 0, 39, '477'),
	(377, 1, 0, -50553, 479, 0, 0, 39, '478'),
	(377, 1, 0, -50553, 480, 0, 0, 39, '479'),
	(377, 1, 0, -50553, 481, 0, 0, 39, '480'),
	(377, 1, 0, -50553, 482, 0, 0, 39, '481'),
	(377, 1, 0, -50553, 483, 0, 0, 39, '482'),
	(377, 1, 0, -50553, 484, 0, 0, 39, '483'),
	(377, 1, 0, -50553, 485, 0, 0, 39, '484'),
	(377, 1, 0, -50553, 486, 0, 0, 39, '485'),
	(377, 1, 0, -50553, 487, 0, 0, 39, '486'),
	(377, 1, 0, -50553, 488, 0, 0, 39, '487'),
	(377, 1, 0, -50553, 489, 0, 0, 39, '488'),
	(377, 1, 0, -50553, 490, 0, 0, 39, '489'),
	(377, 1, 0, -50553, 491, 0, 0, 39, '490'),
	(377, 1, 0, -50553, 492, 0, 0, 39, '491'),
	(377, 1, 0, -50553, 493, 0, 0, 39, '492'),
	(377, 1, 0, -50553, 494, 0, 0, 39, '493'),
	(377, 1, 0, -50553, 495, 0, 0, 39, '494'),
	(377, 1, 0, -50553, 496, 0, 0, 39, '495'),
	(377, 1, 0, -50553, 497, 0, 0, 39, '496'),
	(377, 1, 0, -50553, 498, 0, 0, 39, '497'),
	(377, 1, 0, -50553, 499, 0, 0, 39, '498'),
	(377, 1, 0, -50553, 500, 0, 0, 39, '499'),
	(377, 1, 0, -50553, 501, 0, 0, 39, '500'),
	(377, 1, 0, -50553, 502, 0, 0, 39, '501'),
	(377, 1, 0, -50553, 503, 0, 0, 39, '502'),
	(377, 1, 0, -50553, 504, 0, 0, 39, '503'),
	(377, 1, 0, -50553, 505, 0, 0, 39, '504'),
	(377, 1, 0, -50553, 506, 0, 0, 39, '505'),
	(377, 1, 0, -50553, 507, 0, 0, 39, '506'),
	(377, 1, 0, -50553, 508, 0, 0, 39, '507'),
	(377, 1, 0, -50553, 509, 0, 0, 39, '508'),
	(377, 1, 0, -50553, 510, 0, 0, 39, '509'),
	(377, 1, 0, -50553, 511, 0, 0, 39, '510'),
	(377, 1, 0, -50553, 512, 0, 0, 39, '511'),
	(377, 1, 0, -50553, 513, 0, 0, 39, '512'),
	(377, 1, 0, -50553, 514, 0, 0, 39, '513'),
	(377, 1, 0, -50553, 515, 0, 0, 39, '514'),
	(377, 1, 0, -50553, 516, 0, 0, 39, '515'),
	(377, 1, 0, -50553, 517, 0, 0, 39, '516'),
	(377, 1, 0, -50553, 518, 0, 0, 39, '517'),
	(377, 1, 0, -50553, 519, 0, 0, 39, '518'),
	(377, 1, 0, -50553, 520, 0, 0, 39, '519'),
	(377, 1, 0, -50553, 521, 0, 0, 39, '520'),
	(377, 1, 0, -50553, 522, 0, 0, 39, '521'),
	(377, 1, 0, -50553, 523, 0, 0, 39, '522'),
	(377, 1, 0, -50553, 524, 0, 0, 39, '523'),
	(377, 1, 0, -50553, 525, 0, 0, 39, '524'),
	(377, 1, 0, -50553, 526, 0, 0, 39, '525'),
	(377, 1, 0, -50553, 527, 0, 0, 39, '526'),
	(377, 1, 0, -50553, 528, 0, 0, 39, '527'),
	(377, 1, 0, -50553, 529, 0, 0, 39, '528'),
	(377, 1, 0, -50553, 530, 0, 0, 39, '529'),
	(377, 1, 0, -50553, 531, 0, 0, 39, '530'),
	(377, 1, 0, -50553, 532, 0, 0, 39, '531'),
	(377, 1, 0, -50553, 533, 0, 0, 39, '532'),
	(377, 1, 0, -50553, 534, 0, 0, 39, '533'),
	(377, 1, 0, -50553, 535, 0, 0, 39, '534'),
	(377, 1, 0, -50553, 536, 0, 0, 39, '535'),
	(377, 1, 0, -50553, 537, 0, 0, 39, '536'),
	(377, 1, 0, -50553, 538, 0, 0, 39, '537'),
	(377, 1, 0, -50553, 539, 0, 0, 39, '538'),
	(377, 1, 0, -50553, 540, 0, 0, 39, '539'),
	(377, 1, 0, -50553, 541, 0, 0, 39, '540'),
	(377, 1, 0, -50553, 542, 0, 0, 39, '541'),
	(377, 1, 0, -50553, 543, 0, 0, 39, '542'),
	(377, 1, 0, -50553, 544, 0, 0, 39, '543'),
	(377, 1, 0, -50553, 545, 0, 0, 39, '544'),
	(377, 1, 0, -50553, 546, 0, 0, 39, '545'),
	(377, 1, 0, -50553, 547, 0, 0, 39, '546'),
	(377, 1, 0, -50553, 548, 0, 0, 39, '547'),
	(377, 1, 0, -50553, 549, 0, 0, 39, '548'),
	(377, 1, 0, -50553, 550, 0, 0, 39, '549'),
	(377, 1, 0, -50553, 551, 0, 0, 39, '550'),
	(377, 1, 0, -50553, 552, 0, 0, 39, '551'),
	(377, 1, 0, -50553, 553, 0, 0, 39, '552'),
	(377, 1, 0, -50553, 554, 0, 0, 39, '553'),
	(377, 1, 0, -50553, 555, 0, 0, 39, '554'),
	(377, 1, 0, -50553, 556, 0, 0, 39, '555'),
	(377, 1, 0, -50553, 557, 0, 0, 39, '556'),
	(377, 1, 0, -50553, 558, 0, 0, 39, '557'),
	(377, 1, 0, -50553, 559, 0, 0, 39, '558'),
	(377, 1, 0, -50553, 560, 0, 0, 39, '559'),
	(377, 1, 0, -50553, 561, 0, 0, 39, '560'),
	(377, 1, 0, -50553, 562, 0, 0, 39, '561'),
	(377, 1, 0, -50553, 563, 0, 0, 39, '562'),
	(377, 1, 0, -50553, 564, 0, 0, 39, '563'),
	(377, 1, 0, -50553, 565, 0, 0, 39, '564'),
	(377, 1, 0, -50553, 566, 0, 0, 39, '565'),
	(377, 1, 0, -50553, 567, 0, 0, 39, '566'),
	(377, 1, 0, -50553, 568, 0, 0, 39, '567'),
	(377, 1, 0, -50553, 569, 0, 0, 39, '568'),
	(377, 1, 0, -50553, 570, 0, 0, 39, '569'),
	(377, 1, 0, -50553, 571, 0, 0, 39, '570'),
	(377, 1, 0, -50553, 572, 0, 0, 39, '571'),
	(377, 1, 0, -50553, 573, 0, 0, 39, '572'),
	(377, 1, 0, -50553, 574, 0, 0, 39, '573'),
	(377, 1, 0, -50553, 575, 0, 0, 39, '574'),
	(377, 1, 0, -50553, 576, 0, 0, 39, '575'),
	(377, 1, 0, -50553, 577, 0, 0, 39, '576'),
	(377, 1, 0, -50553, 578, 0, 0, 39, '577'),
	(377, 1, 0, -50553, 579, 0, 0, 39, '578'),
	(377, 1, 0, -50553, 580, 0, 0, 39, '579'),
	(377, 1, 0, -50553, 581, 0, 0, 39, '580'),
	(377, 1, 0, -50553, 582, 0, 0, 39, '581'),
	(377, 1, 0, -50553, 583, 0, 0, 39, '582'),
	(377, 1, 0, -50553, 584, 0, 0, 39, '583'),
	(377, 1, 0, -50553, 585, 0, 0, 39, '584'),
	(377, 1, 0, -50553, 586, 0, 0, 39, '585'),
	(377, 1, 0, -50553, 587, 0, 0, 39, '586'),
	(377, 1, 0, -50553, 588, 0, 0, 39, '587'),
	(377, 1, 0, -50553, 589, 0, 0, 39, '588'),
	(377, 1, 0, -50553, 590, 0, 0, 39, '589'),
	(377, 1, 0, -50553, 591, 0, 0, 39, '590'),
	(377, 1, 0, -50553, 592, 0, 0, 39, '591'),
	(377, 1, 0, -50553, 593, 0, 0, 39, '592'),
	(377, 1, 0, -50553, 594, 0, 0, 39, '593'),
	(377, 1, 0, -50553, 595, 0, 0, 39, '594'),
	(377, 1, 0, -50553, 596, 0, 0, 39, '595'),
	(377, 1, 0, -50553, 597, 0, 0, 39, '596'),
	(377, 1, 0, -50553, 598, 0, 0, 39, '597'),
	(377, 1, 0, -50553, 599, 0, 0, 39, '598'),
	(377, 1, 0, -50553, 600, 0, 0, 39, '599'),
	(377, 1, 0, -50553, 601, 0, 0, 39, '600'),
	(377, 1, 0, -50553, 602, 0, 0, 39, '601'),
	(377, 1, 0, -50553, 603, 0, 0, 39, '602'),
	(377, 1, 0, -50553, 604, 0, 0, 39, '603'),
	(377, 1, 0, -50553, 605, 0, 0, 39, '604'),
	(377, 1, 0, -50553, 606, 0, 0, 39, '605'),
	(377, 1, 0, -50553, 607, 0, 0, 39, '606'),
	(377, 1, 0, -50553, 608, 0, 0, 39, '607'),
	(377, 1, 0, -50553, 609, 0, 0, 39, '608'),
	(377, 1, 0, -50553, 610, 0, 0, 39, '609'),
	(377, 1, 0, -50553, 611, 0, 0, 39, '610'),
	(377, 1, 0, -50553, 612, 0, 0, 39, '611'),
	(377, 1, 0, -50553, 613, 0, 0, 39, '612'),
	(377, 1, 0, -50553, 614, 0, 0, 39, '613'),
	(377, 1, 0, -50553, 615, 0, 0, 39, '614'),
	(377, 1, 0, -50553, 616, 0, 0, 39, '615'),
	(377, 1, 0, -50553, 617, 0, 0, 39, '616'),
	(377, 1, 0, -50553, 618, 0, 0, 39, '617'),
	(377, 1, 0, -50553, 619, 0, 0, 39, '618'),
	(377, 1, 0, -50553, 620, 0, 0, 39, '619'),
	(377, 1, 0, -50553, 621, 0, 0, 39, '620'),
	(377, 1, 0, -50553, 622, 0, 0, 39, '621'),
	(377, 1, 0, -50553, 623, 0, 0, 39, '622'),
	(377, 1, 0, -50553, 624, 0, 0, 39, '623'),
	(377, 1, 0, -50553, 625, 0, 0, 39, '624'),
	(377, 1, 0, -50553, 626, 0, 0, 39, '625'),
	(377, 1, 0, -50553, 627, 0, 0, 39, '626'),
	(377, 1, 0, -50553, 628, 0, 0, 39, '627'),
	(377, 1, 0, -50553, 629, 0, 0, 39, '628'),
	(377, 1, 0, -50553, 630, 0, 0, 39, '629'),
	(377, 1, 0, -50553, 631, 0, 0, 39, '630'),
	(377, 1, 0, -50553, 632, 0, 0, 39, '631'),
	(377, 1, 0, -50553, 633, 0, 0, 39, '632'),
	(377, 1, 0, -50553, 634, 0, 0, 39, '633'),
	(377, 1, 0, -50553, 635, 0, 0, 39, '634'),
	(377, 1, 0, -50553, 636, 0, 0, 39, '635'),
	(377, 1, 0, -50553, 637, 0, 0, 39, '636'),
	(377, 1, 0, -50553, 638, 0, 0, 39, '637'),
	(377, 1, 0, -50553, 639, 0, 0, 39, '638'),
	(377, 1, 0, -50553, 640, 0, 0, 39, '639'),
	(377, 1, 0, -50553, 641, 0, 0, 39, '640'),
	(377, 1, 0, -50553, 642, 0, 0, 39, '641'),
	(377, 1, 0, -50553, 643, 0, 0, 39, '642'),
	(377, 1, 0, -50553, 644, 0, 0, 39, '643'),
	(377, 1, 0, -50553, 645, 0, 0, 39, '644'),
	(377, 1, 0, -50553, 646, 0, 0, 39, '645'),
	(377, 1, 0, -50553, 647, 0, 0, 39, '646'),
	(377, 1, 0, -50553, 648, 0, 0, 39, '647'),
	(377, 1, 0, -50553, 649, 0, 0, 39, '648'),
	(377, 1, 0, -50553, 650, 0, 0, 39, '649'),
	(377, 1, 0, -50553, 651, 0, 0, 39, '650'),
	(377, 1, 0, -50553, 652, 0, 0, 39, '651'),
	(377, 1, 0, -50553, 653, 0, 0, 39, '652'),
	(377, 1, 0, -50553, 654, 0, 0, 39, '653'),
	(377, 1, 0, -50553, 655, 0, 0, 39, '654'),
	(377, 1, 0, -50553, 656, 0, 0, 39, '655'),
	(377, 1, 0, -50553, 657, 0, 0, 39, '656'),
	(377, 1, 0, -50553, 658, 0, 0, 39, '657'),
	(377, 1, 0, -50553, 659, 0, 0, 39, '658'),
	(377, 1, 0, -50553, 660, 0, 0, 39, '659'),
	(377, 1, 0, -50553, 661, 0, 0, 39, '660'),
	(377, 1, 0, -50553, 662, 0, 0, 39, '661'),
	(377, 1, 0, -50553, 663, 0, 0, 39, '662'),
	(377, 1, 0, -50553, 664, 0, 0, 39, '663'),
	(377, 1, 0, -50553, 665, 0, 0, 39, '664'),
	(377, 1, 0, -50553, 666, 0, 0, 39, '665'),
	(377, 1, 0, -50553, 667, 0, 0, 39, '666'),
	(377, 1, 0, -50553, 668, 0, 0, 39, '667'),
	(377, 1, 0, -50553, 669, 0, 0, 39, '668'),
	(377, 1, 0, -50553, 670, 0, 0, 39, '669'),
	(377, 1, 0, -50553, 671, 0, 0, 39, '670'),
	(377, 1, 0, -50553, 672, 0, 0, 39, '671'),
	(377, 1, 0, -50553, 673, 0, 0, 39, '672'),
	(377, 1, 0, -50553, 674, 0, 0, 39, '673'),
	(377, 1, 0, -50553, 675, 0, 0, 39, '674'),
	(377, 1, 0, -50553, 676, 0, 0, 39, '675'),
	(377, 1, 0, -50553, 677, 0, 0, 39, '676'),
	(377, 1, 0, -50553, 678, 0, 0, 39, '677'),
	(377, 1, 0, -50553, 679, 0, 0, 39, '678'),
	(377, 1, 0, -50553, 680, 0, 0, 39, '679'),
	(377, 1, 0, -50553, 681, 0, 0, 39, '680'),
	(377, 1, 0, -50553, 682, 0, 0, 39, '681'),
	(377, 1, 0, -50553, 683, 0, 0, 39, '682'),
	(377, 1, 0, -50553, 684, 0, 0, 39, '683'),
	(377, 1, 0, -50553, 685, 0, 0, 39, '684'),
	(377, 1, 0, -50553, 686, 0, 0, 39, '685'),
	(377, 1, 0, -50553, 687, 0, 0, 39, '686'),
	(377, 1, 0, -50553, 688, 0, 0, 39, '687'),
	(377, 1, 0, -50553, 689, 0, 0, 39, '688'),
	(377, 1, 0, -50553, 690, 0, 0, 39, '689'),
	(377, 1, 0, -50553, 691, 0, 0, 39, '690'),
	(377, 1, 0, -50553, 692, 0, 0, 39, '691'),
	(377, 1, 0, -50553, 693, 0, 0, 39, '692'),
	(377, 1, 0, -50553, 694, 0, 0, 39, '693'),
	(377, 1, 0, -50553, 695, 0, 0, 39, '694'),
	(377, 1, 0, -50553, 696, 0, 0, 39, '695'),
	(377, 1, 0, -50553, 697, 0, 0, 39, '696'),
	(377, 1, 0, -50553, 698, 0, 0, 39, '697'),
	(377, 1, 0, -50553, 699, 0, 0, 39, '698'),
	(377, 1, 0, -50553, 700, 0, 0, 39, '699'),
	(377, 1, 0, -50553, 701, 0, 0, 39, '700'),
	(377, 1, 0, -50553, 702, 0, 0, 39, '701'),
	(377, 1, 0, -50553, 703, 0, 0, 39, '702'),
	(377, 1, 0, -50553, 704, 0, 0, 39, '703'),
	(377, 1, 0, -50553, 705, 0, 0, 39, '704'),
	(377, 1, 0, -50553, 706, 0, 0, 39, '705'),
	(377, 1, 0, -50553, 707, 0, 0, 39, '706'),
	(377, 1, 0, -50553, 708, 0, 0, 39, '707'),
	(377, 1, 0, -50553, 709, 0, 0, 39, '708'),
	(377, 1, 0, -50553, 710, 0, 0, 39, '709'),
	(377, 1, 0, -50553, 711, 0, 0, 39, '710'),
	(377, 1, 0, -50553, 712, 0, 0, 39, '711'),
	(377, 1, 0, -50553, 713, 0, 0, 39, '712'),
	(377, 1, 0, -50553, 714, 0, 0, 39, '713'),
	(377, 1, 0, -50553, 715, 0, 0, 39, '714'),
	(377, 1, 0, -50553, 716, 0, 0, 39, '715'),
	(377, 1, 0, -50553, 717, 0, 0, 39, '716'),
	(377, 1, 0, -50553, 718, 0, 0, 39, '717'),
	(377, 1, 0, -50553, 719, 0, 0, 39, '718'),
	(377, 1, 0, -50553, 720, 0, 0, 39, '719'),
	(377, 1, 0, -50553, 721, 0, 0, 39, '720'),
	(377, 1, 0, -50553, 722, 0, 0, 39, '721'),
	(377, 1, 0, -50553, 723, 0, 0, 39, '722'),
	(377, 1, 0, -50553, 724, 0, 0, 39, '723'),
	(377, 1, 0, -50553, 725, 0, 0, 39, '724'),
	(377, 1, 0, -50553, 726, 0, 0, 39, '725'),
	(377, 1, 0, -50553, 727, 0, 0, 39, '726'),
	(377, 1, 0, -50553, 728, 0, 0, 39, '727'),
	(377, 1, 0, -50553, 729, 0, 0, 39, '728'),
	(377, 1, 0, -50553, 730, 0, 0, 39, '729'),
	(377, 1, 0, -50553, 731, 0, 0, 39, '730'),
	(377, 1, 0, -50553, 732, 0, 0, 39, '731'),
	(377, 1, 0, -50553, 733, 0, 0, 39, '732'),
	(377, 1, 0, -50553, 734, 0, 0, 39, '733'),
	(377, 1, 0, -50553, 735, 0, 0, 39, '734'),
	(377, 1, 0, -50553, 736, 0, 0, 39, '735'),
	(377, 1, 0, -50553, 737, 0, 0, 39, '736'),
	(377, 1, 0, -50553, 738, 0, 0, 39, '737'),
	(377, 1, 0, -50553, 739, 0, 0, 39, '738'),
	(377, 1, 0, -50553, 740, 0, 0, 39, '739'),
	(377, 1, 0, -50553, 741, 0, 0, 39, '740'),
	(377, 1, 0, -50553, 742, 0, 0, 39, '741'),
	(377, 1, 0, -50553, 743, 0, 0, 39, '742'),
	(377, 1, 0, -50553, 744, 0, 0, 39, '743'),
	(377, 1, 0, -50553, 745, 0, 0, 39, '744'),
	(377, 1, 0, -50553, 746, 0, 0, 39, '745'),
	(377, 1, 0, -50553, 747, 0, 0, 39, '746'),
	(377, 1, 0, -50553, 748, 0, 0, 39, '747'),
	(377, 1, 0, -50553, 749, 0, 0, 39, '748'),
	(377, 1, 0, -50553, 750, 0, 0, 39, '749'),
	(377, 1, 0, -50553, 751, 0, 0, 39, '750'),
	(377, 1, 0, -50553, 752, 0, 0, 39, '751'),
	(377, 1, 0, -50553, 753, 0, 0, 39, '752'),
	(377, 1, 0, -50553, 754, 0, 0, 39, '753'),
	(377, 1, 0, -50553, 755, 0, 0, 39, '754'),
	(377, 1, 0, -50553, 756, 0, 0, 39, '755'),
	(377, 1, 0, -50553, 757, 0, 0, 39, '756'),
	(377, 1, 0, -50553, 758, 0, 0, 39, '757'),
	(377, 1, 0, -50553, 759, 0, 0, 39, '758'),
	(377, 1, 0, -50553, 760, 0, 0, 39, '759'),
	(377, 1, 0, -50553, 761, 0, 0, 39, '760'),
	(377, 1, 0, -50553, 762, 0, 0, 39, '761'),
	(377, 1, 0, -50553, 763, 0, 0, 39, '762'),
	(377, 1, 0, -50553, 764, 0, 0, 39, '763'),
	(377, 1, 0, -50553, 765, 0, 0, 39, '764'),
	(377, 1, 0, -50553, 766, 0, 0, 39, '765'),
	(377, 1, 0, -50553, 767, 0, 0, 39, '766'),
	(377, 1, 0, -50553, 768, 0, 0, 39, '767'),
	(377, 1, 0, -50553, 769, 0, 0, 39, '768'),
	(377, 1, 0, -50553, 770, 0, 0, 39, '769'),
	(377, 1, 0, -50553, 771, 0, 0, 39, '770'),
	(377, 1, 0, -50553, 772, 0, 0, 39, '771'),
	(377, 1, 0, -50553, 773, 0, 0, 39, '772'),
	(377, 1, 0, -50553, 774, 0, 0, 39, '773'),
	(377, 1, 0, -50553, 775, 0, 0, 39, '774'),
	(377, 1, 0, -50553, 776, 0, 0, 39, '775'),
	(377, 1, 0, -50553, 777, 0, 0, 39, '776'),
	(377, 1, 0, -50553, 778, 0, 0, 39, '777'),
	(377, 1, 0, -50553, 779, 0, 0, 39, '778'),
	(377, 1, 0, -50553, 780, 0, 0, 39, '779'),
	(377, 1, 0, -50553, 781, 0, 0, 39, '780'),
	(377, 1, 0, -50553, 782, 0, 0, 39, '781'),
	(377, 1, 0, -50553, 783, 0, 0, 39, '782'),
	(377, 1, 0, -50553, 784, 0, 0, 39, '783'),
	(377, 1, 0, -50553, 785, 0, 0, 39, '784'),
	(377, 1, 0, -50553, 786, 0, 0, 39, '785'),
	(377, 1, 0, -50553, 787, 0, 0, 39, '786'),
	(377, 1, 0, -50553, 788, 0, 0, 39, '787'),
	(377, 1, 0, -50553, 789, 0, 0, 39, '788'),
	(377, 1, 0, -50553, 790, 0, 0, 39, '789'),
	(377, 1, 0, -50553, 791, 0, 0, 39, '790'),
	(377, 1, 0, -50553, 792, 0, 0, 39, '791'),
	(377, 1, 0, -50553, 793, 0, 0, 39, '792'),
	(377, 1, 0, -50553, 794, 0, 0, 39, '793'),
	(377, 1, 0, -50553, 795, 0, 0, 39, '794'),
	(377, 1, 0, -50553, 796, 0, 0, 39, '795'),
	(377, 1, 0, -50553, 797, 0, 0, 39, '796'),
	(377, 1, 0, -50553, 798, 0, 0, 39, '797'),
	(377, 1, 0, -50553, 799, 0, 0, 39, '798'),
	(377, 1, 0, -50553, 800, 0, 0, 39, '799'),
	(377, 1, 0, -50553, 801, 0, 0, 39, '800'),
	(377, 1, 0, -50553, 802, 0, 0, 39, '801'),
	(377, 1, 0, -50553, 803, 0, 0, 39, '802'),
	(377, 1, 0, -50553, 804, 0, 0, 39, '803'),
	(377, 1, 0, -50553, 805, 0, 0, 39, '804'),
	(377, 1, 0, -50553, 806, 0, 0, 39, '805'),
	(377, 1, 0, -50553, 807, 0, 0, 39, '806'),
	(377, 1, 0, -50553, 808, 0, 0, 39, '807'),
	(377, 1, 0, -50553, 809, 0, 0, 39, '808'),
	(377, 1, 0, -50553, 810, 0, 0, 39, '809'),
	(377, 1, 0, -50553, 811, 0, 0, 39, '810'),
	(377, 1, 0, -50553, 812, 0, 0, 39, '811'),
	(377, 1, 0, -50553, 813, 0, 0, 39, '812'),
	(377, 1, 0, -50553, 814, 0, 0, 39, '813'),
	(377, 1, 0, -50553, 815, 0, 0, 39, '814'),
	(377, 1, 0, -50553, 816, 0, 0, 39, '815'),
	(377, 1, 0, -50553, 817, 0, 0, 39, '816'),
	(377, 1, 0, -50553, 818, 0, 0, 39, '817'),
	(377, 1, 0, -50553, 819, 0, 0, 39, '818'),
	(377, 1, 0, -50553, 820, 0, 0, 39, '819'),
	(377, 1, 0, -50553, 821, 0, 0, 39, '820'),
	(377, 1, 0, -50553, 822, 0, 0, 39, '821'),
	(377, 1, 0, -50553, 823, 0, 0, 39, '822'),
	(377, 1, 0, -50553, 824, 0, 0, 39, '823'),
	(377, 1, 0, -50553, 825, 0, 0, 39, '824'),
	(377, 1, 0, -50553, 826, 0, 0, 39, '825'),
	(377, 1, 0, -50553, 827, 0, 0, 39, '826'),
	(377, 1, 0, -50553, 828, 0, 0, 39, '827'),
	(377, 1, 0, -50553, 829, 0, 0, 39, '828'),
	(377, 1, 0, -50553, 830, 0, 0, 39, '829'),
	(377, 1, 0, -50553, 831, 0, 0, 39, '830'),
	(377, 1, 0, -50553, 832, 0, 0, 39, '831'),
	(377, 1, 0, -50553, 833, 0, 0, 39, '832'),
	(377, 1, 0, -50553, 834, 0, 0, 39, '833'),
	(377, 1, 0, -50553, 835, 0, 0, 39, '834'),
	(377, 1, 0, -50553, 836, 0, 0, 39, '835'),
	(377, 1, 0, -50553, 837, 0, 0, 39, '836'),
	(377, 1, 0, -50553, 838, 0, 0, 39, '837'),
	(377, 1, 0, -50553, 839, 0, 0, 39, '838'),
	(377, 1, 0, -50553, 840, 0, 0, 39, '839'),
	(377, 1, 0, -50553, 841, 0, 0, 39, '840'),
	(377, 1, 0, -50553, 842, 0, 0, 39, '841'),
	(377, 1, 0, -50553, 843, 0, 0, 39, '842'),
	(377, 1, 0, -50553, 844, 0, 0, 39, '843'),
	(377, 1, 0, -50553, 845, 0, 0, 39, '844'),
	(377, 1, 0, -50553, 846, 0, 0, 39, '845'),
	(377, 1, 0, -50553, 847, 0, 0, 39, '846'),
	(377, 1, 0, -50553, 848, 0, 0, 39, '847'),
	(377, 1, 0, -50553, 849, 0, 0, 39, '848'),
	(377, 1, 0, -50553, 850, 0, 0, 39, '849'),
	(377, 1, 0, -50553, 851, 0, 0, 39, '850'),
	(377, 1, 0, -50553, 852, 0, 0, 39, '851'),
	(377, 1, 0, -50553, 853, 0, 0, 39, '852'),
	(377, 1, 0, -50553, 854, 0, 0, 39, '853'),
	(377, 1, 0, -50553, 855, 0, 0, 39, '854'),
	(377, 1, 0, -50553, 856, 0, 0, 39, '855'),
	(377, 1, 0, -50553, 857, 0, 0, 39, '856'),
	(377, 1, 0, -50553, 858, 0, 0, 39, '857'),
	(377, 1, 0, -50553, 859, 0, 0, 39, '858'),
	(377, 1, 0, -50553, 860, 0, 0, 39, '859'),
	(377, 1, 0, -50553, 861, 0, 0, 39, '860'),
	(377, 1, 0, -50553, 862, 0, 0, 39, '861'),
	(377, 1, 0, -50553, 863, 0, 0, 39, '862'),
	(377, 1, 0, -50553, 864, 0, 0, 39, '863'),
	(377, 1, 0, -50553, 865, 0, 0, 39, '864'),
	(377, 1, 0, -50553, 866, 0, 0, 39, '865'),
	(377, 1, 0, -50553, 867, 0, 0, 39, '866'),
	(377, 1, 0, -50553, 868, 0, 0, 39, '867'),
	(377, 1, 0, -50553, 869, 0, 0, 39, '868'),
	(377, 1, 0, -50553, 870, 0, 0, 39, '869'),
	(377, 1, 0, -50553, 871, 0, 0, 39, '870'),
	(377, 1, 0, -50553, 872, 0, 0, 39, '871'),
	(377, 1, 0, -50553, 873, 0, 0, 39, '872'),
	(377, 1, 0, -50553, 874, 0, 0, 39, '873'),
	(377, 1, 0, -50553, 875, 0, 0, 39, '874'),
	(377, 1, 0, -50553, 876, 0, 0, 39, '875'),
	(377, 1, 0, -50553, 877, 0, 0, 39, '876'),
	(377, 1, 0, -50553, 878, 0, 0, 39, '877'),
	(377, 1, 0, -50553, 879, 0, 0, 39, '878'),
	(377, 1, 0, -50553, 880, 0, 0, 39, '879'),
	(377, 1, 0, -50553, 881, 0, 0, 39, '880'),
	(377, 1, 0, -50553, 882, 0, 0, 39, '881'),
	(377, 1, 0, -50553, 883, 0, 0, 39, '882'),
	(377, 1, 0, -50553, 884, 0, 0, 39, '883'),
	(377, 1, 0, -50553, 885, 0, 0, 39, '884'),
	(377, 1, 0, -50553, 886, 0, 0, 39, '885'),
	(377, 1, 0, -50553, 887, 0, 0, 39, '886'),
	(377, 1, 0, -50553, 888, 0, 0, 39, '887'),
	(377, 1, 0, -50553, 889, 0, 0, 39, '888'),
	(377, 1, 0, -50553, 890, 0, 0, 39, '889'),
	(377, 1, 0, -50553, 891, 0, 0, 39, '890'),
	(377, 1, 0, -50553, 892, 0, 0, 39, '891'),
	(377, 1, 0, -50553, 893, 0, 0, 39, '892'),
	(377, 1, 0, -50553, 894, 0, 0, 39, '893'),
	(377, 1, 0, -50553, 895, 0, 0, 39, '894'),
	(377, 1, 0, -50553, 896, 0, 0, 39, '895'),
	(377, 1, 0, -50553, 897, 0, 0, 39, '896'),
	(377, 1, 0, -50553, 898, 0, 0, 39, '897'),
	(377, 1, 0, -50553, 899, 0, 0, 39, '898'),
	(377, 1, 0, -50553, 900, 0, 0, 39, '899'),
	(377, 1, 0, -50553, 901, 0, 0, 39, '900'),
	(377, 1, 0, -50553, 902, 0, 0, 39, '901'),
	(377, 1, 0, -50553, 903, 0, 0, 39, '902'),
	(377, 1, 0, -50553, 904, 0, 0, 39, '903'),
	(377, 1, 0, -50553, 905, 0, 0, 39, '904'),
	(377, 1, 0, -50553, 906, 0, 0, 39, '905'),
	(377, 1, 0, -50553, 907, 0, 0, 39, '906'),
	(377, 1, 0, -50553, 908, 0, 0, 39, '907'),
	(377, 1, 0, -50553, 909, 0, 0, 39, '908'),
	(377, 1, 0, -50553, 910, 0, 0, 39, '909'),
	(377, 1, 0, -50553, 911, 0, 0, 39, '910'),
	(377, 1, 0, -50553, 912, 0, 0, 39, '911'),
	(377, 1, 0, -50553, 913, 0, 0, 39, '912'),
	(377, 1, 0, -50553, 914, 0, 0, 39, '913'),
	(377, 1, 0, -50553, 915, 0, 0, 39, '914'),
	(377, 1, 0, -50553, 916, 0, 0, 39, '915'),
	(377, 1, 0, -50553, 917, 0, 0, 39, '916'),
	(377, 1, 0, -50553, 918, 0, 0, 39, '917'),
	(377, 1, 0, -50553, 919, 0, 0, 39, '918'),
	(377, 1, 0, -50553, 920, 0, 0, 39, '919'),
	(377, 1, 0, -50553, 921, 0, 0, 39, '920'),
	(377, 1, 0, -50553, 922, 0, 0, 39, '921'),
	(377, 1, 0, -50553, 923, 0, 0, 39, '922'),
	(377, 1, 0, -50553, 924, 0, 0, 39, '923'),
	(377, 1, 0, -50553, 925, 0, 0, 39, '924'),
	(377, 1, 0, -50553, 926, 0, 0, 39, '925'),
	(377, 1, 0, -50553, 927, 0, 0, 39, '926'),
	(377, 1, 0, -50553, 928, 0, 0, 39, '927'),
	(377, 1, 0, -50553, 929, 0, 0, 39, '928'),
	(377, 1, 0, -50553, 930, 0, 0, 39, '929'),
	(377, 1, 0, -50553, 931, 0, 0, 39, '930'),
	(377, 1, 0, -50553, 932, 0, 0, 39, '931'),
	(377, 1, 0, -50553, 933, 0, 0, 39, '932'),
	(377, 1, 0, -50553, 934, 0, 0, 39, '933'),
	(377, 1, 0, -50553, 935, 0, 0, 39, '934'),
	(377, 1, 0, -50553, 936, 0, 0, 39, '935'),
	(377, 1, 0, -50553, 937, 0, 0, 39, '936'),
	(377, 1, 0, -50553, 938, 0, 0, 39, '937'),
	(377, 1, 0, -50553, 939, 0, 0, 39, '938'),
	(377, 1, 0, -50553, 940, 0, 0, 39, '939'),
	(377, 1, 0, -50553, 941, 0, 0, 39, '940'),
	(377, 1, 0, -50553, 942, 0, 0, 39, '941'),
	(377, 1, 0, -50553, 943, 0, 0, 39, '942'),
	(377, 1, 0, -50553, 944, 0, 0, 39, '943'),
	(377, 1, 0, -50553, 945, 0, 0, 39, '944'),
	(377, 1, 0, -50553, 946, 0, 0, 39, '945'),
	(377, 1, 0, -50553, 947, 0, 0, 39, '946'),
	(377, 1, 0, -50553, 948, 0, 0, 39, '947'),
	(377, 1, 0, -50553, 949, 0, 0, 39, '948'),
	(377, 1, 0, -50553, 950, 0, 0, 39, '949'),
	(377, 1, 0, -50553, 951, 0, 0, 39, '950'),
	(377, 1, 0, -50553, 952, 0, 0, 39, '951'),
	(377, 1, 0, -50553, 953, 0, 0, 39, '952'),
	(377, 1, 0, -50553, 954, 0, 0, 39, '953'),
	(377, 1, 0, -50553, 955, 0, 0, 39, '954'),
	(377, 1, 0, -50553, 956, 0, 0, 39, '955'),
	(377, 1, 0, -50553, 957, 0, 0, 39, '956'),
	(377, 1, 0, -50553, 958, 0, 0, 39, '957'),
	(377, 1, 0, -50553, 959, 0, 0, 39, '958'),
	(377, 1, 0, -50553, 960, 0, 0, 39, '959'),
	(377, 1, 0, -50553, 961, 0, 0, 39, '960'),
	(377, 1, 0, -50553, 962, 0, 0, 39, '961'),
	(377, 1, 0, -50553, 963, 0, 0, 39, '962'),
	(377, 1, 0, -50553, 964, 0, 0, 39, '963'),
	(377, 1, 0, -50553, 965, 0, 0, 39, '964'),
	(377, 1, 0, -50553, 966, 0, 0, 39, '965'),
	(377, 1, 0, -50553, 967, 0, 0, 39, '966'),
	(377, 1, 0, -50553, 968, 0, 0, 39, '967'),
	(377, 1, 0, -50553, 969, 0, 0, 39, '968'),
	(377, 1, 0, -50553, 970, 0, 0, 39, '969'),
	(377, 1, 0, -50553, 971, 0, 0, 39, '970'),
	(377, 1, 0, -50553, 972, 0, 0, 39, '971'),
	(377, 1, 0, -50553, 973, 0, 0, 39, '972'),
	(377, 1, 0, -50553, 974, 0, 0, 39, '973'),
	(377, 1, 0, -50553, 975, 0, 0, 39, '974'),
	(377, 1, 0, -50553, 976, 0, 0, 39, '975'),
	(377, 1, 0, -50553, 977, 0, 0, 39, '976'),
	(377, 1, 0, -50553, 978, 0, 0, 39, '977'),
	(377, 1, 0, -50553, 979, 0, 0, 39, '978'),
	(377, 1, 0, -50553, 980, 0, 0, 39, '979'),
	(377, 1, 0, -50553, 981, 0, 0, 39, '980'),
	(377, 1, 0, -50553, 982, 0, 0, 39, '981'),
	(377, 1, 0, -50553, 983, 0, 0, 39, '982'),
	(377, 1, 0, -50553, 984, 0, 0, 39, '983'),
	(377, 1, 0, -50553, 985, 0, 0, 39, '984'),
	(377, 1, 0, -50553, 986, 0, 0, 39, '985'),
	(377, 1, 0, -50553, 987, 0, 0, 39, '986'),
	(377, 1, 0, -50553, 988, 0, 0, 39, '987'),
	(377, 1, 0, -50553, 989, 0, 0, 39, '988'),
	(377, 1, 0, -50553, 990, 0, 0, 39, '989'),
	(377, 1, 0, -50553, 991, 0, 0, 39, '990'),
	(377, 1, 0, -50553, 992, 0, 0, 39, '991'),
	(377, 1, 0, -50553, 993, 0, 0, 39, '992'),
	(377, 1, 0, -50553, 994, 0, 0, 39, '993'),
	(377, 1, 0, -50553, 995, 0, 0, 39, '994'),
	(377, 1, 0, -50553, 996, 0, 0, 39, '995'),
	(377, 1, 0, -50553, 997, 0, 0, 39, '996'),
	(377, 1, 0, -50553, 998, 0, 0, 39, '997'),
	(377, 1, 0, -50553, 999, 0, 0, 39, '998'),
	(377, 1, 0, -50553, 1000, 0, 0, 39, '999'),
	(377, 1, 0, -50553, 1001, 0, 0, 39, '1000'),
	(377, 1, 0, -50553, 1002, 0, 0, 39, '1001'),
	(377, 1, 0, -50553, 1003, 0, 0, 39, '1002'),
	(377, 1, 0, -50553, 1004, 0, 0, 39, '1003'),
	(377, 1, 0, -50553, 1005, 0, 0, 39, '1004'),
	(377, 1, 0, -50553, 1006, 0, 0, 39, '1005'),
	(377, 1, 0, -50553, 1007, 0, 0, 39, '1006'),
	(377, 1, 0, -50553, 1008, 0, 0, 39, '1007'),
	(377, 1, 0, -50553, 1009, 0, 0, 39, '1008'),
	(377, 1, 0, -50553, 1010, 0, 0, 39, '1009'),
	(377, 1, 0, -50553, 1011, 0, 0, 39, '1010'),
	(377, 1, 0, -50553, 1012, 0, 0, 39, '1011'),
	(377, 1, 0, -50553, 1013, 0, 0, 39, '1012'),
	(377, 1, 0, -50553, 1014, 0, 0, 39, '1013'),
	(377, 1, 0, -50553, 1015, 0, 0, 39, '1014'),
	(377, 1, 0, -50553, 1016, 0, 0, 39, '1015'),
	(377, 1, 0, -50553, 1017, 0, 0, 39, '1016'),
	(377, 1, 0, -50553, 1018, 0, 0, 39, '1017'),
	(377, 1, 0, -50553, 1019, 0, 0, 39, '1018'),
	(377, 1, 0, -50553, 1020, 0, 0, 39, '1019'),
	(377, 1, 0, -50553, 1021, 0, 0, 39, '1020'),
	(377, 1, 0, -50553, 1022, 0, 0, 39, '1021'),
	(377, 1, 0, -50553, 1023, 0, 0, 39, '1022'),
	(377, 1, 0, -50553, 1024, 0, 0, 39, '1023'),
	(377, 1, 0, -50553, 1025, 0, 0, 39, '1024'),
	(377, 1, 0, -50553, 1026, 0, 0, 39, '1025'),
	(377, 1, 0, -50553, 1027, 0, 0, 39, '1026'),
	(377, 1, 0, -50553, 1028, 0, 0, 39, '1027'),
	(377, 1, 0, -50553, 1029, 0, 0, 39, '1028'),
	(377, 1, 0, -50553, 1030, 0, 0, 39, '1029'),
	(377, 1, 0, -50553, 1031, 0, 0, 39, '1030'),
	(377, 1, 0, -50553, 1032, 0, 0, 39, '1031'),
	(377, 1, 0, -50553, 1033, 0, 0, 39, '1032'),
	(377, 1, 0, -50553, 1034, 0, 0, 39, '1033'),
	(377, 1, 0, -50553, 1035, 0, 0, 39, '1034'),
	(377, 1, 0, -50553, 1036, 0, 0, 39, '1035'),
	(377, 1, 0, -50553, 1037, 0, 0, 39, '1036'),
	(377, 1, 0, -50553, 1038, 0, 0, 39, '1037'),
	(377, 1, 0, -50553, 1039, 0, 0, 39, '1038'),
	(377, 1, 0, -50553, 1040, 0, 0, 39, '1039'),
	(377, 1, 0, -50553, 1041, 0, 0, 39, '1040'),
	(377, 1, 0, -50553, 1042, 0, 0, 39, '1041'),
	(377, 1, 0, -50553, 1043, 0, 0, 39, '1042'),
	(377, 1, 0, -50553, 1044, 0, 0, 39, '1043'),
	(377, 1, 0, -50553, 1045, 0, 0, 39, '1044'),
	(377, 1, 0, -50553, 1046, 0, 0, 39, '1045'),
	(377, 1, 0, -50553, 1047, 0, 0, 39, '1046'),
	(377, 1, 0, -50553, 1048, 0, 0, 39, '1047'),
	(377, 1, 0, -50553, 1049, 0, 0, 39, '1048'),
	(377, 1, 0, -50553, 1050, 0, 0, 39, '1049'),
	(377, 1, 0, -50553, 1051, 0, 0, 39, '1050'),
	(377, 1, 0, -50553, 1052, 0, 0, 39, '1051'),
	(377, 1, 0, -50553, 1053, 0, 0, 39, '1052'),
	(377, 1, 0, -50553, 1054, 0, 0, 39, '1053'),
	(377, 1, 0, -50553, 1055, 0, 0, 39, '1054'),
	(377, 1, 0, -50553, 1056, 0, 0, 39, '1055'),
	(377, 1, 0, -50553, 1057, 0, 0, 39, '1056'),
	(377, 1, 0, -50553, 1058, 0, 0, 39, '1057'),
	(377, 1, 0, -50553, 1059, 0, 0, 39, '1058'),
	(377, 1, 0, -50553, 1060, 0, 0, 39, '1059'),
	(377, 1, 0, -50553, 1061, 0, 0, 39, '1060'),
	(377, 1, 0, -50553, 1062, 0, 0, 39, '1061'),
	(377, 1, 0, -50553, 1063, 0, 0, 39, '1062'),
	(377, 1, 0, -50553, 1064, 0, 0, 39, '1063'),
	(377, 1, 0, -50553, 1065, 0, 0, 39, '1064'),
	(377, 1, 0, -50553, 1066, 0, 0, 39, '1065'),
	(377, 1, 0, -50553, 1067, 0, 0, 39, '1066'),
	(377, 1, 0, -50553, 1068, 0, 0, 39, '1067'),
	(377, 1, 0, -50553, 1069, 0, 0, 39, '1068'),
	(377, 1, 0, -50553, 1070, 0, 0, 39, '1069'),
	(377, 1, 0, -50553, 1071, 0, 0, 39, '1070'),
	(377, 1, 0, -50553, 1072, 0, 0, 39, '1071'),
	(377, 1, 0, -50553, 1073, 0, 0, 39, '1072'),
	(377, 1, 0, -50553, 1074, 0, 0, 39, '1073'),
	(377, 1, 0, -50553, 1075, 0, 0, 39, '1074'),
	(377, 1, 0, -50553, 1076, 0, 0, 39, '1075'),
	(377, 1, 0, -50553, 1077, 0, 0, 39, '1076'),
	(377, 1, 0, -50553, 1078, 0, 0, 39, '1077'),
	(377, 1, 0, -50553, 1079, 0, 0, 39, '1078'),
	(377, 1, 0, -50553, 1080, 0, 0, 39, '1079'),
	(377, 1, 0, -50553, 1081, 0, 0, 39, '1080'),
	(377, 1, 0, -50553, 1082, 0, 0, 39, '1081'),
	(377, 1, 0, -50553, 1083, 0, 0, 39, '1082'),
	(377, 1, 0, -50553, 1084, 0, 0, 39, '1083'),
	(377, 1, 0, -50553, 1085, 0, 0, 39, '1084'),
	(377, 1, 0, -50553, 1086, 0, 0, 39, '1085'),
	(377, 1, 0, -50553, 1087, 0, 0, 39, '1086'),
	(377, 1, 0, -50553, 1088, 0, 0, 39, '1087'),
	(377, 1, 0, -50553, 1089, 0, 0, 39, '1088'),
	(377, 1, 0, -50553, 1090, 0, 0, 39, '1089'),
	(377, 1, 0, -50553, 1091, 0, 0, 39, '1090'),
	(377, 1, 0, -50553, 1092, 0, 0, 39, '1091'),
	(377, 1, 0, -50553, 1093, 0, 0, 39, '1092'),
	(377, 1, 0, -50553, 1094, 0, 0, 39, '1093'),
	(377, 1, 0, -50553, 1095, 0, 0, 39, '1094'),
	(377, 1, 0, -50553, 1096, 0, 0, 39, '1095'),
	(377, 1, 0, -50553, 1097, 0, 0, 39, '1096'),
	(377, 1, 0, -50553, 1098, 0, 0, 39, '1097'),
	(377, 1, 0, -50553, 1099, 0, 0, 39, '1098'),
	(377, 1, 0, -50553, 1100, 0, 0, 39, '1099'),
	(377, 1, 0, -50553, 1101, 0, 0, 39, '1100'),
	(377, 1, 0, -50553, 1102, 0, 0, 39, '1101'),
	(377, 1, 0, -50553, 1103, 0, 0, 39, '1102'),
	(377, 1, 0, -50553, 1104, 0, 0, 39, '1103'),
	(377, 1, 0, -50553, 1105, 0, 0, 39, '1104'),
	(377, 1, 0, -50553, 1106, 0, 0, 39, '1105'),
	(377, 1, 0, -50553, 1107, 0, 0, 39, '1106'),
	(377, 1, 0, -50553, 1108, 0, 0, 39, '1107'),
	(377, 1, 0, -50553, 1109, 0, 0, 39, '1108'),
	(377, 1, 0, -50553, 1110, 0, 0, 39, '1109'),
	(377, 1, 0, -50553, 1111, 0, 0, 39, '1110'),
	(377, 1, 0, -50553, 1112, 0, 0, 39, '1111'),
	(377, 1, 0, -50553, 1113, 0, 0, 39, '1112'),
	(377, 1, 0, -50553, 1114, 0, 0, 39, '1113'),
	(377, 1, 0, -50553, 1115, 0, 0, 39, '1114'),
	(377, 1, 0, -50553, 1116, 0, 0, 39, '1115'),
	(377, 1, 0, -50553, 1117, 0, 0, 39, '1116'),
	(377, 1, 0, -50553, 1118, 0, 0, 39, '1117'),
	(377, 1, 0, -50553, 1119, 0, 0, 39, '1118'),
	(377, 1, 0, -50553, 1120, 0, 0, 39, '1119'),
	(377, 1, 0, -50553, 1121, 0, 0, 39, '1120'),
	(377, 1, 0, -50553, 1122, 0, 0, 39, '1121'),
	(377, 1, 0, -50553, 1123, 0, 0, 39, '1122'),
	(377, 1, 0, -50553, 1124, 0, 0, 39, '1123'),
	(377, 1, 0, -50553, 1125, 0, 0, 39, '1124'),
	(377, 1, 0, -50553, 1126, 0, 0, 39, '1125'),
	(377, 1, 0, -50553, 1127, 0, 0, 39, '1126'),
	(377, 1, 0, -50553, 1128, 0, 0, 39, '1127'),
	(377, 1, 0, -50553, 1129, 0, 0, 39, '1128'),
	(377, 1, 0, -50553, 1130, 0, 0, 39, '1129'),
	(377, 1, 0, -50553, 1131, 0, 0, 39, '1130'),
	(377, 1, 0, -50553, 1132, 0, 0, 39, '1131'),
	(377, 1, 0, -50553, 1133, 0, 0, 39, '1132'),
	(377, 1, 0, -50553, 1134, 0, 0, 39, '1133'),
	(377, 1, 0, -50553, 1135, 0, 0, 39, '1134'),
	(377, 1, 0, -50553, 1136, 0, 0, 39, '1135'),
	(377, 1, 0, -50553, 1137, 0, 0, 39, '1136'),
	(377, 1, 0, -50553, 1138, 0, 0, 39, '1137'),
	(377, 1, 0, -50553, 1139, 0, 0, 39, '1138'),
	(377, 1, 0, -50553, 1140, 0, 0, 39, '1139'),
	(377, 1, 0, -50553, 1141, 0, 0, 39, '1140'),
	(377, 1, 0, -50553, 1142, 0, 0, 39, '1141'),
	(377, 1, 0, -50553, 1143, 0, 0, 39, '1142'),
	(377, 1, 0, -50553, 1144, 0, 0, 39, '1143'),
	(377, 1, 0, -50553, 1145, 0, 0, 39, '1144'),
	(377, 1, 0, -50553, 1146, 0, 0, 39, '1145'),
	(377, 1, 0, -50553, 1147, 0, 0, 39, '1146'),
	(377, 1, 0, -50553, 1148, 0, 0, 39, '1147'),
	(377, 1, 0, -50553, 1149, 0, 0, 39, '1148'),
	(377, 1, 0, -50553, 1150, 0, 0, 39, '1149'),
	(377, 1, 0, -50553, 1151, 0, 0, 39, '1150'),
	(377, 1, 0, -50553, 1152, 0, 0, 39, '1151'),
	(377, 1, 0, -50553, 1153, 0, 0, 39, '1152'),
	(377, 1, 0, -50553, 1154, 0, 0, 39, '1153'),
	(377, 1, 0, -50553, 1155, 0, 0, 39, '1154'),
	(377, 1, 0, -50553, 1156, 0, 0, 39, '1155'),
	(377, 1, 0, -50553, 1157, 0, 0, 39, '1156'),
	(377, 1, 0, -50553, 1158, 0, 0, 39, '1157'),
	(377, 1, 0, -50553, 1159, 0, 0, 39, '1158'),
	(377, 1, 0, -50553, 1160, 0, 0, 39, '1159'),
	(377, 1, 0, -50553, 1161, 0, 0, 39, '1160'),
	(377, 1, 0, -50553, 1162, 0, 0, 39, '1161'),
	(377, 1, 0, -50553, 1163, 0, 0, 39, '1162'),
	(377, 1, 0, -50553, 1164, 0, 0, 39, '1163'),
	(377, 1, 0, -50553, 1165, 0, 0, 39, '1164'),
	(377, 1, 0, -50553, 1166, 0, 0, 39, '1165'),
	(377, 1, 0, -50553, 1167, 0, 0, 39, '1166'),
	(377, 1, 0, -50553, 1168, 0, 0, 39, '1167'),
	(377, 1, 0, -50553, 1169, 0, 0, 39, '1168'),
	(377, 1, 0, -50553, 1170, 0, 0, 39, '1169'),
	(377, 1, 0, -50553, 1171, 0, 0, 39, '1170'),
	(377, 1, 0, -50553, 1172, 0, 0, 39, '1171'),
	(377, 1, 0, -50553, 1173, 0, 0, 39, '1172'),
	(377, 1, 0, -50553, 1174, 0, 0, 39, '1173'),
	(377, 1, 0, -50553, 1175, 0, 0, 39, '1174'),
	(377, 1, 0, -50553, 1176, 0, 0, 39, '1175'),
	(377, 1, 0, -50553, 1177, 0, 0, 39, '1176'),
	(377, 1, 0, -50553, 1178, 0, 0, 39, '1177'),
	(377, 1, 0, -50553, 1179, 0, 0, 39, '1178'),
	(377, 1, 0, -50553, 1180, 0, 0, 39, '1179'),
	(377, 1, 0, -50553, 1181, 0, 0, 39, '1180'),
	(377, 1, 0, -50553, 1182, 0, 0, 39, '1181'),
	(377, 1, 0, -50553, 1183, 0, 0, 39, '1182'),
	(377, 1, 0, -50553, 1184, 0, 0, 39, '1183'),
	(377, 1, 0, -50553, 1185, 0, 0, 39, '1184'),
	(377, 1, 0, -50553, 1186, 0, 0, 39, '1185'),
	(377, 1, 0, -50553, 1187, 0, 0, 39, '1186'),
	(377, 1, 0, -50553, 1188, 0, 0, 39, '1187'),
	(377, 1, 0, -50553, 1189, 0, 0, 39, '1188'),
	(377, 1, 0, -50553, 1190, 0, 0, 39, '1189'),
	(377, 1, 0, -50553, 1191, 0, 0, 39, '1190'),
	(377, 1, 0, -50553, 1192, 0, 0, 39, '1191'),
	(377, 1, 0, -50553, 1193, 0, 0, 39, '1192'),
	(377, 1, 0, -50553, 1194, 0, 0, 39, '1193'),
	(377, 1, 0, -50553, 1195, 0, 0, 39, '1194'),
	(377, 1, 0, -50553, 1196, 0, 0, 39, '1195'),
	(377, 1, 0, -50553, 1197, 0, 0, 39, '1196'),
	(377, 1, 0, -50553, 1198, 0, 0, 39, '1197'),
	(377, 1, 0, -50553, 1199, 0, 0, 39, '1198'),
	(377, 1, 0, -50553, 1200, 0, 0, 39, '1199'),
	(377, 1, 0, -50553, 1201, 0, 0, 39, '1200'),
	(377, 1, 0, -50553, 1202, 0, 0, 39, '1201'),
	(377, 1, 0, -50553, 1203, 0, 0, 39, '1202'),
	(377, 1, 0, -50553, 1204, 0, 0, 39, '1203'),
	(377, 1, 0, -50553, 1205, 0, 0, 39, '1204'),
	(377, 1, 0, -50553, 1206, 0, 0, 39, '1205'),
	(377, 1, 0, -50553, 1207, 0, 0, 39, '1206'),
	(377, 1, 0, -50553, 1208, 0, 0, 39, '1207'),
	(377, 1, 0, -50553, 1209, 0, 0, 39, '1208'),
	(377, 1, 0, -50553, 1210, 0, 0, 39, '1209'),
	(377, 1, 0, -50553, 1211, 0, 0, 39, '1210'),
	(377, 1, 0, -50553, 1212, 0, 0, 39, '1211'),
	(377, 1, 0, -50553, 1213, 0, 0, 39, '1212'),
	(377, 1, 0, -50553, 1214, 0, 0, 39, '1213'),
	(377, 1, 0, -50553, 1215, 0, 0, 39, '1214'),
	(377, 1, 0, -50553, 1216, 0, 0, 39, '1215'),
	(377, 1, 0, -50553, 1217, 0, 0, 39, '1216'),
	(377, 1, 0, -50553, 1218, 0, 0, 39, '1217'),
	(377, 1, 0, -50553, 1219, 0, 0, 39, '1218'),
	(377, 1, 0, -50553, 1220, 0, 0, 39, '1219'),
	(377, 1, 0, -50553, 1221, 0, 0, 39, '1220'),
	(377, 1, 0, -50553, 1222, 0, 0, 39, '1221'),
	(377, 1, 0, -50553, 1223, 0, 0, 39, '1222'),
	(377, 1, 0, -50553, 1224, 0, 0, 39, '1223'),
	(377, 1, 0, -50553, 1225, 0, 0, 39, '1224'),
	(377, 1, 0, -50553, 1226, 0, 0, 39, '1225'),
	(377, 1, 0, -50553, 1227, 0, 0, 39, '1226'),
	(377, 1, 0, -50553, 1228, 0, 0, 39, '1227'),
	(377, 1, 0, -50553, 1229, 0, 0, 39, '1228'),
	(377, 1, 0, -50553, 1230, 0, 0, 39, '1229'),
	(377, 1, 0, -50553, 1231, 0, 0, 39, '1230'),
	(377, 1, 0, -50553, 1232, 0, 0, 39, '1231'),
	(377, 1, 0, -50553, 1233, 0, 0, 39, '1232'),
	(377, 1, 0, -50553, 1234, 0, 0, 39, '1233'),
	(377, 1, 0, -50553, 1235, 0, 0, 39, '1234'),
	(377, 1, 0, -50553, 1236, 0, 0, 39, '1235'),
	(377, 1, 0, -50553, 1237, 0, 0, 39, '1236'),
	(377, 1, 0, -50553, 1238, 0, 0, 39, '1237'),
	(377, 1, 0, -50553, 1239, 0, 0, 39, '1238'),
	(377, 1, 0, -50553, 1240, 0, 0, 39, '1239'),
	(377, 1, 0, -50553, 1241, 0, 0, 39, '1240'),
	(377, 1, 0, -50553, 1242, 0, 0, 39, '1241'),
	(377, 1, 0, -50553, 1243, 0, 0, 39, '1242'),
	(377, 1, 0, -50553, 1244, 0, 0, 39, '1243'),
	(377, 1, 0, -50553, 1245, 0, 0, 39, '1244'),
	(377, 1, 0, -50553, 1246, 0, 0, 39, '1245'),
	(377, 1, 0, -50553, 1247, 0, 0, 39, '1246'),
	(377, 1, 0, -50553, 1248, 0, 0, 39, '1247'),
	(377, 1, 0, -50553, 1249, 0, 0, 39, '1248'),
	(377, 1, 0, -50553, 1250, 0, 0, 39, '1249'),
	(377, 1, 0, -50553, 1251, 0, 0, 39, '1250'),
	(377, 1, 0, -50553, 1252, 0, 0, 39, '1251'),
	(377, 1, 0, -50553, 1253, 0, 0, 39, '1252'),
	(377, 1, 0, -50553, 1254, 0, 0, 39, '1253'),
	(377, 1, 0, -50553, 1255, 0, 0, 39, '1254'),
	(377, 1, 0, -50553, 1256, 0, 0, 39, '1255'),
	(377, 1, 0, -50553, 1257, 0, 0, 39, '1256'),
	(377, 1, 0, -50553, 1258, 0, 0, 39, '1257'),
	(377, 1, 0, -50553, 1259, 0, 0, 39, '1258'),
	(377, 1, 0, -50553, 1260, 0, 0, 39, '1259'),
	(377, 1, 0, -50553, 1261, 0, 0, 39, '1260'),
	(377, 1, 0, -50553, 1262, 0, 0, 39, '1261'),
	(377, 1, 0, -50553, 1263, 0, 0, 39, '1262'),
	(377, 1, 0, -50553, 1264, 0, 0, 39, '1263'),
	(377, 1, 0, -50553, 1265, 0, 0, 39, '1264'),
	(377, 1, 0, -50553, 1266, 0, 0, 39, '1265'),
	(377, 1, 0, -50553, 1267, 0, 0, 39, '1266'),
	(377, 1, 0, -50553, 1268, 0, 0, 39, '1267'),
	(377, 1, 0, -50553, 1269, 0, 0, 39, '1268'),
	(377, 1, 0, -50553, 1270, 0, 0, 39, '1269'),
	(377, 1, 0, -50553, 1271, 0, 0, 39, '1270'),
	(377, 1, 0, -50553, 1272, 0, 0, 39, '1271'),
	(377, 1, 0, -50553, 1273, 0, 0, 39, '1272'),
	(377, 1, 0, -50553, 1274, 0, 0, 39, '1273'),
	(377, 1, 0, -50553, 1275, 0, 0, 39, '1274'),
	(377, 1, 0, -50553, 1276, 0, 0, 39, '1275'),
	(377, 1, 0, -50553, 1277, 0, 0, 39, '1276'),
	(377, 1, 0, -50553, 1278, 0, 0, 39, '1277'),
	(377, 1, 0, -50553, 1279, 0, 0, 39, '1278'),
	(377, 1, 0, -50553, 1280, 0, 0, 39, '1279'),
	(377, 1, 0, -50553, 1281, 0, 0, 39, '1280'),
	(377, 1, 0, -50553, 1282, 0, 0, 39, '1281'),
	(377, 1, 0, -50553, 1283, 0, 0, 39, '1282'),
	(377, 1, 0, -50553, 1284, 0, 0, 39, '1283'),
	(377, 1, 0, -50553, 1285, 0, 0, 39, '1284'),
	(377, 1, 0, -50553, 1286, 0, 0, 39, '1285'),
	(377, 1, 0, -50553, 1287, 0, 0, 39, '1286'),
	(377, 1, 0, -50553, 1288, 0, 0, 39, '1287'),
	(377, 1, 0, -50553, 1289, 0, 0, 39, '1288'),
	(377, 1, 0, -50553, 1290, 0, 0, 39, '1289'),
	(377, 1, 0, -50553, 1291, 0, 0, 39, '1290'),
	(377, 1, 0, -50553, 1292, 0, 0, 39, '1291'),
	(377, 1, 0, -50553, 1293, 0, 0, 39, '1292'),
	(377, 1, 0, -50553, 1294, 0, 0, 39, '1293'),
	(377, 1, 0, -50553, 1295, 0, 0, 39, '1294'),
	(377, 1, 0, -50553, 1296, 0, 0, 39, '1295'),
	(377, 1, 0, -50553, 1297, 0, 0, 39, '1296'),
	(377, 1, 0, -50553, 1298, 0, 0, 39, '1297'),
	(377, 1, 0, -50553, 1299, 0, 0, 39, '1298'),
	(377, 1, 0, -50553, 1300, 0, 0, 39, '1299'),
	(377, 1, 0, -50553, 1301, 0, 0, 39, '1300'),
	(377, 1, 0, -50553, 1302, 0, 0, 39, '1301'),
	(377, 1, 0, -50553, 1303, 0, 0, 39, '1302'),
	(377, 1, 0, -50553, 1304, 0, 0, 39, '1303'),
	(377, 1, 0, -50553, 1305, 0, 0, 39, '1304'),
	(377, 1, 0, -50553, 1306, 0, 0, 39, '1305'),
	(377, 1, 0, -50553, 1307, 0, 0, 39, '1306'),
	(377, 1, 0, -50553, 1308, 0, 0, 39, '1307'),
	(377, 1, 0, -50553, 1309, 0, 0, 39, '1308'),
	(377, 1, 0, -50553, 1310, 0, 0, 39, '1309'),
	(377, 1, 0, -50553, 1311, 0, 0, 39, '1310'),
	(377, 1, 0, -50553, 1312, 0, 0, 39, '1311'),
	(377, 1, 0, -50553, 1313, 0, 0, 39, '1312'),
	(377, 1, 0, -50553, 1314, 0, 0, 39, '1313'),
	(377, 1, 0, -50553, 1315, 0, 0, 39, '1314'),
	(377, 1, 0, -50553, 1316, 0, 0, 39, '1315'),
	(377, 1, 0, -50553, 1317, 0, 0, 39, '1316'),
	(377, 1, 0, -50553, 1318, 0, 0, 39, '1317'),
	(377, 1, 0, -50553, 1319, 0, 0, 39, '1318'),
	(377, 1, 0, -50553, 1320, 0, 0, 39, '1319'),
	(377, 1, 0, -50553, 1321, 0, 0, 39, '1320'),
	(377, 1, 0, -50553, 1322, 0, 0, 39, '1321'),
	(377, 1, 0, -50553, 1323, 0, 0, 39, '1322'),
	(377, 1, 0, -50553, 1324, 0, 0, 39, '1323'),
	(377, 1, 0, -50553, 1325, 0, 0, 39, '1324'),
	(377, 1, 0, -50553, 1326, 0, 0, 39, '1325'),
	(377, 1, 0, -50553, 1327, 0, 0, 39, '1326'),
	(377, 1, 0, -50553, 1328, 0, 0, 39, '1327'),
	(377, 1, 0, -50553, 1329, 0, 0, 39, '1328'),
	(377, 1, 0, -50553, 1330, 0, 0, 39, '1329'),
	(377, 1, 0, -50553, 1331, 0, 0, 39, '1330'),
	(377, 1, 0, -50553, 1332, 0, 0, 39, '1331'),
	(377, 1, 0, -50553, 1333, 0, 0, 39, '1332'),
	(377, 1, 0, -50553, 1334, 0, 0, 39, '1333'),
	(377, 1, 0, -50553, 1335, 0, 0, 39, '1334'),
	(377, 1, 0, -50553, 1336, 0, 0, 39, '1335'),
	(377, 1, 0, -50553, 1337, 0, 0, 39, '1336'),
	(377, 1, 0, -50553, 1338, 0, 0, 39, '1337'),
	(377, 1, 0, -50553, 1339, 0, 0, 39, '1338'),
	(377, 1, 0, -50553, 1340, 0, 0, 39, '1339'),
	(377, 1, 0, -50553, 1341, 0, 0, 39, '1340'),
	(377, 1, 0, -50553, 1342, 0, 0, 39, '1341'),
	(377, 1, 0, -50553, 1343, 0, 0, 39, '1342'),
	(377, 1, 0, -50553, 1344, 0, 0, 39, '1343'),
	(377, 1, 0, -50553, 1345, 0, 0, 39, '1344'),
	(377, 1, 0, -50553, 1346, 0, 0, 39, '1345'),
	(377, 1, 0, -50553, 1347, 0, 0, 39, '1346'),
	(377, 1, 0, -50553, 1348, 0, 0, 39, '1347'),
	(377, 1, 0, -50553, 1349, 0, 0, 39, '1348'),
	(377, 1, 0, -50553, 1350, 0, 0, 39, '1349'),
	(377, 1, 0, -50553, 1351, 0, 0, 39, '1350'),
	(377, 1, 0, -50553, 1352, 0, 0, 39, '1351'),
	(377, 1, 0, -50553, 1353, 0, 0, 39, '1352'),
	(377, 1, 0, -50553, 1354, 0, 0, 39, '1353'),
	(377, 1, 0, -50553, 1355, 0, 0, 39, '1354'),
	(377, 1, 0, -50553, 1356, 0, 0, 39, '1355'),
	(377, 1, 0, -50553, 1357, 0, 0, 39, '1356'),
	(377, 1, 0, -50553, 1358, 0, 0, 39, '1357'),
	(377, 1, 0, -50553, 1359, 0, 0, 39, '1358'),
	(377, 1, 0, -50553, 1360, 0, 0, 39, '1359'),
	(377, 1, 0, -50553, 1361, 0, 0, 39, '1360'),
	(377, 1, 0, -50553, 1362, 0, 0, 39, '1361'),
	(377, 1, 0, -50553, 1363, 0, 0, 39, '1362'),
	(377, 1, 0, -50553, 1364, 0, 0, 39, '1363'),
	(377, 1, 0, -50553, 1365, 0, 0, 39, '1364'),
	(377, 1, 0, -50553, 1366, 0, 0, 39, '1365'),
	(377, 1, 0, -50553, 1367, 0, 0, 39, '1366'),
	(377, 1, 0, -50553, 1368, 0, 0, 39, '1367'),
	(377, 1, 0, -50553, 1369, 0, 0, 39, '1368'),
	(377, 1, 0, -50553, 1370, 0, 0, 39, '1369'),
	(377, 1, 0, -50553, 1371, 0, 0, 39, '1370'),
	(377, 1, 0, -50553, 1372, 0, 0, 39, '1371'),
	(377, 1, 0, -50553, 1373, 0, 0, 39, '1372'),
	(377, 1, 0, -50553, 1374, 0, 0, 39, '1373'),
	(377, 1, 0, -50553, 1375, 0, 0, 39, '1374'),
	(377, 1, 0, -50553, 1376, 0, 0, 39, '1375'),
	(377, 1, 0, -50553, 1377, 0, 0, 39, '1376'),
	(377, 1, 0, -50553, 1378, 0, 0, 39, '1377'),
	(377, 1, 0, -50553, 1379, 0, 0, 39, '1378'),
	(377, 1, 0, -50553, 1380, 0, 0, 39, '1379'),
	(377, 1, 0, -50553, 1381, 0, 0, 39, '1380'),
	(377, 1, 0, -50553, 1382, 0, 0, 39, '1381'),
	(377, 1, 0, -50553, 1383, 0, 0, 39, '1382'),
	(377, 1, 0, -50553, 1384, 0, 0, 39, '1383'),
	(377, 1, 0, -50553, 1385, 0, 0, 39, '1384'),
	(377, 1, 0, -50553, 1386, 0, 0, 39, '1385'),
	(377, 1, 0, -50553, 1387, 0, 0, 39, '1386'),
	(377, 1, 0, -50553, 1388, 0, 0, 39, '1387'),
	(377, 1, 0, -50553, 1389, 0, 0, 39, '1388'),
	(377, 1, 0, -50553, 1390, 0, 0, 39, '1389'),
	(377, 1, 0, -50553, 1391, 0, 0, 39, '1390'),
	(377, 1, 0, -50553, 1392, 0, 0, 39, '1391'),
	(377, 1, 0, -50553, 1393, 0, 0, 39, '1392'),
	(377, 1, 0, -50553, 1394, 0, 0, 39, '1393'),
	(377, 1, 0, -50553, 1395, 0, 0, 39, '1394'),
	(377, 1, 0, -50553, 1396, 0, 0, 39, '1395'),
	(377, 1, 0, -50553, 1397, 0, 0, 39, '1396'),
	(377, 1, 0, -50553, 1398, 0, 0, 39, '1397'),
	(377, 1, 0, -50553, 1399, 0, 0, 39, '1398'),
	(377, 1, 0, -50553, 1400, 0, 0, 39, '1399'),
	(377, 1, 0, -50553, 1401, 0, 0, 39, '1400'),
	(377, 1, 0, -50553, 1402, 0, 0, 39, '1401'),
	(377, 1, 0, -50553, 1403, 0, 0, 39, '1402'),
	(377, 1, 0, -50553, 1404, 0, 0, 39, '1403'),
	(377, 1, 0, -50553, 1405, 0, 0, 39, '1404'),
	(377, 1, 0, -50553, 1406, 0, 0, 39, '1405'),
	(377, 1, 0, -50553, 1407, 0, 0, 39, '1406'),
	(377, 1, 0, -50553, 1408, 0, 0, 39, '1407'),
	(377, 1, 0, -50553, 1409, 0, 0, 39, '1408'),
	(377, 1, 0, -50553, 1410, 0, 0, 39, '1409'),
	(377, 1, 0, -50553, 1411, 0, 0, 39, '1410'),
	(377, 1, 0, -50553, 1412, 0, 0, 39, '1411'),
	(377, 1, 0, -50553, 1413, 0, 0, 39, '1412'),
	(377, 1, 0, -50553, 1414, 0, 0, 39, '1413'),
	(377, 1, 0, -50553, 1415, 0, 0, 39, '1414'),
	(377, 1, 0, -50553, 1416, 0, 0, 39, '1415'),
	(377, 1, 0, -50553, 1417, 0, 0, 39, '1416'),
	(377, 1, 0, -50553, 1418, 0, 0, 39, '1417'),
	(377, 1, 0, -50553, 1419, 0, 0, 39, '1418'),
	(377, 1, 0, -50553, 1420, 0, 0, 39, '1419'),
	(377, 1, 0, -50553, 1421, 0, 0, 39, '1420'),
	(377, 1, 0, -50553, 1422, 0, 0, 39, '1421'),
	(377, 1, 0, -50553, 1423, 0, 0, 39, '1422'),
	(377, 1, 0, -50553, 1424, 0, 0, 39, '1423'),
	(377, 1, 0, -50553, 1425, 0, 0, 39, '1424'),
	(377, 1, 0, -50553, 1426, 0, 0, 39, '1425'),
	(377, 1, 0, -50553, 1427, 0, 0, 39, '1426'),
	(377, 1, 0, -50553, 1428, 0, 0, 39, '1427'),
	(377, 1, 0, -50553, 1429, 0, 0, 39, '1428'),
	(377, 1, 0, -50553, 1430, 0, 0, 39, '1429'),
	(377, 1, 0, -50553, 1431, 0, 0, 39, '1430'),
	(377, 1, 0, -50553, 1432, 0, 0, 39, '1431'),
	(377, 1, 0, -50553, 1433, 0, 0, 39, '1432'),
	(377, 1, 0, -50553, 1434, 0, 0, 39, '1433'),
	(377, 1, 0, -50553, 1435, 0, 0, 39, '1434'),
	(377, 1, 0, -50553, 1436, 0, 0, 39, '1435'),
	(377, 1, 0, -50553, 1437, 0, 0, 39, '1436'),
	(377, 1, 0, -50553, 1438, 0, 0, 39, '1437'),
	(377, 1, 0, -50553, 1439, 0, 0, 39, '1438'),
	(377, 1, 0, -50553, 1440, 0, 0, 39, '1439'),
	(377, 1, 0, -50553, 1441, 0, 0, 39, '1440'),
	(377, 1, 0, -50553, 1442, 0, 0, 39, '1441'),
	(377, 1, 0, -50553, 1443, 0, 0, 39, '1442'),
	(377, 1, 0, -50553, 1444, 0, 0, 39, '1443'),
	(377, 1, 0, -50553, 1445, 0, 0, 39, '1444'),
	(377, 1, 0, -50553, 1446, 0, 0, 39, '1445'),
	(377, 1, 0, -50553, 1447, 0, 0, 39, '1446'),
	(377, 1, 0, -50553, 1448, 0, 0, 39, '1447'),
	(377, 1, 0, -50553, 1449, 0, 0, 39, '1448'),
	(377, 1, 0, -50553, 1450, 0, 0, 39, '1449'),
	(377, 1, 0, -50553, 1451, 0, 0, 39, '1450'),
	(377, 1, 0, -50553, 1452, 0, 0, 39, '1451'),
	(377, 1, 0, -50553, 1453, 0, 0, 39, '1452'),
	(377, 1, 0, -50553, 1454, 0, 0, 39, '1453'),
	(377, 1, 0, -50553, 1455, 0, 0, 39, '1454'),
	(377, 1, 0, -50553, 1456, 0, 0, 39, '1455'),
	(377, 1, 0, -50553, 1457, 0, 0, 39, '1456'),
	(377, 1, 0, -50553, 1458, 0, 0, 39, '1457'),
	(377, 1, 0, -50553, 1459, 0, 0, 39, '1458'),
	(377, 1, 0, -50553, 1460, 0, 0, 39, '1459'),
	(377, 1, 0, -50553, 1461, 0, 0, 39, '1460'),
	(377, 1, 0, -50553, 1462, 0, 0, 39, '1461'),
	(377, 1, 0, -50553, 1463, 0, 0, 39, '1462'),
	(377, 1, 0, -50553, 1464, 0, 0, 39, '1463'),
	(377, 1, 0, -50553, 1465, 0, 0, 39, '1464'),
	(377, 1, 0, -50553, 1466, 0, 0, 39, '1465'),
	(377, 1, 0, -50553, 1467, 0, 0, 39, '1466'),
	(377, 1, 0, -50553, 1468, 0, 0, 39, '1467'),
	(377, 1, 0, -50553, 1469, 0, 0, 39, '1468'),
	(377, 1, 0, -50553, 1470, 0, 0, 39, '1469'),
	(377, 1, 0, -50553, 1471, 0, 0, 39, '1470'),
	(377, 1, 0, -50553, 1472, 0, 0, 39, '1471'),
	(377, 1, 0, -50553, 1473, 0, 0, 39, '1472'),
	(377, 1, 0, -50553, 1474, 0, 0, 39, '1473'),
	(377, 1, 0, -50553, 1475, 0, 0, 39, '1474'),
	(377, 1, 0, -50553, 1476, 0, 0, 39, '1475'),
	(377, 1, 0, -50553, 1477, 0, 0, 39, '1476'),
	(377, 1, 0, -50553, 1478, 0, 0, 39, '1477'),
	(377, 1, 0, -50553, 1479, 0, 0, 39, '1478'),
	(377, 1, 0, -50553, 1480, 0, 0, 39, '1479'),
	(377, 1, 0, -50553, 1481, 0, 0, 39, '1480'),
	(377, 1, 0, -50553, 1482, 0, 0, 39, '1481'),
	(377, 1, 0, -50553, 1483, 0, 0, 39, '1482'),
	(377, 1, 0, -50553, 1484, 0, 0, 39, '1483'),
	(377, 1, 0, -50553, 1485, 0, 0, 39, '1484'),
	(377, 1, 0, -50553, 1486, 0, 0, 39, '1485'),
	(377, 1, 0, -50553, 1487, 0, 0, 39, '1486'),
	(377, 1, 0, -50553, 1488, 0, 0, 39, '1487'),
	(377, 1, 0, -50553, 1489, 0, 0, 39, '1488'),
	(377, 1, 0, -50553, 1490, 0, 0, 39, '1489'),
	(377, 1, 0, -50553, 1491, 0, 0, 39, '1490'),
	(377, 1, 0, -50553, 1492, 0, 0, 39, '1491'),
	(377, 1, 0, -50553, 1493, 0, 0, 39, '1492'),
	(377, 1, 0, -50553, 1494, 0, 0, 39, '1493'),
	(377, 1, 0, -50553, 1495, 0, 0, 39, '1494'),
	(377, 1, 0, -50553, 1496, 0, 0, 39, '1495'),
	(377, 1, 0, -50553, 1497, 0, 0, 39, '1496'),
	(377, 1, 0, -50553, 1498, 0, 0, 39, '1497'),
	(377, 1, 0, -50553, 1499, 0, 0, 39, '1498'),
	(377, 1, 0, -50553, 1500, 0, 0, 39, '1499'),
	(377, 1, 0, -50553, 1501, 0, 0, 39, '1500'),
	(377, 1, 0, -50553, 1502, 0, 0, 39, '1501'),
	(377, 1, 0, -50553, 1503, 0, 0, 39, '1502'),
	(377, 1, 0, -50553, 1504, 0, 0, 39, '1503'),
	(377, 1, 0, -50553, 1505, 0, 0, 39, '1504'),
	(377, 1, 0, -50553, 1506, 0, 0, 39, '1505'),
	(377, 1, 0, -50553, 1507, 0, 0, 39, '1506'),
	(377, 1, 0, -50553, 1508, 0, 0, 39, '1507'),
	(377, 1, 0, -50553, 1509, 0, 0, 39, '1508'),
	(377, 1, 0, -50553, 1510, 0, 0, 39, '1509'),
	(377, 1, 0, -50553, 1511, 0, 0, 39, '1510'),
	(377, 1, 0, -50553, 1512, 0, 0, 39, '1511'),
	(377, 1, 0, -50553, 1513, 0, 0, 39, '1512'),
	(377, 1, 0, -50553, 1514, 0, 0, 39, '1513'),
	(377, 1, 0, -50553, 1515, 0, 0, 39, '1514'),
	(377, 1, 0, -50553, 1516, 0, 0, 39, '1515'),
	(377, 1, 0, -50553, 1517, 0, 0, 39, '1516'),
	(377, 1, 0, -50553, 1518, 0, 0, 39, '1517'),
	(377, 1, 0, -50553, 1519, 0, 0, 39, '1518'),
	(377, 1, 0, -50553, 1520, 0, 0, 39, '1519'),
	(377, 1, 0, -50553, 1521, 0, 0, 39, '1520'),
	(377, 1, 0, -50553, 1522, 0, 0, 39, '1521'),
	(377, 1, 0, -50553, 1523, 0, 0, 39, '1522'),
	(377, 1, 0, -50553, 1524, 0, 0, 39, '1523'),
	(377, 1, 0, -50553, 1525, 0, 0, 39, '1524'),
	(377, 1, 0, -50553, 1526, 0, 0, 39, '1525'),
	(377, 1, 0, -50553, 1527, 0, 0, 39, '1526'),
	(377, 1, 0, -50553, 1528, 0, 0, 39, '1527'),
	(377, 1, 0, -50553, 1529, 0, 0, 39, '1528'),
	(377, 1, 0, -50553, 1530, 0, 0, 39, '1529'),
	(377, 1, 0, -50553, 1531, 0, 0, 39, '1530'),
	(377, 1, 0, -50553, 1532, 0, 0, 39, '1531'),
	(377, 1, 0, -50553, 1533, 0, 0, 39, '1532'),
	(377, 1, 0, -50553, 1534, 0, 0, 39, '1533'),
	(377, 1, 0, -50553, 1535, 0, 0, 39, '1534'),
	(377, 1, 0, -50553, 1536, 0, 0, 39, '1535'),
	(377, 1, 0, -50553, 1537, 0, 0, 39, '1536'),
	(377, 1, 0, -50553, 1538, 0, 0, 39, '1537'),
	(377, 1, 0, -50553, 1539, 0, 0, 39, '1538'),
	(377, 1, 0, -50553, 1540, 0, 0, 39, '1539'),
	(377, 1, 0, -50553, 1541, 0, 0, 39, '1540'),
	(377, 1, 0, -50553, 1542, 0, 0, 39, '1541'),
	(377, 1, 0, -50553, 1543, 0, 0, 39, '1542'),
	(377, 1, 0, -50553, 1544, 0, 0, 39, '1543'),
	(377, 1, 0, -50553, 1545, 0, 0, 39, '1544'),
	(377, 1, 0, -50553, 1546, 0, 0, 39, '1545'),
	(377, 1, 0, -50553, 1547, 0, 0, 39, '1546'),
	(377, 1, 0, -50553, 1548, 0, 0, 39, '1547'),
	(377, 1, 0, -50553, 1549, 0, 0, 39, '1548'),
	(377, 1, 0, -50553, 1550, 0, 0, 39, '1549'),
	(377, 1, 0, -50553, 1551, 0, 0, 39, '1550'),
	(377, 1, 0, -50553, 1552, 0, 0, 39, '1551'),
	(377, 1, 0, -50553, 1553, 0, 0, 39, '1552'),
	(377, 1, 0, -50553, 1554, 0, 0, 39, '1553'),
	(377, 1, 0, -50553, 1555, 0, 0, 39, '1554'),
	(377, 1, 0, -50553, 1556, 0, 0, 39, '1555'),
	(377, 1, 0, -50553, 1557, 0, 0, 39, '1556'),
	(377, 1, 0, -50553, 1558, 0, 0, 39, '1557'),
	(377, 1, 0, -50553, 1559, 0, 0, 39, '1558'),
	(377, 1, 0, -50553, 1560, 0, 0, 39, '1559'),
	(377, 1, 0, -50553, 1561, 0, 0, 39, '1560'),
	(377, 1, 0, -50553, 1562, 0, 0, 39, '1561'),
	(377, 1, 0, -50553, 1563, 0, 0, 39, '1562'),
	(377, 1, 0, -50553, 1564, 0, 0, 39, '1563'),
	(377, 1, 0, -50553, 1565, 0, 0, 39, '1564'),
	(377, 1, 0, -50553, 1566, 0, 0, 39, '1565'),
	(377, 1, 0, -50553, 1567, 0, 0, 39, '1566'),
	(377, 1, 0, -50553, 1568, 0, 0, 39, '1567'),
	(377, 1, 0, -50553, 1569, 0, 0, 39, '1568'),
	(377, 1, 0, -50553, 1570, 0, 0, 39, '1569'),
	(377, 1, 0, -50553, 1571, 0, 0, 39, '1570'),
	(377, 1, 0, -50553, 1572, 0, 0, 39, '1571'),
	(377, 1, 0, -50553, 1573, 0, 0, 39, '1572'),
	(377, 1, 0, -50553, 1574, 0, 0, 39, '1573'),
	(377, 1, 0, -50553, 1575, 0, 0, 39, '1574'),
	(377, 1, 0, -50553, 1576, 0, 0, 39, '1575'),
	(377, 1, 0, -50553, 1577, 0, 0, 39, '1576'),
	(377, 1, 0, -50553, 1578, 0, 0, 39, '1577'),
	(377, 1, 0, -50553, 1579, 0, 0, 39, '1578'),
	(377, 1, 0, -50553, 1580, 0, 0, 39, '1579'),
	(377, 1, 0, -50553, 1581, 0, 0, 39, '1580'),
	(377, 1, 0, -50553, 1582, 0, 0, 39, '1581'),
	(377, 1, 0, -50553, 1583, 0, 0, 39, '1582'),
	(377, 1, 0, -50553, 1584, 0, 0, 39, '1583'),
	(377, 1, 0, -50553, 1585, 0, 0, 39, '1584'),
	(377, 1, 0, -50553, 1586, 0, 0, 39, '1585'),
	(377, 1, 0, -50553, 1587, 0, 0, 39, '1586'),
	(377, 1, 0, -50553, 1588, 0, 0, 39, '1587'),
	(377, 1, 0, -50553, 1589, 0, 0, 39, '1588'),
	(377, 1, 0, -50553, 1590, 0, 0, 39, '1589'),
	(377, 1, 0, -50553, 1591, 0, 0, 39, '1590'),
	(377, 1, 0, -50553, 1592, 0, 0, 39, '1591'),
	(377, 1, 0, -50553, 1593, 0, 0, 39, '1592'),
	(377, 1, 0, -50553, 1594, 0, 0, 39, '1593'),
	(377, 1, 0, -50553, 1595, 0, 0, 39, '1594'),
	(377, 1, 0, -50553, 1596, 0, 0, 39, '1595'),
	(377, 1, 0, -50553, 1597, 0, 0, 39, '1596'),
	(377, 1, 0, -50553, 1598, 0, 0, 39, '1597'),
	(377, 1, 0, -50553, 1599, 0, 0, 39, '1598'),
	(377, 1, 0, -50553, 1600, 0, 0, 39, '1599'),
	(377, 1, 0, -50553, 1601, 0, 0, 39, '1600'),
	(377, 1, 0, -50553, 1602, 0, 0, 39, '1601'),
	(377, 1, 0, -50553, 1603, 0, 0, 39, '1602'),
	(377, 1, 0, -50553, 1604, 0, 0, 39, '1603'),
	(377, 1, 0, -50553, 1605, 0, 0, 39, '1604'),
	(377, 1, 0, -50553, 1606, 0, 0, 39, '1605'),
	(377, 1, 0, -50553, 1607, 0, 0, 39, '1606'),
	(377, 1, 0, -50553, 1608, 0, 0, 39, '1607'),
	(377, 1, 0, -50553, 1609, 0, 0, 39, '1608'),
	(377, 1, 0, -50553, 1610, 0, 0, 39, '1609'),
	(377, 1, 0, -50553, 1611, 0, 0, 39, '1610'),
	(377, 1, 0, -50553, 1612, 0, 0, 39, '1611'),
	(377, 1, 0, -50553, 1613, 0, 0, 39, '1612'),
	(377, 1, 0, -50553, 1614, 0, 0, 39, '1613'),
	(377, 1, 0, -50553, 1615, 0, 0, 39, '1614'),
	(377, 1, 0, -50553, 1616, 0, 0, 39, '1615'),
	(377, 1, 0, -50553, 1617, 0, 0, 39, '1616'),
	(377, 1, 0, -50553, 1618, 0, 0, 39, '1617'),
	(377, 1, 0, -50553, 1619, 0, 0, 39, '1618'),
	(377, 1, 0, -50553, 1620, 0, 0, 39, '1619'),
	(377, 1, 0, -50553, 1621, 0, 0, 39, '1620'),
	(377, 1, 0, -50553, 1622, 0, 0, 39, '1621'),
	(377, 1, 0, -50553, 1623, 0, 0, 39, '1622'),
	(377, 1, 0, -50553, 1624, 0, 0, 39, '1623'),
	(377, 1, 0, -50553, 1625, 0, 0, 39, '1624'),
	(377, 1, 0, -50553, 1626, 0, 0, 39, '1625'),
	(377, 1, 0, -50553, 1627, 0, 0, 39, '1626'),
	(377, 1, 0, -50553, 1628, 0, 0, 39, '1627'),
	(377, 1, 0, -50553, 1629, 0, 0, 39, '1628'),
	(377, 1, 0, -50553, 1630, 0, 0, 39, '1629'),
	(377, 1, 0, -50553, 1631, 0, 0, 39, '1630'),
	(377, 1, 0, -50553, 1632, 0, 0, 39, '1631'),
	(377, 1, 0, -50553, 1633, 0, 0, 39, '1632'),
	(377, 1, 0, -50553, 1634, 0, 0, 39, '1633'),
	(377, 1, 0, -50553, 1635, 0, 0, 39, '1634'),
	(377, 1, 0, -50553, 1636, 0, 0, 39, '1635'),
	(377, 1, 0, -50553, 1637, 0, 0, 39, '1636'),
	(377, 1, 0, -50553, 1638, 0, 0, 39, '1637'),
	(377, 1, 0, -50553, 1639, 0, 0, 39, '1638'),
	(377, 1, 0, -50553, 1640, 0, 0, 39, '1639'),
	(377, 1, 0, -50553, 1641, 0, 0, 39, '1640'),
	(377, 1, 0, -50553, 1642, 0, 0, 39, '1641'),
	(377, 1, 0, -50553, 1643, 0, 0, 39, '1642'),
	(377, 1, 0, -50553, 1644, 0, 0, 39, '1643'),
	(377, 1, 0, -50553, 1645, 0, 0, 39, '1644'),
	(377, 1, 0, -50553, 1646, 0, 0, 39, '1645'),
	(377, 1, 0, -50553, 1647, 0, 0, 39, '1646'),
	(377, 1, 0, -50553, 1648, 0, 0, 39, '1647'),
	(377, 1, 0, -50553, 1649, 0, 0, 39, '1648'),
	(377, 1, 0, -50553, 1650, 0, 0, 39, '1649'),
	(377, 1, 0, -50553, 1651, 0, 0, 39, '1650'),
	(377, 1, 0, -50553, 1652, 0, 0, 39, '1651'),
	(377, 1, 0, -50553, 1653, 0, 0, 39, '1652'),
	(377, 1, 0, -50553, 1654, 0, 0, 39, '1653'),
	(377, 1, 0, -50553, 1655, 0, 0, 39, '1654'),
	(377, 1, 0, -50553, 1656, 0, 0, 39, '1655'),
	(377, 1, 0, -50553, 1657, 0, 0, 39, '1656'),
	(377, 1, 0, -50553, 1658, 0, 0, 39, '1657'),
	(377, 1, 0, -50553, 1659, 0, 0, 39, '1658'),
	(377, 1, 0, -50553, 1660, 0, 0, 39, '1659'),
	(377, 1, 0, -50553, 1661, 0, 0, 39, '1660'),
	(377, 1, 0, -50553, 1662, 0, 0, 39, '1661'),
	(377, 1, 0, -50553, 1663, 0, 0, 39, '1662'),
	(377, 1, 0, -50553, 1664, 0, 0, 39, '1663'),
	(377, 1, 0, -50553, 1665, 0, 0, 39, '1664'),
	(377, 1, 0, -50553, 1666, 0, 0, 39, '1665'),
	(377, 1, 0, -50553, 1667, 0, 0, 39, '1666'),
	(377, 1, 0, -50553, 1668, 0, 0, 39, '1667'),
	(377, 1, 0, -50553, 1669, 0, 0, 39, '1668'),
	(377, 1, 0, -50553, 1670, 0, 0, 39, '1669'),
	(377, 1, 0, -50553, 1671, 0, 0, 39, '1670'),
	(377, 1, 0, -50553, 1672, 0, 0, 39, '1671'),
	(377, 1, 0, -50553, 1673, 0, 0, 39, '1672'),
	(377, 1, 0, -50553, 1674, 0, 0, 39, '1673'),
	(377, 1, 0, -50553, 1675, 0, 0, 39, '1674'),
	(377, 1, 0, -50553, 1676, 0, 0, 39, '1675'),
	(377, 1, 0, -50553, 1677, 0, 0, 39, '1676'),
	(377, 1, 0, -50553, 1678, 0, 0, 39, '1677'),
	(377, 1, 0, -50553, 1679, 0, 0, 39, '1678'),
	(377, 1, 0, -50553, 1680, 0, 0, 39, '1679'),
	(377, 1, 0, -50553, 1681, 0, 0, 39, '1680'),
	(377, 1, 0, -50553, 1682, 0, 0, 39, '1681'),
	(377, 1, 0, -50553, 1683, 0, 0, 39, '1682'),
	(377, 1, 0, -50553, 1684, 0, 0, 39, '1683'),
	(377, 1, 0, -50553, 1685, 0, 0, 39, '1684'),
	(377, 1, 0, -50553, 1686, 0, 0, 39, '1685'),
	(377, 1, 0, -50553, 1687, 0, 0, 39, '1686'),
	(377, 1, 0, -50553, 1688, 0, 0, 39, '1687'),
	(377, 1, 0, -50553, 1689, 0, 0, 39, '1688'),
	(377, 1, 0, -50553, 1690, 0, 0, 39, '1689'),
	(377, 1, 0, -50553, 1691, 0, 0, 39, '1690'),
	(377, 1, 0, -50553, 1692, 0, 0, 39, '1691'),
	(377, 1, 0, -50553, 1693, 0, 0, 39, '1692'),
	(377, 1, 0, -50553, 1694, 0, 0, 39, '1693'),
	(377, 1, 0, -50553, 1695, 0, 0, 39, '1694'),
	(377, 1, 0, -50553, 1696, 0, 0, 39, '1695'),
	(377, 1, 0, -50553, 1697, 0, 0, 39, '1696'),
	(377, 1, 0, -50553, 1698, 0, 0, 39, '1697'),
	(377, 1, 0, -50553, 1699, 0, 0, 39, '1698'),
	(377, 1, 0, -50553, 1700, 0, 0, 39, '1699'),
	(377, 1, 0, -50553, 1701, 0, 0, 39, '1700'),
	(377, 1, 0, -50553, 1702, 0, 0, 39, '1701'),
	(377, 1, 0, -50553, 1703, 0, 0, 39, '1702'),
	(377, 1, 0, -50553, 1704, 0, 0, 39, '1703'),
	(377, 1, 0, -50553, 1705, 0, 0, 39, '1704'),
	(377, 1, 0, -50553, 1706, 0, 0, 39, '1705'),
	(377, 1, 0, -50553, 1707, 0, 0, 39, '1706'),
	(377, 1, 0, -50553, 1708, 0, 0, 39, '1707'),
	(377, 1, 0, -50553, 1709, 0, 0, 39, '1708'),
	(377, 1, 0, -50553, 1710, 0, 0, 39, '1709'),
	(377, 1, 0, -50553, 1711, 0, 0, 39, '1710'),
	(377, 1, 0, -50553, 1712, 0, 0, 39, '1711'),
	(377, 1, 0, -50553, 1713, 0, 0, 39, '1712'),
	(377, 1, 0, -50553, 1714, 0, 0, 39, '1713'),
	(377, 1, 0, -50553, 1715, 0, 0, 39, '1714'),
	(377, 1, 0, -50553, 1716, 0, 0, 39, '1715'),
	(377, 1, 0, -50553, 1717, 0, 0, 39, '1716'),
	(377, 1, 0, -50553, 1718, 0, 0, 39, '1717'),
	(377, 1, 0, -50553, 1719, 0, 0, 39, '1718'),
	(377, 1, 0, -50553, 1720, 0, 0, 39, '1719'),
	(377, 1, 0, -50553, 1721, 0, 0, 39, '1720'),
	(377, 1, 0, -50553, 1722, 0, 0, 39, '1721'),
	(377, 1, 0, -50553, 1723, 0, 0, 39, '1722'),
	(377, 1, 0, -50553, 1724, 0, 0, 39, '1723'),
	(377, 1, 0, -50553, 1725, 0, 0, 39, '1724'),
	(377, 1, 0, -50553, 1726, 0, 0, 39, '1725'),
	(377, 1, 0, -50553, 1727, 0, 0, 39, '1726'),
	(377, 1, 0, -50553, 1728, 0, 0, 39, '1727'),
	(377, 1, 0, -50553, 1729, 0, 0, 39, '1728'),
	(377, 1, 0, -50553, 1730, 0, 0, 39, '1729'),
	(377, 1, 0, -50553, 1731, 0, 0, 39, '1730'),
	(377, 1, 0, -50553, 1732, 0, 0, 39, '1731'),
	(377, 1, 0, -50553, 1733, 0, 0, 39, '1732'),
	(377, 1, 0, -50553, 1734, 0, 0, 39, '1733'),
	(377, 1, 0, -50553, 1735, 0, 0, 39, '1734'),
	(377, 1, 0, -50553, 1736, 0, 0, 39, '1735'),
	(377, 1, 0, -50553, 1737, 0, 0, 39, '1736'),
	(377, 1, 0, -50553, 1738, 0, 0, 39, '1737'),
	(377, 1, 0, -50553, 1739, 0, 0, 39, '1738'),
	(377, 1, 0, -50553, 1740, 0, 0, 39, '1739'),
	(377, 1, 0, -50553, 1741, 0, 0, 39, '1740'),
	(377, 1, 0, -50553, 1742, 0, 0, 39, '1741'),
	(377, 1, 0, -50553, 1743, 0, 0, 39, '1742'),
	(377, 1, 0, -50553, 1744, 0, 0, 39, '1743'),
	(377, 1, 0, -50553, 1745, 0, 0, 39, '1744'),
	(377, 1, 0, -50553, 1746, 0, 0, 39, '1745'),
	(377, 1, 0, -50553, 1747, 0, 0, 39, '1746'),
	(377, 1, 0, -50553, 1748, 0, 0, 39, '1747'),
	(377, 1, 0, -50553, 1749, 0, 0, 39, '1748'),
	(377, 1, 0, -50553, 1750, 0, 0, 39, '1749'),
	(377, 1, 0, -50553, 1751, 0, 0, 39, '1750'),
	(377, 1, 0, -50553, 1752, 0, 0, 39, '1751'),
	(377, 1, 0, -50553, 1753, 0, 0, 39, '1752'),
	(377, 1, 0, -50553, 1754, 0, 0, 39, '1753'),
	(377, 1, 0, -50553, 1755, 0, 0, 39, '1754'),
	(377, 1, 0, -50553, 1756, 0, 0, 39, '1755'),
	(377, 1, 0, -50553, 1757, 0, 0, 39, '1756'),
	(377, 1, 0, -50553, 1758, 0, 0, 39, '1757'),
	(377, 1, 0, -50553, 1759, 0, 0, 39, '1758'),
	(377, 1, 0, -50553, 1760, 0, 0, 39, '1759'),
	(377, 1, 0, -50553, 1761, 0, 0, 39, '1760'),
	(377, 1, 0, -50553, 1762, 0, 0, 39, '1761'),
	(377, 1, 0, -50553, 1763, 0, 0, 39, '1762'),
	(377, 1, 0, -50553, 1764, 0, 0, 39, '1763'),
	(377, 1, 0, -50553, 1765, 0, 0, 39, '1764'),
	(377, 1, 0, -50553, 1766, 0, 0, 39, '1765'),
	(377, 1, 0, -50553, 1767, 0, 0, 39, '1766'),
	(377, 1, 0, -50553, 1768, 0, 0, 39, '1767'),
	(377, 1, 0, -50553, 1769, 0, 0, 39, '1768'),
	(377, 1, 0, -50553, 1770, 0, 0, 39, '1769'),
	(377, 1, 0, -50553, 1771, 0, 0, 39, '1770'),
	(377, 1, 0, -50553, 1772, 0, 0, 39, '1771'),
	(377, 1, 0, -50553, 1773, 0, 0, 39, '1772'),
	(377, 1, 0, -50553, 1774, 0, 0, 39, '1773'),
	(377, 1, 0, -50553, 1775, 0, 0, 39, '1774'),
	(377, 1, 0, -50553, 1776, 0, 0, 39, '1775'),
	(377, 1, 0, -50553, 1777, 0, 0, 39, '1776'),
	(377, 1, 0, -50553, 1778, 0, 0, 39, '1777'),
	(377, 1, 0, -50553, 1779, 0, 0, 39, '1778'),
	(377, 1, 0, -50553, 1780, 0, 0, 39, '1779'),
	(377, 1, 0, -50553, 1781, 0, 0, 39, '1780'),
	(377, 1, 0, -50553, 1782, 0, 0, 39, '1781'),
	(377, 1, 0, -50553, 1783, 0, 0, 39, '1782'),
	(377, 1, 0, -50553, 1784, 0, 0, 39, '1783'),
	(377, 1, 0, -50553, 1785, 0, 0, 39, '1784'),
	(377, 1, 0, -50553, 1786, 0, 0, 39, '1785'),
	(377, 1, 0, -50553, 1787, 0, 0, 39, '1786'),
	(377, 1, 0, -50553, 1788, 0, 0, 39, '1787'),
	(377, 1, 0, -50553, 1789, 0, 0, 39, '1788'),
	(377, 1, 0, -50553, 1790, 0, 0, 39, '1789'),
	(377, 1, 0, -50553, 1791, 0, 0, 39, '1790'),
	(377, 1, 0, -50553, 1792, 0, 0, 39, '1791'),
	(377, 1, 0, -50553, 1793, 0, 0, 39, '1792'),
	(377, 1, 0, -50553, 1794, 0, 0, 39, '1793'),
	(377, 1, 0, -50553, 1795, 0, 0, 39, '1794'),
	(377, 1, 0, -50553, 1796, 0, 0, 39, '1795'),
	(377, 1, 0, -50553, 1797, 0, 0, 39, '1796'),
	(377, 1, 0, -50553, 1798, 0, 0, 39, '1797'),
	(377, 1, 0, -50553, 1799, 0, 0, 39, '1798'),
	(377, 1, 0, -50553, 1800, 0, 0, 39, '1799'),
	(377, 1, 0, -50553, 1801, 0, 0, 39, '1800'),
	(377, 1, 0, -50553, 1802, 0, 0, 39, '1801'),
	(377, 1, 0, -50553, 1803, 0, 0, 39, '1802'),
	(377, 1, 0, -50553, 1804, 0, 0, 39, '1803'),
	(377, 1, 0, -50553, 1805, 0, 0, 39, '1804'),
	(377, 1, 0, -50553, 1806, 0, 0, 39, '1805'),
	(377, 1, 0, -50553, 1807, 0, 0, 39, '1806'),
	(377, 1, 0, -50553, 1808, 0, 0, 39, '1807'),
	(377, 1, 0, -50553, 1809, 0, 0, 39, '1808'),
	(377, 1, 0, -50553, 1810, 0, 0, 39, '1809'),
	(377, 1, 0, -50553, 1811, 0, 0, 39, '1810'),
	(377, 1, 0, -50553, 1812, 0, 0, 39, '1811'),
	(377, 1, 0, -50553, 1813, 0, 0, 39, '1812'),
	(377, 1, 0, -50553, 1814, 0, 0, 39, '1813'),
	(377, 1, 0, -50553, 1815, 0, 0, 39, '1814'),
	(377, 1, 0, -50553, 1816, 0, 0, 39, '1815'),
	(377, 1, 0, -50553, 1817, 0, 0, 39, '1816'),
	(377, 1, 0, -50553, 1818, 0, 0, 39, '1817'),
	(377, 1, 0, -50553, 1819, 0, 0, 39, '1818'),
	(377, 1, 0, -50553, 1820, 0, 0, 39, '1819'),
	(377, 1, 0, -50553, 1821, 0, 0, 39, '1820'),
	(377, 1, 0, -50553, 1822, 0, 0, 39, '1821'),
	(377, 1, 0, -50553, 1823, 0, 0, 39, '1822'),
	(377, 1, 0, -50553, 1824, 0, 0, 39, '1823'),
	(377, 1, 0, -50553, 1825, 0, 0, 39, '1824'),
	(377, 1, 0, -50553, 1826, 0, 0, 39, '1825'),
	(377, 1, 0, -50553, 1827, 0, 0, 39, '1826'),
	(377, 1, 0, -50553, 1828, 0, 0, 39, '1827'),
	(377, 1, 0, -50553, 1829, 0, 0, 39, '1828'),
	(377, 1, 0, -50553, 1830, 0, 0, 39, '1829'),
	(377, 1, 0, -50553, 1831, 0, 0, 39, '1830'),
	(377, 1, 0, -50553, 1832, 0, 0, 39, '1831'),
	(377, 1, 0, -50553, 1833, 0, 0, 39, '1832'),
	(377, 1, 0, -50553, 1834, 0, 0, 39, '1833'),
	(377, 1, 0, -50553, 1835, 0, 0, 39, '1834'),
	(377, 1, 0, -50553, 1836, 0, 0, 39, '1835'),
	(377, 1, 0, -50553, 1837, 0, 0, 39, '1836'),
	(377, 1, 0, -50553, 1838, 0, 0, 39, '1837'),
	(377, 1, 0, -50553, 1839, 0, 0, 39, '1838'),
	(377, 1, 0, -50553, 1840, 0, 0, 39, '1839'),
	(377, 1, 0, -50553, 1841, 0, 0, 39, '1840'),
	(377, 1, 0, -50553, 1842, 0, 0, 39, '1841'),
	(377, 1, 0, -50553, 1843, 0, 0, 39, '1842'),
	(377, 1, 0, -50553, 1844, 0, 0, 39, '1843'),
	(377, 1, 0, -50553, 1845, 0, 0, 39, '1844'),
	(377, 1, 0, -50553, 1846, 0, 0, 39, '1845'),
	(377, 1, 0, -50553, 1847, 0, 0, 39, '1846'),
	(377, 1, 0, -50553, 1848, 0, 0, 39, '1847'),
	(377, 1, 0, -50553, 1849, 0, 0, 39, '1848'),
	(377, 1, 0, -50553, 1850, 0, 0, 39, '1849'),
	(377, 1, 0, -50553, 1851, 0, 0, 39, '1850'),
	(377, 1, 0, -50553, 1852, 0, 0, 39, '1851'),
	(377, 1, 0, -50553, 1853, 0, 0, 39, '1852'),
	(377, 1, 0, -50553, 1854, 0, 0, 39, '1853'),
	(377, 1, 0, -50553, 1855, 0, 0, 39, '1854'),
	(377, 1, 0, -50553, 1856, 0, 0, 39, '1855'),
	(377, 1, 0, -50553, 1857, 0, 0, 39, '1856'),
	(377, 1, 0, -50553, 1858, 0, 0, 39, '1857'),
	(377, 1, 0, -50553, 1859, 0, 0, 39, '1858'),
	(377, 1, 0, -50553, 1860, 0, 0, 39, '1859'),
	(377, 1, 0, -50553, 1861, 0, 0, 39, '1860'),
	(377, 1, 0, -50553, 1862, 0, 0, 39, '1861'),
	(377, 1, 0, -50553, 1863, 0, 0, 39, '1862'),
	(377, 1, 0, -50553, 1864, 0, 0, 39, '1863'),
	(377, 1, 0, -50553, 1865, 0, 0, 39, '1864'),
	(377, 1, 0, -50553, 1866, 0, 0, 39, '1865'),
	(377, 1, 0, -50553, 1867, 0, 0, 39, '1866'),
	(377, 1, 0, -50553, 1868, 0, 0, 39, '1867'),
	(377, 1, 0, -50553, 1869, 0, 0, 39, '1868'),
	(377, 1, 0, -50553, 1870, 0, 0, 39, '1869'),
	(377, 1, 0, -50553, 1871, 0, 0, 39, '1870'),
	(377, 1, 0, -50553, 1872, 0, 0, 39, '1871'),
	(377, 1, 0, -50553, 1873, 0, 0, 39, '1872'),
	(377, 1, 0, -50553, 1874, 0, 0, 39, '1873'),
	(377, 1, 0, -50553, 1875, 0, 0, 39, '1874'),
	(377, 1, 0, -50553, 1876, 0, 0, 39, '1875'),
	(377, 1, 0, -50553, 1877, 0, 0, 39, '1876'),
	(377, 1, 0, -50553, 1878, 0, 0, 39, '1877'),
	(377, 1, 0, -50553, 1879, 0, 0, 39, '1878'),
	(377, 1, 0, -50553, 1880, 0, 0, 39, '1879'),
	(377, 1, 0, -50553, 1881, 0, 0, 39, '1880'),
	(377, 1, 0, -50553, 1882, 0, 0, 39, '1881'),
	(377, 1, 0, -50553, 1883, 0, 0, 39, '1882'),
	(377, 1, 0, -50553, 1884, 0, 0, 39, '1883'),
	(377, 1, 0, -50553, 1885, 0, 0, 39, '1884'),
	(377, 1, 0, -50553, 1886, 0, 0, 39, '1885'),
	(377, 1, 0, -50553, 1887, 0, 0, 39, '1886'),
	(377, 1, 0, -50553, 1888, 0, 0, 39, '1887'),
	(377, 1, 0, -50553, 1889, 0, 0, 39, '1888'),
	(377, 1, 0, -50553, 1890, 0, 0, 39, '1889'),
	(377, 1, 0, -50553, 1891, 0, 0, 39, '1890'),
	(377, 1, 0, -50553, 1892, 0, 0, 39, '1891'),
	(377, 1, 0, -50553, 1893, 0, 0, 39, '1892'),
	(377, 1, 0, -50553, 1894, 0, 0, 39, '1893'),
	(377, 1, 0, -50553, 1895, 0, 0, 39, '1894'),
	(377, 1, 0, -50553, 1896, 0, 0, 39, '1895'),
	(377, 1, 0, -50553, 1897, 0, 0, 39, '1896'),
	(377, 1, 0, -50553, 1898, 0, 0, 39, '1897'),
	(377, 1, 0, -50553, 1899, 0, 0, 39, '1898'),
	(377, 1, 0, -50553, 1900, 0, 0, 39, '1899'),
	(377, 1, 0, -50553, 1901, 0, 0, 39, '1900'),
	(377, 1, 0, -50553, 1902, 0, 0, 39, '1901'),
	(377, 1, 0, -50553, 1903, 0, 0, 39, '1902'),
	(377, 1, 0, -50553, 1904, 0, 0, 39, '1903'),
	(377, 1, 0, -50553, 1905, 0, 0, 39, '1904'),
	(377, 1, 0, -50553, 1906, 0, 0, 39, '1905'),
	(377, 1, 0, -50553, 1907, 0, 0, 39, '1906'),
	(377, 1, 0, -50553, 1908, 0, 0, 39, '1907'),
	(377, 1, 0, -50553, 1909, 0, 0, 39, '1908'),
	(377, 1, 0, -50553, 1910, 0, 0, 39, '1909'),
	(377, 1, 0, -50553, 1911, 0, 0, 39, '1910'),
	(377, 1, 0, -50553, 1912, 0, 0, 39, '1911'),
	(377, 1, 0, -50553, 1913, 0, 0, 39, '1912'),
	(377, 1, 0, -50553, 1914, 0, 0, 39, '1913'),
	(377, 1, 0, -50553, 1915, 0, 0, 39, '1914'),
	(377, 1, 0, -50553, 1916, 0, 0, 39, '1915'),
	(377, 1, 0, -50553, 1917, 0, 0, 39, '1916'),
	(377, 1, 0, -50553, 1918, 0, 0, 39, '1917'),
	(377, 1, 0, -50553, 1919, 0, 0, 39, '1918'),
	(377, 1, 0, -50553, 1920, 0, 0, 39, '1919'),
	(377, 1, 0, -50553, 1921, 0, 0, 39, '1920'),
	(377, 1, 0, -50553, 1922, 0, 0, 39, '1921'),
	(377, 1, 0, -50553, 1923, 0, 0, 39, '1922'),
	(377, 1, 0, -50553, 1924, 0, 0, 39, '1923'),
	(377, 1, 0, -50553, 1925, 0, 0, 39, '1924'),
	(377, 1, 0, -50553, 1926, 0, 0, 39, '1925'),
	(377, 1, 0, -50553, 1927, 0, 0, 39, '1926'),
	(377, 1, 0, -50553, 1928, 0, 0, 39, '1927'),
	(377, 1, 0, -50553, 1929, 0, 0, 39, '1928'),
	(377, 1, 0, -50553, 1930, 0, 0, 39, '1929'),
	(377, 1, 0, -50553, 1931, 0, 0, 39, '1930'),
	(377, 1, 0, -50553, 1932, 0, 0, 39, '1931'),
	(377, 1, 0, -50553, 1933, 0, 0, 39, '1932'),
	(377, 1, 0, -50553, 1934, 0, 0, 39, '1933'),
	(377, 1, 0, -50553, 1935, 0, 0, 39, '1934'),
	(377, 1, 0, -50553, 1936, 0, 0, 39, '1935'),
	(377, 1, 0, -50553, 1937, 0, 0, 39, '1936'),
	(377, 1, 0, -50553, 1938, 0, 0, 39, '1937'),
	(377, 1, 0, -50553, 1939, 0, 0, 39, '1938'),
	(377, 1, 0, -50553, 1940, 0, 0, 39, '1939'),
	(377, 1, 0, -50553, 1941, 0, 0, 39, '1940'),
	(377, 1, 0, -50553, 1942, 0, 0, 39, '1941'),
	(377, 1, 0, -50553, 1943, 0, 0, 39, '1942'),
	(377, 1, 0, -50553, 1944, 0, 0, 39, '1943'),
	(377, 1, 0, -50553, 1945, 0, 0, 39, '1944'),
	(377, 1, 0, -50553, 1946, 0, 0, 39, '1945'),
	(377, 1, 0, -50553, 1947, 0, 0, 39, '1946'),
	(377, 1, 0, -50553, 1948, 0, 0, 39, '1947'),
	(377, 1, 0, -50553, 1949, 0, 0, 39, '1948'),
	(377, 1, 0, -50553, 1950, 0, 0, 39, '1949'),
	(377, 1, 0, -50553, 1951, 0, 0, 39, '1950'),
	(377, 1, 0, -50553, 1952, 0, 0, 39, '1951'),
	(377, 1, 0, -50553, 1953, 0, 0, 39, '1952'),
	(377, 1, 0, -50553, 1954, 0, 0, 39, '1953'),
	(377, 1, 0, -50553, 1955, 0, 0, 39, '1954'),
	(377, 1, 0, -50553, 1956, 0, 0, 39, '1955'),
	(377, 1, 0, -50553, 1957, 0, 0, 39, '1956'),
	(377, 1, 0, -50553, 1958, 0, 0, 39, '1957'),
	(377, 1, 0, -50553, 1959, 0, 0, 39, '1958'),
	(377, 1, 0, -50553, 1960, 0, 0, 39, '1959'),
	(377, 1, 0, -50553, 1961, 0, 0, 39, '1960'),
	(377, 1, 0, -50553, 1962, 0, 0, 39, '1961'),
	(377, 1, 0, -50553, 1963, 0, 0, 39, '1962'),
	(377, 1, 0, -50553, 1964, 0, 0, 39, '1963'),
	(377, 1, 0, -50553, 1965, 0, 0, 39, '1964'),
	(377, 1, 0, -50553, 1966, 0, 0, 39, '1965'),
	(377, 1, 0, -50553, 1967, 0, 0, 39, '1966'),
	(377, 1, 0, -50553, 1968, 0, 0, 39, '1967'),
	(377, 1, 0, -50553, 1969, 0, 0, 39, '1968'),
	(377, 1, 0, -50553, 1970, 0, 0, 39, '1969'),
	(377, 1, 0, -50553, 1971, 0, 0, 39, '1970'),
	(377, 1, 0, -50553, 1972, 0, 0, 39, '1971'),
	(377, 1, 0, -50553, 1973, 0, 0, 39, '1972'),
	(377, 1, 0, -50553, 1974, 0, 0, 39, '1973'),
	(377, 1, 0, -50553, 1975, 0, 0, 39, '1974'),
	(377, 1, 0, -50553, 1976, 0, 0, 39, '1975'),
	(377, 1, 0, -50553, 1977, 0, 0, 39, '1976'),
	(377, 1, 0, -50553, 1978, 0, 0, 39, '1977'),
	(377, 1, 0, -50553, 1979, 0, 0, 39, '1978'),
	(377, 1, 0, -50553, 1980, 0, 0, 39, '1979'),
	(377, 1, 0, -50553, 1981, 0, 0, 39, '1980'),
	(377, 1, 0, -50553, 1982, 0, 0, 39, '1981'),
	(377, 1, 0, -50553, 1983, 0, 0, 39, '1982'),
	(377, 1, 0, -50553, 1984, 0, 0, 39, '1983'),
	(377, 1, 0, -50553, 1985, 0, 0, 39, '1984'),
	(377, 1, 0, -50553, 1986, 0, 0, 39, '1985'),
	(377, 1, 0, -50553, 1987, 0, 0, 39, '1986'),
	(377, 1, 0, -50553, 1988, 0, 0, 39, '1987'),
	(377, 1, 0, -50553, 1989, 0, 0, 39, '1988'),
	(377, 1, 0, -50553, 1990, 0, 0, 39, '1989'),
	(377, 1, 0, -50553, 1991, 0, 0, 39, '1990'),
	(377, 1, 0, -50553, 1992, 0, 0, 39, '1991'),
	(377, 1, 0, -50553, 1993, 0, 0, 39, '1992'),
	(377, 1, 0, -50553, 1994, 0, 0, 39, '1993'),
	(377, 1, 0, -50553, 1995, 0, 0, 39, '1994'),
	(377, 1, 0, -50553, 1996, 0, 0, 39, '1995'),
	(377, 1, 0, -50553, 1997, 0, 0, 39, '1996'),
	(377, 1, 0, -50553, 1998, 0, 0, 39, '1997'),
	(377, 1, 0, -50553, 1999, 0, 0, 39, '1998'),
	(377, 1, 0, -50553, 2000, 0, 0, 39, '1999'),
	(377, 1, 0, -50553, 2001, 0, 0, 39, '2000'),
	(377, 1, 0, -50553, 2002, 0, 0, 39, '2001'),
	(377, 1, 0, -50553, 2003, 0, 0, 39, '2002'),
	(377, 1, 0, -50553, 2004, 0, 0, 39, '2003'),
	(377, 1, 0, -50553, 2005, 0, 0, 39, '2004'),
	(377, 1, 0, -50553, 2006, 0, 0, 39, '2005'),
	(377, 1, 0, -50553, 2007, 0, 0, 39, '2006'),
	(377, 1, 0, -50553, 2008, 0, 0, 39, '2007'),
	(377, 1, 0, -50553, 2009, 0, 0, 39, '2008'),
	(377, 1, 0, -50553, 2010, 0, 0, 39, '2009'),
	(377, 1, 0, -50553, 2011, 0, 0, 39, '2010'),
	(377, 1, 0, -50553, 2012, 0, 0, 39, '2011'),
	(377, 1, 0, -50553, 2013, 0, 0, 39, '2012'),
	(377, 1, 0, -50553, 2014, 0, 0, 39, '2013'),
	(377, 1, 0, -50553, 2015, 0, 0, 39, '2014'),
	(377, 1, 0, -50553, 2016, 0, 0, 39, '2015'),
	(377, 1, 0, -50553, 2017, 0, 0, 39, '2016'),
	(377, 1, 0, -50553, 2018, 0, 0, 39, '2017'),
	(377, 1, 0, -50553, 2019, 0, 0, 39, '2018'),
	(377, 1, 0, -50553, 2020, 0, 0, 39, '2019'),
	(377, 1, 0, -50553, 2021, 0, 0, 39, '2020'),
	(377, 1, 0, -50553, 2022, 0, 0, 39, '2021'),
	(377, 1, 0, -50553, 2023, 0, 0, 39, '2022'),
	(377, 1, 0, -50553, 2024, 0, 0, 39, '2023'),
	(377, 1, 0, -50553, 2025, 0, 0, 39, '2024'),
	(377, 1, 0, -50553, 2026, 0, 0, 39, '2025'),
	(377, 1, 0, -50553, 2027, 0, 0, 39, '2026'),
	(377, 1, 0, -50553, 2028, 0, 0, 39, '2027'),
	(377, 1, 0, -50553, 2029, 0, 0, 39, '2028'),
	(377, 1, 0, -50553, 2030, 0, 0, 39, '2029'),
	(377, 1, 0, -50553, 2031, 0, 0, 39, '2030'),
	(377, 1, 0, -50553, 2032, 0, 0, 39, '2031'),
	(377, 1, 0, -50553, 2033, 0, 0, 39, '2032'),
	(377, 1, 0, -50553, 2034, 0, 0, 39, '2033'),
	(377, 1, 0, -50553, 2035, 0, 0, 39, '2034'),
	(377, 1, 0, -50553, 2036, 0, 0, 39, '2035'),
	(377, 1, 0, -50553, 2037, 0, 0, 39, '2036'),
	(377, 1, 0, -50553, 2038, 0, 0, 39, '2037'),
	(377, 1, 0, -50553, 2039, 0, 0, 39, '2038'),
	(377, 1, 0, -50553, 2040, 0, 0, 39, '2039'),
	(377, 1, 0, -50553, 2041, 0, 0, 39, '2040'),
	(377, 1, 0, -50553, 2042, 0, 0, 39, '2041'),
	(377, 1, 0, -50553, 2043, 0, 0, 39, '2042'),
	(377, 1, 0, -50553, 2044, 0, 0, 39, '2043'),
	(377, 1, 0, -50553, 2045, 0, 0, 39, '2044'),
	(377, 1, 0, -50553, 2046, 0, 0, 39, '2045'),
	(377, 1, 0, -50553, 2047, 0, 0, 39, '2046'),
	(377, 1, 0, -50553, 2048, 0, 0, 39, '2047'),
	(377, 1, 0, -50553, 2049, 0, 0, 39, '2048'),
	(377, 1, 0, -50553, 2050, 0, 0, 39, '2049'),
	(377, 1, 0, -50553, 2051, 0, 0, 39, '2050'),
	(377, 1, 0, -50553, 2052, 0, 0, 39, '2051'),
	(377, 1, 0, -50553, 2053, 0, 0, 39, '2052'),
	(377, 1, 0, -50553, 2054, 0, 0, 39, '2053'),
	(377, 1, 0, -50553, 2055, 0, 0, 39, '2054'),
	(377, 1, 0, -50553, 2056, 0, 0, 39, '2055'),
	(377, 1, 0, -50553, 2057, 0, 0, 39, '2056'),
	(377, 1, 0, -50553, 2058, 0, 0, 39, '2057'),
	(377, 1, 0, -50553, 2059, 0, 0, 39, '2058'),
	(377, 1, 0, -50553, 2060, 0, 0, 39, '2059'),
	(377, 1, 0, -50553, 2061, 0, 0, 39, '2060'),
	(377, 1, 0, -50553, 2062, 0, 0, 39, '2061'),
	(377, 1, 0, -50553, 2063, 0, 0, 39, '2062'),
	(377, 1, 0, -50553, 2064, 0, 0, 39, '2063'),
	(377, 1, 0, -50553, 2065, 0, 0, 39, '2064'),
	(377, 1, 0, -50553, 2066, 0, 0, 39, '2065'),
	(377, 1, 0, -50553, 2067, 0, 0, 39, '2066'),
	(377, 1, 0, -50553, 2068, 0, 0, 39, '2067'),
	(377, 1, 0, -50553, 2069, 0, 0, 39, '2068'),
	(377, 1, 0, -50553, 2070, 0, 0, 39, '2069'),
	(377, 1, 0, -50553, 2071, 0, 0, 39, '2070'),
	(377, 1, 0, -50553, 2072, 0, 0, 39, '2071'),
	(377, 1, 0, -50553, 2073, 0, 0, 39, '2072'),
	(377, 1, 0, -50553, 2074, 0, 0, 39, '2073'),
	(377, 1, 0, -50553, 2075, 0, 0, 39, '2074'),
	(377, 1, 0, -50553, 2076, 0, 0, 39, '2075'),
	(377, 1, 0, -50553, 2077, 0, 0, 39, '2076'),
	(377, 1, 0, -50553, 2078, 0, 0, 39, '2077'),
	(377, 1, 0, -50553, 2079, 0, 0, 39, '2078'),
	(377, 1, 0, -50553, 2080, 0, 0, 39, '2079'),
	(377, 1, 0, -50553, 2081, 0, 0, 39, '2080'),
	(377, 1, 0, -50553, 2082, 0, 0, 39, '2081'),
	(377, 1, 0, -50553, 2083, 0, 0, 39, '2082'),
	(377, 1, 0, -50553, 2084, 0, 0, 39, '2083'),
	(377, 1, 0, -50553, 2085, 0, 0, 39, '2084'),
	(377, 1, 0, -50553, 2086, 0, 0, 39, '2085'),
	(377, 1, 0, -50553, 2087, 0, 0, 39, '2086'),
	(377, 1, 0, -50553, 2088, 0, 0, 39, '2087'),
	(377, 1, 0, -50553, 2089, 0, 0, 39, '2088'),
	(377, 1, 0, -50553, 2090, 0, 0, 39, '2089'),
	(377, 1, 0, -50553, 2091, 0, 0, 39, '2090'),
	(377, 1, 0, -50553, 2092, 0, 0, 39, '2091'),
	(377, 1, 0, -50553, 2093, 0, 0, 39, '2092'),
	(377, 1, 0, -50553, 2094, 0, 0, 39, '2093'),
	(377, 1, 0, -50553, 2095, 0, 0, 39, '2094'),
	(377, 1, 0, -50553, 2096, 0, 0, 39, '2095'),
	(377, 1, 0, -50553, 2097, 0, 0, 39, '2096'),
	(377, 1, 0, -50553, 2098, 0, 0, 39, '2097'),
	(377, 1, 0, -50553, 2099, 0, 0, 39, '2098'),
	(377, 1, 0, -50553, 2100, 0, 0, 39, '2099'),
	(377, 1, 0, -50553, 2101, 0, 0, 39, '2100'),
	(377, 1, 0, -50553, 2102, 0, 0, 39, '2101'),
	(377, 1, 0, -50553, 2103, 0, 0, 39, '2102'),
	(377, 1, 0, -50553, 2104, 0, 0, 39, '2103'),
	(377, 1, 0, -50553, 2105, 0, 0, 39, '2104'),
	(377, 1, 0, -50553, 2106, 0, 0, 39, '2105'),
	(377, 1, 0, -50553, 2107, 0, 0, 39, '2106'),
	(377, 1, 0, -50553, 2108, 0, 0, 39, '2107'),
	(377, 1, 0, -50553, 2109, 0, 0, 39, '2108'),
	(377, 1, 0, -50553, 2110, 0, 0, 39, '2109'),
	(377, 1, 0, -50553, 2111, 0, 0, 39, '2110'),
	(377, 1, 0, -50553, 2112, 0, 0, 39, '2111'),
	(377, 1, 0, -50553, 2113, 0, 0, 39, '2112'),
	(377, 1, 0, -50553, 2114, 0, 0, 39, '2113'),
	(377, 1, 0, -50553, 2115, 0, 0, 39, '2114'),
	(377, 1, 0, -50553, 2116, 0, 0, 39, '2115'),
	(377, 1, 0, -50553, 2117, 0, 0, 39, '2116'),
	(377, 1, 0, -50553, 2118, 0, 0, 39, '2117'),
	(377, 1, 0, -50553, 2119, 0, 0, 39, '2118'),
	(377, 1, 0, -50553, 2120, 0, 0, 39, '2119'),
	(377, 1, 0, -50553, 2121, 0, 0, 39, '2120'),
	(377, 1, 0, -50553, 2122, 0, 0, 39, '2121'),
	(377, 1, 0, -50553, 2123, 0, 0, 39, '2122'),
	(377, 1, 0, -50553, 2124, 0, 0, 39, '2123'),
	(377, 1, 0, -50553, 2125, 0, 0, 39, '2124'),
	(377, 1, 0, -50553, 2126, 0, 0, 39, '2125'),
	(377, 1, 0, -50553, 2127, 0, 0, 39, '2126'),
	(377, 1, 0, -50553, 2128, 0, 0, 39, '2127'),
	(377, 1, 0, -50553, 2129, 0, 0, 39, '2128'),
	(377, 1, 0, -50553, 2130, 0, 0, 39, '2129'),
	(377, 1, 0, -50553, 2131, 0, 0, 39, '2130'),
	(377, 1, 0, -50553, 2132, 0, 0, 39, '2131'),
	(377, 1, 0, -50553, 2133, 0, 0, 39, '2132'),
	(377, 1, 0, -50553, 2134, 0, 0, 39, '2133'),
	(377, 1, 0, -50553, 2135, 0, 0, 39, '2134'),
	(377, 1, 0, -50553, 2136, 0, 0, 39, '2135'),
	(377, 1, 0, -50553, 2137, 0, 0, 39, '2136'),
	(377, 1, 0, -50553, 2138, 0, 0, 39, '2137'),
	(377, 1, 0, -50553, 2139, 0, 0, 39, '2138'),
	(377, 1, 0, -50553, 2140, 0, 0, 39, '2139'),
	(377, 1, 0, -50553, 2141, 0, 0, 39, '2140'),
	(377, 1, 0, -50553, 2142, 0, 0, 39, '2141'),
	(377, 1, 0, -50553, 2143, 0, 0, 39, '2142'),
	(377, 1, 0, -50553, 2144, 0, 0, 39, '2143'),
	(377, 1, 0, -50553, 2145, 0, 0, 39, '2144'),
	(377, 1, 0, -50553, 2146, 0, 0, 39, '2145'),
	(377, 1, 0, -50553, 2147, 0, 0, 39, '2146'),
	(377, 1, 0, -50553, 2148, 0, 0, 39, '2147'),
	(377, 1, 0, -50553, 2149, 0, 0, 39, '2148'),
	(377, 1, 0, -50553, 2150, 0, 0, 39, '2149'),
	(377, 1, 0, -50553, 2151, 0, 0, 39, '2150'),
	(377, 1, 0, -50553, 2152, 0, 0, 39, '2151'),
	(377, 1, 0, -50553, 2153, 0, 0, 39, '2152'),
	(377, 1, 0, -50553, 2154, 0, 0, 39, '2153'),
	(377, 1, 0, -50553, 2155, 0, 0, 39, '2154'),
	(377, 1, 0, -50553, 2156, 0, 0, 39, '2155'),
	(377, 1, 0, -50553, 2157, 0, 0, 39, '2156'),
	(377, 1, 0, -50553, 2158, 0, 0, 39, '2157'),
	(377, 1, 0, -50553, 2159, 0, 0, 39, '2158'),
	(377, 1, 0, -50553, 2160, 0, 0, 39, '2159'),
	(377, 1, 0, -50553, 2161, 0, 0, 39, '2160'),
	(377, 1, 0, -50553, 2162, 0, 0, 39, '2161'),
	(377, 1, 0, -50553, 2163, 0, 0, 39, '2162'),
	(377, 1, 0, -50553, 2164, 0, 0, 39, '2163'),
	(377, 1, 0, -50553, 2165, 0, 0, 39, '2164'),
	(377, 1, 0, -50553, 2166, 0, 0, 39, '2165'),
	(377, 1, 0, -50553, 2167, 0, 0, 39, '2166'),
	(377, 1, 0, -50553, 2168, 0, 0, 39, '2167'),
	(377, 1, 0, -50553, 2169, 0, 0, 39, '2168'),
	(377, 1, 0, -50553, 2170, 0, 0, 39, '2169'),
	(377, 1, 0, -50553, 2171, 0, 0, 39, '2170'),
	(377, 1, 0, -50553, 2172, 0, 0, 39, '2171'),
	(377, 1, 0, -50553, 2173, 0, 0, 39, '2172'),
	(377, 1, 0, -50553, 2174, 0, 0, 39, '2173'),
	(377, 1, 0, -50553, 2175, 0, 0, 39, '2174'),
	(377, 1, 0, -50553, 2176, 0, 0, 39, '2175'),
	(377, 1, 0, -50553, 2177, 0, 0, 39, '2176'),
	(377, 1, 0, -50553, 2178, 0, 0, 39, '2177'),
	(377, 1, 0, -50553, 2179, 0, 0, 39, '2178'),
	(377, 1, 0, -50553, 2180, 0, 0, 39, '2179'),
	(377, 1, 0, -50553, 2181, 0, 0, 39, '2180'),
	(377, 1, 0, -50553, 2182, 0, 0, 39, '2181'),
	(377, 1, 0, -50553, 2183, 0, 0, 39, '2182'),
	(377, 1, 0, -50553, 2184, 0, 0, 39, '2183'),
	(377, 1, 0, -50553, 2185, 0, 0, 39, '2184'),
	(377, 1, 0, -50553, 2186, 0, 0, 39, '2185'),
	(377, 1, 0, -50553, 2187, 0, 0, 39, '2186'),
	(377, 1, 0, -50553, 2188, 0, 0, 39, '2187'),
	(377, 1, 0, -50553, 2189, 0, 0, 39, '2188'),
	(377, 1, 0, -50553, 2190, 0, 0, 39, '2189'),
	(377, 1, 0, -50553, 2191, 0, 0, 39, '2190'),
	(377, 1, 0, -50553, 2192, 0, 0, 39, '2191'),
	(377, 1, 0, -50553, 2193, 0, 0, 39, '2192'),
	(377, 1, 0, -50553, 2194, 0, 0, 39, '2193'),
	(377, 1, 0, -50553, 2195, 0, 0, 39, '2194'),
	(377, 1, 0, -50553, 2196, 0, 0, 39, '2195'),
	(377, 1, 0, -50553, 2197, 0, 0, 39, '2196'),
	(377, 1, 0, -50553, 2198, 0, 0, 39, '2197'),
	(377, 1, 0, -50553, 2199, 0, 0, 39, '2198'),
	(377, 1, 0, -50553, 2200, 0, 0, 39, '2199'),
	(377, 1, 0, -50553, 2201, 0, 0, 39, '2200'),
	(377, 1, 0, -50553, 2202, 0, 0, 39, '2201'),
	(377, 1, 0, -50553, 2203, 0, 0, 39, '2202'),
	(377, 1, 0, -50553, 2204, 0, 0, 39, '2203'),
	(377, 1, 0, -50553, 2205, 0, 0, 39, '2204'),
	(377, 1, 0, -50553, 2206, 0, 0, 39, '2205'),
	(377, 1, 0, -50553, 2207, 0, 0, 39, '2206'),
	(377, 1, 0, -50553, 2208, 0, 0, 39, '2207'),
	(377, 1, 0, -50553, 2209, 0, 0, 39, '2208'),
	(377, 1, 0, -50553, 2210, 0, 0, 39, '2209'),
	(377, 1, 0, -50553, 2211, 0, 0, 39, '2210'),
	(377, 1, 0, -50553, 2212, 0, 0, 39, '2211'),
	(377, 1, 0, -50553, 2213, 0, 0, 39, '2212'),
	(377, 1, 0, -50553, 2214, 0, 0, 39, '2213'),
	(377, 1, 0, -50553, 2215, 0, 0, 39, '2214'),
	(377, 1, 0, -50553, 2216, 0, 0, 39, '2215'),
	(377, 1, 0, -50553, 2217, 0, 0, 39, '2216'),
	(377, 1, 0, -50553, 2218, 0, 0, 39, '2217'),
	(377, 1, 0, -50553, 2219, 0, 0, 39, '2218'),
	(377, 1, 0, -50553, 2220, 0, 0, 39, '2219'),
	(377, 1, 0, -50553, 2221, 0, 0, 39, '2220'),
	(377, 1, 0, -50553, 2222, 0, 0, 39, '2221'),
	(377, 1, 0, -50553, 2223, 0, 0, 39, '2222'),
	(377, 1, 0, -50553, 2224, 0, 0, 39, '2223'),
	(377, 1, 0, -50553, 2225, 0, 0, 39, '2224'),
	(377, 1, 0, -50553, 2226, 0, 0, 39, '2225'),
	(377, 1, 0, -50553, 2227, 0, 0, 39, '2226'),
	(377, 1, 0, -50553, 2228, 0, 0, 39, '2227'),
	(377, 1, 0, -50553, 2229, 0, 0, 39, '2228'),
	(377, 1, 0, -50553, 2230, 0, 0, 39, '2229'),
	(377, 1, 0, -50553, 2231, 0, 0, 39, '2230'),
	(377, 1, 0, -50553, 2232, 0, 0, 39, '2231'),
	(377, 1, 0, -50553, 2233, 0, 0, 39, '2232'),
	(377, 1, 0, -50553, 2234, 0, 0, 39, '2233'),
	(377, 1, 0, -50553, 2235, 0, 0, 39, '2234'),
	(377, 1, 0, -50553, 2236, 0, 0, 39, '2235'),
	(377, 1, 0, -50553, 2237, 0, 0, 39, '2236'),
	(377, 1, 0, -50553, 2238, 0, 0, 39, '2237'),
	(377, 1, 0, -50553, 2239, 0, 0, 39, '2238'),
	(377, 1, 0, -50553, 2240, 0, 0, 39, '2239'),
	(377, 1, 0, -50553, 2241, 0, 0, 39, '2240'),
	(377, 1, 0, -50553, 2242, 0, 0, 39, '2241'),
	(377, 1, 0, -50553, 2243, 0, 0, 39, '2242'),
	(377, 1, 0, -50553, 2244, 0, 0, 39, '2243'),
	(377, 1, 0, -50553, 2245, 0, 0, 39, '2244'),
	(377, 1, 0, -50553, 2246, 0, 0, 39, '2245'),
	(377, 1, 0, -50553, 2247, 0, 0, 39, '2246'),
	(377, 1, 0, -50553, 2248, 0, 0, 39, '2247'),
	(377, 1, 0, -50553, 2249, 0, 0, 39, '2248'),
	(377, 1, 0, -50553, 2250, 0, 0, 39, '2249'),
	(377, 1, 0, -50553, 2251, 0, 0, 39, '2250'),
	(377, 1, 0, -50553, 2252, 0, 0, 39, '2251'),
	(377, 1, 0, -50553, 2253, 0, 0, 39, '2252'),
	(377, 1, 0, -50553, 2254, 0, 0, 39, '2253'),
	(377, 1, 0, -50553, 2255, 0, 0, 39, '2254'),
	(377, 1, 0, -50553, 2256, 0, 0, 39, '2255'),
	(377, 1, 0, -50553, 2257, 0, 0, 39, '2256'),
	(377, 1, 0, -50553, 2258, 0, 0, 39, '2257'),
	(377, 1, 0, -50553, 2259, 0, 0, 39, '2258'),
	(377, 1, 0, -50553, 2260, 0, 0, 39, '2259'),
	(377, 1, 0, -50553, 2261, 0, 0, 39, '2260'),
	(377, 1, 0, -50553, 2262, 0, 0, 39, '2261'),
	(377, 1, 0, -50553, 2263, 0, 0, 39, '2262'),
	(377, 1, 0, -50553, 2264, 0, 0, 39, '2263'),
	(377, 1, 0, -50553, 2265, 0, 0, 39, '2264'),
	(377, 1, 0, -50553, 2266, 0, 0, 39, '2265'),
	(377, 1, 0, -50553, 2267, 0, 0, 39, '2266'),
	(377, 1, 0, -50553, 2268, 0, 0, 39, '2267'),
	(377, 1, 0, -50553, 2269, 0, 0, 39, '2268'),
	(377, 1, 0, -50553, 2270, 0, 0, 39, '2269'),
	(377, 1, 0, -50553, 2271, 0, 0, 39, '2270'),
	(377, 1, 0, -50553, 2272, 0, 0, 39, '2271'),
	(377, 1, 0, -50553, 2273, 0, 0, 39, '2272'),
	(377, 1, 0, -50553, 2274, 0, 0, 39, '2273'),
	(377, 1, 0, -50553, 2275, 0, 0, 39, '2274'),
	(377, 1, 0, -50553, 2276, 0, 0, 39, '2275'),
	(377, 1, 0, -50553, 2277, 0, 0, 39, '2276'),
	(377, 1, 0, -50553, 2278, 0, 0, 39, '2277'),
	(377, 1, 0, -50553, 2279, 0, 0, 39, '2278'),
	(377, 1, 0, -50553, 2280, 0, 0, 39, '2279'),
	(377, 1, 0, -50553, 2281, 0, 0, 39, '2280'),
	(377, 1, 0, -50553, 2282, 0, 0, 39, '2281'),
	(377, 1, 0, -50553, 2283, 0, 0, 39, '2282'),
	(377, 1, 0, -50553, 2284, 0, 0, 39, '2283'),
	(377, 1, 0, -50553, 2285, 0, 0, 39, '2284'),
	(377, 1, 0, -50553, 2286, 0, 0, 39, '2285'),
	(377, 1, 0, -50553, 2287, 0, 0, 39, '2286'),
	(377, 1, 0, -50553, 2288, 0, 0, 39, '2287'),
	(377, 1, 0, -50553, 2289, 0, 0, 39, '2288'),
	(377, 1, 0, -50553, 2290, 0, 0, 39, '2289'),
	(377, 1, 0, -50553, 2291, 0, 0, 39, '2290'),
	(377, 1, 0, -50553, 2292, 0, 0, 39, '2291'),
	(377, 1, 0, -50553, 2293, 0, 0, 39, '2292'),
	(377, 1, 0, -50553, 2294, 0, 0, 39, '2293'),
	(377, 1, 0, -50553, 2295, 0, 0, 39, '2294'),
	(377, 1, 0, -50553, 2296, 0, 0, 39, '2295'),
	(377, 1, 0, -50553, 2297, 0, 0, 39, '2296'),
	(377, 1, 0, -50553, 2298, 0, 0, 39, '2297'),
	(377, 1, 0, -50553, 2299, 0, 0, 39, '2298'),
	(377, 1, 0, -50553, 2300, 0, 0, 39, '2299'),
	(377, 1, 0, -50553, 2301, 0, 0, 39, '2300'),
	(377, 1, 0, -50553, 2302, 0, 0, 39, '2301'),
	(377, 1, 0, -50553, 2303, 0, 0, 39, '2302'),
	(377, 1, 0, -50553, 2304, 0, 0, 39, '2303'),
	(377, 1, 0, -50553, 2305, 0, 0, 39, '2304'),
	(377, 1, 0, -50553, 2306, 0, 0, 39, '2305'),
	(377, 1, 0, -50553, 2307, 0, 0, 39, '2306'),
	(377, 1, 0, -50553, 2308, 0, 0, 39, '2307'),
	(377, 1, 0, -50553, 2309, 0, 0, 39, '2308'),
	(377, 1, 0, -50553, 2310, 0, 0, 39, '2309'),
	(377, 1, 0, -50553, 2311, 0, 0, 39, '2310'),
	(377, 1, 0, -50553, 2312, 0, 0, 39, '2311'),
	(377, 1, 0, -50553, 2313, 0, 0, 39, '2312'),
	(377, 1, 0, -50553, 2314, 0, 0, 39, '2313'),
	(377, 1, 0, -50553, 2315, 0, 0, 39, '2314'),
	(377, 1, 0, -50553, 2316, 0, 0, 39, '2315'),
	(377, 1, 0, -50553, 2317, 0, 0, 39, '2316'),
	(377, 1, 0, -50553, 2318, 0, 0, 39, '2317'),
	(377, 1, 0, -50553, 2319, 0, 0, 39, '2318'),
	(377, 1, 0, -50553, 2320, 0, 0, 39, '2319'),
	(377, 1, 0, -50553, 2321, 0, 0, 39, '2320'),
	(377, 1, 0, -50553, 2322, 0, 0, 39, '2321'),
	(377, 1, 0, -50553, 2323, 0, 0, 39, '2322'),
	(377, 1, 0, -50553, 2324, 0, 0, 39, '2323'),
	(377, 1, 0, -50553, 2325, 0, 0, 39, '2324'),
	(377, 1, 0, -50553, 2326, 0, 0, 39, '2325'),
	(377, 1, 0, -50553, 2327, 0, 0, 39, '2326'),
	(377, 1, 0, -50553, 2328, 0, 0, 39, '2327'),
	(377, 1, 0, -50553, 2329, 0, 0, 39, '2328'),
	(377, 1, 0, -50553, 2330, 0, 0, 39, '2329'),
	(377, 1, 0, -50553, 2331, 0, 0, 39, '2330'),
	(377, 1, 0, -50553, 2332, 0, 0, 39, '2331'),
	(377, 1, 0, -50553, 2333, 0, 0, 39, '2332'),
	(377, 1, 0, -50553, 2334, 0, 0, 39, '2333'),
	(377, 1, 0, -50553, 2335, 0, 0, 39, '2334'),
	(377, 1, 0, -50553, 2336, 0, 0, 39, '2335'),
	(377, 1, 0, -50553, 2337, 0, 0, 39, '2336'),
	(377, 1, 0, -50553, 2338, 0, 0, 39, '2337'),
	(377, 1, 0, -50553, 2339, 0, 0, 39, '2338'),
	(377, 1, 0, -50553, 2340, 0, 0, 39, '2339'),
	(377, 1, 0, -50553, 2341, 0, 0, 39, '2340'),
	(377, 1, 0, -50553, 2342, 0, 0, 39, '2341'),
	(377, 1, 0, -50553, 2343, 0, 0, 39, '2342'),
	(377, 1, 0, -50553, 2344, 0, 0, 39, '2343'),
	(377, 1, 0, -50553, 2345, 0, 0, 39, '2344'),
	(377, 1, 0, -50553, 2346, 0, 0, 39, '2345'),
	(377, 1, 0, -50553, 2347, 0, 0, 39, '2346'),
	(377, 1, 0, -50553, 2348, 0, 0, 39, '2347'),
	(377, 1, 0, -50553, 2349, 0, 0, 39, '2348'),
	(377, 1, 0, -50553, 2350, 0, 0, 39, '2349'),
	(377, 1, 0, -50553, 2351, 0, 0, 39, '2350'),
	(377, 1, 0, -50553, 2352, 0, 0, 39, '2351'),
	(377, 1, 0, -50553, 2353, 0, 0, 39, '2352'),
	(377, 1, 0, -50553, 2354, 0, 0, 39, '2353'),
	(377, 1, 0, -50553, 2355, 0, 0, 39, '2354'),
	(377, 1, 0, -50553, 2356, 0, 0, 39, '2355'),
	(377, 1, 0, -50553, 2357, 0, 0, 39, '2356'),
	(377, 1, 0, -50553, 2358, 0, 0, 39, '2357'),
	(377, 1, 0, -50553, 2359, 0, 0, 39, '2358'),
	(377, 1, 0, -50553, 2360, 0, 0, 39, '2359'),
	(377, 1, 0, -50553, 2361, 0, 0, 39, '2360'),
	(377, 1, 0, -50553, 2362, 0, 0, 39, '2361'),
	(377, 1, 0, -50553, 2363, 0, 0, 39, '2362'),
	(377, 1, 0, -50553, 2364, 0, 0, 39, '2363'),
	(377, 1, 0, -50553, 2365, 0, 0, 39, '2364'),
	(377, 1, 0, -50553, 2366, 0, 0, 39, '2365'),
	(377, 1, 0, -50553, 2367, 0, 0, 39, '2366'),
	(377, 1, 0, -50553, 2368, 0, 0, 39, '2367'),
	(377, 1, 0, -50553, 2369, 0, 0, 39, '2368'),
	(377, 1, 0, -50553, 2370, 0, 0, 39, '2369'),
	(377, 1, 0, -50553, 2371, 0, 0, 39, '2370'),
	(377, 1, 0, -50553, 2372, 0, 0, 39, '2371'),
	(377, 1, 0, -50553, 2373, 0, 0, 39, '2372'),
	(377, 1, 0, -50553, 2374, 0, 0, 39, '2373'),
	(377, 1, 0, -50553, 2375, 0, 0, 39, '2374'),
	(377, 1, 0, -50553, 2376, 0, 0, 39, '2375'),
	(377, 1, 0, -50553, 2377, 0, 0, 39, '2376'),
	(377, 1, 0, -50553, 2378, 0, 0, 39, '2377'),
	(377, 1, 0, -50553, 2379, 0, 0, 39, '2378'),
	(377, 1, 0, -50553, 2380, 0, 0, 39, '2379'),
	(377, 1, 0, -50553, 2381, 0, 0, 39, '2380'),
	(377, 1, 0, -50553, 2382, 0, 0, 39, '2381'),
	(377, 1, 0, -50553, 2383, 0, 0, 39, '2382'),
	(377, 1, 0, -50553, 2384, 0, 0, 39, '2383'),
	(377, 1, 0, -50553, 2385, 0, 0, 39, '2384'),
	(377, 1, 0, -50553, 2386, 0, 0, 39, '2385'),
	(377, 1, 0, -50553, 2387, 0, 0, 39, '2386'),
	(377, 1, 0, -50553, 2388, 0, 0, 39, '2387'),
	(377, 1, 0, -50553, 2389, 0, 0, 39, '2388'),
	(377, 1, 0, -50553, 2390, 0, 0, 39, '2389'),
	(377, 1, 0, -50553, 2391, 0, 0, 39, '2390'),
	(377, 1, 0, -50553, 2392, 0, 0, 39, '2391'),
	(377, 1, 0, -50553, 2393, 0, 0, 39, '2392'),
	(377, 1, 0, -50553, 2394, 0, 0, 39, '2393'),
	(377, 1, 0, -50553, 2395, 0, 0, 39, '2394'),
	(377, 1, 0, -50553, 2396, 0, 0, 39, '2395'),
	(377, 1, 0, -50553, 2397, 0, 0, 39, '2396'),
	(377, 1, 0, -50553, 2398, 0, 0, 39, '2397'),
	(377, 1, 0, -50553, 2399, 0, 0, 39, '2398'),
	(377, 1, 0, -50553, 2400, 0, 0, 39, '2399'),
	(377, 1, 0, -50553, 2401, 0, 0, 39, '2400'),
	(377, 1, 0, -50553, 2402, 0, 0, 39, '2401'),
	(377, 1, 0, -50553, 2403, 0, 0, 39, '2402'),
	(377, 1, 0, -50553, 2404, 0, 0, 39, '2403'),
	(377, 1, 0, -50553, 2405, 0, 0, 39, '2404'),
	(377, 1, 0, -50553, 2406, 0, 0, 39, '2405'),
	(377, 1, 0, -50553, 2407, 0, 0, 39, '2406'),
	(377, 1, 0, -50553, 2408, 0, 0, 39, '2407'),
	(377, 1, 0, -50553, 2409, 0, 0, 39, '2408'),
	(377, 1, 0, -50553, 2410, 0, 0, 39, '2409'),
	(377, 1, 0, -50553, 2411, 0, 0, 39, '2410'),
	(377, 1, 0, -50553, 2412, 0, 0, 39, '2411'),
	(377, 1, 0, -50553, 2413, 0, 0, 39, '2412'),
	(377, 1, 0, -50553, 2414, 0, 0, 39, '2413'),
	(377, 1, 0, -50553, 2415, 0, 0, 39, '2414'),
	(377, 1, 0, -50553, 2416, 0, 0, 39, '2415'),
	(377, 1, 0, -50553, 2417, 0, 0, 39, '2416'),
	(377, 1, 0, -50553, 2418, 0, 0, 39, '2417'),
	(377, 1, 0, -50553, 2419, 0, 0, 39, '2418'),
	(377, 1, 0, -50553, 2420, 0, 0, 39, '2419'),
	(377, 1, 0, -50553, 2421, 0, 0, 39, '2420'),
	(377, 1, 0, -50553, 2422, 0, 0, 39, '2421'),
	(377, 1, 0, -50553, 2423, 0, 0, 39, '2422'),
	(377, 1, 0, -50553, 2424, 0, 0, 39, '2423'),
	(377, 1, 0, -50553, 2425, 0, 0, 39, '2424'),
	(377, 1, 0, -50553, 2426, 0, 0, 39, '2425'),
	(377, 1, 0, -50553, 2427, 0, 0, 39, '2426'),
	(377, 1, 0, -50553, 2428, 0, 0, 39, '2427'),
	(377, 1, 0, -50553, 2429, 0, 0, 39, '2428'),
	(377, 1, 0, -50553, 2430, 0, 0, 39, '2429'),
	(377, 1, 0, -50553, 2431, 0, 0, 39, '2430'),
	(377, 1, 0, -50553, 2432, 0, 0, 39, '2431'),
	(377, 1, 0, -50553, 2433, 0, 0, 39, '2432'),
	(377, 1, 0, -50553, 2434, 0, 0, 39, '2433'),
	(377, 1, 0, -50553, 2435, 0, 0, 39, '2434'),
	(377, 1, 0, -50553, 2436, 0, 0, 39, '2435'),
	(377, 1, 0, -50553, 2437, 0, 0, 39, '2436'),
	(377, 1, 0, -50553, 2438, 0, 0, 39, '2437'),
	(377, 1, 0, -50553, 2439, 0, 0, 39, '2438'),
	(377, 1, 0, -50553, 2440, 0, 0, 39, '2439'),
	(377, 1, 0, -50553, 2441, 0, 0, 39, '2440'),
	(377, 1, 0, -50553, 2442, 0, 0, 39, '2441'),
	(377, 1, 0, -50553, 2443, 0, 0, 39, '2442'),
	(377, 1, 0, -50553, 2444, 0, 0, 39, '2443'),
	(377, 1, 0, -50553, 2445, 0, 0, 39, '2444'),
	(377, 1, 0, -50553, 2446, 0, 0, 39, '2445'),
	(377, 1, 0, -50553, 2447, 0, 0, 39, '2446'),
	(377, 1, 0, -50553, 2448, 0, 0, 39, '2447'),
	(377, 1, 0, -50553, 2449, 0, 0, 39, '2448'),
	(377, 1, 0, -50553, 2450, 0, 0, 39, '2449'),
	(377, 1, 0, -50553, 2451, 0, 0, 39, '2450'),
	(377, 1, 0, -50553, 2452, 0, 0, 39, '2451'),
	(377, 1, 0, -50553, 2453, 0, 0, 39, '2452'),
	(377, 1, 0, -50553, 2454, 0, 0, 39, '2453'),
	(377, 1, 0, -50553, 2455, 0, 0, 39, '2454'),
	(377, 1, 0, -50553, 2456, 0, 0, 39, '2455'),
	(377, 1, 0, -50553, 2457, 0, 0, 39, '2456'),
	(377, 1, 0, -50553, 2458, 0, 0, 39, '2457'),
	(377, 1, 0, -50553, 2459, 0, 0, 39, '2458'),
	(377, 1, 0, -50553, 2460, 0, 0, 39, '2459'),
	(377, 1, 0, -50553, 2461, 0, 0, 39, '2460'),
	(377, 1, 0, -50553, 2462, 0, 0, 39, '2461'),
	(377, 1, 0, -50553, 2463, 0, 0, 39, '2462'),
	(377, 1, 0, -50553, 2464, 0, 0, 39, '2463'),
	(377, 1, 0, -50553, 2465, 0, 0, 39, '2464'),
	(377, 1, 0, -50553, 2466, 0, 0, 39, '2465'),
	(377, 1, 0, -50553, 2467, 0, 0, 39, '2466'),
	(377, 1, 0, -50553, 2468, 0, 0, 39, '2467'),
	(377, 1, 0, -50553, 2469, 0, 0, 39, '2468'),
	(377, 1, 0, -50553, 2470, 0, 0, 39, '2469'),
	(377, 1, 0, -50553, 2471, 0, 0, 39, '2470'),
	(377, 1, 0, -50553, 2472, 0, 0, 39, '2471'),
	(377, 1, 0, -50553, 2473, 0, 0, 39, '2472'),
	(377, 1, 0, -50553, 2474, 0, 0, 39, '2473'),
	(377, 1, 0, -50553, 2475, 0, 0, 39, '2474'),
	(377, 1, 0, -50553, 2476, 0, 0, 39, '2475'),
	(377, 1, 0, -50553, 2477, 0, 0, 39, '2476'),
	(377, 1, 0, -50553, 2478, 0, 0, 39, '2477'),
	(377, 1, 0, -50553, 2479, 0, 0, 39, '2478'),
	(377, 1, 0, -50553, 2480, 0, 0, 39, '2479'),
	(377, 1, 0, -50553, 2481, 0, 0, 39, '2480'),
	(377, 1, 0, -50553, 2482, 0, 0, 39, '2481'),
	(377, 1, 0, -50553, 2483, 0, 0, 39, '2482'),
	(377, 1, 0, -50553, 2484, 0, 0, 39, '2483'),
	(377, 1, 0, -50553, 2485, 0, 0, 39, '2484'),
	(377, 1, 0, -50553, 2486, 0, 0, 39, '2485'),
	(377, 1, 0, -50553, 2487, 0, 0, 39, '2486'),
	(377, 1, 0, -50553, 2488, 0, 0, 39, '2487'),
	(377, 1, 0, -50553, 2489, 0, 0, 39, '2488'),
	(377, 1, 0, -50553, 2490, 0, 0, 39, '2489'),
	(377, 1, 0, -50553, 2491, 0, 0, 39, '2490'),
	(377, 1, 0, -50553, 2492, 0, 0, 39, '2491'),
	(377, 1, 0, -50553, 2493, 0, 0, 39, '2492'),
	(377, 1, 0, -50553, 2494, 0, 0, 39, '2493'),
	(377, 1, 0, -50553, 2495, 0, 0, 39, '2494'),
	(377, 1, 0, -50553, 2496, 0, 0, 39, '2495'),
	(377, 1, 0, -50553, 2497, 0, 0, 39, '2496'),
	(377, 1, 0, -50553, 2498, 0, 0, 39, '2497'),
	(377, 1, 0, -50553, 2499, 0, 0, 39, '2498'),
	(377, 1, 0, -50553, 2500, 0, 0, 39, '2499'),
	(377, 1, 0, -50553, 2501, 0, 0, 39, '2500'),
	(377, 1, 0, -50553, 2502, 0, 0, 39, '2501'),
	(377, 1, 0, -50553, 2503, 0, 0, 39, '2502'),
	(377, 1, 0, -50553, 2504, 0, 0, 39, '2503'),
	(377, 1, 0, -50553, 2505, 0, 0, 39, '2504'),
	(377, 1, 0, -50553, 2506, 0, 0, 39, '2505'),
	(377, 1, 0, -50553, 2507, 0, 0, 39, '2506'),
	(377, 1, 0, -50553, 2508, 0, 0, 39, '2507'),
	(377, 1, 0, -50553, 2509, 0, 0, 39, '2508'),
	(377, 1, 0, -50553, 2510, 0, 0, 39, '2509'),
	(377, 1, 0, -50553, 2511, 0, 0, 39, '2510'),
	(377, 1, 0, -50553, 2512, 0, 0, 39, '2511'),
	(377, 1, 0, -50553, 2513, 0, 0, 39, '2512'),
	(377, 1, 0, -50553, 2514, 0, 0, 39, '2513'),
	(377, 1, 0, -50553, 2515, 0, 0, 39, '2514'),
	(377, 1, 0, -50553, 2516, 0, 0, 39, '2515'),
	(377, 1, 0, -50553, 2517, 0, 0, 39, '2516'),
	(377, 1, 0, -50553, 2518, 0, 0, 39, '2517'),
	(377, 1, 0, -50553, 2519, 0, 0, 39, '2518'),
	(377, 1, 0, -50553, 2520, 0, 0, 39, '2519'),
	(377, 1, 0, -50553, 2521, 0, 0, 39, '2520'),
	(377, 1, 0, -50553, 2522, 0, 0, 39, '2521'),
	(377, 1, 0, -50553, 2523, 0, 0, 39, '2522'),
	(377, 1, 0, -50553, 2524, 0, 0, 39, '2523'),
	(377, 1, 0, -50553, 2525, 0, 0, 39, '2524'),
	(377, 1, 0, -50553, 2526, 0, 0, 39, '2525'),
	(377, 1, 0, -50553, 2527, 0, 0, 39, '2526'),
	(377, 1, 0, -50553, 2528, 0, 0, 39, '2527'),
	(377, 1, 0, -50553, 2529, 0, 0, 39, '2528'),
	(377, 1, 0, -50553, 2530, 0, 0, 39, '2529'),
	(377, 1, 0, -50553, 2531, 0, 0, 39, '2530'),
	(377, 1, 0, -50553, 2532, 0, 0, 39, '2531'),
	(377, 1, 0, -50553, 2533, 0, 0, 39, '2532'),
	(377, 1, 0, -50553, 2534, 0, 0, 39, '2533'),
	(377, 1, 0, -50553, 2535, 0, 0, 39, '2534'),
	(377, 1, 0, -50553, 2536, 0, 0, 39, '2535'),
	(377, 1, 0, -50553, 2537, 0, 0, 39, '2536'),
	(377, 1, 0, -50553, 2538, 0, 0, 39, '2537'),
	(377, 1, 0, -50553, 2539, 0, 0, 39, '2538'),
	(377, 1, 0, -50553, 2540, 0, 0, 39, '2539'),
	(377, 1, 0, -50553, 2541, 0, 0, 39, '2540'),
	(377, 1, 0, -50553, 2542, 0, 0, 39, '2541'),
	(377, 1, 0, -50553, 2543, 0, 0, 39, '2542'),
	(377, 1, 0, -50553, 2544, 0, 0, 39, '2543'),
	(377, 1, 0, -50553, 2545, 0, 0, 39, '2544'),
	(377, 1, 0, -50553, 2546, 0, 0, 39, '2545'),
	(377, 1, 0, -50553, 2547, 0, 0, 39, '2546'),
	(377, 1, 0, -50553, 2548, 0, 0, 39, '2547'),
	(377, 1, 0, -50553, 2549, 0, 0, 39, '2548'),
	(377, 1, 0, -50553, 2550, 0, 0, 39, '2549'),
	(377, 1, 0, -50553, 2551, 0, 0, 39, '2550'),
	(377, 1, 0, -50553, 2552, 0, 0, 39, '2551'),
	(377, 1, 0, -50553, 2553, 0, 0, 39, '2552'),
	(377, 1, 0, -50553, 2554, 0, 0, 39, '2553'),
	(377, 1, 0, -50553, 2555, 0, 0, 39, '2554'),
	(377, 1, 0, -50553, 2556, 0, 0, 39, '2555'),
	(377, 1, 0, -50553, 2557, 0, 0, 39, '2556'),
	(377, 1, 0, -50553, 2558, 0, 0, 39, '2557'),
	(377, 1, 0, -50553, 2559, 0, 0, 39, '2558'),
	(377, 1, 0, -50553, 2560, 0, 0, 39, '2559'),
	(377, 1, 0, -50553, 2561, 0, 0, 39, '2560'),
	(377, 1, 0, -50553, 2562, 0, 0, 39, '2561'),
	(377, 1, 0, -50553, 2563, 0, 0, 39, '2562'),
	(377, 1, 0, -50553, 2564, 0, 0, 39, '2563'),
	(377, 1, 0, -50553, 2565, 0, 0, 39, '2564'),
	(377, 1, 0, -50553, 2566, 0, 0, 39, '2565'),
	(377, 1, 0, -50553, 2567, 0, 0, 39, '2566'),
	(377, 1, 0, -50553, 2568, 0, 0, 39, '2567'),
	(377, 1, 0, -50553, 2569, 0, 0, 39, '2568'),
	(377, 1, 0, -50553, 2570, 0, 0, 39, '2569'),
	(377, 1, 0, -50553, 2571, 0, 0, 39, '2570'),
	(377, 1, 0, -50553, 2572, 0, 0, 39, '2571'),
	(377, 1, 0, -50553, 2573, 0, 0, 39, '2572'),
	(377, 1, 0, -50553, 2574, 0, 0, 39, '2573'),
	(377, 1, 0, -50553, 2575, 0, 0, 39, '2574'),
	(377, 1, 0, -50553, 2576, 0, 0, 39, '2575'),
	(377, 1, 0, -50553, 2577, 0, 0, 39, '2576'),
	(377, 1, 0, -50553, 2578, 0, 0, 39, '2577'),
	(377, 1, 0, -50553, 2579, 0, 0, 39, '2578'),
	(377, 1, 0, -50553, 2580, 0, 0, 39, '2579'),
	(377, 1, 0, -50553, 2581, 0, 0, 39, '2580'),
	(377, 1, 0, -50553, 2582, 0, 0, 39, '2581'),
	(377, 1, 0, -50553, 2583, 0, 0, 39, '2582'),
	(377, 1, 0, -50553, 2584, 0, 0, 39, '2583'),
	(377, 1, 0, -50553, 2585, 0, 0, 39, '2584'),
	(377, 1, 0, -50553, 2586, 0, 0, 39, '2585'),
	(377, 1, 0, -50553, 2587, 0, 0, 39, '2586'),
	(377, 1, 0, -50553, 2588, 0, 0, 39, '2587'),
	(377, 1, 0, -50553, 2589, 0, 0, 39, '2588'),
	(377, 1, 0, -50553, 2590, 0, 0, 39, '2589'),
	(377, 1, 0, -50553, 2591, 0, 0, 39, '2590'),
	(377, 1, 0, -50553, 2592, 0, 0, 39, '2591'),
	(377, 1, 0, -50553, 2593, 0, 0, 39, '2592'),
	(377, 1, 0, -50553, 2594, 0, 0, 39, '2593'),
	(377, 1, 0, -50553, 2595, 0, 0, 39, '2594'),
	(377, 1, 0, -50553, 2596, 0, 0, 39, '2595'),
	(377, 1, 0, -50553, 2597, 0, 0, 39, '2596'),
	(377, 1, 0, -50553, 2598, 0, 0, 39, '2597'),
	(377, 1, 0, -50553, 2599, 0, 0, 39, '2598'),
	(377, 1, 0, -50553, 2600, 0, 0, 39, '2599'),
	(377, 1, 0, -50553, 2601, 0, 0, 39, '2600'),
	(377, 1, 0, -50553, 2602, 0, 0, 39, '2601'),
	(377, 1, 0, -50553, 2603, 0, 0, 39, '2602'),
	(377, 1, 0, -50553, 2604, 0, 0, 39, '2603'),
	(377, 1, 0, -50553, 2605, 0, 0, 39, '2604'),
	(377, 1, 0, -50553, 2606, 0, 0, 39, '2605'),
	(377, 1, 0, -50553, 2607, 0, 0, 39, '2606'),
	(377, 1, 0, -50553, 2608, 0, 0, 39, '2607'),
	(377, 1, 0, -50553, 2609, 0, 0, 39, '2608'),
	(377, 1, 0, -50553, 2610, 0, 0, 39, '2609'),
	(377, 1, 0, -50553, 2611, 0, 0, 39, '2610'),
	(377, 1, 0, -50553, 2612, 0, 0, 39, '2611'),
	(377, 1, 0, -50553, 2613, 0, 0, 39, '2612'),
	(377, 1, 0, -50553, 2614, 0, 0, 39, '2613'),
	(377, 1, 0, -50553, 2615, 0, 0, 39, '2614'),
	(377, 1, 0, -50553, 2616, 0, 0, 39, '2615'),
	(377, 1, 0, -50553, 2617, 0, 0, 39, '2616'),
	(377, 1, 0, -50553, 2618, 0, 0, 39, '2617'),
	(377, 1, 0, -50553, 2619, 0, 0, 39, '2618'),
	(377, 1, 0, -50553, 2620, 0, 0, 39, '2619'),
	(377, 1, 0, -50553, 2621, 0, 0, 39, '2620'),
	(377, 1, 0, -50553, 2622, 0, 0, 39, '2621'),
	(377, 1, 0, -50553, 2623, 0, 0, 39, '2622'),
	(377, 1, 0, -50553, 2624, 0, 0, 39, '2623'),
	(377, 1, 0, -50553, 2625, 0, 0, 39, '2624'),
	(377, 1, 0, -50553, 2626, 0, 0, 39, '2625'),
	(377, 1, 0, -50553, 2627, 0, 0, 39, '2626'),
	(377, 1, 0, -50553, 2628, 0, 0, 39, '2627'),
	(377, 1, 0, -50553, 2629, 0, 0, 39, '2628'),
	(377, 1, 0, -50553, 2630, 0, 0, 39, '2629'),
	(377, 1, 0, -50553, 2631, 0, 0, 39, '2630'),
	(377, 1, 0, -50553, 2632, 0, 0, 39, '2631'),
	(377, 1, 0, -50553, 2633, 0, 0, 39, '2632'),
	(377, 1, 0, -50553, 2634, 0, 0, 39, '2633'),
	(377, 1, 0, -50553, 2635, 0, 0, 39, '2634'),
	(377, 1, 0, -50553, 2636, 0, 0, 39, '2635'),
	(377, 1, 0, -50553, 2637, 0, 0, 39, '2636'),
	(377, 1, 0, -50553, 2638, 0, 0, 39, '2637'),
	(377, 1, 0, -50553, 2639, 0, 0, 39, '2638'),
	(377, 1, 0, -50553, 2640, 0, 0, 39, '2639'),
	(377, 1, 0, -50553, 2641, 0, 0, 39, '2640'),
	(377, 1, 0, -50553, 2642, 0, 0, 39, '2641'),
	(377, 1, 0, -50553, 2643, 0, 0, 39, '2642'),
	(377, 1, 0, -50553, 2644, 0, 0, 39, '2643'),
	(377, 1, 0, -50553, 2645, 0, 0, 39, '2644'),
	(377, 1, 0, -50553, 2646, 0, 0, 39, '2645'),
	(377, 1, 0, -50553, 2647, 0, 0, 39, '2646'),
	(377, 1, 0, -50553, 2648, 0, 0, 39, '2647'),
	(377, 1, 0, -50553, 2649, 0, 0, 39, '2648'),
	(377, 1, 0, -50553, 2650, 0, 0, 39, '2649'),
	(377, 1, 0, -50553, 2651, 0, 0, 39, '2650'),
	(377, 1, 0, -50553, 2652, 0, 0, 39, '2651'),
	(377, 1, 0, -50553, 2653, 0, 0, 39, '2652'),
	(377, 1, 0, -50553, 2654, 0, 0, 39, '2653'),
	(377, 1, 0, -50553, 2655, 0, 0, 39, '2654'),
	(377, 1, 0, -50553, 2656, 0, 0, 39, '2655'),
	(377, 1, 0, -50553, 2657, 0, 0, 39, '2656'),
	(377, 1, 0, -50553, 2658, 0, 0, 39, '2657'),
	(377, 1, 0, -50553, 2659, 0, 0, 39, '2658'),
	(377, 1, 0, -50553, 2660, 0, 0, 39, '2659'),
	(377, 1, 0, -50553, 2661, 0, 0, 39, '2660'),
	(377, 1, 0, -50553, 2662, 0, 0, 39, '2661'),
	(377, 1, 0, -50553, 2663, 0, 0, 39, '2662'),
	(377, 1, 0, -50553, 2664, 0, 0, 39, '2663'),
	(377, 1, 0, -50553, 2665, 0, 0, 39, '2664'),
	(377, 1, 0, -50553, 2666, 0, 0, 39, '2665'),
	(377, 1, 0, -50553, 2667, 0, 0, 39, '2666'),
	(377, 1, 0, -50553, 2668, 0, 0, 39, '2667'),
	(377, 1, 0, -50553, 2669, 0, 0, 39, '2668'),
	(377, 1, 0, -50553, 2670, 0, 0, 39, '2669'),
	(377, 1, 0, -50553, 2671, 0, 0, 39, '2670'),
	(377, 1, 0, -50553, 2672, 0, 0, 39, '2671'),
	(377, 1, 0, -50553, 2673, 0, 0, 39, '2672'),
	(377, 1, 0, -50553, 2674, 0, 0, 39, '2673'),
	(377, 1, 0, -50553, 2675, 0, 0, 39, '2674'),
	(377, 1, 0, -50553, 2676, 0, 0, 39, '2675'),
	(377, 1, 0, -50553, 2677, 0, 0, 39, '2676'),
	(377, 1, 0, -50553, 2678, 0, 0, 39, '2677'),
	(377, 1, 0, -50553, 2679, 0, 0, 39, '2678'),
	(377, 1, 0, -50553, 2680, 0, 0, 39, '2679'),
	(377, 1, 0, -50553, 2681, 0, 0, 39, '2680'),
	(377, 1, 0, -50553, 2682, 0, 0, 39, '2681'),
	(377, 1, 0, -50553, 2683, 0, 0, 39, '2682'),
	(377, 1, 0, -50553, 2684, 0, 0, 39, '2683'),
	(377, 1, 0, -50553, 2685, 0, 0, 39, '2684'),
	(377, 1, 0, -50553, 2686, 0, 0, 39, '2685'),
	(377, 1, 0, -50553, 2687, 0, 0, 39, '2686'),
	(377, 1, 0, -50553, 2688, 0, 0, 39, '2687'),
	(377, 1, 0, -50553, 2689, 0, 0, 39, '2688'),
	(377, 1, 0, -50553, 2690, 0, 0, 39, '2689'),
	(377, 1, 0, -50553, 2691, 0, 0, 39, '2690'),
	(377, 1, 0, -50553, 2692, 0, 0, 39, '2691'),
	(377, 1, 0, -50553, 2693, 0, 0, 39, '2692'),
	(377, 1, 0, -50553, 2694, 0, 0, 39, '2693'),
	(377, 1, 0, -50553, 2695, 0, 0, 39, '2694'),
	(377, 1, 0, -50553, 2696, 0, 0, 39, '2695'),
	(377, 1, 0, -50553, 2697, 0, 0, 39, '2696'),
	(377, 1, 0, -50553, 2698, 0, 0, 39, '2697'),
	(377, 1, 0, -50553, 2699, 0, 0, 39, '2698'),
	(377, 1, 0, -50553, 2700, 0, 0, 39, '2699'),
	(377, 1, 0, -50553, 2701, 0, 0, 39, '2700'),
	(377, 1, 0, -50553, 2702, 0, 0, 39, '2701'),
	(377, 1, 0, -50553, 2703, 0, 0, 39, '2702'),
	(377, 1, 0, -50553, 2704, 0, 0, 39, '2703'),
	(377, 1, 0, -50553, 2705, 0, 0, 39, '2704'),
	(377, 1, 0, -50553, 2706, 0, 0, 39, '2705'),
	(377, 1, 0, -50553, 2707, 0, 0, 39, '2706'),
	(377, 1, 0, -50553, 2708, 0, 0, 39, '2707'),
	(377, 1, 0, -50553, 2709, 0, 0, 39, '2708'),
	(377, 1, 0, -50553, 2710, 0, 0, 39, '2709'),
	(377, 1, 0, -50553, 2711, 0, 0, 39, '2710'),
	(377, 1, 0, -50553, 2712, 0, 0, 39, '2711'),
	(377, 1, 0, -50553, 2713, 0, 0, 39, '2712'),
	(377, 1, 0, -50553, 2714, 0, 0, 39, '2713'),
	(377, 1, 0, -50553, 2715, 0, 0, 39, '2714'),
	(377, 1, 0, -50553, 2716, 0, 0, 39, '2715'),
	(377, 1, 0, -50553, 2717, 0, 0, 39, '2716'),
	(377, 1, 0, -50553, 2718, 0, 0, 39, '2717'),
	(377, 1, 0, -50553, 2719, 0, 0, 39, '2718'),
	(377, 1, 0, -50553, 2720, 0, 0, 39, '2719'),
	(377, 1, 0, -50553, 2721, 0, 0, 39, '2720'),
	(377, 1, 0, -50553, 2722, 0, 0, 39, '2721'),
	(377, 1, 0, -50553, 2723, 0, 0, 39, '2722'),
	(377, 1, 0, -50553, 2724, 0, 0, 39, '2723'),
	(377, 1, 0, -50553, 2725, 0, 0, 39, '2724'),
	(377, 1, 0, -50553, 2726, 0, 0, 39, '2725'),
	(377, 1, 0, -50553, 2727, 0, 0, 39, '2726'),
	(377, 1, 0, -50553, 2728, 0, 0, 39, '2727'),
	(377, 1, 0, -50553, 2729, 0, 0, 39, '2728'),
	(377, 1, 0, -50553, 2730, 0, 0, 39, '2729'),
	(377, 1, 0, -50553, 2731, 0, 0, 39, '2730'),
	(377, 1, 0, -50553, 2732, 0, 0, 39, '2731'),
	(377, 1, 0, -50553, 2733, 0, 0, 39, '2732'),
	(377, 1, 0, -50553, 2734, 0, 0, 39, '2733'),
	(377, 1, 0, -50553, 2735, 0, 0, 39, '2734'),
	(377, 1, 0, -50553, 2736, 0, 0, 39, '2735'),
	(377, 1, 0, -50553, 2737, 0, 0, 39, '2736'),
	(377, 1, 0, -50553, 2738, 0, 0, 39, '2737'),
	(377, 1, 0, -50553, 2739, 0, 0, 39, '2738'),
	(377, 1, 0, -50553, 2740, 0, 0, 39, '2739'),
	(377, 1, 0, -50553, 2741, 0, 0, 39, '2740'),
	(377, 1, 0, -50553, 2742, 0, 0, 39, '2741'),
	(377, 1, 0, -50553, 2743, 0, 0, 39, '2742'),
	(377, 1, 0, -50553, 2744, 0, 0, 39, '2743'),
	(377, 1, 0, -50553, 2745, 0, 0, 39, '2744'),
	(377, 1, 0, -50553, 2746, 0, 0, 39, '2745'),
	(377, 1, 0, -50553, 2747, 0, 0, 39, '2746'),
	(377, 1, 0, -50553, 2748, 0, 0, 39, '2747'),
	(377, 1, 0, -50553, 2749, 0, 0, 39, '2748'),
	(377, 1, 0, -50553, 2750, 0, 0, 39, '2749'),
	(377, 1, 0, -50553, 2751, 0, 0, 39, '2750'),
	(377, 1, 0, -50553, 2752, 0, 0, 39, '2751'),
	(377, 1, 0, -50553, 2753, 0, 0, 39, '2752'),
	(377, 1, 0, -50553, 2754, 0, 0, 39, '2753'),
	(377, 1, 0, -50553, 2755, 0, 0, 39, '2754'),
	(377, 1, 0, -50553, 2756, 0, 0, 39, '2755'),
	(377, 1, 0, -50553, 2757, 0, 0, 39, '2756'),
	(377, 1, 0, -50553, 2758, 0, 0, 39, '2757'),
	(377, 1, 0, -50553, 2759, 0, 0, 39, '2758'),
	(377, 1, 0, -50553, 2760, 0, 0, 39, '2759'),
	(377, 1, 0, -50553, 2761, 0, 0, 39, '2760'),
	(377, 1, 0, -50553, 2762, 0, 0, 39, '2761'),
	(377, 1, 0, -50553, 2763, 0, 0, 39, '2762'),
	(377, 1, 0, -50553, 2764, 0, 0, 39, '2763'),
	(377, 1, 0, -50553, 2765, 0, 0, 39, '2764'),
	(377, 1, 0, -50553, 2766, 0, 0, 39, '2765'),
	(377, 1, 0, -50553, 2767, 0, 0, 39, '2766'),
	(377, 1, 0, -50553, 2768, 0, 0, 39, '2767'),
	(377, 1, 0, -50553, 2769, 0, 0, 39, '2768'),
	(377, 1, 0, -50553, 2770, 0, 0, 39, '2769'),
	(377, 1, 0, -50553, 2771, 0, 0, 39, '2770'),
	(377, 1, 0, -50553, 2772, 0, 0, 39, '2771'),
	(377, 1, 0, -50553, 2773, 0, 0, 39, '2772'),
	(377, 1, 0, -50553, 2774, 0, 0, 39, '2773'),
	(377, 1, 0, -50553, 2775, 0, 0, 39, '2774'),
	(377, 1, 0, -50553, 2776, 0, 0, 39, '2775'),
	(377, 1, 0, -50553, 2777, 0, 0, 39, '2776'),
	(377, 1, 0, -50553, 2778, 0, 0, 39, '2777'),
	(377, 1, 0, -50553, 2779, 0, 0, 39, '2778'),
	(377, 1, 0, -50553, 2780, 0, 0, 39, '2779'),
	(377, 1, 0, -50553, 2781, 0, 0, 39, '2780'),
	(377, 1, 0, -50553, 2782, 0, 0, 39, '2781'),
	(377, 1, 0, -50553, 2783, 0, 0, 39, '2782'),
	(377, 1, 0, -50553, 2784, 0, 0, 39, '2783'),
	(377, 1, 0, -50553, 2785, 0, 0, 39, '2784'),
	(377, 1, 0, -50553, 2786, 0, 0, 39, '2785'),
	(377, 1, 0, -50553, 2787, 0, 0, 39, '2786'),
	(377, 1, 0, -50553, 2788, 0, 0, 39, '2787'),
	(377, 1, 0, -50553, 2789, 0, 0, 39, '2788'),
	(377, 1, 0, -50553, 2790, 0, 0, 39, '2789'),
	(377, 1, 0, -50553, 2791, 0, 0, 39, '2790'),
	(377, 1, 0, -50553, 2792, 0, 0, 39, '2791'),
	(377, 1, 0, -50553, 2793, 0, 0, 39, '2792'),
	(377, 1, 0, -50553, 2794, 0, 0, 39, '2793'),
	(377, 1, 0, -50553, 2795, 0, 0, 39, '2794'),
	(377, 1, 0, -50553, 2796, 0, 0, 39, '2795'),
	(377, 1, 0, -50553, 2797, 0, 0, 39, '2796'),
	(377, 1, 0, -50553, 2798, 0, 0, 39, '2797'),
	(377, 1, 0, -50553, 2799, 0, 0, 39, '2798'),
	(377, 1, 0, -50553, 2800, 0, 0, 39, '2799'),
	(377, 1, 0, -50553, 2801, 0, 0, 39, '2800'),
	(377, 1, 0, -50553, 2802, 0, 0, 39, '2801'),
	(377, 1, 0, -50553, 2803, 0, 0, 39, '2802'),
	(377, 1, 0, -50553, 2804, 0, 0, 39, '2803'),
	(377, 1, 0, -50553, 2805, 0, 0, 39, '2804'),
	(377, 1, 0, -50553, 2806, 0, 0, 39, '2805'),
	(377, 1, 0, -50553, 2807, 0, 0, 39, '2806'),
	(377, 1, 0, -50553, 2808, 0, 0, 39, '2807'),
	(377, 1, 0, -50553, 2809, 0, 0, 39, '2808'),
	(377, 1, 0, -50553, 2810, 0, 0, 39, '2809'),
	(377, 1, 0, -50553, 2811, 0, 0, 39, '2810'),
	(377, 1, 0, -50553, 2812, 0, 0, 39, '2811'),
	(377, 1, 0, -50553, 2813, 0, 0, 39, '2812'),
	(377, 1, 0, -50553, 2814, 0, 0, 39, '2813'),
	(377, 1, 0, -50553, 2815, 0, 0, 39, '2814'),
	(377, 1, 0, -50553, 2816, 0, 0, 39, '2815'),
	(377, 1, 0, -50553, 2817, 0, 0, 39, '2816'),
	(377, 1, 0, -50553, 2818, 0, 0, 39, '2817'),
	(377, 1, 0, -50553, 2819, 0, 0, 39, '2818'),
	(377, 1, 0, -50553, 2820, 0, 0, 39, '2819'),
	(377, 1, 0, -50553, 2821, 0, 0, 39, '2820'),
	(377, 1, 0, -50553, 2822, 0, 0, 39, '2821'),
	(377, 1, 0, -50553, 2823, 0, 0, 39, '2822'),
	(377, 1, 0, -50553, 2824, 0, 0, 39, '2823'),
	(377, 1, 0, -50553, 2825, 0, 0, 39, '2824'),
	(377, 1, 0, -50553, 2826, 0, 0, 39, '2825'),
	(377, 1, 0, -50553, 2827, 0, 0, 39, '2826'),
	(377, 1, 0, -50553, 2828, 0, 0, 39, '2827'),
	(377, 1, 0, -50553, 2829, 0, 0, 39, '2828'),
	(377, 1, 0, -50553, 2830, 0, 0, 39, '2829'),
	(377, 1, 0, -50553, 2831, 0, 0, 39, '2830'),
	(377, 1, 0, -50553, 2832, 0, 0, 39, '2831'),
	(377, 1, 0, -50553, 2833, 0, 0, 39, '2832'),
	(377, 1, 0, -50553, 2834, 0, 0, 39, '2833'),
	(377, 1, 0, -50553, 2835, 0, 0, 39, '2834'),
	(377, 1, 0, -50553, 2836, 0, 0, 39, '2835'),
	(377, 1, 0, -50553, 2837, 0, 0, 39, '2836'),
	(377, 1, 0, -50553, 2838, 0, 0, 39, '2837'),
	(377, 1, 0, -50553, 2839, 0, 0, 39, '2838'),
	(377, 1, 0, -50553, 2840, 0, 0, 39, '2839'),
	(377, 1, 0, -50553, 2841, 0, 0, 39, '2840'),
	(377, 1, 0, -50553, 2842, 0, 0, 39, '2841'),
	(377, 1, 0, -50553, 2843, 0, 0, 39, '2842'),
	(377, 1, 0, -50553, 2844, 0, 0, 39, '2843'),
	(377, 1, 0, -50553, 2845, 0, 0, 39, '2844'),
	(377, 1, 0, -50553, 2846, 0, 0, 39, '2845'),
	(377, 1, 0, -50553, 2847, 0, 0, 39, '2846'),
	(377, 1, 0, -50553, 2848, 0, 0, 39, '2847'),
	(377, 1, 0, -50553, 2849, 0, 0, 39, '2848'),
	(377, 1, 0, -50553, 2850, 0, 0, 39, '2849'),
	(377, 1, 0, -50553, 2851, 0, 0, 39, '2850'),
	(377, 1, 0, -50553, 2852, 0, 0, 39, '2851'),
	(377, 1, 0, -50553, 2853, 0, 0, 39, '2852'),
	(377, 1, 0, -50553, 2854, 0, 0, 39, '2853'),
	(377, 1, 0, -50553, 2855, 0, 0, 39, '2854'),
	(377, 1, 0, -50553, 2856, 0, 0, 39, '2855'),
	(377, 1, 0, -50553, 2857, 0, 0, 39, '2856'),
	(377, 1, 0, -50553, 2858, 0, 0, 39, '2857'),
	(377, 1, 0, -50553, 2859, 0, 0, 39, '2858'),
	(377, 1, 0, -50553, 2860, 0, 0, 39, '2859'),
	(377, 1, 0, -50553, 2861, 0, 0, 39, '2860'),
	(377, 1, 0, -50553, 2862, 0, 0, 39, '2861'),
	(377, 1, 0, -50553, 2863, 0, 0, 39, '2862'),
	(377, 1, 0, -50553, 2864, 0, 0, 39, '2863'),
	(377, 1, 0, -50553, 2865, 0, 0, 39, '2864'),
	(377, 1, 0, -50553, 2866, 0, 0, 39, '2865'),
	(377, 1, 0, -50553, 2867, 0, 0, 39, '2866'),
	(377, 1, 0, -50553, 2868, 0, 0, 39, '2867'),
	(377, 1, 0, -50553, 2869, 0, 0, 39, '2868'),
	(377, 1, 0, -50553, 2870, 0, 0, 39, '2869'),
	(377, 1, 0, -50553, 2871, 0, 0, 39, '2870'),
	(377, 1, 0, -50553, 2872, 0, 0, 39, '2871'),
	(377, 1, 0, -50553, 2873, 0, 0, 39, '2872'),
	(377, 1, 0, -50553, 2874, 0, 0, 39, '2873'),
	(377, 1, 0, -50553, 2875, 0, 0, 39, '2874'),
	(377, 1, 0, -50553, 2876, 0, 0, 39, '2875'),
	(377, 1, 0, -50553, 2877, 0, 0, 39, '2876'),
	(377, 1, 0, -50553, 2878, 0, 0, 39, '2877'),
	(377, 1, 0, -50553, 2879, 0, 0, 39, '2878'),
	(377, 1, 0, -50553, 2880, 0, 0, 39, '2879'),
	(377, 1, 0, -50553, 2881, 0, 0, 39, '2880'),
	(377, 1, 0, -50553, 2882, 0, 0, 39, '2881'),
	(377, 1, 0, -50553, 2883, 0, 0, 39, '2882'),
	(377, 1, 0, -50553, 2884, 0, 0, 39, '2883'),
	(377, 1, 0, -50553, 2885, 0, 0, 39, '2884'),
	(377, 1, 0, -50553, 2886, 0, 0, 39, '2885'),
	(377, 1, 0, -50553, 2887, 0, 0, 39, '2886'),
	(377, 1, 0, -50553, 2888, 0, 0, 39, '2887'),
	(377, 1, 0, -50553, 2889, 0, 0, 39, '2888'),
	(377, 1, 0, -50553, 2890, 0, 0, 39, '2889'),
	(377, 1, 0, -50553, 2891, 0, 0, 39, '2890'),
	(377, 1, 0, -50553, 2892, 0, 0, 39, '2891'),
	(377, 1, 0, -50553, 2893, 0, 0, 39, '2892'),
	(377, 1, 0, -50553, 2894, 0, 0, 39, '2893'),
	(377, 1, 0, -50553, 2895, 0, 0, 39, '2894'),
	(377, 1, 0, -50553, 2896, 0, 0, 39, '2895'),
	(377, 1, 0, -50553, 2897, 0, 0, 39, '2896'),
	(377, 1, 0, -50553, 2898, 0, 0, 39, '2897'),
	(377, 1, 0, -50553, 2899, 0, 0, 39, '2898'),
	(377, 1, 0, -50553, 2900, 0, 0, 39, '2899'),
	(377, 1, 0, -50553, 2901, 0, 0, 39, '2900'),
	(377, 1, 0, -50553, 2902, 0, 0, 39, '2901'),
	(377, 1, 0, -50553, 2903, 0, 0, 39, '2902'),
	(377, 1, 0, -50553, 2904, 0, 0, 39, '2903'),
	(377, 1, 0, -50553, 2905, 0, 0, 39, '2904'),
	(377, 1, 0, -50553, 2906, 0, 0, 39, '2905'),
	(377, 1, 0, -50553, 2907, 0, 0, 39, '2906'),
	(377, 1, 0, -50553, 2908, 0, 0, 39, '2907'),
	(377, 1, 0, -50553, 2909, 0, 0, 39, '2908'),
	(377, 1, 0, -50553, 2910, 0, 0, 39, '2909'),
	(377, 1, 0, -50553, 2911, 0, 0, 39, '2910'),
	(377, 1, 0, -50553, 2912, 0, 0, 39, '2911'),
	(377, 1, 0, -50553, 2913, 0, 0, 39, '2912'),
	(377, 1, 0, -50553, 2914, 0, 0, 39, '2913'),
	(377, 1, 0, -50553, 2915, 0, 0, 39, '2914'),
	(377, 1, 0, -50553, 2916, 0, 0, 39, '2915'),
	(377, 1, 0, -50553, 2917, 0, 0, 39, '2916'),
	(377, 1, 0, -50553, 2918, 0, 0, 39, '2917'),
	(377, 1, 0, -50553, 2919, 0, 0, 39, '2918'),
	(377, 1, 0, -50553, 2920, 0, 0, 39, '2919'),
	(377, 1, 0, -50553, 2921, 0, 0, 39, '2920'),
	(377, 1, 0, -50553, 2922, 0, 0, 39, '2921'),
	(377, 1, 0, -50553, 2923, 0, 0, 39, '2922'),
	(377, 1, 0, -50553, 2924, 0, 0, 39, '2923'),
	(377, 1, 0, -50553, 2925, 0, 0, 39, '2924'),
	(377, 1, 0, -50553, 2926, 0, 0, 39, '2925'),
	(377, 1, 0, -50553, 2927, 0, 0, 39, '2926'),
	(377, 1, 0, -50553, 2928, 0, 0, 39, '2927'),
	(377, 1, 0, -50553, 2929, 0, 0, 39, '2928'),
	(377, 1, 0, -50553, 2930, 0, 0, 39, '2929'),
	(377, 1, 0, -50553, 2931, 0, 0, 39, '2930'),
	(377, 1, 0, -50553, 2932, 0, 0, 39, '2931'),
	(377, 1, 0, -50553, 2933, 0, 0, 39, '2932'),
	(377, 1, 0, -50553, 2934, 0, 0, 39, '2933'),
	(377, 1, 0, -50553, 2935, 0, 0, 39, '2934'),
	(377, 1, 0, -50553, 2936, 0, 0, 39, '2935'),
	(377, 1, 0, -50553, 2937, 0, 0, 39, '2936'),
	(377, 1, 0, -50553, 2938, 0, 0, 39, '2937'),
	(377, 1, 0, -50553, 2939, 0, 0, 39, '2938'),
	(377, 1, 0, -50553, 2940, 0, 0, 39, '2939'),
	(377, 1, 0, -50553, 2941, 0, 0, 39, '2940'),
	(377, 1, 0, -50553, 2942, 0, 0, 39, '2941'),
	(377, 1, 0, -50553, 2943, 0, 0, 39, '2942'),
	(377, 1, 0, -50553, 2944, 0, 0, 39, '2943'),
	(377, 1, 0, -50553, 2945, 0, 0, 39, '2944'),
	(377, 1, 0, -50553, 2946, 0, 0, 39, '2945'),
	(377, 1, 0, -50553, 2947, 0, 0, 39, '2946'),
	(377, 1, 0, -50553, 2948, 0, 0, 39, '2947'),
	(377, 1, 0, -50553, 2949, 0, 0, 39, '2948'),
	(377, 1, 0, -50553, 2950, 0, 0, 39, '2949'),
	(377, 1, 0, -50553, 2951, 0, 0, 39, '2950'),
	(377, 1, 0, -50553, 2952, 0, 0, 39, '2951'),
	(377, 1, 0, -50553, 2953, 0, 0, 39, '2952'),
	(377, 1, 0, -50553, 2954, 0, 0, 39, '2953'),
	(377, 1, 0, -50553, 2955, 0, 0, 39, '2954'),
	(377, 1, 0, -50553, 2956, 0, 0, 39, '2955'),
	(377, 1, 0, -50553, 2957, 0, 0, 39, '2956'),
	(377, 1, 0, -50553, 2958, 0, 0, 39, '2957'),
	(377, 1, 0, -50553, 2959, 0, 0, 39, '2958'),
	(377, 1, 0, -50553, 2960, 0, 0, 39, '2959'),
	(377, 1, 0, -50553, 2961, 0, 0, 39, '2960'),
	(377, 1, 0, -50553, 2962, 0, 0, 39, '2961'),
	(377, 1, 0, -50553, 2963, 0, 0, 39, '2962'),
	(377, 1, 0, -50553, 2964, 0, 0, 39, '2963'),
	(377, 1, 0, -50553, 2965, 0, 0, 39, '2964'),
	(377, 1, 0, -50553, 2966, 0, 0, 39, '2965'),
	(377, 1, 0, -50553, 2967, 0, 0, 39, '2966'),
	(377, 1, 0, -50553, 2968, 0, 0, 39, '2967'),
	(377, 1, 0, -50553, 2969, 0, 0, 39, '2968'),
	(377, 1, 0, -50553, 2970, 0, 0, 39, '2969'),
	(377, 1, 0, -50553, 2971, 0, 0, 39, '2970'),
	(377, 1, 0, -50553, 2972, 0, 0, 39, '2971'),
	(377, 1, 0, -50553, 2973, 0, 0, 39, '2972'),
	(377, 1, 0, -50553, 2974, 0, 0, 39, '2973'),
	(377, 1, 0, -50553, 2975, 0, 0, 39, '2974'),
	(377, 1, 0, -50553, 2976, 0, 0, 39, '2975'),
	(377, 1, 0, -50553, 2977, 0, 0, 39, '2976'),
	(377, 1, 0, -50553, 2978, 0, 0, 39, '2977'),
	(377, 1, 0, -50553, 2979, 0, 0, 39, '2978'),
	(377, 1, 0, -50553, 2980, 0, 0, 39, '2979'),
	(377, 1, 0, -50553, 2981, 0, 0, 39, '2980'),
	(377, 1, 0, -50553, 2982, 0, 0, 39, '2981'),
	(377, 1, 0, -50553, 2983, 0, 0, 39, '2982'),
	(377, 1, 0, -50553, 2984, 0, 0, 39, '2983'),
	(377, 1, 0, -50553, 2985, 0, 0, 39, '2984'),
	(377, 1, 0, -50553, 2986, 0, 0, 39, '2985'),
	(377, 1, 0, -50553, 2987, 0, 0, 39, '2986'),
	(377, 1, 0, -50553, 2988, 0, 0, 39, '2987'),
	(377, 1, 0, -50553, 2989, 0, 0, 39, '2988'),
	(377, 1, 0, -50553, 2990, 0, 0, 39, '2989'),
	(377, 1, 0, -50553, 2991, 0, 0, 39, '2990'),
	(377, 1, 0, -50553, 2992, 0, 0, 39, '2991'),
	(377, 1, 0, -50553, 2993, 0, 0, 39, '2992'),
	(377, 1, 0, -50553, 2994, 0, 0, 39, '2993'),
	(377, 1, 0, -50553, 2995, 0, 0, 39, '2994'),
	(377, 1, 0, -50553, 2996, 0, 0, 39, '2995'),
	(377, 1, 0, -50553, 2997, 0, 0, 39, '2996'),
	(377, 1, 0, -50553, 2998, 0, 0, 39, '2997'),
	(377, 1, 0, -50553, 2999, 0, 0, 39, '2998'),
	(377, 1, 0, -50553, 3000, 0, 0, 39, '2999'),
	(377, 1, 0, -50553, 3001, 0, 0, 39, '3000'),
	(377, 1, 0, -50553, 3002, 0, 0, 39, '3001'),
	(377, 1, 0, -50553, 3003, 0, 0, 39, '3002'),
	(377, 1, 0, -50553, 3004, 0, 0, 39, '3003'),
	(377, 1, 0, -50553, 3005, 0, 0, 39, '3004'),
	(377, 1, 0, -50553, 3006, 0, 0, 39, '3005'),
	(377, 1, 0, -50553, 3007, 0, 0, 39, '3006'),
	(377, 1, 0, -50553, 3008, 0, 0, 39, '3007'),
	(377, 1, 0, -50553, 3009, 0, 0, 39, '3008'),
	(377, 1, 0, -50553, 3010, 0, 0, 39, '3009'),
	(377, 1, 0, -50553, 3011, 0, 0, 39, '3010'),
	(377, 1, 0, -50553, 3012, 0, 0, 39, '3011'),
	(377, 1, 0, -50553, 3013, 0, 0, 39, '3012'),
	(377, 1, 0, -50553, 3014, 0, 0, 39, '3013'),
	(377, 1, 0, -50553, 3015, 0, 0, 39, '3014'),
	(377, 1, 0, -50553, 3016, 0, 0, 39, '3015'),
	(377, 1, 0, -50553, 3017, 0, 0, 39, '3016'),
	(377, 1, 0, -50553, 3018, 0, 0, 39, '3017'),
	(377, 1, 0, -50553, 3019, 0, 0, 39, '3018'),
	(377, 1, 0, -50553, 3020, 0, 0, 39, '3019'),
	(377, 1, 0, -50553, 3021, 0, 0, 39, '3020'),
	(377, 1, 0, -50553, 3022, 0, 0, 39, '3021'),
	(377, 1, 0, -50553, 3023, 0, 0, 39, '3022'),
	(377, 1, 0, -50553, 3024, 0, 0, 39, '3023'),
	(377, 1, 0, -50553, 3025, 0, 0, 39, '3024'),
	(377, 1, 0, -50553, 3026, 0, 0, 39, '3025'),
	(377, 1, 0, -50553, 3027, 0, 0, 39, '3026'),
	(377, 1, 0, -50553, 3028, 0, 0, 39, '3027'),
	(377, 1, 0, -50553, 3029, 0, 0, 39, '3028'),
	(377, 1, 0, -50553, 3030, 0, 0, 39, '3029'),
	(377, 1, 0, -50553, 3031, 0, 0, 39, '3030'),
	(377, 1, 0, -50553, 3032, 0, 0, 39, '3031'),
	(377, 1, 0, -50553, 3033, 0, 0, 39, '3032'),
	(377, 1, 0, -50553, 3034, 0, 0, 39, '3033'),
	(377, 1, 0, -50553, 3035, 0, 0, 39, '3034'),
	(377, 1, 0, -50553, 3036, 0, 0, 39, '3035'),
	(377, 1, 0, -50553, 3037, 0, 0, 39, '3036'),
	(377, 1, 0, -50553, 3038, 0, 0, 39, '3037'),
	(377, 1, 0, -50553, 3039, 0, 0, 39, '3038'),
	(377, 1, 0, -50553, 3040, 0, 0, 39, '3039'),
	(377, 1, 0, -50553, 3041, 0, 0, 39, '3040'),
	(377, 1, 0, -50553, 3042, 0, 0, 39, '3041'),
	(377, 1, 0, -50553, 3043, 0, 0, 39, '3042'),
	(377, 1, 0, -50553, 3044, 0, 0, 39, '3043'),
	(377, 1, 0, -50553, 3045, 0, 0, 39, '3044'),
	(377, 1, 0, -50553, 3046, 0, 0, 39, '3045'),
	(377, 1, 0, -50553, 3047, 0, 0, 39, '3046'),
	(377, 1, 0, -50553, 3048, 0, 0, 39, '3047'),
	(377, 1, 0, -50553, 3049, 0, 0, 39, '3048'),
	(377, 1, 0, -50553, 3050, 0, 0, 39, '3049'),
	(377, 1, 0, -50553, 3051, 0, 0, 39, '3050'),
	(377, 1, 0, -50553, 3052, 0, 0, 39, '3051'),
	(377, 1, 0, -50553, 3053, 0, 0, 39, '3052'),
	(377, 1, 0, -50553, 3054, 0, 0, 39, '3053'),
	(377, 1, 0, -50553, 3055, 0, 0, 39, '3054'),
	(377, 1, 0, -50553, 3056, 0, 0, 39, '3055'),
	(377, 1, 0, -50553, 3057, 0, 0, 39, '3056'),
	(377, 1, 0, -50553, 3058, 0, 0, 39, '3057'),
	(377, 1, 0, -50553, 3059, 0, 0, 39, '3058'),
	(377, 1, 0, -50553, 3060, 0, 0, 39, '3059'),
	(377, 1, 0, -50553, 3061, 0, 0, 39, '3060'),
	(377, 1, 0, -50553, 3062, 0, 0, 39, '3061'),
	(377, 1, 0, -50553, 3063, 0, 0, 39, '3062'),
	(377, 1, 0, -50553, 3064, 0, 0, 39, '3063'),
	(377, 1, 0, -50553, 3065, 0, 0, 39, '3064'),
	(377, 1, 0, -50553, 3066, 0, 0, 39, '3065'),
	(377, 1, 0, -50553, 3067, 0, 0, 39, '3066'),
	(377, 1, 0, -50553, 3068, 0, 0, 39, '3067'),
	(377, 1, 0, -50553, 3069, 0, 0, 39, '3068'),
	(377, 1, 0, -50553, 3070, 0, 0, 39, '3069'),
	(377, 1, 0, -50553, 3071, 0, 0, 39, '3070'),
	(377, 1, 0, -50553, 3072, 0, 0, 39, '3071'),
	(377, 1, 0, -50553, 3073, 0, 0, 39, '3072'),
	(377, 1, 0, -50553, 3074, 0, 0, 39, '3073'),
	(377, 1, 0, -50553, 3075, 0, 0, 39, '3074'),
	(377, 1, 0, -50553, 3076, 0, 0, 39, '3075'),
	(377, 1, 0, -50553, 3077, 0, 0, 39, '3076'),
	(377, 1, 0, -50553, 3078, 0, 0, 39, '3077'),
	(377, 1, 0, -50553, 3079, 0, 0, 39, '3078'),
	(377, 1, 0, -50553, 3080, 0, 0, 39, '3079'),
	(377, 1, 0, -50553, 3081, 0, 0, 39, '3080'),
	(377, 1, 0, -50553, 3082, 0, 0, 39, '3081'),
	(377, 1, 0, -50553, 3083, 0, 0, 39, '3082'),
	(377, 1, 0, -50553, 3084, 0, 0, 39, '3083'),
	(377, 1, 0, -50553, 3085, 0, 0, 39, '3084'),
	(377, 1, 0, -50553, 3086, 0, 0, 39, '3085'),
	(377, 1, 0, -50553, 3087, 0, 0, 39, '3086'),
	(377, 1, 0, -50553, 3088, 0, 0, 39, '3087'),
	(377, 1, 0, -50553, 3089, 0, 0, 39, '3088'),
	(377, 1, 0, -50553, 3090, 0, 0, 39, '3089'),
	(377, 1, 0, -50553, 3091, 0, 0, 39, '3090'),
	(377, 1, 0, -50553, 3092, 0, 0, 39, '3091'),
	(377, 1, 0, -50553, 3093, 0, 0, 39, '3092'),
	(377, 1, 0, -50553, 3094, 0, 0, 39, '3093'),
	(377, 1, 0, -50553, 3095, 0, 0, 39, '3094'),
	(377, 1, 0, -50553, 3096, 0, 0, 39, '3095'),
	(377, 1, 0, -50553, 3097, 0, 0, 39, '3096'),
	(377, 1, 0, -50553, 3098, 0, 0, 39, '3097'),
	(377, 1, 0, -50553, 3099, 0, 0, 39, '3098'),
	(377, 1, 0, -50553, 3100, 0, 0, 39, '3099'),
	(377, 1, 0, -50553, 3101, 0, 0, 39, '3100'),
	(377, 1, 0, -50553, 3102, 0, 0, 39, '3101'),
	(377, 1, 0, -50553, 3103, 0, 0, 39, '3102'),
	(377, 1, 0, -50553, 3104, 0, 0, 39, '3103'),
	(377, 1, 0, -50553, 3105, 0, 0, 39, '3104'),
	(377, 1, 0, -50553, 3106, 0, 0, 39, '3105'),
	(377, 1, 0, -50553, 3107, 0, 0, 39, '3106'),
	(377, 1, 0, -50553, 3108, 0, 0, 39, '3107'),
	(377, 1, 0, -50553, 3109, 0, 0, 39, '3108'),
	(377, 1, 0, -50553, 3110, 0, 0, 39, '3109'),
	(377, 1, 0, -50553, 3111, 0, 0, 39, '3110'),
	(377, 1, 0, -50553, 3112, 0, 0, 39, '3111'),
	(377, 1, 0, -50553, 3113, 0, 0, 39, '3112'),
	(377, 1, 0, -50553, 3114, 0, 0, 39, '3113'),
	(377, 1, 0, -50553, 3115, 0, 0, 39, '3114'),
	(377, 1, 0, -50553, 3116, 0, 0, 39, '3115'),
	(377, 1, 0, -50553, 3117, 0, 0, 39, '3116'),
	(377, 1, 0, -50553, 3118, 0, 0, 39, '3117'),
	(377, 1, 0, -50553, 3119, 0, 0, 39, '3118'),
	(377, 1, 0, -50553, 3120, 0, 0, 39, '3119'),
	(377, 1, 0, -50553, 3121, 0, 0, 39, '3120'),
	(377, 1, 0, -50553, 3122, 0, 0, 39, '3121'),
	(377, 1, 0, -50553, 3123, 0, 0, 39, '3122'),
	(377, 1, 0, -50553, 3124, 0, 0, 39, '3123'),
	(377, 1, 0, -50553, 3125, 0, 0, 39, '3124'),
	(377, 1, 0, -50553, 3126, 0, 0, 39, '3125'),
	(377, 1, 0, -50553, 3127, 0, 0, 39, '3126'),
	(377, 1, 0, -50553, 3128, 0, 0, 39, '3127'),
	(377, 1, 0, -50553, 3129, 0, 0, 39, '3128'),
	(377, 1, 0, -50553, 3130, 0, 0, 39, '3129'),
	(377, 1, 0, -50553, 3131, 0, 0, 39, '3130'),
	(377, 1, 0, -50553, 3132, 0, 0, 39, '3131'),
	(377, 1, 0, -50553, 3133, 0, 0, 39, '3132'),
	(377, 1, 0, -50553, 3134, 0, 0, 39, '3133'),
	(377, 1, 0, -50553, 3135, 0, 0, 39, '3134'),
	(377, 1, 0, -50553, 3136, 0, 0, 39, '3135'),
	(377, 1, 0, -50553, 3137, 0, 0, 39, '3136'),
	(377, 1, 0, -50553, 3138, 0, 0, 39, '3137'),
	(377, 1, 0, -50553, 3139, 0, 0, 39, '3138'),
	(377, 1, 0, -50553, 3140, 0, 0, 39, '3139'),
	(377, 1, 0, -50553, 3141, 0, 0, 39, '3140'),
	(377, 1, 0, -50553, 3142, 0, 0, 39, '3141'),
	(377, 1, 0, -50553, 3143, 0, 0, 39, '3142'),
	(377, 1, 0, -50553, 3144, 0, 0, 39, '3143'),
	(377, 1, 0, -50553, 3145, 0, 0, 39, '3144'),
	(377, 1, 0, -50553, 3146, 0, 0, 39, '3145'),
	(377, 1, 0, -50553, 3147, 0, 0, 39, '3146'),
	(377, 1, 0, -50553, 3148, 0, 0, 39, '3147'),
	(377, 1, 0, -50553, 3149, 0, 0, 39, '3148'),
	(377, 1, 0, -50553, 3150, 0, 0, 39, '3149'),
	(377, 1, 0, -50553, 3151, 0, 0, 39, '3150'),
	(377, 1, 0, -50553, 3152, 0, 0, 39, '3151'),
	(377, 1, 0, -50553, 3153, 0, 0, 39, '3152'),
	(377, 1, 0, -50553, 3154, 0, 0, 39, '3153'),
	(377, 1, 0, -50553, 3155, 0, 0, 39, '3154'),
	(377, 1, 0, -50553, 3156, 0, 0, 39, '3155'),
	(377, 1, 0, -50553, 3157, 0, 0, 39, '3156'),
	(377, 1, 0, -50553, 3158, 0, 0, 39, '3157'),
	(377, 1, 0, -50553, 3159, 0, 0, 39, '3158'),
	(377, 1, 0, -50553, 3160, 0, 0, 39, '3159'),
	(377, 1, 0, -50553, 3161, 0, 0, 39, '3160'),
	(377, 1, 0, -50553, 3162, 0, 0, 39, '3161'),
	(377, 1, 0, -50553, 3163, 0, 0, 39, '3162'),
	(377, 1, 0, -50553, 3164, 0, 0, 39, '3163'),
	(377, 1, 0, -50553, 3165, 0, 0, 39, '3164'),
	(377, 1, 0, -50553, 3166, 0, 0, 39, '3165'),
	(377, 1, 0, -50553, 3167, 0, 0, 39, '3166'),
	(377, 1, 0, -50553, 3168, 0, 0, 39, '3167'),
	(377, 1, 0, -50553, 3169, 0, 0, 39, '3168'),
	(377, 1, 0, -50553, 3170, 0, 0, 39, '3169'),
	(377, 1, 0, -50553, 3171, 0, 0, 39, '3170'),
	(377, 1, 0, -50553, 3172, 0, 0, 39, '3171'),
	(377, 1, 0, -50553, 3173, 0, 0, 39, '3172'),
	(377, 1, 0, -50553, 3174, 0, 0, 39, '3173'),
	(377, 1, 0, -50553, 3175, 0, 0, 39, '3174'),
	(377, 1, 0, -50553, 3176, 0, 0, 39, '3175'),
	(377, 1, 0, -50553, 3177, 0, 0, 39, '3176'),
	(377, 1, 0, -50553, 3178, 0, 0, 39, '3177'),
	(377, 1, 0, -50553, 3179, 0, 0, 39, '3178'),
	(377, 1, 0, -50553, 3180, 0, 0, 39, '3179'),
	(377, 1, 0, -50553, 3181, 0, 0, 39, '3180'),
	(377, 1, 0, -50553, 3182, 0, 0, 39, '3181'),
	(377, 1, 0, -50553, 3183, 0, 0, 39, '3182'),
	(377, 1, 0, -50553, 3184, 0, 0, 39, '3183'),
	(377, 1, 0, -50553, 3185, 0, 0, 39, '3184'),
	(377, 1, 0, -50553, 3186, 0, 0, 39, '3185'),
	(377, 1, 0, -50553, 3187, 0, 0, 39, '3186'),
	(377, 1, 0, -50553, 3188, 0, 0, 39, '3187'),
	(377, 1, 0, -50553, 3189, 0, 0, 39, '3188'),
	(377, 1, 0, -50553, 3190, 0, 0, 39, '3189'),
	(377, 1, 0, -50553, 3191, 0, 0, 39, '3190'),
	(377, 1, 0, -50553, 3192, 0, 0, 39, '3191'),
	(377, 1, 0, -50553, 3193, 0, 0, 39, '3192'),
	(377, 1, 0, -50553, 3194, 0, 0, 39, '3193'),
	(377, 1, 0, -50553, 3195, 0, 0, 39, '3194'),
	(377, 1, 0, -50553, 3196, 0, 0, 39, '3195'),
	(377, 1, 0, -50553, 3197, 0, 0, 39, '3196'),
	(377, 1, 0, -50553, 3198, 0, 0, 39, '3197'),
	(377, 1, 0, -50553, 3199, 0, 0, 39, '3198'),
	(377, 1, 0, -50553, 3200, 0, 0, 39, '3199'),
	(377, 1, 0, -50553, 3201, 0, 0, 39, '3200'),
	(377, 1, 0, -50553, 3202, 0, 0, 39, '3201'),
	(377, 1, 0, -50553, 3203, 0, 0, 39, '3202'),
	(377, 1, 0, -50553, 3204, 0, 0, 39, '3203'),
	(377, 1, 0, -50553, 3205, 0, 0, 39, '3204'),
	(377, 1, 0, -50553, 3206, 0, 0, 39, '3205'),
	(377, 1, 0, -50553, 3207, 0, 0, 39, '3206'),
	(377, 1, 0, -50553, 3208, 0, 0, 39, '3207'),
	(377, 1, 0, -50553, 3209, 0, 0, 39, '3208'),
	(377, 1, 0, -50553, 3210, 0, 0, 39, '3209'),
	(377, 1, 0, -50553, 3211, 0, 0, 39, '3210'),
	(377, 1, 0, -50553, 3212, 0, 0, 39, '3211'),
	(377, 1, 0, -50553, 3213, 0, 0, 39, '3212'),
	(377, 1, 0, -50553, 3214, 0, 0, 39, '3213'),
	(377, 1, 0, -50553, 3215, 0, 0, 39, '3214'),
	(377, 1, 0, -50553, 3216, 0, 0, 39, '3215'),
	(377, 1, 0, -50553, 3217, 0, 0, 39, '3216'),
	(377, 1, 0, -50553, 3218, 0, 0, 39, '3217'),
	(377, 1, 0, -50553, 3219, 0, 0, 39, '3218'),
	(377, 1, 0, -50553, 3220, 0, 0, 39, '3219'),
	(377, 1, 0, -50553, 3221, 0, 0, 39, '3220'),
	(377, 1, 0, -50553, 3222, 0, 0, 39, '3221'),
	(377, 1, 0, -50553, 3223, 0, 0, 39, '3222'),
	(377, 1, 0, -50553, 3224, 0, 0, 39, '3223'),
	(377, 1, 0, -50553, 3225, 0, 0, 39, '3224'),
	(377, 1, 0, -50553, 3226, 0, 0, 39, '3225'),
	(377, 1, 0, -50553, 3227, 0, 0, 39, '3226'),
	(377, 1, 0, -50553, 3228, 0, 0, 39, '3227'),
	(377, 1, 0, -50553, 3229, 0, 0, 39, '3228'),
	(377, 1, 0, -50553, 3230, 0, 0, 39, '3229'),
	(377, 1, 0, -50553, 3231, 0, 0, 39, '3230'),
	(377, 1, 0, -50553, 3232, 0, 0, 39, '3231'),
	(377, 1, 0, -50553, 3233, 0, 0, 39, '3232'),
	(377, 1, 0, -50553, 3234, 0, 0, 39, '3233'),
	(377, 1, 0, -50553, 3235, 0, 0, 39, '3234'),
	(377, 1, 0, -50553, 3236, 0, 0, 39, '3235'),
	(377, 1, 0, -50553, 3237, 0, 0, 39, '3236'),
	(377, 1, 0, -50553, 3238, 0, 0, 39, '3237'),
	(377, 1, 0, -50553, 3239, 0, 0, 39, '3238'),
	(377, 1, 0, -50553, 3240, 0, 0, 39, '3239'),
	(377, 1, 0, -50553, 3241, 0, 0, 39, '3240'),
	(377, 1, 0, -50553, 3242, 0, 0, 39, '3241'),
	(377, 1, 0, -50553, 3243, 0, 0, 39, '3242'),
	(377, 1, 0, -50553, 3244, 0, 0, 39, '3243'),
	(377, 1, 0, -50553, 3245, 0, 0, 39, '3244'),
	(377, 1, 0, -50553, 3246, 0, 0, 39, '3245'),
	(377, 1, 0, -50553, 3247, 0, 0, 39, '3246'),
	(377, 1, 0, -50553, 3248, 0, 0, 39, '3247'),
	(377, 1, 0, -50553, 3249, 0, 0, 39, '3248'),
	(377, 1, 0, -50553, 3250, 0, 0, 39, '3249'),
	(377, 1, 0, -50553, 3251, 0, 0, 39, '3250'),
	(377, 1, 0, -50553, 3252, 0, 0, 39, '3251'),
	(377, 1, 0, -50553, 3253, 0, 0, 39, '3252'),
	(377, 1, 0, -50553, 3254, 0, 0, 39, '3253'),
	(377, 1, 0, -50553, 3255, 0, 0, 39, '3254'),
	(377, 1, 0, -50553, 3256, 0, 0, 39, '3255'),
	(377, 1, 0, -50553, 3257, 0, 0, 39, '3256'),
	(377, 1, 0, -50553, 3258, 0, 0, 39, '3257'),
	(377, 1, 0, -50553, 3259, 0, 0, 39, '3258'),
	(377, 1, 0, -50553, 3260, 0, 0, 39, '3259'),
	(377, 1, 0, -50553, 3261, 0, 0, 39, '3260'),
	(377, 1, 0, -50553, 3262, 0, 0, 39, '3261'),
	(377, 1, 0, -50553, 3263, 0, 0, 39, '3262'),
	(377, 1, 0, -50553, 3264, 0, 0, 39, '3263'),
	(377, 1, 0, -50553, 3265, 0, 0, 39, '3264'),
	(377, 1, 0, -50553, 3266, 0, 0, 39, '3265'),
	(377, 1, 0, -50553, 3267, 0, 0, 39, '3266'),
	(377, 1, 0, -50553, 3268, 0, 0, 39, '3267'),
	(377, 1, 0, -50553, 3269, 0, 0, 39, '3268'),
	(377, 1, 0, -50553, 3270, 0, 0, 39, '3269'),
	(377, 1, 0, -50553, 3271, 0, 0, 39, '3270'),
	(377, 1, 0, -50553, 3272, 0, 0, 39, '3271'),
	(377, 1, 0, -50553, 3273, 0, 0, 39, '3272'),
	(377, 1, 0, -50553, 3274, 0, 0, 39, '3273'),
	(377, 1, 0, -50553, 3275, 0, 0, 39, '3274'),
	(377, 1, 0, -50553, 3276, 0, 0, 39, '3275'),
	(377, 1, 0, -50553, 3277, 0, 0, 39, '3276'),
	(377, 1, 0, -50553, 3278, 0, 0, 39, '3277'),
	(377, 1, 0, -50553, 3279, 0, 0, 39, '3278'),
	(377, 1, 0, -50553, 3280, 0, 0, 39, '3279'),
	(377, 1, 0, -50553, 3281, 0, 0, 39, '3280'),
	(377, 1, 0, -50553, 3282, 0, 0, 39, '3281'),
	(377, 1, 0, -50553, 3283, 0, 0, 39, '3282'),
	(377, 1, 0, -50553, 3284, 0, 0, 39, '3283'),
	(377, 1, 0, -50553, 3285, 0, 0, 39, '3284'),
	(377, 1, 0, -50553, 3286, 0, 0, 39, '3285'),
	(377, 1, 0, -50553, 3287, 0, 0, 39, '3286'),
	(377, 1, 0, -50553, 3288, 0, 0, 39, '3287'),
	(377, 1, 0, -50553, 3289, 0, 0, 39, '3288'),
	(377, 1, 0, -50553, 3290, 0, 0, 39, '3289'),
	(377, 1, 0, -50553, 3291, 0, 0, 39, '3290'),
	(377, 1, 0, -50553, 3292, 0, 0, 39, '3291'),
	(377, 1, 0, -50553, 3293, 0, 0, 39, '3292'),
	(377, 1, 0, -50553, 3294, 0, 0, 39, '3293'),
	(377, 1, 0, -50553, 3295, 0, 0, 39, '3294'),
	(377, 1, 0, -50553, 3296, 0, 0, 39, '3295'),
	(377, 1, 0, -50553, 3297, 0, 0, 39, '3296'),
	(377, 1, 0, -50553, 3298, 0, 0, 39, '3297'),
	(377, 1, 0, -50553, 3299, 0, 0, 39, '3298'),
	(377, 1, 0, -50553, 3300, 0, 0, 39, '3299'),
	(377, 1, 0, -50553, 3301, 0, 0, 39, '3300'),
	(377, 1, 0, -50553, 3302, 0, 0, 39, '3301'),
	(377, 1, 0, -50553, 3303, 0, 0, 39, '3302'),
	(377, 1, 0, -50553, 3304, 0, 0, 39, '3303'),
	(377, 1, 0, -50553, 3305, 0, 0, 39, '3304'),
	(377, 1, 0, -50553, 3306, 0, 0, 39, '3305'),
	(377, 1, 0, -50553, 3307, 0, 0, 39, '3306'),
	(377, 1, 0, -50553, 3308, 0, 0, 39, '3307'),
	(377, 1, 0, -50553, 3309, 0, 0, 39, '3308'),
	(377, 1, 0, -50553, 3310, 0, 0, 39, '3309'),
	(377, 1, 0, -50553, 3311, 0, 0, 39, '3310'),
	(377, 1, 0, -50553, 3312, 0, 0, 39, '3311'),
	(377, 1, 0, -50553, 3313, 0, 0, 39, '3312'),
	(377, 1, 0, -50553, 3314, 0, 0, 39, '3313'),
	(377, 1, 0, -50553, 3315, 0, 0, 39, '3314'),
	(377, 1, 0, -50553, 3316, 0, 0, 39, '3315'),
	(377, 1, 0, -50553, 3317, 0, 0, 39, '3316'),
	(377, 1, 0, -50553, 3318, 0, 0, 39, '3317'),
	(377, 1, 0, -50553, 3319, 0, 0, 39, '3318'),
	(377, 1, 0, -50553, 3320, 0, 0, 39, '3319'),
	(377, 1, 0, -50553, 3321, 0, 0, 39, '3320'),
	(377, 1, 0, -50553, 3322, 0, 0, 39, '3321'),
	(377, 1, 0, -50553, 3323, 0, 0, 39, '3322'),
	(377, 1, 0, -50553, 3324, 0, 0, 39, '3323'),
	(377, 1, 0, -50553, 3325, 0, 0, 39, '3324'),
	(377, 1, 0, -50553, 3326, 0, 0, 39, '3325'),
	(377, 1, 0, -50553, 3327, 0, 0, 39, '3326'),
	(377, 1, 0, -50553, 3328, 0, 0, 39, '3327'),
	(377, 1, 0, -50553, 3329, 0, 0, 39, '3328'),
	(377, 1, 0, -50553, 3330, 0, 0, 39, '3329'),
	(377, 1, 0, -50553, 3331, 0, 0, 39, '3330'),
	(377, 1, 0, -50553, 3332, 0, 0, 39, '3331'),
	(377, 1, 0, -50553, 3333, 0, 0, 39, '3332'),
	(377, 1, 0, -50553, 3334, 0, 0, 39, '3333'),
	(377, 1, 0, -50553, 3335, 0, 0, 39, '3334'),
	(377, 1, 0, -50553, 3336, 0, 0, 39, '3335'),
	(377, 1, 0, -50553, 3337, 0, 0, 39, '3336'),
	(377, 1, 0, -50553, 3338, 0, 0, 39, '3337'),
	(377, 1, 0, -50553, 3339, 0, 0, 39, '3338'),
	(377, 1, 0, -50553, 3340, 0, 0, 39, '3339'),
	(377, 1, 0, -50553, 3341, 0, 0, 39, '3340'),
	(377, 1, 0, -50553, 3342, 0, 0, 39, '3341'),
	(377, 1, 0, -50553, 3343, 0, 0, 39, '3342'),
	(377, 1, 0, -50553, 3344, 0, 0, 39, '3343'),
	(377, 1, 0, -50553, 3345, 0, 0, 39, '3344'),
	(377, 1, 0, -50553, 3346, 0, 0, 39, '3345'),
	(377, 1, 0, -50553, 3347, 0, 0, 39, '3346'),
	(377, 1, 0, -50553, 3348, 0, 0, 39, '3347'),
	(377, 1, 0, -50553, 3349, 0, 0, 39, '3348'),
	(377, 1, 0, -50553, 3350, 0, 0, 39, '3349'),
	(377, 1, 0, -50553, 3351, 0, 0, 39, '3350'),
	(377, 1, 0, -50553, 3352, 0, 0, 39, '3351'),
	(377, 1, 0, -50553, 3353, 0, 0, 39, '3352'),
	(377, 1, 0, -50553, 3354, 0, 0, 39, '3353'),
	(377, 1, 0, -50553, 3355, 0, 0, 39, '3354'),
	(377, 1, 0, -50553, 3356, 0, 0, 39, '3355'),
	(377, 1, 0, -50553, 3357, 0, 0, 39, '3356'),
	(377, 1, 0, -50553, 3358, 0, 0, 39, '3357'),
	(377, 1, 0, -50553, 3359, 0, 0, 39, '3358'),
	(377, 1, 0, -50553, 3360, 0, 0, 39, '3359'),
	(377, 1, 0, -50553, 3361, 0, 0, 39, '3360'),
	(377, 1, 0, -50553, 3362, 0, 0, 39, '3361'),
	(377, 1, 0, -50553, 3363, 0, 0, 39, '3362'),
	(377, 1, 0, -50553, 3364, 0, 0, 39, '3363'),
	(377, 1, 0, -50553, 3365, 0, 0, 39, '3364'),
	(377, 1, 0, -50553, 3366, 0, 0, 39, '3365'),
	(377, 1, 0, -50553, 3367, 0, 0, 39, '3366'),
	(377, 1, 0, -50553, 3368, 0, 0, 39, '3367'),
	(377, 1, 0, -50553, 3369, 0, 0, 39, '3368'),
	(377, 1, 0, -50553, 3370, 0, 0, 39, '3369'),
	(377, 1, 0, -50553, 3371, 0, 0, 39, '3370'),
	(377, 1, 0, -50553, 3372, 0, 0, 39, '3371'),
	(377, 1, 0, -50553, 3373, 0, 0, 39, '3372'),
	(377, 1, 0, -50553, 3374, 0, 0, 39, '3373'),
	(377, 1, 0, -50553, 3375, 0, 0, 39, '3374'),
	(377, 1, 0, -50553, 3376, 0, 0, 39, '3375'),
	(377, 1, 0, -50553, 3377, 0, 0, 39, '3376'),
	(377, 1, 0, -50553, 3378, 0, 0, 39, '3377'),
	(377, 1, 0, -50553, 3379, 0, 0, 39, '3378'),
	(377, 1, 0, -50553, 3380, 0, 0, 39, '3379'),
	(377, 1, 0, -50553, 3381, 0, 0, 39, '3380'),
	(377, 1, 0, -50553, 3382, 0, 0, 39, '3381'),
	(377, 1, 0, -50553, 3383, 0, 0, 39, '3382'),
	(377, 1, 0, -50553, 3384, 0, 0, 39, '3383'),
	(377, 1, 0, -50553, 3385, 0, 0, 39, '3384'),
	(377, 1, 0, -50553, 3386, 0, 0, 39, '3385'),
	(377, 1, 0, -50553, 3387, 0, 0, 39, '3386'),
	(377, 1, 0, -50553, 3388, 0, 0, 39, '3387'),
	(377, 1, 0, -50553, 3389, 0, 0, 39, '3388'),
	(377, 1, 0, -50553, 3390, 0, 0, 39, '3389'),
	(377, 1, 0, -50553, 3391, 0, 0, 39, '3390'),
	(377, 1, 0, -50553, 3392, 0, 0, 39, '3391'),
	(377, 1, 0, -50553, 3393, 0, 0, 39, '3392'),
	(377, 1, 0, -50553, 3394, 0, 0, 39, '3393'),
	(377, 1, 0, -50553, 3395, 0, 0, 39, '3394'),
	(377, 1, 0, -50553, 3396, 0, 0, 39, '3395'),
	(377, 1, 0, -50553, 3397, 0, 0, 39, '3396'),
	(377, 1, 0, -50553, 3398, 0, 0, 39, '3397'),
	(377, 1, 0, -50553, 3399, 0, 0, 39, '3398'),
	(377, 1, 0, -50553, 3400, 0, 0, 39, '3399'),
	(377, 1, 0, -50553, 3401, 0, 0, 39, '3400'),
	(377, 1, 0, -50553, 3402, 0, 0, 39, '3401'),
	(377, 1, 0, -50553, 3403, 0, 0, 39, '3402'),
	(377, 1, 0, -50553, 3404, 0, 0, 39, '3403'),
	(377, 1, 0, -50553, 3405, 0, 0, 39, '3404'),
	(377, 1, 0, -50553, 3406, 0, 0, 39, '3405'),
	(377, 1, 0, -50553, 3407, 0, 0, 39, '3406'),
	(377, 1, 0, -50553, 3408, 0, 0, 39, '3407'),
	(377, 1, 0, -50553, 3409, 0, 0, 39, '3408'),
	(377, 1, 0, -50553, 3410, 0, 0, 39, '3409'),
	(377, 1, 0, -50553, 3411, 0, 0, 39, '3410'),
	(377, 1, 0, -50553, 3412, 0, 0, 39, '3411'),
	(377, 1, 0, -50553, 3413, 0, 0, 39, '3412'),
	(377, 1, 0, -50553, 3414, 0, 0, 39, '3413'),
	(377, 1, 0, -50553, 3415, 0, 0, 39, '3414'),
	(377, 1, 0, -50553, 3416, 0, 0, 39, '3415'),
	(377, 1, 0, -50553, 3417, 0, 0, 39, '3416'),
	(377, 1, 0, -50553, 3418, 0, 0, 39, '3417'),
	(377, 1, 0, -50553, 3419, 0, 0, 39, '3418'),
	(377, 1, 0, -50553, 3420, 0, 0, 39, '3419'),
	(377, 1, 0, -50553, 3421, 0, 0, 39, '3420'),
	(377, 1, 0, -50553, 3422, 0, 0, 39, '3421'),
	(377, 1, 0, -50553, 3423, 0, 0, 39, '3422'),
	(377, 1, 0, -50553, 3424, 0, 0, 39, '3423'),
	(377, 1, 0, -50553, 3425, 0, 0, 39, '3424'),
	(377, 1, 0, -50553, 3426, 0, 0, 39, '3425'),
	(377, 1, 0, -50553, 3427, 0, 0, 39, '3426'),
	(377, 1, 0, -50553, 3428, 0, 0, 39, '3427'),
	(377, 1, 0, -50553, 3429, 0, 0, 39, '3428'),
	(377, 1, 0, -50553, 3430, 0, 0, 39, '3429'),
	(377, 1, 0, -50553, 3431, 0, 0, 39, '3430'),
	(377, 1, 0, -50553, 3432, 0, 0, 39, '3431'),
	(377, 1, 0, -50553, 3433, 0, 0, 39, '3432'),
	(377, 1, 0, -50553, 3434, 0, 0, 39, '3433'),
	(377, 1, 0, -50553, 3435, 0, 0, 39, '3434'),
	(377, 1, 0, -50553, 3436, 0, 0, 39, '3435'),
	(377, 1, 0, -50553, 3437, 0, 0, 39, '3436'),
	(377, 1, 0, -50553, 3438, 0, 0, 39, '3437'),
	(377, 1, 0, -50553, 3439, 0, 0, 39, '3438'),
	(377, 1, 0, -50553, 3440, 0, 0, 39, '3439'),
	(377, 1, 0, -50553, 3441, 0, 0, 39, '3440'),
	(377, 1, 0, -50553, 3442, 0, 0, 39, '3441'),
	(377, 1, 0, -50553, 3443, 0, 0, 39, '3442'),
	(377, 1, 0, -50553, 3444, 0, 0, 39, '3443'),
	(377, 1, 0, -50553, 3445, 0, 0, 39, '3444'),
	(377, 1, 0, -50553, 3446, 0, 0, 39, '3445'),
	(377, 1, 0, -50553, 3447, 0, 0, 39, '3446'),
	(377, 1, 0, -50553, 3448, 0, 0, 39, '3447'),
	(377, 1, 0, -50553, 3449, 0, 0, 39, '3448'),
	(377, 1, 0, -50553, 3450, 0, 0, 39, '3449'),
	(377, 1, 0, -50553, 3451, 0, 0, 39, '3450'),
	(377, 1, 0, -50553, 3452, 0, 0, 39, '3451'),
	(377, 1, 0, -50553, 3453, 0, 0, 39, '3452'),
	(377, 1, 0, -50553, 3454, 0, 0, 39, '3453'),
	(377, 1, 0, -50553, 3455, 0, 0, 39, '3454'),
	(377, 1, 0, -50553, 3456, 0, 0, 39, '3455'),
	(377, 1, 0, -50553, 3457, 0, 0, 39, '3456'),
	(377, 1, 0, -50553, 3458, 0, 0, 39, '3457'),
	(377, 1, 0, -50553, 3459, 0, 0, 39, '3458'),
	(377, 1, 0, -50553, 3460, 0, 0, 39, '3459'),
	(377, 1, 0, -50553, 3461, 0, 0, 39, '3460'),
	(377, 1, 0, -50553, 3462, 0, 0, 39, '3461'),
	(377, 1, 0, -50553, 3463, 0, 0, 39, '3462'),
	(377, 1, 0, -50553, 3464, 0, 0, 39, '3463'),
	(377, 1, 0, -50553, 3465, 0, 0, 39, '3464'),
	(377, 1, 0, -50553, 3466, 0, 0, 39, '3465'),
	(377, 1, 0, -50553, 3467, 0, 0, 39, '3466'),
	(377, 1, 0, -50553, 3468, 0, 0, 39, '3467'),
	(377, 1, 0, -50553, 3469, 0, 0, 39, '3468'),
	(377, 1, 0, -50553, 3470, 0, 0, 39, '3469'),
	(377, 1, 0, -50553, 3471, 0, 0, 39, '3470'),
	(377, 1, 0, -50553, 3472, 0, 0, 39, '3471'),
	(377, 1, 0, -50553, 3473, 0, 0, 39, '3472'),
	(377, 1, 0, -50553, 3474, 0, 0, 39, '3473'),
	(377, 1, 0, -50553, 3475, 0, 0, 39, '3474'),
	(377, 1, 0, -50553, 3476, 0, 0, 39, '3475'),
	(377, 1, 0, -50553, 3477, 0, 0, 39, '3476'),
	(377, 1, 0, -50553, 3478, 0, 0, 39, '3477'),
	(377, 1, 0, -50553, 3479, 0, 0, 39, '3478'),
	(377, 1, 0, -50553, 3480, 0, 0, 39, '3479'),
	(377, 1, 0, -50553, 3481, 0, 0, 39, '3480'),
	(377, 1, 0, -50553, 3482, 0, 0, 39, '3481'),
	(377, 1, 0, -50553, 3483, 0, 0, 39, '3482'),
	(377, 1, 0, -50553, 3484, 0, 0, 39, '3483'),
	(377, 1, 0, -50553, 3485, 0, 0, 39, '3484'),
	(377, 1, 0, -50553, 3486, 0, 0, 39, '3485'),
	(377, 1, 0, -50553, 3487, 0, 0, 39, '3486'),
	(377, 1, 0, -50553, 3488, 0, 0, 39, '3487'),
	(377, 1, 0, -50553, 3489, 0, 0, 39, '3488'),
	(377, 1, 0, -50553, 3490, 0, 0, 39, '3489'),
	(377, 1, 0, -50553, 3491, 0, 0, 39, '3490'),
	(377, 1, 0, -50553, 3492, 0, 0, 39, '3491'),
	(377, 1, 0, -50553, 3493, 0, 0, 39, '3492'),
	(377, 1, 0, -50553, 3494, 0, 0, 39, '3493'),
	(377, 1, 0, -50553, 3495, 0, 0, 39, '3494'),
	(377, 1, 0, -50553, 3496, 0, 0, 39, '3495'),
	(377, 1, 0, -50553, 3497, 0, 0, 39, '3496'),
	(377, 1, 0, -50553, 3498, 0, 0, 39, '3497'),
	(377, 1, 0, -50553, 3499, 0, 0, 39, '3498'),
	(377, 1, 0, -50553, 3500, 0, 0, 39, '3499'),
	(377, 1, 0, -50553, 3501, 0, 0, 39, '3500'),
	(377, 1, 0, -50553, 3502, 0, 0, 39, '3501'),
	(377, 1, 0, -50553, 3503, 0, 0, 39, '3502'),
	(377, 1, 0, -50553, 3504, 0, 0, 39, '3503'),
	(377, 1, 0, -50553, 3505, 0, 0, 39, '3504'),
	(377, 1, 0, -50553, 3506, 0, 0, 39, '3505'),
	(377, 1, 0, -50553, 3507, 0, 0, 39, '3506'),
	(377, 1, 0, -50553, 3508, 0, 0, 39, '3507'),
	(377, 1, 0, -50553, 3509, 0, 0, 39, '3508'),
	(377, 1, 0, -50553, 3510, 0, 0, 39, '3509'),
	(377, 1, 0, -50553, 3511, 0, 0, 39, '3510'),
	(377, 1, 0, -50553, 3512, 0, 0, 39, '3511'),
	(377, 1, 0, -50553, 3513, 0, 0, 39, '3512'),
	(377, 1, 0, -50553, 3514, 0, 0, 39, '3513'),
	(377, 1, 0, -50553, 3515, 0, 0, 39, '3514'),
	(377, 1, 0, -50553, 3516, 0, 0, 39, '3515'),
	(377, 1, 0, -50553, 3517, 0, 0, 39, '3516'),
	(377, 1, 0, -50553, 3518, 0, 0, 39, '3517'),
	(377, 1, 0, -50553, 3519, 0, 0, 39, '3518'),
	(377, 1, 0, -50553, 3520, 0, 0, 39, '3519'),
	(377, 1, 0, -50553, 3521, 0, 0, 39, '3520'),
	(377, 1, 0, -50553, 3522, 0, 0, 39, '3521'),
	(377, 1, 0, -50553, 3523, 0, 0, 39, '3522'),
	(377, 1, 0, -50553, 3524, 0, 0, 39, '3523'),
	(377, 1, 0, -50553, 3525, 0, 0, 39, '3524'),
	(377, 1, 0, -50553, 3526, 0, 0, 39, '3525'),
	(377, 1, 0, -50553, 3527, 0, 0, 39, '3526'),
	(377, 1, 0, -50553, 3528, 0, 0, 39, '3527'),
	(377, 1, 0, -50553, 3529, 0, 0, 39, '3528'),
	(377, 1, 0, -50553, 3530, 0, 0, 39, '3529'),
	(377, 1, 0, -50553, 3531, 0, 0, 39, '3530'),
	(377, 1, 0, -50553, 3532, 0, 0, 39, '3531'),
	(377, 1, 0, -50553, 3533, 0, 0, 39, '3532'),
	(377, 1, 0, -50553, 3534, 0, 0, 39, '3533'),
	(377, 1, 0, -50553, 3535, 0, 0, 39, '3534'),
	(377, 1, 0, -50553, 3536, 0, 0, 39, '3535'),
	(377, 1, 0, -50553, 3537, 0, 0, 39, '3536'),
	(377, 1, 0, -50553, 3538, 0, 0, 39, '3537'),
	(377, 1, 0, -50553, 3539, 0, 0, 39, '3538'),
	(377, 1, 0, -50553, 3540, 0, 0, 39, '3539'),
	(377, 1, 0, -50553, 3541, 0, 0, 39, '3540'),
	(377, 1, 0, -50553, 3542, 0, 0, 39, '3541'),
	(377, 1, 0, -50553, 3543, 0, 0, 39, '3542'),
	(377, 1, 0, -50553, 3544, 0, 0, 39, '3543'),
	(377, 1, 0, -50553, 3545, 0, 0, 39, '3544'),
	(377, 1, 0, -50553, 3546, 0, 0, 39, '3545'),
	(377, 1, 0, -50553, 3547, 0, 0, 39, '3546'),
	(377, 1, 0, -50553, 3548, 0, 0, 39, '3547'),
	(377, 1, 0, -50553, 3549, 0, 0, 39, '3548'),
	(377, 1, 0, -50553, 3550, 0, 0, 39, '3549'),
	(377, 1, 0, -50553, 3551, 0, 0, 39, '3550'),
	(377, 1, 0, -50553, 3552, 0, 0, 39, '3551'),
	(377, 1, 0, -50553, 3553, 0, 0, 39, '3552'),
	(377, 1, 0, -50553, 3554, 0, 0, 39, '3553'),
	(377, 1, 0, -50553, 3555, 0, 0, 39, '3554'),
	(377, 1, 0, -50553, 3556, 0, 0, 39, '3555'),
	(377, 1, 0, -50553, 3557, 0, 0, 39, '3556'),
	(377, 1, 0, -50553, 3558, 0, 0, 39, '3557'),
	(377, 1, 0, -50553, 3559, 0, 0, 39, '3558'),
	(377, 1, 0, -50553, 3560, 0, 0, 39, '3559'),
	(377, 1, 0, -50553, 3561, 0, 0, 39, '3560'),
	(377, 1, 0, -50553, 3562, 0, 0, 39, '3561'),
	(377, 1, 0, -50553, 3563, 0, 0, 39, '3562'),
	(377, 1, 0, -50553, 3564, 0, 0, 39, '3563'),
	(377, 1, 0, -50553, 3565, 0, 0, 39, '3564'),
	(377, 1, 0, -50553, 3566, 0, 0, 39, '3565'),
	(377, 1, 0, -50553, 3567, 0, 0, 39, '3566'),
	(377, 1, 0, -50553, 3568, 0, 0, 39, '3567'),
	(377, 1, 0, -50553, 3569, 0, 0, 39, '3568'),
	(377, 1, 0, -50553, 3570, 0, 0, 39, '3569'),
	(377, 1, 0, -50553, 3571, 0, 0, 39, '3570'),
	(377, 1, 0, -50553, 3572, 0, 0, 39, '3571'),
	(377, 1, 0, -50553, 3573, 0, 0, 39, '3572'),
	(377, 1, 0, -50553, 3574, 0, 0, 39, '3573'),
	(377, 1, 0, -50553, 3575, 0, 0, 39, '3574'),
	(377, 1, 0, -50553, 3576, 0, 0, 39, '3575'),
	(377, 1, 0, -50553, 3577, 0, 0, 39, '3576'),
	(377, 1, 0, -50553, 3578, 0, 0, 39, '3577'),
	(377, 1, 0, -50553, 3579, 0, 0, 39, '3578'),
	(377, 1, 0, -50553, 3580, 0, 0, 39, '3579'),
	(377, 1, 0, -50553, 3581, 0, 0, 39, '3580'),
	(377, 1, 0, -50553, 3582, 0, 0, 39, '3581'),
	(377, 1, 0, -50553, 3583, 0, 0, 39, '3582'),
	(377, 1, 0, -50553, 3584, 0, 0, 39, '3583'),
	(377, 1, 0, -50553, 3585, 0, 0, 39, '3584'),
	(377, 1, 0, -50553, 3586, 0, 0, 39, '3585'),
	(377, 1, 0, -50553, 3587, 0, 0, 39, '3586'),
	(377, 1, 0, -50553, 3588, 0, 0, 39, '3587'),
	(377, 1, 0, -50553, 3589, 0, 0, 39, '3588'),
	(377, 1, 0, -50553, 3590, 0, 0, 39, '3589'),
	(377, 1, 0, -50553, 3591, 0, 0, 39, '3590'),
	(377, 1, 0, -50553, 3592, 0, 0, 39, '3591'),
	(377, 1, 0, -50553, 3593, 0, 0, 39, '3592'),
	(377, 1, 0, -50553, 3594, 0, 0, 39, '3593'),
	(377, 1, 0, -50553, 3595, 0, 0, 39, '3594'),
	(377, 1, 0, -50553, 3596, 0, 0, 39, '3595'),
	(377, 1, 0, -50553, 3597, 0, 0, 39, '3596'),
	(377, 1, 0, -50553, 3598, 0, 0, 39, '3597'),
	(377, 1, 0, -50553, 3599, 0, 0, 39, '3598'),
	(377, 1, 0, -50553, 3600, 0, 0, 39, '3599'),
	(377, 1, 0, -50553, 3601, 0, 0, 39, '3600'),
	(377, 1, 0, -50553, 3602, 0, 0, 39, '3601'),
	(377, 1, 0, -50553, 3603, 0, 0, 39, '3602'),
	(377, 1, 0, -50553, 3604, 0, 0, 39, '3603'),
	(377, 1, 0, -50553, 3605, 0, 0, 39, '3604'),
	(377, 1, 0, -50553, 3606, 0, 0, 39, '3605'),
	(377, 1, 0, -50553, 3607, 0, 0, 39, '3606'),
	(377, 1, 0, -50553, 3608, 0, 0, 39, '3607'),
	(377, 1, 0, -50553, 3609, 0, 0, 39, '3608'),
	(377, 1, 0, -50553, 3610, 0, 0, 39, '3609'),
	(377, 1, 0, -50553, 3611, 0, 0, 39, '3610'),
	(377, 1, 0, -50553, 3612, 0, 0, 39, '3611'),
	(377, 1, 0, -50553, 3613, 0, 0, 39, '3612'),
	(377, 1, 0, -50553, 3614, 0, 0, 39, '3613'),
	(377, 1, 0, -50553, 3615, 0, 0, 39, '3614'),
	(377, 1, 0, -50553, 3616, 0, 0, 39, '3615'),
	(377, 1, 0, -50553, 3617, 0, 0, 39, '3616'),
	(377, 1, 0, -50553, 3618, 0, 0, 39, '3617'),
	(377, 1, 0, -50553, 3619, 0, 0, 39, '3618'),
	(377, 1, 0, -50553, 3620, 0, 0, 39, '3619'),
	(377, 1, 0, -50553, 3621, 0, 0, 39, '3620'),
	(377, 1, 0, -50553, 3622, 0, 0, 39, '3621'),
	(377, 1, 0, -50553, 3623, 0, 0, 39, '3622'),
	(377, 1, 0, -50553, 3624, 0, 0, 39, '3623'),
	(377, 1, 0, -50553, 3625, 0, 0, 39, '3624'),
	(377, 1, 0, -50553, 3626, 0, 0, 39, '3625'),
	(377, 1, 0, -50553, 3627, 0, 0, 39, '3626'),
	(377, 1, 0, -50553, 3628, 0, 0, 39, '3627'),
	(377, 1, 0, -50553, 3629, 0, 0, 39, '3628'),
	(377, 1, 0, -50553, 3630, 0, 0, 39, '3629'),
	(377, 1, 0, -50553, 3631, 0, 0, 39, '3630'),
	(377, 1, 0, -50553, 3632, 0, 0, 39, '3631'),
	(377, 1, 0, -50553, 3633, 0, 0, 39, '3632'),
	(377, 1, 0, -50553, 3634, 0, 0, 39, '3633'),
	(377, 1, 0, -50553, 3635, 0, 0, 39, '3634'),
	(377, 1, 0, -50553, 3636, 0, 0, 39, '3635'),
	(377, 1, 0, -50553, 3637, 0, 0, 39, '3636'),
	(377, 1, 0, -50553, 3638, 0, 0, 39, '3637'),
	(377, 1, 0, -50553, 3639, 0, 0, 39, '3638'),
	(377, 1, 0, -50553, 3640, 0, 0, 39, '3639'),
	(377, 1, 0, -50553, 3641, 0, 0, 39, '3640'),
	(377, 1, 0, -50553, 3642, 0, 0, 39, '3641'),
	(377, 1, 0, -50553, 3643, 0, 0, 39, '3642'),
	(377, 1, 0, -50553, 3644, 0, 0, 39, '3643'),
	(377, 1, 0, -50553, 3645, 0, 0, 39, '3644'),
	(377, 1, 0, -50553, 3646, 0, 0, 39, '3645'),
	(377, 1, 0, -50553, 3647, 0, 0, 39, '3646'),
	(377, 1, 0, -50553, 3648, 0, 0, 39, '3647'),
	(377, 1, 0, -50553, 3649, 0, 0, 39, '3648'),
	(377, 1, 0, -50553, 3650, 0, 0, 39, '3649'),
	(377, 1, 0, -50553, 3651, 0, 0, 39, '3650'),
	(377, 1, 0, -50553, 3652, 0, 0, 39, '3651'),
	(377, 1, 0, -50553, 3653, 0, 0, 39, '3652'),
	(377, 1, 0, -50553, 3654, 0, 0, 39, '3653'),
	(377, 1, 0, -50553, 3655, 0, 0, 39, '3654'),
	(377, 1, 0, -50553, 3656, 0, 0, 39, '3655'),
	(377, 1, 0, -50553, 3657, 0, 0, 39, '3656'),
	(377, 1, 0, -50553, 3658, 0, 0, 39, '3657'),
	(377, 1, 0, -50553, 3659, 0, 0, 39, '3658'),
	(377, 1, 0, -50553, 3660, 0, 0, 39, '3659'),
	(377, 1, 0, -50553, 3661, 0, 0, 39, '3660'),
	(377, 1, 0, -50553, 3662, 0, 0, 39, '3661'),
	(377, 1, 0, -50553, 3663, 0, 0, 39, '3662'),
	(377, 1, 0, -50553, 3664, 0, 0, 39, '3663'),
	(377, 1, 0, -50553, 3665, 0, 0, 39, '3664'),
	(377, 1, 0, -50553, 3666, 0, 0, 39, '3665'),
	(377, 1, 0, -50553, 3667, 0, 0, 39, '3666'),
	(377, 1, 0, -50553, 3668, 0, 0, 39, '3667'),
	(377, 1, 0, -50553, 3669, 0, 0, 39, '3668'),
	(377, 1, 0, -50553, 3670, 0, 0, 39, '3669'),
	(377, 1, 0, -50553, 3671, 0, 0, 39, '3670'),
	(377, 1, 0, -50553, 3672, 0, 0, 39, '3671'),
	(377, 1, 0, -50553, 3673, 0, 0, 39, '3672'),
	(377, 1, 0, -50553, 3674, 0, 0, 39, '3673'),
	(377, 1, 0, -50553, 3675, 0, 0, 39, '3674'),
	(377, 1, 0, -50553, 3676, 0, 0, 39, '3675'),
	(377, 1, 0, -50553, 3677, 0, 0, 39, '3676'),
	(377, 1, 0, -50553, 3678, 0, 0, 39, '3677'),
	(377, 1, 0, -50553, 3679, 0, 0, 39, '3678'),
	(377, 1, 0, -50553, 3680, 0, 0, 39, '3679'),
	(377, 1, 0, -50553, 3681, 0, 0, 39, '3680'),
	(377, 1, 0, -50553, 3682, 0, 0, 39, '3681'),
	(377, 1, 0, -50553, 3683, 0, 0, 39, '3682'),
	(377, 1, 0, -50553, 3684, 0, 0, 39, '3683'),
	(377, 1, 0, -50553, 3685, 0, 0, 39, '3684'),
	(377, 1, 0, -50553, 3686, 0, 0, 39, '3685'),
	(377, 1, 0, -50553, 3687, 0, 0, 39, '3686'),
	(377, 1, 0, -50553, 3688, 0, 0, 39, '3687'),
	(377, 1, 0, -50553, 3689, 0, 0, 39, '3688'),
	(377, 1, 0, -50553, 3690, 0, 0, 39, '3689'),
	(377, 1, 0, -50553, 3691, 0, 0, 39, '3690'),
	(377, 1, 0, -50553, 3692, 0, 0, 39, '3691'),
	(377, 1, 0, -50553, 3693, 0, 0, 39, '3692'),
	(377, 1, 0, -50553, 3694, 0, 0, 39, '3693'),
	(377, 1, 0, -50553, 3695, 0, 0, 39, '3694'),
	(377, 1, 0, -50553, 3696, 0, 0, 39, '3695'),
	(377, 1, 0, -50553, 3697, 0, 0, 39, '3696'),
	(377, 1, 0, -50553, 3698, 0, 0, 39, '3697'),
	(377, 1, 0, -50553, 3699, 0, 0, 39, '3698'),
	(377, 1, 0, -50553, 3700, 0, 0, 39, '3699'),
	(377, 1, 0, -50553, 3701, 0, 0, 39, '3700'),
	(377, 1, 0, -50553, 3702, 0, 0, 39, '3701'),
	(377, 1, 0, -50553, 3703, 0, 0, 39, '3702'),
	(377, 1, 0, -50553, 3704, 0, 0, 39, '3703'),
	(377, 1, 0, -50553, 3705, 0, 0, 39, '3704'),
	(377, 1, 0, -50553, 3706, 0, 0, 39, '3705'),
	(377, 1, 0, -50553, 3707, 0, 0, 39, '3706'),
	(377, 1, 0, -50553, 3708, 0, 0, 39, '3707'),
	(377, 1, 0, -50553, 3709, 0, 0, 39, '3708'),
	(377, 1, 0, -50553, 3710, 0, 0, 39, '3709'),
	(377, 1, 0, -50553, 3711, 0, 0, 39, '3710'),
	(377, 1, 0, -50553, 3712, 0, 0, 39, '3711'),
	(377, 1, 0, -50553, 3713, 0, 0, 39, '3712'),
	(377, 1, 0, -50553, 3714, 0, 0, 39, '3713'),
	(377, 1, 0, -50553, 3715, 0, 0, 39, '3714'),
	(377, 1, 0, -50553, 3716, 0, 0, 39, '3715'),
	(377, 1, 0, -50553, 3717, 0, 0, 39, '3716'),
	(377, 1, 0, -50553, 3718, 0, 0, 39, '3717'),
	(377, 1, 0, -50553, 3719, 0, 0, 39, '3718'),
	(377, 1, 0, -50553, 3720, 0, 0, 39, '3719'),
	(377, 1, 0, -50553, 3721, 0, 0, 39, '3720'),
	(377, 1, 0, -50553, 3722, 0, 0, 39, '3721'),
	(377, 1, 0, -50553, 3723, 0, 0, 39, '3722'),
	(377, 1, 0, -50553, 3724, 0, 0, 39, '3723'),
	(377, 1, 0, -50553, 3725, 0, 0, 39, '3724'),
	(377, 1, 0, -50553, 3726, 0, 0, 39, '3725'),
	(377, 1, 0, -50553, 3727, 0, 0, 39, '3726'),
	(377, 1, 0, -50553, 3728, 0, 0, 39, '3727'),
	(377, 1, 0, -50553, 3729, 0, 0, 39, '3728'),
	(377, 1, 0, -50553, 3730, 0, 0, 39, '3729'),
	(377, 1, 0, -50553, 3731, 0, 0, 39, '3730'),
	(377, 1, 0, -50553, 3732, 0, 0, 39, '3731'),
	(377, 1, 0, -50553, 3733, 0, 0, 39, '3732'),
	(377, 1, 0, -50553, 3734, 0, 0, 39, '3733'),
	(377, 1, 0, -50553, 3735, 0, 0, 39, '3734'),
	(377, 1, 0, -50553, 3736, 0, 0, 39, '3735'),
	(377, 1, 0, -50553, 3737, 0, 0, 39, '3736'),
	(377, 1, 0, -50553, 3738, 0, 0, 39, '3737'),
	(377, 1, 0, -50553, 3739, 0, 0, 39, '3738'),
	(377, 1, 0, -50553, 3740, 0, 0, 39, '3739'),
	(377, 1, 0, -50553, 3741, 0, 0, 39, '3740'),
	(377, 1, 0, -50553, 3742, 0, 0, 39, '3741'),
	(377, 1, 0, -50553, 3743, 0, 0, 39, '3742'),
	(377, 1, 0, -50553, 3744, 0, 0, 39, '3743'),
	(377, 1, 0, -50553, 3745, 0, 0, 39, '3744'),
	(377, 1, 0, -50553, 3746, 0, 0, 39, '3745'),
	(377, 1, 0, -50553, 3747, 0, 0, 39, '3746'),
	(377, 1, 0, -50553, 3748, 0, 0, 39, '3747'),
	(377, 1, 0, -50553, 3749, 0, 0, 39, '3748'),
	(377, 1, 0, -50553, 3750, 0, 0, 39, '3749'),
	(377, 1, 0, -50553, 3751, 0, 0, 39, '3750'),
	(377, 1, 0, -50553, 3752, 0, 0, 39, '3751'),
	(377, 1, 0, -50553, 3753, 0, 0, 39, '3752'),
	(377, 1, 0, -50553, 3754, 0, 0, 39, '3753'),
	(377, 1, 0, -50553, 3755, 0, 0, 39, '3754'),
	(377, 1, 0, -50553, 3756, 0, 0, 39, '3755'),
	(377, 1, 0, -50553, 3757, 0, 0, 39, '3756'),
	(377, 1, 0, -50553, 3758, 0, 0, 39, '3757'),
	(377, 1, 0, -50553, 3759, 0, 0, 39, '3758'),
	(377, 1, 0, -50553, 3760, 0, 0, 39, '3759'),
	(377, 1, 0, -50553, 3761, 0, 0, 39, '3760'),
	(377, 1, 0, -50553, 3762, 0, 0, 39, '3761'),
	(377, 1, 0, -50553, 3763, 0, 0, 39, '3762'),
	(377, 1, 0, -50553, 3764, 0, 0, 39, '3763'),
	(377, 1, 0, -50553, 3765, 0, 0, 39, '3764'),
	(377, 1, 0, -50553, 3766, 0, 0, 39, '3765'),
	(377, 1, 0, -50553, 3767, 0, 0, 39, '3766'),
	(377, 1, 0, -50553, 3768, 0, 0, 39, '3767'),
	(377, 1, 0, -50553, 3769, 0, 0, 39, '3768'),
	(377, 1, 0, -50553, 3770, 0, 0, 39, '3769'),
	(377, 1, 0, -50553, 3771, 0, 0, 39, '3770'),
	(377, 1, 0, -50553, 3772, 0, 0, 39, '3771'),
	(377, 1, 0, -50553, 3773, 0, 0, 39, '3772'),
	(377, 1, 0, -50553, 3774, 0, 0, 39, '3773'),
	(377, 1, 0, -50553, 3775, 0, 0, 39, '3774'),
	(377, 1, 0, -50553, 3776, 0, 0, 39, '3775'),
	(377, 1, 0, -50553, 3777, 0, 0, 39, '3776'),
	(377, 1, 0, -50553, 3778, 0, 0, 39, '3777'),
	(377, 1, 0, -50553, 3779, 0, 0, 39, '3778'),
	(377, 1, 0, -50553, 3780, 0, 0, 39, '3779'),
	(377, 1, 0, -50553, 3781, 0, 0, 39, '3780'),
	(377, 1, 0, -50553, 3782, 0, 0, 39, '3781'),
	(377, 1, 0, -50553, 3783, 0, 0, 39, '3782'),
	(377, 1, 0, -50553, 3784, 0, 0, 39, '3783'),
	(377, 1, 0, -50553, 3785, 0, 0, 39, '3784'),
	(377, 1, 0, -50553, 3786, 0, 0, 39, '3785'),
	(377, 1, 0, -50553, 3787, 0, 0, 39, '3786'),
	(377, 1, 0, -50553, 3788, 0, 0, 39, '3787'),
	(377, 1, 0, -50553, 3789, 0, 0, 39, '3788'),
	(377, 1, 0, -50553, 3790, 0, 0, 39, '3789'),
	(377, 1, 0, -50553, 3791, 0, 0, 39, '3790'),
	(377, 1, 0, -50553, 3792, 0, 0, 39, '3791'),
	(377, 1, 0, -50553, 3793, 0, 0, 39, '3792'),
	(377, 1, 0, -50553, 3794, 0, 0, 39, '3793'),
	(377, 1, 0, -50553, 3795, 0, 0, 39, '3794'),
	(377, 1, 0, -50553, 3796, 0, 0, 39, '3795'),
	(377, 1, 0, -50553, 3797, 0, 0, 39, '3796'),
	(377, 1, 0, -50553, 3798, 0, 0, 39, '3797'),
	(377, 1, 0, -50553, 3799, 0, 0, 39, '3798'),
	(377, 1, 0, -50553, 3800, 0, 0, 39, '3799'),
	(377, 1, 0, -50553, 3801, 0, 0, 39, '3800'),
	(377, 1, 0, -50553, 3802, 0, 0, 39, '3801'),
	(377, 1, 0, -50553, 3803, 0, 0, 39, '3802'),
	(377, 1, 0, -50553, 3804, 0, 0, 39, '3803'),
	(377, 1, 0, -50553, 3805, 0, 0, 39, '3804'),
	(377, 1, 0, -50553, 3806, 0, 0, 39, '3805'),
	(377, 1, 0, -50553, 3807, 0, 0, 39, '3806'),
	(377, 1, 0, -50553, 3808, 0, 0, 39, '3807'),
	(377, 1, 0, -50553, 3809, 0, 0, 39, '3808'),
	(377, 1, 0, -50553, 3810, 0, 0, 39, '3809'),
	(377, 1, 0, -50553, 3811, 0, 0, 39, '3810'),
	(377, 1, 0, -50553, 3812, 0, 0, 39, '3811'),
	(377, 1, 0, -50553, 3813, 0, 0, 39, '3812'),
	(377, 1, 0, -50553, 3814, 0, 0, 39, '3813'),
	(377, 1, 0, -50553, 3815, 0, 0, 39, '3814'),
	(377, 1, 0, -50553, 3816, 0, 0, 39, '3815'),
	(377, 1, 0, -50553, 3817, 0, 0, 39, '3816'),
	(377, 1, 0, -50553, 3818, 0, 0, 39, '3817'),
	(377, 1, 0, -50553, 3819, 0, 0, 39, '3818'),
	(377, 1, 0, -50553, 3820, 0, 0, 39, '3819'),
	(377, 1, 0, -50553, 3821, 0, 0, 39, '3820'),
	(377, 1, 0, -50553, 3822, 0, 0, 39, '3821'),
	(377, 1, 0, -50553, 3823, 0, 0, 39, '3822'),
	(377, 1, 0, -50553, 3824, 0, 0, 39, '3823'),
	(377, 1, 0, -50553, 3825, 0, 0, 39, '3824'),
	(377, 1, 0, -50553, 3826, 0, 0, 39, '3825'),
	(377, 1, 0, -50553, 3827, 0, 0, 39, '3826'),
	(377, 1, 0, -50553, 3828, 0, 0, 39, '3827'),
	(377, 1, 0, -50553, 3829, 0, 0, 39, '3828'),
	(377, 1, 0, -50553, 3830, 0, 0, 39, '3829'),
	(377, 1, 0, -50553, 3831, 0, 0, 39, '3830'),
	(377, 1, 0, -50553, 3832, 0, 0, 39, '3831'),
	(377, 1, 0, -50553, 3833, 0, 0, 39, '3832'),
	(377, 1, 0, -50553, 3834, 0, 0, 39, '3833'),
	(377, 1, 0, -50553, 3835, 0, 0, 39, '3834'),
	(377, 1, 0, -50553, 3836, 0, 0, 39, '3835'),
	(377, 1, 0, -50553, 3837, 0, 0, 39, '3836'),
	(377, 1, 0, -50553, 3838, 0, 0, 39, '3837'),
	(377, 1, 0, -50553, 3839, 0, 0, 39, '3838'),
	(377, 1, 0, -50553, 3840, 0, 0, 39, '3839'),
	(377, 1, 0, -50553, 3841, 0, 0, 39, '3840'),
	(377, 1, 0, -50553, 3842, 0, 0, 39, '3841'),
	(377, 1, 0, -50553, 3843, 0, 0, 39, '3842'),
	(377, 1, 0, -50553, 3844, 0, 0, 39, '3843'),
	(377, 1, 0, -50553, 3845, 0, 0, 39, '3844'),
	(377, 1, 0, -50553, 3846, 0, 0, 39, '3845'),
	(377, 1, 0, -50553, 3847, 0, 0, 39, '3846'),
	(377, 1, 0, -50553, 3848, 0, 0, 39, '3847'),
	(377, 1, 0, -50553, 3849, 0, 0, 39, '3848'),
	(377, 1, 0, -50553, 3850, 0, 0, 39, '3849'),
	(377, 1, 0, -50553, 3851, 0, 0, 39, '3850'),
	(377, 1, 0, -50553, 3852, 0, 0, 39, '3851'),
	(377, 1, 0, -50553, 3853, 0, 0, 39, '3852'),
	(377, 1, 0, -50553, 3854, 0, 0, 39, '3853'),
	(377, 1, 0, -50553, 3855, 0, 0, 39, '3854'),
	(377, 1, 0, -50553, 3856, 0, 0, 39, '3855'),
	(377, 1, 0, -50553, 3857, 0, 0, 39, '3856'),
	(377, 1, 0, -50553, 3858, 0, 0, 39, '3857'),
	(377, 1, 0, -50553, 3859, 0, 0, 39, '3858'),
	(377, 1, 0, -50553, 3860, 0, 0, 39, '3859'),
	(377, 1, 0, -50553, 3861, 0, 0, 39, '3860'),
	(377, 1, 0, -50553, 3862, 0, 0, 39, '3861'),
	(377, 1, 0, -50553, 3863, 0, 0, 39, '3862'),
	(377, 1, 0, -50553, 3864, 0, 0, 39, '3863'),
	(377, 1, 0, -50553, 3865, 0, 0, 39, '3864'),
	(377, 1, 0, -50553, 3866, 0, 0, 39, '3865'),
	(377, 1, 0, -50553, 3867, 0, 0, 39, '3866'),
	(377, 1, 0, -50553, 3868, 0, 0, 39, '3867'),
	(377, 1, 0, -50553, 3869, 0, 0, 39, '3868'),
	(377, 1, 0, -50553, 3870, 0, 0, 39, '3869'),
	(377, 1, 0, -50553, 3871, 0, 0, 39, '3870'),
	(377, 1, 0, -50553, 3872, 0, 0, 39, '3871'),
	(377, 1, 0, -50553, 3873, 0, 0, 39, '3872'),
	(377, 1, 0, -50553, 3874, 0, 0, 39, '3873'),
	(377, 1, 0, -50553, 3875, 0, 0, 39, '3874'),
	(377, 1, 0, -50553, 3876, 0, 0, 39, '3875'),
	(377, 1, 0, -50553, 3877, 0, 0, 39, '3876'),
	(377, 1, 0, -50553, 3878, 0, 0, 39, '3877'),
	(377, 1, 0, -50553, 3879, 0, 0, 39, '3878'),
	(377, 1, 0, -50553, 3880, 0, 0, 39, '3879'),
	(377, 1, 0, -50553, 3881, 0, 0, 39, '3880'),
	(377, 1, 0, -50553, 3882, 0, 0, 39, '3881'),
	(377, 1, 0, -50553, 3883, 0, 0, 39, '3882'),
	(377, 1, 0, -50553, 3884, 0, 0, 39, '3883'),
	(377, 1, 0, -50553, 3885, 0, 0, 39, '3884'),
	(377, 1, 0, -50553, 3886, 0, 0, 39, '3885'),
	(377, 1, 0, -50553, 3887, 0, 0, 39, '3886'),
	(377, 1, 0, -50553, 3888, 0, 0, 39, '3887'),
	(377, 1, 0, -50553, 3889, 0, 0, 39, '3888'),
	(377, 1, 0, -50553, 3890, 0, 0, 39, '3889'),
	(377, 1, 0, -50553, 3891, 0, 0, 39, '3890'),
	(377, 1, 0, -50553, 3892, 0, 0, 39, '3891'),
	(377, 1, 0, -50553, 3893, 0, 0, 39, '3892'),
	(377, 1, 0, -50553, 3894, 0, 0, 39, '3893'),
	(377, 1, 0, -50553, 3895, 0, 0, 39, '3894'),
	(377, 1, 0, -50553, 3896, 0, 0, 39, '3895'),
	(377, 1, 0, -50553, 3897, 0, 0, 39, '3896'),
	(377, 1, 0, -50553, 3898, 0, 0, 39, '3897'),
	(377, 1, 0, -50553, 3899, 0, 0, 39, '3898'),
	(377, 1, 0, -50553, 3900, 0, 0, 39, '3899'),
	(377, 1, 0, -50553, 3901, 0, 0, 39, '3900'),
	(377, 1, 0, -50553, 3902, 0, 0, 39, '3901'),
	(377, 1, 0, -50553, 3903, 0, 0, 39, '3902'),
	(377, 1, 0, -50553, 3904, 0, 0, 39, '3903'),
	(377, 1, 0, -50553, 3905, 0, 0, 39, '3904'),
	(377, 1, 0, -50553, 3906, 0, 0, 39, '3905'),
	(377, 1, 0, -50553, 3907, 0, 0, 39, '3906'),
	(377, 1, 0, -50553, 3908, 0, 0, 39, '3907'),
	(377, 1, 0, -50553, 3909, 0, 0, 39, '3908'),
	(377, 1, 0, -50553, 3910, 0, 0, 39, '3909'),
	(377, 1, 0, -50553, 3911, 0, 0, 39, '3910'),
	(377, 1, 0, -50553, 3912, 0, 0, 39, '3911'),
	(377, 1, 0, -50553, 3913, 0, 0, 39, '3912'),
	(377, 1, 0, -50553, 3914, 0, 0, 39, '3913'),
	(377, 1, 0, -50553, 3915, 0, 0, 39, '3914'),
	(377, 1, 0, -50553, 3916, 0, 0, 39, '3915'),
	(377, 1, 0, -50553, 3917, 0, 0, 39, '3916'),
	(377, 1, 0, -50553, 3918, 0, 0, 39, '3917'),
	(377, 1, 0, -50553, 3919, 0, 0, 39, '3918'),
	(377, 1, 0, -50553, 3920, 0, 0, 39, '3919'),
	(377, 1, 0, -50553, 3921, 0, 0, 39, '3920'),
	(377, 1, 0, -50553, 3922, 0, 0, 39, '3921'),
	(377, 1, 0, -50553, 3923, 0, 0, 39, '3922'),
	(377, 1, 0, -50553, 3924, 0, 0, 39, '3923'),
	(377, 1, 0, -50553, 3925, 0, 0, 39, '3924'),
	(377, 1, 0, -50553, 3926, 0, 0, 39, '3925'),
	(377, 1, 0, -50553, 3927, 0, 0, 39, '3926'),
	(377, 1, 0, -50553, 3928, 0, 0, 39, '3927'),
	(377, 1, 0, -50553, 3929, 0, 0, 39, '3928'),
	(377, 1, 0, -50553, 3930, 0, 0, 39, '3929'),
	(377, 1, 0, -50553, 3931, 0, 0, 39, '3930'),
	(377, 1, 0, -50553, 3932, 0, 0, 39, '3931'),
	(377, 1, 0, -50553, 3933, 0, 0, 39, '3932'),
	(377, 1, 0, -50553, 3934, 0, 0, 39, '3933'),
	(377, 1, 0, -50553, 3935, 0, 0, 39, '3934'),
	(377, 1, 0, -50553, 3936, 0, 0, 39, '3935'),
	(377, 1, 0, -50553, 3937, 0, 0, 39, '3936'),
	(377, 1, 0, -50553, 3938, 0, 0, 39, '3937'),
	(377, 1, 0, -50553, 3939, 0, 0, 39, '3938'),
	(377, 1, 0, -50553, 3940, 0, 0, 39, '3939'),
	(377, 1, 0, -50553, 3941, 0, 0, 39, '3940'),
	(377, 1, 0, -50553, 3942, 0, 0, 39, '3941'),
	(377, 1, 0, -50553, 3943, 0, 0, 39, '3942'),
	(377, 1, 0, -50553, 3944, 0, 0, 39, '3943'),
	(377, 1, 0, -50553, 3945, 0, 0, 39, '3944'),
	(377, 1, 0, -50553, 3946, 0, 0, 39, '3945'),
	(377, 1, 0, -50553, 3947, 0, 0, 39, '3946'),
	(377, 1, 0, -50553, 3948, 0, 0, 39, '3947'),
	(377, 1, 0, -50553, 3949, 0, 0, 39, '3948'),
	(377, 1, 0, -50553, 3950, 0, 0, 39, '3949'),
	(377, 1, 0, -50553, 3951, 0, 0, 39, '3950'),
	(377, 1, 0, -50553, 3952, 0, 0, 39, '3951'),
	(377, 1, 0, -50553, 3953, 0, 0, 39, '3952'),
	(377, 1, 0, -50553, 3954, 0, 0, 39, '3953'),
	(377, 1, 0, -50553, 3955, 0, 0, 39, '3954'),
	(377, 1, 0, -50553, 3956, 0, 0, 39, '3955'),
	(377, 1, 0, -50553, 3957, 0, 0, 39, '3956'),
	(377, 1, 0, -50553, 3958, 0, 0, 39, '3957'),
	(377, 1, 0, -50553, 3959, 0, 0, 39, '3958'),
	(377, 1, 0, -50553, 3960, 0, 0, 39, '3959'),
	(377, 1, 0, -50553, 3961, 0, 0, 39, '3960'),
	(377, 1, 0, -50553, 3962, 0, 0, 39, '3961'),
	(377, 1, 0, -50553, 3963, 0, 0, 39, '3962'),
	(377, 1, 0, -50553, 3964, 0, 0, 39, '3963'),
	(377, 1, 0, -50553, 3965, 0, 0, 39, '3964'),
	(377, 1, 0, -50553, 3966, 0, 0, 39, '3965'),
	(377, 1, 0, -50553, 3967, 0, 0, 39, '3966'),
	(377, 1, 0, -50553, 3968, 0, 0, 39, '3967'),
	(377, 1, 0, -50553, 3969, 0, 0, 39, '3968'),
	(377, 1, 0, -50553, 3970, 0, 0, 39, '3969'),
	(377, 1, 0, -50553, 3971, 0, 0, 39, '3970'),
	(377, 1, 0, -50553, 3972, 0, 0, 39, '3971'),
	(377, 1, 0, -50553, 3973, 0, 0, 39, '3972'),
	(377, 1, 0, -50553, 3974, 0, 0, 39, '3973'),
	(377, 1, 0, -50553, 3975, 0, 0, 39, '3974'),
	(377, 1, 0, -50553, 3976, 0, 0, 39, '3975'),
	(377, 1, 0, -50553, 3977, 0, 0, 39, '3976'),
	(377, 1, 0, -50553, 3978, 0, 0, 39, '3977'),
	(377, 1, 0, -50553, 3979, 0, 0, 39, '3978'),
	(377, 1, 0, -50553, 3980, 0, 0, 39, '3979'),
	(377, 1, 0, -50553, 3981, 0, 0, 39, '3980'),
	(377, 1, 0, -50553, 3982, 0, 0, 39, '3981'),
	(377, 1, 0, -50553, 3983, 0, 0, 39, '3982'),
	(377, 1, 0, -50553, 3984, 0, 0, 39, '3983'),
	(377, 1, 0, -50553, 3985, 0, 0, 39, '3984'),
	(377, 1, 0, -50553, 3986, 0, 0, 39, '3985'),
	(377, 1, 0, -50553, 3987, 0, 0, 39, '3986'),
	(377, 1, 0, -50553, 3988, 0, 0, 39, '3987'),
	(377, 1, 0, -50553, 3989, 0, 0, 39, '3988'),
	(377, 1, 0, -50553, 3990, 0, 0, 39, '3989'),
	(377, 1, 0, -50553, 3991, 0, 0, 39, '3990'),
	(377, 1, 0, -50553, 3992, 0, 0, 39, '3991'),
	(377, 1, 0, -50553, 3993, 0, 0, 39, '3992'),
	(377, 1, 0, -50553, 3994, 0, 0, 39, '3993'),
	(377, 1, 0, -50553, 3995, 0, 0, 39, '3994'),
	(377, 1, 0, -50553, 3996, 0, 0, 39, '3995'),
	(377, 1, 0, -50553, 3997, 0, 0, 39, '3996'),
	(377, 1, 0, -50553, 3998, 0, 0, 39, '3997'),
	(377, 1, 0, -50553, 3999, 0, 0, 39, '3998'),
	(377, 1, 0, -50553, 4000, 0, 0, 39, '3999'),
	(377, 1, 0, -50378, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50378, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50378, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50378, 4, 0, 0, 39, '3'),
	(377, 1, 0, -50378, 5, 0, 0, 39, '4'),
	(377, 1, 0, -50378, 6, 0, 0, 39, '5'),
	(377, 1, 0, -50378, 7, 0, 0, 39, '6'),
	(377, 1, 0, -50378, 8, 0, 0, 39, '7'),
	(377, 1, 0, -50378, 9, 0, 0, 39, '8'),
	(377, 1, 0, -50378, 10, 0, 0, 39, '9'),
	(377, 1, 0, -50378, 11, 0, 0, 39, '10'),
	(377, 1, 0, -50378, 12, 0, 0, 39, '11'),
	(377, 1, 0, -50378, 13, 0, 0, 39, '12'),
	(377, 1, 0, -50378, 14, 0, 0, 39, '13'),
	(377, 1, 0, -50378, 15, 0, 0, 39, '14'),
	(377, 1, 0, -50378, 16, 0, 0, 39, '15'),
	(377, 1, 0, -50378, 17, 0, 0, 39, '16'),
	(377, 1, 0, -50378, 18, 0, 0, 39, '17'),
	(377, 1, 0, -50378, 19, 0, 0, 39, '18'),
	(377, 1, 0, -50378, 20, 0, 0, 39, '19'),
	(377, 1, 0, -50378, 21, 0, 0, 39, '20'),
	(377, 1, 0, -50378, 22, 0, 0, 39, '21'),
	(377, 1, 0, -50378, 23, 0, 0, 39, '22'),
	(377, 1, 0, -50378, 24, 0, 0, 39, '23'),
	(377, 1, 0, -50378, 25, 0, 0, 39, '24'),
	(377, 1, 0, -50378, 26, 0, 0, 39, '25'),
	(377, 1, 0, -50378, 27, 0, 0, 39, '26'),
	(377, 1, 0, -50378, 28, 0, 0, 39, '27'),
	(377, 1, 0, -50378, 29, 0, 0, 39, '28'),
	(377, 1, 0, -50378, 30, 0, 0, 39, '29'),
	(377, 1, 0, -50378, 31, 0, 0, 39, '30'),
	(377, 1, 0, -50378, 32, 0, 0, 39, '31'),
	(377, 1, 0, -50378, 33, 0, 0, 39, '32'),
	(377, 1, 0, -50378, 34, 0, 0, 39, '33'),
	(377, 1, 0, -50378, 35, 0, 0, 39, '34'),
	(377, 1, 0, -50378, 36, 0, 0, 39, '35'),
	(377, 1, 0, -50378, 37, 0, 0, 39, '36'),
	(377, 1, 0, -50378, 38, 0, 0, 39, '37'),
	(377, 1, 0, -50378, 39, 0, 0, 39, '38'),
	(377, 1, 0, -50378, 40, 0, 0, 39, '39'),
	(377, 1, 0, -50378, 41, 0, 0, 39, '40'),
	(377, 1, 0, -50378, 42, 0, 0, 39, '41'),
	(377, 1, 0, -50378, 43, 0, 0, 39, '42'),
	(377, 1, 0, -50378, 44, 0, 0, 39, '43'),
	(377, 1, 0, -50378, 45, 0, 0, 39, '44'),
	(377, 1, 0, -50378, 46, 0, 0, 39, '45'),
	(377, 1, 0, -50378, 47, 0, 0, 39, '46'),
	(377, 1, 0, -50378, 48, 0, 0, 39, '47'),
	(377, 1, 0, -50378, 49, 0, 0, 39, '48'),
	(377, 1, 0, -50378, 50, 0, 0, 39, '49'),
	(377, 1, 0, -50378, 51, 0, 0, 39, '50'),
	(377, 1, 0, -50378, 52, 0, 0, 39, '51'),
	(377, 1, 0, -50378, 53, 0, 0, 39, '52'),
	(377, 1, 0, -50378, 54, 0, 0, 39, '53'),
	(377, 1, 0, -50378, 55, 0, 0, 39, '54'),
	(377, 1, 0, -50378, 56, 0, 0, 39, '55'),
	(377, 1, 0, -50378, 57, 0, 0, 39, '56'),
	(377, 1, 0, -50378, 58, 0, 0, 39, '57'),
	(377, 1, 0, -50378, 59, 0, 0, 39, '58'),
	(377, 1, 0, -50378, 60, 0, 0, 39, '59'),
	(377, 1, 0, -50378, 61, 0, 0, 39, '60'),
	(377, 1, 0, -50378, 62, 0, 0, 39, '61'),
	(377, 1, 0, -50378, 63, 0, 0, 39, '62'),
	(377, 1, 0, -50378, 64, 0, 0, 39, '63'),
	(377, 1, 0, -50378, 65, 0, 0, 39, '64'),
	(377, 1, 0, -50378, 66, 0, 0, 39, '65'),
	(377, 1, 0, -50378, 67, 0, 0, 39, '66'),
	(377, 1, 0, -50378, 68, 0, 0, 39, '67'),
	(377, 1, 0, -50378, 69, 0, 0, 39, '68'),
	(377, 1, 0, -50378, 70, 0, 0, 39, '69'),
	(377, 1, 0, -50378, 71, 0, 0, 39, '70'),
	(377, 1, 0, -50378, 72, 0, 0, 39, '71'),
	(377, 1, 0, -50378, 73, 0, 0, 39, '72'),
	(377, 1, 0, -50378, 74, 0, 0, 39, '73'),
	(377, 1, 0, -50378, 75, 0, 0, 39, '74'),
	(377, 1, 0, -50378, 76, 0, 0, 39, '75'),
	(377, 1, 0, -50378, 77, 0, 0, 39, '76'),
	(377, 1, 0, -50378, 78, 0, 0, 39, '77'),
	(377, 1, 0, -50378, 79, 0, 0, 39, '78'),
	(377, 1, 0, -50378, 80, 0, 0, 39, '79'),
	(377, 1, 0, -50378, 81, 0, 0, 39, '80'),
	(377, 1, 0, -50378, 82, 0, 0, 39, '81'),
	(377, 1, 0, -50378, 83, 0, 0, 39, '82'),
	(377, 1, 0, -50378, 84, 0, 0, 39, '83'),
	(377, 1, 0, -50378, 85, 0, 0, 39, '84'),
	(377, 1, 0, -50378, 86, 0, 0, 39, '85'),
	(377, 1, 0, -50378, 87, 0, 0, 39, '86'),
	(377, 1, 0, -50378, 88, 0, 0, 39, '87'),
	(377, 1, 0, -50378, 89, 0, 0, 39, '88'),
	(377, 1, 0, -50378, 90, 0, 0, 39, '89'),
	(377, 1, 0, -50378, 91, 0, 0, 39, '90'),
	(377, 1, 0, -50378, 92, 0, 0, 39, '91'),
	(377, 1, 0, -50378, 93, 0, 0, 39, '92'),
	(377, 1, 0, -50378, 94, 0, 0, 39, '93'),
	(377, 1, 0, -50378, 95, 0, 0, 39, '94'),
	(377, 1, 0, -50378, 96, 0, 0, 39, '95'),
	(377, 1, 0, -50378, 97, 0, 0, 39, '96'),
	(377, 1, 0, -50378, 98, 0, 0, 39, '97'),
	(377, 1, 0, -50378, 99, 0, 0, 39, '98'),
	(377, 1, 0, -50378, 100, 0, 0, 39, '99'),
	(377, 1, 0, -50378, 101, 0, 0, 39, '100'),
	(377, 1, 0, -50378, 102, 0, 0, 39, '101'),
	(377, 1, 0, -50378, 103, 0, 0, 39, '102'),
	(377, 1, 0, -50378, 104, 0, 0, 39, '103'),
	(377, 1, 0, -50378, 105, 0, 0, 39, '104'),
	(377, 1, 0, -50378, 106, 0, 0, 39, '105'),
	(377, 1, 0, -50378, 107, 0, 0, 39, '106'),
	(377, 1, 0, -50378, 108, 0, 0, 39, '107'),
	(377, 1, 0, -50378, 109, 0, 0, 39, '108'),
	(377, 1, 0, -50378, 110, 0, 0, 39, '109'),
	(377, 1, 0, -50378, 111, 0, 0, 39, '110'),
	(377, 1, 0, -50378, 112, 0, 0, 39, '111'),
	(377, 1, 0, -50378, 113, 0, 0, 39, '112'),
	(377, 1, 0, -50378, 114, 0, 0, 39, '113'),
	(377, 1, 0, -50378, 115, 0, 0, 39, '114'),
	(377, 1, 0, -50378, 116, 0, 0, 39, '115'),
	(377, 1, 0, -50378, 117, 0, 0, 39, '116'),
	(377, 1, 0, -50378, 118, 0, 0, 39, '117'),
	(377, 1, 0, -50378, 119, 0, 0, 39, '118'),
	(377, 1, 0, -50378, 120, 0, 0, 39, '119'),
	(377, 1, 0, -50378, 121, 0, 0, 39, '120'),
	(377, 1, 0, -50378, 122, 0, 0, 39, '121'),
	(377, 1, 0, -50378, 123, 0, 0, 39, '122'),
	(377, 1, 0, -50378, 124, 0, 0, 39, '123'),
	(377, 1, 0, -50378, 125, 0, 0, 39, '124'),
	(377, 1, 0, -50378, 126, 0, 0, 39, '125'),
	(377, 1, 0, -50378, 127, 0, 0, 39, '126'),
	(377, 1, 0, -50378, 128, 0, 0, 39, '127'),
	(377, 1, 0, -50378, 129, 0, 0, 39, '128'),
	(377, 1, 0, -50378, 130, 0, 0, 39, '129'),
	(377, 1, 0, -50378, 131, 0, 0, 39, '130'),
	(377, 1, 0, -50378, 132, 0, 0, 39, '131'),
	(377, 1, 0, -50378, 133, 0, 0, 39, '132'),
	(377, 1, 0, -50378, 134, 0, 0, 39, '133'),
	(377, 1, 0, -50378, 135, 0, 0, 39, '134'),
	(377, 1, 0, -50378, 136, 0, 0, 39, '135'),
	(377, 1, 0, -50378, 137, 0, 0, 39, '136'),
	(377, 1, 0, -50378, 138, 0, 0, 39, '137'),
	(377, 1, 0, -50378, 139, 0, 0, 39, '138'),
	(377, 1, 0, -50378, 140, 0, 0, 39, '139'),
	(377, 1, 0, -50378, 141, 0, 0, 39, '140'),
	(377, 1, 0, -50378, 142, 0, 0, 39, '141'),
	(377, 1, 0, -50378, 143, 0, 0, 39, '142'),
	(377, 1, 0, -50378, 144, 0, 0, 39, '143'),
	(377, 1, 0, -50378, 145, 0, 0, 39, '144'),
	(377, 1, 0, -50378, 146, 0, 0, 39, '145'),
	(377, 1, 0, -50378, 147, 0, 0, 39, '146'),
	(377, 1, 0, -50378, 148, 0, 0, 39, '147'),
	(377, 1, 0, -50378, 149, 0, 0, 39, '148'),
	(377, 1, 0, -50378, 150, 0, 0, 39, '149'),
	(377, 1, 0, -50378, 151, 0, 0, 39, '150'),
	(377, 1, 0, -50378, 152, 0, 0, 39, '151'),
	(377, 1, 0, -50378, 153, 0, 0, 39, '152'),
	(377, 1, 0, -50378, 154, 0, 0, 39, '153'),
	(377, 1, 0, -50378, 155, 0, 0, 39, '154'),
	(377, 1, 0, -50378, 156, 0, 0, 39, '155'),
	(377, 1, 0, -50378, 157, 0, 0, 39, '156'),
	(377, 1, 0, -50378, 158, 0, 0, 39, '157'),
	(377, 1, 0, -50378, 159, 0, 0, 39, '158'),
	(377, 1, 0, -50378, 160, 0, 0, 39, '159'),
	(377, 1, 0, -50378, 161, 0, 0, 39, '160'),
	(377, 1, 0, -50378, 162, 0, 0, 39, '161'),
	(377, 1, 0, -50378, 163, 0, 0, 39, '162'),
	(377, 1, 0, -50378, 164, 0, 0, 39, '163'),
	(377, 1, 0, -50378, 165, 0, 0, 39, '164'),
	(377, 1, 0, -50378, 166, 0, 0, 39, '165'),
	(377, 1, 0, -50378, 167, 0, 0, 39, '166'),
	(377, 1, 0, -50378, 168, 0, 0, 39, '167'),
	(377, 1, 0, -50378, 169, 0, 0, 39, '168'),
	(377, 1, 0, -50378, 170, 0, 0, 39, '169'),
	(377, 1, 0, -50378, 171, 0, 0, 39, '170'),
	(377, 1, 0, -50378, 172, 0, 0, 39, '171'),
	(377, 1, 0, -50378, 173, 0, 0, 39, '172'),
	(377, 1, 0, -50378, 174, 0, 0, 39, '173'),
	(377, 1, 0, -50378, 175, 0, 0, 39, '174'),
	(377, 1, 0, -50378, 176, 0, 0, 39, '175'),
	(377, 1, 0, -50378, 177, 0, 0, 39, '176'),
	(377, 1, 0, -50378, 178, 0, 0, 39, '177'),
	(377, 1, 0, -50378, 179, 0, 0, 39, '178'),
	(377, 1, 0, -50378, 180, 0, 0, 39, '179'),
	(377, 1, 0, -50378, 181, 0, 0, 39, '180'),
	(377, 1, 0, -50378, 182, 0, 0, 39, '181'),
	(377, 1, 0, -50378, 183, 0, 0, 39, '182'),
	(377, 1, 0, -50378, 184, 0, 0, 39, '183'),
	(377, 1, 0, -50378, 185, 0, 0, 39, '184'),
	(377, 1, 0, -50378, 186, 0, 0, 39, '185'),
	(377, 1, 0, -50378, 187, 0, 0, 39, '186'),
	(377, 1, 0, -50378, 188, 0, 0, 39, '187'),
	(377, 1, 0, -50378, 189, 0, 0, 39, '188'),
	(377, 1, 0, -50378, 190, 0, 0, 39, '189'),
	(377, 1, 0, -50378, 191, 0, 0, 39, '190'),
	(377, 1, 0, -50378, 192, 0, 0, 39, '191'),
	(377, 1, 0, -50378, 193, 0, 0, 39, '192'),
	(377, 1, 0, -50378, 194, 0, 0, 39, '193'),
	(377, 1, 0, -50378, 195, 0, 0, 39, '194'),
	(377, 1, 0, -50378, 196, 0, 0, 39, '195'),
	(377, 1, 0, -50378, 197, 0, 0, 39, '196'),
	(377, 1, 0, -50378, 198, 0, 0, 39, '197'),
	(377, 1, 0, -50378, 199, 0, 0, 39, '198'),
	(377, 1, 0, -50378, 200, 0, 0, 39, '199'),
	(377, 1, 0, -50378, 201, 0, 0, 39, '200'),
	(377, 1, 0, -50378, 202, 0, 0, 39, '201'),
	(377, 1, 0, -50378, 203, 0, 0, 39, '202'),
	(377, 1, 0, -50378, 204, 0, 0, 39, '203'),
	(377, 1, 0, -50378, 205, 0, 0, 39, '204'),
	(377, 1, 0, -50378, 206, 0, 0, 39, '205'),
	(377, 1, 0, -50378, 207, 0, 0, 39, '206'),
	(377, 1, 0, -50378, 208, 0, 0, 39, '207'),
	(377, 1, 0, -50378, 209, 0, 0, 39, '208'),
	(377, 1, 0, -50378, 210, 0, 0, 39, '209'),
	(377, 1, 0, -50378, 211, 0, 0, 39, '210'),
	(377, 1, 0, -50378, 212, 0, 0, 39, '211'),
	(377, 1, 0, -50378, 213, 0, 0, 39, '212'),
	(377, 1, 0, -50378, 214, 0, 0, 39, '213'),
	(377, 1, 0, -50378, 215, 0, 0, 39, '214'),
	(377, 1, 0, -50378, 216, 0, 0, 39, '215'),
	(377, 1, 0, -50378, 217, 0, 0, 39, '216'),
	(377, 1, 0, -50378, 218, 0, 0, 39, '217'),
	(377, 1, 0, -50378, 219, 0, 0, 39, '218'),
	(377, 1, 0, -50378, 220, 0, 0, 39, '219'),
	(377, 1, 0, -50378, 221, 0, 0, 39, '220'),
	(377, 1, 0, -50378, 222, 0, 0, 39, '221'),
	(377, 1, 0, -50378, 223, 0, 0, 39, '222'),
	(377, 1, 0, -50378, 224, 0, 0, 39, '223'),
	(377, 1, 0, -50378, 225, 0, 0, 39, '224'),
	(377, 1, 0, -50378, 226, 0, 0, 39, '225'),
	(377, 1, 0, -50378, 227, 0, 0, 39, '226'),
	(377, 1, 0, -50378, 228, 0, 0, 39, '227'),
	(377, 1, 0, -50378, 229, 0, 0, 39, '228'),
	(377, 1, 0, -50378, 230, 0, 0, 39, '229'),
	(377, 1, 0, -50378, 231, 0, 0, 39, '230'),
	(377, 1, 0, -50378, 232, 0, 0, 39, '231'),
	(377, 1, 0, -50378, 233, 0, 0, 39, '232'),
	(377, 1, 0, -50378, 234, 0, 0, 39, '233'),
	(377, 1, 0, -50378, 235, 0, 0, 39, '234'),
	(377, 1, 0, -50378, 236, 0, 0, 39, '235'),
	(377, 1, 0, -50378, 237, 0, 0, 39, '236'),
	(377, 1, 0, -50378, 238, 0, 0, 39, '237'),
	(377, 1, 0, -50378, 239, 0, 0, 39, '238'),
	(377, 1, 0, -50378, 240, 0, 0, 39, '239'),
	(377, 1, 0, -50378, 241, 0, 0, 39, '240'),
	(377, 1, 0, -50378, 242, 0, 0, 39, '241'),
	(377, 1, 0, -50378, 243, 0, 0, 39, '242'),
	(377, 1, 0, -50378, 244, 0, 0, 39, '243'),
	(377, 1, 0, -50378, 245, 0, 0, 39, '244'),
	(377, 1, 0, -50378, 246, 0, 0, 39, '245'),
	(377, 1, 0, -50378, 247, 0, 0, 39, '246'),
	(377, 1, 0, -50378, 248, 0, 0, 39, '247'),
	(377, 1, 0, -50378, 249, 0, 0, 39, '248'),
	(377, 1, 0, -50378, 250, 0, 0, 39, '249'),
	(377, 1, 0, -50378, 251, 0, 0, 39, '250'),
	(377, 1, 0, -50378, 252, 0, 0, 39, '251'),
	(377, 1, 0, -50378, 253, 0, 0, 39, '252'),
	(377, 1, 0, -50378, 254, 0, 0, 39, '253'),
	(377, 1, 0, -50378, 255, 0, 0, 39, '254'),
	(377, 1, 0, -50378, 256, 0, 0, 39, '255'),
	(377, 1, 0, -50378, 257, 0, 0, 39, '256'),
	(377, 1, 0, -50378, 258, 0, 0, 39, '257'),
	(377, 1, 0, -50378, 259, 0, 0, 39, '258'),
	(377, 1, 0, -50378, 260, 0, 0, 39, '259'),
	(377, 1, 0, -50378, 261, 0, 0, 39, '260'),
	(377, 1, 0, -50378, 262, 0, 0, 39, '261'),
	(377, 1, 0, -50378, 263, 0, 0, 39, '262'),
	(377, 1, 0, -50378, 264, 0, 0, 39, '263'),
	(377, 1, 0, -50378, 265, 0, 0, 39, '264'),
	(377, 1, 0, -50378, 266, 0, 0, 39, '265'),
	(377, 1, 0, -50378, 267, 0, 0, 39, '266'),
	(377, 1, 0, -50378, 268, 0, 0, 39, '267'),
	(377, 1, 0, -50378, 269, 0, 0, 39, '268'),
	(377, 1, 0, -50378, 270, 0, 0, 39, '269'),
	(377, 1, 0, -50378, 271, 0, 0, 39, '270'),
	(377, 1, 0, -50378, 272, 0, 0, 39, '271'),
	(377, 1, 0, -50378, 273, 0, 0, 39, '272'),
	(377, 1, 0, -50378, 274, 0, 0, 39, '273'),
	(377, 1, 0, -50378, 275, 0, 0, 39, '274'),
	(377, 1, 0, -50378, 276, 0, 0, 39, '275'),
	(377, 1, 0, -50378, 277, 0, 0, 39, '276'),
	(377, 1, 0, -50378, 278, 0, 0, 39, '277'),
	(377, 1, 0, -50378, 279, 0, 0, 39, '278'),
	(377, 1, 0, -50378, 280, 0, 0, 39, '279'),
	(377, 1, 0, -50378, 281, 0, 0, 39, '280'),
	(377, 1, 0, -50378, 282, 0, 0, 39, '281'),
	(377, 1, 0, -50378, 283, 0, 0, 39, '282'),
	(377, 1, 0, -50378, 284, 0, 0, 39, '283'),
	(377, 1, 0, -50378, 285, 0, 0, 39, '284'),
	(377, 1, 0, -50378, 286, 0, 0, 39, '285'),
	(377, 1, 0, -50378, 287, 0, 0, 39, '286'),
	(377, 1, 0, -50378, 288, 0, 0, 39, '287'),
	(377, 1, 0, -50378, 289, 0, 0, 39, '288'),
	(377, 1, 0, -50378, 290, 0, 0, 39, '289'),
	(377, 1, 0, -50378, 291, 0, 0, 39, '290'),
	(377, 1, 0, -50378, 292, 0, 0, 39, '291'),
	(377, 1, 0, -50378, 293, 0, 0, 39, '292'),
	(377, 1, 0, -50378, 294, 0, 0, 39, '293'),
	(377, 1, 0, -50378, 295, 0, 0, 39, '294'),
	(377, 1, 0, -50378, 296, 0, 0, 39, '295'),
	(377, 1, 0, -50378, 297, 0, 0, 39, '296'),
	(377, 1, 0, -50378, 298, 0, 0, 39, '297'),
	(377, 1, 0, -50378, 299, 0, 0, 39, '298'),
	(377, 1, 0, -50378, 300, 0, 0, 39, '299'),
	(377, 1, 0, -50378, 301, 0, 0, 39, '300'),
	(377, 1, 0, -50378, 302, 0, 0, 39, '301'),
	(377, 1, 0, -50378, 303, 0, 0, 39, '302'),
	(377, 1, 0, -50378, 304, 0, 0, 39, '303'),
	(377, 1, 0, -50378, 305, 0, 0, 39, '304'),
	(377, 1, 0, -50378, 306, 0, 0, 39, '305'),
	(377, 1, 0, -50378, 307, 0, 0, 39, '306'),
	(377, 1, 0, -50378, 308, 0, 0, 39, '307'),
	(377, 1, 0, -50378, 309, 0, 0, 39, '308'),
	(377, 1, 0, -50378, 310, 0, 0, 39, '309'),
	(377, 1, 0, -50378, 311, 0, 0, 39, '310'),
	(377, 1, 0, -50378, 312, 0, 0, 39, '311'),
	(377, 1, 0, -50378, 313, 0, 0, 39, '312'),
	(377, 1, 0, -50378, 314, 0, 0, 39, '313'),
	(377, 1, 0, -50378, 315, 0, 0, 39, '314'),
	(377, 1, 0, -50378, 316, 0, 0, 39, '315'),
	(377, 1, 0, -50378, 317, 0, 0, 39, '316'),
	(377, 1, 0, -50378, 318, 0, 0, 39, '317'),
	(377, 1, 0, -50378, 319, 0, 0, 39, '318'),
	(377, 1, 0, -50378, 320, 0, 0, 39, '319'),
	(377, 1, 0, -50378, 321, 0, 0, 39, '320'),
	(377, 1, 0, -50378, 322, 0, 0, 39, '321'),
	(377, 1, 0, -50378, 323, 0, 0, 39, '322'),
	(377, 1, 0, -50378, 324, 0, 0, 39, '323'),
	(377, 1, 0, -50378, 325, 0, 0, 39, '324'),
	(377, 1, 0, -50378, 326, 0, 0, 39, '325'),
	(377, 1, 0, -50378, 327, 0, 0, 39, '326'),
	(377, 1, 0, -50378, 328, 0, 0, 39, '327'),
	(377, 1, 0, -50378, 329, 0, 0, 39, '328'),
	(377, 1, 0, -50378, 330, 0, 0, 39, '329'),
	(377, 1, 0, -50378, 331, 0, 0, 39, '330'),
	(377, 1, 0, -50378, 332, 0, 0, 39, '331'),
	(377, 1, 0, -50378, 333, 0, 0, 39, '332'),
	(377, 1, 0, -50378, 334, 0, 0, 39, '333'),
	(377, 1, 0, -50378, 335, 0, 0, 39, '334'),
	(377, 1, 0, -50378, 336, 0, 0, 39, '335'),
	(377, 1, 0, -50378, 337, 0, 0, 39, '336'),
	(377, 1, 0, -50378, 338, 0, 0, 39, '337'),
	(377, 1, 0, -50378, 339, 0, 0, 39, '338'),
	(377, 1, 0, -50378, 340, 0, 0, 39, '339'),
	(377, 1, 0, -50378, 341, 0, 0, 39, '340'),
	(377, 1, 0, -50378, 342, 0, 0, 39, '341'),
	(377, 1, 0, -50378, 343, 0, 0, 39, '342'),
	(377, 1, 0, -50378, 344, 0, 0, 39, '343'),
	(377, 1, 0, -50378, 345, 0, 0, 39, '344'),
	(377, 1, 0, -50378, 346, 0, 0, 39, '345'),
	(377, 1, 0, -50378, 347, 0, 0, 39, '346'),
	(377, 1, 0, -50378, 348, 0, 0, 39, '347'),
	(377, 1, 0, -50378, 349, 0, 0, 39, '348'),
	(377, 1, 0, -50378, 350, 0, 0, 39, '349'),
	(377, 1, 0, -50378, 351, 0, 0, 39, '350'),
	(377, 1, 0, -50378, 352, 0, 0, 39, '351'),
	(377, 1, 0, -50378, 353, 0, 0, 39, '352'),
	(377, 1, 0, -50378, 354, 0, 0, 39, '353'),
	(377, 1, 0, -50378, 355, 0, 0, 39, '354'),
	(377, 1, 0, -50378, 356, 0, 0, 39, '355'),
	(377, 1, 0, -50378, 357, 0, 0, 39, '356'),
	(377, 1, 0, -50378, 358, 0, 0, 39, '357'),
	(377, 1, 0, -50378, 359, 0, 0, 39, '358'),
	(377, 1, 0, -50378, 360, 0, 0, 39, '359'),
	(377, 1, 0, -50378, 361, 0, 0, 39, '360'),
	(377, 1, 0, -50378, 362, 0, 0, 39, '361'),
	(377, 1, 0, -50378, 363, 0, 0, 39, '362'),
	(377, 1, 0, -50378, 364, 0, 0, 39, '363'),
	(377, 1, 0, -50378, 365, 0, 0, 39, '364'),
	(377, 1, 0, -50378, 366, 0, 0, 39, '365'),
	(377, 1, 0, -50378, 367, 0, 0, 39, '366'),
	(377, 1, 0, -50378, 368, 0, 0, 39, '367'),
	(377, 1, 0, -50378, 369, 0, 0, 39, '368'),
	(377, 1, 0, -50378, 370, 0, 0, 39, '369'),
	(377, 1, 0, -50378, 371, 0, 0, 39, '370'),
	(377, 1, 0, -50378, 372, 0, 0, 39, '371'),
	(377, 1, 0, -50378, 373, 0, 0, 39, '372'),
	(377, 1, 0, -50378, 374, 0, 0, 39, '373'),
	(377, 1, 0, -50378, 375, 0, 0, 39, '374'),
	(377, 1, 0, -50378, 376, 0, 0, 39, '375'),
	(377, 1, 0, -50378, 377, 0, 0, 39, '376'),
	(377, 1, 0, -50378, 378, 0, 0, 39, '377'),
	(377, 1, 0, -50378, 379, 0, 0, 39, '378'),
	(377, 1, 0, -50378, 380, 0, 0, 39, '379'),
	(377, 1, 0, -50378, 381, 0, 0, 39, '380'),
	(377, 1, 0, -50378, 382, 0, 0, 39, '381'),
	(377, 1, 0, -50378, 383, 0, 0, 39, '382'),
	(377, 1, 0, -50378, 384, 0, 0, 39, '383'),
	(377, 1, 0, -50378, 385, 0, 0, 39, '384'),
	(377, 1, 0, -50378, 386, 0, 0, 39, '385'),
	(377, 1, 0, -50378, 387, 0, 0, 39, '386'),
	(377, 1, 0, -50378, 388, 0, 0, 39, '387'),
	(377, 1, 0, -50378, 389, 0, 0, 39, '388'),
	(377, 1, 0, -50378, 390, 0, 0, 39, '389'),
	(377, 1, 0, -50378, 391, 0, 0, 39, '390'),
	(377, 1, 0, -50378, 392, 0, 0, 39, '391'),
	(377, 1, 0, -50378, 393, 0, 0, 39, '392'),
	(377, 1, 0, -50378, 394, 0, 0, 39, '393'),
	(377, 1, 0, -50378, 395, 0, 0, 39, '394'),
	(377, 1, 0, -50378, 396, 0, 0, 39, '395'),
	(377, 1, 0, -50378, 397, 0, 0, 39, '396'),
	(377, 1, 0, -50378, 398, 0, 0, 39, '397'),
	(377, 1, 0, -50378, 399, 0, 0, 39, '398'),
	(377, 1, 0, -50378, 400, 0, 0, 39, '399'),
	(377, 1, 0, -50378, 401, 0, 0, 39, '400'),
	(377, 1, 0, -50378, 402, 0, 0, 39, '401'),
	(377, 1, 0, -50378, 403, 0, 0, 39, '402'),
	(377, 1, 0, -50378, 404, 0, 0, 39, '403'),
	(377, 1, 0, -50378, 405, 0, 0, 39, '404'),
	(377, 1, 0, -50378, 406, 0, 0, 39, '405'),
	(377, 1, 0, -50378, 407, 0, 0, 39, '406'),
	(377, 1, 0, -50378, 408, 0, 0, 39, '407'),
	(377, 1, 0, -50378, 409, 0, 0, 39, '408'),
	(377, 1, 0, -50378, 410, 0, 0, 39, '409'),
	(377, 1, 0, -50378, 411, 0, 0, 39, '410'),
	(377, 1, 0, -50378, 412, 0, 0, 39, '411'),
	(377, 1, 0, -50378, 413, 0, 0, 39, '412'),
	(377, 1, 0, -50378, 414, 0, 0, 39, '413'),
	(377, 1, 0, -50378, 415, 0, 0, 39, '414'),
	(377, 1, 0, -50378, 416, 0, 0, 39, '415'),
	(377, 1, 0, -50378, 417, 0, 0, 39, '416'),
	(377, 1, 0, -50378, 418, 0, 0, 39, '417'),
	(377, 1, 0, -50378, 419, 0, 0, 39, '418'),
	(377, 1, 0, -50378, 420, 0, 0, 39, '419'),
	(377, 1, 0, -50378, 421, 0, 0, 39, '420'),
	(377, 1, 0, -50378, 422, 0, 0, 39, '421'),
	(377, 1, 0, -50378, 423, 0, 0, 39, '422'),
	(377, 1, 0, -50378, 424, 0, 0, 39, '423'),
	(377, 1, 0, -50378, 425, 0, 0, 39, '424'),
	(377, 1, 0, -50378, 426, 0, 0, 39, '425'),
	(377, 1, 0, -50378, 427, 0, 0, 39, '426'),
	(377, 1, 0, -50378, 428, 0, 0, 39, '427'),
	(377, 1, 0, -50378, 429, 0, 0, 39, '428'),
	(377, 1, 0, -50378, 430, 0, 0, 39, '429'),
	(377, 1, 0, -50378, 431, 0, 0, 39, '430'),
	(377, 1, 0, -50378, 432, 0, 0, 39, '431'),
	(377, 1, 0, -50378, 433, 0, 0, 39, '432'),
	(377, 1, 0, -50378, 434, 0, 0, 39, '433'),
	(377, 1, 0, -50378, 435, 0, 0, 39, '434'),
	(377, 1, 0, -50378, 436, 0, 0, 39, '435'),
	(377, 1, 0, -50378, 437, 0, 0, 39, '436'),
	(377, 1, 0, -50378, 438, 0, 0, 39, '437'),
	(377, 1, 0, -50378, 439, 0, 0, 39, '438'),
	(377, 1, 0, -50378, 440, 0, 0, 39, '439'),
	(377, 1, 0, -50378, 441, 0, 0, 39, '440'),
	(377, 1, 0, -50378, 442, 0, 0, 39, '441'),
	(377, 1, 0, -50378, 443, 0, 0, 39, '442'),
	(377, 1, 0, -50378, 444, 0, 0, 39, '443'),
	(377, 1, 0, -50378, 445, 0, 0, 39, '444'),
	(377, 1, 0, -50378, 446, 0, 0, 39, '445'),
	(377, 1, 0, -50378, 447, 0, 0, 39, '446'),
	(377, 1, 0, -50378, 448, 0, 0, 39, '447'),
	(377, 1, 0, -50378, 449, 0, 0, 39, '448'),
	(377, 1, 0, -50378, 450, 0, 0, 39, '449'),
	(377, 1, 0, -50378, 451, 0, 0, 39, '450'),
	(377, 1, 0, -50378, 452, 0, 0, 39, '451'),
	(377, 1, 0, -50378, 453, 0, 0, 39, '452'),
	(377, 1, 0, -50378, 454, 0, 0, 39, '453'),
	(377, 1, 0, -50378, 455, 0, 0, 39, '454'),
	(377, 1, 0, -50378, 456, 0, 0, 39, '455'),
	(377, 1, 0, -50378, 457, 0, 0, 39, '456'),
	(377, 1, 0, -50378, 458, 0, 0, 39, '457'),
	(377, 1, 0, -50378, 459, 0, 0, 39, '458'),
	(377, 1, 0, -50378, 460, 0, 0, 39, '459'),
	(377, 1, 0, -50378, 461, 0, 0, 39, '460'),
	(377, 1, 0, -50378, 462, 0, 0, 39, '461'),
	(377, 1, 0, -50378, 463, 0, 0, 39, '462'),
	(377, 1, 0, -50378, 464, 0, 0, 39, '463'),
	(377, 1, 0, -50378, 465, 0, 0, 39, '464'),
	(377, 1, 0, -50378, 466, 0, 0, 39, '465'),
	(377, 1, 0, -50378, 467, 0, 0, 39, '466'),
	(377, 1, 0, -50378, 468, 0, 0, 39, '467'),
	(377, 1, 0, -50378, 469, 0, 0, 39, '468'),
	(377, 1, 0, -50378, 470, 0, 0, 39, '469'),
	(377, 1, 0, -50378, 471, 0, 0, 39, '470'),
	(377, 1, 0, -50378, 472, 0, 0, 39, '471'),
	(377, 1, 0, -50378, 473, 0, 0, 39, '472'),
	(377, 1, 0, -50378, 474, 0, 0, 39, '473'),
	(377, 1, 0, -50378, 475, 0, 0, 39, '474'),
	(377, 1, 0, -50378, 476, 0, 0, 39, '475'),
	(377, 1, 0, -50378, 477, 0, 0, 39, '476'),
	(377, 1, 0, -50378, 478, 0, 0, 39, '477'),
	(377, 1, 0, -50378, 479, 0, 0, 39, '478'),
	(377, 1, 0, -50378, 480, 0, 0, 39, '479'),
	(377, 1, 0, -50378, 481, 0, 0, 39, '480'),
	(377, 1, 0, -50378, 482, 0, 0, 39, '481'),
	(377, 1, 0, -50378, 483, 0, 0, 39, '482'),
	(377, 1, 0, -50378, 484, 0, 0, 39, '483'),
	(377, 1, 0, -50378, 485, 0, 0, 39, '484'),
	(377, 1, 0, -50378, 486, 0, 0, 39, '485'),
	(377, 1, 0, -50378, 487, 0, 0, 39, '486'),
	(377, 1, 0, -50378, 488, 0, 0, 39, '487'),
	(377, 1, 0, -50378, 489, 0, 0, 39, '488'),
	(377, 1, 0, -50378, 490, 0, 0, 39, '489'),
	(377, 1, 0, -50378, 491, 0, 0, 39, '490'),
	(377, 1, 0, -50378, 492, 0, 0, 39, '491'),
	(377, 1, 0, -50378, 493, 0, 0, 39, '492'),
	(377, 1, 0, -50378, 494, 0, 0, 39, '493'),
	(377, 1, 0, -50378, 495, 0, 0, 39, '494'),
	(377, 1, 0, -50378, 496, 0, 0, 39, '495'),
	(377, 1, 0, -50378, 497, 0, 0, 39, '496'),
	(377, 1, 0, -50378, 498, 0, 0, 39, '497'),
	(377, 1, 0, -50378, 499, 0, 0, 39, '498'),
	(377, 1, 0, -50378, 500, 0, 0, 39, '499'),
	(377, 1, 0, -50378, 501, 0, 0, 39, '500'),
	(377, 1, 0, -50378, 502, 0, 0, 39, '501'),
	(377, 1, 0, -50378, 503, 0, 0, 39, '502'),
	(377, 1, 0, -50378, 504, 0, 0, 39, '503'),
	(377, 1, 0, -50378, 505, 0, 0, 39, '504'),
	(377, 1, 0, -50378, 506, 0, 0, 39, '505'),
	(377, 1, 0, -50378, 507, 0, 0, 39, '506'),
	(377, 1, 0, -50378, 508, 0, 0, 39, '507'),
	(377, 1, 0, -50378, 509, 0, 0, 39, '508'),
	(377, 1, 0, -50378, 510, 0, 0, 39, '509'),
	(377, 1, 0, -50378, 511, 0, 0, 39, '510'),
	(377, 1, 0, -50378, 512, 0, 0, 39, '511'),
	(377, 1, 0, -50378, 513, 0, 0, 39, '512'),
	(377, 1, 0, -50378, 514, 0, 0, 39, '513'),
	(377, 1, 0, -50378, 515, 0, 0, 39, '514'),
	(377, 1, 0, -50378, 516, 0, 0, 39, '515'),
	(377, 1, 0, -50378, 517, 0, 0, 39, '516'),
	(377, 1, 0, -50378, 518, 0, 0, 39, '517'),
	(377, 1, 0, -50378, 519, 0, 0, 39, '518'),
	(377, 1, 0, -50378, 520, 0, 0, 39, '519'),
	(377, 1, 0, -50378, 521, 0, 0, 39, '520'),
	(377, 1, 0, -50378, 522, 0, 0, 39, '521'),
	(377, 1, 0, -50378, 523, 0, 0, 39, '522'),
	(377, 1, 0, -50378, 524, 0, 0, 39, '523'),
	(377, 1, 0, -50378, 525, 0, 0, 39, '524'),
	(377, 1, 0, -50378, 526, 0, 0, 39, '525'),
	(377, 1, 0, -50378, 527, 0, 0, 39, '526'),
	(377, 1, 0, -50378, 528, 0, 0, 39, '527'),
	(377, 1, 0, -50378, 529, 0, 0, 39, '528'),
	(377, 1, 0, -50378, 530, 0, 0, 39, '529'),
	(377, 1, 0, -50378, 531, 0, 0, 39, '530'),
	(377, 1, 0, -50378, 532, 0, 0, 39, '531'),
	(377, 1, 0, -50378, 533, 0, 0, 39, '532'),
	(377, 1, 0, -50378, 534, 0, 0, 39, '533'),
	(377, 1, 0, -50378, 535, 0, 0, 39, '534'),
	(377, 1, 0, -50378, 536, 0, 0, 39, '535'),
	(377, 1, 0, -50378, 537, 0, 0, 39, '536'),
	(377, 1, 0, -50378, 538, 0, 0, 39, '537'),
	(377, 1, 0, -50378, 539, 0, 0, 39, '538'),
	(377, 1, 0, -50378, 540, 0, 0, 39, '539'),
	(377, 1, 0, -50378, 541, 0, 0, 39, '540'),
	(377, 1, 0, -50378, 542, 0, 0, 39, '541'),
	(377, 1, 0, -50378, 543, 0, 0, 39, '542'),
	(377, 1, 0, -50378, 544, 0, 0, 39, '543'),
	(377, 1, 0, -50378, 545, 0, 0, 39, '544'),
	(377, 1, 0, -50378, 546, 0, 0, 39, '545'),
	(377, 1, 0, -50378, 547, 0, 0, 39, '546'),
	(377, 1, 0, -50378, 548, 0, 0, 39, '547'),
	(377, 1, 0, -50378, 549, 0, 0, 39, '548'),
	(377, 1, 0, -50378, 550, 0, 0, 39, '549'),
	(377, 1, 0, -50378, 551, 0, 0, 39, '550'),
	(377, 1, 0, -50378, 552, 0, 0, 39, '551'),
	(377, 1, 0, -50378, 553, 0, 0, 39, '552'),
	(377, 1, 0, -50378, 554, 0, 0, 39, '553'),
	(377, 1, 0, -50378, 555, 0, 0, 39, '554'),
	(377, 1, 0, -50378, 556, 0, 0, 39, '555'),
	(377, 1, 0, -50378, 557, 0, 0, 39, '556'),
	(377, 1, 0, -50378, 558, 0, 0, 39, '557'),
	(377, 1, 0, -50378, 559, 0, 0, 39, '558'),
	(377, 1, 0, -50378, 560, 0, 0, 39, '559'),
	(377, 1, 0, -50378, 561, 0, 0, 39, '560'),
	(377, 1, 0, -50378, 562, 0, 0, 39, '561'),
	(377, 1, 0, -50378, 563, 0, 0, 39, '562'),
	(377, 1, 0, -50378, 564, 0, 0, 39, '563'),
	(377, 1, 0, -50378, 565, 0, 0, 39, '564'),
	(377, 1, 0, -50378, 566, 0, 0, 39, '565'),
	(377, 1, 0, -50378, 567, 0, 0, 39, '566'),
	(377, 1, 0, -50378, 568, 0, 0, 39, '567'),
	(377, 1, 0, -50378, 569, 0, 0, 39, '568'),
	(377, 1, 0, -50378, 570, 0, 0, 39, '569'),
	(377, 1, 0, -50378, 571, 0, 0, 39, '570'),
	(377, 1, 0, -50378, 572, 0, 0, 39, '571'),
	(377, 1, 0, -50378, 573, 0, 0, 39, '572'),
	(377, 1, 0, -50378, 574, 0, 0, 39, '573'),
	(377, 1, 0, -50378, 575, 0, 0, 39, '574'),
	(377, 1, 0, -50378, 576, 0, 0, 39, '575'),
	(377, 1, 0, -50378, 577, 0, 0, 39, '576'),
	(377, 1, 0, -50378, 578, 0, 0, 39, '577'),
	(377, 1, 0, -50378, 579, 0, 0, 39, '578'),
	(377, 1, 0, -50378, 580, 0, 0, 39, '579'),
	(377, 1, 0, -50378, 581, 0, 0, 39, '580'),
	(377, 1, 0, -50378, 582, 0, 0, 39, '581'),
	(377, 1, 0, -50378, 583, 0, 0, 39, '582'),
	(377, 1, 0, -50378, 584, 0, 0, 39, '583'),
	(377, 1, 0, -50378, 585, 0, 0, 39, '584'),
	(377, 1, 0, -50378, 586, 0, 0, 39, '585'),
	(377, 1, 0, -50378, 587, 0, 0, 39, '586'),
	(377, 1, 0, -50378, 588, 0, 0, 39, '587'),
	(377, 1, 0, -50378, 589, 0, 0, 39, '588'),
	(377, 1, 0, -50378, 590, 0, 0, 39, '589'),
	(377, 1, 0, -50378, 591, 0, 0, 39, '590'),
	(377, 1, 0, -50378, 592, 0, 0, 39, '591'),
	(377, 1, 0, -50378, 593, 0, 0, 39, '592'),
	(377, 1, 0, -50378, 594, 0, 0, 39, '593'),
	(377, 1, 0, -50378, 595, 0, 0, 39, '594'),
	(377, 1, 0, -50378, 596, 0, 0, 39, '595'),
	(377, 1, 0, -50378, 597, 0, 0, 39, '596'),
	(377, 1, 0, -50378, 598, 0, 0, 39, '597'),
	(377, 1, 0, -50378, 599, 0, 0, 39, '598'),
	(377, 1, 0, -50378, 600, 0, 0, 39, '599'),
	(377, 1, 0, -50378, 601, 0, 0, 39, '600'),
	(377, 1, 0, -50378, 602, 0, 0, 39, '601'),
	(377, 1, 0, -50378, 603, 0, 0, 39, '602'),
	(377, 1, 0, -50378, 604, 0, 0, 39, '603'),
	(377, 1, 0, -50378, 605, 0, 0, 39, '604'),
	(377, 1, 0, -50378, 606, 0, 0, 39, '605'),
	(377, 1, 0, -50378, 607, 0, 0, 39, '606'),
	(377, 1, 0, -50378, 608, 0, 0, 39, '607'),
	(377, 1, 0, -50378, 609, 0, 0, 39, '608'),
	(377, 1, 0, -50378, 610, 0, 0, 39, '609'),
	(377, 1, 0, -50378, 611, 0, 0, 39, '610'),
	(377, 1, 0, -50378, 612, 0, 0, 39, '611'),
	(377, 1, 0, -50378, 613, 0, 0, 39, '612'),
	(377, 1, 0, -50378, 614, 0, 0, 39, '613'),
	(377, 1, 0, -50378, 615, 0, 0, 39, '614'),
	(377, 1, 0, -50378, 616, 0, 0, 39, '615'),
	(377, 1, 0, -50378, 617, 0, 0, 39, '616'),
	(377, 1, 0, -50378, 618, 0, 0, 39, '617'),
	(377, 1, 0, -50378, 619, 0, 0, 39, '618'),
	(377, 1, 0, -50378, 620, 0, 0, 39, '619'),
	(377, 1, 0, -50378, 621, 0, 0, 39, '620'),
	(377, 1, 0, -50378, 622, 0, 0, 39, '621'),
	(377, 1, 0, -50378, 623, 0, 0, 39, '622'),
	(377, 1, 0, -50378, 624, 0, 0, 39, '623'),
	(377, 1, 0, -50378, 625, 0, 0, 39, '624'),
	(377, 1, 0, -50378, 626, 0, 0, 39, '625'),
	(377, 1, 0, -50378, 627, 0, 0, 39, '626'),
	(377, 1, 0, -50378, 628, 0, 0, 39, '627'),
	(377, 1, 0, -50378, 629, 0, 0, 39, '628'),
	(377, 1, 0, -50378, 630, 0, 0, 39, '629'),
	(377, 1, 0, -50378, 631, 0, 0, 39, '630'),
	(377, 1, 0, -50378, 632, 0, 0, 39, '631'),
	(377, 1, 0, -50378, 633, 0, 0, 39, '632'),
	(377, 1, 0, -50378, 634, 0, 0, 39, '633'),
	(377, 1, 0, -50378, 635, 0, 0, 39, '634'),
	(377, 1, 0, -50378, 636, 0, 0, 39, '635'),
	(377, 1, 0, -50378, 637, 0, 0, 39, '636'),
	(377, 1, 0, -50378, 638, 0, 0, 39, '637'),
	(377, 1, 0, -50378, 639, 0, 0, 39, '638'),
	(377, 1, 0, -50378, 640, 0, 0, 39, '639'),
	(377, 1, 0, -50378, 641, 0, 0, 39, '640'),
	(377, 1, 0, -50378, 642, 0, 0, 39, '641'),
	(377, 1, 0, -50378, 643, 0, 0, 39, '642'),
	(377, 1, 0, -50378, 644, 0, 0, 39, '643'),
	(377, 1, 0, -50378, 645, 0, 0, 39, '644'),
	(377, 1, 0, -50378, 646, 0, 0, 39, '645'),
	(377, 1, 0, -50378, 647, 0, 0, 39, '646'),
	(377, 1, 0, -50378, 648, 0, 0, 39, '647'),
	(377, 1, 0, -50378, 649, 0, 0, 39, '648'),
	(377, 1, 0, -50378, 650, 0, 0, 39, '649'),
	(377, 1, 0, -50378, 651, 0, 0, 39, '650'),
	(377, 1, 0, -50378, 652, 0, 0, 39, '651'),
	(377, 1, 0, -50378, 653, 0, 0, 39, '652'),
	(377, 1, 0, -50378, 654, 0, 0, 39, '653'),
	(377, 1, 0, -50378, 655, 0, 0, 39, '654'),
	(377, 1, 0, -50378, 656, 0, 0, 39, '655'),
	(377, 1, 0, -50378, 657, 0, 0, 39, '656'),
	(377, 1, 0, -50378, 658, 0, 0, 39, '657'),
	(377, 1, 0, -50378, 659, 0, 0, 39, '658'),
	(377, 1, 0, -50378, 660, 0, 0, 39, '659'),
	(377, 1, 0, -50378, 661, 0, 0, 39, '660'),
	(377, 1, 0, -50378, 662, 0, 0, 39, '661'),
	(377, 1, 0, -50378, 663, 0, 0, 39, '662'),
	(377, 1, 0, -50378, 664, 0, 0, 39, '663'),
	(377, 1, 0, -50378, 665, 0, 0, 39, '664'),
	(377, 1, 0, -50378, 666, 0, 0, 39, '665'),
	(377, 1, 0, -50378, 667, 0, 0, 39, '666'),
	(377, 1, 0, -50378, 668, 0, 0, 39, '667'),
	(377, 1, 0, -50378, 669, 0, 0, 39, '668'),
	(377, 1, 0, -50378, 670, 0, 0, 39, '669'),
	(377, 1, 0, -50378, 671, 0, 0, 39, '670'),
	(377, 1, 0, -50378, 672, 0, 0, 39, '671'),
	(377, 1, 0, -50378, 673, 0, 0, 39, '672'),
	(377, 1, 0, -50378, 674, 0, 0, 39, '673'),
	(377, 1, 0, -50378, 675, 0, 0, 39, '674'),
	(377, 1, 0, -50378, 676, 0, 0, 39, '675'),
	(377, 1, 0, -50378, 677, 0, 0, 39, '676'),
	(377, 1, 0, -50378, 678, 0, 0, 39, '677'),
	(377, 1, 0, -50378, 679, 0, 0, 39, '678'),
	(377, 1, 0, -50378, 680, 0, 0, 39, '679'),
	(377, 1, 0, -50378, 681, 0, 0, 39, '680'),
	(377, 1, 0, -50378, 682, 0, 0, 39, '681'),
	(377, 1, 0, -50378, 683, 0, 0, 39, '682'),
	(377, 1, 0, -50378, 684, 0, 0, 39, '683'),
	(377, 1, 0, -50378, 685, 0, 0, 39, '684'),
	(377, 1, 0, -50378, 686, 0, 0, 39, '685'),
	(377, 1, 0, -50378, 687, 0, 0, 39, '686'),
	(377, 1, 0, -50378, 688, 0, 0, 39, '687'),
	(377, 1, 0, -50378, 689, 0, 0, 39, '688'),
	(377, 1, 0, -50378, 690, 0, 0, 39, '689'),
	(377, 1, 0, -50378, 691, 0, 0, 39, '690'),
	(377, 1, 0, -50378, 692, 0, 0, 39, '691'),
	(377, 1, 0, -50378, 693, 0, 0, 39, '692'),
	(377, 1, 0, -50378, 694, 0, 0, 39, '693'),
	(377, 1, 0, -50378, 695, 0, 0, 39, '694'),
	(377, 1, 0, -50378, 696, 0, 0, 39, '695'),
	(377, 1, 0, -50378, 697, 0, 0, 39, '696'),
	(377, 1, 0, -50378, 698, 0, 0, 39, '697'),
	(377, 1, 0, -50378, 699, 0, 0, 39, '698'),
	(377, 1, 0, -50378, 700, 0, 0, 39, '699'),
	(377, 1, 0, -50378, 701, 0, 0, 39, '700'),
	(377, 1, 0, -50378, 702, 0, 0, 39, '701'),
	(377, 1, 0, -50378, 703, 0, 0, 39, '702'),
	(377, 1, 0, -50378, 704, 0, 0, 39, '703'),
	(377, 1, 0, -50378, 705, 0, 0, 39, '704'),
	(377, 1, 0, -50378, 706, 0, 0, 39, '705'),
	(377, 1, 0, -50378, 707, 0, 0, 39, '706'),
	(377, 1, 0, -50378, 708, 0, 0, 39, '707'),
	(377, 1, 0, -50378, 709, 0, 0, 39, '708'),
	(377, 1, 0, -50378, 710, 0, 0, 39, '709'),
	(377, 1, 0, -50378, 711, 0, 0, 39, '710'),
	(377, 1, 0, -50378, 712, 0, 0, 39, '711'),
	(377, 1, 0, -50378, 713, 0, 0, 39, '712'),
	(377, 1, 0, -50378, 714, 0, 0, 39, '713'),
	(377, 1, 0, -50378, 715, 0, 0, 39, '714'),
	(377, 1, 0, -50378, 716, 0, 0, 39, '715'),
	(377, 1, 0, -50378, 717, 0, 0, 39, '716'),
	(377, 1, 0, -50378, 718, 0, 0, 39, '717'),
	(377, 1, 0, -50378, 719, 0, 0, 39, '718'),
	(377, 1, 0, -50378, 720, 0, 0, 39, '719'),
	(377, 1, 0, -50378, 721, 0, 0, 39, '720'),
	(377, 1, 0, -50378, 722, 0, 0, 39, '721'),
	(377, 1, 0, -50378, 723, 0, 0, 39, '722'),
	(377, 1, 0, -50378, 724, 0, 0, 39, '723'),
	(377, 1, 0, -50378, 725, 0, 0, 39, '724'),
	(377, 1, 0, -50378, 726, 0, 0, 39, '725'),
	(377, 1, 0, -50378, 727, 0, 0, 39, '726'),
	(377, 1, 0, -50378, 728, 0, 0, 39, '727'),
	(377, 1, 0, -50378, 729, 0, 0, 39, '728'),
	(377, 1, 0, -50378, 730, 0, 0, 39, '729'),
	(377, 1, 0, -50378, 731, 0, 0, 39, '730'),
	(377, 1, 0, -50378, 732, 0, 0, 39, '731'),
	(377, 1, 0, -50378, 733, 0, 0, 39, '732'),
	(377, 1, 0, -50378, 734, 0, 0, 39, '733'),
	(377, 1, 0, -50378, 735, 0, 0, 39, '734'),
	(377, 1, 0, -50378, 736, 0, 0, 39, '735'),
	(377, 1, 0, -50378, 737, 0, 0, 39, '736'),
	(377, 1, 0, -50378, 738, 0, 0, 39, '737'),
	(377, 1, 0, -50378, 739, 0, 0, 39, '738'),
	(377, 1, 0, -50378, 740, 0, 0, 39, '739'),
	(377, 1, 0, -50378, 741, 0, 0, 39, '740'),
	(377, 1, 0, -50378, 742, 0, 0, 39, '741'),
	(377, 1, 0, -50378, 743, 0, 0, 39, '742'),
	(377, 1, 0, -50378, 744, 0, 0, 39, '743'),
	(377, 1, 0, -50378, 745, 0, 0, 39, '744'),
	(377, 1, 0, -50378, 746, 0, 0, 39, '745'),
	(377, 1, 0, -50378, 747, 0, 0, 39, '746'),
	(377, 1, 0, -50378, 748, 0, 0, 39, '747'),
	(377, 1, 0, -50378, 749, 0, 0, 39, '748'),
	(377, 1, 0, -50378, 750, 0, 0, 39, '749'),
	(377, 1, 0, -50378, 751, 0, 0, 39, '750'),
	(377, 1, 0, -50378, 752, 0, 0, 39, '751'),
	(377, 1, 0, -50378, 753, 0, 0, 39, '752'),
	(377, 1, 0, -50378, 754, 0, 0, 39, '753'),
	(377, 1, 0, -50378, 755, 0, 0, 39, '754'),
	(377, 1, 0, -50378, 756, 0, 0, 39, '755'),
	(377, 1, 0, -50378, 757, 0, 0, 39, '756'),
	(377, 1, 0, -50378, 758, 0, 0, 39, '757'),
	(377, 1, 0, -50378, 759, 0, 0, 39, '758'),
	(377, 1, 0, -50378, 760, 0, 0, 39, '759'),
	(377, 1, 0, -50378, 761, 0, 0, 39, '760'),
	(377, 1, 0, -50378, 762, 0, 0, 39, '761'),
	(377, 1, 0, -50378, 763, 0, 0, 39, '762'),
	(377, 1, 0, -50378, 764, 0, 0, 39, '763'),
	(377, 1, 0, -50378, 765, 0, 0, 39, '764'),
	(377, 1, 0, -50378, 766, 0, 0, 39, '765'),
	(377, 1, 0, -50378, 767, 0, 0, 39, '766'),
	(377, 1, 0, -50378, 768, 0, 0, 39, '767'),
	(377, 1, 0, -50378, 769, 0, 0, 39, '768'),
	(377, 1, 0, -50378, 770, 0, 0, 39, '769'),
	(377, 1, 0, -50378, 771, 0, 0, 39, '770'),
	(377, 1, 0, -50378, 772, 0, 0, 39, '771'),
	(377, 1, 0, -50378, 773, 0, 0, 39, '772'),
	(377, 1, 0, -50378, 774, 0, 0, 39, '773'),
	(377, 1, 0, -50378, 775, 0, 0, 39, '774'),
	(377, 1, 0, -50378, 776, 0, 0, 39, '775'),
	(377, 1, 0, -50378, 777, 0, 0, 39, '776'),
	(377, 1, 0, -50378, 778, 0, 0, 39, '777'),
	(377, 1, 0, -50378, 779, 0, 0, 39, '778'),
	(377, 1, 0, -50378, 780, 0, 0, 39, '779'),
	(377, 1, 0, -50378, 781, 0, 0, 39, '780'),
	(377, 1, 0, -50378, 782, 0, 0, 39, '781'),
	(377, 1, 0, -50378, 783, 0, 0, 39, '782'),
	(377, 1, 0, -50378, 784, 0, 0, 39, '783'),
	(377, 1, 0, -50378, 785, 0, 0, 39, '784'),
	(377, 1, 0, -50378, 786, 0, 0, 39, '785'),
	(377, 1, 0, -50378, 787, 0, 0, 39, '786'),
	(377, 1, 0, -50378, 788, 0, 0, 39, '787'),
	(377, 1, 0, -50378, 789, 0, 0, 39, '788'),
	(377, 1, 0, -50378, 790, 0, 0, 39, '789'),
	(377, 1, 0, -50378, 791, 0, 0, 39, '790'),
	(377, 1, 0, -50378, 792, 0, 0, 39, '791'),
	(377, 1, 0, -50378, 793, 0, 0, 39, '792'),
	(377, 1, 0, -50378, 794, 0, 0, 39, '793'),
	(377, 1, 0, -50378, 795, 0, 0, 39, '794'),
	(377, 1, 0, -50378, 796, 0, 0, 39, '795'),
	(377, 1, 0, -50378, 797, 0, 0, 39, '796'),
	(377, 1, 0, -50378, 798, 0, 0, 39, '797'),
	(377, 1, 0, -50378, 799, 0, 0, 39, '798'),
	(377, 1, 0, -50378, 800, 0, 0, 39, '799'),
	(377, 1, 0, -50378, 801, 0, 0, 39, '800'),
	(377, 1, 0, -50378, 802, 0, 0, 39, '801'),
	(377, 1, 0, -50378, 803, 0, 0, 39, '802'),
	(377, 1, 0, -50378, 804, 0, 0, 39, '803'),
	(377, 1, 0, -50378, 805, 0, 0, 39, '804'),
	(377, 1, 0, -50378, 806, 0, 0, 39, '805'),
	(377, 1, 0, -50378, 807, 0, 0, 39, '806'),
	(377, 1, 0, -50378, 808, 0, 0, 39, '807'),
	(377, 1, 0, -50378, 809, 0, 0, 39, '808'),
	(377, 1, 0, -50378, 810, 0, 0, 39, '809'),
	(377, 1, 0, -50378, 811, 0, 0, 39, '810'),
	(377, 1, 0, -50378, 812, 0, 0, 39, '811'),
	(377, 1, 0, -50378, 813, 0, 0, 39, '812'),
	(377, 1, 0, -50378, 814, 0, 0, 39, '813'),
	(377, 1, 0, -50378, 815, 0, 0, 39, '814'),
	(377, 1, 0, -50378, 816, 0, 0, 39, '815'),
	(377, 1, 0, -50378, 817, 0, 0, 39, '816'),
	(377, 1, 0, -50378, 818, 0, 0, 39, '817'),
	(377, 1, 0, -50378, 819, 0, 0, 39, '818'),
	(377, 1, 0, -50378, 820, 0, 0, 39, '819'),
	(377, 1, 0, -50378, 821, 0, 0, 39, '820'),
	(377, 1, 0, -50378, 822, 0, 0, 39, '821'),
	(377, 1, 0, -50378, 823, 0, 0, 39, '822'),
	(377, 1, 0, -50378, 824, 0, 0, 39, '823'),
	(377, 1, 0, -50378, 825, 0, 0, 39, '824'),
	(377, 1, 0, -50378, 826, 0, 0, 39, '825'),
	(377, 1, 0, -50378, 827, 0, 0, 39, '826'),
	(377, 1, 0, -50378, 828, 0, 0, 39, '827'),
	(377, 1, 0, -50378, 829, 0, 0, 39, '828'),
	(377, 1, 0, -50378, 830, 0, 0, 39, '829'),
	(377, 1, 0, -50378, 831, 0, 0, 39, '830'),
	(377, 1, 0, -50378, 832, 0, 0, 39, '831'),
	(377, 1, 0, -50378, 833, 0, 0, 39, '832'),
	(377, 1, 0, -50378, 834, 0, 0, 39, '833'),
	(377, 1, 0, -50378, 835, 0, 0, 39, '834'),
	(377, 1, 0, -50378, 836, 0, 0, 39, '835'),
	(377, 1, 0, -50378, 837, 0, 0, 39, '836'),
	(377, 1, 0, -50378, 838, 0, 0, 39, '837'),
	(377, 1, 0, -50378, 839, 0, 0, 39, '838'),
	(377, 1, 0, -50378, 840, 0, 0, 39, '839'),
	(377, 1, 0, -50378, 841, 0, 0, 39, '840'),
	(377, 1, 0, -50378, 842, 0, 0, 39, '841'),
	(377, 1, 0, -50378, 843, 0, 0, 39, '842'),
	(377, 1, 0, -50378, 844, 0, 0, 39, '843'),
	(377, 1, 0, -50378, 845, 0, 0, 39, '844'),
	(377, 1, 0, -50378, 846, 0, 0, 39, '845'),
	(377, 1, 0, -50378, 847, 0, 0, 39, '846'),
	(377, 1, 0, -50378, 848, 0, 0, 39, '847'),
	(377, 1, 0, -50378, 849, 0, 0, 39, '848'),
	(377, 1, 0, -50378, 850, 0, 0, 39, '849'),
	(377, 1, 0, -50378, 851, 0, 0, 39, '850'),
	(377, 1, 0, -50378, 852, 0, 0, 39, '851'),
	(377, 1, 0, -50378, 853, 0, 0, 39, '852'),
	(377, 1, 0, -50378, 854, 0, 0, 39, '853'),
	(377, 1, 0, -50378, 855, 0, 0, 39, '854'),
	(377, 1, 0, -50378, 856, 0, 0, 39, '855'),
	(377, 1, 0, -50378, 857, 0, 0, 39, '856'),
	(377, 1, 0, -50378, 858, 0, 0, 39, '857'),
	(377, 1, 0, -50378, 859, 0, 0, 39, '858'),
	(377, 1, 0, -50378, 860, 0, 0, 39, '859'),
	(377, 1, 0, -50378, 861, 0, 0, 39, '860'),
	(377, 1, 0, -50378, 862, 0, 0, 39, '861'),
	(377, 1, 0, -50378, 863, 0, 0, 39, '862'),
	(377, 1, 0, -50378, 864, 0, 0, 39, '863'),
	(377, 1, 0, -50378, 865, 0, 0, 39, '864'),
	(377, 1, 0, -50378, 866, 0, 0, 39, '865'),
	(377, 1, 0, -50378, 867, 0, 0, 39, '866'),
	(377, 1, 0, -50378, 868, 0, 0, 39, '867'),
	(377, 1, 0, -50378, 869, 0, 0, 39, '868'),
	(377, 1, 0, -50378, 870, 0, 0, 39, '869'),
	(377, 1, 0, -50378, 871, 0, 0, 39, '870'),
	(377, 1, 0, -50378, 872, 0, 0, 39, '871'),
	(377, 1, 0, -50378, 873, 0, 0, 39, '872'),
	(377, 1, 0, -50378, 874, 0, 0, 39, '873'),
	(377, 1, 0, -50378, 875, 0, 0, 39, '874'),
	(377, 1, 0, -50378, 876, 0, 0, 39, '875'),
	(377, 1, 0, -50378, 877, 0, 0, 39, '876'),
	(377, 1, 0, -50378, 878, 0, 0, 39, '877'),
	(377, 1, 0, -50378, 879, 0, 0, 39, '878'),
	(377, 1, 0, -50378, 880, 0, 0, 39, '879'),
	(377, 1, 0, -50378, 881, 0, 0, 39, '880'),
	(377, 1, 0, -50378, 882, 0, 0, 39, '881'),
	(377, 1, 0, -50378, 883, 0, 0, 39, '882'),
	(377, 1, 0, -50378, 884, 0, 0, 39, '883'),
	(377, 1, 0, -50378, 885, 0, 0, 39, '884'),
	(377, 1, 0, -50378, 886, 0, 0, 39, '885'),
	(377, 1, 0, -50378, 887, 0, 0, 39, '886'),
	(377, 1, 0, -50378, 888, 0, 0, 39, '887'),
	(377, 1, 0, -50378, 889, 0, 0, 39, '888'),
	(377, 1, 0, -50378, 890, 0, 0, 39, '889'),
	(377, 1, 0, -50378, 891, 0, 0, 39, '890'),
	(377, 1, 0, -50378, 892, 0, 0, 39, '891'),
	(377, 1, 0, -50378, 893, 0, 0, 39, '892'),
	(377, 1, 0, -50378, 894, 0, 0, 39, '893'),
	(377, 1, 0, -50378, 895, 0, 0, 39, '894'),
	(377, 1, 0, -50378, 896, 0, 0, 39, '895'),
	(377, 1, 0, -50378, 897, 0, 0, 39, '896'),
	(377, 1, 0, -50378, 898, 0, 0, 39, '897'),
	(377, 1, 0, -50378, 899, 0, 0, 39, '898'),
	(377, 1, 0, -50378, 900, 0, 0, 39, '899'),
	(377, 1, 0, -50378, 901, 0, 0, 39, '900'),
	(377, 1, 0, -50378, 902, 0, 0, 39, '901'),
	(377, 1, 0, -50378, 903, 0, 0, 39, '902'),
	(377, 1, 0, -50378, 904, 0, 0, 39, '903'),
	(377, 1, 0, -50378, 905, 0, 0, 39, '904'),
	(377, 1, 0, -50378, 906, 0, 0, 39, '905'),
	(377, 1, 0, -50378, 907, 0, 0, 39, '906'),
	(377, 1, 0, -50378, 908, 0, 0, 39, '907'),
	(377, 1, 0, -50378, 909, 0, 0, 39, '908'),
	(377, 1, 0, -50378, 910, 0, 0, 39, '909'),
	(377, 1, 0, -50378, 911, 0, 0, 39, '910'),
	(377, 1, 0, -50378, 912, 0, 0, 39, '911'),
	(377, 1, 0, -50378, 913, 0, 0, 39, '912'),
	(377, 1, 0, -50378, 914, 0, 0, 39, '913'),
	(377, 1, 0, -50378, 915, 0, 0, 39, '914'),
	(377, 1, 0, -50378, 916, 0, 0, 39, '915'),
	(377, 1, 0, -50378, 917, 0, 0, 39, '916'),
	(377, 1, 0, -50378, 918, 0, 0, 39, '917'),
	(377, 1, 0, -50378, 919, 0, 0, 39, '918'),
	(377, 1, 0, -50378, 920, 0, 0, 39, '919'),
	(377, 1, 0, -50378, 921, 0, 0, 39, '920'),
	(377, 1, 0, -50378, 922, 0, 0, 39, '921'),
	(377, 1, 0, -50378, 923, 0, 0, 39, '922'),
	(377, 1, 0, -50378, 924, 0, 0, 39, '923'),
	(377, 1, 0, -50378, 925, 0, 0, 39, '924'),
	(377, 1, 0, -50378, 926, 0, 0, 39, '925'),
	(377, 1, 0, -50378, 927, 0, 0, 39, '926'),
	(377, 1, 0, -50378, 928, 0, 0, 39, '927'),
	(377, 1, 0, -50378, 929, 0, 0, 39, '928'),
	(377, 1, 0, -50378, 930, 0, 0, 39, '929'),
	(377, 1, 0, -50378, 931, 0, 0, 39, '930'),
	(377, 1, 0, -50378, 932, 0, 0, 39, '931'),
	(377, 1, 0, -50378, 933, 0, 0, 39, '932'),
	(377, 1, 0, -50378, 934, 0, 0, 39, '933'),
	(377, 1, 0, -50378, 935, 0, 0, 39, '934'),
	(377, 1, 0, -50378, 936, 0, 0, 39, '935'),
	(377, 1, 0, -50378, 937, 0, 0, 39, '936'),
	(377, 1, 0, -50378, 938, 0, 0, 39, '937'),
	(377, 1, 0, -50378, 939, 0, 0, 39, '938'),
	(377, 1, 0, -50378, 940, 0, 0, 39, '939'),
	(377, 1, 0, -50378, 941, 0, 0, 39, '940'),
	(377, 1, 0, -50378, 942, 0, 0, 39, '941'),
	(377, 1, 0, -50378, 943, 0, 0, 39, '942'),
	(377, 1, 0, -50378, 944, 0, 0, 39, '943'),
	(377, 1, 0, -50378, 945, 0, 0, 39, '944'),
	(377, 1, 0, -50378, 946, 0, 0, 39, '945'),
	(377, 1, 0, -50378, 947, 0, 0, 39, '946'),
	(377, 1, 0, -50378, 948, 0, 0, 39, '947'),
	(377, 1, 0, -50378, 949, 0, 0, 39, '948'),
	(377, 1, 0, -50378, 950, 0, 0, 39, '949'),
	(377, 1, 0, -50378, 951, 0, 0, 39, '950'),
	(377, 1, 0, -50378, 952, 0, 0, 39, '951'),
	(377, 1, 0, -50378, 953, 0, 0, 39, '952'),
	(377, 1, 0, -50378, 954, 0, 0, 39, '953'),
	(377, 1, 0, -50378, 955, 0, 0, 39, '954'),
	(377, 1, 0, -50378, 956, 0, 0, 39, '955'),
	(377, 1, 0, -50378, 957, 0, 0, 39, '956'),
	(377, 1, 0, -50378, 958, 0, 0, 39, '957'),
	(377, 1, 0, -50378, 959, 0, 0, 39, '958'),
	(377, 1, 0, -50378, 960, 0, 0, 39, '959'),
	(377, 1, 0, -50378, 961, 0, 0, 39, '960'),
	(377, 1, 0, -50378, 962, 0, 0, 39, '961'),
	(377, 1, 0, -50378, 963, 0, 0, 39, '962'),
	(377, 1, 0, -50378, 964, 0, 0, 39, '963'),
	(377, 1, 0, -50378, 965, 0, 0, 39, '964'),
	(377, 1, 0, -50378, 966, 0, 0, 39, '965'),
	(377, 1, 0, -50378, 967, 0, 0, 39, '966'),
	(377, 1, 0, -50378, 968, 0, 0, 39, '967'),
	(377, 1, 0, -50378, 969, 0, 0, 39, '968'),
	(377, 1, 0, -50378, 970, 0, 0, 39, '969'),
	(377, 1, 0, -50378, 971, 0, 0, 39, '970'),
	(377, 1, 0, -50378, 972, 0, 0, 39, '971'),
	(377, 1, 0, -50378, 973, 0, 0, 39, '972'),
	(377, 1, 0, -50378, 974, 0, 0, 39, '973'),
	(377, 1, 0, -50378, 975, 0, 0, 39, '974'),
	(377, 1, 0, -50378, 976, 0, 0, 39, '975'),
	(377, 1, 0, -50378, 977, 0, 0, 39, '976'),
	(377, 1, 0, -50378, 978, 0, 0, 39, '977'),
	(377, 1, 0, -50378, 979, 0, 0, 39, '978'),
	(377, 1, 0, -50378, 980, 0, 0, 39, '979'),
	(377, 1, 0, -50378, 981, 0, 0, 39, '980'),
	(377, 1, 0, -50378, 982, 0, 0, 39, '981'),
	(377, 1, 0, -50378, 983, 0, 0, 39, '982'),
	(377, 1, 0, -50378, 984, 0, 0, 39, '983'),
	(377, 1, 0, -50378, 985, 0, 0, 39, '984'),
	(377, 1, 0, -50378, 986, 0, 0, 39, '985'),
	(377, 1, 0, -50378, 987, 0, 0, 39, '986'),
	(377, 1, 0, -50378, 988, 0, 0, 39, '987'),
	(377, 1, 0, -50378, 989, 0, 0, 39, '988'),
	(377, 1, 0, -50378, 990, 0, 0, 39, '989'),
	(377, 1, 0, -50378, 991, 0, 0, 39, '990'),
	(377, 1, 0, -50378, 992, 0, 0, 39, '991'),
	(377, 1, 0, -50378, 993, 0, 0, 39, '992'),
	(377, 1, 0, -50378, 994, 0, 0, 39, '993'),
	(377, 1, 0, -50378, 995, 0, 0, 39, '994'),
	(377, 1, 0, -50378, 996, 0, 0, 39, '995'),
	(377, 1, 0, -50378, 997, 0, 0, 39, '996'),
	(377, 1, 0, -50378, 998, 0, 0, 39, '997'),
	(377, 1, 0, -50378, 999, 0, 0, 39, '998'),
	(377, 1, 0, -50378, 1000, 0, 0, 39, '999'),
	(377, 1, 0, -50378, 1001, 0, 0, 39, '1000'),
	(377, 1, 0, -50378, 1002, 0, 0, 39, '1001'),
	(377, 1, 0, -50378, 1003, 0, 0, 39, '1002'),
	(377, 1, 0, -50378, 1004, 0, 0, 39, '1003'),
	(377, 1, 0, -50378, 1005, 0, 0, 39, '1004'),
	(377, 1, 0, -50378, 1006, 0, 0, 39, '1005'),
	(377, 1, 0, -50378, 1007, 0, 0, 39, '1006'),
	(377, 1, 0, -50378, 1008, 0, 0, 39, '1007'),
	(377, 1, 0, -50378, 1009, 0, 0, 39, '1008'),
	(377, 1, 0, -50378, 1010, 0, 0, 39, '1009'),
	(377, 1, 0, -50378, 1011, 0, 0, 39, '1010'),
	(377, 1, 0, -50378, 1012, 0, 0, 39, '1011'),
	(377, 1, 0, -50378, 1013, 0, 0, 39, '1012'),
	(377, 1, 0, -50378, 1014, 0, 0, 39, '1013'),
	(377, 1, 0, -50378, 1015, 0, 0, 39, '1014'),
	(377, 1, 0, -50378, 1016, 0, 0, 39, '1015'),
	(377, 1, 0, -50378, 1017, 0, 0, 39, '1016'),
	(377, 1, 0, -50378, 1018, 0, 0, 39, '1017'),
	(377, 1, 0, -50378, 1019, 0, 0, 39, '1018'),
	(377, 1, 0, -50378, 1020, 0, 0, 39, '1019'),
	(377, 1, 0, -50378, 1021, 0, 0, 39, '1020'),
	(377, 1, 0, -50378, 1022, 0, 0, 39, '1021'),
	(377, 1, 0, -50378, 1023, 0, 0, 39, '1022'),
	(377, 1, 0, -50378, 1024, 0, 0, 39, '1023'),
	(377, 1, 0, -50378, 1025, 0, 0, 39, '1024'),
	(377, 1, 0, -50378, 1026, 0, 0, 39, '1025'),
	(377, 1, 0, -50378, 1027, 0, 0, 39, '1026'),
	(377, 1, 0, -50378, 1028, 0, 0, 39, '1027'),
	(377, 1, 0, -50378, 1029, 0, 0, 39, '1028'),
	(377, 1, 0, -50378, 1030, 0, 0, 39, '1029'),
	(377, 1, 0, -50378, 1031, 0, 0, 39, '1030'),
	(377, 1, 0, -50378, 1032, 0, 0, 39, '1031'),
	(377, 1, 0, -50378, 1033, 0, 0, 39, '1032'),
	(377, 1, 0, -50378, 1034, 0, 0, 39, '1033'),
	(377, 1, 0, -50378, 1035, 0, 0, 39, '1034'),
	(377, 1, 0, -50378, 1036, 0, 0, 39, '1035'),
	(377, 1, 0, -50378, 1037, 0, 0, 39, '1036'),
	(377, 1, 0, -50378, 1038, 0, 0, 39, '1037'),
	(377, 1, 0, -50378, 1039, 0, 0, 39, '1038'),
	(377, 1, 0, -50378, 1040, 0, 0, 39, '1039'),
	(377, 1, 0, -50378, 1041, 0, 0, 39, '1040'),
	(377, 1, 0, -50378, 1042, 0, 0, 39, '1041'),
	(377, 1, 0, -50378, 1043, 0, 0, 39, '1042'),
	(377, 1, 0, -50378, 1044, 0, 0, 39, '1043'),
	(377, 1, 0, -50378, 1045, 0, 0, 39, '1044'),
	(377, 1, 0, -50378, 1046, 0, 0, 39, '1045'),
	(377, 1, 0, -50378, 1047, 0, 0, 39, '1046'),
	(377, 1, 0, -50378, 1048, 0, 0, 39, '1047'),
	(377, 1, 0, -50378, 1049, 0, 0, 39, '1048'),
	(377, 1, 0, -50378, 1050, 0, 0, 39, '1049'),
	(377, 1, 0, -50378, 1051, 0, 0, 39, '1050'),
	(377, 1, 0, -50378, 1052, 0, 0, 39, '1051'),
	(377, 1, 0, -50378, 1053, 0, 0, 39, '1052'),
	(377, 1, 0, -50378, 1054, 0, 0, 39, '1053'),
	(377, 1, 0, -50378, 1055, 0, 0, 39, '1054'),
	(377, 1, 0, -50378, 1056, 0, 0, 39, '1055'),
	(377, 1, 0, -50378, 1057, 0, 0, 39, '1056'),
	(377, 1, 0, -50378, 1058, 0, 0, 39, '1057'),
	(377, 1, 0, -50378, 1059, 0, 0, 39, '1058'),
	(377, 1, 0, -50378, 1060, 0, 0, 39, '1059'),
	(377, 1, 0, -50378, 1061, 0, 0, 39, '1060'),
	(377, 1, 0, -50378, 1062, 0, 0, 39, '1061'),
	(377, 1, 0, -50378, 1063, 0, 0, 39, '1062'),
	(377, 1, 0, -50378, 1064, 0, 0, 39, '1063'),
	(377, 1, 0, -50378, 1065, 0, 0, 39, '1064'),
	(377, 1, 0, -50378, 1066, 0, 0, 39, '1065'),
	(377, 1, 0, -50378, 1067, 0, 0, 39, '1066'),
	(377, 1, 0, -50378, 1068, 0, 0, 39, '1067'),
	(377, 1, 0, -50378, 1069, 0, 0, 39, '1068'),
	(377, 1, 0, -50378, 1070, 0, 0, 39, '1069'),
	(377, 1, 0, -50378, 1071, 0, 0, 39, '1070'),
	(377, 1, 0, -50378, 1072, 0, 0, 39, '1071'),
	(377, 1, 0, -50378, 1073, 0, 0, 39, '1072'),
	(377, 1, 0, -50378, 1074, 0, 0, 39, '1073'),
	(377, 1, 0, -50378, 1075, 0, 0, 39, '1074'),
	(377, 1, 0, -50378, 1076, 0, 0, 39, '1075'),
	(377, 1, 0, -50378, 1077, 0, 0, 39, '1076'),
	(377, 1, 0, -50378, 1078, 0, 0, 39, '1077'),
	(377, 1, 0, -50378, 1079, 0, 0, 39, '1078'),
	(377, 1, 0, -50378, 1080, 0, 0, 39, '1079'),
	(377, 1, 0, -50378, 1081, 0, 0, 39, '1080'),
	(377, 1, 0, -50378, 1082, 0, 0, 39, '1081'),
	(377, 1, 0, -50378, 1083, 0, 0, 39, '1082'),
	(377, 1, 0, -50378, 1084, 0, 0, 39, '1083'),
	(377, 1, 0, -50378, 1085, 0, 0, 39, '1084'),
	(377, 1, 0, -50378, 1086, 0, 0, 39, '1085'),
	(377, 1, 0, -50378, 1087, 0, 0, 39, '1086'),
	(377, 1, 0, -50378, 1088, 0, 0, 39, '1087'),
	(377, 1, 0, -50378, 1089, 0, 0, 39, '1088'),
	(377, 1, 0, -50378, 1090, 0, 0, 39, '1089'),
	(377, 1, 0, -50378, 1091, 0, 0, 39, '1090'),
	(377, 1, 0, -50378, 1092, 0, 0, 39, '1091'),
	(377, 1, 0, -50378, 1093, 0, 0, 39, '1092'),
	(377, 1, 0, -50378, 1094, 0, 0, 39, '1093'),
	(377, 1, 0, -50378, 1095, 0, 0, 39, '1094'),
	(377, 1, 0, -50378, 1096, 0, 0, 39, '1095'),
	(377, 1, 0, -50378, 1097, 0, 0, 39, '1096'),
	(377, 1, 0, -50378, 1098, 0, 0, 39, '1097'),
	(377, 1, 0, -50378, 1099, 0, 0, 39, '1098'),
	(377, 1, 0, -50378, 1100, 0, 0, 39, '1099'),
	(377, 1, 0, -50378, 1101, 0, 0, 39, '1100'),
	(377, 1, 0, -50378, 1102, 0, 0, 39, '1101'),
	(377, 1, 0, -50378, 1103, 0, 0, 39, '1102'),
	(377, 1, 0, -50378, 1104, 0, 0, 39, '1103'),
	(377, 1, 0, -50378, 1105, 0, 0, 39, '1104'),
	(377, 1, 0, -50378, 1106, 0, 0, 39, '1105'),
	(377, 1, 0, -50378, 1107, 0, 0, 39, '1106'),
	(377, 1, 0, -50378, 1108, 0, 0, 39, '1107'),
	(377, 1, 0, -50378, 1109, 0, 0, 39, '1108'),
	(377, 1, 0, -50378, 1110, 0, 0, 39, '1109'),
	(377, 1, 0, -50378, 1111, 0, 0, 39, '1110'),
	(377, 1, 0, -50378, 1112, 0, 0, 39, '1111'),
	(377, 1, 0, -50378, 1113, 0, 0, 39, '1112'),
	(377, 1, 0, -50378, 1114, 0, 0, 39, '1113'),
	(377, 1, 0, -50378, 1115, 0, 0, 39, '1114'),
	(377, 1, 0, -50378, 1116, 0, 0, 39, '1115'),
	(377, 1, 0, -50378, 1117, 0, 0, 39, '1116'),
	(377, 1, 0, -50378, 1118, 0, 0, 39, '1117'),
	(377, 1, 0, -50378, 1119, 0, 0, 39, '1118'),
	(377, 1, 0, -50378, 1120, 0, 0, 39, '1119'),
	(377, 1, 0, -50378, 1121, 0, 0, 39, '1120'),
	(377, 1, 0, -50378, 1122, 0, 0, 39, '1121'),
	(377, 1, 0, -50378, 1123, 0, 0, 39, '1122'),
	(377, 1, 0, -50378, 1124, 0, 0, 39, '1123'),
	(377, 1, 0, -50378, 1125, 0, 0, 39, '1124'),
	(377, 1, 0, -50378, 1126, 0, 0, 39, '1125'),
	(377, 1, 0, -50378, 1127, 0, 0, 39, '1126'),
	(377, 1, 0, -50378, 1128, 0, 0, 39, '1127'),
	(377, 1, 0, -50378, 1129, 0, 0, 39, '1128'),
	(377, 1, 0, -50378, 1130, 0, 0, 39, '1129'),
	(377, 1, 0, -50378, 1131, 0, 0, 39, '1130'),
	(377, 1, 0, -50378, 1132, 0, 0, 39, '1131'),
	(377, 1, 0, -50378, 1133, 0, 0, 39, '1132'),
	(377, 1, 0, -50378, 1134, 0, 0, 39, '1133'),
	(377, 1, 0, -50378, 1135, 0, 0, 39, '1134'),
	(377, 1, 0, -50378, 1136, 0, 0, 39, '1135'),
	(377, 1, 0, -50378, 1137, 0, 0, 39, '1136'),
	(377, 1, 0, -50378, 1138, 0, 0, 39, '1137'),
	(377, 1, 0, -50378, 1139, 0, 0, 39, '1138'),
	(377, 1, 0, -50378, 1140, 0, 0, 39, '1139'),
	(377, 1, 0, -50378, 1141, 0, 0, 39, '1140'),
	(377, 1, 0, -50378, 1142, 0, 0, 39, '1141'),
	(377, 1, 0, -50378, 1143, 0, 0, 39, '1142'),
	(377, 1, 0, -50378, 1144, 0, 0, 39, '1143'),
	(377, 1, 0, -50378, 1145, 0, 0, 39, '1144'),
	(377, 1, 0, -50378, 1146, 0, 0, 39, '1145'),
	(377, 1, 0, -50378, 1147, 0, 0, 39, '1146'),
	(377, 1, 0, -50378, 1148, 0, 0, 39, '1147'),
	(377, 1, 0, -50378, 1149, 0, 0, 39, '1148'),
	(377, 1, 0, -50378, 1150, 0, 0, 39, '1149'),
	(377, 1, 0, -50378, 1151, 0, 0, 39, '1150'),
	(377, 1, 0, -50378, 1152, 0, 0, 39, '1151'),
	(377, 1, 0, -50378, 1153, 0, 0, 39, '1152'),
	(377, 1, 0, -50378, 1154, 0, 0, 39, '1153'),
	(377, 1, 0, -50378, 1155, 0, 0, 39, '1154'),
	(377, 1, 0, -50378, 1156, 0, 0, 39, '1155'),
	(377, 1, 0, -50378, 1157, 0, 0, 39, '1156'),
	(377, 1, 0, -50378, 1158, 0, 0, 39, '1157'),
	(377, 1, 0, -50378, 1159, 0, 0, 39, '1158'),
	(377, 1, 0, -50378, 1160, 0, 0, 39, '1159'),
	(377, 1, 0, -50378, 1161, 0, 0, 39, '1160'),
	(377, 1, 0, -50378, 1162, 0, 0, 39, '1161'),
	(377, 1, 0, -50378, 1163, 0, 0, 39, '1162'),
	(377, 1, 0, -50378, 1164, 0, 0, 39, '1163'),
	(377, 1, 0, -50378, 1165, 0, 0, 39, '1164'),
	(377, 1, 0, -50378, 1166, 0, 0, 39, '1165'),
	(377, 1, 0, -50378, 1167, 0, 0, 39, '1166'),
	(377, 1, 0, -50378, 1168, 0, 0, 39, '1167'),
	(377, 1, 0, -50378, 1169, 0, 0, 39, '1168'),
	(377, 1, 0, -50378, 1170, 0, 0, 39, '1169'),
	(377, 1, 0, -50378, 1171, 0, 0, 39, '1170'),
	(377, 1, 0, -50378, 1172, 0, 0, 39, '1171'),
	(377, 1, 0, -50378, 1173, 0, 0, 39, '1172'),
	(377, 1, 0, -50378, 1174, 0, 0, 39, '1173'),
	(377, 1, 0, -50378, 1175, 0, 0, 39, '1174'),
	(377, 1, 0, -50378, 1176, 0, 0, 39, '1175'),
	(377, 1, 0, -50378, 1177, 0, 0, 39, '1176'),
	(377, 1, 0, -50378, 1178, 0, 0, 39, '1177'),
	(377, 1, 0, -50378, 1179, 0, 0, 39, '1178'),
	(377, 1, 0, -50378, 1180, 0, 0, 39, '1179'),
	(377, 1, 0, -50378, 1181, 0, 0, 39, '1180'),
	(377, 1, 0, -50378, 1182, 0, 0, 39, '1181'),
	(377, 1, 0, -50378, 1183, 0, 0, 39, '1182'),
	(377, 1, 0, -50378, 1184, 0, 0, 39, '1183'),
	(377, 1, 0, -50378, 1185, 0, 0, 39, '1184'),
	(377, 1, 0, -50378, 1186, 0, 0, 39, '1185'),
	(377, 1, 0, -50378, 1187, 0, 0, 39, '1186'),
	(377, 1, 0, -50378, 1188, 0, 0, 39, '1187'),
	(377, 1, 0, -50378, 1189, 0, 0, 39, '1188'),
	(377, 1, 0, -50378, 1190, 0, 0, 39, '1189'),
	(377, 1, 0, -50378, 1191, 0, 0, 39, '1190'),
	(377, 1, 0, -50378, 1192, 0, 0, 39, '1191'),
	(377, 1, 0, -50378, 1193, 0, 0, 39, '1192'),
	(377, 1, 0, -50378, 1194, 0, 0, 39, '1193'),
	(377, 1, 0, -50378, 1195, 0, 0, 39, '1194'),
	(377, 1, 0, -50378, 1196, 0, 0, 39, '1195'),
	(377, 1, 0, -50378, 1197, 0, 0, 39, '1196'),
	(377, 1, 0, -50378, 1198, 0, 0, 39, '1197'),
	(377, 1, 0, -50378, 1199, 0, 0, 39, '1198'),
	(377, 1, 0, -50378, 1200, 0, 0, 39, '1199'),
	(377, 1, 0, -50378, 1201, 0, 0, 39, '1200'),
	(377, 1, 0, -50378, 1202, 0, 0, 39, '1201'),
	(377, 1, 0, -50378, 1203, 0, 0, 39, '1202'),
	(377, 1, 0, -50378, 1204, 0, 0, 39, '1203'),
	(377, 1, 0, -50378, 1205, 0, 0, 39, '1204'),
	(377, 1, 0, -50378, 1206, 0, 0, 39, '1205'),
	(377, 1, 0, -50378, 1207, 0, 0, 39, '1206'),
	(377, 1, 0, -50378, 1208, 0, 0, 39, '1207'),
	(377, 1, 0, -50378, 1209, 0, 0, 39, '1208'),
	(377, 1, 0, -50378, 1210, 0, 0, 39, '1209'),
	(377, 1, 0, -50378, 1211, 0, 0, 39, '1210'),
	(377, 1, 0, -50378, 1212, 0, 0, 39, '1211'),
	(377, 1, 0, -50378, 1213, 0, 0, 39, '1212'),
	(377, 1, 0, -50378, 1214, 0, 0, 39, '1213'),
	(377, 1, 0, -50378, 1215, 0, 0, 39, '1214'),
	(377, 1, 0, -50378, 1216, 0, 0, 39, '1215'),
	(377, 1, 0, -50378, 1217, 0, 0, 39, '1216'),
	(377, 1, 0, -50378, 1218, 0, 0, 39, '1217'),
	(377, 1, 0, -50378, 1219, 0, 0, 39, '1218'),
	(377, 1, 0, -50378, 1220, 0, 0, 39, '1219'),
	(377, 1, 0, -50378, 1221, 0, 0, 39, '1220'),
	(377, 1, 0, -50378, 1222, 0, 0, 39, '1221'),
	(377, 1, 0, -50378, 1223, 0, 0, 39, '1222'),
	(377, 1, 0, -50378, 1224, 0, 0, 39, '1223'),
	(377, 1, 0, -50378, 1225, 0, 0, 39, '1224'),
	(377, 1, 0, -50378, 1226, 0, 0, 39, '1225'),
	(377, 1, 0, -50378, 1227, 0, 0, 39, '1226'),
	(377, 1, 0, -50378, 1228, 0, 0, 39, '1227'),
	(377, 1, 0, -50378, 1229, 0, 0, 39, '1228'),
	(377, 1, 0, -50378, 1230, 0, 0, 39, '1229'),
	(377, 1, 0, -50378, 1231, 0, 0, 39, '1230'),
	(377, 1, 0, -50378, 1232, 0, 0, 39, '1231'),
	(377, 1, 0, -50378, 1233, 0, 0, 39, '1232'),
	(377, 1, 0, -50378, 1234, 0, 0, 39, '1233'),
	(377, 1, 0, -50378, 1235, 0, 0, 39, '1234'),
	(377, 1, 0, -50378, 1236, 0, 0, 39, '1235'),
	(377, 1, 0, -50378, 1237, 0, 0, 39, '1236'),
	(377, 1, 0, -50378, 1238, 0, 0, 39, '1237'),
	(377, 1, 0, -50378, 1239, 0, 0, 39, '1238'),
	(377, 1, 0, -50378, 1240, 0, 0, 39, '1239'),
	(377, 1, 0, -50378, 1241, 0, 0, 39, '1240'),
	(377, 1, 0, -50378, 1242, 0, 0, 39, '1241'),
	(377, 1, 0, -50378, 1243, 0, 0, 39, '1242'),
	(377, 1, 0, -50378, 1244, 0, 0, 39, '1243'),
	(377, 1, 0, -50378, 1245, 0, 0, 39, '1244'),
	(377, 1, 0, -50378, 1246, 0, 0, 39, '1245'),
	(377, 1, 0, -50378, 1247, 0, 0, 39, '1246'),
	(377, 1, 0, -50378, 1248, 0, 0, 39, '1247'),
	(377, 1, 0, -50378, 1249, 0, 0, 39, '1248'),
	(377, 1, 0, -50378, 1250, 0, 0, 39, '1249'),
	(377, 1, 0, -50378, 1251, 0, 0, 39, '1250'),
	(377, 1, 0, -50378, 1252, 0, 0, 39, '1251'),
	(377, 1, 0, -50378, 1253, 0, 0, 39, '1252'),
	(377, 1, 0, -50378, 1254, 0, 0, 39, '1253'),
	(377, 1, 0, -50378, 1255, 0, 0, 39, '1254'),
	(377, 1, 0, -50378, 1256, 0, 0, 39, '1255'),
	(377, 1, 0, -50378, 1257, 0, 0, 39, '1256'),
	(377, 1, 0, -50378, 1258, 0, 0, 39, '1257'),
	(377, 1, 0, -50378, 1259, 0, 0, 39, '1258'),
	(377, 1, 0, -50378, 1260, 0, 0, 39, '1259'),
	(377, 1, 0, -50378, 1261, 0, 0, 39, '1260'),
	(377, 1, 0, -50378, 1262, 0, 0, 39, '1261'),
	(377, 1, 0, -50378, 1263, 0, 0, 39, '1262'),
	(377, 1, 0, -50378, 1264, 0, 0, 39, '1263'),
	(377, 1, 0, -50378, 1265, 0, 0, 39, '1264'),
	(377, 1, 0, -50378, 1266, 0, 0, 39, '1265'),
	(377, 1, 0, -50378, 1267, 0, 0, 39, '1266'),
	(377, 1, 0, -50378, 1268, 0, 0, 39, '1267'),
	(377, 1, 0, -50378, 1269, 0, 0, 39, '1268'),
	(377, 1, 0, -50378, 1270, 0, 0, 39, '1269'),
	(377, 1, 0, -50378, 1271, 0, 0, 39, '1270'),
	(377, 1, 0, -50378, 1272, 0, 0, 39, '1271'),
	(377, 1, 0, -50378, 1273, 0, 0, 39, '1272'),
	(377, 1, 0, -50378, 1274, 0, 0, 39, '1273'),
	(377, 1, 0, -50378, 1275, 0, 0, 39, '1274'),
	(377, 1, 0, -50378, 1276, 0, 0, 39, '1275'),
	(377, 1, 0, -50378, 1277, 0, 0, 39, '1276'),
	(377, 1, 0, -50378, 1278, 0, 0, 39, '1277'),
	(377, 1, 0, -50378, 1279, 0, 0, 39, '1278'),
	(377, 1, 0, -50378, 1280, 0, 0, 39, '1279'),
	(377, 1, 0, -50378, 1281, 0, 0, 39, '1280'),
	(377, 1, 0, -50378, 1282, 0, 0, 39, '1281'),
	(377, 1, 0, -50378, 1283, 0, 0, 39, '1282'),
	(377, 1, 0, -50378, 1284, 0, 0, 39, '1283'),
	(377, 1, 0, -50378, 1285, 0, 0, 39, '1284'),
	(377, 1, 0, -50378, 1286, 0, 0, 39, '1285'),
	(377, 1, 0, -50378, 1287, 0, 0, 39, '1286'),
	(377, 1, 0, -50378, 1288, 0, 0, 39, '1287'),
	(377, 1, 0, -50378, 1289, 0, 0, 39, '1288'),
	(377, 1, 0, -50378, 1290, 0, 0, 39, '1289'),
	(377, 1, 0, -50378, 1291, 0, 0, 39, '1290'),
	(377, 1, 0, -50378, 1292, 0, 0, 39, '1291'),
	(377, 1, 0, -50378, 1293, 0, 0, 39, '1292'),
	(377, 1, 0, -50378, 1294, 0, 0, 39, '1293'),
	(377, 1, 0, -50378, 1295, 0, 0, 39, '1294'),
	(377, 1, 0, -50378, 1296, 0, 0, 39, '1295'),
	(377, 1, 0, -50378, 1297, 0, 0, 39, '1296'),
	(377, 1, 0, -50378, 1298, 0, 0, 39, '1297'),
	(377, 1, 0, -50378, 1299, 0, 0, 39, '1298'),
	(377, 1, 0, -50378, 1300, 0, 0, 39, '1299'),
	(377, 1, 0, -50378, 1301, 0, 0, 39, '1300'),
	(377, 1, 0, -50378, 1302, 0, 0, 39, '1301'),
	(377, 1, 0, -50378, 1303, 0, 0, 39, '1302'),
	(377, 1, 0, -50378, 1304, 0, 0, 39, '1303'),
	(377, 1, 0, -50378, 1305, 0, 0, 39, '1304'),
	(377, 1, 0, -50378, 1306, 0, 0, 39, '1305'),
	(377, 1, 0, -50378, 1307, 0, 0, 39, '1306'),
	(377, 1, 0, -50378, 1308, 0, 0, 39, '1307'),
	(377, 1, 0, -50378, 1309, 0, 0, 39, '1308'),
	(377, 1, 0, -50378, 1310, 0, 0, 39, '1309'),
	(377, 1, 0, -50378, 1311, 0, 0, 39, '1310'),
	(377, 1, 0, -50378, 1312, 0, 0, 39, '1311'),
	(377, 1, 0, -50378, 1313, 0, 0, 39, '1312'),
	(377, 1, 0, -50378, 1314, 0, 0, 39, '1313'),
	(377, 1, 0, -50378, 1315, 0, 0, 39, '1314'),
	(377, 1, 0, -50378, 1316, 0, 0, 39, '1315'),
	(377, 1, 0, -50378, 1317, 0, 0, 39, '1316'),
	(377, 1, 0, -50378, 1318, 0, 0, 39, '1317'),
	(377, 1, 0, -50378, 1319, 0, 0, 39, '1318'),
	(377, 1, 0, -50378, 1320, 0, 0, 39, '1319'),
	(377, 1, 0, -50378, 1321, 0, 0, 39, '1320'),
	(377, 1, 0, -50378, 1322, 0, 0, 39, '1321'),
	(377, 1, 0, -50378, 1323, 0, 0, 39, '1322'),
	(377, 1, 0, -50378, 1324, 0, 0, 39, '1323'),
	(377, 1, 0, -50378, 1325, 0, 0, 39, '1324'),
	(377, 1, 0, -50378, 1326, 0, 0, 39, '1325'),
	(377, 1, 0, -50378, 1327, 0, 0, 39, '1326'),
	(377, 1, 0, -50378, 1328, 0, 0, 39, '1327'),
	(377, 1, 0, -50378, 1329, 0, 0, 39, '1328'),
	(377, 1, 0, -50378, 1330, 0, 0, 39, '1329'),
	(377, 1, 0, -50378, 1331, 0, 0, 39, '1330'),
	(377, 1, 0, -50378, 1332, 0, 0, 39, '1331'),
	(377, 1, 0, -50378, 1333, 0, 0, 39, '1332'),
	(377, 1, 0, -50378, 1334, 0, 0, 39, '1333'),
	(377, 1, 0, -50378, 1335, 0, 0, 39, '1334'),
	(377, 1, 0, -50378, 1336, 0, 0, 39, '1335'),
	(377, 1, 0, -50378, 1337, 0, 0, 39, '1336'),
	(377, 1, 0, -50378, 1338, 0, 0, 39, '1337'),
	(377, 1, 0, -50378, 1339, 0, 0, 39, '1338'),
	(377, 1, 0, -50378, 1340, 0, 0, 39, '1339'),
	(377, 1, 0, -50378, 1341, 0, 0, 39, '1340'),
	(377, 1, 0, -50378, 1342, 0, 0, 39, '1341'),
	(377, 1, 0, -50378, 1343, 0, 0, 39, '1342'),
	(377, 1, 0, -50378, 1344, 0, 0, 39, '1343'),
	(377, 1, 0, -50378, 1345, 0, 0, 39, '1344'),
	(377, 1, 0, -50378, 1346, 0, 0, 39, '1345'),
	(377, 1, 0, -50378, 1347, 0, 0, 39, '1346'),
	(377, 1, 0, -50378, 1348, 0, 0, 39, '1347'),
	(377, 1, 0, -50378, 1349, 0, 0, 39, '1348'),
	(377, 1, 0, -50378, 1350, 0, 0, 39, '1349'),
	(377, 1, 0, -50378, 1351, 0, 0, 39, '1350'),
	(377, 1, 0, -50378, 1352, 0, 0, 39, '1351'),
	(377, 1, 0, -50378, 1353, 0, 0, 39, '1352'),
	(377, 1, 0, -50378, 1354, 0, 0, 39, '1353'),
	(377, 1, 0, -50378, 1355, 0, 0, 39, '1354'),
	(377, 1, 0, -50378, 1356, 0, 0, 39, '1355'),
	(377, 1, 0, -50378, 1357, 0, 0, 39, '1356'),
	(377, 1, 0, -50378, 1358, 0, 0, 39, '1357'),
	(377, 1, 0, -50378, 1359, 0, 0, 39, '1358'),
	(377, 1, 0, -50378, 1360, 0, 0, 39, '1359'),
	(377, 1, 0, -50378, 1361, 0, 0, 39, '1360'),
	(377, 1, 0, -50378, 1362, 0, 0, 39, '1361'),
	(377, 1, 0, -50378, 1363, 0, 0, 39, '1362'),
	(377, 1, 0, -50378, 1364, 0, 0, 39, '1363'),
	(377, 1, 0, -50378, 1365, 0, 0, 39, '1364'),
	(377, 1, 0, -50378, 1366, 0, 0, 39, '1365'),
	(377, 1, 0, -50378, 1367, 0, 0, 39, '1366'),
	(377, 1, 0, -50378, 1368, 0, 0, 39, '1367'),
	(377, 1, 0, -50378, 1369, 0, 0, 39, '1368'),
	(377, 1, 0, -50378, 1370, 0, 0, 39, '1369'),
	(377, 1, 0, -50378, 1371, 0, 0, 39, '1370'),
	(377, 1, 0, -50378, 1372, 0, 0, 39, '1371'),
	(377, 1, 0, -50378, 1373, 0, 0, 39, '1372'),
	(377, 1, 0, -50378, 1374, 0, 0, 39, '1373'),
	(377, 1, 0, -50378, 1375, 0, 0, 39, '1374'),
	(377, 1, 0, -50378, 1376, 0, 0, 39, '1375'),
	(377, 1, 0, -50378, 1377, 0, 0, 39, '1376'),
	(377, 1, 0, -50378, 1378, 0, 0, 39, '1377'),
	(377, 1, 0, -50378, 1379, 0, 0, 39, '1378'),
	(377, 1, 0, -50378, 1380, 0, 0, 39, '1379'),
	(377, 1, 0, -50378, 1381, 0, 0, 39, '1380'),
	(377, 1, 0, -50378, 1382, 0, 0, 39, '1381'),
	(377, 1, 0, -50378, 1383, 0, 0, 39, '1382'),
	(377, 1, 0, -50378, 1384, 0, 0, 39, '1383'),
	(377, 1, 0, -50378, 1385, 0, 0, 39, '1384'),
	(377, 1, 0, -50378, 1386, 0, 0, 39, '1385'),
	(377, 1, 0, -50378, 1387, 0, 0, 39, '1386'),
	(377, 1, 0, -50378, 1388, 0, 0, 39, '1387'),
	(377, 1, 0, -50378, 1389, 0, 0, 39, '1388'),
	(377, 1, 0, -50378, 1390, 0, 0, 39, '1389'),
	(377, 1, 0, -50378, 1391, 0, 0, 39, '1390'),
	(377, 1, 0, -50378, 1392, 0, 0, 39, '1391'),
	(377, 1, 0, -50378, 1393, 0, 0, 39, '1392'),
	(377, 1, 0, -50378, 1394, 0, 0, 39, '1393'),
	(377, 1, 0, -50378, 1395, 0, 0, 39, '1394'),
	(377, 1, 0, -50378, 1396, 0, 0, 39, '1395'),
	(377, 1, 0, -50378, 1397, 0, 0, 39, '1396'),
	(377, 1, 0, -50378, 1398, 0, 0, 39, '1397'),
	(377, 1, 0, -50378, 1399, 0, 0, 39, '1398'),
	(377, 1, 0, -50378, 1400, 0, 0, 39, '1399'),
	(377, 1, 0, -50378, 1401, 0, 0, 39, '1400'),
	(377, 1, 0, -50378, 1402, 0, 0, 39, '1401'),
	(377, 1, 0, -50378, 1403, 0, 0, 39, '1402'),
	(377, 1, 0, -50378, 1404, 0, 0, 39, '1403'),
	(377, 1, 0, -50378, 1405, 0, 0, 39, '1404'),
	(377, 1, 0, -50378, 1406, 0, 0, 39, '1405'),
	(377, 1, 0, -50378, 1407, 0, 0, 39, '1406'),
	(377, 1, 0, -50378, 1408, 0, 0, 39, '1407'),
	(377, 1, 0, -50378, 1409, 0, 0, 39, '1408'),
	(377, 1, 0, -50378, 1410, 0, 0, 39, '1409'),
	(377, 1, 0, -50378, 1411, 0, 0, 39, '1410'),
	(377, 1, 0, -50378, 1412, 0, 0, 39, '1411'),
	(377, 1, 0, -50378, 1413, 0, 0, 39, '1412'),
	(377, 1, 0, -50378, 1414, 0, 0, 39, '1413'),
	(377, 1, 0, -50378, 1415, 0, 0, 39, '1414'),
	(377, 1, 0, -50378, 1416, 0, 0, 39, '1415'),
	(377, 1, 0, -50378, 1417, 0, 0, 39, '1416'),
	(377, 1, 0, -50378, 1418, 0, 0, 39, '1417'),
	(377, 1, 0, -50378, 1419, 0, 0, 39, '1418'),
	(377, 1, 0, -50378, 1420, 0, 0, 39, '1419'),
	(377, 1, 0, -50378, 1421, 0, 0, 39, '1420'),
	(377, 1, 0, -50378, 1422, 0, 0, 39, '1421'),
	(377, 1, 0, -50378, 1423, 0, 0, 39, '1422'),
	(377, 1, 0, -50378, 1424, 0, 0, 39, '1423'),
	(377, 1, 0, -50378, 1425, 0, 0, 39, '1424'),
	(377, 1, 0, -50378, 1426, 0, 0, 39, '1425'),
	(377, 1, 0, -50378, 1427, 0, 0, 39, '1426'),
	(377, 1, 0, -50378, 1428, 0, 0, 39, '1427'),
	(377, 1, 0, -50378, 1429, 0, 0, 39, '1428'),
	(377, 1, 0, -50378, 1430, 0, 0, 39, '1429'),
	(377, 1, 0, -50378, 1431, 0, 0, 39, '1430'),
	(377, 1, 0, -50378, 1432, 0, 0, 39, '1431'),
	(377, 1, 0, -50378, 1433, 0, 0, 39, '1432'),
	(377, 1, 0, -50378, 1434, 0, 0, 39, '1433'),
	(377, 1, 0, -50378, 1435, 0, 0, 39, '1434'),
	(377, 1, 0, -50378, 1436, 0, 0, 39, '1435'),
	(377, 1, 0, -50378, 1437, 0, 0, 39, '1436'),
	(377, 1, 0, -50378, 1438, 0, 0, 39, '1437'),
	(377, 1, 0, -50378, 1439, 0, 0, 39, '1438'),
	(377, 1, 0, -50378, 1440, 0, 0, 39, '1439'),
	(377, 1, 0, -50378, 1441, 0, 0, 39, '1440'),
	(377, 1, 0, -50378, 1442, 0, 0, 39, '1441'),
	(377, 1, 0, -50378, 1443, 0, 0, 39, '1442'),
	(377, 1, 0, -50378, 1444, 0, 0, 39, '1443'),
	(377, 1, 0, -50378, 1445, 0, 0, 39, '1444'),
	(377, 1, 0, -50378, 1446, 0, 0, 39, '1445'),
	(377, 1, 0, -50378, 1447, 0, 0, 39, '1446'),
	(377, 1, 0, -50378, 1448, 0, 0, 39, '1447'),
	(377, 1, 0, -50378, 1449, 0, 0, 39, '1448'),
	(377, 1, 0, -50378, 1450, 0, 0, 39, '1449'),
	(377, 1, 0, -50378, 1451, 0, 0, 39, '1450'),
	(377, 1, 0, -50378, 1452, 0, 0, 39, '1451'),
	(377, 1, 0, -50378, 1453, 0, 0, 39, '1452'),
	(377, 1, 0, -50378, 1454, 0, 0, 39, '1453'),
	(377, 1, 0, -50378, 1455, 0, 0, 39, '1454'),
	(377, 1, 0, -50378, 1456, 0, 0, 39, '1455'),
	(377, 1, 0, -50378, 1457, 0, 0, 39, '1456'),
	(377, 1, 0, -50378, 1458, 0, 0, 39, '1457'),
	(377, 1, 0, -50378, 1459, 0, 0, 39, '1458'),
	(377, 1, 0, -50378, 1460, 0, 0, 39, '1459'),
	(377, 1, 0, -50378, 1461, 0, 0, 39, '1460'),
	(377, 1, 0, -50378, 1462, 0, 0, 39, '1461'),
	(377, 1, 0, -50378, 1463, 0, 0, 39, '1462'),
	(377, 1, 0, -50378, 1464, 0, 0, 39, '1463'),
	(377, 1, 0, -50378, 1465, 0, 0, 39, '1464'),
	(377, 1, 0, -50378, 1466, 0, 0, 39, '1465'),
	(377, 1, 0, -50378, 1467, 0, 0, 39, '1466'),
	(377, 1, 0, -50378, 1468, 0, 0, 39, '1467'),
	(377, 1, 0, -50378, 1469, 0, 0, 39, '1468'),
	(377, 1, 0, -50378, 1470, 0, 0, 39, '1469'),
	(377, 1, 0, -50378, 1471, 0, 0, 39, '1470'),
	(377, 1, 0, -50378, 1472, 0, 0, 39, '1471'),
	(377, 1, 0, -50378, 1473, 0, 0, 39, '1472'),
	(377, 1, 0, -50378, 1474, 0, 0, 39, '1473'),
	(377, 1, 0, -50378, 1475, 0, 0, 39, '1474'),
	(377, 1, 0, -50378, 1476, 0, 0, 39, '1475'),
	(377, 1, 0, -50378, 1477, 0, 0, 39, '1476'),
	(377, 1, 0, -50378, 1478, 0, 0, 39, '1477'),
	(377, 1, 0, -50378, 1479, 0, 0, 39, '1478'),
	(377, 1, 0, -50378, 1480, 0, 0, 39, '1479'),
	(377, 1, 0, -50378, 1481, 0, 0, 39, '1480'),
	(377, 1, 0, -50378, 1482, 0, 0, 39, '1481'),
	(377, 1, 0, -50378, 1483, 0, 0, 39, '1482'),
	(377, 1, 0, -50378, 1484, 0, 0, 39, '1483'),
	(377, 1, 0, -50378, 1485, 0, 0, 39, '1484'),
	(377, 1, 0, -50378, 1486, 0, 0, 39, '1485'),
	(377, 1, 0, -50378, 1487, 0, 0, 39, '1486'),
	(377, 1, 0, -50378, 1488, 0, 0, 39, '1487'),
	(377, 1, 0, -50378, 1489, 0, 0, 39, '1488'),
	(377, 1, 0, -50378, 1490, 0, 0, 39, '1489'),
	(377, 1, 0, -50378, 1491, 0, 0, 39, '1490'),
	(377, 1, 0, -50378, 1492, 0, 0, 39, '1491'),
	(377, 1, 0, -50378, 1493, 0, 0, 39, '1492'),
	(377, 1, 0, -50378, 1494, 0, 0, 39, '1493'),
	(377, 1, 0, -50378, 1495, 0, 0, 39, '1494'),
	(377, 1, 0, -50378, 1496, 0, 0, 39, '1495'),
	(377, 1, 0, -50378, 1497, 0, 0, 39, '1496'),
	(377, 1, 0, -50378, 1498, 0, 0, 39, '1497'),
	(377, 1, 0, -50378, 1499, 0, 0, 39, '1498'),
	(377, 1, 0, -50378, 1500, 0, 0, 39, '1499'),
	(377, 1, 0, -50378, 1501, 0, 0, 39, '1500'),
	(377, 1, 0, -50378, 1502, 0, 0, 39, '1501'),
	(377, 1, 0, -50378, 1503, 0, 0, 39, '1502'),
	(377, 1, 0, -50378, 1504, 0, 0, 39, '1503'),
	(377, 1, 0, -50378, 1505, 0, 0, 39, '1504'),
	(377, 1, 0, -50378, 1506, 0, 0, 39, '1505'),
	(377, 1, 0, -50378, 1507, 0, 0, 39, '1506'),
	(377, 1, 0, -50378, 1508, 0, 0, 39, '1507'),
	(377, 1, 0, -50378, 1509, 0, 0, 39, '1508'),
	(377, 1, 0, -50378, 1510, 0, 0, 39, '1509'),
	(377, 1, 0, -50378, 1511, 0, 0, 39, '1510'),
	(377, 1, 0, -50378, 1512, 0, 0, 39, '1511'),
	(377, 1, 0, -50378, 1513, 0, 0, 39, '1512'),
	(377, 1, 0, -50378, 1514, 0, 0, 39, '1513'),
	(377, 1, 0, -50378, 1515, 0, 0, 39, '1514'),
	(377, 1, 0, -50378, 1516, 0, 0, 39, '1515'),
	(377, 1, 0, -50378, 1517, 0, 0, 39, '1516'),
	(377, 1, 0, -50378, 1518, 0, 0, 39, '1517'),
	(377, 1, 0, -50378, 1519, 0, 0, 39, '1518'),
	(377, 1, 0, -50378, 1520, 0, 0, 39, '1519'),
	(377, 1, 0, -50378, 1521, 0, 0, 39, '1520'),
	(377, 1, 0, -50378, 1522, 0, 0, 39, '1521'),
	(377, 1, 0, -50378, 1523, 0, 0, 39, '1522'),
	(377, 1, 0, -50378, 1524, 0, 0, 39, '1523'),
	(377, 1, 0, -50378, 1525, 0, 0, 39, '1524'),
	(377, 1, 0, -50378, 1526, 0, 0, 39, '1525'),
	(377, 1, 0, -50378, 1527, 0, 0, 39, '1526'),
	(377, 1, 0, -50378, 1528, 0, 0, 39, '1527'),
	(377, 1, 0, -50378, 1529, 0, 0, 39, '1528'),
	(377, 1, 0, -50378, 1530, 0, 0, 39, '1529'),
	(377, 1, 0, -50378, 1531, 0, 0, 39, '1530'),
	(377, 1, 0, -50378, 1532, 0, 0, 39, '1531'),
	(377, 1, 0, -50378, 1533, 0, 0, 39, '1532'),
	(377, 1, 0, -50378, 1534, 0, 0, 39, '1533'),
	(377, 1, 0, -50378, 1535, 0, 0, 39, '1534'),
	(377, 1, 0, -50378, 1536, 0, 0, 39, '1535'),
	(377, 1, 0, -50378, 1537, 0, 0, 39, '1536'),
	(377, 1, 0, -50378, 1538, 0, 0, 39, '1537'),
	(377, 1, 0, -50378, 1539, 0, 0, 39, '1538'),
	(377, 1, 0, -50378, 1540, 0, 0, 39, '1539'),
	(377, 1, 0, -50378, 1541, 0, 0, 39, '1540'),
	(377, 1, 0, -50378, 1542, 0, 0, 39, '1541'),
	(377, 1, 0, -50378, 1543, 0, 0, 39, '1542'),
	(377, 1, 0, -50378, 1544, 0, 0, 39, '1543'),
	(377, 1, 0, -50378, 1545, 0, 0, 39, '1544'),
	(377, 1, 0, -50378, 1546, 0, 0, 39, '1545'),
	(377, 1, 0, -50378, 1547, 0, 0, 39, '1546'),
	(377, 1, 0, -50378, 1548, 0, 0, 39, '1547'),
	(377, 1, 0, -50378, 1549, 0, 0, 39, '1548'),
	(377, 1, 0, -50378, 1550, 0, 0, 39, '1549'),
	(377, 1, 0, -50378, 1551, 0, 0, 39, '1550'),
	(377, 1, 0, -50378, 1552, 0, 0, 39, '1551'),
	(377, 1, 0, -50378, 1553, 0, 0, 39, '1552'),
	(377, 1, 0, -50378, 1554, 0, 0, 39, '1553'),
	(377, 1, 0, -50378, 1555, 0, 0, 39, '1554'),
	(377, 1, 0, -50378, 1556, 0, 0, 39, '1555'),
	(377, 1, 0, -50378, 1557, 0, 0, 39, '1556'),
	(377, 1, 0, -50378, 1558, 0, 0, 39, '1557'),
	(377, 1, 0, -50378, 1559, 0, 0, 39, '1558'),
	(377, 1, 0, -50378, 1560, 0, 0, 39, '1559'),
	(377, 1, 0, -50378, 1561, 0, 0, 39, '1560'),
	(377, 1, 0, -50378, 1562, 0, 0, 39, '1561'),
	(377, 1, 0, -50378, 1563, 0, 0, 39, '1562'),
	(377, 1, 0, -50378, 1564, 0, 0, 39, '1563'),
	(377, 1, 0, -50378, 1565, 0, 0, 39, '1564'),
	(377, 1, 0, -50378, 1566, 0, 0, 39, '1565'),
	(377, 1, 0, -50378, 1567, 0, 0, 39, '1566'),
	(377, 1, 0, -50378, 1568, 0, 0, 39, '1567'),
	(377, 1, 0, -50378, 1569, 0, 0, 39, '1568'),
	(377, 1, 0, -50378, 1570, 0, 0, 39, '1569'),
	(377, 1, 0, -50378, 1571, 0, 0, 39, '1570'),
	(377, 1, 0, -50378, 1572, 0, 0, 39, '1571'),
	(377, 1, 0, -50378, 1573, 0, 0, 39, '1572'),
	(377, 1, 0, -50378, 1574, 0, 0, 39, '1573'),
	(377, 1, 0, -50378, 1575, 0, 0, 39, '1574'),
	(377, 1, 0, -50378, 1576, 0, 0, 39, '1575'),
	(377, 1, 0, -50378, 1577, 0, 0, 39, '1576'),
	(377, 1, 0, -50378, 1578, 0, 0, 39, '1577'),
	(377, 1, 0, -50378, 1579, 0, 0, 39, '1578'),
	(377, 1, 0, -50378, 1580, 0, 0, 39, '1579'),
	(377, 1, 0, -50378, 1581, 0, 0, 39, '1580'),
	(377, 1, 0, -50378, 1582, 0, 0, 39, '1581'),
	(377, 1, 0, -50378, 1583, 0, 0, 39, '1582'),
	(377, 1, 0, -50378, 1584, 0, 0, 39, '1583'),
	(377, 1, 0, -50378, 1585, 0, 0, 39, '1584'),
	(377, 1, 0, -50378, 1586, 0, 0, 39, '1585'),
	(377, 1, 0, -50378, 1587, 0, 0, 39, '1586'),
	(377, 1, 0, -50378, 1588, 0, 0, 39, '1587'),
	(377, 1, 0, -50378, 1589, 0, 0, 39, '1588'),
	(377, 1, 0, -50378, 1590, 0, 0, 39, '1589'),
	(377, 1, 0, -50378, 1591, 0, 0, 39, '1590'),
	(377, 1, 0, -50378, 1592, 0, 0, 39, '1591'),
	(377, 1, 0, -50378, 1593, 0, 0, 39, '1592'),
	(377, 1, 0, -50378, 1594, 0, 0, 39, '1593'),
	(377, 1, 0, -50378, 1595, 0, 0, 39, '1594'),
	(377, 1, 0, -50378, 1596, 0, 0, 39, '1595'),
	(377, 1, 0, -50378, 1597, 0, 0, 39, '1596'),
	(377, 1, 0, -50378, 1598, 0, 0, 39, '1597'),
	(377, 1, 0, -50378, 1599, 0, 0, 39, '1598'),
	(377, 1, 0, -50378, 1600, 0, 0, 39, '1599'),
	(377, 1, 0, -50378, 1601, 0, 0, 39, '1600'),
	(377, 1, 0, -50378, 1602, 0, 0, 39, '1601'),
	(377, 1, 0, -50378, 1603, 0, 0, 39, '1602'),
	(377, 1, 0, -50378, 1604, 0, 0, 39, '1603'),
	(377, 1, 0, -50378, 1605, 0, 0, 39, '1604'),
	(377, 1, 0, -50378, 1606, 0, 0, 39, '1605'),
	(377, 1, 0, -50378, 1607, 0, 0, 39, '1606'),
	(377, 1, 0, -50378, 1608, 0, 0, 39, '1607'),
	(377, 1, 0, -50378, 1609, 0, 0, 39, '1608'),
	(377, 1, 0, -50378, 1610, 0, 0, 39, '1609'),
	(377, 1, 0, -50378, 1611, 0, 0, 39, '1610'),
	(377, 1, 0, -50378, 1612, 0, 0, 39, '1611'),
	(377, 1, 0, -50378, 1613, 0, 0, 39, '1612'),
	(377, 1, 0, -50378, 1614, 0, 0, 39, '1613'),
	(377, 1, 0, -50378, 1615, 0, 0, 39, '1614'),
	(377, 1, 0, -50378, 1616, 0, 0, 39, '1615'),
	(377, 1, 0, -50378, 1617, 0, 0, 39, '1616'),
	(377, 1, 0, -50378, 1618, 0, 0, 39, '1617'),
	(377, 1, 0, -50378, 1619, 0, 0, 39, '1618'),
	(377, 1, 0, -50378, 1620, 0, 0, 39, '1619'),
	(377, 1, 0, -50378, 1621, 0, 0, 39, '1620'),
	(377, 1, 0, -50378, 1622, 0, 0, 39, '1621'),
	(377, 1, 0, -50378, 1623, 0, 0, 39, '1622'),
	(377, 1, 0, -50378, 1624, 0, 0, 39, '1623'),
	(377, 1, 0, -50378, 1625, 0, 0, 39, '1624'),
	(377, 1, 0, -50378, 1626, 0, 0, 39, '1625'),
	(377, 1, 0, -50378, 1627, 0, 0, 39, '1626'),
	(377, 1, 0, -50378, 1628, 0, 0, 39, '1627'),
	(377, 1, 0, -50378, 1629, 0, 0, 39, '1628'),
	(377, 1, 0, -50378, 1630, 0, 0, 39, '1629'),
	(377, 1, 0, -50378, 1631, 0, 0, 39, '1630'),
	(377, 1, 0, -50378, 1632, 0, 0, 39, '1631'),
	(377, 1, 0, -50378, 1633, 0, 0, 39, '1632'),
	(377, 1, 0, -50378, 1634, 0, 0, 39, '1633'),
	(377, 1, 0, -50378, 1635, 0, 0, 39, '1634'),
	(377, 1, 0, -50378, 1636, 0, 0, 39, '1635'),
	(377, 1, 0, -50378, 1637, 0, 0, 39, '1636'),
	(377, 1, 0, -50378, 1638, 0, 0, 39, '1637'),
	(377, 1, 0, -50378, 1639, 0, 0, 39, '1638'),
	(377, 1, 0, -50378, 1640, 0, 0, 39, '1639'),
	(377, 1, 0, -50378, 1641, 0, 0, 39, '1640'),
	(377, 1, 0, -50378, 1642, 0, 0, 39, '1641'),
	(377, 1, 0, -50378, 1643, 0, 0, 39, '1642'),
	(377, 1, 0, -50378, 1644, 0, 0, 39, '1643'),
	(377, 1, 0, -50378, 1645, 0, 0, 39, '1644'),
	(377, 1, 0, -50378, 1646, 0, 0, 39, '1645'),
	(377, 1, 0, -50378, 1647, 0, 0, 39, '1646'),
	(377, 1, 0, -50378, 1648, 0, 0, 39, '1647'),
	(377, 1, 0, -50378, 1649, 0, 0, 39, '1648'),
	(377, 1, 0, -50378, 1650, 0, 0, 39, '1649'),
	(377, 1, 0, -50378, 1651, 0, 0, 39, '1650'),
	(377, 1, 0, -50378, 1652, 0, 0, 39, '1651'),
	(377, 1, 0, -50378, 1653, 0, 0, 39, '1652'),
	(377, 1, 0, -50378, 1654, 0, 0, 39, '1653'),
	(377, 1, 0, -50378, 1655, 0, 0, 39, '1654'),
	(377, 1, 0, -50378, 1656, 0, 0, 39, '1655'),
	(377, 1, 0, -50378, 1657, 0, 0, 39, '1656'),
	(377, 1, 0, -50378, 1658, 0, 0, 39, '1657'),
	(377, 1, 0, -50378, 1659, 0, 0, 39, '1658'),
	(377, 1, 0, -50378, 1660, 0, 0, 39, '1659'),
	(377, 1, 0, -50378, 1661, 0, 0, 39, '1660'),
	(377, 1, 0, -50378, 1662, 0, 0, 39, '1661'),
	(377, 1, 0, -50378, 1663, 0, 0, 39, '1662'),
	(377, 1, 0, -50378, 1664, 0, 0, 39, '1663'),
	(377, 1, 0, -50378, 1665, 0, 0, 39, '1664'),
	(377, 1, 0, -50378, 1666, 0, 0, 39, '1665'),
	(377, 1, 0, -50378, 1667, 0, 0, 39, '1666'),
	(377, 1, 0, -50378, 1668, 0, 0, 39, '1667'),
	(377, 1, 0, -50378, 1669, 0, 0, 39, '1668'),
	(377, 1, 0, -50378, 1670, 0, 0, 39, '1669'),
	(377, 1, 0, -50378, 1671, 0, 0, 39, '1670'),
	(377, 1, 0, -50378, 1672, 0, 0, 39, '1671'),
	(377, 1, 0, -50378, 1673, 0, 0, 39, '1672'),
	(377, 1, 0, -50378, 1674, 0, 0, 39, '1673'),
	(377, 1, 0, -50378, 1675, 0, 0, 39, '1674'),
	(377, 1, 0, -50378, 1676, 0, 0, 39, '1675'),
	(377, 1, 0, -50378, 1677, 0, 0, 39, '1676'),
	(377, 1, 0, -50378, 1678, 0, 0, 39, '1677'),
	(377, 1, 0, -50378, 1679, 0, 0, 39, '1678'),
	(377, 1, 0, -50378, 1680, 0, 0, 39, '1679'),
	(377, 1, 0, -50378, 1681, 0, 0, 39, '1680'),
	(377, 1, 0, -50378, 1682, 0, 0, 39, '1681'),
	(377, 1, 0, -50378, 1683, 0, 0, 39, '1682'),
	(377, 1, 0, -50378, 1684, 0, 0, 39, '1683'),
	(377, 1, 0, -50378, 1685, 0, 0, 39, '1684'),
	(377, 1, 0, -50378, 1686, 0, 0, 39, '1685'),
	(377, 1, 0, -50378, 1687, 0, 0, 39, '1686'),
	(377, 1, 0, -50378, 1688, 0, 0, 39, '1687'),
	(377, 1, 0, -50378, 1689, 0, 0, 39, '1688'),
	(377, 1, 0, -50378, 1690, 0, 0, 39, '1689'),
	(377, 1, 0, -50378, 1691, 0, 0, 39, '1690'),
	(377, 1, 0, -50378, 1692, 0, 0, 39, '1691'),
	(377, 1, 0, -50378, 1693, 0, 0, 39, '1692'),
	(377, 1, 0, -50378, 1694, 0, 0, 39, '1693'),
	(377, 1, 0, -50378, 1695, 0, 0, 39, '1694'),
	(377, 1, 0, -50378, 1696, 0, 0, 39, '1695'),
	(377, 1, 0, -50378, 1697, 0, 0, 39, '1696'),
	(377, 1, 0, -50378, 1698, 0, 0, 39, '1697'),
	(377, 1, 0, -50378, 1699, 0, 0, 39, '1698'),
	(377, 1, 0, -50378, 1700, 0, 0, 39, '1699'),
	(377, 1, 0, -50378, 1701, 0, 0, 39, '1700'),
	(377, 1, 0, -50378, 1702, 0, 0, 39, '1701'),
	(377, 1, 0, -50378, 1703, 0, 0, 39, '1702'),
	(377, 1, 0, -50378, 1704, 0, 0, 39, '1703'),
	(377, 1, 0, -50378, 1705, 0, 0, 39, '1704'),
	(377, 1, 0, -50378, 1706, 0, 0, 39, '1705'),
	(377, 1, 0, -50378, 1707, 0, 0, 39, '1706'),
	(377, 1, 0, -50378, 1708, 0, 0, 39, '1707'),
	(377, 1, 0, -50378, 1709, 0, 0, 39, '1708'),
	(377, 1, 0, -50378, 1710, 0, 0, 39, '1709'),
	(377, 1, 0, -50378, 1711, 0, 0, 39, '1710'),
	(377, 1, 0, -50378, 1712, 0, 0, 39, '1711'),
	(377, 1, 0, -50378, 1713, 0, 0, 39, '1712'),
	(377, 1, 0, -50378, 1714, 0, 0, 39, '1713'),
	(377, 1, 0, -50378, 1715, 0, 0, 39, '1714'),
	(377, 1, 0, -50378, 1716, 0, 0, 39, '1715'),
	(377, 1, 0, -50378, 1717, 0, 0, 39, '1716'),
	(377, 1, 0, -50378, 1718, 0, 0, 39, '1717'),
	(377, 1, 0, -50378, 1719, 0, 0, 39, '1718'),
	(377, 1, 0, -50378, 1720, 0, 0, 39, '1719'),
	(377, 1, 0, -50378, 1721, 0, 0, 39, '1720'),
	(377, 1, 0, -50378, 1722, 0, 0, 39, '1721'),
	(377, 1, 0, -50378, 1723, 0, 0, 39, '1722'),
	(377, 1, 0, -50378, 1724, 0, 0, 39, '1723'),
	(377, 1, 0, -50378, 1725, 0, 0, 39, '1724'),
	(377, 1, 0, -50378, 1726, 0, 0, 39, '1725'),
	(377, 1, 0, -50378, 1727, 0, 0, 39, '1726'),
	(377, 1, 0, -50378, 1728, 0, 0, 39, '1727'),
	(377, 1, 0, -50378, 1729, 0, 0, 39, '1728'),
	(377, 1, 0, -50378, 1730, 0, 0, 39, '1729'),
	(377, 1, 0, -50378, 1731, 0, 0, 39, '1730'),
	(377, 1, 0, -50378, 1732, 0, 0, 39, '1731'),
	(377, 1, 0, -50378, 1733, 0, 0, 39, '1732'),
	(377, 1, 0, -50378, 1734, 0, 0, 39, '1733'),
	(377, 1, 0, -50378, 1735, 0, 0, 39, '1734'),
	(377, 1, 0, -50378, 1736, 0, 0, 39, '1735'),
	(377, 1, 0, -50378, 1737, 0, 0, 39, '1736'),
	(377, 1, 0, -50378, 1738, 0, 0, 39, '1737'),
	(377, 1, 0, -50378, 1739, 0, 0, 39, '1738'),
	(377, 1, 0, -50378, 1740, 0, 0, 39, '1739'),
	(377, 1, 0, -50378, 1741, 0, 0, 39, '1740'),
	(377, 1, 0, -50378, 1742, 0, 0, 39, '1741'),
	(377, 1, 0, -50378, 1743, 0, 0, 39, '1742'),
	(377, 1, 0, -50378, 1744, 0, 0, 39, '1743'),
	(377, 1, 0, -50378, 1745, 0, 0, 39, '1744'),
	(377, 1, 0, -50378, 1746, 0, 0, 39, '1745'),
	(377, 1, 0, -50378, 1747, 0, 0, 39, '1746'),
	(377, 1, 0, -50378, 1748, 0, 0, 39, '1747'),
	(377, 1, 0, -50378, 1749, 0, 0, 39, '1748'),
	(377, 1, 0, -50378, 1750, 0, 0, 39, '1749'),
	(377, 1, 0, -50378, 1751, 0, 0, 39, '1750'),
	(377, 1, 0, -50378, 1752, 0, 0, 39, '1751'),
	(377, 1, 0, -50378, 1753, 0, 0, 39, '1752'),
	(377, 1, 0, -50378, 1754, 0, 0, 39, '1753'),
	(377, 1, 0, -50378, 1755, 0, 0, 39, '1754'),
	(377, 1, 0, -50378, 1756, 0, 0, 39, '1755'),
	(377, 1, 0, -50378, 1757, 0, 0, 39, '1756'),
	(377, 1, 0, -50378, 1758, 0, 0, 39, '1757'),
	(377, 1, 0, -50378, 1759, 0, 0, 39, '1758'),
	(377, 1, 0, -50378, 1760, 0, 0, 39, '1759'),
	(377, 1, 0, -50378, 1761, 0, 0, 39, '1760'),
	(377, 1, 0, -50378, 1762, 0, 0, 39, '1761'),
	(377, 1, 0, -50378, 1763, 0, 0, 39, '1762'),
	(377, 1, 0, -50378, 1764, 0, 0, 39, '1763'),
	(377, 1, 0, -50378, 1765, 0, 0, 39, '1764'),
	(377, 1, 0, -50378, 1766, 0, 0, 39, '1765'),
	(377, 1, 0, -50378, 1767, 0, 0, 39, '1766'),
	(377, 1, 0, -50378, 1768, 0, 0, 39, '1767'),
	(377, 1, 0, -50378, 1769, 0, 0, 39, '1768'),
	(377, 1, 0, -50378, 1770, 0, 0, 39, '1769'),
	(377, 1, 0, -50378, 1771, 0, 0, 39, '1770'),
	(377, 1, 0, -50378, 1772, 0, 0, 39, '1771'),
	(377, 1, 0, -50378, 1773, 0, 0, 39, '1772'),
	(377, 1, 0, -50378, 1774, 0, 0, 39, '1773'),
	(377, 1, 0, -50378, 1775, 0, 0, 39, '1774'),
	(377, 1, 0, -50378, 1776, 0, 0, 39, '1775'),
	(377, 1, 0, -50378, 1777, 0, 0, 39, '1776'),
	(377, 1, 0, -50378, 1778, 0, 0, 39, '1777'),
	(377, 1, 0, -50378, 1779, 0, 0, 39, '1778'),
	(377, 1, 0, -50378, 1780, 0, 0, 39, '1779'),
	(377, 1, 0, -50378, 1781, 0, 0, 39, '1780'),
	(377, 1, 0, -50378, 1782, 0, 0, 39, '1781'),
	(377, 1, 0, -50378, 1783, 0, 0, 39, '1782'),
	(377, 1, 0, -50378, 1784, 0, 0, 39, '1783'),
	(377, 1, 0, -50378, 1785, 0, 0, 39, '1784'),
	(377, 1, 0, -50378, 1786, 0, 0, 39, '1785'),
	(377, 1, 0, -50378, 1787, 0, 0, 39, '1786'),
	(377, 1, 0, -50378, 1788, 0, 0, 39, '1787'),
	(377, 1, 0, -50378, 1789, 0, 0, 39, '1788'),
	(377, 1, 0, -50378, 1790, 0, 0, 39, '1789'),
	(377, 1, 0, -50378, 1791, 0, 0, 39, '1790'),
	(377, 1, 0, -50378, 1792, 0, 0, 39, '1791'),
	(377, 1, 0, -50378, 1793, 0, 0, 39, '1792'),
	(377, 1, 0, -50378, 1794, 0, 0, 39, '1793'),
	(377, 1, 0, -50378, 1795, 0, 0, 39, '1794'),
	(377, 1, 0, -50378, 1796, 0, 0, 39, '1795'),
	(377, 1, 0, -50378, 1797, 0, 0, 39, '1796'),
	(377, 1, 0, -50378, 1798, 0, 0, 39, '1797'),
	(377, 1, 0, -50378, 1799, 0, 0, 39, '1798'),
	(377, 1, 0, -50378, 1800, 0, 0, 39, '1799'),
	(377, 1, 0, -50378, 1801, 0, 0, 39, '1800'),
	(377, 1, 0, -50378, 1802, 0, 0, 39, '1801'),
	(377, 1, 0, -50378, 1803, 0, 0, 39, '1802'),
	(377, 1, 0, -50378, 1804, 0, 0, 39, '1803'),
	(377, 1, 0, -50378, 1805, 0, 0, 39, '1804'),
	(377, 1, 0, -50378, 1806, 0, 0, 39, '1805'),
	(377, 1, 0, -50378, 1807, 0, 0, 39, '1806'),
	(377, 1, 0, -50378, 1808, 0, 0, 39, '1807'),
	(377, 1, 0, -50378, 1809, 0, 0, 39, '1808'),
	(377, 1, 0, -50378, 1810, 0, 0, 39, '1809'),
	(377, 1, 0, -50378, 1811, 0, 0, 39, '1810'),
	(377, 1, 0, -50378, 1812, 0, 0, 39, '1811'),
	(377, 1, 0, -50378, 1813, 0, 0, 39, '1812'),
	(377, 1, 0, -50378, 1814, 0, 0, 39, '1813'),
	(377, 1, 0, -50378, 1815, 0, 0, 39, '1814'),
	(377, 1, 0, -50378, 1816, 0, 0, 39, '1815'),
	(377, 1, 0, -50378, 1817, 0, 0, 39, '1816'),
	(377, 1, 0, -50378, 1818, 0, 0, 39, '1817'),
	(377, 1, 0, -50378, 1819, 0, 0, 39, '1818'),
	(377, 1, 0, -50378, 1820, 0, 0, 39, '1819'),
	(377, 1, 0, -50378, 1821, 0, 0, 39, '1820'),
	(377, 1, 0, -50378, 1822, 0, 0, 39, '1821'),
	(377, 1, 0, -50378, 1823, 0, 0, 39, '1822'),
	(377, 1, 0, -50378, 1824, 0, 0, 39, '1823'),
	(377, 1, 0, -50378, 1825, 0, 0, 39, '1824'),
	(377, 1, 0, -50378, 1826, 0, 0, 39, '1825'),
	(377, 1, 0, -50378, 1827, 0, 0, 39, '1826'),
	(377, 1, 0, -50378, 1828, 0, 0, 39, '1827'),
	(377, 1, 0, -50378, 1829, 0, 0, 39, '1828'),
	(377, 1, 0, -50378, 1830, 0, 0, 39, '1829'),
	(377, 1, 0, -50378, 1831, 0, 0, 39, '1830'),
	(377, 1, 0, -50378, 1832, 0, 0, 39, '1831'),
	(377, 1, 0, -50378, 1833, 0, 0, 39, '1832'),
	(377, 1, 0, -50378, 1834, 0, 0, 39, '1833'),
	(377, 1, 0, -50378, 1835, 0, 0, 39, '1834'),
	(377, 1, 0, -50378, 1836, 0, 0, 39, '1835'),
	(377, 1, 0, -50378, 1837, 0, 0, 39, '1836'),
	(377, 1, 0, -50378, 1838, 0, 0, 39, '1837'),
	(377, 1, 0, -50378, 1839, 0, 0, 39, '1838'),
	(377, 1, 0, -50378, 1840, 0, 0, 39, '1839'),
	(377, 1, 0, -50378, 1841, 0, 0, 39, '1840'),
	(377, 1, 0, -50378, 1842, 0, 0, 39, '1841'),
	(377, 1, 0, -50378, 1843, 0, 0, 39, '1842'),
	(377, 1, 0, -50378, 1844, 0, 0, 39, '1843'),
	(377, 1, 0, -50378, 1845, 0, 0, 39, '1844'),
	(377, 1, 0, -50378, 1846, 0, 0, 39, '1845'),
	(377, 1, 0, -50378, 1847, 0, 0, 39, '1846'),
	(377, 1, 0, -50378, 1848, 0, 0, 39, '1847'),
	(377, 1, 0, -50378, 1849, 0, 0, 39, '1848'),
	(377, 1, 0, -50378, 1850, 0, 0, 39, '1849'),
	(377, 1, 0, -50378, 1851, 0, 0, 39, '1850'),
	(377, 1, 0, -50378, 1852, 0, 0, 39, '1851'),
	(377, 1, 0, -50378, 1853, 0, 0, 39, '1852'),
	(377, 1, 0, -50378, 1854, 0, 0, 39, '1853'),
	(377, 1, 0, -50378, 1855, 0, 0, 39, '1854'),
	(377, 1, 0, -50378, 1856, 0, 0, 39, '1855'),
	(377, 1, 0, -50378, 1857, 0, 0, 39, '1856'),
	(377, 1, 0, -50378, 1858, 0, 0, 39, '1857'),
	(377, 1, 0, -50378, 1859, 0, 0, 39, '1858'),
	(377, 1, 0, -50378, 1860, 0, 0, 39, '1859'),
	(377, 1, 0, -50378, 1861, 0, 0, 39, '1860'),
	(377, 1, 0, -50378, 1862, 0, 0, 39, '1861'),
	(377, 1, 0, -50378, 1863, 0, 0, 39, '1862'),
	(377, 1, 0, -50378, 1864, 0, 0, 39, '1863'),
	(377, 1, 0, -50378, 1865, 0, 0, 39, '1864'),
	(377, 1, 0, -50378, 1866, 0, 0, 39, '1865'),
	(377, 1, 0, -50378, 1867, 0, 0, 39, '1866'),
	(377, 1, 0, -50378, 1868, 0, 0, 39, '1867'),
	(377, 1, 0, -50378, 1869, 0, 0, 39, '1868'),
	(377, 1, 0, -50378, 1870, 0, 0, 39, '1869'),
	(377, 1, 0, -50378, 1871, 0, 0, 39, '1870'),
	(377, 1, 0, -50378, 1872, 0, 0, 39, '1871'),
	(377, 1, 0, -50378, 1873, 0, 0, 39, '1872'),
	(377, 1, 0, -50378, 1874, 0, 0, 39, '1873'),
	(377, 1, 0, -50378, 1875, 0, 0, 39, '1874'),
	(377, 1, 0, -50378, 1876, 0, 0, 39, '1875'),
	(377, 1, 0, -50378, 1877, 0, 0, 39, '1876'),
	(377, 1, 0, -50378, 1878, 0, 0, 39, '1877'),
	(377, 1, 0, -50378, 1879, 0, 0, 39, '1878'),
	(377, 1, 0, -50378, 1880, 0, 0, 39, '1879'),
	(377, 1, 0, -50378, 1881, 0, 0, 39, '1880'),
	(377, 1, 0, -50378, 1882, 0, 0, 39, '1881'),
	(377, 1, 0, -50378, 1883, 0, 0, 39, '1882'),
	(377, 1, 0, -50378, 1884, 0, 0, 39, '1883'),
	(377, 1, 0, -50378, 1885, 0, 0, 39, '1884'),
	(377, 1, 0, -50378, 1886, 0, 0, 39, '1885'),
	(377, 1, 0, -50378, 1887, 0, 0, 39, '1886'),
	(377, 1, 0, -50378, 1888, 0, 0, 39, '1887'),
	(377, 1, 0, -50378, 1889, 0, 0, 39, '1888'),
	(377, 1, 0, -50378, 1890, 0, 0, 39, '1889'),
	(377, 1, 0, -50378, 1891, 0, 0, 39, '1890'),
	(377, 1, 0, -50378, 1892, 0, 0, 39, '1891'),
	(377, 1, 0, -50378, 1893, 0, 0, 39, '1892'),
	(377, 1, 0, -50378, 1894, 0, 0, 39, '1893'),
	(377, 1, 0, -50378, 1895, 0, 0, 39, '1894'),
	(377, 1, 0, -50378, 1896, 0, 0, 39, '1895'),
	(377, 1, 0, -50378, 1897, 0, 0, 39, '1896'),
	(377, 1, 0, -50378, 1898, 0, 0, 39, '1897'),
	(377, 1, 0, -50378, 1899, 0, 0, 39, '1898'),
	(377, 1, 0, -50378, 1900, 0, 0, 39, '1899'),
	(377, 1, 0, -50378, 1901, 0, 0, 39, '1900'),
	(377, 1, 0, -50378, 1902, 0, 0, 39, '1901'),
	(377, 1, 0, -50378, 1903, 0, 0, 39, '1902'),
	(377, 1, 0, -50378, 1904, 0, 0, 39, '1903'),
	(377, 1, 0, -50378, 1905, 0, 0, 39, '1904'),
	(377, 1, 0, -50378, 1906, 0, 0, 39, '1905'),
	(377, 1, 0, -50378, 1907, 0, 0, 39, '1906'),
	(377, 1, 0, -50378, 1908, 0, 0, 39, '1907'),
	(377, 1, 0, -50378, 1909, 0, 0, 39, '1908'),
	(377, 1, 0, -50378, 1910, 0, 0, 39, '1909'),
	(377, 1, 0, -50378, 1911, 0, 0, 39, '1910'),
	(377, 1, 0, -50378, 1912, 0, 0, 39, '1911'),
	(377, 1, 0, -50378, 1913, 0, 0, 39, '1912'),
	(377, 1, 0, -50378, 1914, 0, 0, 39, '1913'),
	(377, 1, 0, -50378, 1915, 0, 0, 39, '1914'),
	(377, 1, 0, -50378, 1916, 0, 0, 39, '1915'),
	(377, 1, 0, -50378, 1917, 0, 0, 39, '1916'),
	(377, 1, 0, -50378, 1918, 0, 0, 39, '1917'),
	(377, 1, 0, -50378, 1919, 0, 0, 39, '1918'),
	(377, 1, 0, -50378, 1920, 0, 0, 39, '1919'),
	(377, 1, 0, -50378, 1921, 0, 0, 39, '1920'),
	(377, 1, 0, -50378, 1922, 0, 0, 39, '1921'),
	(377, 1, 0, -50378, 1923, 0, 0, 39, '1922'),
	(377, 1, 0, -50378, 1924, 0, 0, 39, '1923'),
	(377, 1, 0, -50378, 1925, 0, 0, 39, '1924'),
	(377, 1, 0, -50378, 1926, 0, 0, 39, '1925'),
	(377, 1, 0, -50378, 1927, 0, 0, 39, '1926'),
	(377, 1, 0, -50378, 1928, 0, 0, 39, '1927'),
	(377, 1, 0, -50378, 1929, 0, 0, 39, '1928'),
	(377, 1, 0, -50378, 1930, 0, 0, 39, '1929'),
	(377, 1, 0, -50378, 1931, 0, 0, 39, '1930'),
	(377, 1, 0, -50378, 1932, 0, 0, 39, '1931'),
	(377, 1, 0, -50378, 1933, 0, 0, 39, '1932'),
	(377, 1, 0, -50378, 1934, 0, 0, 39, '1933'),
	(377, 1, 0, -50378, 1935, 0, 0, 39, '1934'),
	(377, 1, 0, -50378, 1936, 0, 0, 39, '1935'),
	(377, 1, 0, -50378, 1937, 0, 0, 39, '1936'),
	(377, 1, 0, -50378, 1938, 0, 0, 39, '1937'),
	(377, 1, 0, -50378, 1939, 0, 0, 39, '1938'),
	(377, 1, 0, -50378, 1940, 0, 0, 39, '1939'),
	(377, 1, 0, -50378, 1941, 0, 0, 39, '1940'),
	(377, 1, 0, -50378, 1942, 0, 0, 39, '1941'),
	(377, 1, 0, -50378, 1943, 0, 0, 39, '1942'),
	(377, 1, 0, -50378, 1944, 0, 0, 39, '1943'),
	(377, 1, 0, -50378, 1945, 0, 0, 39, '1944'),
	(377, 1, 0, -50378, 1946, 0, 0, 39, '1945'),
	(377, 1, 0, -50378, 1947, 0, 0, 39, '1946'),
	(377, 1, 0, -50378, 1948, 0, 0, 39, '1947'),
	(377, 1, 0, -50378, 1949, 0, 0, 39, '1948'),
	(377, 1, 0, -50378, 1950, 0, 0, 39, '1949'),
	(377, 1, 0, -50378, 1951, 0, 0, 39, '1950'),
	(377, 1, 0, -50378, 1952, 0, 0, 39, '1951'),
	(377, 1, 0, -50378, 1953, 0, 0, 39, '1952'),
	(377, 1, 0, -50378, 1954, 0, 0, 39, '1953'),
	(377, 1, 0, -50378, 1955, 0, 0, 39, '1954'),
	(377, 1, 0, -50378, 1956, 0, 0, 39, '1955'),
	(377, 1, 0, -50378, 1957, 0, 0, 39, '1956'),
	(377, 1, 0, -50378, 1958, 0, 0, 39, '1957'),
	(377, 1, 0, -50378, 1959, 0, 0, 39, '1958'),
	(377, 1, 0, -50378, 1960, 0, 0, 39, '1959'),
	(377, 1, 0, -50378, 1961, 0, 0, 39, '1960'),
	(377, 1, 0, -50378, 1962, 0, 0, 39, '1961'),
	(377, 1, 0, -50378, 1963, 0, 0, 39, '1962'),
	(377, 1, 0, -50378, 1964, 0, 0, 39, '1963'),
	(377, 1, 0, -50378, 1965, 0, 0, 39, '1964'),
	(377, 1, 0, -50378, 1966, 0, 0, 39, '1965'),
	(377, 1, 0, -50378, 1967, 0, 0, 39, '1966'),
	(377, 1, 0, -50378, 1968, 0, 0, 39, '1967'),
	(377, 1, 0, -50378, 1969, 0, 0, 39, '1968'),
	(377, 1, 0, -50378, 1970, 0, 0, 39, '1969'),
	(377, 1, 0, -50378, 1971, 0, 0, 39, '1970'),
	(377, 1, 0, -50378, 1972, 0, 0, 39, '1971'),
	(377, 1, 0, -50378, 1973, 0, 0, 39, '1972'),
	(377, 1, 0, -50378, 1974, 0, 0, 39, '1973'),
	(377, 1, 0, -50378, 1975, 0, 0, 39, '1974'),
	(377, 1, 0, -50378, 1976, 0, 0, 39, '1975'),
	(377, 1, 0, -50378, 1977, 0, 0, 39, '1976'),
	(377, 1, 0, -50378, 1978, 0, 0, 39, '1977'),
	(377, 1, 0, -50378, 1979, 0, 0, 39, '1978'),
	(377, 1, 0, -50378, 1980, 0, 0, 39, '1979'),
	(377, 1, 0, -50378, 1981, 0, 0, 39, '1980'),
	(377, 1, 0, -50378, 1982, 0, 0, 39, '1981'),
	(377, 1, 0, -50378, 1983, 0, 0, 39, '1982'),
	(377, 1, 0, -50378, 1984, 0, 0, 39, '1983'),
	(377, 1, 0, -50378, 1985, 0, 0, 39, '1984'),
	(377, 1, 0, -50378, 1986, 0, 0, 39, '1985'),
	(377, 1, 0, -50378, 1987, 0, 0, 39, '1986'),
	(377, 1, 0, -50378, 1988, 0, 0, 39, '1987'),
	(377, 1, 0, -50378, 1989, 0, 0, 39, '1988'),
	(377, 1, 0, -50378, 1990, 0, 0, 39, '1989'),
	(377, 1, 0, -50378, 1991, 0, 0, 39, '1990'),
	(377, 1, 0, -50378, 1992, 0, 0, 39, '1991'),
	(377, 1, 0, -50378, 1993, 0, 0, 39, '1992'),
	(377, 1, 0, -50378, 1994, 0, 0, 39, '1993'),
	(377, 1, 0, -50378, 1995, 0, 0, 39, '1994'),
	(377, 1, 0, -50378, 1996, 0, 0, 39, '1995'),
	(377, 1, 0, -50378, 1997, 0, 0, 39, '1996'),
	(377, 1, 0, -50378, 1998, 0, 0, 39, '1997'),
	(377, 1, 0, -50378, 1999, 0, 0, 39, '1998'),
	(377, 1, 0, -50378, 2000, 0, 0, 39, '1999'),
	(377, 1, 0, -50378, 2001, 0, 0, 39, '2000'),
	(377, 1, 0, -50378, 2002, 0, 0, 39, '2001'),
	(377, 1, 0, -50378, 2003, 0, 0, 39, '2002'),
	(377, 1, 0, -50378, 2004, 0, 0, 39, '2003'),
	(377, 1, 0, -50378, 2005, 0, 0, 39, '2004'),
	(377, 1, 0, -50378, 2006, 0, 0, 39, '2005'),
	(377, 1, 0, -50378, 2007, 0, 0, 39, '2006'),
	(377, 1, 0, -50378, 2008, 0, 0, 39, '2007'),
	(377, 1, 0, -50378, 2009, 0, 0, 39, '2008'),
	(377, 1, 0, -50378, 2010, 0, 0, 39, '2009'),
	(377, 1, 0, -50378, 2011, 0, 0, 39, '2010'),
	(377, 1, 0, -50378, 2012, 0, 0, 39, '2011'),
	(377, 1, 0, -50378, 2013, 0, 0, 39, '2012'),
	(377, 1, 0, -50378, 2014, 0, 0, 39, '2013'),
	(377, 1, 0, -50378, 2015, 0, 0, 39, '2014'),
	(377, 1, 0, -50378, 2016, 0, 0, 39, '2015'),
	(377, 1, 0, -50378, 2017, 0, 0, 39, '2016'),
	(377, 1, 0, -50378, 2018, 0, 0, 39, '2017'),
	(377, 1, 0, -50378, 2019, 0, 0, 39, '2018'),
	(377, 1, 0, -50378, 2020, 0, 0, 39, '2019'),
	(377, 1, 0, -50378, 2021, 0, 0, 39, '2020'),
	(377, 1, 0, -50378, 2022, 0, 0, 39, '2021'),
	(377, 1, 0, -50378, 2023, 0, 0, 39, '2022'),
	(377, 1, 0, -50378, 2024, 0, 0, 39, '2023'),
	(377, 1, 0, -50378, 2025, 0, 0, 39, '2024'),
	(377, 1, 0, -50378, 2026, 0, 0, 39, '2025'),
	(377, 1, 0, -50378, 2027, 0, 0, 39, '2026'),
	(377, 1, 0, -50378, 2028, 0, 0, 39, '2027'),
	(377, 1, 0, -50378, 2029, 0, 0, 39, '2028'),
	(377, 1, 0, -50378, 2030, 0, 0, 39, '2029'),
	(377, 1, 0, -50378, 2031, 0, 0, 39, '2030'),
	(377, 1, 0, -50378, 2032, 0, 0, 39, '2031'),
	(377, 1, 0, -50378, 2033, 0, 0, 39, '2032'),
	(377, 1, 0, -50378, 2034, 0, 0, 39, '2033'),
	(377, 1, 0, -50378, 2035, 0, 0, 39, '2034'),
	(377, 1, 0, -50378, 2036, 0, 0, 39, '2035'),
	(377, 1, 0, -50378, 2037, 0, 0, 39, '2036'),
	(377, 1, 0, -50378, 2038, 0, 0, 39, '2037'),
	(377, 1, 0, -50378, 2039, 0, 0, 39, '2038'),
	(377, 1, 0, -50378, 2040, 0, 0, 39, '2039'),
	(377, 1, 0, -50378, 2041, 0, 0, 39, '2040'),
	(377, 1, 0, -50378, 2042, 0, 0, 39, '2041'),
	(377, 1, 0, -50378, 2043, 0, 0, 39, '2042'),
	(377, 1, 0, -50378, 2044, 0, 0, 39, '2043'),
	(377, 1, 0, -50378, 2045, 0, 0, 39, '2044'),
	(377, 1, 0, -50378, 2046, 0, 0, 39, '2045'),
	(377, 1, 0, -50378, 2047, 0, 0, 39, '2046'),
	(377, 1, 0, -50378, 2048, 0, 0, 39, '2047'),
	(377, 1, 0, -50378, 2049, 0, 0, 39, '2048'),
	(377, 1, 0, -50378, 2050, 0, 0, 39, '2049'),
	(377, 1, 0, -50378, 2051, 0, 0, 39, '2050'),
	(377, 1, 0, -50378, 2052, 0, 0, 39, '2051'),
	(377, 1, 0, -50378, 2053, 0, 0, 39, '2052'),
	(377, 1, 0, -50378, 2054, 0, 0, 39, '2053'),
	(377, 1, 0, -50378, 2055, 0, 0, 39, '2054'),
	(377, 1, 0, -50378, 2056, 0, 0, 39, '2055'),
	(377, 1, 0, -50378, 2057, 0, 0, 39, '2056'),
	(377, 1, 0, -50378, 2058, 0, 0, 39, '2057'),
	(377, 1, 0, -50378, 2059, 0, 0, 39, '2058'),
	(377, 1, 0, -50378, 2060, 0, 0, 39, '2059'),
	(377, 1, 0, -50378, 2061, 0, 0, 39, '2060'),
	(377, 1, 0, -50378, 2062, 0, 0, 39, '2061'),
	(377, 1, 0, -50378, 2063, 0, 0, 39, '2062'),
	(377, 1, 0, -50378, 2064, 0, 0, 39, '2063'),
	(377, 1, 0, -50378, 2065, 0, 0, 39, '2064'),
	(377, 1, 0, -50378, 2066, 0, 0, 39, '2065'),
	(377, 1, 0, -50378, 2067, 0, 0, 39, '2066'),
	(377, 1, 0, -50378, 2068, 0, 0, 39, '2067'),
	(377, 1, 0, -50378, 2069, 0, 0, 39, '2068'),
	(377, 1, 0, -50378, 2070, 0, 0, 39, '2069'),
	(377, 1, 0, -50378, 2071, 0, 0, 39, '2070'),
	(377, 1, 0, -50378, 2072, 0, 0, 39, '2071'),
	(377, 1, 0, -50378, 2073, 0, 0, 39, '2072'),
	(377, 1, 0, -50378, 2074, 0, 0, 39, '2073'),
	(377, 1, 0, -50378, 2075, 0, 0, 39, '2074'),
	(377, 1, 0, -50378, 2076, 0, 0, 39, '2075'),
	(377, 1, 0, -50378, 2077, 0, 0, 39, '2076'),
	(377, 1, 0, -50378, 2078, 0, 0, 39, '2077'),
	(377, 1, 0, -50378, 2079, 0, 0, 39, '2078'),
	(377, 1, 0, -50378, 2080, 0, 0, 39, '2079'),
	(377, 1, 0, -50378, 2081, 0, 0, 39, '2080'),
	(377, 1, 0, -50378, 2082, 0, 0, 39, '2081'),
	(377, 1, 0, -50378, 2083, 0, 0, 39, '2082'),
	(377, 1, 0, -50378, 2084, 0, 0, 39, '2083'),
	(377, 1, 0, -50378, 2085, 0, 0, 39, '2084'),
	(377, 1, 0, -50378, 2086, 0, 0, 39, '2085'),
	(377, 1, 0, -50378, 2087, 0, 0, 39, '2086'),
	(377, 1, 0, -50378, 2088, 0, 0, 39, '2087'),
	(377, 1, 0, -50378, 2089, 0, 0, 39, '2088'),
	(377, 1, 0, -50378, 2090, 0, 0, 39, '2089'),
	(377, 1, 0, -50378, 2091, 0, 0, 39, '2090'),
	(377, 1, 0, -50378, 2092, 0, 0, 39, '2091'),
	(377, 1, 0, -50378, 2093, 0, 0, 39, '2092'),
	(377, 1, 0, -50378, 2094, 0, 0, 39, '2093'),
	(377, 1, 0, -50378, 2095, 0, 0, 39, '2094'),
	(377, 1, 0, -50378, 2096, 0, 0, 39, '2095'),
	(377, 1, 0, -50378, 2097, 0, 0, 39, '2096'),
	(377, 1, 0, -50378, 2098, 0, 0, 39, '2097'),
	(377, 1, 0, -50378, 2099, 0, 0, 39, '2098'),
	(377, 1, 0, -50378, 2100, 0, 0, 39, '2099'),
	(377, 1, 0, -50378, 2101, 0, 0, 39, '2100'),
	(377, 1, 0, -50378, 2102, 0, 0, 39, '2101'),
	(377, 1, 0, -50378, 2103, 0, 0, 39, '2102'),
	(377, 1, 0, -50378, 2104, 0, 0, 39, '2103'),
	(377, 1, 0, -50378, 2105, 0, 0, 39, '2104'),
	(377, 1, 0, -50378, 2106, 0, 0, 39, '2105'),
	(377, 1, 0, -50378, 2107, 0, 0, 39, '2106'),
	(377, 1, 0, -50378, 2108, 0, 0, 39, '2107'),
	(377, 1, 0, -50378, 2109, 0, 0, 39, '2108'),
	(377, 1, 0, -50378, 2110, 0, 0, 39, '2109'),
	(377, 1, 0, -50378, 2111, 0, 0, 39, '2110'),
	(377, 1, 0, -50378, 2112, 0, 0, 39, '2111'),
	(377, 1, 0, -50378, 2113, 0, 0, 39, '2112'),
	(377, 1, 0, -50378, 2114, 0, 0, 39, '2113'),
	(377, 1, 0, -50378, 2115, 0, 0, 39, '2114'),
	(377, 1, 0, -50378, 2116, 0, 0, 39, '2115'),
	(377, 1, 0, -50378, 2117, 0, 0, 39, '2116'),
	(377, 1, 0, -50378, 2118, 0, 0, 39, '2117'),
	(377, 1, 0, -50378, 2119, 0, 0, 39, '2118'),
	(377, 1, 0, -50378, 2120, 0, 0, 39, '2119'),
	(377, 1, 0, -50378, 2121, 0, 0, 39, '2120'),
	(377, 1, 0, -50378, 2122, 0, 0, 39, '2121'),
	(377, 1, 0, -50378, 2123, 0, 0, 39, '2122'),
	(377, 1, 0, -50378, 2124, 0, 0, 39, '2123'),
	(377, 1, 0, -50378, 2125, 0, 0, 39, '2124'),
	(377, 1, 0, -50378, 2126, 0, 0, 39, '2125'),
	(377, 1, 0, -50378, 2127, 0, 0, 39, '2126'),
	(377, 1, 0, -50378, 2128, 0, 0, 39, '2127'),
	(377, 1, 0, -50378, 2129, 0, 0, 39, '2128'),
	(377, 1, 0, -50378, 2130, 0, 0, 39, '2129'),
	(377, 1, 0, -50378, 2131, 0, 0, 39, '2130'),
	(377, 1, 0, -50378, 2132, 0, 0, 39, '2131'),
	(377, 1, 0, -50378, 2133, 0, 0, 39, '2132'),
	(377, 1, 0, -50378, 2134, 0, 0, 39, '2133'),
	(377, 1, 0, -50378, 2135, 0, 0, 39, '2134'),
	(377, 1, 0, -50378, 2136, 0, 0, 39, '2135'),
	(377, 1, 0, -50378, 2137, 0, 0, 39, '2136'),
	(377, 1, 0, -50378, 2138, 0, 0, 39, '2137'),
	(377, 1, 0, -50378, 2139, 0, 0, 39, '2138'),
	(377, 1, 0, -50378, 2140, 0, 0, 39, '2139'),
	(377, 1, 0, -50378, 2141, 0, 0, 39, '2140'),
	(377, 1, 0, -50378, 2142, 0, 0, 39, '2141'),
	(377, 1, 0, -50378, 2143, 0, 0, 39, '2142'),
	(377, 1, 0, -50378, 2144, 0, 0, 39, '2143'),
	(377, 1, 0, -50378, 2145, 0, 0, 39, '2144'),
	(377, 1, 0, -50378, 2146, 0, 0, 39, '2145'),
	(377, 1, 0, -50378, 2147, 0, 0, 39, '2146'),
	(377, 1, 0, -50378, 2148, 0, 0, 39, '2147'),
	(377, 1, 0, -50378, 2149, 0, 0, 39, '2148'),
	(377, 1, 0, -50378, 2150, 0, 0, 39, '2149'),
	(377, 1, 0, -50378, 2151, 0, 0, 39, '2150'),
	(377, 1, 0, -50378, 2152, 0, 0, 39, '2151'),
	(377, 1, 0, -50378, 2153, 0, 0, 39, '2152'),
	(377, 1, 0, -50378, 2154, 0, 0, 39, '2153'),
	(377, 1, 0, -50378, 2155, 0, 0, 39, '2154'),
	(377, 1, 0, -50378, 2156, 0, 0, 39, '2155'),
	(377, 1, 0, -50378, 2157, 0, 0, 39, '2156'),
	(377, 1, 0, -50378, 2158, 0, 0, 39, '2157'),
	(377, 1, 0, -50378, 2159, 0, 0, 39, '2158'),
	(377, 1, 0, -50378, 2160, 0, 0, 39, '2159'),
	(377, 1, 0, -50378, 2161, 0, 0, 39, '2160'),
	(377, 1, 0, -50378, 2162, 0, 0, 39, '2161'),
	(377, 1, 0, -50378, 2163, 0, 0, 39, '2162'),
	(377, 1, 0, -50378, 2164, 0, 0, 39, '2163'),
	(377, 1, 0, -50378, 2165, 0, 0, 39, '2164'),
	(377, 1, 0, -50378, 2166, 0, 0, 39, '2165'),
	(377, 1, 0, -50378, 2167, 0, 0, 39, '2166'),
	(377, 1, 0, -50378, 2168, 0, 0, 39, '2167'),
	(377, 1, 0, -50378, 2169, 0, 0, 39, '2168'),
	(377, 1, 0, -50378, 2170, 0, 0, 39, '2169'),
	(377, 1, 0, -50378, 2171, 0, 0, 39, '2170'),
	(377, 1, 0, -50378, 2172, 0, 0, 39, '2171'),
	(377, 1, 0, -50378, 2173, 0, 0, 39, '2172'),
	(377, 1, 0, -50378, 2174, 0, 0, 39, '2173'),
	(377, 1, 0, -50378, 2175, 0, 0, 39, '2174'),
	(377, 1, 0, -50378, 2176, 0, 0, 39, '2175'),
	(377, 1, 0, -50378, 2177, 0, 0, 39, '2176'),
	(377, 1, 0, -50378, 2178, 0, 0, 39, '2177'),
	(377, 1, 0, -50378, 2179, 0, 0, 39, '2178'),
	(377, 1, 0, -50378, 2180, 0, 0, 39, '2179'),
	(377, 1, 0, -50378, 2181, 0, 0, 39, '2180'),
	(377, 1, 0, -50378, 2182, 0, 0, 39, '2181'),
	(377, 1, 0, -50378, 2183, 0, 0, 39, '2182'),
	(377, 1, 0, -50378, 2184, 0, 0, 39, '2183'),
	(377, 1, 0, -50378, 2185, 0, 0, 39, '2184'),
	(377, 1, 0, -50378, 2186, 0, 0, 39, '2185'),
	(377, 1, 0, -50378, 2187, 0, 0, 39, '2186'),
	(377, 1, 0, -50378, 2188, 0, 0, 39, '2187'),
	(377, 1, 0, -50378, 2189, 0, 0, 39, '2188'),
	(377, 1, 0, -50378, 2190, 0, 0, 39, '2189'),
	(377, 1, 0, -50378, 2191, 0, 0, 39, '2190'),
	(377, 1, 0, -50378, 2192, 0, 0, 39, '2191'),
	(377, 1, 0, -50378, 2193, 0, 0, 39, '2192'),
	(377, 1, 0, -50378, 2194, 0, 0, 39, '2193'),
	(377, 1, 0, -50378, 2195, 0, 0, 39, '2194'),
	(377, 1, 0, -50378, 2196, 0, 0, 39, '2195'),
	(377, 1, 0, -50378, 2197, 0, 0, 39, '2196'),
	(377, 1, 0, -50378, 2198, 0, 0, 39, '2197'),
	(377, 1, 0, -50378, 2199, 0, 0, 39, '2198'),
	(377, 1, 0, -50378, 2200, 0, 0, 39, '2199'),
	(377, 1, 0, -50378, 2201, 0, 0, 39, '2200'),
	(377, 1, 0, -50378, 2202, 0, 0, 39, '2201'),
	(377, 1, 0, -50378, 2203, 0, 0, 39, '2202'),
	(377, 1, 0, -50378, 2204, 0, 0, 39, '2203'),
	(377, 1, 0, -50378, 2205, 0, 0, 39, '2204'),
	(377, 1, 0, -50378, 2206, 0, 0, 39, '2205'),
	(377, 1, 0, -50378, 2207, 0, 0, 39, '2206'),
	(377, 1, 0, -50378, 2208, 0, 0, 39, '2207'),
	(377, 1, 0, -50378, 2209, 0, 0, 39, '2208'),
	(377, 1, 0, -50378, 2210, 0, 0, 39, '2209'),
	(377, 1, 0, -50378, 2211, 0, 0, 39, '2210'),
	(377, 1, 0, -50378, 2212, 0, 0, 39, '2211'),
	(377, 1, 0, -50378, 2213, 0, 0, 39, '2212'),
	(377, 1, 0, -50378, 2214, 0, 0, 39, '2213'),
	(377, 1, 0, -50378, 2215, 0, 0, 39, '2214'),
	(377, 1, 0, -50378, 2216, 0, 0, 39, '2215'),
	(377, 1, 0, -50378, 2217, 0, 0, 39, '2216'),
	(377, 1, 0, -50378, 2218, 0, 0, 39, '2217'),
	(377, 1, 0, -50378, 2219, 0, 0, 39, '2218'),
	(377, 1, 0, -50378, 2220, 0, 0, 39, '2219'),
	(377, 1, 0, -50378, 2221, 0, 0, 39, '2220'),
	(377, 1, 0, -50378, 2222, 0, 0, 39, '2221'),
	(377, 1, 0, -50378, 2223, 0, 0, 39, '2222'),
	(377, 1, 0, -50378, 2224, 0, 0, 39, '2223'),
	(377, 1, 0, -50378, 2225, 0, 0, 39, '2224'),
	(377, 1, 0, -50378, 2226, 0, 0, 39, '2225'),
	(377, 1, 0, -50378, 2227, 0, 0, 39, '2226'),
	(377, 1, 0, -50378, 2228, 0, 0, 39, '2227'),
	(377, 1, 0, -50378, 2229, 0, 0, 39, '2228'),
	(377, 1, 0, -50378, 2230, 0, 0, 39, '2229'),
	(377, 1, 0, -50378, 2231, 0, 0, 39, '2230'),
	(377, 1, 0, -50378, 2232, 0, 0, 39, '2231'),
	(377, 1, 0, -50378, 2233, 0, 0, 39, '2232'),
	(377, 1, 0, -50378, 2234, 0, 0, 39, '2233'),
	(377, 1, 0, -50378, 2235, 0, 0, 39, '2234'),
	(377, 1, 0, -50378, 2236, 0, 0, 39, '2235'),
	(377, 1, 0, -50378, 2237, 0, 0, 39, '2236'),
	(377, 1, 0, -50378, 2238, 0, 0, 39, '2237'),
	(377, 1, 0, -50378, 2239, 0, 0, 39, '2238'),
	(377, 1, 0, -50378, 2240, 0, 0, 39, '2239'),
	(377, 1, 0, -50378, 2241, 0, 0, 39, '2240'),
	(377, 1, 0, -50378, 2242, 0, 0, 39, '2241'),
	(377, 1, 0, -50378, 2243, 0, 0, 39, '2242'),
	(377, 1, 0, -50378, 2244, 0, 0, 39, '2243'),
	(377, 1, 0, -50378, 2245, 0, 0, 39, '2244'),
	(377, 1, 0, -50378, 2246, 0, 0, 39, '2245'),
	(377, 1, 0, -50378, 2247, 0, 0, 39, '2246'),
	(377, 1, 0, -50378, 2248, 0, 0, 39, '2247'),
	(377, 1, 0, -50378, 2249, 0, 0, 39, '2248'),
	(377, 1, 0, -50378, 2250, 0, 0, 39, '2249'),
	(377, 1, 0, -50378, 2251, 0, 0, 39, '2250'),
	(377, 1, 0, -50378, 2252, 0, 0, 39, '2251'),
	(377, 1, 0, -50378, 2253, 0, 0, 39, '2252'),
	(377, 1, 0, -50378, 2254, 0, 0, 39, '2253'),
	(377, 1, 0, -50378, 2255, 0, 0, 39, '2254'),
	(377, 1, 0, -50378, 2256, 0, 0, 39, '2255'),
	(377, 1, 0, -50378, 2257, 0, 0, 39, '2256'),
	(377, 1, 0, -50378, 2258, 0, 0, 39, '2257'),
	(377, 1, 0, -50378, 2259, 0, 0, 39, '2258'),
	(377, 1, 0, -50378, 2260, 0, 0, 39, '2259'),
	(377, 1, 0, -50378, 2261, 0, 0, 39, '2260'),
	(377, 1, 0, -50378, 2262, 0, 0, 39, '2261'),
	(377, 1, 0, -50378, 2263, 0, 0, 39, '2262'),
	(377, 1, 0, -50378, 2264, 0, 0, 39, '2263'),
	(377, 1, 0, -50378, 2265, 0, 0, 39, '2264'),
	(377, 1, 0, -50378, 2266, 0, 0, 39, '2265'),
	(377, 1, 0, -50378, 2267, 0, 0, 39, '2266'),
	(377, 1, 0, -50378, 2268, 0, 0, 39, '2267'),
	(377, 1, 0, -50378, 2269, 0, 0, 39, '2268'),
	(377, 1, 0, -50378, 2270, 0, 0, 39, '2269'),
	(377, 1, 0, -50378, 2271, 0, 0, 39, '2270'),
	(377, 1, 0, -50378, 2272, 0, 0, 39, '2271'),
	(377, 1, 0, -50378, 2273, 0, 0, 39, '2272'),
	(377, 1, 0, -50378, 2274, 0, 0, 39, '2273'),
	(377, 1, 0, -50378, 2275, 0, 0, 39, '2274'),
	(377, 1, 0, -50378, 2276, 0, 0, 39, '2275'),
	(377, 1, 0, -50378, 2277, 0, 0, 39, '2276'),
	(377, 1, 0, -50378, 2278, 0, 0, 39, '2277'),
	(377, 1, 0, -50378, 2279, 0, 0, 39, '2278'),
	(377, 1, 0, -50378, 2280, 0, 0, 39, '2279'),
	(377, 1, 0, -50378, 2281, 0, 0, 39, '2280'),
	(377, 1, 0, -50378, 2282, 0, 0, 39, '2281'),
	(377, 1, 0, -50378, 2283, 0, 0, 39, '2282'),
	(377, 1, 0, -50378, 2284, 0, 0, 39, '2283'),
	(377, 1, 0, -50378, 2285, 0, 0, 39, '2284'),
	(377, 1, 0, -50378, 2286, 0, 0, 39, '2285'),
	(377, 1, 0, -50378, 2287, 0, 0, 39, '2286'),
	(377, 1, 0, -50378, 2288, 0, 0, 39, '2287'),
	(377, 1, 0, -50378, 2289, 0, 0, 39, '2288'),
	(377, 1, 0, -50378, 2290, 0, 0, 39, '2289'),
	(377, 1, 0, -50378, 2291, 0, 0, 39, '2290'),
	(377, 1, 0, -50378, 2292, 0, 0, 39, '2291'),
	(377, 1, 0, -50378, 2293, 0, 0, 39, '2292'),
	(377, 1, 0, -50378, 2294, 0, 0, 39, '2293'),
	(377, 1, 0, -50378, 2295, 0, 0, 39, '2294'),
	(377, 1, 0, -50378, 2296, 0, 0, 39, '2295'),
	(377, 1, 0, -50378, 2297, 0, 0, 39, '2296'),
	(377, 1, 0, -50378, 2298, 0, 0, 39, '2297'),
	(377, 1, 0, -50378, 2299, 0, 0, 39, '2298'),
	(377, 1, 0, -50378, 2300, 0, 0, 39, '2299'),
	(377, 1, 0, -50378, 2301, 0, 0, 39, '2300'),
	(377, 1, 0, -50378, 2302, 0, 0, 39, '2301'),
	(377, 1, 0, -50378, 2303, 0, 0, 39, '2302'),
	(377, 1, 0, -50378, 2304, 0, 0, 39, '2303'),
	(377, 1, 0, -50378, 2305, 0, 0, 39, '2304'),
	(377, 1, 0, -50378, 2306, 0, 0, 39, '2305'),
	(377, 1, 0, -50378, 2307, 0, 0, 39, '2306'),
	(377, 1, 0, -50378, 2308, 0, 0, 39, '2307'),
	(377, 1, 0, -50378, 2309, 0, 0, 39, '2308'),
	(377, 1, 0, -50378, 2310, 0, 0, 39, '2309'),
	(377, 1, 0, -50378, 2311, 0, 0, 39, '2310'),
	(377, 1, 0, -50378, 2312, 0, 0, 39, '2311'),
	(377, 1, 0, -50378, 2313, 0, 0, 39, '2312'),
	(377, 1, 0, -50378, 2314, 0, 0, 39, '2313'),
	(377, 1, 0, -50378, 2315, 0, 0, 39, '2314'),
	(377, 1, 0, -50378, 2316, 0, 0, 39, '2315'),
	(377, 1, 0, -50378, 2317, 0, 0, 39, '2316'),
	(377, 1, 0, -50378, 2318, 0, 0, 39, '2317'),
	(377, 1, 0, -50378, 2319, 0, 0, 39, '2318'),
	(377, 1, 0, -50378, 2320, 0, 0, 39, '2319'),
	(377, 1, 0, -50378, 2321, 0, 0, 39, '2320'),
	(377, 1, 0, -50378, 2322, 0, 0, 39, '2321'),
	(377, 1, 0, -50378, 2323, 0, 0, 39, '2322'),
	(377, 1, 0, -50378, 2324, 0, 0, 39, '2323'),
	(377, 1, 0, -50378, 2325, 0, 0, 39, '2324'),
	(377, 1, 0, -50378, 2326, 0, 0, 39, '2325'),
	(377, 1, 0, -50378, 2327, 0, 0, 39, '2326'),
	(377, 1, 0, -50378, 2328, 0, 0, 39, '2327'),
	(377, 1, 0, -50378, 2329, 0, 0, 39, '2328'),
	(377, 1, 0, -50378, 2330, 0, 0, 39, '2329'),
	(377, 1, 0, -50378, 2331, 0, 0, 39, '2330'),
	(377, 1, 0, -50378, 2332, 0, 0, 39, '2331'),
	(377, 1, 0, -50378, 2333, 0, 0, 39, '2332'),
	(377, 1, 0, -50378, 2334, 0, 0, 39, '2333'),
	(377, 1, 0, -50378, 2335, 0, 0, 39, '2334'),
	(377, 1, 0, -50378, 2336, 0, 0, 39, '2335'),
	(377, 1, 0, -50378, 2337, 0, 0, 39, '2336'),
	(377, 1, 0, -50378, 2338, 0, 0, 39, '2337'),
	(377, 1, 0, -50378, 2339, 0, 0, 39, '2338'),
	(377, 1, 0, -50378, 2340, 0, 0, 39, '2339'),
	(377, 1, 0, -50378, 2341, 0, 0, 39, '2340'),
	(377, 1, 0, -50378, 2342, 0, 0, 39, '2341'),
	(377, 1, 0, -50378, 2343, 0, 0, 39, '2342'),
	(377, 1, 0, -50378, 2344, 0, 0, 39, '2343'),
	(377, 1, 0, -50378, 2345, 0, 0, 39, '2344'),
	(377, 1, 0, -50378, 2346, 0, 0, 39, '2345'),
	(377, 1, 0, -50378, 2347, 0, 0, 39, '2346'),
	(377, 1, 0, -50378, 2348, 0, 0, 39, '2347'),
	(377, 1, 0, -50378, 2349, 0, 0, 39, '2348'),
	(377, 1, 0, -50378, 2350, 0, 0, 39, '2349'),
	(377, 1, 0, -50378, 2351, 0, 0, 39, '2350'),
	(377, 1, 0, -50378, 2352, 0, 0, 39, '2351'),
	(377, 1, 0, -50378, 2353, 0, 0, 39, '2352'),
	(377, 1, 0, -50378, 2354, 0, 0, 39, '2353'),
	(377, 1, 0, -50378, 2355, 0, 0, 39, '2354'),
	(377, 1, 0, -50378, 2356, 0, 0, 39, '2355'),
	(377, 1, 0, -50378, 2357, 0, 0, 39, '2356'),
	(377, 1, 0, -50378, 2358, 0, 0, 39, '2357'),
	(377, 1, 0, -50378, 2359, 0, 0, 39, '2358'),
	(377, 1, 0, -50378, 2360, 0, 0, 39, '2359'),
	(377, 1, 0, -50378, 2361, 0, 0, 39, '2360'),
	(377, 1, 0, -50378, 2362, 0, 0, 39, '2361'),
	(377, 1, 0, -50378, 2363, 0, 0, 39, '2362'),
	(377, 1, 0, -50378, 2364, 0, 0, 39, '2363'),
	(377, 1, 0, -50378, 2365, 0, 0, 39, '2364'),
	(377, 1, 0, -50378, 2366, 0, 0, 39, '2365'),
	(377, 1, 0, -50378, 2367, 0, 0, 39, '2366'),
	(377, 1, 0, -50378, 2368, 0, 0, 39, '2367'),
	(377, 1, 0, -50378, 2369, 0, 0, 39, '2368'),
	(377, 1, 0, -50378, 2370, 0, 0, 39, '2369'),
	(377, 1, 0, -50378, 2371, 0, 0, 39, '2370'),
	(377, 1, 0, -50378, 2372, 0, 0, 39, '2371'),
	(377, 1, 0, -50378, 2373, 0, 0, 39, '2372'),
	(377, 1, 0, -50378, 2374, 0, 0, 39, '2373'),
	(377, 1, 0, -50378, 2375, 0, 0, 39, '2374'),
	(377, 1, 0, -50378, 2376, 0, 0, 39, '2375'),
	(377, 1, 0, -50378, 2377, 0, 0, 39, '2376'),
	(377, 1, 0, -50378, 2378, 0, 0, 39, '2377'),
	(377, 1, 0, -50378, 2379, 0, 0, 39, '2378'),
	(377, 1, 0, -50378, 2380, 0, 0, 39, '2379'),
	(377, 1, 0, -50378, 2381, 0, 0, 39, '2380'),
	(377, 1, 0, -50378, 2382, 0, 0, 39, '2381'),
	(377, 1, 0, -50378, 2383, 0, 0, 39, '2382'),
	(377, 1, 0, -50378, 2384, 0, 0, 39, '2383'),
	(377, 1, 0, -50378, 2385, 0, 0, 39, '2384'),
	(377, 1, 0, -50378, 2386, 0, 0, 39, '2385'),
	(377, 1, 0, -50378, 2387, 0, 0, 39, '2386'),
	(377, 1, 0, -50378, 2388, 0, 0, 39, '2387'),
	(377, 1, 0, -50378, 2389, 0, 0, 39, '2388'),
	(377, 1, 0, -50378, 2390, 0, 0, 39, '2389'),
	(377, 1, 0, -50378, 2391, 0, 0, 39, '2390'),
	(377, 1, 0, -50378, 2392, 0, 0, 39, '2391'),
	(377, 1, 0, -50378, 2393, 0, 0, 39, '2392'),
	(377, 1, 0, -50378, 2394, 0, 0, 39, '2393'),
	(377, 1, 0, -50378, 2395, 0, 0, 39, '2394'),
	(377, 1, 0, -50378, 2396, 0, 0, 39, '2395'),
	(377, 1, 0, -50378, 2397, 0, 0, 39, '2396'),
	(377, 1, 0, -50378, 2398, 0, 0, 39, '2397'),
	(377, 1, 0, -50378, 2399, 0, 0, 39, '2398'),
	(377, 1, 0, -50378, 2400, 0, 0, 39, '2399'),
	(377, 1, 0, -50378, 2401, 0, 0, 39, '2400'),
	(377, 1, 0, -50378, 2402, 0, 0, 39, '2401'),
	(377, 1, 0, -50378, 2403, 0, 0, 39, '2402'),
	(377, 1, 0, -50378, 2404, 0, 0, 39, '2403'),
	(377, 1, 0, -50378, 2405, 0, 0, 39, '2404'),
	(377, 1, 0, -50378, 2406, 0, 0, 39, '2405'),
	(377, 1, 0, -50378, 2407, 0, 0, 39, '2406'),
	(377, 1, 0, -50378, 2408, 0, 0, 39, '2407'),
	(377, 1, 0, -50378, 2409, 0, 0, 39, '2408'),
	(377, 1, 0, -50378, 2410, 0, 0, 39, '2409'),
	(377, 1, 0, -50378, 2411, 0, 0, 39, '2410'),
	(377, 1, 0, -50378, 2412, 0, 0, 39, '2411'),
	(377, 1, 0, -50378, 2413, 0, 0, 39, '2412'),
	(377, 1, 0, -50378, 2414, 0, 0, 39, '2413'),
	(377, 1, 0, -50378, 2415, 0, 0, 39, '2414'),
	(377, 1, 0, -50378, 2416, 0, 0, 39, '2415'),
	(377, 1, 0, -50378, 2417, 0, 0, 39, '2416'),
	(377, 1, 0, -50378, 2418, 0, 0, 39, '2417'),
	(377, 1, 0, -50378, 2419, 0, 0, 39, '2418'),
	(377, 1, 0, -50378, 2420, 0, 0, 39, '2419'),
	(377, 1, 0, -50378, 2421, 0, 0, 39, '2420'),
	(377, 1, 0, -50378, 2422, 0, 0, 39, '2421'),
	(377, 1, 0, -50378, 2423, 0, 0, 39, '2422'),
	(377, 1, 0, -50378, 2424, 0, 0, 39, '2423'),
	(377, 1, 0, -50378, 2425, 0, 0, 39, '2424'),
	(377, 1, 0, -50378, 2426, 0, 0, 39, '2425'),
	(377, 1, 0, -50378, 2427, 0, 0, 39, '2426'),
	(377, 1, 0, -50378, 2428, 0, 0, 39, '2427'),
	(377, 1, 0, -50378, 2429, 0, 0, 39, '2428'),
	(377, 1, 0, -50378, 2430, 0, 0, 39, '2429'),
	(377, 1, 0, -50378, 2431, 0, 0, 39, '2430'),
	(377, 1, 0, -50378, 2432, 0, 0, 39, '2431'),
	(377, 1, 0, -50378, 2433, 0, 0, 39, '2432'),
	(377, 1, 0, -50378, 2434, 0, 0, 39, '2433'),
	(377, 1, 0, -50378, 2435, 0, 0, 39, '2434'),
	(377, 1, 0, -50378, 2436, 0, 0, 39, '2435'),
	(377, 1, 0, -50378, 2437, 0, 0, 39, '2436'),
	(377, 1, 0, -50378, 2438, 0, 0, 39, '2437'),
	(377, 1, 0, -50378, 2439, 0, 0, 39, '2438'),
	(377, 1, 0, -50378, 2440, 0, 0, 39, '2439'),
	(377, 1, 0, -50378, 2441, 0, 0, 39, '2440'),
	(377, 1, 0, -50378, 2442, 0, 0, 39, '2441'),
	(377, 1, 0, -50378, 2443, 0, 0, 39, '2442'),
	(377, 1, 0, -50378, 2444, 0, 0, 39, '2443'),
	(377, 1, 0, -50378, 2445, 0, 0, 39, '2444'),
	(377, 1, 0, -50378, 2446, 0, 0, 39, '2445'),
	(377, 1, 0, -50378, 2447, 0, 0, 39, '2446'),
	(377, 1, 0, -50378, 2448, 0, 0, 39, '2447'),
	(377, 1, 0, -50378, 2449, 0, 0, 39, '2448'),
	(377, 1, 0, -50378, 2450, 0, 0, 39, '2449'),
	(377, 1, 0, -50378, 2451, 0, 0, 39, '2450'),
	(377, 1, 0, -50378, 2452, 0, 0, 39, '2451'),
	(377, 1, 0, -50378, 2453, 0, 0, 39, '2452'),
	(377, 1, 0, -50378, 2454, 0, 0, 39, '2453'),
	(377, 1, 0, -50378, 2455, 0, 0, 39, '2454'),
	(377, 1, 0, -50378, 2456, 0, 0, 39, '2455'),
	(377, 1, 0, -50378, 2457, 0, 0, 39, '2456'),
	(377, 1, 0, -50378, 2458, 0, 0, 39, '2457'),
	(377, 1, 0, -50378, 2459, 0, 0, 39, '2458'),
	(377, 1, 0, -50378, 2460, 0, 0, 39, '2459'),
	(377, 1, 0, -50378, 2461, 0, 0, 39, '2460'),
	(377, 1, 0, -50378, 2462, 0, 0, 39, '2461'),
	(377, 1, 0, -50378, 2463, 0, 0, 39, '2462'),
	(377, 1, 0, -50378, 2464, 0, 0, 39, '2463'),
	(377, 1, 0, -50378, 2465, 0, 0, 39, '2464'),
	(377, 1, 0, -50378, 2466, 0, 0, 39, '2465'),
	(377, 1, 0, -50378, 2467, 0, 0, 39, '2466'),
	(377, 1, 0, -50378, 2468, 0, 0, 39, '2467'),
	(377, 1, 0, -50378, 2469, 0, 0, 39, '2468'),
	(377, 1, 0, -50378, 2470, 0, 0, 39, '2469'),
	(377, 1, 0, -50378, 2471, 0, 0, 39, '2470'),
	(377, 1, 0, -50378, 2472, 0, 0, 39, '2471'),
	(377, 1, 0, -50378, 2473, 0, 0, 39, '2472'),
	(377, 1, 0, -50378, 2474, 0, 0, 39, '2473'),
	(377, 1, 0, -50378, 2475, 0, 0, 39, '2474'),
	(377, 1, 0, -50378, 2476, 0, 0, 39, '2475'),
	(377, 1, 0, -50378, 2477, 0, 0, 39, '2476'),
	(377, 1, 0, -50378, 2478, 0, 0, 39, '2477'),
	(377, 1, 0, -50378, 2479, 0, 0, 39, '2478'),
	(377, 1, 0, -50378, 2480, 0, 0, 39, '2479'),
	(377, 1, 0, -50378, 2481, 0, 0, 39, '2480'),
	(377, 1, 0, -50378, 2482, 0, 0, 39, '2481'),
	(377, 1, 0, -50378, 2483, 0, 0, 39, '2482'),
	(377, 1, 0, -50378, 2484, 0, 0, 39, '2483'),
	(377, 1, 0, -50378, 2485, 0, 0, 39, '2484'),
	(377, 1, 0, -50378, 2486, 0, 0, 39, '2485'),
	(377, 1, 0, -50378, 2487, 0, 0, 39, '2486'),
	(377, 1, 0, -50378, 2488, 0, 0, 39, '2487'),
	(377, 1, 0, -50378, 2489, 0, 0, 39, '2488'),
	(377, 1, 0, -50378, 2490, 0, 0, 39, '2489'),
	(377, 1, 0, -50378, 2491, 0, 0, 39, '2490'),
	(377, 1, 0, -50378, 2492, 0, 0, 39, '2491'),
	(377, 1, 0, -50378, 2493, 0, 0, 39, '2492'),
	(377, 1, 0, -50378, 2494, 0, 0, 39, '2493'),
	(377, 1, 0, -50378, 2495, 0, 0, 39, '2494'),
	(377, 1, 0, -50378, 2496, 0, 0, 39, '2495'),
	(377, 1, 0, -50378, 2497, 0, 0, 39, '2496'),
	(377, 1, 0, -50378, 2498, 0, 0, 39, '2497'),
	(377, 1, 0, -50378, 2499, 0, 0, 39, '2498'),
	(377, 1, 0, -50378, 2500, 0, 0, 39, '2499'),
	(377, 1, 0, -50378, 2501, 0, 0, 39, '2500'),
	(377, 1, 0, -50378, 2502, 0, 0, 39, '2501'),
	(377, 1, 0, -50378, 2503, 0, 0, 39, '2502'),
	(377, 1, 0, -50378, 2504, 0, 0, 39, '2503'),
	(377, 1, 0, -50378, 2505, 0, 0, 39, '2504'),
	(377, 1, 0, -50378, 2506, 0, 0, 39, '2505'),
	(377, 1, 0, -50378, 2507, 0, 0, 39, '2506'),
	(377, 1, 0, -50378, 2508, 0, 0, 39, '2507'),
	(377, 1, 0, -50378, 2509, 0, 0, 39, '2508'),
	(377, 1, 0, -50378, 2510, 0, 0, 39, '2509'),
	(377, 1, 0, -50378, 2511, 0, 0, 39, '2510'),
	(377, 1, 0, -50378, 2512, 0, 0, 39, '2511'),
	(377, 1, 0, -50378, 2513, 0, 0, 39, '2512'),
	(377, 1, 0, -50378, 2514, 0, 0, 39, '2513'),
	(377, 1, 0, -50378, 2515, 0, 0, 39, '2514'),
	(377, 1, 0, -50378, 2516, 0, 0, 39, '2515'),
	(377, 1, 0, -50378, 2517, 0, 0, 39, '2516'),
	(377, 1, 0, -50378, 2518, 0, 0, 39, '2517'),
	(377, 1, 0, -50378, 2519, 0, 0, 39, '2518'),
	(377, 1, 0, -50378, 2520, 0, 0, 39, '2519'),
	(377, 1, 0, -50378, 2521, 0, 0, 39, '2520'),
	(377, 1, 0, -50378, 2522, 0, 0, 39, '2521'),
	(377, 1, 0, -50378, 2523, 0, 0, 39, '2522'),
	(377, 1, 0, -50378, 2524, 0, 0, 39, '2523'),
	(377, 1, 0, -50378, 2525, 0, 0, 39, '2524'),
	(377, 1, 0, -50378, 2526, 0, 0, 39, '2525'),
	(377, 1, 0, -50378, 2527, 0, 0, 39, '2526'),
	(377, 1, 0, -50378, 2528, 0, 0, 39, '2527'),
	(377, 1, 0, -50378, 2529, 0, 0, 39, '2528'),
	(377, 1, 0, -50378, 2530, 0, 0, 39, '2529'),
	(377, 1, 0, -50378, 2531, 0, 0, 39, '2530'),
	(377, 1, 0, -50378, 2532, 0, 0, 39, '2531'),
	(377, 1, 0, -50378, 2533, 0, 0, 39, '2532'),
	(377, 1, 0, -50378, 2534, 0, 0, 39, '2533'),
	(377, 1, 0, -50378, 2535, 0, 0, 39, '2534'),
	(377, 1, 0, -50378, 2536, 0, 0, 39, '2535'),
	(377, 1, 0, -50378, 2537, 0, 0, 39, '2536'),
	(377, 1, 0, -50378, 2538, 0, 0, 39, '2537'),
	(377, 1, 0, -50378, 2539, 0, 0, 39, '2538'),
	(377, 1, 0, -50378, 2540, 0, 0, 39, '2539'),
	(377, 1, 0, -50378, 2541, 0, 0, 39, '2540'),
	(377, 1, 0, -50378, 2542, 0, 0, 39, '2541'),
	(377, 1, 0, -50378, 2543, 0, 0, 39, '2542'),
	(377, 1, 0, -50378, 2544, 0, 0, 39, '2543'),
	(377, 1, 0, -50378, 2545, 0, 0, 39, '2544'),
	(377, 1, 0, -50378, 2546, 0, 0, 39, '2545'),
	(377, 1, 0, -50378, 2547, 0, 0, 39, '2546'),
	(377, 1, 0, -50378, 2548, 0, 0, 39, '2547'),
	(377, 1, 0, -50378, 2549, 0, 0, 39, '2548'),
	(377, 1, 0, -50378, 2550, 0, 0, 39, '2549'),
	(377, 1, 0, -50378, 2551, 0, 0, 39, '2550'),
	(377, 1, 0, -50378, 2552, 0, 0, 39, '2551'),
	(377, 1, 0, -50378, 2553, 0, 0, 39, '2552'),
	(377, 1, 0, -50378, 2554, 0, 0, 39, '2553'),
	(377, 1, 0, -50378, 2555, 0, 0, 39, '2554'),
	(377, 1, 0, -50378, 2556, 0, 0, 39, '2555'),
	(377, 1, 0, -50378, 2557, 0, 0, 39, '2556'),
	(377, 1, 0, -50378, 2558, 0, 0, 39, '2557'),
	(377, 1, 0, -50378, 2559, 0, 0, 39, '2558'),
	(377, 1, 0, -50378, 2560, 0, 0, 39, '2559'),
	(377, 1, 0, -50378, 2561, 0, 0, 39, '2560'),
	(377, 1, 0, -50378, 2562, 0, 0, 39, '2561'),
	(377, 1, 0, -50378, 2563, 0, 0, 39, '2562'),
	(377, 1, 0, -50378, 2564, 0, 0, 39, '2563'),
	(377, 1, 0, -50378, 2565, 0, 0, 39, '2564'),
	(377, 1, 0, -50378, 2566, 0, 0, 39, '2565'),
	(377, 1, 0, -50378, 2567, 0, 0, 39, '2566'),
	(377, 1, 0, -50378, 2568, 0, 0, 39, '2567'),
	(377, 1, 0, -50378, 2569, 0, 0, 39, '2568'),
	(377, 1, 0, -50378, 2570, 0, 0, 39, '2569'),
	(377, 1, 0, -50378, 2571, 0, 0, 39, '2570'),
	(377, 1, 0, -50378, 2572, 0, 0, 39, '2571'),
	(377, 1, 0, -50378, 2573, 0, 0, 39, '2572'),
	(377, 1, 0, -50378, 2574, 0, 0, 39, '2573'),
	(377, 1, 0, -50378, 2575, 0, 0, 39, '2574'),
	(377, 1, 0, -50378, 2576, 0, 0, 39, '2575'),
	(377, 1, 0, -50378, 2577, 0, 0, 39, '2576'),
	(377, 1, 0, -50378, 2578, 0, 0, 39, '2577'),
	(377, 1, 0, -50378, 2579, 0, 0, 39, '2578'),
	(377, 1, 0, -50378, 2580, 0, 0, 39, '2579'),
	(377, 1, 0, -50378, 2581, 0, 0, 39, '2580'),
	(377, 1, 0, -50378, 2582, 0, 0, 39, '2581'),
	(377, 1, 0, -50378, 2583, 0, 0, 39, '2582'),
	(377, 1, 0, -50378, 2584, 0, 0, 39, '2583'),
	(377, 1, 0, -50378, 2585, 0, 0, 39, '2584'),
	(377, 1, 0, -50378, 2586, 0, 0, 39, '2585'),
	(377, 1, 0, -50378, 2587, 0, 0, 39, '2586'),
	(377, 1, 0, -50378, 2588, 0, 0, 39, '2587'),
	(377, 1, 0, -50378, 2589, 0, 0, 39, '2588'),
	(377, 1, 0, -50378, 2590, 0, 0, 39, '2589'),
	(377, 1, 0, -50378, 2591, 0, 0, 39, '2590'),
	(377, 1, 0, -50378, 2592, 0, 0, 39, '2591'),
	(377, 1, 0, -50378, 2593, 0, 0, 39, '2592'),
	(377, 1, 0, -50378, 2594, 0, 0, 39, '2593'),
	(377, 1, 0, -50378, 2595, 0, 0, 39, '2594'),
	(377, 1, 0, -50378, 2596, 0, 0, 39, '2595'),
	(377, 1, 0, -50378, 2597, 0, 0, 39, '2596'),
	(377, 1, 0, -50378, 2598, 0, 0, 39, '2597'),
	(377, 1, 0, -50378, 2599, 0, 0, 39, '2598'),
	(377, 1, 0, -50378, 2600, 0, 0, 39, '2599'),
	(377, 1, 0, -50378, 2601, 0, 0, 39, '2600'),
	(377, 1, 0, -50378, 2602, 0, 0, 39, '2601'),
	(377, 1, 0, -50378, 2603, 0, 0, 39, '2602'),
	(377, 1, 0, -50378, 2604, 0, 0, 39, '2603'),
	(377, 1, 0, -50378, 2605, 0, 0, 39, '2604'),
	(377, 1, 0, -50378, 2606, 0, 0, 39, '2605'),
	(377, 1, 0, -50378, 2607, 0, 0, 39, '2606'),
	(377, 1, 0, -50378, 2608, 0, 0, 39, '2607'),
	(377, 1, 0, -50378, 2609, 0, 0, 39, '2608'),
	(377, 1, 0, -50378, 2610, 0, 0, 39, '2609'),
	(377, 1, 0, -50378, 2611, 0, 0, 39, '2610'),
	(377, 1, 0, -50378, 2612, 0, 0, 39, '2611'),
	(377, 1, 0, -50378, 2613, 0, 0, 39, '2612'),
	(377, 1, 0, -50378, 2614, 0, 0, 39, '2613'),
	(377, 1, 0, -50378, 2615, 0, 0, 39, '2614'),
	(377, 1, 0, -50378, 2616, 0, 0, 39, '2615'),
	(377, 1, 0, -50378, 2617, 0, 0, 39, '2616'),
	(377, 1, 0, -50378, 2618, 0, 0, 39, '2617'),
	(377, 1, 0, -50378, 2619, 0, 0, 39, '2618'),
	(377, 1, 0, -50378, 2620, 0, 0, 39, '2619'),
	(377, 1, 0, -50378, 2621, 0, 0, 39, '2620'),
	(377, 1, 0, -50378, 2622, 0, 0, 39, '2621'),
	(377, 1, 0, -50378, 2623, 0, 0, 39, '2622'),
	(377, 1, 0, -50378, 2624, 0, 0, 39, '2623'),
	(377, 1, 0, -50378, 2625, 0, 0, 39, '2624'),
	(377, 1, 0, -50378, 2626, 0, 0, 39, '2625'),
	(377, 1, 0, -50378, 2627, 0, 0, 39, '2626'),
	(377, 1, 0, -50378, 2628, 0, 0, 39, '2627'),
	(377, 1, 0, -50378, 2629, 0, 0, 39, '2628'),
	(377, 1, 0, -50378, 2630, 0, 0, 39, '2629'),
	(377, 1, 0, -50378, 2631, 0, 0, 39, '2630'),
	(377, 1, 0, -50378, 2632, 0, 0, 39, '2631'),
	(377, 1, 0, -50378, 2633, 0, 0, 39, '2632'),
	(377, 1, 0, -50378, 2634, 0, 0, 39, '2633'),
	(377, 1, 0, -50378, 2635, 0, 0, 39, '2634'),
	(377, 1, 0, -50378, 2636, 0, 0, 39, '2635'),
	(377, 1, 0, -50378, 2637, 0, 0, 39, '2636'),
	(377, 1, 0, -50378, 2638, 0, 0, 39, '2637'),
	(377, 1, 0, -50378, 2639, 0, 0, 39, '2638'),
	(377, 1, 0, -50378, 2640, 0, 0, 39, '2639'),
	(377, 1, 0, -50378, 2641, 0, 0, 39, '2640'),
	(377, 1, 0, -50378, 2642, 0, 0, 39, '2641'),
	(377, 1, 0, -50378, 2643, 0, 0, 39, '2642'),
	(377, 1, 0, -50378, 2644, 0, 0, 39, '2643'),
	(377, 1, 0, -50378, 2645, 0, 0, 39, '2644'),
	(377, 1, 0, -50378, 2646, 0, 0, 39, '2645'),
	(377, 1, 0, -50378, 2647, 0, 0, 39, '2646'),
	(377, 1, 0, -50378, 2648, 0, 0, 39, '2647'),
	(377, 1, 0, -50378, 2649, 0, 0, 39, '2648'),
	(377, 1, 0, -50378, 2650, 0, 0, 39, '2649'),
	(377, 1, 0, -50378, 2651, 0, 0, 39, '2650'),
	(377, 1, 0, -50378, 2652, 0, 0, 39, '2651'),
	(377, 1, 0, -50378, 2653, 0, 0, 39, '2652'),
	(377, 1, 0, -50378, 2654, 0, 0, 39, '2653'),
	(377, 1, 0, -50378, 2655, 0, 0, 39, '2654'),
	(377, 1, 0, -50378, 2656, 0, 0, 39, '2655'),
	(377, 1, 0, -50378, 2657, 0, 0, 39, '2656'),
	(377, 1, 0, -50378, 2658, 0, 0, 39, '2657'),
	(377, 1, 0, -50378, 2659, 0, 0, 39, '2658'),
	(377, 1, 0, -50378, 2660, 0, 0, 39, '2659'),
	(377, 1, 0, -50378, 2661, 0, 0, 39, '2660'),
	(377, 1, 0, -50378, 2662, 0, 0, 39, '2661'),
	(377, 1, 0, -50378, 2663, 0, 0, 39, '2662'),
	(377, 1, 0, -50378, 2664, 0, 0, 39, '2663'),
	(377, 1, 0, -50378, 2665, 0, 0, 39, '2664'),
	(377, 1, 0, -50378, 2666, 0, 0, 39, '2665'),
	(377, 1, 0, -50378, 2667, 0, 0, 39, '2666'),
	(377, 1, 0, -50378, 2668, 0, 0, 39, '2667'),
	(377, 1, 0, -50378, 2669, 0, 0, 39, '2668'),
	(377, 1, 0, -50378, 2670, 0, 0, 39, '2669'),
	(377, 1, 0, -50378, 2671, 0, 0, 39, '2670'),
	(377, 1, 0, -50378, 2672, 0, 0, 39, '2671'),
	(377, 1, 0, -50378, 2673, 0, 0, 39, '2672'),
	(377, 1, 0, -50378, 2674, 0, 0, 39, '2673'),
	(377, 1, 0, -50378, 2675, 0, 0, 39, '2674'),
	(377, 1, 0, -50378, 2676, 0, 0, 39, '2675'),
	(377, 1, 0, -50378, 2677, 0, 0, 39, '2676'),
	(377, 1, 0, -50378, 2678, 0, 0, 39, '2677'),
	(377, 1, 0, -50378, 2679, 0, 0, 39, '2678'),
	(377, 1, 0, -50378, 2680, 0, 0, 39, '2679'),
	(377, 1, 0, -50378, 2681, 0, 0, 39, '2680'),
	(377, 1, 0, -50378, 2682, 0, 0, 39, '2681'),
	(377, 1, 0, -50378, 2683, 0, 0, 39, '2682'),
	(377, 1, 0, -50378, 2684, 0, 0, 39, '2683'),
	(377, 1, 0, -50378, 2685, 0, 0, 39, '2684'),
	(377, 1, 0, -50378, 2686, 0, 0, 39, '2685'),
	(377, 1, 0, -50378, 2687, 0, 0, 39, '2686'),
	(377, 1, 0, -50378, 2688, 0, 0, 39, '2687'),
	(377, 1, 0, -50378, 2689, 0, 0, 39, '2688'),
	(377, 1, 0, -50378, 2690, 0, 0, 39, '2689'),
	(377, 1, 0, -50378, 2691, 0, 0, 39, '2690'),
	(377, 1, 0, -50378, 2692, 0, 0, 39, '2691'),
	(377, 1, 0, -50378, 2693, 0, 0, 39, '2692'),
	(377, 1, 0, -50378, 2694, 0, 0, 39, '2693'),
	(377, 1, 0, -50378, 2695, 0, 0, 39, '2694'),
	(377, 1, 0, -50378, 2696, 0, 0, 39, '2695'),
	(377, 1, 0, -50378, 2697, 0, 0, 39, '2696'),
	(377, 1, 0, -50378, 2698, 0, 0, 39, '2697'),
	(377, 1, 0, -50378, 2699, 0, 0, 39, '2698'),
	(377, 1, 0, -50378, 2700, 0, 0, 39, '2699'),
	(377, 1, 0, -50378, 2701, 0, 0, 39, '2700'),
	(377, 1, 0, -50378, 2702, 0, 0, 39, '2701'),
	(377, 1, 0, -50378, 2703, 0, 0, 39, '2702'),
	(377, 1, 0, -50378, 2704, 0, 0, 39, '2703'),
	(377, 1, 0, -50378, 2705, 0, 0, 39, '2704'),
	(377, 1, 0, -50378, 2706, 0, 0, 39, '2705'),
	(377, 1, 0, -50378, 2707, 0, 0, 39, '2706'),
	(377, 1, 0, -50378, 2708, 0, 0, 39, '2707'),
	(377, 1, 0, -50378, 2709, 0, 0, 39, '2708'),
	(377, 1, 0, -50378, 2710, 0, 0, 39, '2709'),
	(377, 1, 0, -50378, 2711, 0, 0, 39, '2710'),
	(377, 1, 0, -50378, 2712, 0, 0, 39, '2711'),
	(377, 1, 0, -50378, 2713, 0, 0, 39, '2712'),
	(377, 1, 0, -50378, 2714, 0, 0, 39, '2713'),
	(377, 1, 0, -50378, 2715, 0, 0, 39, '2714'),
	(377, 1, 0, -50378, 2716, 0, 0, 39, '2715'),
	(377, 1, 0, -50378, 2717, 0, 0, 39, '2716'),
	(377, 1, 0, -50378, 2718, 0, 0, 39, '2717'),
	(377, 1, 0, -50378, 2719, 0, 0, 39, '2718'),
	(377, 1, 0, -50378, 2720, 0, 0, 39, '2719'),
	(377, 1, 0, -50378, 2721, 0, 0, 39, '2720'),
	(377, 1, 0, -50378, 2722, 0, 0, 39, '2721'),
	(377, 1, 0, -50378, 2723, 0, 0, 39, '2722'),
	(377, 1, 0, -50378, 2724, 0, 0, 39, '2723'),
	(377, 1, 0, -50378, 2725, 0, 0, 39, '2724'),
	(377, 1, 0, -50378, 2726, 0, 0, 39, '2725'),
	(377, 1, 0, -50378, 2727, 0, 0, 39, '2726'),
	(377, 1, 0, -50378, 2728, 0, 0, 39, '2727'),
	(377, 1, 0, -50378, 2729, 0, 0, 39, '2728'),
	(377, 1, 0, -50378, 2730, 0, 0, 39, '2729'),
	(377, 1, 0, -50378, 2731, 0, 0, 39, '2730'),
	(377, 1, 0, -50378, 2732, 0, 0, 39, '2731'),
	(377, 1, 0, -50378, 2733, 0, 0, 39, '2732'),
	(377, 1, 0, -50378, 2734, 0, 0, 39, '2733'),
	(377, 1, 0, -50378, 2735, 0, 0, 39, '2734'),
	(377, 1, 0, -50378, 2736, 0, 0, 39, '2735'),
	(377, 1, 0, -50378, 2737, 0, 0, 39, '2736'),
	(377, 1, 0, -50378, 2738, 0, 0, 39, '2737'),
	(377, 1, 0, -50378, 2739, 0, 0, 39, '2738'),
	(377, 1, 0, -50378, 2740, 0, 0, 39, '2739'),
	(377, 1, 0, -50378, 2741, 0, 0, 39, '2740'),
	(377, 1, 0, -50378, 2742, 0, 0, 39, '2741'),
	(377, 1, 0, -50378, 2743, 0, 0, 39, '2742'),
	(377, 1, 0, -50378, 2744, 0, 0, 39, '2743'),
	(377, 1, 0, -50378, 2745, 0, 0, 39, '2744'),
	(377, 1, 0, -50378, 2746, 0, 0, 39, '2745'),
	(377, 1, 0, -50378, 2747, 0, 0, 39, '2746'),
	(377, 1, 0, -50378, 2748, 0, 0, 39, '2747'),
	(377, 1, 0, -50378, 2749, 0, 0, 39, '2748'),
	(377, 1, 0, -50378, 2750, 0, 0, 39, '2749'),
	(377, 1, 0, -50378, 2751, 0, 0, 39, '2750'),
	(377, 1, 0, -50378, 2752, 0, 0, 39, '2751'),
	(377, 1, 0, -50378, 2753, 0, 0, 39, '2752'),
	(377, 1, 0, -50378, 2754, 0, 0, 39, '2753'),
	(377, 1, 0, -50378, 2755, 0, 0, 39, '2754'),
	(377, 1, 0, -50378, 2756, 0, 0, 39, '2755'),
	(377, 1, 0, -50378, 2757, 0, 0, 39, '2756'),
	(377, 1, 0, -50378, 2758, 0, 0, 39, '2757'),
	(377, 1, 0, -50378, 2759, 0, 0, 39, '2758'),
	(377, 1, 0, -50378, 2760, 0, 0, 39, '2759'),
	(377, 1, 0, -50378, 2761, 0, 0, 39, '2760'),
	(377, 1, 0, -50378, 2762, 0, 0, 39, '2761'),
	(377, 1, 0, -50378, 2763, 0, 0, 39, '2762'),
	(377, 1, 0, -50378, 2764, 0, 0, 39, '2763'),
	(377, 1, 0, -50378, 2765, 0, 0, 39, '2764'),
	(377, 1, 0, -50378, 2766, 0, 0, 39, '2765'),
	(377, 1, 0, -50378, 2767, 0, 0, 39, '2766'),
	(377, 1, 0, -50378, 2768, 0, 0, 39, '2767'),
	(377, 1, 0, -50378, 2769, 0, 0, 39, '2768'),
	(377, 1, 0, -50378, 2770, 0, 0, 39, '2769'),
	(377, 1, 0, -50378, 2771, 0, 0, 39, '2770'),
	(377, 1, 0, -50378, 2772, 0, 0, 39, '2771'),
	(377, 1, 0, -50378, 2773, 0, 0, 39, '2772'),
	(377, 1, 0, -50378, 2774, 0, 0, 39, '2773'),
	(377, 1, 0, -50378, 2775, 0, 0, 39, '2774'),
	(377, 1, 0, -50378, 2776, 0, 0, 39, '2775'),
	(377, 1, 0, -50378, 2777, 0, 0, 39, '2776'),
	(377, 1, 0, -50378, 2778, 0, 0, 39, '2777'),
	(377, 1, 0, -50378, 2779, 0, 0, 39, '2778'),
	(377, 1, 0, -50378, 2780, 0, 0, 39, '2779'),
	(377, 1, 0, -50378, 2781, 0, 0, 39, '2780'),
	(377, 1, 0, -50378, 2782, 0, 0, 39, '2781'),
	(377, 1, 0, -50378, 2783, 0, 0, 39, '2782'),
	(377, 1, 0, -50378, 2784, 0, 0, 39, '2783'),
	(377, 1, 0, -50378, 2785, 0, 0, 39, '2784'),
	(377, 1, 0, -50378, 2786, 0, 0, 39, '2785'),
	(377, 1, 0, -50378, 2787, 0, 0, 39, '2786'),
	(377, 1, 0, -50378, 2788, 0, 0, 39, '2787'),
	(377, 1, 0, -50378, 2789, 0, 0, 39, '2788'),
	(377, 1, 0, -50378, 2790, 0, 0, 39, '2789'),
	(377, 1, 0, -50378, 2791, 0, 0, 39, '2790'),
	(377, 1, 0, -50378, 2792, 0, 0, 39, '2791'),
	(377, 1, 0, -50378, 2793, 0, 0, 39, '2792'),
	(377, 1, 0, -50378, 2794, 0, 0, 39, '2793'),
	(377, 1, 0, -50378, 2795, 0, 0, 39, '2794'),
	(377, 1, 0, -50378, 2796, 0, 0, 39, '2795'),
	(377, 1, 0, -50378, 2797, 0, 0, 39, '2796'),
	(377, 1, 0, -50378, 2798, 0, 0, 39, '2797'),
	(377, 1, 0, -50378, 2799, 0, 0, 39, '2798'),
	(377, 1, 0, -50378, 2800, 0, 0, 39, '2799'),
	(377, 1, 0, -50378, 2801, 0, 0, 39, '2800'),
	(377, 1, 0, -50378, 2802, 0, 0, 39, '2801'),
	(377, 1, 0, -50378, 2803, 0, 0, 39, '2802'),
	(377, 1, 0, -50378, 2804, 0, 0, 39, '2803'),
	(377, 1, 0, -50378, 2805, 0, 0, 39, '2804'),
	(377, 1, 0, -50378, 2806, 0, 0, 39, '2805'),
	(377, 1, 0, -50378, 2807, 0, 0, 39, '2806'),
	(377, 1, 0, -50378, 2808, 0, 0, 39, '2807'),
	(377, 1, 0, -50378, 2809, 0, 0, 39, '2808'),
	(377, 1, 0, -50378, 2810, 0, 0, 39, '2809'),
	(377, 1, 0, -50378, 2811, 0, 0, 39, '2810'),
	(377, 1, 0, -50378, 2812, 0, 0, 39, '2811'),
	(377, 1, 0, -50378, 2813, 0, 0, 39, '2812'),
	(377, 1, 0, -50378, 2814, 0, 0, 39, '2813'),
	(377, 1, 0, -50378, 2815, 0, 0, 39, '2814'),
	(377, 1, 0, -50378, 2816, 0, 0, 39, '2815'),
	(377, 1, 0, -50378, 2817, 0, 0, 39, '2816'),
	(377, 1, 0, -50378, 2818, 0, 0, 39, '2817'),
	(377, 1, 0, -50378, 2819, 0, 0, 39, '2818'),
	(377, 1, 0, -50378, 2820, 0, 0, 39, '2819'),
	(377, 1, 0, -50378, 2821, 0, 0, 39, '2820'),
	(377, 1, 0, -50378, 2822, 0, 0, 39, '2821'),
	(377, 1, 0, -50378, 2823, 0, 0, 39, '2822'),
	(377, 1, 0, -50378, 2824, 0, 0, 39, '2823'),
	(377, 1, 0, -50378, 2825, 0, 0, 39, '2824'),
	(377, 1, 0, -50378, 2826, 0, 0, 39, '2825'),
	(377, 1, 0, -50378, 2827, 0, 0, 39, '2826'),
	(377, 1, 0, -50378, 2828, 0, 0, 39, '2827'),
	(377, 1, 0, -50378, 2829, 0, 0, 39, '2828'),
	(377, 1, 0, -50378, 2830, 0, 0, 39, '2829'),
	(377, 1, 0, -50378, 2831, 0, 0, 39, '2830'),
	(377, 1, 0, -50378, 2832, 0, 0, 39, '2831'),
	(377, 1, 0, -50378, 2833, 0, 0, 39, '2832'),
	(377, 1, 0, -50378, 2834, 0, 0, 39, '2833'),
	(377, 1, 0, -50378, 2835, 0, 0, 39, '2834'),
	(377, 1, 0, -50378, 2836, 0, 0, 39, '2835'),
	(377, 1, 0, -50378, 2837, 0, 0, 39, '2836'),
	(377, 1, 0, -50378, 2838, 0, 0, 39, '2837'),
	(377, 1, 0, -50378, 2839, 0, 0, 39, '2838'),
	(377, 1, 0, -50378, 2840, 0, 0, 39, '2839'),
	(377, 1, 0, -50378, 2841, 0, 0, 39, '2840'),
	(377, 1, 0, -50378, 2842, 0, 0, 39, '2841'),
	(377, 1, 0, -50378, 2843, 0, 0, 39, '2842'),
	(377, 1, 0, -50378, 2844, 0, 0, 39, '2843'),
	(377, 1, 0, -50378, 2845, 0, 0, 39, '2844'),
	(377, 1, 0, -50378, 2846, 0, 0, 39, '2845'),
	(377, 1, 0, -50378, 2847, 0, 0, 39, '2846'),
	(377, 1, 0, -50378, 2848, 0, 0, 39, '2847'),
	(377, 1, 0, -50378, 2849, 0, 0, 39, '2848'),
	(377, 1, 0, -50378, 2850, 0, 0, 39, '2849'),
	(377, 1, 0, -50378, 2851, 0, 0, 39, '2850'),
	(377, 1, 0, -50378, 2852, 0, 0, 39, '2851'),
	(377, 1, 0, -50378, 2853, 0, 0, 39, '2852'),
	(377, 1, 0, -50378, 2854, 0, 0, 39, '2853'),
	(377, 1, 0, -50378, 2855, 0, 0, 39, '2854'),
	(377, 1, 0, -50378, 2856, 0, 0, 39, '2855'),
	(377, 1, 0, -50378, 2857, 0, 0, 39, '2856'),
	(377, 1, 0, -50378, 2858, 0, 0, 39, '2857'),
	(377, 1, 0, -50378, 2859, 0, 0, 39, '2858'),
	(377, 1, 0, -50378, 2860, 0, 0, 39, '2859'),
	(377, 1, 0, -50378, 2861, 0, 0, 39, '2860'),
	(377, 1, 0, -50378, 2862, 0, 0, 39, '2861'),
	(377, 1, 0, -50378, 2863, 0, 0, 39, '2862'),
	(377, 1, 0, -50378, 2864, 0, 0, 39, '2863'),
	(377, 1, 0, -50378, 2865, 0, 0, 39, '2864'),
	(377, 1, 0, -50378, 2866, 0, 0, 39, '2865'),
	(377, 1, 0, -50378, 2867, 0, 0, 39, '2866'),
	(377, 1, 0, -50378, 2868, 0, 0, 39, '2867'),
	(377, 1, 0, -50378, 2869, 0, 0, 39, '2868'),
	(377, 1, 0, -50378, 2870, 0, 0, 39, '2869'),
	(377, 1, 0, -50378, 2871, 0, 0, 39, '2870'),
	(377, 1, 0, -50378, 2872, 0, 0, 39, '2871'),
	(377, 1, 0, -50378, 2873, 0, 0, 39, '2872'),
	(377, 1, 0, -50378, 2874, 0, 0, 39, '2873'),
	(377, 1, 0, -50378, 2875, 0, 0, 39, '2874'),
	(377, 1, 0, -50378, 2876, 0, 0, 39, '2875'),
	(377, 1, 0, -50378, 2877, 0, 0, 39, '2876'),
	(377, 1, 0, -50378, 2878, 0, 0, 39, '2877'),
	(377, 1, 0, -50378, 2879, 0, 0, 39, '2878'),
	(377, 1, 0, -50378, 2880, 0, 0, 39, '2879'),
	(377, 1, 0, -50378, 2881, 0, 0, 39, '2880'),
	(377, 1, 0, -50378, 2882, 0, 0, 39, '2881'),
	(377, 1, 0, -50378, 2883, 0, 0, 39, '2882'),
	(377, 1, 0, -50378, 2884, 0, 0, 39, '2883'),
	(377, 1, 0, -50378, 2885, 0, 0, 39, '2884'),
	(377, 1, 0, -50378, 2886, 0, 0, 39, '2885'),
	(377, 1, 0, -50378, 2887, 0, 0, 39, '2886'),
	(377, 1, 0, -50378, 2888, 0, 0, 39, '2887'),
	(377, 1, 0, -50378, 2889, 0, 0, 39, '2888'),
	(377, 1, 0, -50378, 2890, 0, 0, 39, '2889'),
	(377, 1, 0, -50378, 2891, 0, 0, 39, '2890'),
	(377, 1, 0, -50378, 2892, 0, 0, 39, '2891'),
	(377, 1, 0, -50378, 2893, 0, 0, 39, '2892'),
	(377, 1, 0, -50378, 2894, 0, 0, 39, '2893'),
	(377, 1, 0, -50378, 2895, 0, 0, 39, '2894'),
	(377, 1, 0, -50378, 2896, 0, 0, 39, '2895'),
	(377, 1, 0, -50378, 2897, 0, 0, 39, '2896'),
	(377, 1, 0, -50378, 2898, 0, 0, 39, '2897'),
	(377, 1, 0, -50378, 2899, 0, 0, 39, '2898'),
	(377, 1, 0, -50378, 2900, 0, 0, 39, '2899'),
	(377, 1, 0, -50378, 2901, 0, 0, 39, '2900'),
	(377, 1, 0, -50378, 2902, 0, 0, 39, '2901'),
	(377, 1, 0, -50378, 2903, 0, 0, 39, '2902'),
	(377, 1, 0, -50378, 2904, 0, 0, 39, '2903'),
	(377, 1, 0, -50378, 2905, 0, 0, 39, '2904'),
	(377, 1, 0, -50378, 2906, 0, 0, 39, '2905'),
	(377, 1, 0, -50378, 2907, 0, 0, 39, '2906'),
	(377, 1, 0, -50378, 2908, 0, 0, 39, '2907'),
	(377, 1, 0, -50378, 2909, 0, 0, 39, '2908'),
	(377, 1, 0, -50378, 2910, 0, 0, 39, '2909'),
	(377, 1, 0, -50378, 2911, 0, 0, 39, '2910'),
	(377, 1, 0, -50378, 2912, 0, 0, 39, '2911'),
	(377, 1, 0, -50378, 2913, 0, 0, 39, '2912'),
	(377, 1, 0, -50378, 2914, 0, 0, 39, '2913'),
	(377, 1, 0, -50378, 2915, 0, 0, 39, '2914'),
	(377, 1, 0, -50378, 2916, 0, 0, 39, '2915'),
	(377, 1, 0, -50378, 2917, 0, 0, 39, '2916'),
	(377, 1, 0, -50378, 2918, 0, 0, 39, '2917'),
	(377, 1, 0, -50378, 2919, 0, 0, 39, '2918'),
	(377, 1, 0, -50378, 2920, 0, 0, 39, '2919'),
	(377, 1, 0, -50378, 2921, 0, 0, 39, '2920'),
	(377, 1, 0, -50378, 2922, 0, 0, 39, '2921'),
	(377, 1, 0, -50378, 2923, 0, 0, 39, '2922'),
	(377, 1, 0, -50378, 2924, 0, 0, 39, '2923'),
	(377, 1, 0, -50378, 2925, 0, 0, 39, '2924'),
	(377, 1, 0, -50378, 2926, 0, 0, 39, '2925'),
	(377, 1, 0, -50378, 2927, 0, 0, 39, '2926'),
	(377, 1, 0, -50378, 2928, 0, 0, 39, '2927'),
	(377, 1, 0, -50378, 2929, 0, 0, 39, '2928'),
	(377, 1, 0, -50378, 2930, 0, 0, 39, '2929'),
	(377, 1, 0, -50378, 2931, 0, 0, 39, '2930'),
	(377, 1, 0, -50378, 2932, 0, 0, 39, '2931'),
	(377, 1, 0, -50378, 2933, 0, 0, 39, '2932'),
	(377, 1, 0, -50378, 2934, 0, 0, 39, '2933'),
	(377, 1, 0, -50378, 2935, 0, 0, 39, '2934'),
	(377, 1, 0, -50378, 2936, 0, 0, 39, '2935'),
	(377, 1, 0, -50378, 2937, 0, 0, 39, '2936'),
	(377, 1, 0, -50378, 2938, 0, 0, 39, '2937'),
	(377, 1, 0, -50378, 2939, 0, 0, 39, '2938'),
	(377, 1, 0, -50378, 2940, 0, 0, 39, '2939'),
	(377, 1, 0, -50378, 2941, 0, 0, 39, '2940'),
	(377, 1, 0, -50378, 2942, 0, 0, 39, '2941'),
	(377, 1, 0, -50378, 2943, 0, 0, 39, '2942'),
	(377, 1, 0, -50378, 2944, 0, 0, 39, '2943'),
	(377, 1, 0, -50378, 2945, 0, 0, 39, '2944'),
	(377, 1, 0, -50378, 2946, 0, 0, 39, '2945'),
	(377, 1, 0, -50378, 2947, 0, 0, 39, '2946'),
	(377, 1, 0, -50378, 2948, 0, 0, 39, '2947'),
	(377, 1, 0, -50378, 2949, 0, 0, 39, '2948'),
	(377, 1, 0, -50378, 2950, 0, 0, 39, '2949'),
	(377, 1, 0, -50378, 2951, 0, 0, 39, '2950'),
	(377, 1, 0, -50378, 2952, 0, 0, 39, '2951'),
	(377, 1, 0, -50378, 2953, 0, 0, 39, '2952'),
	(377, 1, 0, -50378, 2954, 0, 0, 39, '2953'),
	(377, 1, 0, -50378, 2955, 0, 0, 39, '2954'),
	(377, 1, 0, -50378, 2956, 0, 0, 39, '2955'),
	(377, 1, 0, -50378, 2957, 0, 0, 39, '2956'),
	(377, 1, 0, -50378, 2958, 0, 0, 39, '2957'),
	(377, 1, 0, -50378, 2959, 0, 0, 39, '2958'),
	(377, 1, 0, -50378, 2960, 0, 0, 39, '2959'),
	(377, 1, 0, -50378, 2961, 0, 0, 39, '2960'),
	(377, 1, 0, -50378, 2962, 0, 0, 39, '2961'),
	(377, 1, 0, -50378, 2963, 0, 0, 39, '2962'),
	(377, 1, 0, -50378, 2964, 0, 0, 39, '2963'),
	(377, 1, 0, -50378, 2965, 0, 0, 39, '2964'),
	(377, 1, 0, -50378, 2966, 0, 0, 39, '2965'),
	(377, 1, 0, -50378, 2967, 0, 0, 39, '2966'),
	(377, 1, 0, -50378, 2968, 0, 0, 39, '2967'),
	(377, 1, 0, -50378, 2969, 0, 0, 39, '2968'),
	(377, 1, 0, -50378, 2970, 0, 0, 39, '2969'),
	(377, 1, 0, -50378, 2971, 0, 0, 39, '2970'),
	(377, 1, 0, -50378, 2972, 0, 0, 39, '2971'),
	(377, 1, 0, -50378, 2973, 0, 0, 39, '2972'),
	(377, 1, 0, -50378, 2974, 0, 0, 39, '2973'),
	(377, 1, 0, -50378, 2975, 0, 0, 39, '2974'),
	(377, 1, 0, -50378, 2976, 0, 0, 39, '2975'),
	(377, 1, 0, -50378, 2977, 0, 0, 39, '2976'),
	(377, 1, 0, -50378, 2978, 0, 0, 39, '2977'),
	(377, 1, 0, -50378, 2979, 0, 0, 39, '2978'),
	(377, 1, 0, -50378, 2980, 0, 0, 39, '2979'),
	(377, 1, 0, -50378, 2981, 0, 0, 39, '2980'),
	(377, 1, 0, -50378, 2982, 0, 0, 39, '2981'),
	(377, 1, 0, -50378, 2983, 0, 0, 39, '2982'),
	(377, 1, 0, -50378, 2984, 0, 0, 39, '2983'),
	(377, 1, 0, -50378, 2985, 0, 0, 39, '2984'),
	(377, 1, 0, -50378, 2986, 0, 0, 39, '2985'),
	(377, 1, 0, -50378, 2987, 0, 0, 39, '2986'),
	(377, 1, 0, -50378, 2988, 0, 0, 39, '2987'),
	(377, 1, 0, -50378, 2989, 0, 0, 39, '2988'),
	(377, 1, 0, -50378, 2990, 0, 0, 39, '2989'),
	(377, 1, 0, -50378, 2991, 0, 0, 39, '2990'),
	(377, 1, 0, -50378, 2992, 0, 0, 39, '2991'),
	(377, 1, 0, -50378, 2993, 0, 0, 39, '2992'),
	(377, 1, 0, -50378, 2994, 0, 0, 39, '2993'),
	(377, 1, 0, -50378, 2995, 0, 0, 39, '2994'),
	(377, 1, 0, -50378, 2996, 0, 0, 39, '2995'),
	(377, 1, 0, -50378, 2997, 0, 0, 39, '2996'),
	(377, 1, 0, -50378, 2998, 0, 0, 39, '2997'),
	(377, 1, 0, -50378, 2999, 0, 0, 39, '2998'),
	(377, 1, 0, -50378, 3000, 0, 0, 39, '2999'),
	(377, 1, 0, -50378, 3001, 0, 0, 39, '3000'),
	(377, 1, 0, -50378, 3002, 0, 0, 39, '3001'),
	(377, 1, 0, -50378, 3003, 0, 0, 39, '3002'),
	(377, 1, 0, -50378, 3004, 0, 0, 39, '3003'),
	(377, 1, 0, -50378, 3005, 0, 0, 39, '3004'),
	(377, 1, 0, -50378, 3006, 0, 0, 39, '3005'),
	(377, 1, 0, -50378, 3007, 0, 0, 39, '3006'),
	(377, 1, 0, -50378, 3008, 0, 0, 39, '3007'),
	(377, 1, 0, -50378, 3009, 0, 0, 39, '3008'),
	(377, 1, 0, -50378, 3010, 0, 0, 39, '3009'),
	(377, 1, 0, -50378, 3011, 0, 0, 39, '3010'),
	(377, 1, 0, -50378, 3012, 0, 0, 39, '3011'),
	(377, 1, 0, -50378, 3013, 0, 0, 39, '3012'),
	(377, 1, 0, -50378, 3014, 0, 0, 39, '3013'),
	(377, 1, 0, -50378, 3015, 0, 0, 39, '3014'),
	(377, 1, 0, -50378, 3016, 0, 0, 39, '3015'),
	(377, 1, 0, -50378, 3017, 0, 0, 39, '3016'),
	(377, 1, 0, -50378, 3018, 0, 0, 39, '3017'),
	(377, 1, 0, -50378, 3019, 0, 0, 39, '3018'),
	(377, 1, 0, -50378, 3020, 0, 0, 39, '3019'),
	(377, 1, 0, -50378, 3021, 0, 0, 39, '3020'),
	(377, 1, 0, -50378, 3022, 0, 0, 39, '3021'),
	(377, 1, 0, -50378, 3023, 0, 0, 39, '3022'),
	(377, 1, 0, -50378, 3024, 0, 0, 39, '3023'),
	(377, 1, 0, -50378, 3025, 0, 0, 39, '3024'),
	(377, 1, 0, -50378, 3026, 0, 0, 39, '3025'),
	(377, 1, 0, -50378, 3027, 0, 0, 39, '3026'),
	(377, 1, 0, -50378, 3028, 0, 0, 39, '3027'),
	(377, 1, 0, -50378, 3029, 0, 0, 39, '3028'),
	(377, 1, 0, -50378, 3030, 0, 0, 39, '3029'),
	(377, 1, 0, -50378, 3031, 0, 0, 39, '3030'),
	(377, 1, 0, -50378, 3032, 0, 0, 39, '3031'),
	(377, 1, 0, -50378, 3033, 0, 0, 39, '3032'),
	(377, 1, 0, -50378, 3034, 0, 0, 39, '3033'),
	(377, 1, 0, -50378, 3035, 0, 0, 39, '3034'),
	(377, 1, 0, -50378, 3036, 0, 0, 39, '3035'),
	(377, 1, 0, -50378, 3037, 0, 0, 39, '3036'),
	(377, 1, 0, -50378, 3038, 0, 0, 39, '3037'),
	(377, 1, 0, -50378, 3039, 0, 0, 39, '3038'),
	(377, 1, 0, -50378, 3040, 0, 0, 39, '3039'),
	(377, 1, 0, -50378, 3041, 0, 0, 39, '3040'),
	(377, 1, 0, -50378, 3042, 0, 0, 39, '3041'),
	(377, 1, 0, -50378, 3043, 0, 0, 39, '3042'),
	(377, 1, 0, -50378, 3044, 0, 0, 39, '3043'),
	(377, 1, 0, -50378, 3045, 0, 0, 39, '3044'),
	(377, 1, 0, -50378, 3046, 0, 0, 39, '3045'),
	(377, 1, 0, -50378, 3047, 0, 0, 39, '3046'),
	(377, 1, 0, -50378, 3048, 0, 0, 39, '3047'),
	(377, 1, 0, -50378, 3049, 0, 0, 39, '3048'),
	(377, 1, 0, -50378, 3050, 0, 0, 39, '3049'),
	(377, 1, 0, -50378, 3051, 0, 0, 39, '3050'),
	(377, 1, 0, -50378, 3052, 0, 0, 39, '3051'),
	(377, 1, 0, -50378, 3053, 0, 0, 39, '3052'),
	(377, 1, 0, -50378, 3054, 0, 0, 39, '3053'),
	(377, 1, 0, -50378, 3055, 0, 0, 39, '3054'),
	(377, 1, 0, -50378, 3056, 0, 0, 39, '3055'),
	(377, 1, 0, -50378, 3057, 0, 0, 39, '3056'),
	(377, 1, 0, -50378, 3058, 0, 0, 39, '3057'),
	(377, 1, 0, -50378, 3059, 0, 0, 39, '3058'),
	(377, 1, 0, -50378, 3060, 0, 0, 39, '3059'),
	(377, 1, 0, -50378, 3061, 0, 0, 39, '3060'),
	(377, 1, 0, -50378, 3062, 0, 0, 39, '3061'),
	(377, 1, 0, -50378, 3063, 0, 0, 39, '3062'),
	(377, 1, 0, -50378, 3064, 0, 0, 39, '3063'),
	(377, 1, 0, -50378, 3065, 0, 0, 39, '3064'),
	(377, 1, 0, -50378, 3066, 0, 0, 39, '3065'),
	(377, 1, 0, -50378, 3067, 0, 0, 39, '3066'),
	(377, 1, 0, -50378, 3068, 0, 0, 39, '3067'),
	(377, 1, 0, -50378, 3069, 0, 0, 39, '3068'),
	(377, 1, 0, -50378, 3070, 0, 0, 39, '3069'),
	(377, 1, 0, -50378, 3071, 0, 0, 39, '3070'),
	(377, 1, 0, -50378, 3072, 0, 0, 39, '3071'),
	(377, 1, 0, -50378, 3073, 0, 0, 39, '3072'),
	(377, 1, 0, -50378, 3074, 0, 0, 39, '3073'),
	(377, 1, 0, -50378, 3075, 0, 0, 39, '3074'),
	(377, 1, 0, -50378, 3076, 0, 0, 39, '3075'),
	(377, 1, 0, -50378, 3077, 0, 0, 39, '3076'),
	(377, 1, 0, -50378, 3078, 0, 0, 39, '3077'),
	(377, 1, 0, -50378, 3079, 0, 0, 39, '3078'),
	(377, 1, 0, -50378, 3080, 0, 0, 39, '3079'),
	(377, 1, 0, -50378, 3081, 0, 0, 39, '3080'),
	(377, 1, 0, -50378, 3082, 0, 0, 39, '3081'),
	(377, 1, 0, -50378, 3083, 0, 0, 39, '3082'),
	(377, 1, 0, -50378, 3084, 0, 0, 39, '3083'),
	(377, 1, 0, -50378, 3085, 0, 0, 39, '3084'),
	(377, 1, 0, -50378, 3086, 0, 0, 39, '3085'),
	(377, 1, 0, -50378, 3087, 0, 0, 39, '3086'),
	(377, 1, 0, -50378, 3088, 0, 0, 39, '3087'),
	(377, 1, 0, -50378, 3089, 0, 0, 39, '3088'),
	(377, 1, 0, -50378, 3090, 0, 0, 39, '3089'),
	(377, 1, 0, -50378, 3091, 0, 0, 39, '3090'),
	(377, 1, 0, -50378, 3092, 0, 0, 39, '3091'),
	(377, 1, 0, -50378, 3093, 0, 0, 39, '3092'),
	(377, 1, 0, -50378, 3094, 0, 0, 39, '3093'),
	(377, 1, 0, -50378, 3095, 0, 0, 39, '3094'),
	(377, 1, 0, -50378, 3096, 0, 0, 39, '3095'),
	(377, 1, 0, -50378, 3097, 0, 0, 39, '3096'),
	(377, 1, 0, -50378, 3098, 0, 0, 39, '3097'),
	(377, 1, 0, -50378, 3099, 0, 0, 39, '3098'),
	(377, 1, 0, -50378, 3100, 0, 0, 39, '3099'),
	(377, 1, 0, -50378, 3101, 0, 0, 39, '3100'),
	(377, 1, 0, -50378, 3102, 0, 0, 39, '3101'),
	(377, 1, 0, -50378, 3103, 0, 0, 39, '3102'),
	(377, 1, 0, -50378, 3104, 0, 0, 39, '3103'),
	(377, 1, 0, -50378, 3105, 0, 0, 39, '3104'),
	(377, 1, 0, -50378, 3106, 0, 0, 39, '3105'),
	(377, 1, 0, -50378, 3107, 0, 0, 39, '3106'),
	(377, 1, 0, -50378, 3108, 0, 0, 39, '3107'),
	(377, 1, 0, -50378, 3109, 0, 0, 39, '3108'),
	(377, 1, 0, -50378, 3110, 0, 0, 39, '3109'),
	(377, 1, 0, -50378, 3111, 0, 0, 39, '3110'),
	(377, 1, 0, -50378, 3112, 0, 0, 39, '3111'),
	(377, 1, 0, -50378, 3113, 0, 0, 39, '3112'),
	(377, 1, 0, -50378, 3114, 0, 0, 39, '3113'),
	(377, 1, 0, -50378, 3115, 0, 0, 39, '3114'),
	(377, 1, 0, -50378, 3116, 0, 0, 39, '3115'),
	(377, 1, 0, -50378, 3117, 0, 0, 39, '3116'),
	(377, 1, 0, -50378, 3118, 0, 0, 39, '3117'),
	(377, 1, 0, -50378, 3119, 0, 0, 39, '3118'),
	(377, 1, 0, -50378, 3120, 0, 0, 39, '3119'),
	(377, 1, 0, -50378, 3121, 0, 0, 39, '3120'),
	(377, 1, 0, -50378, 3122, 0, 0, 39, '3121'),
	(377, 1, 0, -50378, 3123, 0, 0, 39, '3122'),
	(377, 1, 0, -50378, 3124, 0, 0, 39, '3123'),
	(377, 1, 0, -50378, 3125, 0, 0, 39, '3124'),
	(377, 1, 0, -50378, 3126, 0, 0, 39, '3125'),
	(377, 1, 0, -50378, 3127, 0, 0, 39, '3126'),
	(377, 1, 0, -50378, 3128, 0, 0, 39, '3127'),
	(377, 1, 0, -50378, 3129, 0, 0, 39, '3128'),
	(377, 1, 0, -50378, 3130, 0, 0, 39, '3129'),
	(377, 1, 0, -50378, 3131, 0, 0, 39, '3130'),
	(377, 1, 0, -50378, 3132, 0, 0, 39, '3131'),
	(377, 1, 0, -50378, 3133, 0, 0, 39, '3132'),
	(377, 1, 0, -50378, 3134, 0, 0, 39, '3133'),
	(377, 1, 0, -50378, 3135, 0, 0, 39, '3134'),
	(377, 1, 0, -50378, 3136, 0, 0, 39, '3135'),
	(377, 1, 0, -50378, 3137, 0, 0, 39, '3136'),
	(377, 1, 0, -50378, 3138, 0, 0, 39, '3137'),
	(377, 1, 0, -50378, 3139, 0, 0, 39, '3138'),
	(377, 1, 0, -50378, 3140, 0, 0, 39, '3139'),
	(377, 1, 0, -50378, 3141, 0, 0, 39, '3140'),
	(377, 1, 0, -50378, 3142, 0, 0, 39, '3141'),
	(377, 1, 0, -50378, 3143, 0, 0, 39, '3142'),
	(377, 1, 0, -50378, 3144, 0, 0, 39, '3143'),
	(377, 1, 0, -50378, 3145, 0, 0, 39, '3144'),
	(377, 1, 0, -50378, 3146, 0, 0, 39, '3145'),
	(377, 1, 0, -50378, 3147, 0, 0, 39, '3146'),
	(377, 1, 0, -50378, 3148, 0, 0, 39, '3147'),
	(377, 1, 0, -50378, 3149, 0, 0, 39, '3148'),
	(377, 1, 0, -50378, 3150, 0, 0, 39, '3149'),
	(377, 1, 0, -50378, 3151, 0, 0, 39, '3150'),
	(377, 1, 0, -50378, 3152, 0, 0, 39, '3151'),
	(377, 1, 0, -50378, 3153, 0, 0, 39, '3152'),
	(377, 1, 0, -50378, 3154, 0, 0, 39, '3153'),
	(377, 1, 0, -50378, 3155, 0, 0, 39, '3154'),
	(377, 1, 0, -50378, 3156, 0, 0, 39, '3155'),
	(377, 1, 0, -50378, 3157, 0, 0, 39, '3156'),
	(377, 1, 0, -50378, 3158, 0, 0, 39, '3157'),
	(377, 1, 0, -50378, 3159, 0, 0, 39, '3158'),
	(377, 1, 0, -50378, 3160, 0, 0, 39, '3159'),
	(377, 1, 0, -50378, 3161, 0, 0, 39, '3160'),
	(377, 1, 0, -50378, 3162, 0, 0, 39, '3161'),
	(377, 1, 0, -50378, 3163, 0, 0, 39, '3162'),
	(377, 1, 0, -50378, 3164, 0, 0, 39, '3163'),
	(377, 1, 0, -50378, 3165, 0, 0, 39, '3164'),
	(377, 1, 0, -50378, 3166, 0, 0, 39, '3165'),
	(377, 1, 0, -50378, 3167, 0, 0, 39, '3166'),
	(377, 1, 0, -50378, 3168, 0, 0, 39, '3167'),
	(377, 1, 0, -50378, 3169, 0, 0, 39, '3168'),
	(377, 1, 0, -50378, 3170, 0, 0, 39, '3169'),
	(377, 1, 0, -50378, 3171, 0, 0, 39, '3170'),
	(377, 1, 0, -50378, 3172, 0, 0, 39, '3171'),
	(377, 1, 0, -50378, 3173, 0, 0, 39, '3172'),
	(377, 1, 0, -50378, 3174, 0, 0, 39, '3173'),
	(377, 1, 0, -50378, 3175, 0, 0, 39, '3174'),
	(377, 1, 0, -50378, 3176, 0, 0, 39, '3175'),
	(377, 1, 0, -50378, 3177, 0, 0, 39, '3176'),
	(377, 1, 0, -50378, 3178, 0, 0, 39, '3177'),
	(377, 1, 0, -50378, 3179, 0, 0, 39, '3178'),
	(377, 1, 0, -50378, 3180, 0, 0, 39, '3179'),
	(377, 1, 0, -50378, 3181, 0, 0, 39, '3180'),
	(377, 1, 0, -50378, 3182, 0, 0, 39, '3181'),
	(377, 1, 0, -50378, 3183, 0, 0, 39, '3182'),
	(377, 1, 0, -50378, 3184, 0, 0, 39, '3183'),
	(377, 1, 0, -50378, 3185, 0, 0, 39, '3184'),
	(377, 1, 0, -50378, 3186, 0, 0, 39, '3185'),
	(377, 1, 0, -50378, 3187, 0, 0, 39, '3186'),
	(377, 1, 0, -50378, 3188, 0, 0, 39, '3187'),
	(377, 1, 0, -50378, 3189, 0, 0, 39, '3188'),
	(377, 1, 0, -50378, 3190, 0, 0, 39, '3189'),
	(377, 1, 0, -50378, 3191, 0, 0, 39, '3190'),
	(377, 1, 0, -50378, 3192, 0, 0, 39, '3191'),
	(377, 1, 0, -50378, 3193, 0, 0, 39, '3192'),
	(377, 1, 0, -50378, 3194, 0, 0, 39, '3193'),
	(377, 1, 0, -50378, 3195, 0, 0, 39, '3194'),
	(377, 1, 0, -50378, 3196, 0, 0, 39, '3195'),
	(377, 1, 0, -50378, 3197, 0, 0, 39, '3196'),
	(377, 1, 0, -50378, 3198, 0, 0, 39, '3197'),
	(377, 1, 0, -50378, 3199, 0, 0, 39, '3198'),
	(377, 1, 0, -50378, 3200, 0, 0, 39, '3199'),
	(377, 1, 0, -50378, 3201, 0, 0, 39, '3200'),
	(377, 1, 0, -50378, 3202, 0, 0, 39, '3201'),
	(377, 1, 0, -50378, 3203, 0, 0, 39, '3202'),
	(377, 1, 0, -50378, 3204, 0, 0, 39, '3203'),
	(377, 1, 0, -50378, 3205, 0, 0, 39, '3204'),
	(377, 1, 0, -50378, 3206, 0, 0, 39, '3205'),
	(377, 1, 0, -50378, 3207, 0, 0, 39, '3206'),
	(377, 1, 0, -50378, 3208, 0, 0, 39, '3207'),
	(377, 1, 0, -50378, 3209, 0, 0, 39, '3208'),
	(377, 1, 0, -50378, 3210, 0, 0, 39, '3209'),
	(377, 1, 0, -50378, 3211, 0, 0, 39, '3210'),
	(377, 1, 0, -50378, 3212, 0, 0, 39, '3211'),
	(377, 1, 0, -50378, 3213, 0, 0, 39, '3212'),
	(377, 1, 0, -50378, 3214, 0, 0, 39, '3213'),
	(377, 1, 0, -50378, 3215, 0, 0, 39, '3214'),
	(377, 1, 0, -50378, 3216, 0, 0, 39, '3215'),
	(377, 1, 0, -50378, 3217, 0, 0, 39, '3216'),
	(377, 1, 0, -50378, 3218, 0, 0, 39, '3217'),
	(377, 1, 0, -50378, 3219, 0, 0, 39, '3218'),
	(377, 1, 0, -50378, 3220, 0, 0, 39, '3219'),
	(377, 1, 0, -50378, 3221, 0, 0, 39, '3220'),
	(377, 1, 0, -50378, 3222, 0, 0, 39, '3221'),
	(377, 1, 0, -50378, 3223, 0, 0, 39, '3222'),
	(377, 1, 0, -50378, 3224, 0, 0, 39, '3223'),
	(377, 1, 0, -50378, 3225, 0, 0, 39, '3224'),
	(377, 1, 0, -50378, 3226, 0, 0, 39, '3225'),
	(377, 1, 0, -50378, 3227, 0, 0, 39, '3226'),
	(377, 1, 0, -50378, 3228, 0, 0, 39, '3227'),
	(377, 1, 0, -50378, 3229, 0, 0, 39, '3228'),
	(377, 1, 0, -50378, 3230, 0, 0, 39, '3229'),
	(377, 1, 0, -50378, 3231, 0, 0, 39, '3230'),
	(377, 1, 0, -50378, 3232, 0, 0, 39, '3231'),
	(377, 1, 0, -50378, 3233, 0, 0, 39, '3232'),
	(377, 1, 0, -50378, 3234, 0, 0, 39, '3233'),
	(377, 1, 0, -50378, 3235, 0, 0, 39, '3234'),
	(377, 1, 0, -50378, 3236, 0, 0, 39, '3235'),
	(377, 1, 0, -50378, 3237, 0, 0, 39, '3236'),
	(377, 1, 0, -50378, 3238, 0, 0, 39, '3237'),
	(377, 1, 0, -50378, 3239, 0, 0, 39, '3238'),
	(377, 1, 0, -50378, 3240, 0, 0, 39, '3239'),
	(377, 1, 0, -50378, 3241, 0, 0, 39, '3240'),
	(377, 1, 0, -50378, 3242, 0, 0, 39, '3241'),
	(377, 1, 0, -50378, 3243, 0, 0, 39, '3242'),
	(377, 1, 0, -50378, 3244, 0, 0, 39, '3243'),
	(377, 1, 0, -50378, 3245, 0, 0, 39, '3244'),
	(377, 1, 0, -50378, 3246, 0, 0, 39, '3245'),
	(377, 1, 0, -50378, 3247, 0, 0, 39, '3246'),
	(377, 1, 0, -50378, 3248, 0, 0, 39, '3247'),
	(377, 1, 0, -50378, 3249, 0, 0, 39, '3248'),
	(377, 1, 0, -50378, 3250, 0, 0, 39, '3249'),
	(377, 1, 0, -50378, 3251, 0, 0, 39, '3250'),
	(377, 1, 0, -50378, 3252, 0, 0, 39, '3251'),
	(377, 1, 0, -50378, 3253, 0, 0, 39, '3252'),
	(377, 1, 0, -50378, 3254, 0, 0, 39, '3253'),
	(377, 1, 0, -50378, 3255, 0, 0, 39, '3254'),
	(377, 1, 0, -50378, 3256, 0, 0, 39, '3255'),
	(377, 1, 0, -50378, 3257, 0, 0, 39, '3256'),
	(377, 1, 0, -50378, 3258, 0, 0, 39, '3257'),
	(377, 1, 0, -50378, 3259, 0, 0, 39, '3258'),
	(377, 1, 0, -50378, 3260, 0, 0, 39, '3259'),
	(377, 1, 0, -50378, 3261, 0, 0, 39, '3260'),
	(377, 1, 0, -50378, 3262, 0, 0, 39, '3261'),
	(377, 1, 0, -50378, 3263, 0, 0, 39, '3262'),
	(377, 1, 0, -50378, 3264, 0, 0, 39, '3263'),
	(377, 1, 0, -50378, 3265, 0, 0, 39, '3264'),
	(377, 1, 0, -50378, 3266, 0, 0, 39, '3265'),
	(377, 1, 0, -50378, 3267, 0, 0, 39, '3266'),
	(377, 1, 0, -50378, 3268, 0, 0, 39, '3267'),
	(377, 1, 0, -50378, 3269, 0, 0, 39, '3268'),
	(377, 1, 0, -50378, 3270, 0, 0, 39, '3269'),
	(377, 1, 0, -50378, 3271, 0, 0, 39, '3270'),
	(377, 1, 0, -50378, 3272, 0, 0, 39, '3271'),
	(377, 1, 0, -50378, 3273, 0, 0, 39, '3272'),
	(377, 1, 0, -50378, 3274, 0, 0, 39, '3273'),
	(377, 1, 0, -50378, 3275, 0, 0, 39, '3274'),
	(377, 1, 0, -50378, 3276, 0, 0, 39, '3275'),
	(377, 1, 0, -50378, 3277, 0, 0, 39, '3276'),
	(377, 1, 0, -50378, 3278, 0, 0, 39, '3277'),
	(377, 1, 0, -50378, 3279, 0, 0, 39, '3278'),
	(377, 1, 0, -50378, 3280, 0, 0, 39, '3279'),
	(377, 1, 0, -50378, 3281, 0, 0, 39, '3280'),
	(377, 1, 0, -50378, 3282, 0, 0, 39, '3281'),
	(377, 1, 0, -50378, 3283, 0, 0, 39, '3282'),
	(377, 1, 0, -50378, 3284, 0, 0, 39, '3283'),
	(377, 1, 0, -50378, 3285, 0, 0, 39, '3284'),
	(377, 1, 0, -50378, 3286, 0, 0, 39, '3285'),
	(377, 1, 0, -50378, 3287, 0, 0, 39, '3286'),
	(377, 1, 0, -50378, 3288, 0, 0, 39, '3287'),
	(377, 1, 0, -50378, 3289, 0, 0, 39, '3288'),
	(377, 1, 0, -50378, 3290, 0, 0, 39, '3289'),
	(377, 1, 0, -50378, 3291, 0, 0, 39, '3290'),
	(377, 1, 0, -50378, 3292, 0, 0, 39, '3291'),
	(377, 1, 0, -50378, 3293, 0, 0, 39, '3292'),
	(377, 1, 0, -50378, 3294, 0, 0, 39, '3293'),
	(377, 1, 0, -50378, 3295, 0, 0, 39, '3294'),
	(377, 1, 0, -50378, 3296, 0, 0, 39, '3295'),
	(377, 1, 0, -50378, 3297, 0, 0, 39, '3296'),
	(377, 1, 0, -50378, 3298, 0, 0, 39, '3297'),
	(377, 1, 0, -50378, 3299, 0, 0, 39, '3298'),
	(377, 1, 0, -50378, 3300, 0, 0, 39, '3299'),
	(377, 1, 0, -50378, 3301, 0, 0, 39, '3300'),
	(377, 1, 0, -50378, 3302, 0, 0, 39, '3301'),
	(377, 1, 0, -50378, 3303, 0, 0, 39, '3302'),
	(377, 1, 0, -50378, 3304, 0, 0, 39, '3303'),
	(377, 1, 0, -50378, 3305, 0, 0, 39, '3304'),
	(377, 1, 0, -50378, 3306, 0, 0, 39, '3305'),
	(377, 1, 0, -50378, 3307, 0, 0, 39, '3306'),
	(377, 1, 0, -50378, 3308, 0, 0, 39, '3307'),
	(377, 1, 0, -50378, 3309, 0, 0, 39, '3308'),
	(377, 1, 0, -50378, 3310, 0, 0, 39, '3309'),
	(377, 1, 0, -50378, 3311, 0, 0, 39, '3310'),
	(377, 1, 0, -50378, 3312, 0, 0, 39, '3311'),
	(377, 1, 0, -50378, 3313, 0, 0, 39, '3312'),
	(377, 1, 0, -50378, 3314, 0, 0, 39, '3313'),
	(377, 1, 0, -50378, 3315, 0, 0, 39, '3314'),
	(377, 1, 0, -50378, 3316, 0, 0, 39, '3315'),
	(377, 1, 0, -50378, 3317, 0, 0, 39, '3316'),
	(377, 1, 0, -50378, 3318, 0, 0, 39, '3317'),
	(377, 1, 0, -50378, 3319, 0, 0, 39, '3318'),
	(377, 1, 0, -50378, 3320, 0, 0, 39, '3319'),
	(377, 1, 0, -50378, 3321, 0, 0, 39, '3320'),
	(377, 1, 0, -50378, 3322, 0, 0, 39, '3321'),
	(377, 1, 0, -50378, 3323, 0, 0, 39, '3322'),
	(377, 1, 0, -50378, 3324, 0, 0, 39, '3323'),
	(377, 1, 0, -50378, 3325, 0, 0, 39, '3324'),
	(377, 1, 0, -50378, 3326, 0, 0, 39, '3325'),
	(377, 1, 0, -50378, 3327, 0, 0, 39, '3326'),
	(377, 1, 0, -50378, 3328, 0, 0, 39, '3327'),
	(377, 1, 0, -50378, 3329, 0, 0, 39, '3328'),
	(377, 1, 0, -50378, 3330, 0, 0, 39, '3329'),
	(377, 1, 0, -50378, 3331, 0, 0, 39, '3330'),
	(377, 1, 0, -50378, 3332, 0, 0, 39, '3331'),
	(377, 1, 0, -50378, 3333, 0, 0, 39, '3332'),
	(377, 1, 0, -50378, 3334, 0, 0, 39, '3333'),
	(377, 1, 0, -50378, 3335, 0, 0, 39, '3334'),
	(377, 1, 0, -50378, 3336, 0, 0, 39, '3335'),
	(377, 1, 0, -50378, 3337, 0, 0, 39, '3336'),
	(377, 1, 0, -50378, 3338, 0, 0, 39, '3337'),
	(377, 1, 0, -50378, 3339, 0, 0, 39, '3338'),
	(377, 1, 0, -50378, 3340, 0, 0, 39, '3339'),
	(377, 1, 0, -50378, 3341, 0, 0, 39, '3340'),
	(377, 1, 0, -50378, 3342, 0, 0, 39, '3341'),
	(377, 1, 0, -50378, 3343, 0, 0, 39, '3342'),
	(377, 1, 0, -50378, 3344, 0, 0, 39, '3343'),
	(377, 1, 0, -50378, 3345, 0, 0, 39, '3344'),
	(377, 1, 0, -50378, 3346, 0, 0, 39, '3345'),
	(377, 1, 0, -50378, 3347, 0, 0, 39, '3346'),
	(377, 1, 0, -50378, 3348, 0, 0, 39, '3347'),
	(377, 1, 0, -50378, 3349, 0, 0, 39, '3348'),
	(377, 1, 0, -50378, 3350, 0, 0, 39, '3349'),
	(377, 1, 0, -50378, 3351, 0, 0, 39, '3350'),
	(377, 1, 0, -50378, 3352, 0, 0, 39, '3351'),
	(377, 1, 0, -50378, 3353, 0, 0, 39, '3352'),
	(377, 1, 0, -50378, 3354, 0, 0, 39, '3353'),
	(377, 1, 0, -50378, 3355, 0, 0, 39, '3354'),
	(377, 1, 0, -50378, 3356, 0, 0, 39, '3355'),
	(377, 1, 0, -50378, 3357, 0, 0, 39, '3356'),
	(377, 1, 0, -50378, 3358, 0, 0, 39, '3357'),
	(377, 1, 0, -50378, 3359, 0, 0, 39, '3358'),
	(377, 1, 0, -50378, 3360, 0, 0, 39, '3359'),
	(377, 1, 0, -50378, 3361, 0, 0, 39, '3360'),
	(377, 1, 0, -50378, 3362, 0, 0, 39, '3361'),
	(377, 1, 0, -50378, 3363, 0, 0, 39, '3362'),
	(377, 1, 0, -50378, 3364, 0, 0, 39, '3363'),
	(377, 1, 0, -50378, 3365, 0, 0, 39, '3364'),
	(377, 1, 0, -50378, 3366, 0, 0, 39, '3365'),
	(377, 1, 0, -50378, 3367, 0, 0, 39, '3366'),
	(377, 1, 0, -50378, 3368, 0, 0, 39, '3367'),
	(377, 1, 0, -50378, 3369, 0, 0, 39, '3368'),
	(377, 1, 0, -50378, 3370, 0, 0, 39, '3369'),
	(377, 1, 0, -50378, 3371, 0, 0, 39, '3370'),
	(377, 1, 0, -50378, 3372, 0, 0, 39, '3371'),
	(377, 1, 0, -50378, 3373, 0, 0, 39, '3372'),
	(377, 1, 0, -50378, 3374, 0, 0, 39, '3373'),
	(377, 1, 0, -50378, 3375, 0, 0, 39, '3374'),
	(377, 1, 0, -50378, 3376, 0, 0, 39, '3375'),
	(377, 1, 0, -50378, 3377, 0, 0, 39, '3376'),
	(377, 1, 0, -50378, 3378, 0, 0, 39, '3377'),
	(377, 1, 0, -50378, 3379, 0, 0, 39, '3378'),
	(377, 1, 0, -50378, 3380, 0, 0, 39, '3379'),
	(377, 1, 0, -50378, 3381, 0, 0, 39, '3380'),
	(377, 1, 0, -50378, 3382, 0, 0, 39, '3381'),
	(377, 1, 0, -50378, 3383, 0, 0, 39, '3382'),
	(377, 1, 0, -50378, 3384, 0, 0, 39, '3383'),
	(377, 1, 0, -50378, 3385, 0, 0, 39, '3384'),
	(377, 1, 0, -50378, 3386, 0, 0, 39, '3385'),
	(377, 1, 0, -50378, 3387, 0, 0, 39, '3386'),
	(377, 1, 0, -50378, 3388, 0, 0, 39, '3387'),
	(377, 1, 0, -50378, 3389, 0, 0, 39, '3388'),
	(377, 1, 0, -50378, 3390, 0, 0, 39, '3389'),
	(377, 1, 0, -50378, 3391, 0, 0, 39, '3390'),
	(377, 1, 0, -50378, 3392, 0, 0, 39, '3391'),
	(377, 1, 0, -50378, 3393, 0, 0, 39, '3392'),
	(377, 1, 0, -50378, 3394, 0, 0, 39, '3393'),
	(377, 1, 0, -50378, 3395, 0, 0, 39, '3394'),
	(377, 1, 0, -50378, 3396, 0, 0, 39, '3395'),
	(377, 1, 0, -50378, 3397, 0, 0, 39, '3396'),
	(377, 1, 0, -50378, 3398, 0, 0, 39, '3397'),
	(377, 1, 0, -50378, 3399, 0, 0, 39, '3398'),
	(377, 1, 0, -50378, 3400, 0, 0, 39, '3399'),
	(377, 1, 0, -50378, 3401, 0, 0, 39, '3400'),
	(377, 1, 0, -50378, 3402, 0, 0, 39, '3401'),
	(377, 1, 0, -50378, 3403, 0, 0, 39, '3402'),
	(377, 1, 0, -50378, 3404, 0, 0, 39, '3403'),
	(377, 1, 0, -50378, 3405, 0, 0, 39, '3404'),
	(377, 1, 0, -50378, 3406, 0, 0, 39, '3405'),
	(377, 1, 0, -50378, 3407, 0, 0, 39, '3406'),
	(377, 1, 0, -50378, 3408, 0, 0, 39, '3407'),
	(377, 1, 0, -50378, 3409, 0, 0, 39, '3408'),
	(377, 1, 0, -50378, 3410, 0, 0, 39, '3409'),
	(377, 1, 0, -50378, 3411, 0, 0, 39, '3410'),
	(377, 1, 0, -50378, 3412, 0, 0, 39, '3411'),
	(377, 1, 0, -50378, 3413, 0, 0, 39, '3412'),
	(377, 1, 0, -50378, 3414, 0, 0, 39, '3413'),
	(377, 1, 0, -50378, 3415, 0, 0, 39, '3414'),
	(377, 1, 0, -50378, 3416, 0, 0, 39, '3415'),
	(377, 1, 0, -50378, 3417, 0, 0, 39, '3416'),
	(377, 1, 0, -50378, 3418, 0, 0, 39, '3417'),
	(377, 1, 0, -50378, 3419, 0, 0, 39, '3418'),
	(377, 1, 0, -50378, 3420, 0, 0, 39, '3419'),
	(377, 1, 0, -50378, 3421, 0, 0, 39, '3420'),
	(377, 1, 0, -50378, 3422, 0, 0, 39, '3421'),
	(377, 1, 0, -50378, 3423, 0, 0, 39, '3422'),
	(377, 1, 0, -50378, 3424, 0, 0, 39, '3423'),
	(377, 1, 0, -50378, 3425, 0, 0, 39, '3424'),
	(377, 1, 0, -50378, 3426, 0, 0, 39, '3425'),
	(377, 1, 0, -50378, 3427, 0, 0, 39, '3426'),
	(377, 1, 0, -50378, 3428, 0, 0, 39, '3427'),
	(377, 1, 0, -50378, 3429, 0, 0, 39, '3428'),
	(377, 1, 0, -50378, 3430, 0, 0, 39, '3429'),
	(377, 1, 0, -50378, 3431, 0, 0, 39, '3430'),
	(377, 1, 0, -50378, 3432, 0, 0, 39, '3431'),
	(377, 1, 0, -50378, 3433, 0, 0, 39, '3432'),
	(377, 1, 0, -50378, 3434, 0, 0, 39, '3433'),
	(377, 1, 0, -50378, 3435, 0, 0, 39, '3434'),
	(377, 1, 0, -50378, 3436, 0, 0, 39, '3435'),
	(377, 1, 0, -50378, 3437, 0, 0, 39, '3436'),
	(377, 1, 0, -50378, 3438, 0, 0, 39, '3437'),
	(377, 1, 0, -50378, 3439, 0, 0, 39, '3438'),
	(377, 1, 0, -50378, 3440, 0, 0, 39, '3439'),
	(377, 1, 0, -50378, 3441, 0, 0, 39, '3440'),
	(377, 1, 0, -50378, 3442, 0, 0, 39, '3441'),
	(377, 1, 0, -50378, 3443, 0, 0, 39, '3442'),
	(377, 1, 0, -50378, 3444, 0, 0, 39, '3443'),
	(377, 1, 0, -50378, 3445, 0, 0, 39, '3444'),
	(377, 1, 0, -50378, 3446, 0, 0, 39, '3445'),
	(377, 1, 0, -50378, 3447, 0, 0, 39, '3446'),
	(377, 1, 0, -50378, 3448, 0, 0, 39, '3447'),
	(377, 1, 0, -50378, 3449, 0, 0, 39, '3448'),
	(377, 1, 0, -50378, 3450, 0, 0, 39, '3449'),
	(377, 1, 0, -50378, 3451, 0, 0, 39, '3450'),
	(377, 1, 0, -50378, 3452, 0, 0, 39, '3451'),
	(377, 1, 0, -50378, 3453, 0, 0, 39, '3452'),
	(377, 1, 0, -50378, 3454, 0, 0, 39, '3453'),
	(377, 1, 0, -50378, 3455, 0, 0, 39, '3454'),
	(377, 1, 0, -50378, 3456, 0, 0, 39, '3455'),
	(377, 1, 0, -50378, 3457, 0, 0, 39, '3456'),
	(377, 1, 0, -50378, 3458, 0, 0, 39, '3457'),
	(377, 1, 0, -50378, 3459, 0, 0, 39, '3458'),
	(377, 1, 0, -50378, 3460, 0, 0, 39, '3459'),
	(377, 1, 0, -50378, 3461, 0, 0, 39, '3460'),
	(377, 1, 0, -50378, 3462, 0, 0, 39, '3461'),
	(377, 1, 0, -50378, 3463, 0, 0, 39, '3462'),
	(377, 1, 0, -50378, 3464, 0, 0, 39, '3463'),
	(377, 1, 0, -50378, 3465, 0, 0, 39, '3464'),
	(377, 1, 0, -50378, 3466, 0, 0, 39, '3465'),
	(377, 1, 0, -50378, 3467, 0, 0, 39, '3466'),
	(377, 1, 0, -50378, 3468, 0, 0, 39, '3467'),
	(377, 1, 0, -50378, 3469, 0, 0, 39, '3468'),
	(377, 1, 0, -50378, 3470, 0, 0, 39, '3469'),
	(377, 1, 0, -50378, 3471, 0, 0, 39, '3470'),
	(377, 1, 0, -50378, 3472, 0, 0, 39, '3471'),
	(377, 1, 0, -50378, 3473, 0, 0, 39, '3472'),
	(377, 1, 0, -50378, 3474, 0, 0, 39, '3473'),
	(377, 1, 0, -50378, 3475, 0, 0, 39, '3474'),
	(377, 1, 0, -50378, 3476, 0, 0, 39, '3475'),
	(377, 1, 0, -50378, 3477, 0, 0, 39, '3476'),
	(377, 1, 0, -50378, 3478, 0, 0, 39, '3477'),
	(377, 1, 0, -50378, 3479, 0, 0, 39, '3478'),
	(377, 1, 0, -50378, 3480, 0, 0, 39, '3479'),
	(377, 1, 0, -50378, 3481, 0, 0, 39, '3480'),
	(377, 1, 0, -50378, 3482, 0, 0, 39, '3481'),
	(377, 1, 0, -50378, 3483, 0, 0, 39, '3482'),
	(377, 1, 0, -50378, 3484, 0, 0, 39, '3483'),
	(377, 1, 0, -50378, 3485, 0, 0, 39, '3484'),
	(377, 1, 0, -50378, 3486, 0, 0, 39, '3485'),
	(377, 1, 0, -50378, 3487, 0, 0, 39, '3486'),
	(377, 1, 0, -50378, 3488, 0, 0, 39, '3487'),
	(377, 1, 0, -50378, 3489, 0, 0, 39, '3488'),
	(377, 1, 0, -50378, 3490, 0, 0, 39, '3489'),
	(377, 1, 0, -50378, 3491, 0, 0, 39, '3490'),
	(377, 1, 0, -50378, 3492, 0, 0, 39, '3491'),
	(377, 1, 0, -50378, 3493, 0, 0, 39, '3492'),
	(377, 1, 0, -50378, 3494, 0, 0, 39, '3493'),
	(377, 1, 0, -50378, 3495, 0, 0, 39, '3494'),
	(377, 1, 0, -50378, 3496, 0, 0, 39, '3495'),
	(377, 1, 0, -50378, 3497, 0, 0, 39, '3496'),
	(377, 1, 0, -50378, 3498, 0, 0, 39, '3497'),
	(377, 1, 0, -50378, 3499, 0, 0, 39, '3498'),
	(377, 1, 0, -50378, 3500, 0, 0, 39, '3499'),
	(377, 1, 0, -50378, 3501, 0, 0, 39, '3500'),
	(377, 1, 0, -50378, 3502, 0, 0, 39, '3501'),
	(377, 1, 0, -50378, 3503, 0, 0, 39, '3502'),
	(377, 1, 0, -50378, 3504, 0, 0, 39, '3503'),
	(377, 1, 0, -50378, 3505, 0, 0, 39, '3504'),
	(377, 1, 0, -50378, 3506, 0, 0, 39, '3505'),
	(377, 1, 0, -50378, 3507, 0, 0, 39, '3506'),
	(377, 1, 0, -50378, 3508, 0, 0, 39, '3507'),
	(377, 1, 0, -50378, 3509, 0, 0, 39, '3508'),
	(377, 1, 0, -50378, 3510, 0, 0, 39, '3509'),
	(377, 1, 0, -50378, 3511, 0, 0, 39, '3510'),
	(377, 1, 0, -50378, 3512, 0, 0, 39, '3511'),
	(377, 1, 0, -50378, 3513, 0, 0, 39, '3512'),
	(377, 1, 0, -50378, 3514, 0, 0, 39, '3513'),
	(377, 1, 0, -50378, 3515, 0, 0, 39, '3514'),
	(377, 1, 0, -50378, 3516, 0, 0, 39, '3515'),
	(377, 1, 0, -50378, 3517, 0, 0, 39, '3516'),
	(377, 1, 0, -50378, 3518, 0, 0, 39, '3517'),
	(377, 1, 0, -50378, 3519, 0, 0, 39, '3518'),
	(377, 1, 0, -50378, 3520, 0, 0, 39, '3519'),
	(377, 1, 0, -50378, 3521, 0, 0, 39, '3520'),
	(377, 1, 0, -50378, 3522, 0, 0, 39, '3521'),
	(377, 1, 0, -50378, 3523, 0, 0, 39, '3522'),
	(377, 1, 0, -50378, 3524, 0, 0, 39, '3523'),
	(377, 1, 0, -50378, 3525, 0, 0, 39, '3524'),
	(377, 1, 0, -50378, 3526, 0, 0, 39, '3525'),
	(377, 1, 0, -50378, 3527, 0, 0, 39, '3526'),
	(377, 1, 0, -50378, 3528, 0, 0, 39, '3527'),
	(377, 1, 0, -50378, 3529, 0, 0, 39, '3528'),
	(377, 1, 0, -50378, 3530, 0, 0, 39, '3529'),
	(377, 1, 0, -50378, 3531, 0, 0, 39, '3530'),
	(377, 1, 0, -50378, 3532, 0, 0, 39, '3531'),
	(377, 1, 0, -50378, 3533, 0, 0, 39, '3532'),
	(377, 1, 0, -50378, 3534, 0, 0, 39, '3533'),
	(377, 1, 0, -50378, 3535, 0, 0, 39, '3534'),
	(377, 1, 0, -50378, 3536, 0, 0, 39, '3535'),
	(377, 1, 0, -50378, 3537, 0, 0, 39, '3536'),
	(377, 1, 0, -50378, 3538, 0, 0, 39, '3537'),
	(377, 1, 0, -50378, 3539, 0, 0, 39, '3538'),
	(377, 1, 0, -50378, 3540, 0, 0, 39, '3539'),
	(377, 1, 0, -50378, 3541, 0, 0, 39, '3540'),
	(377, 1, 0, -50378, 3542, 0, 0, 39, '3541'),
	(377, 1, 0, -50378, 3543, 0, 0, 39, '3542'),
	(377, 1, 0, -50378, 3544, 0, 0, 39, '3543'),
	(377, 1, 0, -50378, 3545, 0, 0, 39, '3544'),
	(377, 1, 0, -50378, 3546, 0, 0, 39, '3545'),
	(377, 1, 0, -50378, 3547, 0, 0, 39, '3546'),
	(377, 1, 0, -50378, 3548, 0, 0, 39, '3547'),
	(377, 1, 0, -50378, 3549, 0, 0, 39, '3548'),
	(377, 1, 0, -50378, 3550, 0, 0, 39, '3549'),
	(377, 1, 0, -50378, 3551, 0, 0, 39, '3550'),
	(377, 1, 0, -50378, 3552, 0, 0, 39, '3551'),
	(377, 1, 0, -50378, 3553, 0, 0, 39, '3552'),
	(377, 1, 0, -50378, 3554, 0, 0, 39, '3553'),
	(377, 1, 0, -50378, 3555, 0, 0, 39, '3554'),
	(377, 1, 0, -50378, 3556, 0, 0, 39, '3555'),
	(377, 1, 0, -50378, 3557, 0, 0, 39, '3556'),
	(377, 1, 0, -50378, 3558, 0, 0, 39, '3557'),
	(377, 1, 0, -50378, 3559, 0, 0, 39, '3558'),
	(377, 1, 0, -50378, 3560, 0, 0, 39, '3559'),
	(377, 1, 0, -50378, 3561, 0, 0, 39, '3560'),
	(377, 1, 0, -50378, 3562, 0, 0, 39, '3561'),
	(377, 1, 0, -50378, 3563, 0, 0, 39, '3562'),
	(377, 1, 0, -50378, 3564, 0, 0, 39, '3563'),
	(377, 1, 0, -50378, 3565, 0, 0, 39, '3564'),
	(377, 1, 0, -50378, 3566, 0, 0, 39, '3565'),
	(377, 1, 0, -50378, 3567, 0, 0, 39, '3566'),
	(377, 1, 0, -50378, 3568, 0, 0, 39, '3567'),
	(377, 1, 0, -50378, 3569, 0, 0, 39, '3568'),
	(377, 1, 0, -50378, 3570, 0, 0, 39, '3569'),
	(377, 1, 0, -50378, 3571, 0, 0, 39, '3570'),
	(377, 1, 0, -50378, 3572, 0, 0, 39, '3571'),
	(377, 1, 0, -50378, 3573, 0, 0, 39, '3572'),
	(377, 1, 0, -50378, 3574, 0, 0, 39, '3573'),
	(377, 1, 0, -50378, 3575, 0, 0, 39, '3574'),
	(377, 1, 0, -50378, 3576, 0, 0, 39, '3575'),
	(377, 1, 0, -50378, 3577, 0, 0, 39, '3576'),
	(377, 1, 0, -50378, 3578, 0, 0, 39, '3577'),
	(377, 1, 0, -50378, 3579, 0, 0, 39, '3578'),
	(377, 1, 0, -50378, 3580, 0, 0, 39, '3579'),
	(377, 1, 0, -50378, 3581, 0, 0, 39, '3580'),
	(377, 1, 0, -50378, 3582, 0, 0, 39, '3581'),
	(377, 1, 0, -50378, 3583, 0, 0, 39, '3582'),
	(377, 1, 0, -50378, 3584, 0, 0, 39, '3583'),
	(377, 1, 0, -50378, 3585, 0, 0, 39, '3584'),
	(377, 1, 0, -50378, 3586, 0, 0, 39, '3585'),
	(377, 1, 0, -50378, 3587, 0, 0, 39, '3586'),
	(377, 1, 0, -50378, 3588, 0, 0, 39, '3587'),
	(377, 1, 0, -50378, 3589, 0, 0, 39, '3588'),
	(377, 1, 0, -50378, 3590, 0, 0, 39, '3589'),
	(377, 1, 0, -50378, 3591, 0, 0, 39, '3590'),
	(377, 1, 0, -50378, 3592, 0, 0, 39, '3591'),
	(377, 1, 0, -50378, 3593, 0, 0, 39, '3592'),
	(377, 1, 0, -50378, 3594, 0, 0, 39, '3593'),
	(377, 1, 0, -50378, 3595, 0, 0, 39, '3594'),
	(377, 1, 0, -50378, 3596, 0, 0, 39, '3595'),
	(377, 1, 0, -50378, 3597, 0, 0, 39, '3596'),
	(377, 1, 0, -50378, 3598, 0, 0, 39, '3597'),
	(377, 1, 0, -50378, 3599, 0, 0, 39, '3598'),
	(377, 1, 0, -50378, 3600, 0, 0, 39, '3599'),
	(377, 1, 0, -50378, 3601, 0, 0, 39, '3600'),
	(377, 1, 0, -50378, 3602, 0, 0, 39, '3601'),
	(377, 1, 0, -50378, 3603, 0, 0, 39, '3602'),
	(377, 1, 0, -50378, 3604, 0, 0, 39, '3603'),
	(377, 1, 0, -50378, 3605, 0, 0, 39, '3604'),
	(377, 1, 0, -50378, 3606, 0, 0, 39, '3605'),
	(377, 1, 0, -50378, 3607, 0, 0, 39, '3606'),
	(377, 1, 0, -50378, 3608, 0, 0, 39, '3607'),
	(377, 1, 0, -50378, 3609, 0, 0, 39, '3608'),
	(377, 1, 0, -50378, 3610, 0, 0, 39, '3609'),
	(377, 1, 0, -50378, 3611, 0, 0, 39, '3610'),
	(377, 1, 0, -50378, 3612, 0, 0, 39, '3611'),
	(377, 1, 0, -50378, 3613, 0, 0, 39, '3612'),
	(377, 1, 0, -50378, 3614, 0, 0, 39, '3613'),
	(377, 1, 0, -50378, 3615, 0, 0, 39, '3614'),
	(377, 1, 0, -50378, 3616, 0, 0, 39, '3615'),
	(377, 1, 0, -50378, 3617, 0, 0, 39, '3616'),
	(377, 1, 0, -50378, 3618, 0, 0, 39, '3617'),
	(377, 1, 0, -50378, 3619, 0, 0, 39, '3618'),
	(377, 1, 0, -50378, 3620, 0, 0, 39, '3619'),
	(377, 1, 0, -50378, 3621, 0, 0, 39, '3620'),
	(377, 1, 0, -50378, 3622, 0, 0, 39, '3621'),
	(377, 1, 0, -50378, 3623, 0, 0, 39, '3622'),
	(377, 1, 0, -50378, 3624, 0, 0, 39, '3623'),
	(377, 1, 0, -50378, 3625, 0, 0, 39, '3624'),
	(377, 1, 0, -50378, 3626, 0, 0, 39, '3625'),
	(377, 1, 0, -50378, 3627, 0, 0, 39, '3626'),
	(377, 1, 0, -50378, 3628, 0, 0, 39, '3627'),
	(377, 1, 0, -50378, 3629, 0, 0, 39, '3628'),
	(377, 1, 0, -50378, 3630, 0, 0, 39, '3629'),
	(377, 1, 0, -50378, 3631, 0, 0, 39, '3630'),
	(377, 1, 0, -50378, 3632, 0, 0, 39, '3631'),
	(377, 1, 0, -50378, 3633, 0, 0, 39, '3632'),
	(377, 1, 0, -50378, 3634, 0, 0, 39, '3633'),
	(377, 1, 0, -50378, 3635, 0, 0, 39, '3634'),
	(377, 1, 0, -50378, 3636, 0, 0, 39, '3635'),
	(377, 1, 0, -50378, 3637, 0, 0, 39, '3636'),
	(377, 1, 0, -50378, 3638, 0, 0, 39, '3637'),
	(377, 1, 0, -50378, 3639, 0, 0, 39, '3638'),
	(377, 1, 0, -50378, 3640, 0, 0, 39, '3639'),
	(377, 1, 0, -50378, 3641, 0, 0, 39, '3640'),
	(377, 1, 0, -50378, 3642, 0, 0, 39, '3641'),
	(377, 1, 0, -50378, 3643, 0, 0, 39, '3642'),
	(377, 1, 0, -50378, 3644, 0, 0, 39, '3643'),
	(377, 1, 0, -50378, 3645, 0, 0, 39, '3644'),
	(377, 1, 0, -50378, 3646, 0, 0, 39, '3645'),
	(377, 1, 0, -50378, 3647, 0, 0, 39, '3646'),
	(377, 1, 0, -50378, 3648, 0, 0, 39, '3647'),
	(377, 1, 0, -50378, 3649, 0, 0, 39, '3648'),
	(377, 1, 0, -50378, 3650, 0, 0, 39, '3649'),
	(377, 1, 0, -50378, 3651, 0, 0, 39, '3650'),
	(377, 1, 0, -50378, 3652, 0, 0, 39, '3651'),
	(377, 1, 0, -50378, 3653, 0, 0, 39, '3652'),
	(377, 1, 0, -50378, 3654, 0, 0, 39, '3653'),
	(377, 1, 0, -50378, 3655, 0, 0, 39, '3654'),
	(377, 1, 0, -50378, 3656, 0, 0, 39, '3655'),
	(377, 1, 0, -50378, 3657, 0, 0, 39, '3656'),
	(377, 1, 0, -50378, 3658, 0, 0, 39, '3657'),
	(377, 1, 0, -50378, 3659, 0, 0, 39, '3658'),
	(377, 1, 0, -50378, 3660, 0, 0, 39, '3659'),
	(377, 1, 0, -50378, 3661, 0, 0, 39, '3660'),
	(377, 1, 0, -50378, 3662, 0, 0, 39, '3661'),
	(377, 1, 0, -50378, 3663, 0, 0, 39, '3662'),
	(377, 1, 0, -50378, 3664, 0, 0, 39, '3663'),
	(377, 1, 0, -50378, 3665, 0, 0, 39, '3664'),
	(377, 1, 0, -50378, 3666, 0, 0, 39, '3665'),
	(377, 1, 0, -50378, 3667, 0, 0, 39, '3666'),
	(377, 1, 0, -50378, 3668, 0, 0, 39, '3667'),
	(377, 1, 0, -50378, 3669, 0, 0, 39, '3668'),
	(377, 1, 0, -50378, 3670, 0, 0, 39, '3669'),
	(377, 1, 0, -50378, 3671, 0, 0, 39, '3670'),
	(377, 1, 0, -50378, 3672, 0, 0, 39, '3671'),
	(377, 1, 0, -50378, 3673, 0, 0, 39, '3672'),
	(377, 1, 0, -50378, 3674, 0, 0, 39, '3673'),
	(377, 1, 0, -50378, 3675, 0, 0, 39, '3674'),
	(377, 1, 0, -50378, 3676, 0, 0, 39, '3675'),
	(377, 1, 0, -50378, 3677, 0, 0, 39, '3676'),
	(377, 1, 0, -50378, 3678, 0, 0, 39, '3677'),
	(377, 1, 0, -50378, 3679, 0, 0, 39, '3678'),
	(377, 1, 0, -50378, 3680, 0, 0, 39, '3679'),
	(377, 1, 0, -50378, 3681, 0, 0, 39, '3680'),
	(377, 1, 0, -50378, 3682, 0, 0, 39, '3681'),
	(377, 1, 0, -50378, 3683, 0, 0, 39, '3682'),
	(377, 1, 0, -50378, 3684, 0, 0, 39, '3683'),
	(377, 1, 0, -50378, 3685, 0, 0, 39, '3684'),
	(377, 1, 0, -50378, 3686, 0, 0, 39, '3685'),
	(377, 1, 0, -50378, 3687, 0, 0, 39, '3686'),
	(377, 1, 0, -50378, 3688, 0, 0, 39, '3687'),
	(377, 1, 0, -50378, 3689, 0, 0, 39, '3688'),
	(377, 1, 0, -50378, 3690, 0, 0, 39, '3689'),
	(377, 1, 0, -50378, 3691, 0, 0, 39, '3690'),
	(377, 1, 0, -50378, 3692, 0, 0, 39, '3691'),
	(377, 1, 0, -50378, 3693, 0, 0, 39, '3692'),
	(377, 1, 0, -50378, 3694, 0, 0, 39, '3693'),
	(377, 1, 0, -50378, 3695, 0, 0, 39, '3694'),
	(377, 1, 0, -50378, 3696, 0, 0, 39, '3695'),
	(377, 1, 0, -50378, 3697, 0, 0, 39, '3696'),
	(377, 1, 0, -50378, 3698, 0, 0, 39, '3697'),
	(377, 1, 0, -50378, 3699, 0, 0, 39, '3698'),
	(377, 1, 0, -50378, 3700, 0, 0, 39, '3699'),
	(377, 1, 0, -50378, 3701, 0, 0, 39, '3700'),
	(377, 1, 0, -50378, 3702, 0, 0, 39, '3701'),
	(377, 1, 0, -50378, 3703, 0, 0, 39, '3702'),
	(377, 1, 0, -50378, 3704, 0, 0, 39, '3703'),
	(377, 1, 0, -50378, 3705, 0, 0, 39, '3704'),
	(377, 1, 0, -50378, 3706, 0, 0, 39, '3705'),
	(377, 1, 0, -50378, 3707, 0, 0, 39, '3706'),
	(377, 1, 0, -50378, 3708, 0, 0, 39, '3707'),
	(377, 1, 0, -50378, 3709, 0, 0, 39, '3708'),
	(377, 1, 0, -50378, 3710, 0, 0, 39, '3709'),
	(377, 1, 0, -50378, 3711, 0, 0, 39, '3710'),
	(377, 1, 0, -50378, 3712, 0, 0, 39, '3711'),
	(377, 1, 0, -50378, 3713, 0, 0, 39, '3712'),
	(377, 1, 0, -50378, 3714, 0, 0, 39, '3713'),
	(377, 1, 0, -50378, 3715, 0, 0, 39, '3714'),
	(377, 1, 0, -50378, 3716, 0, 0, 39, '3715'),
	(377, 1, 0, -50378, 3717, 0, 0, 39, '3716'),
	(377, 1, 0, -50378, 3718, 0, 0, 39, '3717'),
	(377, 1, 0, -50378, 3719, 0, 0, 39, '3718'),
	(377, 1, 0, -50378, 3720, 0, 0, 39, '3719'),
	(377, 1, 0, -50378, 3721, 0, 0, 39, '3720'),
	(377, 1, 0, -50378, 3722, 0, 0, 39, '3721'),
	(377, 1, 0, -50378, 3723, 0, 0, 39, '3722'),
	(377, 1, 0, -50378, 3724, 0, 0, 39, '3723'),
	(377, 1, 0, -50378, 3725, 0, 0, 39, '3724'),
	(377, 1, 0, -50378, 3726, 0, 0, 39, '3725'),
	(377, 1, 0, -50378, 3727, 0, 0, 39, '3726'),
	(377, 1, 0, -50378, 3728, 0, 0, 39, '3727'),
	(377, 1, 0, -50378, 3729, 0, 0, 39, '3728'),
	(377, 1, 0, -50378, 3730, 0, 0, 39, '3729'),
	(377, 1, 0, -50378, 3731, 0, 0, 39, '3730'),
	(377, 1, 0, -50378, 3732, 0, 0, 39, '3731'),
	(377, 1, 0, -50378, 3733, 0, 0, 39, '3732'),
	(377, 1, 0, -50378, 3734, 0, 0, 39, '3733'),
	(377, 1, 0, -50378, 3735, 0, 0, 39, '3734'),
	(377, 1, 0, -50378, 3736, 0, 0, 39, '3735'),
	(377, 1, 0, -50378, 3737, 0, 0, 39, '3736'),
	(377, 1, 0, -50378, 3738, 0, 0, 39, '3737'),
	(377, 1, 0, -50378, 3739, 0, 0, 39, '3738'),
	(377, 1, 0, -50378, 3740, 0, 0, 39, '3739'),
	(377, 1, 0, -50378, 3741, 0, 0, 39, '3740'),
	(377, 1, 0, -50378, 3742, 0, 0, 39, '3741'),
	(377, 1, 0, -50378, 3743, 0, 0, 39, '3742'),
	(377, 1, 0, -50378, 3744, 0, 0, 39, '3743'),
	(377, 1, 0, -50378, 3745, 0, 0, 39, '3744'),
	(377, 1, 0, -50378, 3746, 0, 0, 39, '3745'),
	(377, 1, 0, -50378, 3747, 0, 0, 39, '3746'),
	(377, 1, 0, -50378, 3748, 0, 0, 39, '3747'),
	(377, 1, 0, -50378, 3749, 0, 0, 39, '3748'),
	(377, 1, 0, -50378, 3750, 0, 0, 39, '3749'),
	(377, 1, 0, -50378, 3751, 0, 0, 39, '3750'),
	(377, 1, 0, -50378, 3752, 0, 0, 39, '3751'),
	(377, 1, 0, -50378, 3753, 0, 0, 39, '3752'),
	(377, 1, 0, -50378, 3754, 0, 0, 39, '3753'),
	(377, 1, 0, -50378, 3755, 0, 0, 39, '3754'),
	(377, 1, 0, -50378, 3756, 0, 0, 39, '3755'),
	(377, 1, 0, -50378, 3757, 0, 0, 39, '3756'),
	(377, 1, 0, -50378, 3758, 0, 0, 39, '3757'),
	(377, 1, 0, -50378, 3759, 0, 0, 39, '3758'),
	(377, 1, 0, -50378, 3760, 0, 0, 39, '3759'),
	(377, 1, 0, -50378, 3761, 0, 0, 39, '3760'),
	(377, 1, 0, -50378, 3762, 0, 0, 39, '3761'),
	(377, 1, 0, -50378, 3763, 0, 0, 39, '3762'),
	(377, 1, 0, -50378, 3764, 0, 0, 39, '3763'),
	(377, 1, 0, -50378, 3765, 0, 0, 39, '3764'),
	(377, 1, 0, -50378, 3766, 0, 0, 39, '3765'),
	(377, 1, 0, -50378, 3767, 0, 0, 39, '3766'),
	(377, 1, 0, -50378, 3768, 0, 0, 39, '3767'),
	(377, 1, 0, -50378, 3769, 0, 0, 39, '3768'),
	(377, 1, 0, -50378, 3770, 0, 0, 39, '3769'),
	(377, 1, 0, -50378, 3771, 0, 0, 39, '3770'),
	(377, 1, 0, -50378, 3772, 0, 0, 39, '3771'),
	(377, 1, 0, -50378, 3773, 0, 0, 39, '3772'),
	(377, 1, 0, -50378, 3774, 0, 0, 39, '3773'),
	(377, 1, 0, -50378, 3775, 0, 0, 39, '3774'),
	(377, 1, 0, -50378, 3776, 0, 0, 39, '3775'),
	(377, 1, 0, -50378, 3777, 0, 0, 39, '3776'),
	(377, 1, 0, -50378, 3778, 0, 0, 39, '3777'),
	(377, 1, 0, -50378, 3779, 0, 0, 39, '3778'),
	(377, 1, 0, -50378, 3780, 0, 0, 39, '3779'),
	(377, 1, 0, -50378, 3781, 0, 0, 39, '3780'),
	(377, 1, 0, -50378, 3782, 0, 0, 39, '3781'),
	(377, 1, 0, -50378, 3783, 0, 0, 39, '3782'),
	(377, 1, 0, -50378, 3784, 0, 0, 39, '3783'),
	(377, 1, 0, -50378, 3785, 0, 0, 39, '3784'),
	(377, 1, 0, -50378, 3786, 0, 0, 39, '3785'),
	(377, 1, 0, -50378, 3787, 0, 0, 39, '3786'),
	(377, 1, 0, -50378, 3788, 0, 0, 39, '3787'),
	(377, 1, 0, -50378, 3789, 0, 0, 39, '3788'),
	(377, 1, 0, -50378, 3790, 0, 0, 39, '3789'),
	(377, 1, 0, -50378, 3791, 0, 0, 39, '3790'),
	(377, 1, 0, -50378, 3792, 0, 0, 39, '3791'),
	(377, 1, 0, -50378, 3793, 0, 0, 39, '3792'),
	(377, 1, 0, -50378, 3794, 0, 0, 39, '3793'),
	(377, 1, 0, -50378, 3795, 0, 0, 39, '3794'),
	(377, 1, 0, -50378, 3796, 0, 0, 39, '3795'),
	(377, 1, 0, -50378, 3797, 0, 0, 39, '3796'),
	(377, 1, 0, -50378, 3798, 0, 0, 39, '3797'),
	(377, 1, 0, -50378, 3799, 0, 0, 39, '3798'),
	(377, 1, 0, -50378, 3800, 0, 0, 39, '3799'),
	(377, 1, 0, -50378, 3801, 0, 0, 39, '3800'),
	(377, 1, 0, -50378, 3802, 0, 0, 39, '3801'),
	(377, 1, 0, -50378, 3803, 0, 0, 39, '3802'),
	(377, 1, 0, -50378, 3804, 0, 0, 39, '3803'),
	(377, 1, 0, -50378, 3805, 0, 0, 39, '3804'),
	(377, 1, 0, -50378, 3806, 0, 0, 39, '3805'),
	(377, 1, 0, -50378, 3807, 0, 0, 39, '3806'),
	(377, 1, 0, -50378, 3808, 0, 0, 39, '3807'),
	(377, 1, 0, -50378, 3809, 0, 0, 39, '3808'),
	(377, 1, 0, -50378, 3810, 0, 0, 39, '3809'),
	(377, 1, 0, -50378, 3811, 0, 0, 39, '3810'),
	(377, 1, 0, -50378, 3812, 0, 0, 39, '3811'),
	(377, 1, 0, -50378, 3813, 0, 0, 39, '3812'),
	(377, 1, 0, -50378, 3814, 0, 0, 39, '3813'),
	(377, 1, 0, -50378, 3815, 0, 0, 39, '3814'),
	(377, 1, 0, -50378, 3816, 0, 0, 39, '3815'),
	(377, 1, 0, -50378, 3817, 0, 0, 39, '3816'),
	(377, 1, 0, -50378, 3818, 0, 0, 39, '3817'),
	(377, 1, 0, -50378, 3819, 0, 0, 39, '3818'),
	(377, 1, 0, -50378, 3820, 0, 0, 39, '3819'),
	(377, 1, 0, -50378, 3821, 0, 0, 39, '3820'),
	(377, 1, 0, -50378, 3822, 0, 0, 39, '3821'),
	(377, 1, 0, -50378, 3823, 0, 0, 39, '3822'),
	(377, 1, 0, -50378, 3824, 0, 0, 39, '3823'),
	(377, 1, 0, -50378, 3825, 0, 0, 39, '3824'),
	(377, 1, 0, -50378, 3826, 0, 0, 39, '3825'),
	(377, 1, 0, -50378, 3827, 0, 0, 39, '3826'),
	(377, 1, 0, -50378, 3828, 0, 0, 39, '3827'),
	(377, 1, 0, -50378, 3829, 0, 0, 39, '3828'),
	(377, 1, 0, -50378, 3830, 0, 0, 39, '3829'),
	(377, 1, 0, -50378, 3831, 0, 0, 39, '3830'),
	(377, 1, 0, -50378, 3832, 0, 0, 39, '3831'),
	(377, 1, 0, -50378, 3833, 0, 0, 39, '3832'),
	(377, 1, 0, -50378, 3834, 0, 0, 39, '3833'),
	(377, 1, 0, -50378, 3835, 0, 0, 39, '3834'),
	(377, 1, 0, -50378, 3836, 0, 0, 39, '3835'),
	(377, 1, 0, -50378, 3837, 0, 0, 39, '3836'),
	(377, 1, 0, -50378, 3838, 0, 0, 39, '3837'),
	(377, 1, 0, -50378, 3839, 0, 0, 39, '3838'),
	(377, 1, 0, -50378, 3840, 0, 0, 39, '3839'),
	(377, 1, 0, -50378, 3841, 0, 0, 39, '3840'),
	(377, 1, 0, -50378, 3842, 0, 0, 39, '3841'),
	(377, 1, 0, -50378, 3843, 0, 0, 39, '3842'),
	(377, 1, 0, -50378, 3844, 0, 0, 39, '3843'),
	(377, 1, 0, -50378, 3845, 0, 0, 39, '3844'),
	(377, 1, 0, -50378, 3846, 0, 0, 39, '3845'),
	(377, 1, 0, -50378, 3847, 0, 0, 39, '3846'),
	(377, 1, 0, -50378, 3848, 0, 0, 39, '3847'),
	(377, 1, 0, -50378, 3849, 0, 0, 39, '3848'),
	(377, 1, 0, -50378, 3850, 0, 0, 39, '3849'),
	(377, 1, 0, -50378, 3851, 0, 0, 39, '3850'),
	(377, 1, 0, -50378, 3852, 0, 0, 39, '3851'),
	(377, 1, 0, -50378, 3853, 0, 0, 39, '3852'),
	(377, 1, 0, -50378, 3854, 0, 0, 39, '3853'),
	(377, 1, 0, -50378, 3855, 0, 0, 39, '3854'),
	(377, 1, 0, -50378, 3856, 0, 0, 39, '3855'),
	(377, 1, 0, -50378, 3857, 0, 0, 39, '3856'),
	(377, 1, 0, -50378, 3858, 0, 0, 39, '3857'),
	(377, 1, 0, -50378, 3859, 0, 0, 39, '3858'),
	(377, 1, 0, -50378, 3860, 0, 0, 39, '3859'),
	(377, 1, 0, -50378, 3861, 0, 0, 39, '3860'),
	(377, 1, 0, -50378, 3862, 0, 0, 39, '3861'),
	(377, 1, 0, -50378, 3863, 0, 0, 39, '3862'),
	(377, 1, 0, -50378, 3864, 0, 0, 39, '3863'),
	(377, 1, 0, -50378, 3865, 0, 0, 39, '3864'),
	(377, 1, 0, -50378, 3866, 0, 0, 39, '3865'),
	(377, 1, 0, -50378, 3867, 0, 0, 39, '3866'),
	(377, 1, 0, -50378, 3868, 0, 0, 39, '3867'),
	(377, 1, 0, -50378, 3869, 0, 0, 39, '3868'),
	(377, 1, 0, -50378, 3870, 0, 0, 39, '3869'),
	(377, 1, 0, -50378, 3871, 0, 0, 39, '3870'),
	(377, 1, 0, -50378, 3872, 0, 0, 39, '3871'),
	(377, 1, 0, -50378, 3873, 0, 0, 39, '3872'),
	(377, 1, 0, -50378, 3874, 0, 0, 39, '3873'),
	(377, 1, 0, -50378, 3875, 0, 0, 39, '3874'),
	(377, 1, 0, -50378, 3876, 0, 0, 39, '3875'),
	(377, 1, 0, -50378, 3877, 0, 0, 39, '3876'),
	(377, 1, 0, -50378, 3878, 0, 0, 39, '3877'),
	(377, 1, 0, -50378, 3879, 0, 0, 39, '3878'),
	(377, 1, 0, -50378, 3880, 0, 0, 39, '3879'),
	(377, 1, 0, -50378, 3881, 0, 0, 39, '3880'),
	(377, 1, 0, -50378, 3882, 0, 0, 39, '3881'),
	(377, 1, 0, -50378, 3883, 0, 0, 39, '3882'),
	(377, 1, 0, -50378, 3884, 0, 0, 39, '3883'),
	(377, 1, 0, -50378, 3885, 0, 0, 39, '3884'),
	(377, 1, 0, -50378, 3886, 0, 0, 39, '3885'),
	(377, 1, 0, -50378, 3887, 0, 0, 39, '3886'),
	(377, 1, 0, -50378, 3888, 0, 0, 39, '3887'),
	(377, 1, 0, -50378, 3889, 0, 0, 39, '3888'),
	(377, 1, 0, -50378, 3890, 0, 0, 39, '3889'),
	(377, 1, 0, -50378, 3891, 0, 0, 39, '3890'),
	(377, 1, 0, -50378, 3892, 0, 0, 39, '3891'),
	(377, 1, 0, -50378, 3893, 0, 0, 39, '3892'),
	(377, 1, 0, -50378, 3894, 0, 0, 39, '3893'),
	(377, 1, 0, -50378, 3895, 0, 0, 39, '3894'),
	(377, 1, 0, -50378, 3896, 0, 0, 39, '3895'),
	(377, 1, 0, -50378, 3897, 0, 0, 39, '3896'),
	(377, 1, 0, -50378, 3898, 0, 0, 39, '3897'),
	(377, 1, 0, -50378, 3899, 0, 0, 39, '3898'),
	(377, 1, 0, -50378, 3900, 0, 0, 39, '3899'),
	(377, 1, 0, -50378, 3901, 0, 0, 39, '3900'),
	(377, 1, 0, -50378, 3902, 0, 0, 39, '3901'),
	(377, 1, 0, -50378, 3903, 0, 0, 39, '3902'),
	(377, 1, 0, -50378, 3904, 0, 0, 39, '3903'),
	(377, 1, 0, -50378, 3905, 0, 0, 39, '3904'),
	(377, 1, 0, -50378, 3906, 0, 0, 39, '3905'),
	(377, 1, 0, -50378, 3907, 0, 0, 39, '3906'),
	(377, 1, 0, -50378, 3908, 0, 0, 39, '3907'),
	(377, 1, 0, -50378, 3909, 0, 0, 39, '3908'),
	(377, 1, 0, -50378, 3910, 0, 0, 39, '3909'),
	(377, 1, 0, -50378, 3911, 0, 0, 39, '3910'),
	(377, 1, 0, -50378, 3912, 0, 0, 39, '3911'),
	(377, 1, 0, -50378, 3913, 0, 0, 39, '3912'),
	(377, 1, 0, -50378, 3914, 0, 0, 39, '3913'),
	(377, 1, 0, -50378, 3915, 0, 0, 39, '3914'),
	(377, 1, 0, -50378, 3916, 0, 0, 39, '3915'),
	(377, 1, 0, -50378, 3917, 0, 0, 39, '3916'),
	(377, 1, 0, -50378, 3918, 0, 0, 39, '3917'),
	(377, 1, 0, -50378, 3919, 0, 0, 39, '3918'),
	(377, 1, 0, -50378, 3920, 0, 0, 39, '3919'),
	(377, 1, 0, -50378, 3921, 0, 0, 39, '3920'),
	(377, 1, 0, -50378, 3922, 0, 0, 39, '3921'),
	(377, 1, 0, -50378, 3923, 0, 0, 39, '3922'),
	(377, 1, 0, -50378, 3924, 0, 0, 39, '3923'),
	(377, 1, 0, -50378, 3925, 0, 0, 39, '3924'),
	(377, 1, 0, -50378, 3926, 0, 0, 39, '3925'),
	(377, 1, 0, -50378, 3927, 0, 0, 39, '3926'),
	(377, 1, 0, -50378, 3928, 0, 0, 39, '3927'),
	(377, 1, 0, -50378, 3929, 0, 0, 39, '3928'),
	(377, 1, 0, -50378, 3930, 0, 0, 39, '3929'),
	(377, 1, 0, -50378, 3931, 0, 0, 39, '3930'),
	(377, 1, 0, -50378, 3932, 0, 0, 39, '3931'),
	(377, 1, 0, -50378, 3933, 0, 0, 39, '3932'),
	(377, 1, 0, -50378, 3934, 0, 0, 39, '3933'),
	(377, 1, 0, -50378, 3935, 0, 0, 39, '3934'),
	(377, 1, 0, -50378, 3936, 0, 0, 39, '3935'),
	(377, 1, 0, -50378, 3937, 0, 0, 39, '3936'),
	(377, 1, 0, -50378, 3938, 0, 0, 39, '3937'),
	(377, 1, 0, -50378, 3939, 0, 0, 39, '3938'),
	(377, 1, 0, -50378, 3940, 0, 0, 39, '3939'),
	(377, 1, 0, -50378, 3941, 0, 0, 39, '3940'),
	(377, 1, 0, -50378, 3942, 0, 0, 39, '3941'),
	(377, 1, 0, -50378, 3943, 0, 0, 39, '3942'),
	(377, 1, 0, -50378, 3944, 0, 0, 39, '3943'),
	(377, 1, 0, -50378, 3945, 0, 0, 39, '3944'),
	(377, 1, 0, -50378, 3946, 0, 0, 39, '3945'),
	(377, 1, 0, -50378, 3947, 0, 0, 39, '3946'),
	(377, 1, 0, -50378, 3948, 0, 0, 39, '3947'),
	(377, 1, 0, -50378, 3949, 0, 0, 39, '3948'),
	(377, 1, 0, -50378, 3950, 0, 0, 39, '3949'),
	(377, 1, 0, -50378, 3951, 0, 0, 39, '3950'),
	(377, 1, 0, -50378, 3952, 0, 0, 39, '3951'),
	(377, 1, 0, -50378, 3953, 0, 0, 39, '3952'),
	(377, 1, 0, -50378, 3954, 0, 0, 39, '3953'),
	(377, 1, 0, -50378, 3955, 0, 0, 39, '3954'),
	(377, 1, 0, -50378, 3956, 0, 0, 39, '3955'),
	(377, 1, 0, -50378, 3957, 0, 0, 39, '3956'),
	(377, 1, 0, -50378, 3958, 0, 0, 39, '3957'),
	(377, 1, 0, -50378, 3959, 0, 0, 39, '3958'),
	(377, 1, 0, -50378, 3960, 0, 0, 39, '3959'),
	(377, 1, 0, -50378, 3961, 0, 0, 39, '3960'),
	(377, 1, 0, -50378, 3962, 0, 0, 39, '3961'),
	(377, 1, 0, -50378, 3963, 0, 0, 39, '3962'),
	(377, 1, 0, -50378, 3964, 0, 0, 39, '3963'),
	(377, 1, 0, -50378, 3965, 0, 0, 39, '3964'),
	(377, 1, 0, -50378, 3966, 0, 0, 39, '3965'),
	(377, 1, 0, -50378, 3967, 0, 0, 39, '3966'),
	(377, 1, 0, -50378, 3968, 0, 0, 39, '3967'),
	(377, 1, 0, -50378, 3969, 0, 0, 39, '3968'),
	(377, 1, 0, -50378, 3970, 0, 0, 39, '3969'),
	(377, 1, 0, -50378, 3971, 0, 0, 39, '3970'),
	(377, 1, 0, -50378, 3972, 0, 0, 39, '3971'),
	(377, 1, 0, -50378, 3973, 0, 0, 39, '3972'),
	(377, 1, 0, -50378, 3974, 0, 0, 39, '3973'),
	(377, 1, 0, -50378, 3975, 0, 0, 39, '3974'),
	(377, 1, 0, -50378, 3976, 0, 0, 39, '3975'),
	(377, 1, 0, -50378, 3977, 0, 0, 39, '3976'),
	(377, 1, 0, -50378, 3978, 0, 0, 39, '3977'),
	(377, 1, 0, -50378, 3979, 0, 0, 39, '3978'),
	(377, 1, 0, -50378, 3980, 0, 0, 39, '3979'),
	(377, 1, 0, -50378, 3981, 0, 0, 39, '3980'),
	(377, 1, 0, -50378, 3982, 0, 0, 39, '3981'),
	(377, 1, 0, -50378, 3983, 0, 0, 39, '3982'),
	(377, 1, 0, -50378, 3984, 0, 0, 39, '3983'),
	(377, 1, 0, -50378, 3985, 0, 0, 39, '3984'),
	(377, 1, 0, -50378, 3986, 0, 0, 39, '3985'),
	(377, 1, 0, -50378, 3987, 0, 0, 39, '3986'),
	(377, 1, 0, -50378, 3988, 0, 0, 39, '3987'),
	(377, 1, 0, -50378, 3989, 0, 0, 39, '3988'),
	(377, 1, 0, -50378, 3990, 0, 0, 39, '3989'),
	(377, 1, 0, -50378, 3991, 0, 0, 39, '3990'),
	(377, 1, 0, -50378, 3992, 0, 0, 39, '3991'),
	(377, 1, 0, -50378, 3993, 0, 0, 39, '3992'),
	(377, 1, 0, -50378, 3994, 0, 0, 39, '3993'),
	(377, 1, 0, -50378, 3995, 0, 0, 39, '3994'),
	(377, 1, 0, -50378, 3996, 0, 0, 39, '3995'),
	(377, 1, 0, -50378, 3997, 0, 0, 39, '3996'),
	(377, 1, 0, -50378, 3998, 0, 0, 39, '3997'),
	(377, 1, 0, -50378, 3999, 0, 0, 39, '3998'),
	(377, 1, 0, -50378, 4000, 0, 0, 39, '3999'),
	(377, 1, 0, -50331, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50331, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50331, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50331, 4, 0, 0, 39, '3'),
	(377, 1, 0, -50331, 5, 0, 0, 39, '4'),
	(377, 1, 0, -50331, 6, 0, 0, 39, '5'),
	(377, 1, 0, -50331, 7, 0, 0, 39, '6'),
	(377, 1, 0, -50331, 8, 0, 0, 39, '7'),
	(377, 1, 0, -50331, 9, 0, 0, 39, '8'),
	(377, 1, 0, -50331, 10, 0, 0, 39, '9'),
	(377, 1, 0, -50331, 11, 0, 0, 39, '10'),
	(377, 1, 0, -50331, 12, 0, 0, 39, '11'),
	(377, 1, 0, -50331, 13, 0, 0, 39, '12'),
	(377, 1, 0, -50331, 14, 0, 0, 39, '13'),
	(377, 1, 0, -50331, 15, 0, 0, 39, '14'),
	(377, 1, 0, -50331, 16, 0, 0, 39, '15'),
	(377, 1, 0, -50331, 17, 0, 0, 39, '16'),
	(377, 1, 0, -50331, 18, 0, 0, 39, '17'),
	(377, 1, 0, -50331, 19, 0, 0, 39, '18'),
	(377, 1, 0, -50331, 20, 0, 0, 39, '19'),
	(377, 1, 0, -50331, 21, 0, 0, 39, '20'),
	(377, 1, 0, -50331, 22, 0, 0, 39, '21'),
	(377, 1, 0, -50331, 23, 0, 0, 39, '22'),
	(377, 1, 0, -50331, 24, 0, 0, 39, '23'),
	(377, 1, 0, -50331, 25, 0, 0, 39, '24'),
	(377, 1, 0, -50331, 26, 0, 0, 39, '25'),
	(377, 1, 0, -50331, 27, 0, 0, 39, '26'),
	(377, 1, 0, -50331, 28, 0, 0, 39, '27'),
	(377, 1, 0, -50331, 29, 0, 0, 39, '28'),
	(377, 1, 0, -50331, 30, 0, 0, 39, '29'),
	(377, 1, 0, -50331, 31, 0, 0, 39, '30'),
	(377, 1, 0, -50331, 32, 0, 0, 39, '31'),
	(377, 1, 0, -50331, 33, 0, 0, 39, '32'),
	(377, 1, 0, -50331, 34, 0, 0, 39, '33'),
	(377, 1, 0, -50331, 35, 0, 0, 39, '34'),
	(377, 1, 0, -50331, 36, 0, 0, 39, '35'),
	(377, 1, 0, -50331, 37, 0, 0, 39, '36'),
	(377, 1, 0, -50331, 38, 0, 0, 39, '37'),
	(377, 1, 0, -50331, 39, 0, 0, 39, '38'),
	(377, 1, 0, -50331, 40, 0, 0, 39, '39'),
	(377, 1, 0, -50331, 41, 0, 0, 39, '40'),
	(377, 1, 0, -50331, 42, 0, 0, 39, '41'),
	(377, 1, 0, -50331, 43, 0, 0, 39, '42'),
	(377, 1, 0, -50331, 44, 0, 0, 39, '43'),
	(377, 1, 0, -50331, 45, 0, 0, 39, '44'),
	(377, 1, 0, -50331, 46, 0, 0, 39, '45'),
	(377, 1, 0, -50331, 47, 0, 0, 39, '46'),
	(377, 1, 0, -50331, 48, 0, 0, 39, '47'),
	(377, 1, 0, -50331, 49, 0, 0, 39, '48'),
	(377, 1, 0, -50331, 50, 0, 0, 39, '49'),
	(377, 1, 0, -50331, 51, 0, 0, 39, '50'),
	(377, 1, 0, -50331, 52, 0, 0, 39, '51'),
	(377, 1, 0, -50331, 53, 0, 0, 39, '52'),
	(377, 1, 0, -50331, 54, 0, 0, 39, '53'),
	(377, 1, 0, -50331, 55, 0, 0, 39, '54'),
	(377, 1, 0, -50331, 56, 0, 0, 39, '55'),
	(377, 1, 0, -50331, 57, 0, 0, 39, '56'),
	(377, 1, 0, -50331, 58, 0, 0, 39, '57'),
	(377, 1, 0, -50331, 59, 0, 0, 39, '58'),
	(377, 1, 0, -50331, 60, 0, 0, 39, '59'),
	(377, 1, 0, -50331, 61, 0, 0, 39, '60'),
	(377, 1, 0, -50331, 62, 0, 0, 39, '61'),
	(377, 1, 0, -50331, 63, 0, 0, 39, '62'),
	(377, 1, 0, -50331, 64, 0, 0, 39, '63'),
	(377, 1, 0, -50331, 65, 0, 0, 39, '64'),
	(377, 1, 0, -50331, 66, 0, 0, 39, '65'),
	(377, 1, 0, -50331, 67, 0, 0, 39, '66'),
	(377, 1, 0, -50331, 68, 0, 0, 39, '67'),
	(377, 1, 0, -50331, 69, 0, 0, 39, '68'),
	(377, 1, 0, -50331, 70, 0, 0, 39, '69'),
	(377, 1, 0, -50331, 71, 0, 0, 39, '70'),
	(377, 1, 0, -50331, 72, 0, 0, 39, '71'),
	(377, 1, 0, -50331, 73, 0, 0, 39, '72'),
	(377, 1, 0, -50331, 74, 0, 0, 39, '73'),
	(377, 1, 0, -50331, 75, 0, 0, 39, '74'),
	(377, 1, 0, -50331, 76, 0, 0, 39, '75'),
	(377, 1, 0, -50331, 77, 0, 0, 39, '76'),
	(377, 1, 0, -50331, 78, 0, 0, 39, '77'),
	(377, 1, 0, -50331, 79, 0, 0, 39, '78'),
	(377, 1, 0, -50331, 80, 0, 0, 39, '79'),
	(377, 1, 0, -50331, 81, 0, 0, 39, '80'),
	(377, 1, 0, -50331, 82, 0, 0, 39, '81'),
	(377, 1, 0, -50331, 83, 0, 0, 39, '82'),
	(377, 1, 0, -50331, 84, 0, 0, 39, '83'),
	(377, 1, 0, -50331, 85, 0, 0, 39, '84'),
	(377, 1, 0, -50331, 86, 0, 0, 39, '85'),
	(377, 1, 0, -50331, 87, 0, 0, 39, '86'),
	(377, 1, 0, -50331, 88, 0, 0, 39, '87'),
	(377, 1, 0, -50331, 89, 0, 0, 39, '88'),
	(377, 1, 0, -50331, 90, 0, 0, 39, '89'),
	(377, 1, 0, -50331, 91, 0, 0, 39, '90'),
	(377, 1, 0, -50331, 92, 0, 0, 39, '91'),
	(377, 1, 0, -50331, 93, 0, 0, 39, '92'),
	(377, 1, 0, -50331, 94, 0, 0, 39, '93'),
	(377, 1, 0, -50331, 95, 0, 0, 39, '94'),
	(377, 1, 0, -50331, 96, 0, 0, 39, '95'),
	(377, 1, 0, -50331, 97, 0, 0, 39, '96'),
	(377, 1, 0, -50331, 98, 0, 0, 39, '97'),
	(377, 1, 0, -50331, 99, 0, 0, 39, '98'),
	(377, 1, 0, -50331, 100, 0, 0, 39, '99'),
	(377, 1, 0, -50331, 101, 0, 0, 39, '100'),
	(377, 1, 0, -50331, 102, 0, 0, 39, '101'),
	(377, 1, 0, -50331, 103, 0, 0, 39, '102'),
	(377, 1, 0, -50331, 104, 0, 0, 39, '103'),
	(377, 1, 0, -50331, 105, 0, 0, 39, '104'),
	(377, 1, 0, -50331, 106, 0, 0, 39, '105'),
	(377, 1, 0, -50331, 107, 0, 0, 39, '106'),
	(377, 1, 0, -50331, 108, 0, 0, 39, '107'),
	(377, 1, 0, -50331, 109, 0, 0, 39, '108'),
	(377, 1, 0, -50331, 110, 0, 0, 39, '109'),
	(377, 1, 0, -50331, 111, 0, 0, 39, '110'),
	(377, 1, 0, -50331, 112, 0, 0, 39, '111'),
	(377, 1, 0, -50331, 113, 0, 0, 39, '112'),
	(377, 1, 0, -50331, 114, 0, 0, 39, '113'),
	(377, 1, 0, -50331, 115, 0, 0, 39, '114'),
	(377, 1, 0, -50331, 116, 0, 0, 39, '115'),
	(377, 1, 0, -50331, 117, 0, 0, 39, '116'),
	(377, 1, 0, -50331, 118, 0, 0, 39, '117'),
	(377, 1, 0, -50331, 119, 0, 0, 39, '118'),
	(377, 1, 0, -50331, 120, 0, 0, 39, '119'),
	(377, 1, 0, -50331, 121, 0, 0, 39, '120'),
	(377, 1, 0, -50331, 122, 0, 0, 39, '121'),
	(377, 1, 0, -50331, 123, 0, 0, 39, '122'),
	(377, 1, 0, -50331, 124, 0, 0, 39, '123'),
	(377, 1, 0, -50331, 125, 0, 0, 39, '124'),
	(377, 1, 0, -50331, 126, 0, 0, 39, '125'),
	(377, 1, 0, -50331, 127, 0, 0, 39, '126'),
	(377, 1, 0, -50331, 128, 0, 0, 39, '127'),
	(377, 1, 0, -50331, 129, 0, 0, 39, '128'),
	(377, 1, 0, -50331, 130, 0, 0, 39, '129'),
	(377, 1, 0, -50331, 131, 0, 0, 39, '130'),
	(377, 1, 0, -50331, 132, 0, 0, 39, '131'),
	(377, 1, 0, -50331, 133, 0, 0, 39, '132'),
	(377, 1, 0, -50331, 134, 0, 0, 39, '133'),
	(377, 1, 0, -50331, 135, 0, 0, 39, '134'),
	(377, 1, 0, -50331, 136, 0, 0, 39, '135'),
	(377, 1, 0, -50331, 137, 0, 0, 39, '136'),
	(377, 1, 0, -50331, 138, 0, 0, 39, '137'),
	(377, 1, 0, -50331, 139, 0, 0, 39, '138'),
	(377, 1, 0, -50331, 140, 0, 0, 39, '139'),
	(377, 1, 0, -50331, 141, 0, 0, 39, '140'),
	(377, 1, 0, -50331, 142, 0, 0, 39, '141'),
	(377, 1, 0, -50331, 143, 0, 0, 39, '142'),
	(377, 1, 0, -50331, 144, 0, 0, 39, '143'),
	(377, 1, 0, -50331, 145, 0, 0, 39, '144'),
	(377, 1, 0, -50331, 146, 0, 0, 39, '145'),
	(377, 1, 0, -50331, 147, 0, 0, 39, '146'),
	(377, 1, 0, -50331, 148, 0, 0, 39, '147'),
	(377, 1, 0, -50331, 149, 0, 0, 39, '148'),
	(377, 1, 0, -50331, 150, 0, 0, 39, '149'),
	(377, 1, 0, -50331, 151, 0, 0, 39, '150'),
	(377, 1, 0, -50331, 152, 0, 0, 39, '151'),
	(377, 1, 0, -50331, 153, 0, 0, 39, '152'),
	(377, 1, 0, -50331, 154, 0, 0, 39, '153'),
	(377, 1, 0, -50331, 155, 0, 0, 39, '154'),
	(377, 1, 0, -50331, 156, 0, 0, 39, '155'),
	(377, 1, 0, -50331, 157, 0, 0, 39, '156'),
	(377, 1, 0, -50331, 158, 0, 0, 39, '157'),
	(377, 1, 0, -50331, 159, 0, 0, 39, '158'),
	(377, 1, 0, -50331, 160, 0, 0, 39, '159'),
	(377, 1, 0, -50331, 161, 0, 0, 39, '160'),
	(377, 1, 0, -50331, 162, 0, 0, 39, '161'),
	(377, 1, 0, -50331, 163, 0, 0, 39, '162'),
	(377, 1, 0, -50331, 164, 0, 0, 39, '163'),
	(377, 1, 0, -50331, 165, 0, 0, 39, '164'),
	(377, 1, 0, -50331, 166, 0, 0, 39, '165'),
	(377, 1, 0, -50331, 167, 0, 0, 39, '166'),
	(377, 1, 0, -50331, 168, 0, 0, 39, '167'),
	(377, 1, 0, -50331, 169, 0, 0, 39, '168'),
	(377, 1, 0, -50331, 170, 0, 0, 39, '169'),
	(377, 1, 0, -50331, 171, 0, 0, 39, '170'),
	(377, 1, 0, -50331, 172, 0, 0, 39, '171'),
	(377, 1, 0, -50331, 173, 0, 0, 39, '172'),
	(377, 1, 0, -50331, 174, 0, 0, 39, '173'),
	(377, 1, 0, -50331, 175, 0, 0, 39, '174'),
	(377, 1, 0, -50331, 176, 0, 0, 39, '175'),
	(377, 1, 0, -50331, 177, 0, 0, 39, '176'),
	(377, 1, 0, -50331, 178, 0, 0, 39, '177'),
	(377, 1, 0, -50331, 179, 0, 0, 39, '178'),
	(377, 1, 0, -50331, 180, 0, 0, 39, '179'),
	(377, 1, 0, -50331, 181, 0, 0, 39, '180'),
	(377, 1, 0, -50331, 182, 0, 0, 39, '181'),
	(377, 1, 0, -50331, 183, 0, 0, 39, '182'),
	(377, 1, 0, -50331, 184, 0, 0, 39, '183'),
	(377, 1, 0, -50331, 185, 0, 0, 39, '184'),
	(377, 1, 0, -50331, 186, 0, 0, 39, '185'),
	(377, 1, 0, -50331, 187, 0, 0, 39, '186'),
	(377, 1, 0, -50331, 188, 0, 0, 39, '187'),
	(377, 1, 0, -50331, 189, 0, 0, 39, '188'),
	(377, 1, 0, -50331, 190, 0, 0, 39, '189'),
	(377, 1, 0, -50331, 191, 0, 0, 39, '190'),
	(377, 1, 0, -50331, 192, 0, 0, 39, '191'),
	(377, 1, 0, -50331, 193, 0, 0, 39, '192'),
	(377, 1, 0, -50331, 194, 0, 0, 39, '193'),
	(377, 1, 0, -50331, 195, 0, 0, 39, '194'),
	(377, 1, 0, -50331, 196, 0, 0, 39, '195'),
	(377, 1, 0, -50331, 197, 0, 0, 39, '196'),
	(377, 1, 0, -50331, 198, 0, 0, 39, '197'),
	(377, 1, 0, -50331, 199, 0, 0, 39, '198'),
	(377, 1, 0, -50331, 200, 0, 0, 39, '199'),
	(377, 1, 0, -50331, 201, 0, 0, 39, '200'),
	(377, 1, 0, -50331, 202, 0, 0, 39, '201'),
	(377, 1, 0, -50331, 203, 0, 0, 39, '202'),
	(377, 1, 0, -50331, 204, 0, 0, 39, '203'),
	(377, 1, 0, -50331, 205, 0, 0, 39, '204'),
	(377, 1, 0, -50331, 206, 0, 0, 39, '205'),
	(377, 1, 0, -50331, 207, 0, 0, 39, '206'),
	(377, 1, 0, -50331, 208, 0, 0, 39, '207'),
	(377, 1, 0, -50331, 209, 0, 0, 39, '208'),
	(377, 1, 0, -50331, 210, 0, 0, 39, '209'),
	(377, 1, 0, -50331, 211, 0, 0, 39, '210'),
	(377, 1, 0, -50331, 212, 0, 0, 39, '211'),
	(377, 1, 0, -50331, 213, 0, 0, 39, '212'),
	(377, 1, 0, -50331, 214, 0, 0, 39, '213'),
	(377, 1, 0, -50331, 215, 0, 0, 39, '214'),
	(377, 1, 0, -50331, 216, 0, 0, 39, '215'),
	(377, 1, 0, -50331, 217, 0, 0, 39, '216'),
	(377, 1, 0, -50331, 218, 0, 0, 39, '217'),
	(377, 1, 0, -50331, 219, 0, 0, 39, '218'),
	(377, 1, 0, -50331, 220, 0, 0, 39, '219'),
	(377, 1, 0, -50331, 221, 0, 0, 39, '220'),
	(377, 1, 0, -50331, 222, 0, 0, 39, '221'),
	(377, 1, 0, -50331, 223, 0, 0, 39, '222'),
	(377, 1, 0, -50331, 224, 0, 0, 39, '223'),
	(377, 1, 0, -50331, 225, 0, 0, 39, '224'),
	(377, 1, 0, -50331, 226, 0, 0, 39, '225'),
	(377, 1, 0, -50331, 227, 0, 0, 39, '226'),
	(377, 1, 0, -50331, 228, 0, 0, 39, '227'),
	(377, 1, 0, -50331, 229, 0, 0, 39, '228'),
	(377, 1, 0, -50331, 230, 0, 0, 39, '229'),
	(377, 1, 0, -50331, 231, 0, 0, 39, '230'),
	(377, 1, 0, -50331, 232, 0, 0, 39, '231'),
	(377, 1, 0, -50331, 233, 0, 0, 39, '232'),
	(377, 1, 0, -50331, 234, 0, 0, 39, '233'),
	(377, 1, 0, -50331, 235, 0, 0, 39, '234'),
	(377, 1, 0, -50331, 236, 0, 0, 39, '235'),
	(377, 1, 0, -50331, 237, 0, 0, 39, '236'),
	(377, 1, 0, -50331, 238, 0, 0, 39, '237'),
	(377, 1, 0, -50331, 239, 0, 0, 39, '238'),
	(377, 1, 0, -50331, 240, 0, 0, 39, '239'),
	(377, 1, 0, -50331, 241, 0, 0, 39, '240'),
	(377, 1, 0, -50331, 242, 0, 0, 39, '241'),
	(377, 1, 0, -50331, 243, 0, 0, 39, '242'),
	(377, 1, 0, -50331, 244, 0, 0, 39, '243'),
	(377, 1, 0, -50331, 245, 0, 0, 39, '244'),
	(377, 1, 0, -50331, 246, 0, 0, 39, '245'),
	(377, 1, 0, -50331, 247, 0, 0, 39, '246'),
	(377, 1, 0, -50331, 248, 0, 0, 39, '247'),
	(377, 1, 0, -50331, 249, 0, 0, 39, '248'),
	(377, 1, 0, -50331, 250, 0, 0, 39, '249'),
	(377, 1, 0, -50331, 251, 0, 0, 39, '250'),
	(377, 1, 0, -50331, 252, 0, 0, 39, '251'),
	(377, 1, 0, -50331, 253, 0, 0, 39, '252'),
	(377, 1, 0, -50331, 254, 0, 0, 39, '253'),
	(377, 1, 0, -50331, 255, 0, 0, 39, '254'),
	(377, 1, 0, -50331, 256, 0, 0, 39, '255'),
	(377, 1, 0, -50331, 257, 0, 0, 39, '256'),
	(377, 1, 0, -50331, 258, 0, 0, 39, '257'),
	(377, 1, 0, -50331, 259, 0, 0, 39, '258'),
	(377, 1, 0, -50331, 260, 0, 0, 39, '259'),
	(377, 1, 0, -50331, 261, 0, 0, 39, '260'),
	(377, 1, 0, -50331, 262, 0, 0, 39, '261'),
	(377, 1, 0, -50331, 263, 0, 0, 39, '262'),
	(377, 1, 0, -50331, 264, 0, 0, 39, '263'),
	(377, 1, 0, -50331, 265, 0, 0, 39, '264'),
	(377, 1, 0, -50331, 266, 0, 0, 39, '265'),
	(377, 1, 0, -50331, 267, 0, 0, 39, '266'),
	(377, 1, 0, -50331, 268, 0, 0, 39, '267'),
	(377, 1, 0, -50331, 269, 0, 0, 39, '268'),
	(377, 1, 0, -50331, 270, 0, 0, 39, '269'),
	(377, 1, 0, -50331, 271, 0, 0, 39, '270'),
	(377, 1, 0, -50331, 272, 0, 0, 39, '271'),
	(377, 1, 0, -50331, 273, 0, 0, 39, '272'),
	(377, 1, 0, -50331, 274, 0, 0, 39, '273'),
	(377, 1, 0, -50331, 275, 0, 0, 39, '274'),
	(377, 1, 0, -50331, 276, 0, 0, 39, '275'),
	(377, 1, 0, -50331, 277, 0, 0, 39, '276'),
	(377, 1, 0, -50331, 278, 0, 0, 39, '277'),
	(377, 1, 0, -50331, 279, 0, 0, 39, '278'),
	(377, 1, 0, -50331, 280, 0, 0, 39, '279'),
	(377, 1, 0, -50331, 281, 0, 0, 39, '280'),
	(377, 1, 0, -50331, 282, 0, 0, 39, '281'),
	(377, 1, 0, -50331, 283, 0, 0, 39, '282'),
	(377, 1, 0, -50331, 284, 0, 0, 39, '283'),
	(377, 1, 0, -50331, 285, 0, 0, 39, '284'),
	(377, 1, 0, -50331, 286, 0, 0, 39, '285'),
	(377, 1, 0, -50331, 287, 0, 0, 39, '286'),
	(377, 1, 0, -50331, 288, 0, 0, 39, '287'),
	(377, 1, 0, -50331, 289, 0, 0, 39, '288'),
	(377, 1, 0, -50331, 290, 0, 0, 39, '289'),
	(377, 1, 0, -50331, 291, 0, 0, 39, '290'),
	(377, 1, 0, -50331, 292, 0, 0, 39, '291'),
	(377, 1, 0, -50331, 293, 0, 0, 39, '292'),
	(377, 1, 0, -50331, 294, 0, 0, 39, '293'),
	(377, 1, 0, -50331, 295, 0, 0, 39, '294'),
	(377, 1, 0, -50331, 296, 0, 0, 39, '295'),
	(377, 1, 0, -50331, 297, 0, 0, 39, '296'),
	(377, 1, 0, -50331, 298, 0, 0, 39, '297'),
	(377, 1, 0, -50331, 299, 0, 0, 39, '298'),
	(377, 1, 0, -50331, 300, 0, 0, 39, '299'),
	(377, 1, 0, -50331, 301, 0, 0, 39, '300'),
	(377, 1, 0, -50331, 302, 0, 0, 39, '301'),
	(377, 1, 0, -50331, 303, 0, 0, 39, '302'),
	(377, 1, 0, -50331, 304, 0, 0, 39, '303'),
	(377, 1, 0, -50331, 305, 0, 0, 39, '304'),
	(377, 1, 0, -50331, 306, 0, 0, 39, '305'),
	(377, 1, 0, -50331, 307, 0, 0, 39, '306'),
	(377, 1, 0, -50331, 308, 0, 0, 39, '307'),
	(377, 1, 0, -50331, 309, 0, 0, 39, '308'),
	(377, 1, 0, -50331, 310, 0, 0, 39, '309'),
	(377, 1, 0, -50331, 311, 0, 0, 39, '310'),
	(377, 1, 0, -50331, 312, 0, 0, 39, '311'),
	(377, 1, 0, -50331, 313, 0, 0, 39, '312'),
	(377, 1, 0, -50331, 314, 0, 0, 39, '313'),
	(377, 1, 0, -50331, 315, 0, 0, 39, '314'),
	(377, 1, 0, -50331, 316, 0, 0, 39, '315'),
	(377, 1, 0, -50331, 317, 0, 0, 39, '316'),
	(377, 1, 0, -50331, 318, 0, 0, 39, '317'),
	(377, 1, 0, -50331, 319, 0, 0, 39, '318'),
	(377, 1, 0, -50331, 320, 0, 0, 39, '319'),
	(377, 1, 0, -50331, 321, 0, 0, 39, '320'),
	(377, 1, 0, -50331, 322, 0, 0, 39, '321'),
	(377, 1, 0, -50331, 323, 0, 0, 39, '322'),
	(377, 1, 0, -50331, 324, 0, 0, 39, '323'),
	(377, 1, 0, -50331, 325, 0, 0, 39, '324'),
	(377, 1, 0, -50331, 326, 0, 0, 39, '325'),
	(377, 1, 0, -50331, 327, 0, 0, 39, '326'),
	(377, 1, 0, -50331, 328, 0, 0, 39, '327'),
	(377, 1, 0, -50331, 329, 0, 0, 39, '328'),
	(377, 1, 0, -50331, 330, 0, 0, 39, '329'),
	(377, 1, 0, -50331, 331, 0, 0, 39, '330'),
	(377, 1, 0, -50331, 332, 0, 0, 39, '331'),
	(377, 1, 0, -50331, 333, 0, 0, 39, '332'),
	(377, 1, 0, -50331, 334, 0, 0, 39, '333'),
	(377, 1, 0, -50331, 335, 0, 0, 39, '334'),
	(377, 1, 0, -50331, 336, 0, 0, 39, '335'),
	(377, 1, 0, -50331, 337, 0, 0, 39, '336'),
	(377, 1, 0, -50331, 338, 0, 0, 39, '337'),
	(377, 1, 0, -50331, 339, 0, 0, 39, '338'),
	(377, 1, 0, -50331, 340, 0, 0, 39, '339'),
	(377, 1, 0, -50331, 341, 0, 0, 39, '340'),
	(377, 1, 0, -50331, 342, 0, 0, 39, '341'),
	(377, 1, 0, -50331, 343, 0, 0, 39, '342'),
	(377, 1, 0, -50331, 344, 0, 0, 39, '343'),
	(377, 1, 0, -50331, 345, 0, 0, 39, '344'),
	(377, 1, 0, -50331, 346, 0, 0, 39, '345'),
	(377, 1, 0, -50331, 347, 0, 0, 39, '346'),
	(377, 1, 0, -50331, 348, 0, 0, 39, '347'),
	(377, 1, 0, -50331, 349, 0, 0, 39, '348'),
	(377, 1, 0, -50331, 350, 0, 0, 39, '349'),
	(377, 1, 0, -50331, 351, 0, 0, 39, '350'),
	(377, 1, 0, -50331, 352, 0, 0, 39, '351'),
	(377, 1, 0, -50331, 353, 0, 0, 39, '352'),
	(377, 1, 0, -50331, 354, 0, 0, 39, '353'),
	(377, 1, 0, -50331, 355, 0, 0, 39, '354'),
	(377, 1, 0, -50331, 356, 0, 0, 39, '355'),
	(377, 1, 0, -50331, 357, 0, 0, 39, '356'),
	(377, 1, 0, -50331, 358, 0, 0, 39, '357'),
	(377, 1, 0, -50331, 359, 0, 0, 39, '358'),
	(377, 1, 0, -50331, 360, 0, 0, 39, '359'),
	(377, 1, 0, -50331, 361, 0, 0, 39, '360'),
	(377, 1, 0, -50331, 362, 0, 0, 39, '361'),
	(377, 1, 0, -50331, 363, 0, 0, 39, '362'),
	(377, 1, 0, -50331, 364, 0, 0, 39, '363'),
	(377, 1, 0, -50331, 365, 0, 0, 39, '364'),
	(377, 1, 0, -50331, 366, 0, 0, 39, '365'),
	(377, 1, 0, -50331, 367, 0, 0, 39, '366'),
	(377, 1, 0, -50331, 368, 0, 0, 39, '367'),
	(377, 1, 0, -50331, 369, 0, 0, 39, '368'),
	(377, 1, 0, -50331, 370, 0, 0, 39, '369'),
	(377, 1, 0, -50331, 371, 0, 0, 39, '370'),
	(377, 1, 0, -50331, 372, 0, 0, 39, '371'),
	(377, 1, 0, -50331, 373, 0, 0, 39, '372'),
	(377, 1, 0, -50331, 374, 0, 0, 39, '373'),
	(377, 1, 0, -50331, 375, 0, 0, 39, '374'),
	(377, 1, 0, -50331, 376, 0, 0, 39, '375'),
	(377, 1, 0, -50331, 377, 0, 0, 39, '376'),
	(377, 1, 0, -50331, 378, 0, 0, 39, '377'),
	(377, 1, 0, -50331, 379, 0, 0, 39, '378'),
	(377, 1, 0, -50331, 380, 0, 0, 39, '379'),
	(377, 1, 0, -50331, 381, 0, 0, 39, '380'),
	(377, 1, 0, -50331, 382, 0, 0, 39, '381'),
	(377, 1, 0, -50331, 383, 0, 0, 39, '382'),
	(377, 1, 0, -50331, 384, 0, 0, 39, '383'),
	(377, 1, 0, -50331, 385, 0, 0, 39, '384'),
	(377, 1, 0, -50331, 386, 0, 0, 39, '385'),
	(377, 1, 0, -50331, 387, 0, 0, 39, '386'),
	(377, 1, 0, -50331, 388, 0, 0, 39, '387'),
	(377, 1, 0, -50331, 389, 0, 0, 39, '388'),
	(377, 1, 0, -50331, 390, 0, 0, 39, '389'),
	(377, 1, 0, -50331, 391, 0, 0, 39, '390'),
	(377, 1, 0, -50331, 392, 0, 0, 39, '391'),
	(377, 1, 0, -50331, 393, 0, 0, 39, '392'),
	(377, 1, 0, -50331, 394, 0, 0, 39, '393'),
	(377, 1, 0, -50331, 395, 0, 0, 39, '394'),
	(377, 1, 0, -50331, 396, 0, 0, 39, '395'),
	(377, 1, 0, -50331, 397, 0, 0, 39, '396'),
	(377, 1, 0, -50331, 398, 0, 0, 39, '397'),
	(377, 1, 0, -50331, 399, 0, 0, 39, '398'),
	(377, 1, 0, -50331, 400, 0, 0, 39, '399'),
	(377, 1, 0, -50331, 401, 0, 0, 39, '400'),
	(377, 1, 0, -50331, 402, 0, 0, 39, '401'),
	(377, 1, 0, -50331, 403, 0, 0, 39, '402'),
	(377, 1, 0, -50331, 404, 0, 0, 39, '403'),
	(377, 1, 0, -50331, 405, 0, 0, 39, '404'),
	(377, 1, 0, -50331, 406, 0, 0, 39, '405'),
	(377, 1, 0, -50331, 407, 0, 0, 39, '406'),
	(377, 1, 0, -50331, 408, 0, 0, 39, '407'),
	(377, 1, 0, -50331, 409, 0, 0, 39, '408'),
	(377, 1, 0, -50331, 410, 0, 0, 39, '409'),
	(377, 1, 0, -50331, 411, 0, 0, 39, '410'),
	(377, 1, 0, -50331, 412, 0, 0, 39, '411'),
	(377, 1, 0, -50331, 413, 0, 0, 39, '412'),
	(377, 1, 0, -50331, 414, 0, 0, 39, '413'),
	(377, 1, 0, -50331, 415, 0, 0, 39, '414'),
	(377, 1, 0, -50331, 416, 0, 0, 39, '415'),
	(377, 1, 0, -50331, 417, 0, 0, 39, '416'),
	(377, 1, 0, -50331, 418, 0, 0, 39, '417'),
	(377, 1, 0, -50331, 419, 0, 0, 39, '418'),
	(377, 1, 0, -50331, 420, 0, 0, 39, '419'),
	(377, 1, 0, -50331, 421, 0, 0, 39, '420'),
	(377, 1, 0, -50331, 422, 0, 0, 39, '421'),
	(377, 1, 0, -50331, 423, 0, 0, 39, '422'),
	(377, 1, 0, -50331, 424, 0, 0, 39, '423'),
	(377, 1, 0, -50331, 425, 0, 0, 39, '424'),
	(377, 1, 0, -50331, 426, 0, 0, 39, '425'),
	(377, 1, 0, -50331, 427, 0, 0, 39, '426'),
	(377, 1, 0, -50331, 428, 0, 0, 39, '427'),
	(377, 1, 0, -50331, 429, 0, 0, 39, '428'),
	(377, 1, 0, -50331, 430, 0, 0, 39, '429'),
	(377, 1, 0, -50331, 431, 0, 0, 39, '430'),
	(377, 1, 0, -50331, 432, 0, 0, 39, '431'),
	(377, 1, 0, -50331, 433, 0, 0, 39, '432'),
	(377, 1, 0, -50331, 434, 0, 0, 39, '433'),
	(377, 1, 0, -50331, 435, 0, 0, 39, '434'),
	(377, 1, 0, -50331, 436, 0, 0, 39, '435'),
	(377, 1, 0, -50331, 437, 0, 0, 39, '436'),
	(377, 1, 0, -50331, 438, 0, 0, 39, '437'),
	(377, 1, 0, -50331, 439, 0, 0, 39, '438'),
	(377, 1, 0, -50331, 440, 0, 0, 39, '439'),
	(377, 1, 0, -50331, 441, 0, 0, 39, '440'),
	(377, 1, 0, -50331, 442, 0, 0, 39, '441'),
	(377, 1, 0, -50331, 443, 0, 0, 39, '442'),
	(377, 1, 0, -50331, 444, 0, 0, 39, '443'),
	(377, 1, 0, -50331, 445, 0, 0, 39, '444'),
	(377, 1, 0, -50331, 446, 0, 0, 39, '445'),
	(377, 1, 0, -50331, 447, 0, 0, 39, '446'),
	(377, 1, 0, -50331, 448, 0, 0, 39, '447'),
	(377, 1, 0, -50331, 449, 0, 0, 39, '448'),
	(377, 1, 0, -50331, 450, 0, 0, 39, '449'),
	(377, 1, 0, -50331, 451, 0, 0, 39, '450'),
	(377, 1, 0, -50331, 452, 0, 0, 39, '451'),
	(377, 1, 0, -50331, 453, 0, 0, 39, '452'),
	(377, 1, 0, -50331, 454, 0, 0, 39, '453'),
	(377, 1, 0, -50331, 455, 0, 0, 39, '454'),
	(377, 1, 0, -50331, 456, 0, 0, 39, '455'),
	(377, 1, 0, -50331, 457, 0, 0, 39, '456'),
	(377, 1, 0, -50331, 458, 0, 0, 39, '457'),
	(377, 1, 0, -50331, 459, 0, 0, 39, '458'),
	(377, 1, 0, -50331, 460, 0, 0, 39, '459'),
	(377, 1, 0, -50331, 461, 0, 0, 39, '460'),
	(377, 1, 0, -50331, 462, 0, 0, 39, '461'),
	(377, 1, 0, -50331, 463, 0, 0, 39, '462'),
	(377, 1, 0, -50331, 464, 0, 0, 39, '463'),
	(377, 1, 0, -50331, 465, 0, 0, 39, '464'),
	(377, 1, 0, -50331, 466, 0, 0, 39, '465'),
	(377, 1, 0, -50331, 467, 0, 0, 39, '466'),
	(377, 1, 0, -50331, 468, 0, 0, 39, '467'),
	(377, 1, 0, -50331, 469, 0, 0, 39, '468'),
	(377, 1, 0, -50331, 470, 0, 0, 39, '469'),
	(377, 1, 0, -50331, 471, 0, 0, 39, '470'),
	(377, 1, 0, -50331, 472, 0, 0, 39, '471'),
	(377, 1, 0, -50331, 473, 0, 0, 39, '472'),
	(377, 1, 0, -50331, 474, 0, 0, 39, '473'),
	(377, 1, 0, -50331, 475, 0, 0, 39, '474'),
	(377, 1, 0, -50331, 476, 0, 0, 39, '475'),
	(377, 1, 0, -50331, 477, 0, 0, 39, '476'),
	(377, 1, 0, -50331, 478, 0, 0, 39, '477'),
	(377, 1, 0, -50331, 479, 0, 0, 39, '478'),
	(377, 1, 0, -50331, 480, 0, 0, 39, '479'),
	(377, 1, 0, -50331, 481, 0, 0, 39, '480'),
	(377, 1, 0, -50331, 482, 0, 0, 39, '481'),
	(377, 1, 0, -50331, 483, 0, 0, 39, '482'),
	(377, 1, 0, -50331, 484, 0, 0, 39, '483'),
	(377, 1, 0, -50331, 485, 0, 0, 39, '484'),
	(377, 1, 0, -50331, 486, 0, 0, 39, '485'),
	(377, 1, 0, -50331, 487, 0, 0, 39, '486'),
	(377, 1, 0, -50331, 488, 0, 0, 39, '487'),
	(377, 1, 0, -50331, 489, 0, 0, 39, '488'),
	(377, 1, 0, -50331, 490, 0, 0, 39, '489'),
	(377, 1, 0, -50331, 491, 0, 0, 39, '490'),
	(377, 1, 0, -50331, 492, 0, 0, 39, '491'),
	(377, 1, 0, -50331, 493, 0, 0, 39, '492'),
	(377, 1, 0, -50331, 494, 0, 0, 39, '493'),
	(377, 1, 0, -50331, 495, 0, 0, 39, '494'),
	(377, 1, 0, -50331, 496, 0, 0, 39, '495'),
	(377, 1, 0, -50331, 497, 0, 0, 39, '496'),
	(377, 1, 0, -50331, 498, 0, 0, 39, '497'),
	(377, 1, 0, -50331, 499, 0, 0, 39, '498'),
	(377, 1, 0, -50331, 500, 0, 0, 39, '499'),
	(377, 1, 0, -50331, 501, 0, 0, 39, '500'),
	(377, 1, 0, -50331, 502, 0, 0, 39, '501'),
	(377, 1, 0, -50331, 503, 0, 0, 39, '502'),
	(377, 1, 0, -50331, 504, 0, 0, 39, '503'),
	(377, 1, 0, -50331, 505, 0, 0, 39, '504'),
	(377, 1, 0, -50331, 506, 0, 0, 39, '505'),
	(377, 1, 0, -50331, 507, 0, 0, 39, '506'),
	(377, 1, 0, -50331, 508, 0, 0, 39, '507'),
	(377, 1, 0, -50331, 509, 0, 0, 39, '508'),
	(377, 1, 0, -50331, 510, 0, 0, 39, '509'),
	(377, 1, 0, -50331, 511, 0, 0, 39, '510'),
	(377, 1, 0, -50331, 512, 0, 0, 39, '511'),
	(377, 1, 0, -50331, 513, 0, 0, 39, '512'),
	(377, 1, 0, -50331, 514, 0, 0, 39, '513'),
	(377, 1, 0, -50331, 515, 0, 0, 39, '514'),
	(377, 1, 0, -50331, 516, 0, 0, 39, '515'),
	(377, 1, 0, -50331, 517, 0, 0, 39, '516'),
	(377, 1, 0, -50331, 518, 0, 0, 39, '517'),
	(377, 1, 0, -50331, 519, 0, 0, 39, '518'),
	(377, 1, 0, -50331, 520, 0, 0, 39, '519'),
	(377, 1, 0, -50331, 521, 0, 0, 39, '520'),
	(377, 1, 0, -50331, 522, 0, 0, 39, '521'),
	(377, 1, 0, -50331, 523, 0, 0, 39, '522'),
	(377, 1, 0, -50331, 524, 0, 0, 39, '523'),
	(377, 1, 0, -50331, 525, 0, 0, 39, '524'),
	(377, 1, 0, -50331, 526, 0, 0, 39, '525'),
	(377, 1, 0, -50331, 527, 0, 0, 39, '526'),
	(377, 1, 0, -50331, 528, 0, 0, 39, '527'),
	(377, 1, 0, -50331, 529, 0, 0, 39, '528'),
	(377, 1, 0, -50331, 530, 0, 0, 39, '529'),
	(377, 1, 0, -50331, 531, 0, 0, 39, '530'),
	(377, 1, 0, -50331, 532, 0, 0, 39, '531'),
	(377, 1, 0, -50331, 533, 0, 0, 39, '532'),
	(377, 1, 0, -50331, 534, 0, 0, 39, '533'),
	(377, 1, 0, -50331, 535, 0, 0, 39, '534'),
	(377, 1, 0, -50331, 536, 0, 0, 39, '535'),
	(377, 1, 0, -50331, 537, 0, 0, 39, '536'),
	(377, 1, 0, -50331, 538, 0, 0, 39, '537'),
	(377, 1, 0, -50331, 539, 0, 0, 39, '538'),
	(377, 1, 0, -50331, 540, 0, 0, 39, '539'),
	(377, 1, 0, -50331, 541, 0, 0, 39, '540'),
	(377, 1, 0, -50331, 542, 0, 0, 39, '541'),
	(377, 1, 0, -50331, 543, 0, 0, 39, '542'),
	(377, 1, 0, -50331, 544, 0, 0, 39, '543'),
	(377, 1, 0, -50331, 545, 0, 0, 39, '544'),
	(377, 1, 0, -50331, 546, 0, 0, 39, '545'),
	(377, 1, 0, -50331, 547, 0, 0, 39, '546'),
	(377, 1, 0, -50331, 548, 0, 0, 39, '547'),
	(377, 1, 0, -50331, 549, 0, 0, 39, '548'),
	(377, 1, 0, -50331, 550, 0, 0, 39, '549'),
	(377, 1, 0, -50331, 551, 0, 0, 39, '550'),
	(377, 1, 0, -50331, 552, 0, 0, 39, '551'),
	(377, 1, 0, -50331, 553, 0, 0, 39, '552'),
	(377, 1, 0, -50331, 554, 0, 0, 39, '553'),
	(377, 1, 0, -50331, 555, 0, 0, 39, '554'),
	(377, 1, 0, -50331, 556, 0, 0, 39, '555'),
	(377, 1, 0, -50331, 557, 0, 0, 39, '556'),
	(377, 1, 0, -50331, 558, 0, 0, 39, '557'),
	(377, 1, 0, -50331, 559, 0, 0, 39, '558'),
	(377, 1, 0, -50331, 560, 0, 0, 39, '559'),
	(377, 1, 0, -50331, 561, 0, 0, 39, '560'),
	(377, 1, 0, -50331, 562, 0, 0, 39, '561'),
	(377, 1, 0, -50331, 563, 0, 0, 39, '562'),
	(377, 1, 0, -50331, 564, 0, 0, 39, '563'),
	(377, 1, 0, -50331, 565, 0, 0, 39, '564'),
	(377, 1, 0, -50331, 566, 0, 0, 39, '565'),
	(377, 1, 0, -50331, 567, 0, 0, 39, '566'),
	(377, 1, 0, -50331, 568, 0, 0, 39, '567'),
	(377, 1, 0, -50331, 569, 0, 0, 39, '568'),
	(377, 1, 0, -50331, 570, 0, 0, 39, '569'),
	(377, 1, 0, -50331, 571, 0, 0, 39, '570'),
	(377, 1, 0, -50331, 572, 0, 0, 39, '571'),
	(377, 1, 0, -50331, 573, 0, 0, 39, '572'),
	(377, 1, 0, -50331, 574, 0, 0, 39, '573'),
	(377, 1, 0, -50331, 575, 0, 0, 39, '574'),
	(377, 1, 0, -50331, 576, 0, 0, 39, '575'),
	(377, 1, 0, -50331, 577, 0, 0, 39, '576'),
	(377, 1, 0, -50331, 578, 0, 0, 39, '577'),
	(377, 1, 0, -50331, 579, 0, 0, 39, '578'),
	(377, 1, 0, -50331, 580, 0, 0, 39, '579'),
	(377, 1, 0, -50331, 581, 0, 0, 39, '580'),
	(377, 1, 0, -50331, 582, 0, 0, 39, '581'),
	(377, 1, 0, -50331, 583, 0, 0, 39, '582'),
	(377, 1, 0, -50331, 584, 0, 0, 39, '583'),
	(377, 1, 0, -50331, 585, 0, 0, 39, '584'),
	(377, 1, 0, -50331, 586, 0, 0, 39, '585'),
	(377, 1, 0, -50331, 587, 0, 0, 39, '586'),
	(377, 1, 0, -50331, 588, 0, 0, 39, '587'),
	(377, 1, 0, -50331, 589, 0, 0, 39, '588'),
	(377, 1, 0, -50331, 590, 0, 0, 39, '589'),
	(377, 1, 0, -50331, 591, 0, 0, 39, '590'),
	(377, 1, 0, -50331, 592, 0, 0, 39, '591'),
	(377, 1, 0, -50331, 593, 0, 0, 39, '592'),
	(377, 1, 0, -50331, 594, 0, 0, 39, '593'),
	(377, 1, 0, -50331, 595, 0, 0, 39, '594'),
	(377, 1, 0, -50331, 596, 0, 0, 39, '595'),
	(377, 1, 0, -50331, 597, 0, 0, 39, '596'),
	(377, 1, 0, -50331, 598, 0, 0, 39, '597'),
	(377, 1, 0, -50331, 599, 0, 0, 39, '598'),
	(377, 1, 0, -50331, 600, 0, 0, 39, '599'),
	(377, 1, 0, -50331, 601, 0, 0, 39, '600'),
	(377, 1, 0, -50331, 602, 0, 0, 39, '601'),
	(377, 1, 0, -50331, 603, 0, 0, 39, '602'),
	(377, 1, 0, -50331, 604, 0, 0, 39, '603'),
	(377, 1, 0, -50331, 605, 0, 0, 39, '604'),
	(377, 1, 0, -50331, 606, 0, 0, 39, '605'),
	(377, 1, 0, -50331, 607, 0, 0, 39, '606'),
	(377, 1, 0, -50331, 608, 0, 0, 39, '607'),
	(377, 1, 0, -50331, 609, 0, 0, 39, '608'),
	(377, 1, 0, -50331, 610, 0, 0, 39, '609'),
	(377, 1, 0, -50331, 611, 0, 0, 39, '610'),
	(377, 1, 0, -50331, 612, 0, 0, 39, '611'),
	(377, 1, 0, -50331, 613, 0, 0, 39, '612'),
	(377, 1, 0, -50331, 614, 0, 0, 39, '613'),
	(377, 1, 0, -50331, 615, 0, 0, 39, '614'),
	(377, 1, 0, -50331, 616, 0, 0, 39, '615'),
	(377, 1, 0, -50331, 617, 0, 0, 39, '616'),
	(377, 1, 0, -50331, 618, 0, 0, 39, '617'),
	(377, 1, 0, -50331, 619, 0, 0, 39, '618'),
	(377, 1, 0, -50331, 620, 0, 0, 39, '619'),
	(377, 1, 0, -50331, 621, 0, 0, 39, '620'),
	(377, 1, 0, -50331, 622, 0, 0, 39, '621'),
	(377, 1, 0, -50331, 623, 0, 0, 39, '622'),
	(377, 1, 0, -50331, 624, 0, 0, 39, '623'),
	(377, 1, 0, -50331, 625, 0, 0, 39, '624'),
	(377, 1, 0, -50331, 626, 0, 0, 39, '625'),
	(377, 1, 0, -50331, 627, 0, 0, 39, '626'),
	(377, 1, 0, -50331, 628, 0, 0, 39, '627'),
	(377, 1, 0, -50331, 629, 0, 0, 39, '628'),
	(377, 1, 0, -50331, 630, 0, 0, 39, '629'),
	(377, 1, 0, -50331, 631, 0, 0, 39, '630'),
	(377, 1, 0, -50331, 632, 0, 0, 39, '631'),
	(377, 1, 0, -50331, 633, 0, 0, 39, '632'),
	(377, 1, 0, -50331, 634, 0, 0, 39, '633'),
	(377, 1, 0, -50331, 635, 0, 0, 39, '634'),
	(377, 1, 0, -50331, 636, 0, 0, 39, '635'),
	(377, 1, 0, -50331, 637, 0, 0, 39, '636'),
	(377, 1, 0, -50331, 638, 0, 0, 39, '637'),
	(377, 1, 0, -50331, 639, 0, 0, 39, '638'),
	(377, 1, 0, -50331, 640, 0, 0, 39, '639'),
	(377, 1, 0, -50331, 641, 0, 0, 39, '640'),
	(377, 1, 0, -50331, 642, 0, 0, 39, '641'),
	(377, 1, 0, -50331, 643, 0, 0, 39, '642'),
	(377, 1, 0, -50331, 644, 0, 0, 39, '643'),
	(377, 1, 0, -50331, 645, 0, 0, 39, '644'),
	(377, 1, 0, -50331, 646, 0, 0, 39, '645'),
	(377, 1, 0, -50331, 647, 0, 0, 39, '646'),
	(377, 1, 0, -50331, 648, 0, 0, 39, '647'),
	(377, 1, 0, -50331, 649, 0, 0, 39, '648'),
	(377, 1, 0, -50331, 650, 0, 0, 39, '649'),
	(377, 1, 0, -50331, 651, 0, 0, 39, '650'),
	(377, 1, 0, -50331, 652, 0, 0, 39, '651'),
	(377, 1, 0, -50331, 653, 0, 0, 39, '652'),
	(377, 1, 0, -50331, 654, 0, 0, 39, '653'),
	(377, 1, 0, -50331, 655, 0, 0, 39, '654'),
	(377, 1, 0, -50331, 656, 0, 0, 39, '655'),
	(377, 1, 0, -50331, 657, 0, 0, 39, '656'),
	(377, 1, 0, -50331, 658, 0, 0, 39, '657'),
	(377, 1, 0, -50331, 659, 0, 0, 39, '658'),
	(377, 1, 0, -50331, 660, 0, 0, 39, '659'),
	(377, 1, 0, -50331, 661, 0, 0, 39, '660'),
	(377, 1, 0, -50331, 662, 0, 0, 39, '661'),
	(377, 1, 0, -50331, 663, 0, 0, 39, '662'),
	(377, 1, 0, -50331, 664, 0, 0, 39, '663'),
	(377, 1, 0, -50331, 665, 0, 0, 39, '664'),
	(377, 1, 0, -50331, 666, 0, 0, 39, '665'),
	(377, 1, 0, -50331, 667, 0, 0, 39, '666'),
	(377, 1, 0, -50331, 668, 0, 0, 39, '667'),
	(377, 1, 0, -50331, 669, 0, 0, 39, '668'),
	(377, 1, 0, -50331, 670, 0, 0, 39, '669'),
	(377, 1, 0, -50331, 671, 0, 0, 39, '670'),
	(377, 1, 0, -50331, 672, 0, 0, 39, '671'),
	(377, 1, 0, -50331, 673, 0, 0, 39, '672'),
	(377, 1, 0, -50331, 674, 0, 0, 39, '673'),
	(377, 1, 0, -50331, 675, 0, 0, 39, '674'),
	(377, 1, 0, -50331, 676, 0, 0, 39, '675'),
	(377, 1, 0, -50331, 677, 0, 0, 39, '676'),
	(377, 1, 0, -50331, 678, 0, 0, 39, '677'),
	(377, 1, 0, -50331, 679, 0, 0, 39, '678'),
	(377, 1, 0, -50331, 680, 0, 0, 39, '679'),
	(377, 1, 0, -50331, 681, 0, 0, 39, '680'),
	(377, 1, 0, -50331, 682, 0, 0, 39, '681'),
	(377, 1, 0, -50331, 683, 0, 0, 39, '682'),
	(377, 1, 0, -50331, 684, 0, 0, 39, '683'),
	(377, 1, 0, -50331, 685, 0, 0, 39, '684'),
	(377, 1, 0, -50331, 686, 0, 0, 39, '685'),
	(377, 1, 0, -50331, 687, 0, 0, 39, '686'),
	(377, 1, 0, -50331, 688, 0, 0, 39, '687'),
	(377, 1, 0, -50331, 689, 0, 0, 39, '688'),
	(377, 1, 0, -50331, 690, 0, 0, 39, '689'),
	(377, 1, 0, -50331, 691, 0, 0, 39, '690'),
	(377, 1, 0, -50331, 692, 0, 0, 39, '691'),
	(377, 1, 0, -50331, 693, 0, 0, 39, '692'),
	(377, 1, 0, -50331, 694, 0, 0, 39, '693'),
	(377, 1, 0, -50331, 695, 0, 0, 39, '694'),
	(377, 1, 0, -50331, 696, 0, 0, 39, '695'),
	(377, 1, 0, -50331, 697, 0, 0, 39, '696'),
	(377, 1, 0, -50331, 698, 0, 0, 39, '697'),
	(377, 1, 0, -50331, 699, 0, 0, 39, '698'),
	(377, 1, 0, -50331, 700, 0, 0, 39, '699'),
	(377, 1, 0, -50331, 701, 0, 0, 39, '700'),
	(377, 1, 0, -50331, 702, 0, 0, 39, '701'),
	(377, 1, 0, -50331, 703, 0, 0, 39, '702'),
	(377, 1, 0, -50331, 704, 0, 0, 39, '703'),
	(377, 1, 0, -50331, 705, 0, 0, 39, '704'),
	(377, 1, 0, -50331, 706, 0, 0, 39, '705'),
	(377, 1, 0, -50331, 707, 0, 0, 39, '706'),
	(377, 1, 0, -50331, 708, 0, 0, 39, '707'),
	(377, 1, 0, -50331, 709, 0, 0, 39, '708'),
	(377, 1, 0, -50331, 710, 0, 0, 39, '709'),
	(377, 1, 0, -50331, 711, 0, 0, 39, '710'),
	(377, 1, 0, -50331, 712, 0, 0, 39, '711'),
	(377, 1, 0, -50331, 713, 0, 0, 39, '712'),
	(377, 1, 0, -50331, 714, 0, 0, 39, '713'),
	(377, 1, 0, -50331, 715, 0, 0, 39, '714'),
	(377, 1, 0, -50331, 716, 0, 0, 39, '715'),
	(377, 1, 0, -50331, 717, 0, 0, 39, '716'),
	(377, 1, 0, -50331, 718, 0, 0, 39, '717'),
	(377, 1, 0, -50331, 719, 0, 0, 39, '718'),
	(377, 1, 0, -50331, 720, 0, 0, 39, '719'),
	(377, 1, 0, -50331, 721, 0, 0, 39, '720'),
	(377, 1, 0, -50331, 722, 0, 0, 39, '721'),
	(377, 1, 0, -50331, 723, 0, 0, 39, '722'),
	(377, 1, 0, -50331, 724, 0, 0, 39, '723'),
	(377, 1, 0, -50331, 725, 0, 0, 39, '724'),
	(377, 1, 0, -50331, 726, 0, 0, 39, '725'),
	(377, 1, 0, -50331, 727, 0, 0, 39, '726'),
	(377, 1, 0, -50331, 728, 0, 0, 39, '727'),
	(377, 1, 0, -50331, 729, 0, 0, 39, '728'),
	(377, 1, 0, -50331, 730, 0, 0, 39, '729'),
	(377, 1, 0, -50331, 731, 0, 0, 39, '730'),
	(377, 1, 0, -50331, 732, 0, 0, 39, '731'),
	(377, 1, 0, -50331, 733, 0, 0, 39, '732'),
	(377, 1, 0, -50331, 734, 0, 0, 39, '733'),
	(377, 1, 0, -50331, 735, 0, 0, 39, '734'),
	(377, 1, 0, -50331, 736, 0, 0, 39, '735'),
	(377, 1, 0, -50331, 737, 0, 0, 39, '736'),
	(377, 1, 0, -50331, 738, 0, 0, 39, '737'),
	(377, 1, 0, -50331, 739, 0, 0, 39, '738'),
	(377, 1, 0, -50331, 740, 0, 0, 39, '739'),
	(377, 1, 0, -50331, 741, 0, 0, 39, '740'),
	(377, 1, 0, -50331, 742, 0, 0, 39, '741'),
	(377, 1, 0, -50331, 743, 0, 0, 39, '742'),
	(377, 1, 0, -50331, 744, 0, 0, 39, '743'),
	(377, 1, 0, -50331, 745, 0, 0, 39, '744'),
	(377, 1, 0, -50331, 746, 0, 0, 39, '745'),
	(377, 1, 0, -50331, 747, 0, 0, 39, '746'),
	(377, 1, 0, -50331, 748, 0, 0, 39, '747'),
	(377, 1, 0, -50331, 749, 0, 0, 39, '748'),
	(377, 1, 0, -50331, 750, 0, 0, 39, '749'),
	(377, 1, 0, -50331, 751, 0, 0, 39, '750'),
	(377, 1, 0, -50331, 752, 0, 0, 39, '751'),
	(377, 1, 0, -50331, 753, 0, 0, 39, '752'),
	(377, 1, 0, -50331, 754, 0, 0, 39, '753'),
	(377, 1, 0, -50331, 755, 0, 0, 39, '754'),
	(377, 1, 0, -50331, 756, 0, 0, 39, '755'),
	(377, 1, 0, -50331, 757, 0, 0, 39, '756'),
	(377, 1, 0, -50331, 758, 0, 0, 39, '757'),
	(377, 1, 0, -50331, 759, 0, 0, 39, '758'),
	(377, 1, 0, -50331, 760, 0, 0, 39, '759'),
	(377, 1, 0, -50331, 761, 0, 0, 39, '760'),
	(377, 1, 0, -50331, 762, 0, 0, 39, '761'),
	(377, 1, 0, -50331, 763, 0, 0, 39, '762'),
	(377, 1, 0, -50331, 764, 0, 0, 39, '763'),
	(377, 1, 0, -50331, 765, 0, 0, 39, '764'),
	(377, 1, 0, -50331, 766, 0, 0, 39, '765'),
	(377, 1, 0, -50331, 767, 0, 0, 39, '766'),
	(377, 1, 0, -50331, 768, 0, 0, 39, '767'),
	(377, 1, 0, -50331, 769, 0, 0, 39, '768'),
	(377, 1, 0, -50331, 770, 0, 0, 39, '769'),
	(377, 1, 0, -50331, 771, 0, 0, 39, '770'),
	(377, 1, 0, -50331, 772, 0, 0, 39, '771'),
	(377, 1, 0, -50331, 773, 0, 0, 39, '772'),
	(377, 1, 0, -50331, 774, 0, 0, 39, '773'),
	(377, 1, 0, -50331, 775, 0, 0, 39, '774'),
	(377, 1, 0, -50331, 776, 0, 0, 39, '775'),
	(377, 1, 0, -50331, 777, 0, 0, 39, '776'),
	(377, 1, 0, -50331, 778, 0, 0, 39, '777'),
	(377, 1, 0, -50331, 779, 0, 0, 39, '778'),
	(377, 1, 0, -50331, 780, 0, 0, 39, '779'),
	(377, 1, 0, -50331, 781, 0, 0, 39, '780'),
	(377, 1, 0, -50331, 782, 0, 0, 39, '781'),
	(377, 1, 0, -50331, 783, 0, 0, 39, '782'),
	(377, 1, 0, -50331, 784, 0, 0, 39, '783'),
	(377, 1, 0, -50331, 785, 0, 0, 39, '784'),
	(377, 1, 0, -50331, 786, 0, 0, 39, '785'),
	(377, 1, 0, -50331, 787, 0, 0, 39, '786'),
	(377, 1, 0, -50331, 788, 0, 0, 39, '787'),
	(377, 1, 0, -50331, 789, 0, 0, 39, '788'),
	(377, 1, 0, -50331, 790, 0, 0, 39, '789'),
	(377, 1, 0, -50331, 791, 0, 0, 39, '790'),
	(377, 1, 0, -50331, 792, 0, 0, 39, '791'),
	(377, 1, 0, -50331, 793, 0, 0, 39, '792'),
	(377, 1, 0, -50331, 794, 0, 0, 39, '793'),
	(377, 1, 0, -50331, 795, 0, 0, 39, '794'),
	(377, 1, 0, -50331, 796, 0, 0, 39, '795'),
	(377, 1, 0, -50331, 797, 0, 0, 39, '796'),
	(377, 1, 0, -50331, 798, 0, 0, 39, '797'),
	(377, 1, 0, -50331, 799, 0, 0, 39, '798'),
	(377, 1, 0, -50331, 800, 0, 0, 39, '799'),
	(377, 1, 0, -50331, 801, 0, 0, 39, '800'),
	(377, 1, 0, -50331, 802, 0, 0, 39, '801'),
	(377, 1, 0, -50331, 803, 0, 0, 39, '802'),
	(377, 1, 0, -50331, 804, 0, 0, 39, '803'),
	(377, 1, 0, -50331, 805, 0, 0, 39, '804'),
	(377, 1, 0, -50331, 806, 0, 0, 39, '805'),
	(377, 1, 0, -50331, 807, 0, 0, 39, '806'),
	(377, 1, 0, -50331, 808, 0, 0, 39, '807'),
	(377, 1, 0, -50331, 809, 0, 0, 39, '808'),
	(377, 1, 0, -50331, 810, 0, 0, 39, '809'),
	(377, 1, 0, -50331, 811, 0, 0, 39, '810'),
	(377, 1, 0, -50331, 812, 0, 0, 39, '811'),
	(377, 1, 0, -50331, 813, 0, 0, 39, '812'),
	(377, 1, 0, -50331, 814, 0, 0, 39, '813'),
	(377, 1, 0, -50331, 815, 0, 0, 39, '814'),
	(377, 1, 0, -50331, 816, 0, 0, 39, '815'),
	(377, 1, 0, -50331, 817, 0, 0, 39, '816'),
	(377, 1, 0, -50331, 818, 0, 0, 39, '817'),
	(377, 1, 0, -50331, 819, 0, 0, 39, '818'),
	(377, 1, 0, -50331, 820, 0, 0, 39, '819'),
	(377, 1, 0, -50331, 821, 0, 0, 39, '820'),
	(377, 1, 0, -50331, 822, 0, 0, 39, '821'),
	(377, 1, 0, -50331, 823, 0, 0, 39, '822'),
	(377, 1, 0, -50331, 824, 0, 0, 39, '823'),
	(377, 1, 0, -50331, 825, 0, 0, 39, '824'),
	(377, 1, 0, -50331, 826, 0, 0, 39, '825'),
	(377, 1, 0, -50331, 827, 0, 0, 39, '826'),
	(377, 1, 0, -50331, 828, 0, 0, 39, '827'),
	(377, 1, 0, -50331, 829, 0, 0, 39, '828'),
	(377, 1, 0, -50331, 830, 0, 0, 39, '829'),
	(377, 1, 0, -50331, 831, 0, 0, 39, '830'),
	(377, 1, 0, -50331, 832, 0, 0, 39, '831'),
	(377, 1, 0, -50331, 833, 0, 0, 39, '832'),
	(377, 1, 0, -50331, 834, 0, 0, 39, '833'),
	(377, 1, 0, -50331, 835, 0, 0, 39, '834'),
	(377, 1, 0, -50331, 836, 0, 0, 39, '835'),
	(377, 1, 0, -50331, 837, 0, 0, 39, '836'),
	(377, 1, 0, -50331, 838, 0, 0, 39, '837'),
	(377, 1, 0, -50331, 839, 0, 0, 39, '838'),
	(377, 1, 0, -50331, 840, 0, 0, 39, '839'),
	(377, 1, 0, -50331, 841, 0, 0, 39, '840'),
	(377, 1, 0, -50331, 842, 0, 0, 39, '841'),
	(377, 1, 0, -50331, 843, 0, 0, 39, '842'),
	(377, 1, 0, -50331, 844, 0, 0, 39, '843'),
	(377, 1, 0, -50331, 845, 0, 0, 39, '844'),
	(377, 1, 0, -50331, 846, 0, 0, 39, '845'),
	(377, 1, 0, -50331, 847, 0, 0, 39, '846'),
	(377, 1, 0, -50331, 848, 0, 0, 39, '847'),
	(377, 1, 0, -50331, 849, 0, 0, 39, '848'),
	(377, 1, 0, -50331, 850, 0, 0, 39, '849'),
	(377, 1, 0, -50331, 851, 0, 0, 39, '850'),
	(377, 1, 0, -50331, 852, 0, 0, 39, '851'),
	(377, 1, 0, -50331, 853, 0, 0, 39, '852'),
	(377, 1, 0, -50331, 854, 0, 0, 39, '853'),
	(377, 1, 0, -50331, 855, 0, 0, 39, '854'),
	(377, 1, 0, -50331, 856, 0, 0, 39, '855'),
	(377, 1, 0, -50331, 857, 0, 0, 39, '856'),
	(377, 1, 0, -50331, 858, 0, 0, 39, '857'),
	(377, 1, 0, -50331, 859, 0, 0, 39, '858'),
	(377, 1, 0, -50331, 860, 0, 0, 39, '859'),
	(377, 1, 0, -50331, 861, 0, 0, 39, '860'),
	(377, 1, 0, -50331, 862, 0, 0, 39, '861'),
	(377, 1, 0, -50331, 863, 0, 0, 39, '862'),
	(377, 1, 0, -50331, 864, 0, 0, 39, '863'),
	(377, 1, 0, -50331, 865, 0, 0, 39, '864'),
	(377, 1, 0, -50331, 866, 0, 0, 39, '865'),
	(377, 1, 0, -50331, 867, 0, 0, 39, '866'),
	(377, 1, 0, -50331, 868, 0, 0, 39, '867'),
	(377, 1, 0, -50331, 869, 0, 0, 39, '868'),
	(377, 1, 0, -50331, 870, 0, 0, 39, '869'),
	(377, 1, 0, -50331, 871, 0, 0, 39, '870'),
	(377, 1, 0, -50331, 872, 0, 0, 39, '871'),
	(377, 1, 0, -50331, 873, 0, 0, 39, '872'),
	(377, 1, 0, -50331, 874, 0, 0, 39, '873'),
	(377, 1, 0, -50331, 875, 0, 0, 39, '874'),
	(377, 1, 0, -50331, 876, 0, 0, 39, '875'),
	(377, 1, 0, -50331, 877, 0, 0, 39, '876'),
	(377, 1, 0, -50331, 878, 0, 0, 39, '877'),
	(377, 1, 0, -50331, 879, 0, 0, 39, '878'),
	(377, 1, 0, -50331, 880, 0, 0, 39, '879'),
	(377, 1, 0, -50331, 881, 0, 0, 39, '880'),
	(377, 1, 0, -50331, 882, 0, 0, 39, '881'),
	(377, 1, 0, -50331, 883, 0, 0, 39, '882'),
	(377, 1, 0, -50331, 884, 0, 0, 39, '883'),
	(377, 1, 0, -50331, 885, 0, 0, 39, '884'),
	(377, 1, 0, -50331, 886, 0, 0, 39, '885'),
	(377, 1, 0, -50331, 887, 0, 0, 39, '886'),
	(377, 1, 0, -50331, 888, 0, 0, 39, '887'),
	(377, 1, 0, -50331, 889, 0, 0, 39, '888'),
	(377, 1, 0, -50331, 890, 0, 0, 39, '889'),
	(377, 1, 0, -50331, 891, 0, 0, 39, '890'),
	(377, 1, 0, -50331, 892, 0, 0, 39, '891'),
	(377, 1, 0, -50331, 893, 0, 0, 39, '892'),
	(377, 1, 0, -50331, 894, 0, 0, 39, '893'),
	(377, 1, 0, -50331, 895, 0, 0, 39, '894'),
	(377, 1, 0, -50331, 896, 0, 0, 39, '895'),
	(377, 1, 0, -50331, 897, 0, 0, 39, '896'),
	(377, 1, 0, -50331, 898, 0, 0, 39, '897'),
	(377, 1, 0, -50331, 899, 0, 0, 39, '898'),
	(377, 1, 0, -50331, 900, 0, 0, 39, '899'),
	(377, 1, 0, -50331, 901, 0, 0, 39, '900'),
	(377, 1, 0, -50331, 902, 0, 0, 39, '901'),
	(377, 1, 0, -50331, 903, 0, 0, 39, '902'),
	(377, 1, 0, -50331, 904, 0, 0, 39, '903'),
	(377, 1, 0, -50331, 905, 0, 0, 39, '904'),
	(377, 1, 0, -50331, 906, 0, 0, 39, '905'),
	(377, 1, 0, -50331, 907, 0, 0, 39, '906'),
	(377, 1, 0, -50331, 908, 0, 0, 39, '907'),
	(377, 1, 0, -50331, 909, 0, 0, 39, '908'),
	(377, 1, 0, -50331, 910, 0, 0, 39, '909'),
	(377, 1, 0, -50331, 911, 0, 0, 39, '910'),
	(377, 1, 0, -50331, 912, 0, 0, 39, '911'),
	(377, 1, 0, -50331, 913, 0, 0, 39, '912'),
	(377, 1, 0, -50331, 914, 0, 0, 39, '913'),
	(377, 1, 0, -50331, 915, 0, 0, 39, '914'),
	(377, 1, 0, -50331, 916, 0, 0, 39, '915'),
	(377, 1, 0, -50331, 917, 0, 0, 39, '916'),
	(377, 1, 0, -50331, 918, 0, 0, 39, '917'),
	(377, 1, 0, -50331, 919, 0, 0, 39, '918'),
	(377, 1, 0, -50331, 920, 0, 0, 39, '919'),
	(377, 1, 0, -50331, 921, 0, 0, 39, '920'),
	(377, 1, 0, -50331, 922, 0, 0, 39, '921'),
	(377, 1, 0, -50331, 923, 0, 0, 39, '922'),
	(377, 1, 0, -50331, 924, 0, 0, 39, '923'),
	(377, 1, 0, -50331, 925, 0, 0, 39, '924'),
	(377, 1, 0, -50331, 926, 0, 0, 39, '925'),
	(377, 1, 0, -50331, 927, 0, 0, 39, '926'),
	(377, 1, 0, -50331, 928, 0, 0, 39, '927'),
	(377, 1, 0, -50331, 929, 0, 0, 39, '928'),
	(377, 1, 0, -50331, 930, 0, 0, 39, '929'),
	(377, 1, 0, -50331, 931, 0, 0, 39, '930'),
	(377, 1, 0, -50331, 932, 0, 0, 39, '931'),
	(377, 1, 0, -50331, 933, 0, 0, 39, '932'),
	(377, 1, 0, -50331, 934, 0, 0, 39, '933'),
	(377, 1, 0, -50331, 935, 0, 0, 39, '934'),
	(377, 1, 0, -50331, 936, 0, 0, 39, '935'),
	(377, 1, 0, -50331, 937, 0, 0, 39, '936'),
	(377, 1, 0, -50331, 938, 0, 0, 39, '937'),
	(377, 1, 0, -50331, 939, 0, 0, 39, '938'),
	(377, 1, 0, -50331, 940, 0, 0, 39, '939'),
	(377, 1, 0, -50331, 941, 0, 0, 39, '940'),
	(377, 1, 0, -50331, 942, 0, 0, 39, '941'),
	(377, 1, 0, -50331, 943, 0, 0, 39, '942'),
	(377, 1, 0, -50331, 944, 0, 0, 39, '943'),
	(377, 1, 0, -50331, 945, 0, 0, 39, '944'),
	(377, 1, 0, -50331, 946, 0, 0, 39, '945'),
	(377, 1, 0, -50331, 947, 0, 0, 39, '946'),
	(377, 1, 0, -50331, 948, 0, 0, 39, '947'),
	(377, 1, 0, -50331, 949, 0, 0, 39, '948'),
	(377, 1, 0, -50331, 950, 0, 0, 39, '949'),
	(377, 1, 0, -50331, 951, 0, 0, 39, '950'),
	(377, 1, 0, -50331, 952, 0, 0, 39, '951'),
	(377, 1, 0, -50331, 953, 0, 0, 39, '952'),
	(377, 1, 0, -50331, 954, 0, 0, 39, '953'),
	(377, 1, 0, -50331, 955, 0, 0, 39, '954'),
	(377, 1, 0, -50331, 956, 0, 0, 39, '955'),
	(377, 1, 0, -50331, 957, 0, 0, 39, '956'),
	(377, 1, 0, -50331, 958, 0, 0, 39, '957'),
	(377, 1, 0, -50331, 959, 0, 0, 39, '958'),
	(377, 1, 0, -50331, 960, 0, 0, 39, '959'),
	(377, 1, 0, -50331, 961, 0, 0, 39, '960'),
	(377, 1, 0, -50331, 962, 0, 0, 39, '961'),
	(377, 1, 0, -50331, 963, 0, 0, 39, '962'),
	(377, 1, 0, -50331, 964, 0, 0, 39, '963'),
	(377, 1, 0, -50331, 965, 0, 0, 39, '964'),
	(377, 1, 0, -50331, 966, 0, 0, 39, '965'),
	(377, 1, 0, -50331, 967, 0, 0, 39, '966'),
	(377, 1, 0, -50331, 968, 0, 0, 39, '967'),
	(377, 1, 0, -50331, 969, 0, 0, 39, '968'),
	(377, 1, 0, -50331, 970, 0, 0, 39, '969'),
	(377, 1, 0, -50331, 971, 0, 0, 39, '970'),
	(377, 1, 0, -50331, 972, 0, 0, 39, '971'),
	(377, 1, 0, -50331, 973, 0, 0, 39, '972'),
	(377, 1, 0, -50331, 974, 0, 0, 39, '973'),
	(377, 1, 0, -50331, 975, 0, 0, 39, '974'),
	(377, 1, 0, -50331, 976, 0, 0, 39, '975'),
	(377, 1, 0, -50331, 977, 0, 0, 39, '976'),
	(377, 1, 0, -50331, 978, 0, 0, 39, '977'),
	(377, 1, 0, -50331, 979, 0, 0, 39, '978'),
	(377, 1, 0, -50331, 980, 0, 0, 39, '979'),
	(377, 1, 0, -50331, 981, 0, 0, 39, '980'),
	(377, 1, 0, -50331, 982, 0, 0, 39, '981'),
	(377, 1, 0, -50331, 983, 0, 0, 39, '982'),
	(377, 1, 0, -50331, 984, 0, 0, 39, '983'),
	(377, 1, 0, -50331, 985, 0, 0, 39, '984'),
	(377, 1, 0, -50331, 986, 0, 0, 39, '985'),
	(377, 1, 0, -50331, 987, 0, 0, 39, '986'),
	(377, 1, 0, -50331, 988, 0, 0, 39, '987'),
	(377, 1, 0, -50331, 989, 0, 0, 39, '988'),
	(377, 1, 0, -50331, 990, 0, 0, 39, '989'),
	(377, 1, 0, -50331, 991, 0, 0, 39, '990'),
	(377, 1, 0, -50331, 992, 0, 0, 39, '991'),
	(377, 1, 0, -50331, 993, 0, 0, 39, '992'),
	(377, 1, 0, -50331, 994, 0, 0, 39, '993'),
	(377, 1, 0, -50331, 995, 0, 0, 39, '994'),
	(377, 1, 0, -50331, 996, 0, 0, 39, '995'),
	(377, 1, 0, -50331, 997, 0, 0, 39, '996'),
	(377, 1, 0, -50331, 998, 0, 0, 39, '997'),
	(377, 1, 0, -50331, 999, 0, 0, 39, '998'),
	(377, 1, 0, -50331, 1000, 0, 0, 39, '999'),
	(377, 1, 0, -50331, 1001, 0, 0, 39, '1000'),
	(377, 1, 0, -50331, 1002, 0, 0, 39, '1001'),
	(377, 1, 0, -50331, 1003, 0, 0, 39, '1002'),
	(377, 1, 0, -50331, 1004, 0, 0, 39, '1003'),
	(377, 1, 0, -50331, 1005, 0, 0, 39, '1004'),
	(377, 1, 0, -50331, 1006, 0, 0, 39, '1005'),
	(377, 1, 0, -50331, 1007, 0, 0, 39, '1006'),
	(377, 1, 0, -50331, 1008, 0, 0, 39, '1007'),
	(377, 1, 0, -50331, 1009, 0, 0, 39, '1008'),
	(377, 1, 0, -50331, 1010, 0, 0, 39, '1009'),
	(377, 1, 0, -50331, 1011, 0, 0, 39, '1010'),
	(377, 1, 0, -50331, 1012, 0, 0, 39, '1011'),
	(377, 1, 0, -50331, 1013, 0, 0, 39, '1012'),
	(377, 1, 0, -50331, 1014, 0, 0, 39, '1013'),
	(377, 1, 0, -50331, 1015, 0, 0, 39, '1014'),
	(377, 1, 0, -50331, 1016, 0, 0, 39, '1015'),
	(377, 1, 0, -50331, 1017, 0, 0, 39, '1016'),
	(377, 1, 0, -50331, 1018, 0, 0, 39, '1017'),
	(377, 1, 0, -50331, 1019, 0, 0, 39, '1018'),
	(377, 1, 0, -50331, 1020, 0, 0, 39, '1019'),
	(377, 1, 0, -50331, 1021, 0, 0, 39, '1020'),
	(377, 1, 0, -50331, 1022, 0, 0, 39, '1021'),
	(377, 1, 0, -50331, 1023, 0, 0, 39, '1022'),
	(377, 1, 0, -50331, 1024, 0, 0, 39, '1023'),
	(377, 1, 0, -50331, 1025, 0, 0, 39, '1024'),
	(377, 1, 0, -50331, 1026, 0, 0, 39, '1025'),
	(377, 1, 0, -50331, 1027, 0, 0, 39, '1026'),
	(377, 1, 0, -50331, 1028, 0, 0, 39, '1027'),
	(377, 1, 0, -50331, 1029, 0, 0, 39, '1028'),
	(377, 1, 0, -50331, 1030, 0, 0, 39, '1029'),
	(377, 1, 0, -50331, 1031, 0, 0, 39, '1030'),
	(377, 1, 0, -50331, 1032, 0, 0, 39, '1031'),
	(377, 1, 0, -50331, 1033, 0, 0, 39, '1032'),
	(377, 1, 0, -50331, 1034, 0, 0, 39, '1033'),
	(377, 1, 0, -50331, 1035, 0, 0, 39, '1034'),
	(377, 1, 0, -50331, 1036, 0, 0, 39, '1035'),
	(377, 1, 0, -50331, 1037, 0, 0, 39, '1036'),
	(377, 1, 0, -50331, 1038, 0, 0, 39, '1037'),
	(377, 1, 0, -50331, 1039, 0, 0, 39, '1038'),
	(377, 1, 0, -50331, 1040, 0, 0, 39, '1039'),
	(377, 1, 0, -50331, 1041, 0, 0, 39, '1040'),
	(377, 1, 0, -50331, 1042, 0, 0, 39, '1041'),
	(377, 1, 0, -50331, 1043, 0, 0, 39, '1042'),
	(377, 1, 0, -50331, 1044, 0, 0, 39, '1043'),
	(377, 1, 0, -50331, 1045, 0, 0, 39, '1044'),
	(377, 1, 0, -50331, 1046, 0, 0, 39, '1045'),
	(377, 1, 0, -50331, 1047, 0, 0, 39, '1046'),
	(377, 1, 0, -50331, 1048, 0, 0, 39, '1047'),
	(377, 1, 0, -50331, 1049, 0, 0, 39, '1048'),
	(377, 1, 0, -50331, 1050, 0, 0, 39, '1049'),
	(377, 1, 0, -50331, 1051, 0, 0, 39, '1050'),
	(377, 1, 0, -50331, 1052, 0, 0, 39, '1051'),
	(377, 1, 0, -50331, 1053, 0, 0, 39, '1052'),
	(377, 1, 0, -50331, 1054, 0, 0, 39, '1053'),
	(377, 1, 0, -50331, 1055, 0, 0, 39, '1054'),
	(377, 1, 0, -50331, 1056, 0, 0, 39, '1055'),
	(377, 1, 0, -50331, 1057, 0, 0, 39, '1056'),
	(377, 1, 0, -50331, 1058, 0, 0, 39, '1057'),
	(377, 1, 0, -50331, 1059, 0, 0, 39, '1058'),
	(377, 1, 0, -50331, 1060, 0, 0, 39, '1059'),
	(377, 1, 0, -50331, 1061, 0, 0, 39, '1060'),
	(377, 1, 0, -50331, 1062, 0, 0, 39, '1061'),
	(377, 1, 0, -50331, 1063, 0, 0, 39, '1062'),
	(377, 1, 0, -50331, 1064, 0, 0, 39, '1063'),
	(377, 1, 0, -50331, 1065, 0, 0, 39, '1064'),
	(377, 1, 0, -50331, 1066, 0, 0, 39, '1065'),
	(377, 1, 0, -50331, 1067, 0, 0, 39, '1066'),
	(377, 1, 0, -50331, 1068, 0, 0, 39, '1067'),
	(377, 1, 0, -50331, 1069, 0, 0, 39, '1068'),
	(377, 1, 0, -50331, 1070, 0, 0, 39, '1069'),
	(377, 1, 0, -50331, 1071, 0, 0, 39, '1070'),
	(377, 1, 0, -50331, 1072, 0, 0, 39, '1071'),
	(377, 1, 0, -50331, 1073, 0, 0, 39, '1072'),
	(377, 1, 0, -50331, 1074, 0, 0, 39, '1073'),
	(377, 1, 0, -50331, 1075, 0, 0, 39, '1074'),
	(377, 1, 0, -50331, 1076, 0, 0, 39, '1075'),
	(377, 1, 0, -50331, 1077, 0, 0, 39, '1076'),
	(377, 1, 0, -50331, 1078, 0, 0, 39, '1077'),
	(377, 1, 0, -50331, 1079, 0, 0, 39, '1078'),
	(377, 1, 0, -50331, 1080, 0, 0, 39, '1079'),
	(377, 1, 0, -50331, 1081, 0, 0, 39, '1080'),
	(377, 1, 0, -50331, 1082, 0, 0, 39, '1081'),
	(377, 1, 0, -50331, 1083, 0, 0, 39, '1082'),
	(377, 1, 0, -50331, 1084, 0, 0, 39, '1083'),
	(377, 1, 0, -50331, 1085, 0, 0, 39, '1084'),
	(377, 1, 0, -50331, 1086, 0, 0, 39, '1085'),
	(377, 1, 0, -50331, 1087, 0, 0, 39, '1086'),
	(377, 1, 0, -50331, 1088, 0, 0, 39, '1087'),
	(377, 1, 0, -50331, 1089, 0, 0, 39, '1088'),
	(377, 1, 0, -50331, 1090, 0, 0, 39, '1089'),
	(377, 1, 0, -50331, 1091, 0, 0, 39, '1090'),
	(377, 1, 0, -50331, 1092, 0, 0, 39, '1091'),
	(377, 1, 0, -50331, 1093, 0, 0, 39, '1092'),
	(377, 1, 0, -50331, 1094, 0, 0, 39, '1093'),
	(377, 1, 0, -50331, 1095, 0, 0, 39, '1094'),
	(377, 1, 0, -50331, 1096, 0, 0, 39, '1095'),
	(377, 1, 0, -50331, 1097, 0, 0, 39, '1096'),
	(377, 1, 0, -50331, 1098, 0, 0, 39, '1097'),
	(377, 1, 0, -50331, 1099, 0, 0, 39, '1098'),
	(377, 1, 0, -50331, 1100, 0, 0, 39, '1099'),
	(377, 1, 0, -50331, 1101, 0, 0, 39, '1100'),
	(377, 1, 0, -50331, 1102, 0, 0, 39, '1101'),
	(377, 1, 0, -50331, 1103, 0, 0, 39, '1102'),
	(377, 1, 0, -50331, 1104, 0, 0, 39, '1103'),
	(377, 1, 0, -50331, 1105, 0, 0, 39, '1104'),
	(377, 1, 0, -50331, 1106, 0, 0, 39, '1105'),
	(377, 1, 0, -50331, 1107, 0, 0, 39, '1106'),
	(377, 1, 0, -50331, 1108, 0, 0, 39, '1107'),
	(377, 1, 0, -50331, 1109, 0, 0, 39, '1108'),
	(377, 1, 0, -50331, 1110, 0, 0, 39, '1109'),
	(377, 1, 0, -50331, 1111, 0, 0, 39, '1110'),
	(377, 1, 0, -50331, 1112, 0, 0, 39, '1111'),
	(377, 1, 0, -50331, 1113, 0, 0, 39, '1112'),
	(377, 1, 0, -50331, 1114, 0, 0, 39, '1113'),
	(377, 1, 0, -50331, 1115, 0, 0, 39, '1114'),
	(377, 1, 0, -50331, 1116, 0, 0, 39, '1115'),
	(377, 1, 0, -50331, 1117, 0, 0, 39, '1116'),
	(377, 1, 0, -50331, 1118, 0, 0, 39, '1117'),
	(377, 1, 0, -50331, 1119, 0, 0, 39, '1118'),
	(377, 1, 0, -50331, 1120, 0, 0, 39, '1119'),
	(377, 1, 0, -50331, 1121, 0, 0, 39, '1120'),
	(377, 1, 0, -50331, 1122, 0, 0, 39, '1121'),
	(377, 1, 0, -50331, 1123, 0, 0, 39, '1122'),
	(377, 1, 0, -50331, 1124, 0, 0, 39, '1123'),
	(377, 1, 0, -50331, 1125, 0, 0, 39, '1124'),
	(377, 1, 0, -50331, 1126, 0, 0, 39, '1125'),
	(377, 1, 0, -50331, 1127, 0, 0, 39, '1126'),
	(377, 1, 0, -50331, 1128, 0, 0, 39, '1127'),
	(377, 1, 0, -50331, 1129, 0, 0, 39, '1128'),
	(377, 1, 0, -50331, 1130, 0, 0, 39, '1129'),
	(377, 1, 0, -50331, 1131, 0, 0, 39, '1130'),
	(377, 1, 0, -50331, 1132, 0, 0, 39, '1131'),
	(377, 1, 0, -50331, 1133, 0, 0, 39, '1132'),
	(377, 1, 0, -50331, 1134, 0, 0, 39, '1133'),
	(377, 1, 0, -50331, 1135, 0, 0, 39, '1134'),
	(377, 1, 0, -50331, 1136, 0, 0, 39, '1135'),
	(377, 1, 0, -50331, 1137, 0, 0, 39, '1136'),
	(377, 1, 0, -50331, 1138, 0, 0, 39, '1137'),
	(377, 1, 0, -50331, 1139, 0, 0, 39, '1138'),
	(377, 1, 0, -50331, 1140, 0, 0, 39, '1139'),
	(377, 1, 0, -50331, 1141, 0, 0, 39, '1140'),
	(377, 1, 0, -50331, 1142, 0, 0, 39, '1141'),
	(377, 1, 0, -50331, 1143, 0, 0, 39, '1142'),
	(377, 1, 0, -50331, 1144, 0, 0, 39, '1143'),
	(377, 1, 0, -50331, 1145, 0, 0, 39, '1144'),
	(377, 1, 0, -50331, 1146, 0, 0, 39, '1145'),
	(377, 1, 0, -50331, 1147, 0, 0, 39, '1146'),
	(377, 1, 0, -50331, 1148, 0, 0, 39, '1147'),
	(377, 1, 0, -50331, 1149, 0, 0, 39, '1148'),
	(377, 1, 0, -50331, 1150, 0, 0, 39, '1149'),
	(377, 1, 0, -50331, 1151, 0, 0, 39, '1150'),
	(377, 1, 0, -50331, 1152, 0, 0, 39, '1151'),
	(377, 1, 0, -50331, 1153, 0, 0, 39, '1152'),
	(377, 1, 0, -50331, 1154, 0, 0, 39, '1153'),
	(377, 1, 0, -50331, 1155, 0, 0, 39, '1154'),
	(377, 1, 0, -50331, 1156, 0, 0, 39, '1155'),
	(377, 1, 0, -50331, 1157, 0, 0, 39, '1156'),
	(377, 1, 0, -50331, 1158, 0, 0, 39, '1157'),
	(377, 1, 0, -50331, 1159, 0, 0, 39, '1158'),
	(377, 1, 0, -50331, 1160, 0, 0, 39, '1159'),
	(377, 1, 0, -50331, 1161, 0, 0, 39, '1160'),
	(377, 1, 0, -50331, 1162, 0, 0, 39, '1161'),
	(377, 1, 0, -50331, 1163, 0, 0, 39, '1162'),
	(377, 1, 0, -50331, 1164, 0, 0, 39, '1163'),
	(377, 1, 0, -50331, 1165, 0, 0, 39, '1164'),
	(377, 1, 0, -50331, 1166, 0, 0, 39, '1165'),
	(377, 1, 0, -50331, 1167, 0, 0, 39, '1166'),
	(377, 1, 0, -50331, 1168, 0, 0, 39, '1167'),
	(377, 1, 0, -50331, 1169, 0, 0, 39, '1168'),
	(377, 1, 0, -50331, 1170, 0, 0, 39, '1169'),
	(377, 1, 0, -50331, 1171, 0, 0, 39, '1170'),
	(377, 1, 0, -50331, 1172, 0, 0, 39, '1171'),
	(377, 1, 0, -50331, 1173, 0, 0, 39, '1172'),
	(377, 1, 0, -50331, 1174, 0, 0, 39, '1173'),
	(377, 1, 0, -50331, 1175, 0, 0, 39, '1174'),
	(377, 1, 0, -50331, 1176, 0, 0, 39, '1175'),
	(377, 1, 0, -50331, 1177, 0, 0, 39, '1176'),
	(377, 1, 0, -50331, 1178, 0, 0, 39, '1177'),
	(377, 1, 0, -50331, 1179, 0, 0, 39, '1178'),
	(377, 1, 0, -50331, 1180, 0, 0, 39, '1179'),
	(377, 1, 0, -50331, 1181, 0, 0, 39, '1180'),
	(377, 1, 0, -50331, 1182, 0, 0, 39, '1181'),
	(377, 1, 0, -50331, 1183, 0, 0, 39, '1182'),
	(377, 1, 0, -50331, 1184, 0, 0, 39, '1183'),
	(377, 1, 0, -50331, 1185, 0, 0, 39, '1184'),
	(377, 1, 0, -50331, 1186, 0, 0, 39, '1185'),
	(377, 1, 0, -50331, 1187, 0, 0, 39, '1186'),
	(377, 1, 0, -50331, 1188, 0, 0, 39, '1187'),
	(377, 1, 0, -50331, 1189, 0, 0, 39, '1188'),
	(377, 1, 0, -50331, 1190, 0, 0, 39, '1189'),
	(377, 1, 0, -50331, 1191, 0, 0, 39, '1190'),
	(377, 1, 0, -50331, 1192, 0, 0, 39, '1191'),
	(377, 1, 0, -50331, 1193, 0, 0, 39, '1192'),
	(377, 1, 0, -50331, 1194, 0, 0, 39, '1193'),
	(377, 1, 0, -50331, 1195, 0, 0, 39, '1194'),
	(377, 1, 0, -50331, 1196, 0, 0, 39, '1195'),
	(377, 1, 0, -50331, 1197, 0, 0, 39, '1196'),
	(377, 1, 0, -50331, 1198, 0, 0, 39, '1197'),
	(377, 1, 0, -50331, 1199, 0, 0, 39, '1198'),
	(377, 1, 0, -50331, 1200, 0, 0, 39, '1199'),
	(377, 1, 0, -50331, 1201, 0, 0, 39, '1200'),
	(377, 1, 0, -50331, 1202, 0, 0, 39, '1201'),
	(377, 1, 0, -50331, 1203, 0, 0, 39, '1202'),
	(377, 1, 0, -50331, 1204, 0, 0, 39, '1203'),
	(377, 1, 0, -50331, 1205, 0, 0, 39, '1204'),
	(377, 1, 0, -50331, 1206, 0, 0, 39, '1205'),
	(377, 1, 0, -50331, 1207, 0, 0, 39, '1206'),
	(377, 1, 0, -50331, 1208, 0, 0, 39, '1207'),
	(377, 1, 0, -50331, 1209, 0, 0, 39, '1208'),
	(377, 1, 0, -50331, 1210, 0, 0, 39, '1209'),
	(377, 1, 0, -50331, 1211, 0, 0, 39, '1210'),
	(377, 1, 0, -50331, 1212, 0, 0, 39, '1211'),
	(377, 1, 0, -50331, 1213, 0, 0, 39, '1212'),
	(377, 1, 0, -50331, 1214, 0, 0, 39, '1213'),
	(377, 1, 0, -50331, 1215, 0, 0, 39, '1214'),
	(377, 1, 0, -50331, 1216, 0, 0, 39, '1215'),
	(377, 1, 0, -50331, 1217, 0, 0, 39, '1216'),
	(377, 1, 0, -50331, 1218, 0, 0, 39, '1217'),
	(377, 1, 0, -50331, 1219, 0, 0, 39, '1218'),
	(377, 1, 0, -50331, 1220, 0, 0, 39, '1219'),
	(377, 1, 0, -50331, 1221, 0, 0, 39, '1220'),
	(377, 1, 0, -50331, 1222, 0, 0, 39, '1221'),
	(377, 1, 0, -50331, 1223, 0, 0, 39, '1222'),
	(377, 1, 0, -50331, 1224, 0, 0, 39, '1223'),
	(377, 1, 0, -50331, 1225, 0, 0, 39, '1224'),
	(377, 1, 0, -50331, 1226, 0, 0, 39, '1225'),
	(377, 1, 0, -50331, 1227, 0, 0, 39, '1226'),
	(377, 1, 0, -50331, 1228, 0, 0, 39, '1227'),
	(377, 1, 0, -50331, 1229, 0, 0, 39, '1228'),
	(377, 1, 0, -50331, 1230, 0, 0, 39, '1229'),
	(377, 1, 0, -50331, 1231, 0, 0, 39, '1230'),
	(377, 1, 0, -50331, 1232, 0, 0, 39, '1231'),
	(377, 1, 0, -50331, 1233, 0, 0, 39, '1232'),
	(377, 1, 0, -50331, 1234, 0, 0, 39, '1233'),
	(377, 1, 0, -50331, 1235, 0, 0, 39, '1234'),
	(377, 1, 0, -50331, 1236, 0, 0, 39, '1235'),
	(377, 1, 0, -50331, 1237, 0, 0, 39, '1236'),
	(377, 1, 0, -50331, 1238, 0, 0, 39, '1237'),
	(377, 1, 0, -50331, 1239, 0, 0, 39, '1238'),
	(377, 1, 0, -50331, 1240, 0, 0, 39, '1239'),
	(377, 1, 0, -50331, 1241, 0, 0, 39, '1240'),
	(377, 1, 0, -50331, 1242, 0, 0, 39, '1241'),
	(377, 1, 0, -50331, 1243, 0, 0, 39, '1242'),
	(377, 1, 0, -50331, 1244, 0, 0, 39, '1243'),
	(377, 1, 0, -50331, 1245, 0, 0, 39, '1244'),
	(377, 1, 0, -50331, 1246, 0, 0, 39, '1245'),
	(377, 1, 0, -50331, 1247, 0, 0, 39, '1246'),
	(377, 1, 0, -50331, 1248, 0, 0, 39, '1247'),
	(377, 1, 0, -50331, 1249, 0, 0, 39, '1248'),
	(377, 1, 0, -50331, 1250, 0, 0, 39, '1249'),
	(377, 1, 0, -50331, 1251, 0, 0, 39, '1250'),
	(377, 1, 0, -50331, 1252, 0, 0, 39, '1251'),
	(377, 1, 0, -50331, 1253, 0, 0, 39, '1252'),
	(377, 1, 0, -50331, 1254, 0, 0, 39, '1253'),
	(377, 1, 0, -50331, 1255, 0, 0, 39, '1254'),
	(377, 1, 0, -50331, 1256, 0, 0, 39, '1255'),
	(377, 1, 0, -50331, 1257, 0, 0, 39, '1256'),
	(377, 1, 0, -50331, 1258, 0, 0, 39, '1257'),
	(377, 1, 0, -50331, 1259, 0, 0, 39, '1258'),
	(377, 1, 0, -50331, 1260, 0, 0, 39, '1259'),
	(377, 1, 0, -50331, 1261, 0, 0, 39, '1260'),
	(377, 1, 0, -50331, 1262, 0, 0, 39, '1261'),
	(377, 1, 0, -50331, 1263, 0, 0, 39, '1262'),
	(377, 1, 0, -50331, 1264, 0, 0, 39, '1263'),
	(377, 1, 0, -50331, 1265, 0, 0, 39, '1264'),
	(377, 1, 0, -50331, 1266, 0, 0, 39, '1265'),
	(377, 1, 0, -50331, 1267, 0, 0, 39, '1266'),
	(377, 1, 0, -50331, 1268, 0, 0, 39, '1267'),
	(377, 1, 0, -50331, 1269, 0, 0, 39, '1268'),
	(377, 1, 0, -50331, 1270, 0, 0, 39, '1269'),
	(377, 1, 0, -50331, 1271, 0, 0, 39, '1270'),
	(377, 1, 0, -50331, 1272, 0, 0, 39, '1271'),
	(377, 1, 0, -50331, 1273, 0, 0, 39, '1272'),
	(377, 1, 0, -50331, 1274, 0, 0, 39, '1273'),
	(377, 1, 0, -50331, 1275, 0, 0, 39, '1274'),
	(377, 1, 0, -50331, 1276, 0, 0, 39, '1275'),
	(377, 1, 0, -50331, 1277, 0, 0, 39, '1276'),
	(377, 1, 0, -50331, 1278, 0, 0, 39, '1277'),
	(377, 1, 0, -50331, 1279, 0, 0, 39, '1278'),
	(377, 1, 0, -50331, 1280, 0, 0, 39, '1279'),
	(377, 1, 0, -50331, 1281, 0, 0, 39, '1280'),
	(377, 1, 0, -50331, 1282, 0, 0, 39, '1281'),
	(377, 1, 0, -50331, 1283, 0, 0, 39, '1282'),
	(377, 1, 0, -50331, 1284, 0, 0, 39, '1283'),
	(377, 1, 0, -50331, 1285, 0, 0, 39, '1284'),
	(377, 1, 0, -50331, 1286, 0, 0, 39, '1285'),
	(377, 1, 0, -50331, 1287, 0, 0, 39, '1286'),
	(377, 1, 0, -50331, 1288, 0, 0, 39, '1287'),
	(377, 1, 0, -50331, 1289, 0, 0, 39, '1288'),
	(377, 1, 0, -50331, 1290, 0, 0, 39, '1289'),
	(377, 1, 0, -50331, 1291, 0, 0, 39, '1290'),
	(377, 1, 0, -50331, 1292, 0, 0, 39, '1291'),
	(377, 1, 0, -50331, 1293, 0, 0, 39, '1292'),
	(377, 1, 0, -50331, 1294, 0, 0, 39, '1293'),
	(377, 1, 0, -50331, 1295, 0, 0, 39, '1294'),
	(377, 1, 0, -50331, 1296, 0, 0, 39, '1295'),
	(377, 1, 0, -50331, 1297, 0, 0, 39, '1296'),
	(377, 1, 0, -50331, 1298, 0, 0, 39, '1297'),
	(377, 1, 0, -50331, 1299, 0, 0, 39, '1298'),
	(377, 1, 0, -50331, 1300, 0, 0, 39, '1299'),
	(377, 1, 0, -50331, 1301, 0, 0, 39, '1300'),
	(377, 1, 0, -50331, 1302, 0, 0, 39, '1301'),
	(377, 1, 0, -50331, 1303, 0, 0, 39, '1302'),
	(377, 1, 0, -50331, 1304, 0, 0, 39, '1303'),
	(377, 1, 0, -50331, 1305, 0, 0, 39, '1304'),
	(377, 1, 0, -50331, 1306, 0, 0, 39, '1305'),
	(377, 1, 0, -50331, 1307, 0, 0, 39, '1306'),
	(377, 1, 0, -50331, 1308, 0, 0, 39, '1307'),
	(377, 1, 0, -50331, 1309, 0, 0, 39, '1308'),
	(377, 1, 0, -50331, 1310, 0, 0, 39, '1309'),
	(377, 1, 0, -50331, 1311, 0, 0, 39, '1310'),
	(377, 1, 0, -50331, 1312, 0, 0, 39, '1311'),
	(377, 1, 0, -50331, 1313, 0, 0, 39, '1312'),
	(377, 1, 0, -50331, 1314, 0, 0, 39, '1313'),
	(377, 1, 0, -50331, 1315, 0, 0, 39, '1314'),
	(377, 1, 0, -50331, 1316, 0, 0, 39, '1315'),
	(377, 1, 0, -50331, 1317, 0, 0, 39, '1316'),
	(377, 1, 0, -50331, 1318, 0, 0, 39, '1317'),
	(377, 1, 0, -50331, 1319, 0, 0, 39, '1318'),
	(377, 1, 0, -50331, 1320, 0, 0, 39, '1319'),
	(377, 1, 0, -50331, 1321, 0, 0, 39, '1320'),
	(377, 1, 0, -50331, 1322, 0, 0, 39, '1321'),
	(377, 1, 0, -50331, 1323, 0, 0, 39, '1322'),
	(377, 1, 0, -50331, 1324, 0, 0, 39, '1323'),
	(377, 1, 0, -50331, 1325, 0, 0, 39, '1324'),
	(377, 1, 0, -50331, 1326, 0, 0, 39, '1325'),
	(377, 1, 0, -50331, 1327, 0, 0, 39, '1326'),
	(377, 1, 0, -50331, 1328, 0, 0, 39, '1327'),
	(377, 1, 0, -50331, 1329, 0, 0, 39, '1328'),
	(377, 1, 0, -50331, 1330, 0, 0, 39, '1329'),
	(377, 1, 0, -50331, 1331, 0, 0, 39, '1330'),
	(377, 1, 0, -50331, 1332, 0, 0, 39, '1331'),
	(377, 1, 0, -50331, 1333, 0, 0, 39, '1332'),
	(377, 1, 0, -50331, 1334, 0, 0, 39, '1333'),
	(377, 1, 0, -50331, 1335, 0, 0, 39, '1334'),
	(377, 1, 0, -50331, 1336, 0, 0, 39, '1335'),
	(377, 1, 0, -50331, 1337, 0, 0, 39, '1336'),
	(377, 1, 0, -50331, 1338, 0, 0, 39, '1337'),
	(377, 1, 0, -50331, 1339, 0, 0, 39, '1338'),
	(377, 1, 0, -50331, 1340, 0, 0, 39, '1339'),
	(377, 1, 0, -50331, 1341, 0, 0, 39, '1340'),
	(377, 1, 0, -50331, 1342, 0, 0, 39, '1341'),
	(377, 1, 0, -50331, 1343, 0, 0, 39, '1342'),
	(377, 1, 0, -50331, 1344, 0, 0, 39, '1343'),
	(377, 1, 0, -50331, 1345, 0, 0, 39, '1344'),
	(377, 1, 0, -50331, 1346, 0, 0, 39, '1345'),
	(377, 1, 0, -50331, 1347, 0, 0, 39, '1346'),
	(377, 1, 0, -50331, 1348, 0, 0, 39, '1347'),
	(377, 1, 0, -50331, 1349, 0, 0, 39, '1348'),
	(377, 1, 0, -50331, 1350, 0, 0, 39, '1349'),
	(377, 1, 0, -50331, 1351, 0, 0, 39, '1350'),
	(377, 1, 0, -50331, 1352, 0, 0, 39, '1351'),
	(377, 1, 0, -50331, 1353, 0, 0, 39, '1352'),
	(377, 1, 0, -50331, 1354, 0, 0, 39, '1353'),
	(377, 1, 0, -50331, 1355, 0, 0, 39, '1354'),
	(377, 1, 0, -50331, 1356, 0, 0, 39, '1355'),
	(377, 1, 0, -50331, 1357, 0, 0, 39, '1356'),
	(377, 1, 0, -50331, 1358, 0, 0, 39, '1357'),
	(377, 1, 0, -50331, 1359, 0, 0, 39, '1358'),
	(377, 1, 0, -50331, 1360, 0, 0, 39, '1359'),
	(377, 1, 0, -50331, 1361, 0, 0, 39, '1360'),
	(377, 1, 0, -50331, 1362, 0, 0, 39, '1361'),
	(377, 1, 0, -50331, 1363, 0, 0, 39, '1362'),
	(377, 1, 0, -50331, 1364, 0, 0, 39, '1363'),
	(377, 1, 0, -50331, 1365, 0, 0, 39, '1364'),
	(377, 1, 0, -50331, 1366, 0, 0, 39, '1365'),
	(377, 1, 0, -50331, 1367, 0, 0, 39, '1366'),
	(377, 1, 0, -50331, 1368, 0, 0, 39, '1367'),
	(377, 1, 0, -50331, 1369, 0, 0, 39, '1368'),
	(377, 1, 0, -50331, 1370, 0, 0, 39, '1369'),
	(377, 1, 0, -50331, 1371, 0, 0, 39, '1370'),
	(377, 1, 0, -50331, 1372, 0, 0, 39, '1371'),
	(377, 1, 0, -50331, 1373, 0, 0, 39, '1372'),
	(377, 1, 0, -50331, 1374, 0, 0, 39, '1373'),
	(377, 1, 0, -50331, 1375, 0, 0, 39, '1374'),
	(377, 1, 0, -50331, 1376, 0, 0, 39, '1375'),
	(377, 1, 0, -50331, 1377, 0, 0, 39, '1376'),
	(377, 1, 0, -50331, 1378, 0, 0, 39, '1377'),
	(377, 1, 0, -50331, 1379, 0, 0, 39, '1378'),
	(377, 1, 0, -50331, 1380, 0, 0, 39, '1379'),
	(377, 1, 0, -50331, 1381, 0, 0, 39, '1380'),
	(377, 1, 0, -50331, 1382, 0, 0, 39, '1381'),
	(377, 1, 0, -50331, 1383, 0, 0, 39, '1382'),
	(377, 1, 0, -50331, 1384, 0, 0, 39, '1383'),
	(377, 1, 0, -50331, 1385, 0, 0, 39, '1384'),
	(377, 1, 0, -50331, 1386, 0, 0, 39, '1385'),
	(377, 1, 0, -50331, 1387, 0, 0, 39, '1386'),
	(377, 1, 0, -50331, 1388, 0, 0, 39, '1387'),
	(377, 1, 0, -50331, 1389, 0, 0, 39, '1388'),
	(377, 1, 0, -50331, 1390, 0, 0, 39, '1389'),
	(377, 1, 0, -50331, 1391, 0, 0, 39, '1390'),
	(377, 1, 0, -50331, 1392, 0, 0, 39, '1391'),
	(377, 1, 0, -50331, 1393, 0, 0, 39, '1392'),
	(377, 1, 0, -50331, 1394, 0, 0, 39, '1393'),
	(377, 1, 0, -50331, 1395, 0, 0, 39, '1394'),
	(377, 1, 0, -50331, 1396, 0, 0, 39, '1395'),
	(377, 1, 0, -50331, 1397, 0, 0, 39, '1396'),
	(377, 1, 0, -50331, 1398, 0, 0, 39, '1397'),
	(377, 1, 0, -50331, 1399, 0, 0, 39, '1398'),
	(377, 1, 0, -50331, 1400, 0, 0, 39, '1399'),
	(377, 1, 0, -50331, 1401, 0, 0, 39, '1400'),
	(377, 1, 0, -50331, 1402, 0, 0, 39, '1401'),
	(377, 1, 0, -50331, 1403, 0, 0, 39, '1402'),
	(377, 1, 0, -50331, 1404, 0, 0, 39, '1403'),
	(377, 1, 0, -50331, 1405, 0, 0, 39, '1404'),
	(377, 1, 0, -50331, 1406, 0, 0, 39, '1405'),
	(377, 1, 0, -50331, 1407, 0, 0, 39, '1406'),
	(377, 1, 0, -50331, 1408, 0, 0, 39, '1407'),
	(377, 1, 0, -50331, 1409, 0, 0, 39, '1408'),
	(377, 1, 0, -50331, 1410, 0, 0, 39, '1409'),
	(377, 1, 0, -50331, 1411, 0, 0, 39, '1410'),
	(377, 1, 0, -50331, 1412, 0, 0, 39, '1411'),
	(377, 1, 0, -50331, 1413, 0, 0, 39, '1412'),
	(377, 1, 0, -50331, 1414, 0, 0, 39, '1413'),
	(377, 1, 0, -50331, 1415, 0, 0, 39, '1414'),
	(377, 1, 0, -50331, 1416, 0, 0, 39, '1415'),
	(377, 1, 0, -50331, 1417, 0, 0, 39, '1416'),
	(377, 1, 0, -50331, 1418, 0, 0, 39, '1417'),
	(377, 1, 0, -50331, 1419, 0, 0, 39, '1418'),
	(377, 1, 0, -50331, 1420, 0, 0, 39, '1419'),
	(377, 1, 0, -50331, 1421, 0, 0, 39, '1420'),
	(377, 1, 0, -50331, 1422, 0, 0, 39, '1421'),
	(377, 1, 0, -50331, 1423, 0, 0, 39, '1422'),
	(377, 1, 0, -50331, 1424, 0, 0, 39, '1423'),
	(377, 1, 0, -50331, 1425, 0, 0, 39, '1424'),
	(377, 1, 0, -50331, 1426, 0, 0, 39, '1425'),
	(377, 1, 0, -50331, 1427, 0, 0, 39, '1426'),
	(377, 1, 0, -50331, 1428, 0, 0, 39, '1427'),
	(377, 1, 0, -50331, 1429, 0, 0, 39, '1428'),
	(377, 1, 0, -50331, 1430, 0, 0, 39, '1429'),
	(377, 1, 0, -50331, 1431, 0, 0, 39, '1430'),
	(377, 1, 0, -50331, 1432, 0, 0, 39, '1431'),
	(377, 1, 0, -50331, 1433, 0, 0, 39, '1432'),
	(377, 1, 0, -50331, 1434, 0, 0, 39, '1433'),
	(377, 1, 0, -50331, 1435, 0, 0, 39, '1434'),
	(377, 1, 0, -50331, 1436, 0, 0, 39, '1435'),
	(377, 1, 0, -50331, 1437, 0, 0, 39, '1436'),
	(377, 1, 0, -50331, 1438, 0, 0, 39, '1437'),
	(377, 1, 0, -50331, 1439, 0, 0, 39, '1438'),
	(377, 1, 0, -50331, 1440, 0, 0, 39, '1439'),
	(377, 1, 0, -50331, 1441, 0, 0, 39, '1440'),
	(377, 1, 0, -50331, 1442, 0, 0, 39, '1441'),
	(377, 1, 0, -50331, 1443, 0, 0, 39, '1442'),
	(377, 1, 0, -50331, 1444, 0, 0, 39, '1443'),
	(377, 1, 0, -50331, 1445, 0, 0, 39, '1444'),
	(377, 1, 0, -50331, 1446, 0, 0, 39, '1445'),
	(377, 1, 0, -50331, 1447, 0, 0, 39, '1446'),
	(377, 1, 0, -50331, 1448, 0, 0, 39, '1447'),
	(377, 1, 0, -50331, 1449, 0, 0, 39, '1448'),
	(377, 1, 0, -50331, 1450, 0, 0, 39, '1449'),
	(377, 1, 0, -50331, 1451, 0, 0, 39, '1450'),
	(377, 1, 0, -50331, 1452, 0, 0, 39, '1451'),
	(377, 1, 0, -50331, 1453, 0, 0, 39, '1452'),
	(377, 1, 0, -50331, 1454, 0, 0, 39, '1453'),
	(377, 1, 0, -50331, 1455, 0, 0, 39, '1454'),
	(377, 1, 0, -50331, 1456, 0, 0, 39, '1455'),
	(377, 1, 0, -50331, 1457, 0, 0, 39, '1456'),
	(377, 1, 0, -50331, 1458, 0, 0, 39, '1457'),
	(377, 1, 0, -50331, 1459, 0, 0, 39, '1458'),
	(377, 1, 0, -50331, 1460, 0, 0, 39, '1459'),
	(377, 1, 0, -50331, 1461, 0, 0, 39, '1460'),
	(377, 1, 0, -50331, 1462, 0, 0, 39, '1461'),
	(377, 1, 0, -50331, 1463, 0, 0, 39, '1462'),
	(377, 1, 0, -50331, 1464, 0, 0, 39, '1463'),
	(377, 1, 0, -50331, 1465, 0, 0, 39, '1464'),
	(377, 1, 0, -50331, 1466, 0, 0, 39, '1465'),
	(377, 1, 0, -50331, 1467, 0, 0, 39, '1466'),
	(377, 1, 0, -50331, 1468, 0, 0, 39, '1467'),
	(377, 1, 0, -50331, 1469, 0, 0, 39, '1468'),
	(377, 1, 0, -50331, 1470, 0, 0, 39, '1469'),
	(377, 1, 0, -50331, 1471, 0, 0, 39, '1470'),
	(377, 1, 0, -50331, 1472, 0, 0, 39, '1471'),
	(377, 1, 0, -50331, 1473, 0, 0, 39, '1472'),
	(377, 1, 0, -50331, 1474, 0, 0, 39, '1473'),
	(377, 1, 0, -50331, 1475, 0, 0, 39, '1474'),
	(377, 1, 0, -50331, 1476, 0, 0, 39, '1475'),
	(377, 1, 0, -50331, 1477, 0, 0, 39, '1476'),
	(377, 1, 0, -50331, 1478, 0, 0, 39, '1477'),
	(377, 1, 0, -50331, 1479, 0, 0, 39, '1478'),
	(377, 1, 0, -50331, 1480, 0, 0, 39, '1479'),
	(377, 1, 0, -50331, 1481, 0, 0, 39, '1480'),
	(377, 1, 0, -50331, 1482, 0, 0, 39, '1481'),
	(377, 1, 0, -50331, 1483, 0, 0, 39, '1482'),
	(377, 1, 0, -50331, 1484, 0, 0, 39, '1483'),
	(377, 1, 0, -50331, 1485, 0, 0, 39, '1484'),
	(377, 1, 0, -50331, 1486, 0, 0, 39, '1485'),
	(377, 1, 0, -50331, 1487, 0, 0, 39, '1486'),
	(377, 1, 0, -50331, 1488, 0, 0, 39, '1487'),
	(377, 1, 0, -50331, 1489, 0, 0, 39, '1488'),
	(377, 1, 0, -50331, 1490, 0, 0, 39, '1489'),
	(377, 1, 0, -50331, 1491, 0, 0, 39, '1490'),
	(377, 1, 0, -50331, 1492, 0, 0, 39, '1491'),
	(377, 1, 0, -50331, 1493, 0, 0, 39, '1492'),
	(377, 1, 0, -50331, 1494, 0, 0, 39, '1493'),
	(377, 1, 0, -50331, 1495, 0, 0, 39, '1494'),
	(377, 1, 0, -50331, 1496, 0, 0, 39, '1495'),
	(377, 1, 0, -50331, 1497, 0, 0, 39, '1496'),
	(377, 1, 0, -50331, 1498, 0, 0, 39, '1497'),
	(377, 1, 0, -50331, 1499, 0, 0, 39, '1498'),
	(377, 1, 0, -50331, 1500, 0, 0, 39, '1499'),
	(377, 1, 0, -50331, 1501, 0, 0, 39, '1500'),
	(377, 1, 0, -50331, 1502, 0, 0, 39, '1501'),
	(377, 1, 0, -50331, 1503, 0, 0, 39, '1502'),
	(377, 1, 0, -50331, 1504, 0, 0, 39, '1503'),
	(377, 1, 0, -50331, 1505, 0, 0, 39, '1504'),
	(377, 1, 0, -50331, 1506, 0, 0, 39, '1505'),
	(377, 1, 0, -50331, 1507, 0, 0, 39, '1506'),
	(377, 1, 0, -50331, 1508, 0, 0, 39, '1507'),
	(377, 1, 0, -50331, 1509, 0, 0, 39, '1508'),
	(377, 1, 0, -50331, 1510, 0, 0, 39, '1509'),
	(377, 1, 0, -50331, 1511, 0, 0, 39, '1510'),
	(377, 1, 0, -50331, 1512, 0, 0, 39, '1511'),
	(377, 1, 0, -50331, 1513, 0, 0, 39, '1512'),
	(377, 1, 0, -50331, 1514, 0, 0, 39, '1513'),
	(377, 1, 0, -50331, 1515, 0, 0, 39, '1514'),
	(377, 1, 0, -50331, 1516, 0, 0, 39, '1515'),
	(377, 1, 0, -50331, 1517, 0, 0, 39, '1516'),
	(377, 1, 0, -50331, 1518, 0, 0, 39, '1517'),
	(377, 1, 0, -50331, 1519, 0, 0, 39, '1518'),
	(377, 1, 0, -50331, 1520, 0, 0, 39, '1519'),
	(377, 1, 0, -50331, 1521, 0, 0, 39, '1520'),
	(377, 1, 0, -50331, 1522, 0, 0, 39, '1521'),
	(377, 1, 0, -50331, 1523, 0, 0, 39, '1522'),
	(377, 1, 0, -50331, 1524, 0, 0, 39, '1523'),
	(377, 1, 0, -50331, 1525, 0, 0, 39, '1524'),
	(377, 1, 0, -50331, 1526, 0, 0, 39, '1525'),
	(377, 1, 0, -50331, 1527, 0, 0, 39, '1526'),
	(377, 1, 0, -50331, 1528, 0, 0, 39, '1527'),
	(377, 1, 0, -50331, 1529, 0, 0, 39, '1528'),
	(377, 1, 0, -50331, 1530, 0, 0, 39, '1529'),
	(377, 1, 0, -50331, 1531, 0, 0, 39, '1530'),
	(377, 1, 0, -50331, 1532, 0, 0, 39, '1531'),
	(377, 1, 0, -50331, 1533, 0, 0, 39, '1532'),
	(377, 1, 0, -50331, 1534, 0, 0, 39, '1533'),
	(377, 1, 0, -50331, 1535, 0, 0, 39, '1534'),
	(377, 1, 0, -50331, 1536, 0, 0, 39, '1535'),
	(377, 1, 0, -50331, 1537, 0, 0, 39, '1536'),
	(377, 1, 0, -50331, 1538, 0, 0, 39, '1537'),
	(377, 1, 0, -50331, 1539, 0, 0, 39, '1538'),
	(377, 1, 0, -50331, 1540, 0, 0, 39, '1539'),
	(377, 1, 0, -50331, 1541, 0, 0, 39, '1540'),
	(377, 1, 0, -50331, 1542, 0, 0, 39, '1541'),
	(377, 1, 0, -50331, 1543, 0, 0, 39, '1542'),
	(377, 1, 0, -50331, 1544, 0, 0, 39, '1543'),
	(377, 1, 0, -50331, 1545, 0, 0, 39, '1544'),
	(377, 1, 0, -50331, 1546, 0, 0, 39, '1545'),
	(377, 1, 0, -50331, 1547, 0, 0, 39, '1546'),
	(377, 1, 0, -50331, 1548, 0, 0, 39, '1547'),
	(377, 1, 0, -50331, 1549, 0, 0, 39, '1548'),
	(377, 1, 0, -50331, 1550, 0, 0, 39, '1549'),
	(377, 1, 0, -50331, 1551, 0, 0, 39, '1550'),
	(377, 1, 0, -50331, 1552, 0, 0, 39, '1551'),
	(377, 1, 0, -50331, 1553, 0, 0, 39, '1552'),
	(377, 1, 0, -50331, 1554, 0, 0, 39, '1553'),
	(377, 1, 0, -50331, 1555, 0, 0, 39, '1554'),
	(377, 1, 0, -50331, 1556, 0, 0, 39, '1555'),
	(377, 1, 0, -50331, 1557, 0, 0, 39, '1556'),
	(377, 1, 0, -50331, 1558, 0, 0, 39, '1557'),
	(377, 1, 0, -50331, 1559, 0, 0, 39, '1558'),
	(377, 1, 0, -50331, 1560, 0, 0, 39, '1559'),
	(377, 1, 0, -50331, 1561, 0, 0, 39, '1560'),
	(377, 1, 0, -50331, 1562, 0, 0, 39, '1561'),
	(377, 1, 0, -50331, 1563, 0, 0, 39, '1562'),
	(377, 1, 0, -50331, 1564, 0, 0, 39, '1563'),
	(377, 1, 0, -50331, 1565, 0, 0, 39, '1564'),
	(377, 1, 0, -50331, 1566, 0, 0, 39, '1565'),
	(377, 1, 0, -50331, 1567, 0, 0, 39, '1566'),
	(377, 1, 0, -50331, 1568, 0, 0, 39, '1567'),
	(377, 1, 0, -50331, 1569, 0, 0, 39, '1568'),
	(377, 1, 0, -50331, 1570, 0, 0, 39, '1569'),
	(377, 1, 0, -50331, 1571, 0, 0, 39, '1570'),
	(377, 1, 0, -50331, 1572, 0, 0, 39, '1571'),
	(377, 1, 0, -50331, 1573, 0, 0, 39, '1572'),
	(377, 1, 0, -50331, 1574, 0, 0, 39, '1573'),
	(377, 1, 0, -50331, 1575, 0, 0, 39, '1574'),
	(377, 1, 0, -50331, 1576, 0, 0, 39, '1575'),
	(377, 1, 0, -50331, 1577, 0, 0, 39, '1576'),
	(377, 1, 0, -50331, 1578, 0, 0, 39, '1577'),
	(377, 1, 0, -50331, 1579, 0, 0, 39, '1578'),
	(377, 1, 0, -50331, 1580, 0, 0, 39, '1579'),
	(377, 1, 0, -50331, 1581, 0, 0, 39, '1580'),
	(377, 1, 0, -50331, 1582, 0, 0, 39, '1581'),
	(377, 1, 0, -50331, 1583, 0, 0, 39, '1582'),
	(377, 1, 0, -50331, 1584, 0, 0, 39, '1583'),
	(377, 1, 0, -50331, 1585, 0, 0, 39, '1584'),
	(377, 1, 0, -50331, 1586, 0, 0, 39, '1585'),
	(377, 1, 0, -50331, 1587, 0, 0, 39, '1586'),
	(377, 1, 0, -50331, 1588, 0, 0, 39, '1587'),
	(377, 1, 0, -50331, 1589, 0, 0, 39, '1588'),
	(377, 1, 0, -50331, 1590, 0, 0, 39, '1589'),
	(377, 1, 0, -50331, 1591, 0, 0, 39, '1590'),
	(377, 1, 0, -50331, 1592, 0, 0, 39, '1591'),
	(377, 1, 0, -50331, 1593, 0, 0, 39, '1592'),
	(377, 1, 0, -50331, 1594, 0, 0, 39, '1593'),
	(377, 1, 0, -50331, 1595, 0, 0, 39, '1594'),
	(377, 1, 0, -50331, 1596, 0, 0, 39, '1595'),
	(377, 1, 0, -50331, 1597, 0, 0, 39, '1596'),
	(377, 1, 0, -50331, 1598, 0, 0, 39, '1597'),
	(377, 1, 0, -50331, 1599, 0, 0, 39, '1598'),
	(377, 1, 0, -50331, 1600, 0, 0, 39, '1599'),
	(377, 1, 0, -50331, 1601, 0, 0, 39, '1600'),
	(377, 1, 0, -50331, 1602, 0, 0, 39, '1601'),
	(377, 1, 0, -50331, 1603, 0, 0, 39, '1602'),
	(377, 1, 0, -50331, 1604, 0, 0, 39, '1603'),
	(377, 1, 0, -50331, 1605, 0, 0, 39, '1604'),
	(377, 1, 0, -50331, 1606, 0, 0, 39, '1605'),
	(377, 1, 0, -50331, 1607, 0, 0, 39, '1606'),
	(377, 1, 0, -50331, 1608, 0, 0, 39, '1607'),
	(377, 1, 0, -50331, 1609, 0, 0, 39, '1608'),
	(377, 1, 0, -50331, 1610, 0, 0, 39, '1609'),
	(377, 1, 0, -50331, 1611, 0, 0, 39, '1610'),
	(377, 1, 0, -50331, 1612, 0, 0, 39, '1611'),
	(377, 1, 0, -50331, 1613, 0, 0, 39, '1612'),
	(377, 1, 0, -50331, 1614, 0, 0, 39, '1613'),
	(377, 1, 0, -50331, 1615, 0, 0, 39, '1614'),
	(377, 1, 0, -50331, 1616, 0, 0, 39, '1615'),
	(377, 1, 0, -50331, 1617, 0, 0, 39, '1616'),
	(377, 1, 0, -50331, 1618, 0, 0, 39, '1617'),
	(377, 1, 0, -50331, 1619, 0, 0, 39, '1618'),
	(377, 1, 0, -50331, 1620, 0, 0, 39, '1619'),
	(377, 1, 0, -50331, 1621, 0, 0, 39, '1620'),
	(377, 1, 0, -50331, 1622, 0, 0, 39, '1621'),
	(377, 1, 0, -50331, 1623, 0, 0, 39, '1622'),
	(377, 1, 0, -50331, 1624, 0, 0, 39, '1623'),
	(377, 1, 0, -50331, 1625, 0, 0, 39, '1624'),
	(377, 1, 0, -50331, 1626, 0, 0, 39, '1625'),
	(377, 1, 0, -50331, 1627, 0, 0, 39, '1626'),
	(377, 1, 0, -50331, 1628, 0, 0, 39, '1627'),
	(377, 1, 0, -50331, 1629, 0, 0, 39, '1628'),
	(377, 1, 0, -50331, 1630, 0, 0, 39, '1629'),
	(377, 1, 0, -50331, 1631, 0, 0, 39, '1630'),
	(377, 1, 0, -50331, 1632, 0, 0, 39, '1631'),
	(377, 1, 0, -50331, 1633, 0, 0, 39, '1632'),
	(377, 1, 0, -50331, 1634, 0, 0, 39, '1633'),
	(377, 1, 0, -50331, 1635, 0, 0, 39, '1634'),
	(377, 1, 0, -50331, 1636, 0, 0, 39, '1635'),
	(377, 1, 0, -50331, 1637, 0, 0, 39, '1636'),
	(377, 1, 0, -50331, 1638, 0, 0, 39, '1637'),
	(377, 1, 0, -50331, 1639, 0, 0, 39, '1638'),
	(377, 1, 0, -50331, 1640, 0, 0, 39, '1639'),
	(377, 1, 0, -50331, 1641, 0, 0, 39, '1640'),
	(377, 1, 0, -50331, 1642, 0, 0, 39, '1641'),
	(377, 1, 0, -50331, 1643, 0, 0, 39, '1642'),
	(377, 1, 0, -50331, 1644, 0, 0, 39, '1643'),
	(377, 1, 0, -50331, 1645, 0, 0, 39, '1644'),
	(377, 1, 0, -50331, 1646, 0, 0, 39, '1645'),
	(377, 1, 0, -50331, 1647, 0, 0, 39, '1646'),
	(377, 1, 0, -50331, 1648, 0, 0, 39, '1647'),
	(377, 1, 0, -50331, 1649, 0, 0, 39, '1648'),
	(377, 1, 0, -50331, 1650, 0, 0, 39, '1649'),
	(377, 1, 0, -50331, 1651, 0, 0, 39, '1650'),
	(377, 1, 0, -50331, 1652, 0, 0, 39, '1651'),
	(377, 1, 0, -50331, 1653, 0, 0, 39, '1652'),
	(377, 1, 0, -50331, 1654, 0, 0, 39, '1653'),
	(377, 1, 0, -50331, 1655, 0, 0, 39, '1654'),
	(377, 1, 0, -50331, 1656, 0, 0, 39, '1655'),
	(377, 1, 0, -50331, 1657, 0, 0, 39, '1656'),
	(377, 1, 0, -50331, 1658, 0, 0, 39, '1657'),
	(377, 1, 0, -50331, 1659, 0, 0, 39, '1658'),
	(377, 1, 0, -50331, 1660, 0, 0, 39, '1659'),
	(377, 1, 0, -50331, 1661, 0, 0, 39, '1660'),
	(377, 1, 0, -50331, 1662, 0, 0, 39, '1661'),
	(377, 1, 0, -50331, 1663, 0, 0, 39, '1662'),
	(377, 1, 0, -50331, 1664, 0, 0, 39, '1663'),
	(377, 1, 0, -50331, 1665, 0, 0, 39, '1664'),
	(377, 1, 0, -50331, 1666, 0, 0, 39, '1665'),
	(377, 1, 0, -50331, 1667, 0, 0, 39, '1666'),
	(377, 1, 0, -50331, 1668, 0, 0, 39, '1667'),
	(377, 1, 0, -50331, 1669, 0, 0, 39, '1668'),
	(377, 1, 0, -50331, 1670, 0, 0, 39, '1669'),
	(377, 1, 0, -50331, 1671, 0, 0, 39, '1670'),
	(377, 1, 0, -50331, 1672, 0, 0, 39, '1671'),
	(377, 1, 0, -50331, 1673, 0, 0, 39, '1672'),
	(377, 1, 0, -50331, 1674, 0, 0, 39, '1673'),
	(377, 1, 0, -50331, 1675, 0, 0, 39, '1674'),
	(377, 1, 0, -50331, 1676, 0, 0, 39, '1675'),
	(377, 1, 0, -50331, 1677, 0, 0, 39, '1676'),
	(377, 1, 0, -50331, 1678, 0, 0, 39, '1677'),
	(377, 1, 0, -50331, 1679, 0, 0, 39, '1678'),
	(377, 1, 0, -50331, 1680, 0, 0, 39, '1679'),
	(377, 1, 0, -50331, 1681, 0, 0, 39, '1680'),
	(377, 1, 0, -50331, 1682, 0, 0, 39, '1681'),
	(377, 1, 0, -50331, 1683, 0, 0, 39, '1682'),
	(377, 1, 0, -50331, 1684, 0, 0, 39, '1683'),
	(377, 1, 0, -50331, 1685, 0, 0, 39, '1684'),
	(377, 1, 0, -50331, 1686, 0, 0, 39, '1685'),
	(377, 1, 0, -50331, 1687, 0, 0, 39, '1686'),
	(377, 1, 0, -50331, 1688, 0, 0, 39, '1687'),
	(377, 1, 0, -50331, 1689, 0, 0, 39, '1688'),
	(377, 1, 0, -50331, 1690, 0, 0, 39, '1689'),
	(377, 1, 0, -50331, 1691, 0, 0, 39, '1690'),
	(377, 1, 0, -50331, 1692, 0, 0, 39, '1691'),
	(377, 1, 0, -50331, 1693, 0, 0, 39, '1692'),
	(377, 1, 0, -50331, 1694, 0, 0, 39, '1693'),
	(377, 1, 0, -50331, 1695, 0, 0, 39, '1694'),
	(377, 1, 0, -50331, 1696, 0, 0, 39, '1695'),
	(377, 1, 0, -50331, 1697, 0, 0, 39, '1696'),
	(377, 1, 0, -50331, 1698, 0, 0, 39, '1697'),
	(377, 1, 0, -50331, 1699, 0, 0, 39, '1698'),
	(377, 1, 0, -50331, 1700, 0, 0, 39, '1699'),
	(377, 1, 0, -50331, 1701, 0, 0, 39, '1700'),
	(377, 1, 0, -50331, 1702, 0, 0, 39, '1701'),
	(377, 1, 0, -50331, 1703, 0, 0, 39, '1702'),
	(377, 1, 0, -50331, 1704, 0, 0, 39, '1703'),
	(377, 1, 0, -50331, 1705, 0, 0, 39, '1704'),
	(377, 1, 0, -50331, 1706, 0, 0, 39, '1705'),
	(377, 1, 0, -50331, 1707, 0, 0, 39, '1706'),
	(377, 1, 0, -50331, 1708, 0, 0, 39, '1707'),
	(377, 1, 0, -50331, 1709, 0, 0, 39, '1708'),
	(377, 1, 0, -50331, 1710, 0, 0, 39, '1709'),
	(377, 1, 0, -50331, 1711, 0, 0, 39, '1710'),
	(377, 1, 0, -50331, 1712, 0, 0, 39, '1711'),
	(377, 1, 0, -50331, 1713, 0, 0, 39, '1712'),
	(377, 1, 0, -50331, 1714, 0, 0, 39, '1713'),
	(377, 1, 0, -50331, 1715, 0, 0, 39, '1714'),
	(377, 1, 0, -50331, 1716, 0, 0, 39, '1715'),
	(377, 1, 0, -50331, 1717, 0, 0, 39, '1716'),
	(377, 1, 0, -50331, 1718, 0, 0, 39, '1717'),
	(377, 1, 0, -50331, 1719, 0, 0, 39, '1718'),
	(377, 1, 0, -50331, 1720, 0, 0, 39, '1719'),
	(377, 1, 0, -50331, 1721, 0, 0, 39, '1720'),
	(377, 1, 0, -50331, 1722, 0, 0, 39, '1721'),
	(377, 1, 0, -50331, 1723, 0, 0, 39, '1722'),
	(377, 1, 0, -50331, 1724, 0, 0, 39, '1723'),
	(377, 1, 0, -50331, 1725, 0, 0, 39, '1724'),
	(377, 1, 0, -50331, 1726, 0, 0, 39, '1725'),
	(377, 1, 0, -50331, 1727, 0, 0, 39, '1726'),
	(377, 1, 0, -50331, 1728, 0, 0, 39, '1727'),
	(377, 1, 0, -50331, 1729, 0, 0, 39, '1728'),
	(377, 1, 0, -50331, 1730, 0, 0, 39, '1729'),
	(377, 1, 0, -50331, 1731, 0, 0, 39, '1730'),
	(377, 1, 0, -50331, 1732, 0, 0, 39, '1731'),
	(377, 1, 0, -50331, 1733, 0, 0, 39, '1732'),
	(377, 1, 0, -50331, 1734, 0, 0, 39, '1733'),
	(377, 1, 0, -50331, 1735, 0, 0, 39, '1734'),
	(377, 1, 0, -50331, 1736, 0, 0, 39, '1735'),
	(377, 1, 0, -50331, 1737, 0, 0, 39, '1736'),
	(377, 1, 0, -50331, 1738, 0, 0, 39, '1737'),
	(377, 1, 0, -50331, 1739, 0, 0, 39, '1738'),
	(377, 1, 0, -50331, 1740, 0, 0, 39, '1739'),
	(377, 1, 0, -50331, 1741, 0, 0, 39, '1740'),
	(377, 1, 0, -50331, 1742, 0, 0, 39, '1741'),
	(377, 1, 0, -50331, 1743, 0, 0, 39, '1742'),
	(377, 1, 0, -50331, 1744, 0, 0, 39, '1743'),
	(377, 1, 0, -50331, 1745, 0, 0, 39, '1744'),
	(377, 1, 0, -50331, 1746, 0, 0, 39, '1745'),
	(377, 1, 0, -50331, 1747, 0, 0, 39, '1746'),
	(377, 1, 0, -50331, 1748, 0, 0, 39, '1747'),
	(377, 1, 0, -50331, 1749, 0, 0, 39, '1748'),
	(377, 1, 0, -50331, 1750, 0, 0, 39, '1749'),
	(377, 1, 0, -50331, 1751, 0, 0, 39, '1750'),
	(377, 1, 0, -50331, 1752, 0, 0, 39, '1751'),
	(377, 1, 0, -50331, 1753, 0, 0, 39, '1752'),
	(377, 1, 0, -50331, 1754, 0, 0, 39, '1753'),
	(377, 1, 0, -50331, 1755, 0, 0, 39, '1754'),
	(377, 1, 0, -50331, 1756, 0, 0, 39, '1755'),
	(377, 1, 0, -50331, 1757, 0, 0, 39, '1756'),
	(377, 1, 0, -50331, 1758, 0, 0, 39, '1757'),
	(377, 1, 0, -50331, 1759, 0, 0, 39, '1758'),
	(377, 1, 0, -50331, 1760, 0, 0, 39, '1759'),
	(377, 1, 0, -50331, 1761, 0, 0, 39, '1760'),
	(377, 1, 0, -50331, 1762, 0, 0, 39, '1761'),
	(377, 1, 0, -50331, 1763, 0, 0, 39, '1762'),
	(377, 1, 0, -50331, 1764, 0, 0, 39, '1763'),
	(377, 1, 0, -50331, 1765, 0, 0, 39, '1764'),
	(377, 1, 0, -50331, 1766, 0, 0, 39, '1765'),
	(377, 1, 0, -50331, 1767, 0, 0, 39, '1766'),
	(377, 1, 0, -50331, 1768, 0, 0, 39, '1767'),
	(377, 1, 0, -50331, 1769, 0, 0, 39, '1768'),
	(377, 1, 0, -50331, 1770, 0, 0, 39, '1769'),
	(377, 1, 0, -50331, 1771, 0, 0, 39, '1770'),
	(377, 1, 0, -50331, 1772, 0, 0, 39, '1771'),
	(377, 1, 0, -50331, 1773, 0, 0, 39, '1772'),
	(377, 1, 0, -50331, 1774, 0, 0, 39, '1773'),
	(377, 1, 0, -50331, 1775, 0, 0, 39, '1774'),
	(377, 1, 0, -50331, 1776, 0, 0, 39, '1775'),
	(377, 1, 0, -50331, 1777, 0, 0, 39, '1776'),
	(377, 1, 0, -50331, 1778, 0, 0, 39, '1777'),
	(377, 1, 0, -50331, 1779, 0, 0, 39, '1778'),
	(377, 1, 0, -50331, 1780, 0, 0, 39, '1779'),
	(377, 1, 0, -50331, 1781, 0, 0, 39, '1780'),
	(377, 1, 0, -50331, 1782, 0, 0, 39, '1781'),
	(377, 1, 0, -50331, 1783, 0, 0, 39, '1782'),
	(377, 1, 0, -50331, 1784, 0, 0, 39, '1783'),
	(377, 1, 0, -50331, 1785, 0, 0, 39, '1784'),
	(377, 1, 0, -50331, 1786, 0, 0, 39, '1785'),
	(377, 1, 0, -50331, 1787, 0, 0, 39, '1786'),
	(377, 1, 0, -50331, 1788, 0, 0, 39, '1787'),
	(377, 1, 0, -50331, 1789, 0, 0, 39, '1788'),
	(377, 1, 0, -50331, 1790, 0, 0, 39, '1789'),
	(377, 1, 0, -50331, 1791, 0, 0, 39, '1790'),
	(377, 1, 0, -50331, 1792, 0, 0, 39, '1791'),
	(377, 1, 0, -50331, 1793, 0, 0, 39, '1792'),
	(377, 1, 0, -50331, 1794, 0, 0, 39, '1793'),
	(377, 1, 0, -50331, 1795, 0, 0, 39, '1794'),
	(377, 1, 0, -50331, 1796, 0, 0, 39, '1795'),
	(377, 1, 0, -50331, 1797, 0, 0, 39, '1796'),
	(377, 1, 0, -50331, 1798, 0, 0, 39, '1797'),
	(377, 1, 0, -50331, 1799, 0, 0, 39, '1798'),
	(377, 1, 0, -50331, 1800, 0, 0, 39, '1799'),
	(377, 1, 0, -50331, 1801, 0, 0, 39, '1800'),
	(377, 1, 0, -50331, 1802, 0, 0, 39, '1801'),
	(377, 1, 0, -50331, 1803, 0, 0, 39, '1802'),
	(377, 1, 0, -50331, 1804, 0, 0, 39, '1803'),
	(377, 1, 0, -50331, 1805, 0, 0, 39, '1804'),
	(377, 1, 0, -50331, 1806, 0, 0, 39, '1805'),
	(377, 1, 0, -50331, 1807, 0, 0, 39, '1806'),
	(377, 1, 0, -50331, 1808, 0, 0, 39, '1807'),
	(377, 1, 0, -50331, 1809, 0, 0, 39, '1808'),
	(377, 1, 0, -50331, 1810, 0, 0, 39, '1809'),
	(377, 1, 0, -50331, 1811, 0, 0, 39, '1810'),
	(377, 1, 0, -50331, 1812, 0, 0, 39, '1811'),
	(377, 1, 0, -50331, 1813, 0, 0, 39, '1812'),
	(377, 1, 0, -50331, 1814, 0, 0, 39, '1813'),
	(377, 1, 0, -50331, 1815, 0, 0, 39, '1814'),
	(377, 1, 0, -50331, 1816, 0, 0, 39, '1815'),
	(377, 1, 0, -50331, 1817, 0, 0, 39, '1816'),
	(377, 1, 0, -50331, 1818, 0, 0, 39, '1817'),
	(377, 1, 0, -50331, 1819, 0, 0, 39, '1818'),
	(377, 1, 0, -50331, 1820, 0, 0, 39, '1819'),
	(377, 1, 0, -50331, 1821, 0, 0, 39, '1820'),
	(377, 1, 0, -50331, 1822, 0, 0, 39, '1821'),
	(377, 1, 0, -50331, 1823, 0, 0, 39, '1822'),
	(377, 1, 0, -50331, 1824, 0, 0, 39, '1823'),
	(377, 1, 0, -50331, 1825, 0, 0, 39, '1824'),
	(377, 1, 0, -50331, 1826, 0, 0, 39, '1825'),
	(377, 1, 0, -50331, 1827, 0, 0, 39, '1826'),
	(377, 1, 0, -50331, 1828, 0, 0, 39, '1827'),
	(377, 1, 0, -50331, 1829, 0, 0, 39, '1828'),
	(377, 1, 0, -50331, 1830, 0, 0, 39, '1829'),
	(377, 1, 0, -50331, 1831, 0, 0, 39, '1830'),
	(377, 1, 0, -50331, 1832, 0, 0, 39, '1831'),
	(377, 1, 0, -50331, 1833, 0, 0, 39, '1832'),
	(377, 1, 0, -50331, 1834, 0, 0, 39, '1833'),
	(377, 1, 0, -50331, 1835, 0, 0, 39, '1834'),
	(377, 1, 0, -50331, 1836, 0, 0, 39, '1835'),
	(377, 1, 0, -50331, 1837, 0, 0, 39, '1836'),
	(377, 1, 0, -50331, 1838, 0, 0, 39, '1837'),
	(377, 1, 0, -50331, 1839, 0, 0, 39, '1838'),
	(377, 1, 0, -50331, 1840, 0, 0, 39, '1839'),
	(377, 1, 0, -50331, 1841, 0, 0, 39, '1840'),
	(377, 1, 0, -50331, 1842, 0, 0, 39, '1841'),
	(377, 1, 0, -50331, 1843, 0, 0, 39, '1842'),
	(377, 1, 0, -50331, 1844, 0, 0, 39, '1843'),
	(377, 1, 0, -50331, 1845, 0, 0, 39, '1844'),
	(377, 1, 0, -50331, 1846, 0, 0, 39, '1845'),
	(377, 1, 0, -50331, 1847, 0, 0, 39, '1846'),
	(377, 1, 0, -50331, 1848, 0, 0, 39, '1847'),
	(377, 1, 0, -50331, 1849, 0, 0, 39, '1848'),
	(377, 1, 0, -50331, 1850, 0, 0, 39, '1849'),
	(377, 1, 0, -50331, 1851, 0, 0, 39, '1850'),
	(377, 1, 0, -50331, 1852, 0, 0, 39, '1851'),
	(377, 1, 0, -50331, 1853, 0, 0, 39, '1852'),
	(377, 1, 0, -50331, 1854, 0, 0, 39, '1853'),
	(377, 1, 0, -50331, 1855, 0, 0, 39, '1854'),
	(377, 1, 0, -50331, 1856, 0, 0, 39, '1855'),
	(377, 1, 0, -50331, 1857, 0, 0, 39, '1856'),
	(377, 1, 0, -50331, 1858, 0, 0, 39, '1857'),
	(377, 1, 0, -50331, 1859, 0, 0, 39, '1858'),
	(377, 1, 0, -50331, 1860, 0, 0, 39, '1859'),
	(377, 1, 0, -50331, 1861, 0, 0, 39, '1860'),
	(377, 1, 0, -50331, 1862, 0, 0, 39, '1861'),
	(377, 1, 0, -50331, 1863, 0, 0, 39, '1862'),
	(377, 1, 0, -50331, 1864, 0, 0, 39, '1863'),
	(377, 1, 0, -50331, 1865, 0, 0, 39, '1864'),
	(377, 1, 0, -50331, 1866, 0, 0, 39, '1865'),
	(377, 1, 0, -50331, 1867, 0, 0, 39, '1866'),
	(377, 1, 0, -50331, 1868, 0, 0, 39, '1867'),
	(377, 1, 0, -50331, 1869, 0, 0, 39, '1868'),
	(377, 1, 0, -50331, 1870, 0, 0, 39, '1869'),
	(377, 1, 0, -50331, 1871, 0, 0, 39, '1870'),
	(377, 1, 0, -50331, 1872, 0, 0, 39, '1871'),
	(377, 1, 0, -50331, 1873, 0, 0, 39, '1872'),
	(377, 1, 0, -50331, 1874, 0, 0, 39, '1873'),
	(377, 1, 0, -50331, 1875, 0, 0, 39, '1874'),
	(377, 1, 0, -50331, 1876, 0, 0, 39, '1875'),
	(377, 1, 0, -50331, 1877, 0, 0, 39, '1876'),
	(377, 1, 0, -50331, 1878, 0, 0, 39, '1877'),
	(377, 1, 0, -50331, 1879, 0, 0, 39, '1878'),
	(377, 1, 0, -50331, 1880, 0, 0, 39, '1879'),
	(377, 1, 0, -50331, 1881, 0, 0, 39, '1880'),
	(377, 1, 0, -50331, 1882, 0, 0, 39, '1881'),
	(377, 1, 0, -50331, 1883, 0, 0, 39, '1882'),
	(377, 1, 0, -50331, 1884, 0, 0, 39, '1883'),
	(377, 1, 0, -50331, 1885, 0, 0, 39, '1884'),
	(377, 1, 0, -50331, 1886, 0, 0, 39, '1885'),
	(377, 1, 0, -50331, 1887, 0, 0, 39, '1886'),
	(377, 1, 0, -50331, 1888, 0, 0, 39, '1887'),
	(377, 1, 0, -50331, 1889, 0, 0, 39, '1888'),
	(377, 1, 0, -50331, 1890, 0, 0, 39, '1889'),
	(377, 1, 0, -50331, 1891, 0, 0, 39, '1890'),
	(377, 1, 0, -50331, 1892, 0, 0, 39, '1891'),
	(377, 1, 0, -50331, 1893, 0, 0, 39, '1892'),
	(377, 1, 0, -50331, 1894, 0, 0, 39, '1893'),
	(377, 1, 0, -50331, 1895, 0, 0, 39, '1894'),
	(377, 1, 0, -50331, 1896, 0, 0, 39, '1895'),
	(377, 1, 0, -50331, 1897, 0, 0, 39, '1896'),
	(377, 1, 0, -50331, 1898, 0, 0, 39, '1897'),
	(377, 1, 0, -50331, 1899, 0, 0, 39, '1898'),
	(377, 1, 0, -50331, 1900, 0, 0, 39, '1899'),
	(377, 1, 0, -50331, 1901, 0, 0, 39, '1900'),
	(377, 1, 0, -50331, 1902, 0, 0, 39, '1901'),
	(377, 1, 0, -50331, 1903, 0, 0, 39, '1902'),
	(377, 1, 0, -50331, 1904, 0, 0, 39, '1903'),
	(377, 1, 0, -50331, 1905, 0, 0, 39, '1904'),
	(377, 1, 0, -50331, 1906, 0, 0, 39, '1905'),
	(377, 1, 0, -50331, 1907, 0, 0, 39, '1906'),
	(377, 1, 0, -50331, 1908, 0, 0, 39, '1907'),
	(377, 1, 0, -50331, 1909, 0, 0, 39, '1908'),
	(377, 1, 0, -50331, 1910, 0, 0, 39, '1909'),
	(377, 1, 0, -50331, 1911, 0, 0, 39, '1910'),
	(377, 1, 0, -50331, 1912, 0, 0, 39, '1911'),
	(377, 1, 0, -50331, 1913, 0, 0, 39, '1912'),
	(377, 1, 0, -50331, 1914, 0, 0, 39, '1913'),
	(377, 1, 0, -50331, 1915, 0, 0, 39, '1914'),
	(377, 1, 0, -50331, 1916, 0, 0, 39, '1915'),
	(377, 1, 0, -50331, 1917, 0, 0, 39, '1916'),
	(377, 1, 0, -50331, 1918, 0, 0, 39, '1917'),
	(377, 1, 0, -50331, 1919, 0, 0, 39, '1918'),
	(377, 1, 0, -50331, 1920, 0, 0, 39, '1919'),
	(377, 1, 0, -50331, 1921, 0, 0, 39, '1920'),
	(377, 1, 0, -50331, 1922, 0, 0, 39, '1921'),
	(377, 1, 0, -50331, 1923, 0, 0, 39, '1922'),
	(377, 1, 0, -50331, 1924, 0, 0, 39, '1923'),
	(377, 1, 0, -50331, 1925, 0, 0, 39, '1924'),
	(377, 1, 0, -50331, 1926, 0, 0, 39, '1925'),
	(377, 1, 0, -50331, 1927, 0, 0, 39, '1926'),
	(377, 1, 0, -50331, 1928, 0, 0, 39, '1927'),
	(377, 1, 0, -50331, 1929, 0, 0, 39, '1928'),
	(377, 1, 0, -50331, 1930, 0, 0, 39, '1929'),
	(377, 1, 0, -50331, 1931, 0, 0, 39, '1930'),
	(377, 1, 0, -50331, 1932, 0, 0, 39, '1931'),
	(377, 1, 0, -50331, 1933, 0, 0, 39, '1932'),
	(377, 1, 0, -50331, 1934, 0, 0, 39, '1933'),
	(377, 1, 0, -50331, 1935, 0, 0, 39, '1934'),
	(377, 1, 0, -50331, 1936, 0, 0, 39, '1935'),
	(377, 1, 0, -50331, 1937, 0, 0, 39, '1936'),
	(377, 1, 0, -50331, 1938, 0, 0, 39, '1937'),
	(377, 1, 0, -50331, 1939, 0, 0, 39, '1938'),
	(377, 1, 0, -50331, 1940, 0, 0, 39, '1939'),
	(377, 1, 0, -50331, 1941, 0, 0, 39, '1940'),
	(377, 1, 0, -50331, 1942, 0, 0, 39, '1941'),
	(377, 1, 0, -50331, 1943, 0, 0, 39, '1942'),
	(377, 1, 0, -50331, 1944, 0, 0, 39, '1943'),
	(377, 1, 0, -50331, 1945, 0, 0, 39, '1944'),
	(377, 1, 0, -50331, 1946, 0, 0, 39, '1945'),
	(377, 1, 0, -50331, 1947, 0, 0, 39, '1946'),
	(377, 1, 0, -50331, 1948, 0, 0, 39, '1947'),
	(377, 1, 0, -50331, 1949, 0, 0, 39, '1948'),
	(377, 1, 0, -50331, 1950, 0, 0, 39, '1949'),
	(377, 1, 0, -50331, 1951, 0, 0, 39, '1950'),
	(377, 1, 0, -50331, 1952, 0, 0, 39, '1951'),
	(377, 1, 0, -50331, 1953, 0, 0, 39, '1952'),
	(377, 1, 0, -50331, 1954, 0, 0, 39, '1953'),
	(377, 1, 0, -50331, 1955, 0, 0, 39, '1954'),
	(377, 1, 0, -50331, 1956, 0, 0, 39, '1955'),
	(377, 1, 0, -50331, 1957, 0, 0, 39, '1956'),
	(377, 1, 0, -50331, 1958, 0, 0, 39, '1957'),
	(377, 1, 0, -50331, 1959, 0, 0, 39, '1958'),
	(377, 1, 0, -50331, 1960, 0, 0, 39, '1959'),
	(377, 1, 0, -50331, 1961, 0, 0, 39, '1960'),
	(377, 1, 0, -50331, 1962, 0, 0, 39, '1961'),
	(377, 1, 0, -50331, 1963, 0, 0, 39, '1962'),
	(377, 1, 0, -50331, 1964, 0, 0, 39, '1963'),
	(377, 1, 0, -50331, 1965, 0, 0, 39, '1964'),
	(377, 1, 0, -50331, 1966, 0, 0, 39, '1965'),
	(377, 1, 0, -50331, 1967, 0, 0, 39, '1966'),
	(377, 1, 0, -50331, 1968, 0, 0, 39, '1967'),
	(377, 1, 0, -50331, 1969, 0, 0, 39, '1968'),
	(377, 1, 0, -50331, 1970, 0, 0, 39, '1969'),
	(377, 1, 0, -50331, 1971, 0, 0, 39, '1970'),
	(377, 1, 0, -50331, 1972, 0, 0, 39, '1971'),
	(377, 1, 0, -50331, 1973, 0, 0, 39, '1972'),
	(377, 1, 0, -50331, 1974, 0, 0, 39, '1973'),
	(377, 1, 0, -50331, 1975, 0, 0, 39, '1974'),
	(377, 1, 0, -50331, 1976, 0, 0, 39, '1975'),
	(377, 1, 0, -50331, 1977, 0, 0, 39, '1976'),
	(377, 1, 0, -50331, 1978, 0, 0, 39, '1977'),
	(377, 1, 0, -50331, 1979, 0, 0, 39, '1978'),
	(377, 1, 0, -50331, 1980, 0, 0, 39, '1979'),
	(377, 1, 0, -50331, 1981, 0, 0, 39, '1980'),
	(377, 1, 0, -50331, 1982, 0, 0, 39, '1981'),
	(377, 1, 0, -50331, 1983, 0, 0, 39, '1982'),
	(377, 1, 0, -50331, 1984, 0, 0, 39, '1983'),
	(377, 1, 0, -50331, 1985, 0, 0, 39, '1984'),
	(377, 1, 0, -50331, 1986, 0, 0, 39, '1985'),
	(377, 1, 0, -50331, 1987, 0, 0, 39, '1986'),
	(377, 1, 0, -50331, 1988, 0, 0, 39, '1987'),
	(377, 1, 0, -50331, 1989, 0, 0, 39, '1988'),
	(377, 1, 0, -50331, 1990, 0, 0, 39, '1989'),
	(377, 1, 0, -50331, 1991, 0, 0, 39, '1990'),
	(377, 1, 0, -50331, 1992, 0, 0, 39, '1991'),
	(377, 1, 0, -50331, 1993, 0, 0, 39, '1992'),
	(377, 1, 0, -50331, 1994, 0, 0, 39, '1993'),
	(377, 1, 0, -50331, 1995, 0, 0, 39, '1994'),
	(377, 1, 0, -50331, 1996, 0, 0, 39, '1995'),
	(377, 1, 0, -50331, 1997, 0, 0, 39, '1996'),
	(377, 1, 0, -50331, 1998, 0, 0, 39, '1997'),
	(377, 1, 0, -50331, 1999, 0, 0, 39, '1998'),
	(377, 1, 0, -50331, 2000, 0, 0, 39, '1999'),
	(377, 1, 0, -50331, 2001, 0, 0, 39, '2000'),
	(377, 1, 0, -50331, 2002, 0, 0, 39, '2001'),
	(377, 1, 0, -50331, 2003, 0, 0, 39, '2002'),
	(377, 1, 0, -50331, 2004, 0, 0, 39, '2003'),
	(377, 1, 0, -50331, 2005, 0, 0, 39, '2004'),
	(377, 1, 0, -50331, 2006, 0, 0, 39, '2005'),
	(377, 1, 0, -50331, 2007, 0, 0, 39, '2006'),
	(377, 1, 0, -50331, 2008, 0, 0, 39, '2007'),
	(377, 1, 0, -50331, 2009, 0, 0, 39, '2008'),
	(377, 1, 0, -50331, 2010, 0, 0, 39, '2009'),
	(377, 1, 0, -50331, 2011, 0, 0, 39, '2010'),
	(377, 1, 0, -50331, 2012, 0, 0, 39, '2011'),
	(377, 1, 0, -50331, 2013, 0, 0, 39, '2012'),
	(377, 1, 0, -50331, 2014, 0, 0, 39, '2013'),
	(377, 1, 0, -50331, 2015, 0, 0, 39, '2014'),
	(377, 1, 0, -50331, 2016, 0, 0, 39, '2015'),
	(377, 1, 0, -50331, 2017, 0, 0, 39, '2016'),
	(377, 1, 0, -50331, 2018, 0, 0, 39, '2017'),
	(377, 1, 0, -50331, 2019, 0, 0, 39, '2018'),
	(377, 1, 0, -50331, 2020, 0, 0, 39, '2019'),
	(377, 1, 0, -50331, 2021, 0, 0, 39, '2020'),
	(377, 1, 0, -50331, 2022, 0, 0, 39, '2021'),
	(377, 1, 0, -50331, 2023, 0, 0, 39, '2022'),
	(377, 1, 0, -50331, 2024, 0, 0, 39, '2023'),
	(377, 1, 0, -50331, 2025, 0, 0, 39, '2024'),
	(377, 1, 0, -50331, 2026, 0, 0, 39, '2025'),
	(377, 1, 0, -50331, 2027, 0, 0, 39, '2026'),
	(377, 1, 0, -50331, 2028, 0, 0, 39, '2027'),
	(377, 1, 0, -50331, 2029, 0, 0, 39, '2028'),
	(377, 1, 0, -50331, 2030, 0, 0, 39, '2029'),
	(377, 1, 0, -50331, 2031, 0, 0, 39, '2030'),
	(377, 1, 0, -50331, 2032, 0, 0, 39, '2031'),
	(377, 1, 0, -50331, 2033, 0, 0, 39, '2032'),
	(377, 1, 0, -50331, 2034, 0, 0, 39, '2033'),
	(377, 1, 0, -50331, 2035, 0, 0, 39, '2034'),
	(377, 1, 0, -50331, 2036, 0, 0, 39, '2035'),
	(377, 1, 0, -50331, 2037, 0, 0, 39, '2036'),
	(377, 1, 0, -50331, 2038, 0, 0, 39, '2037'),
	(377, 1, 0, -50331, 2039, 0, 0, 39, '2038'),
	(377, 1, 0, -50331, 2040, 0, 0, 39, '2039'),
	(377, 1, 0, -50331, 2041, 0, 0, 39, '2040'),
	(377, 1, 0, -50331, 2042, 0, 0, 39, '2041'),
	(377, 1, 0, -50331, 2043, 0, 0, 39, '2042'),
	(377, 1, 0, -50331, 2044, 0, 0, 39, '2043'),
	(377, 1, 0, -50331, 2045, 0, 0, 39, '2044'),
	(377, 1, 0, -50331, 2046, 0, 0, 39, '2045'),
	(377, 1, 0, -50331, 2047, 0, 0, 39, '2046'),
	(377, 1, 0, -50331, 2048, 0, 0, 39, '2047'),
	(377, 1, 0, -50331, 2049, 0, 0, 39, '2048'),
	(377, 1, 0, -50331, 2050, 0, 0, 39, '2049'),
	(377, 1, 0, -50331, 2051, 0, 0, 39, '2050'),
	(377, 1, 0, -50331, 2052, 0, 0, 39, '2051'),
	(377, 1, 0, -50331, 2053, 0, 0, 39, '2052'),
	(377, 1, 0, -50331, 2054, 0, 0, 39, '2053'),
	(377, 1, 0, -50331, 2055, 0, 0, 39, '2054'),
	(377, 1, 0, -50331, 2056, 0, 0, 39, '2055'),
	(377, 1, 0, -50331, 2057, 0, 0, 39, '2056'),
	(377, 1, 0, -50331, 2058, 0, 0, 39, '2057'),
	(377, 1, 0, -50331, 2059, 0, 0, 39, '2058'),
	(377, 1, 0, -50331, 2060, 0, 0, 39, '2059'),
	(377, 1, 0, -50331, 2061, 0, 0, 39, '2060'),
	(377, 1, 0, -50331, 2062, 0, 0, 39, '2061'),
	(377, 1, 0, -50331, 2063, 0, 0, 39, '2062'),
	(377, 1, 0, -50331, 2064, 0, 0, 39, '2063'),
	(377, 1, 0, -50331, 2065, 0, 0, 39, '2064'),
	(377, 1, 0, -50331, 2066, 0, 0, 39, '2065'),
	(377, 1, 0, -50331, 2067, 0, 0, 39, '2066'),
	(377, 1, 0, -50331, 2068, 0, 0, 39, '2067'),
	(377, 1, 0, -50331, 2069, 0, 0, 39, '2068'),
	(377, 1, 0, -50331, 2070, 0, 0, 39, '2069'),
	(377, 1, 0, -50331, 2071, 0, 0, 39, '2070'),
	(377, 1, 0, -50331, 2072, 0, 0, 39, '2071'),
	(377, 1, 0, -50331, 2073, 0, 0, 39, '2072'),
	(377, 1, 0, -50331, 2074, 0, 0, 39, '2073'),
	(377, 1, 0, -50331, 2075, 0, 0, 39, '2074'),
	(377, 1, 0, -50331, 2076, 0, 0, 39, '2075'),
	(377, 1, 0, -50331, 2077, 0, 0, 39, '2076'),
	(377, 1, 0, -50331, 2078, 0, 0, 39, '2077'),
	(377, 1, 0, -50331, 2079, 0, 0, 39, '2078'),
	(377, 1, 0, -50331, 2080, 0, 0, 39, '2079'),
	(377, 1, 0, -50331, 2081, 0, 0, 39, '2080'),
	(377, 1, 0, -50331, 2082, 0, 0, 39, '2081'),
	(377, 1, 0, -50331, 2083, 0, 0, 39, '2082'),
	(377, 1, 0, -50331, 2084, 0, 0, 39, '2083'),
	(377, 1, 0, -50331, 2085, 0, 0, 39, '2084'),
	(377, 1, 0, -50331, 2086, 0, 0, 39, '2085'),
	(377, 1, 0, -50331, 2087, 0, 0, 39, '2086'),
	(377, 1, 0, -50331, 2088, 0, 0, 39, '2087'),
	(377, 1, 0, -50331, 2089, 0, 0, 39, '2088'),
	(377, 1, 0, -50331, 2090, 0, 0, 39, '2089'),
	(377, 1, 0, -50331, 2091, 0, 0, 39, '2090'),
	(377, 1, 0, -50331, 2092, 0, 0, 39, '2091'),
	(377, 1, 0, -50331, 2093, 0, 0, 39, '2092'),
	(377, 1, 0, -50331, 2094, 0, 0, 39, '2093'),
	(377, 1, 0, -50331, 2095, 0, 0, 39, '2094'),
	(377, 1, 0, -50331, 2096, 0, 0, 39, '2095'),
	(377, 1, 0, -50331, 2097, 0, 0, 39, '2096'),
	(377, 1, 0, -50331, 2098, 0, 0, 39, '2097'),
	(377, 1, 0, -50331, 2099, 0, 0, 39, '2098'),
	(377, 1, 0, -50331, 2100, 0, 0, 39, '2099'),
	(377, 1, 0, -50331, 2101, 0, 0, 39, '2100'),
	(377, 1, 0, -50331, 2102, 0, 0, 39, '2101'),
	(377, 1, 0, -50331, 2103, 0, 0, 39, '2102'),
	(377, 1, 0, -50331, 2104, 0, 0, 39, '2103'),
	(377, 1, 0, -50331, 2105, 0, 0, 39, '2104'),
	(377, 1, 0, -50331, 2106, 0, 0, 39, '2105'),
	(377, 1, 0, -50331, 2107, 0, 0, 39, '2106'),
	(377, 1, 0, -50331, 2108, 0, 0, 39, '2107'),
	(377, 1, 0, -50331, 2109, 0, 0, 39, '2108'),
	(377, 1, 0, -50331, 2110, 0, 0, 39, '2109'),
	(377, 1, 0, -50331, 2111, 0, 0, 39, '2110'),
	(377, 1, 0, -50331, 2112, 0, 0, 39, '2111'),
	(377, 1, 0, -50331, 2113, 0, 0, 39, '2112'),
	(377, 1, 0, -50331, 2114, 0, 0, 39, '2113'),
	(377, 1, 0, -50331, 2115, 0, 0, 39, '2114'),
	(377, 1, 0, -50331, 2116, 0, 0, 39, '2115'),
	(377, 1, 0, -50331, 2117, 0, 0, 39, '2116'),
	(377, 1, 0, -50331, 2118, 0, 0, 39, '2117'),
	(377, 1, 0, -50331, 2119, 0, 0, 39, '2118'),
	(377, 1, 0, -50331, 2120, 0, 0, 39, '2119'),
	(377, 1, 0, -50331, 2121, 0, 0, 39, '2120'),
	(377, 1, 0, -50331, 2122, 0, 0, 39, '2121'),
	(377, 1, 0, -50331, 2123, 0, 0, 39, '2122'),
	(377, 1, 0, -50331, 2124, 0, 0, 39, '2123'),
	(377, 1, 0, -50331, 2125, 0, 0, 39, '2124'),
	(377, 1, 0, -50331, 2126, 0, 0, 39, '2125'),
	(377, 1, 0, -50331, 2127, 0, 0, 39, '2126'),
	(377, 1, 0, -50331, 2128, 0, 0, 39, '2127'),
	(377, 1, 0, -50331, 2129, 0, 0, 39, '2128'),
	(377, 1, 0, -50331, 2130, 0, 0, 39, '2129'),
	(377, 1, 0, -50331, 2131, 0, 0, 39, '2130'),
	(377, 1, 0, -50331, 2132, 0, 0, 39, '2131'),
	(377, 1, 0, -50331, 2133, 0, 0, 39, '2132'),
	(377, 1, 0, -50331, 2134, 0, 0, 39, '2133'),
	(377, 1, 0, -50331, 2135, 0, 0, 39, '2134'),
	(377, 1, 0, -50331, 2136, 0, 0, 39, '2135'),
	(377, 1, 0, -50331, 2137, 0, 0, 39, '2136'),
	(377, 1, 0, -50331, 2138, 0, 0, 39, '2137'),
	(377, 1, 0, -50331, 2139, 0, 0, 39, '2138'),
	(377, 1, 0, -50331, 2140, 0, 0, 39, '2139'),
	(377, 1, 0, -50331, 2141, 0, 0, 39, '2140'),
	(377, 1, 0, -50331, 2142, 0, 0, 39, '2141'),
	(377, 1, 0, -50331, 2143, 0, 0, 39, '2142'),
	(377, 1, 0, -50331, 2144, 0, 0, 39, '2143'),
	(377, 1, 0, -50331, 2145, 0, 0, 39, '2144'),
	(377, 1, 0, -50331, 2146, 0, 0, 39, '2145'),
	(377, 1, 0, -50331, 2147, 0, 0, 39, '2146'),
	(377, 1, 0, -50331, 2148, 0, 0, 39, '2147'),
	(377, 1, 0, -50331, 2149, 0, 0, 39, '2148'),
	(377, 1, 0, -50331, 2150, 0, 0, 39, '2149'),
	(377, 1, 0, -50331, 2151, 0, 0, 39, '2150'),
	(377, 1, 0, -50331, 2152, 0, 0, 39, '2151'),
	(377, 1, 0, -50331, 2153, 0, 0, 39, '2152'),
	(377, 1, 0, -50331, 2154, 0, 0, 39, '2153'),
	(377, 1, 0, -50331, 2155, 0, 0, 39, '2154'),
	(377, 1, 0, -50331, 2156, 0, 0, 39, '2155'),
	(377, 1, 0, -50331, 2157, 0, 0, 39, '2156'),
	(377, 1, 0, -50331, 2158, 0, 0, 39, '2157'),
	(377, 1, 0, -50331, 2159, 0, 0, 39, '2158'),
	(377, 1, 0, -50331, 2160, 0, 0, 39, '2159'),
	(377, 1, 0, -50331, 2161, 0, 0, 39, '2160'),
	(377, 1, 0, -50331, 2162, 0, 0, 39, '2161'),
	(377, 1, 0, -50331, 2163, 0, 0, 39, '2162'),
	(377, 1, 0, -50331, 2164, 0, 0, 39, '2163'),
	(377, 1, 0, -50331, 2165, 0, 0, 39, '2164'),
	(377, 1, 0, -50331, 2166, 0, 0, 39, '2165'),
	(377, 1, 0, -50331, 2167, 0, 0, 39, '2166'),
	(377, 1, 0, -50331, 2168, 0, 0, 39, '2167'),
	(377, 1, 0, -50331, 2169, 0, 0, 39, '2168'),
	(377, 1, 0, -50331, 2170, 0, 0, 39, '2169'),
	(377, 1, 0, -50331, 2171, 0, 0, 39, '2170'),
	(377, 1, 0, -50331, 2172, 0, 0, 39, '2171'),
	(377, 1, 0, -50331, 2173, 0, 0, 39, '2172'),
	(377, 1, 0, -50331, 2174, 0, 0, 39, '2173'),
	(377, 1, 0, -50331, 2175, 0, 0, 39, '2174'),
	(377, 1, 0, -50331, 2176, 0, 0, 39, '2175'),
	(377, 1, 0, -50331, 2177, 0, 0, 39, '2176'),
	(377, 1, 0, -50331, 2178, 0, 0, 39, '2177'),
	(377, 1, 0, -50331, 2179, 0, 0, 39, '2178'),
	(377, 1, 0, -50331, 2180, 0, 0, 39, '2179'),
	(377, 1, 0, -50331, 2181, 0, 0, 39, '2180'),
	(377, 1, 0, -50331, 2182, 0, 0, 39, '2181'),
	(377, 1, 0, -50331, 2183, 0, 0, 39, '2182'),
	(377, 1, 0, -50331, 2184, 0, 0, 39, '2183'),
	(377, 1, 0, -50331, 2185, 0, 0, 39, '2184'),
	(377, 1, 0, -50331, 2186, 0, 0, 39, '2185'),
	(377, 1, 0, -50331, 2187, 0, 0, 39, '2186'),
	(377, 1, 0, -50331, 2188, 0, 0, 39, '2187'),
	(377, 1, 0, -50331, 2189, 0, 0, 39, '2188'),
	(377, 1, 0, -50331, 2190, 0, 0, 39, '2189'),
	(377, 1, 0, -50331, 2191, 0, 0, 39, '2190'),
	(377, 1, 0, -50331, 2192, 0, 0, 39, '2191'),
	(377, 1, 0, -50331, 2193, 0, 0, 39, '2192'),
	(377, 1, 0, -50331, 2194, 0, 0, 39, '2193'),
	(377, 1, 0, -50331, 2195, 0, 0, 39, '2194'),
	(377, 1, 0, -50331, 2196, 0, 0, 39, '2195'),
	(377, 1, 0, -50331, 2197, 0, 0, 39, '2196'),
	(377, 1, 0, -50331, 2198, 0, 0, 39, '2197'),
	(377, 1, 0, -50331, 2199, 0, 0, 39, '2198'),
	(377, 1, 0, -50331, 2200, 0, 0, 39, '2199'),
	(377, 1, 0, -50331, 2201, 0, 0, 39, '2200'),
	(377, 1, 0, -50331, 2202, 0, 0, 39, '2201'),
	(377, 1, 0, -50331, 2203, 0, 0, 39, '2202'),
	(377, 1, 0, -50331, 2204, 0, 0, 39, '2203'),
	(377, 1, 0, -50331, 2205, 0, 0, 39, '2204'),
	(377, 1, 0, -50331, 2206, 0, 0, 39, '2205'),
	(377, 1, 0, -50331, 2207, 0, 0, 39, '2206'),
	(377, 1, 0, -50331, 2208, 0, 0, 39, '2207'),
	(377, 1, 0, -50331, 2209, 0, 0, 39, '2208'),
	(377, 1, 0, -50331, 2210, 0, 0, 39, '2209'),
	(377, 1, 0, -50331, 2211, 0, 0, 39, '2210'),
	(377, 1, 0, -50331, 2212, 0, 0, 39, '2211'),
	(377, 1, 0, -50331, 2213, 0, 0, 39, '2212'),
	(377, 1, 0, -50331, 2214, 0, 0, 39, '2213'),
	(377, 1, 0, -50331, 2215, 0, 0, 39, '2214'),
	(377, 1, 0, -50331, 2216, 0, 0, 39, '2215'),
	(377, 1, 0, -50331, 2217, 0, 0, 39, '2216'),
	(377, 1, 0, -50331, 2218, 0, 0, 39, '2217'),
	(377, 1, 0, -50331, 2219, 0, 0, 39, '2218'),
	(377, 1, 0, -50331, 2220, 0, 0, 39, '2219'),
	(377, 1, 0, -50331, 2221, 0, 0, 39, '2220'),
	(377, 1, 0, -50331, 2222, 0, 0, 39, '2221'),
	(377, 1, 0, -50331, 2223, 0, 0, 39, '2222'),
	(377, 1, 0, -50331, 2224, 0, 0, 39, '2223'),
	(377, 1, 0, -50331, 2225, 0, 0, 39, '2224'),
	(377, 1, 0, -50331, 2226, 0, 0, 39, '2225'),
	(377, 1, 0, -50331, 2227, 0, 0, 39, '2226'),
	(377, 1, 0, -50331, 2228, 0, 0, 39, '2227'),
	(377, 1, 0, -50331, 2229, 0, 0, 39, '2228'),
	(377, 1, 0, -50331, 2230, 0, 0, 39, '2229'),
	(377, 1, 0, -50331, 2231, 0, 0, 39, '2230'),
	(377, 1, 0, -50331, 2232, 0, 0, 39, '2231'),
	(377, 1, 0, -50331, 2233, 0, 0, 39, '2232'),
	(377, 1, 0, -50331, 2234, 0, 0, 39, '2233'),
	(377, 1, 0, -50331, 2235, 0, 0, 39, '2234'),
	(377, 1, 0, -50331, 2236, 0, 0, 39, '2235'),
	(377, 1, 0, -50331, 2237, 0, 0, 39, '2236'),
	(377, 1, 0, -50331, 2238, 0, 0, 39, '2237'),
	(377, 1, 0, -50331, 2239, 0, 0, 39, '2238'),
	(377, 1, 0, -50331, 2240, 0, 0, 39, '2239'),
	(377, 1, 0, -50331, 2241, 0, 0, 39, '2240'),
	(377, 1, 0, -50331, 2242, 0, 0, 39, '2241'),
	(377, 1, 0, -50331, 2243, 0, 0, 39, '2242'),
	(377, 1, 0, -50331, 2244, 0, 0, 39, '2243'),
	(377, 1, 0, -50331, 2245, 0, 0, 39, '2244'),
	(377, 1, 0, -50331, 2246, 0, 0, 39, '2245'),
	(377, 1, 0, -50331, 2247, 0, 0, 39, '2246'),
	(377, 1, 0, -50331, 2248, 0, 0, 39, '2247'),
	(377, 1, 0, -50331, 2249, 0, 0, 39, '2248'),
	(377, 1, 0, -50331, 2250, 0, 0, 39, '2249'),
	(377, 1, 0, -50331, 2251, 0, 0, 39, '2250'),
	(377, 1, 0, -50331, 2252, 0, 0, 39, '2251'),
	(377, 1, 0, -50331, 2253, 0, 0, 39, '2252'),
	(377, 1, 0, -50331, 2254, 0, 0, 39, '2253'),
	(377, 1, 0, -50331, 2255, 0, 0, 39, '2254'),
	(377, 1, 0, -50331, 2256, 0, 0, 39, '2255'),
	(377, 1, 0, -50331, 2257, 0, 0, 39, '2256'),
	(377, 1, 0, -50331, 2258, 0, 0, 39, '2257'),
	(377, 1, 0, -50331, 2259, 0, 0, 39, '2258'),
	(377, 1, 0, -50331, 2260, 0, 0, 39, '2259'),
	(377, 1, 0, -50331, 2261, 0, 0, 39, '2260'),
	(377, 1, 0, -50331, 2262, 0, 0, 39, '2261'),
	(377, 1, 0, -50331, 2263, 0, 0, 39, '2262'),
	(377, 1, 0, -50331, 2264, 0, 0, 39, '2263'),
	(377, 1, 0, -50331, 2265, 0, 0, 39, '2264'),
	(377, 1, 0, -50331, 2266, 0, 0, 39, '2265'),
	(377, 1, 0, -50331, 2267, 0, 0, 39, '2266'),
	(377, 1, 0, -50331, 2268, 0, 0, 39, '2267'),
	(377, 1, 0, -50331, 2269, 0, 0, 39, '2268'),
	(377, 1, 0, -50331, 2270, 0, 0, 39, '2269'),
	(377, 1, 0, -50331, 2271, 0, 0, 39, '2270'),
	(377, 1, 0, -50331, 2272, 0, 0, 39, '2271'),
	(377, 1, 0, -50331, 2273, 0, 0, 39, '2272'),
	(377, 1, 0, -50331, 2274, 0, 0, 39, '2273'),
	(377, 1, 0, -50331, 2275, 0, 0, 39, '2274'),
	(377, 1, 0, -50331, 2276, 0, 0, 39, '2275'),
	(377, 1, 0, -50331, 2277, 0, 0, 39, '2276'),
	(377, 1, 0, -50331, 2278, 0, 0, 39, '2277'),
	(377, 1, 0, -50331, 2279, 0, 0, 39, '2278'),
	(377, 1, 0, -50331, 2280, 0, 0, 39, '2279'),
	(377, 1, 0, -50331, 2281, 0, 0, 39, '2280'),
	(377, 1, 0, -50331, 2282, 0, 0, 39, '2281'),
	(377, 1, 0, -50331, 2283, 0, 0, 39, '2282'),
	(377, 1, 0, -50331, 2284, 0, 0, 39, '2283'),
	(377, 1, 0, -50331, 2285, 0, 0, 39, '2284'),
	(377, 1, 0, -50331, 2286, 0, 0, 39, '2285'),
	(377, 1, 0, -50331, 2287, 0, 0, 39, '2286'),
	(377, 1, 0, -50331, 2288, 0, 0, 39, '2287'),
	(377, 1, 0, -50331, 2289, 0, 0, 39, '2288'),
	(377, 1, 0, -50331, 2290, 0, 0, 39, '2289'),
	(377, 1, 0, -50331, 2291, 0, 0, 39, '2290'),
	(377, 1, 0, -50331, 2292, 0, 0, 39, '2291'),
	(377, 1, 0, -50331, 2293, 0, 0, 39, '2292'),
	(377, 1, 0, -50331, 2294, 0, 0, 39, '2293'),
	(377, 1, 0, -50331, 2295, 0, 0, 39, '2294'),
	(377, 1, 0, -50331, 2296, 0, 0, 39, '2295'),
	(377, 1, 0, -50331, 2297, 0, 0, 39, '2296'),
	(377, 1, 0, -50331, 2298, 0, 0, 39, '2297'),
	(377, 1, 0, -50331, 2299, 0, 0, 39, '2298'),
	(377, 1, 0, -50331, 2300, 0, 0, 39, '2299'),
	(377, 1, 0, -50331, 2301, 0, 0, 39, '2300'),
	(377, 1, 0, -50331, 2302, 0, 0, 39, '2301'),
	(377, 1, 0, -50331, 2303, 0, 0, 39, '2302'),
	(377, 1, 0, -50331, 2304, 0, 0, 39, '2303'),
	(377, 1, 0, -50331, 2305, 0, 0, 39, '2304'),
	(377, 1, 0, -50331, 2306, 0, 0, 39, '2305'),
	(377, 1, 0, -50331, 2307, 0, 0, 39, '2306'),
	(377, 1, 0, -50331, 2308, 0, 0, 39, '2307'),
	(377, 1, 0, -50331, 2309, 0, 0, 39, '2308'),
	(377, 1, 0, -50331, 2310, 0, 0, 39, '2309'),
	(377, 1, 0, -50331, 2311, 0, 0, 39, '2310'),
	(377, 1, 0, -50331, 2312, 0, 0, 39, '2311'),
	(377, 1, 0, -50331, 2313, 0, 0, 39, '2312'),
	(377, 1, 0, -50331, 2314, 0, 0, 39, '2313'),
	(377, 1, 0, -50331, 2315, 0, 0, 39, '2314'),
	(377, 1, 0, -50331, 2316, 0, 0, 39, '2315'),
	(377, 1, 0, -50331, 2317, 0, 0, 39, '2316'),
	(377, 1, 0, -50331, 2318, 0, 0, 39, '2317'),
	(377, 1, 0, -50331, 2319, 0, 0, 39, '2318'),
	(377, 1, 0, -50331, 2320, 0, 0, 39, '2319'),
	(377, 1, 0, -50331, 2321, 0, 0, 39, '2320'),
	(377, 1, 0, -50331, 2322, 0, 0, 39, '2321'),
	(377, 1, 0, -50331, 2323, 0, 0, 39, '2322'),
	(377, 1, 0, -50331, 2324, 0, 0, 39, '2323'),
	(377, 1, 0, -50331, 2325, 0, 0, 39, '2324'),
	(377, 1, 0, -50331, 2326, 0, 0, 39, '2325'),
	(377, 1, 0, -50331, 2327, 0, 0, 39, '2326'),
	(377, 1, 0, -50331, 2328, 0, 0, 39, '2327'),
	(377, 1, 0, -50331, 2329, 0, 0, 39, '2328'),
	(377, 1, 0, -50331, 2330, 0, 0, 39, '2329'),
	(377, 1, 0, -50331, 2331, 0, 0, 39, '2330'),
	(377, 1, 0, -50331, 2332, 0, 0, 39, '2331'),
	(377, 1, 0, -50331, 2333, 0, 0, 39, '2332'),
	(377, 1, 0, -50331, 2334, 0, 0, 39, '2333'),
	(377, 1, 0, -50331, 2335, 0, 0, 39, '2334'),
	(377, 1, 0, -50331, 2336, 0, 0, 39, '2335'),
	(377, 1, 0, -50331, 2337, 0, 0, 39, '2336'),
	(377, 1, 0, -50331, 2338, 0, 0, 39, '2337'),
	(377, 1, 0, -50331, 2339, 0, 0, 39, '2338'),
	(377, 1, 0, -50331, 2340, 0, 0, 39, '2339'),
	(377, 1, 0, -50331, 2341, 0, 0, 39, '2340'),
	(377, 1, 0, -50331, 2342, 0, 0, 39, '2341'),
	(377, 1, 0, -50331, 2343, 0, 0, 39, '2342'),
	(377, 1, 0, -50331, 2344, 0, 0, 39, '2343'),
	(377, 1, 0, -50331, 2345, 0, 0, 39, '2344'),
	(377, 1, 0, -50331, 2346, 0, 0, 39, '2345'),
	(377, 1, 0, -50331, 2347, 0, 0, 39, '2346'),
	(377, 1, 0, -50331, 2348, 0, 0, 39, '2347'),
	(377, 1, 0, -50331, 2349, 0, 0, 39, '2348'),
	(377, 1, 0, -50331, 2350, 0, 0, 39, '2349'),
	(377, 1, 0, -50331, 2351, 0, 0, 39, '2350'),
	(377, 1, 0, -50331, 2352, 0, 0, 39, '2351'),
	(377, 1, 0, -50331, 2353, 0, 0, 39, '2352'),
	(377, 1, 0, -50331, 2354, 0, 0, 39, '2353'),
	(377, 1, 0, -50331, 2355, 0, 0, 39, '2354'),
	(377, 1, 0, -50331, 2356, 0, 0, 39, '2355'),
	(377, 1, 0, -50331, 2357, 0, 0, 39, '2356'),
	(377, 1, 0, -50331, 2358, 0, 0, 39, '2357'),
	(377, 1, 0, -50331, 2359, 0, 0, 39, '2358'),
	(377, 1, 0, -50331, 2360, 0, 0, 39, '2359'),
	(377, 1, 0, -50331, 2361, 0, 0, 39, '2360'),
	(377, 1, 0, -50331, 2362, 0, 0, 39, '2361'),
	(377, 1, 0, -50331, 2363, 0, 0, 39, '2362'),
	(377, 1, 0, -50331, 2364, 0, 0, 39, '2363'),
	(377, 1, 0, -50331, 2365, 0, 0, 39, '2364'),
	(377, 1, 0, -50331, 2366, 0, 0, 39, '2365'),
	(377, 1, 0, -50331, 2367, 0, 0, 39, '2366'),
	(377, 1, 0, -50331, 2368, 0, 0, 39, '2367'),
	(377, 1, 0, -50331, 2369, 0, 0, 39, '2368'),
	(377, 1, 0, -50331, 2370, 0, 0, 39, '2369'),
	(377, 1, 0, -50331, 2371, 0, 0, 39, '2370'),
	(377, 1, 0, -50331, 2372, 0, 0, 39, '2371'),
	(377, 1, 0, -50331, 2373, 0, 0, 39, '2372'),
	(377, 1, 0, -50331, 2374, 0, 0, 39, '2373'),
	(377, 1, 0, -50331, 2375, 0, 0, 39, '2374'),
	(377, 1, 0, -50331, 2376, 0, 0, 39, '2375'),
	(377, 1, 0, -50331, 2377, 0, 0, 39, '2376'),
	(377, 1, 0, -50331, 2378, 0, 0, 39, '2377'),
	(377, 1, 0, -50331, 2379, 0, 0, 39, '2378'),
	(377, 1, 0, -50331, 2380, 0, 0, 39, '2379'),
	(377, 1, 0, -50331, 2381, 0, 0, 39, '2380'),
	(377, 1, 0, -50331, 2382, 0, 0, 39, '2381'),
	(377, 1, 0, -50331, 2383, 0, 0, 39, '2382'),
	(377, 1, 0, -50331, 2384, 0, 0, 39, '2383'),
	(377, 1, 0, -50331, 2385, 0, 0, 39, '2384'),
	(377, 1, 0, -50331, 2386, 0, 0, 39, '2385'),
	(377, 1, 0, -50331, 2387, 0, 0, 39, '2386'),
	(377, 1, 0, -50331, 2388, 0, 0, 39, '2387'),
	(377, 1, 0, -50331, 2389, 0, 0, 39, '2388'),
	(377, 1, 0, -50331, 2390, 0, 0, 39, '2389'),
	(377, 1, 0, -50331, 2391, 0, 0, 39, '2390'),
	(377, 1, 0, -50331, 2392, 0, 0, 39, '2391'),
	(377, 1, 0, -50331, 2393, 0, 0, 39, '2392'),
	(377, 1, 0, -50331, 2394, 0, 0, 39, '2393'),
	(377, 1, 0, -50331, 2395, 0, 0, 39, '2394'),
	(377, 1, 0, -50331, 2396, 0, 0, 39, '2395'),
	(377, 1, 0, -50331, 2397, 0, 0, 39, '2396'),
	(377, 1, 0, -50331, 2398, 0, 0, 39, '2397'),
	(377, 1, 0, -50331, 2399, 0, 0, 39, '2398'),
	(377, 1, 0, -50331, 2400, 0, 0, 39, '2399'),
	(377, 1, 0, -50331, 2401, 0, 0, 39, '2400'),
	(377, 1, 0, -50331, 2402, 0, 0, 39, '2401'),
	(377, 1, 0, -50331, 2403, 0, 0, 39, '2402'),
	(377, 1, 0, -50331, 2404, 0, 0, 39, '2403'),
	(377, 1, 0, -50331, 2405, 0, 0, 39, '2404'),
	(377, 1, 0, -50331, 2406, 0, 0, 39, '2405'),
	(377, 1, 0, -50331, 2407, 0, 0, 39, '2406'),
	(377, 1, 0, -50331, 2408, 0, 0, 39, '2407'),
	(377, 1, 0, -50331, 2409, 0, 0, 39, '2408'),
	(377, 1, 0, -50331, 2410, 0, 0, 39, '2409'),
	(377, 1, 0, -50331, 2411, 0, 0, 39, '2410'),
	(377, 1, 0, -50331, 2412, 0, 0, 39, '2411'),
	(377, 1, 0, -50331, 2413, 0, 0, 39, '2412'),
	(377, 1, 0, -50331, 2414, 0, 0, 39, '2413'),
	(377, 1, 0, -50331, 2415, 0, 0, 39, '2414'),
	(377, 1, 0, -50331, 2416, 0, 0, 39, '2415'),
	(377, 1, 0, -50331, 2417, 0, 0, 39, '2416'),
	(377, 1, 0, -50331, 2418, 0, 0, 39, '2417'),
	(377, 1, 0, -50331, 2419, 0, 0, 39, '2418'),
	(377, 1, 0, -50331, 2420, 0, 0, 39, '2419'),
	(377, 1, 0, -50331, 2421, 0, 0, 39, '2420'),
	(377, 1, 0, -50331, 2422, 0, 0, 39, '2421'),
	(377, 1, 0, -50331, 2423, 0, 0, 39, '2422'),
	(377, 1, 0, -50331, 2424, 0, 0, 39, '2423'),
	(377, 1, 0, -50331, 2425, 0, 0, 39, '2424'),
	(377, 1, 0, -50331, 2426, 0, 0, 39, '2425'),
	(377, 1, 0, -50331, 2427, 0, 0, 39, '2426'),
	(377, 1, 0, -50331, 2428, 0, 0, 39, '2427'),
	(377, 1, 0, -50331, 2429, 0, 0, 39, '2428'),
	(377, 1, 0, -50331, 2430, 0, 0, 39, '2429'),
	(377, 1, 0, -50331, 2431, 0, 0, 39, '2430'),
	(377, 1, 0, -50331, 2432, 0, 0, 39, '2431'),
	(377, 1, 0, -50331, 2433, 0, 0, 39, '2432'),
	(377, 1, 0, -50331, 2434, 0, 0, 39, '2433'),
	(377, 1, 0, -50331, 2435, 0, 0, 39, '2434'),
	(377, 1, 0, -50331, 2436, 0, 0, 39, '2435'),
	(377, 1, 0, -50331, 2437, 0, 0, 39, '2436'),
	(377, 1, 0, -50331, 2438, 0, 0, 39, '2437'),
	(377, 1, 0, -50331, 2439, 0, 0, 39, '2438'),
	(377, 1, 0, -50331, 2440, 0, 0, 39, '2439'),
	(377, 1, 0, -50331, 2441, 0, 0, 39, '2440'),
	(377, 1, 0, -50331, 2442, 0, 0, 39, '2441'),
	(377, 1, 0, -50331, 2443, 0, 0, 39, '2442'),
	(377, 1, 0, -50331, 2444, 0, 0, 39, '2443'),
	(377, 1, 0, -50331, 2445, 0, 0, 39, '2444'),
	(377, 1, 0, -50331, 2446, 0, 0, 39, '2445'),
	(377, 1, 0, -50331, 2447, 0, 0, 39, '2446'),
	(377, 1, 0, -50331, 2448, 0, 0, 39, '2447'),
	(377, 1, 0, -50331, 2449, 0, 0, 39, '2448'),
	(377, 1, 0, -50331, 2450, 0, 0, 39, '2449'),
	(377, 1, 0, -50331, 2451, 0, 0, 39, '2450'),
	(377, 1, 0, -50331, 2452, 0, 0, 39, '2451'),
	(377, 1, 0, -50331, 2453, 0, 0, 39, '2452'),
	(377, 1, 0, -50331, 2454, 0, 0, 39, '2453'),
	(377, 1, 0, -50331, 2455, 0, 0, 39, '2454'),
	(377, 1, 0, -50331, 2456, 0, 0, 39, '2455'),
	(377, 1, 0, -50331, 2457, 0, 0, 39, '2456'),
	(377, 1, 0, -50331, 2458, 0, 0, 39, '2457'),
	(377, 1, 0, -50331, 2459, 0, 0, 39, '2458'),
	(377, 1, 0, -50331, 2460, 0, 0, 39, '2459'),
	(377, 1, 0, -50331, 2461, 0, 0, 39, '2460'),
	(377, 1, 0, -50331, 2462, 0, 0, 39, '2461'),
	(377, 1, 0, -50331, 2463, 0, 0, 39, '2462'),
	(377, 1, 0, -50331, 2464, 0, 0, 39, '2463'),
	(377, 1, 0, -50331, 2465, 0, 0, 39, '2464'),
	(377, 1, 0, -50331, 2466, 0, 0, 39, '2465'),
	(377, 1, 0, -50331, 2467, 0, 0, 39, '2466'),
	(377, 1, 0, -50331, 2468, 0, 0, 39, '2467'),
	(377, 1, 0, -50331, 2469, 0, 0, 39, '2468'),
	(377, 1, 0, -50331, 2470, 0, 0, 39, '2469'),
	(377, 1, 0, -50331, 2471, 0, 0, 39, '2470'),
	(377, 1, 0, -50331, 2472, 0, 0, 39, '2471'),
	(377, 1, 0, -50331, 2473, 0, 0, 39, '2472'),
	(377, 1, 0, -50331, 2474, 0, 0, 39, '2473'),
	(377, 1, 0, -50331, 2475, 0, 0, 39, '2474'),
	(377, 1, 0, -50331, 2476, 0, 0, 39, '2475'),
	(377, 1, 0, -50331, 2477, 0, 0, 39, '2476'),
	(377, 1, 0, -50331, 2478, 0, 0, 39, '2477'),
	(377, 1, 0, -50331, 2479, 0, 0, 39, '2478'),
	(377, 1, 0, -50331, 2480, 0, 0, 39, '2479'),
	(377, 1, 0, -50331, 2481, 0, 0, 39, '2480'),
	(377, 1, 0, -50331, 2482, 0, 0, 39, '2481'),
	(377, 1, 0, -50331, 2483, 0, 0, 39, '2482'),
	(377, 1, 0, -50331, 2484, 0, 0, 39, '2483'),
	(377, 1, 0, -50331, 2485, 0, 0, 39, '2484'),
	(377, 1, 0, -50331, 2486, 0, 0, 39, '2485'),
	(377, 1, 0, -50331, 2487, 0, 0, 39, '2486'),
	(377, 1, 0, -50331, 2488, 0, 0, 39, '2487'),
	(377, 1, 0, -50331, 2489, 0, 0, 39, '2488'),
	(377, 1, 0, -50331, 2490, 0, 0, 39, '2489'),
	(377, 1, 0, -50331, 2491, 0, 0, 39, '2490'),
	(377, 1, 0, -50331, 2492, 0, 0, 39, '2491'),
	(377, 1, 0, -50331, 2493, 0, 0, 39, '2492'),
	(377, 1, 0, -50331, 2494, 0, 0, 39, '2493'),
	(377, 1, 0, -50331, 2495, 0, 0, 39, '2494'),
	(377, 1, 0, -50331, 2496, 0, 0, 39, '2495'),
	(377, 1, 0, -50331, 2497, 0, 0, 39, '2496'),
	(377, 1, 0, -50331, 2498, 0, 0, 39, '2497'),
	(377, 1, 0, -50331, 2499, 0, 0, 39, '2498'),
	(377, 1, 0, -50331, 2500, 0, 0, 39, '2499'),
	(377, 1, 0, -50331, 2501, 0, 0, 39, '2500'),
	(377, 1, 0, -50331, 2502, 0, 0, 39, '2501'),
	(377, 1, 0, -50331, 2503, 0, 0, 39, '2502'),
	(377, 1, 0, -50331, 2504, 0, 0, 39, '2503'),
	(377, 1, 0, -50331, 2505, 0, 0, 39, '2504'),
	(377, 1, 0, -50331, 2506, 0, 0, 39, '2505'),
	(377, 1, 0, -50331, 2507, 0, 0, 39, '2506'),
	(377, 1, 0, -50331, 2508, 0, 0, 39, '2507'),
	(377, 1, 0, -50331, 2509, 0, 0, 39, '2508'),
	(377, 1, 0, -50331, 2510, 0, 0, 39, '2509'),
	(377, 1, 0, -50331, 2511, 0, 0, 39, '2510'),
	(377, 1, 0, -50331, 2512, 0, 0, 39, '2511'),
	(377, 1, 0, -50331, 2513, 0, 0, 39, '2512'),
	(377, 1, 0, -50331, 2514, 0, 0, 39, '2513'),
	(377, 1, 0, -50331, 2515, 0, 0, 39, '2514'),
	(377, 1, 0, -50331, 2516, 0, 0, 39, '2515'),
	(377, 1, 0, -50331, 2517, 0, 0, 39, '2516'),
	(377, 1, 0, -50331, 2518, 0, 0, 39, '2517'),
	(377, 1, 0, -50331, 2519, 0, 0, 39, '2518'),
	(377, 1, 0, -50331, 2520, 0, 0, 39, '2519'),
	(377, 1, 0, -50331, 2521, 0, 0, 39, '2520'),
	(377, 1, 0, -50331, 2522, 0, 0, 39, '2521'),
	(377, 1, 0, -50331, 2523, 0, 0, 39, '2522'),
	(377, 1, 0, -50331, 2524, 0, 0, 39, '2523'),
	(377, 1, 0, -50331, 2525, 0, 0, 39, '2524'),
	(377, 1, 0, -50331, 2526, 0, 0, 39, '2525'),
	(377, 1, 0, -50331, 2527, 0, 0, 39, '2526'),
	(377, 1, 0, -50331, 2528, 0, 0, 39, '2527'),
	(377, 1, 0, -50331, 2529, 0, 0, 39, '2528'),
	(377, 1, 0, -50331, 2530, 0, 0, 39, '2529'),
	(377, 1, 0, -50331, 2531, 0, 0, 39, '2530'),
	(377, 1, 0, -50331, 2532, 0, 0, 39, '2531'),
	(377, 1, 0, -50331, 2533, 0, 0, 39, '2532'),
	(377, 1, 0, -50331, 2534, 0, 0, 39, '2533'),
	(377, 1, 0, -50331, 2535, 0, 0, 39, '2534'),
	(377, 1, 0, -50331, 2536, 0, 0, 39, '2535'),
	(377, 1, 0, -50331, 2537, 0, 0, 39, '2536'),
	(377, 1, 0, -50331, 2538, 0, 0, 39, '2537'),
	(377, 1, 0, -50331, 2539, 0, 0, 39, '2538'),
	(377, 1, 0, -50331, 2540, 0, 0, 39, '2539'),
	(377, 1, 0, -50331, 2541, 0, 0, 39, '2540'),
	(377, 1, 0, -50331, 2542, 0, 0, 39, '2541'),
	(377, 1, 0, -50331, 2543, 0, 0, 39, '2542'),
	(377, 1, 0, -50331, 2544, 0, 0, 39, '2543'),
	(377, 1, 0, -50331, 2545, 0, 0, 39, '2544'),
	(377, 1, 0, -50331, 2546, 0, 0, 39, '2545'),
	(377, 1, 0, -50331, 2547, 0, 0, 39, '2546'),
	(377, 1, 0, -50331, 2548, 0, 0, 39, '2547'),
	(377, 1, 0, -50331, 2549, 0, 0, 39, '2548'),
	(377, 1, 0, -50331, 2550, 0, 0, 39, '2549'),
	(377, 1, 0, -50331, 2551, 0, 0, 39, '2550'),
	(377, 1, 0, -50331, 2552, 0, 0, 39, '2551'),
	(377, 1, 0, -50331, 2553, 0, 0, 39, '2552'),
	(377, 1, 0, -50331, 2554, 0, 0, 39, '2553'),
	(377, 1, 0, -50331, 2555, 0, 0, 39, '2554'),
	(377, 1, 0, -50331, 2556, 0, 0, 39, '2555'),
	(377, 1, 0, -50331, 2557, 0, 0, 39, '2556'),
	(377, 1, 0, -50331, 2558, 0, 0, 39, '2557'),
	(377, 1, 0, -50331, 2559, 0, 0, 39, '2558'),
	(377, 1, 0, -50331, 2560, 0, 0, 39, '2559'),
	(377, 1, 0, -50331, 2561, 0, 0, 39, '2560'),
	(377, 1, 0, -50331, 2562, 0, 0, 39, '2561'),
	(377, 1, 0, -50331, 2563, 0, 0, 39, '2562'),
	(377, 1, 0, -50331, 2564, 0, 0, 39, '2563'),
	(377, 1, 0, -50331, 2565, 0, 0, 39, '2564'),
	(377, 1, 0, -50331, 2566, 0, 0, 39, '2565'),
	(377, 1, 0, -50331, 2567, 0, 0, 39, '2566'),
	(377, 1, 0, -50331, 2568, 0, 0, 39, '2567'),
	(377, 1, 0, -50331, 2569, 0, 0, 39, '2568'),
	(377, 1, 0, -50331, 2570, 0, 0, 39, '2569'),
	(377, 1, 0, -50331, 2571, 0, 0, 39, '2570'),
	(377, 1, 0, -50331, 2572, 0, 0, 39, '2571'),
	(377, 1, 0, -50331, 2573, 0, 0, 39, '2572'),
	(377, 1, 0, -50331, 2574, 0, 0, 39, '2573'),
	(377, 1, 0, -50331, 2575, 0, 0, 39, '2574'),
	(377, 1, 0, -50331, 2576, 0, 0, 39, '2575'),
	(377, 1, 0, -50331, 2577, 0, 0, 39, '2576'),
	(377, 1, 0, -50331, 2578, 0, 0, 39, '2577'),
	(377, 1, 0, -50331, 2579, 0, 0, 39, '2578'),
	(377, 1, 0, -50331, 2580, 0, 0, 39, '2579'),
	(377, 1, 0, -50331, 2581, 0, 0, 39, '2580'),
	(377, 1, 0, -50331, 2582, 0, 0, 39, '2581'),
	(377, 1, 0, -50331, 2583, 0, 0, 39, '2582'),
	(377, 1, 0, -50331, 2584, 0, 0, 39, '2583'),
	(377, 1, 0, -50331, 2585, 0, 0, 39, '2584'),
	(377, 1, 0, -50331, 2586, 0, 0, 39, '2585'),
	(377, 1, 0, -50331, 2587, 0, 0, 39, '2586'),
	(377, 1, 0, -50331, 2588, 0, 0, 39, '2587'),
	(377, 1, 0, -50331, 2589, 0, 0, 39, '2588'),
	(377, 1, 0, -50331, 2590, 0, 0, 39, '2589'),
	(377, 1, 0, -50331, 2591, 0, 0, 39, '2590'),
	(377, 1, 0, -50331, 2592, 0, 0, 39, '2591'),
	(377, 1, 0, -50331, 2593, 0, 0, 39, '2592'),
	(377, 1, 0, -50331, 2594, 0, 0, 39, '2593'),
	(377, 1, 0, -50331, 2595, 0, 0, 39, '2594'),
	(377, 1, 0, -50331, 2596, 0, 0, 39, '2595'),
	(377, 1, 0, -50331, 2597, 0, 0, 39, '2596'),
	(377, 1, 0, -50331, 2598, 0, 0, 39, '2597'),
	(377, 1, 0, -50331, 2599, 0, 0, 39, '2598'),
	(377, 1, 0, -50331, 2600, 0, 0, 39, '2599'),
	(377, 1, 0, -50331, 2601, 0, 0, 39, '2600'),
	(377, 1, 0, -50331, 2602, 0, 0, 39, '2601'),
	(377, 1, 0, -50331, 2603, 0, 0, 39, '2602'),
	(377, 1, 0, -50331, 2604, 0, 0, 39, '2603'),
	(377, 1, 0, -50331, 2605, 0, 0, 39, '2604'),
	(377, 1, 0, -50331, 2606, 0, 0, 39, '2605'),
	(377, 1, 0, -50331, 2607, 0, 0, 39, '2606'),
	(377, 1, 0, -50331, 2608, 0, 0, 39, '2607'),
	(377, 1, 0, -50331, 2609, 0, 0, 39, '2608'),
	(377, 1, 0, -50331, 2610, 0, 0, 39, '2609'),
	(377, 1, 0, -50331, 2611, 0, 0, 39, '2610'),
	(377, 1, 0, -50331, 2612, 0, 0, 39, '2611'),
	(377, 1, 0, -50331, 2613, 0, 0, 39, '2612'),
	(377, 1, 0, -50331, 2614, 0, 0, 39, '2613'),
	(377, 1, 0, -50331, 2615, 0, 0, 39, '2614'),
	(377, 1, 0, -50331, 2616, 0, 0, 39, '2615'),
	(377, 1, 0, -50331, 2617, 0, 0, 39, '2616'),
	(377, 1, 0, -50331, 2618, 0, 0, 39, '2617'),
	(377, 1, 0, -50331, 2619, 0, 0, 39, '2618'),
	(377, 1, 0, -50331, 2620, 0, 0, 39, '2619'),
	(377, 1, 0, -50331, 2621, 0, 0, 39, '2620'),
	(377, 1, 0, -50331, 2622, 0, 0, 39, '2621'),
	(377, 1, 0, -50331, 2623, 0, 0, 39, '2622'),
	(377, 1, 0, -50331, 2624, 0, 0, 39, '2623'),
	(377, 1, 0, -50331, 2625, 0, 0, 39, '2624'),
	(377, 1, 0, -50331, 2626, 0, 0, 39, '2625'),
	(377, 1, 0, -50331, 2627, 0, 0, 39, '2626'),
	(377, 1, 0, -50331, 2628, 0, 0, 39, '2627'),
	(377, 1, 0, -50331, 2629, 0, 0, 39, '2628'),
	(377, 1, 0, -50331, 2630, 0, 0, 39, '2629'),
	(377, 1, 0, -50331, 2631, 0, 0, 39, '2630'),
	(377, 1, 0, -50331, 2632, 0, 0, 39, '2631'),
	(377, 1, 0, -50331, 2633, 0, 0, 39, '2632'),
	(377, 1, 0, -50331, 2634, 0, 0, 39, '2633'),
	(377, 1, 0, -50331, 2635, 0, 0, 39, '2634'),
	(377, 1, 0, -50331, 2636, 0, 0, 39, '2635'),
	(377, 1, 0, -50331, 2637, 0, 0, 39, '2636'),
	(377, 1, 0, -50331, 2638, 0, 0, 39, '2637'),
	(377, 1, 0, -50331, 2639, 0, 0, 39, '2638'),
	(377, 1, 0, -50331, 2640, 0, 0, 39, '2639'),
	(377, 1, 0, -50331, 2641, 0, 0, 39, '2640'),
	(377, 1, 0, -50331, 2642, 0, 0, 39, '2641'),
	(377, 1, 0, -50331, 2643, 0, 0, 39, '2642'),
	(377, 1, 0, -50331, 2644, 0, 0, 39, '2643'),
	(377, 1, 0, -50331, 2645, 0, 0, 39, '2644'),
	(377, 1, 0, -50331, 2646, 0, 0, 39, '2645'),
	(377, 1, 0, -50331, 2647, 0, 0, 39, '2646'),
	(377, 1, 0, -50331, 2648, 0, 0, 39, '2647'),
	(377, 1, 0, -50331, 2649, 0, 0, 39, '2648'),
	(377, 1, 0, -50331, 2650, 0, 0, 39, '2649'),
	(377, 1, 0, -50331, 2651, 0, 0, 39, '2650'),
	(377, 1, 0, -50331, 2652, 0, 0, 39, '2651'),
	(377, 1, 0, -50331, 2653, 0, 0, 39, '2652'),
	(377, 1, 0, -50331, 2654, 0, 0, 39, '2653'),
	(377, 1, 0, -50331, 2655, 0, 0, 39, '2654'),
	(377, 1, 0, -50331, 2656, 0, 0, 39, '2655'),
	(377, 1, 0, -50331, 2657, 0, 0, 39, '2656'),
	(377, 1, 0, -50331, 2658, 0, 0, 39, '2657'),
	(377, 1, 0, -50331, 2659, 0, 0, 39, '2658'),
	(377, 1, 0, -50331, 2660, 0, 0, 39, '2659'),
	(377, 1, 0, -50331, 2661, 0, 0, 39, '2660'),
	(377, 1, 0, -50331, 2662, 0, 0, 39, '2661'),
	(377, 1, 0, -50331, 2663, 0, 0, 39, '2662'),
	(377, 1, 0, -50331, 2664, 0, 0, 39, '2663'),
	(377, 1, 0, -50331, 2665, 0, 0, 39, '2664'),
	(377, 1, 0, -50331, 2666, 0, 0, 39, '2665'),
	(377, 1, 0, -50331, 2667, 0, 0, 39, '2666'),
	(377, 1, 0, -50331, 2668, 0, 0, 39, '2667'),
	(377, 1, 0, -50331, 2669, 0, 0, 39, '2668'),
	(377, 1, 0, -50331, 2670, 0, 0, 39, '2669'),
	(377, 1, 0, -50331, 2671, 0, 0, 39, '2670'),
	(377, 1, 0, -50331, 2672, 0, 0, 39, '2671'),
	(377, 1, 0, -50331, 2673, 0, 0, 39, '2672'),
	(377, 1, 0, -50331, 2674, 0, 0, 39, '2673'),
	(377, 1, 0, -50331, 2675, 0, 0, 39, '2674'),
	(377, 1, 0, -50331, 2676, 0, 0, 39, '2675'),
	(377, 1, 0, -50331, 2677, 0, 0, 39, '2676'),
	(377, 1, 0, -50331, 2678, 0, 0, 39, '2677'),
	(377, 1, 0, -50331, 2679, 0, 0, 39, '2678'),
	(377, 1, 0, -50331, 2680, 0, 0, 39, '2679'),
	(377, 1, 0, -50331, 2681, 0, 0, 39, '2680'),
	(377, 1, 0, -50331, 2682, 0, 0, 39, '2681'),
	(377, 1, 0, -50331, 2683, 0, 0, 39, '2682'),
	(377, 1, 0, -50331, 2684, 0, 0, 39, '2683'),
	(377, 1, 0, -50331, 2685, 0, 0, 39, '2684'),
	(377, 1, 0, -50331, 2686, 0, 0, 39, '2685'),
	(377, 1, 0, -50331, 2687, 0, 0, 39, '2686'),
	(377, 1, 0, -50331, 2688, 0, 0, 39, '2687'),
	(377, 1, 0, -50331, 2689, 0, 0, 39, '2688'),
	(377, 1, 0, -50331, 2690, 0, 0, 39, '2689'),
	(377, 1, 0, -50331, 2691, 0, 0, 39, '2690'),
	(377, 1, 0, -50331, 2692, 0, 0, 39, '2691'),
	(377, 1, 0, -50331, 2693, 0, 0, 39, '2692'),
	(377, 1, 0, -50331, 2694, 0, 0, 39, '2693'),
	(377, 1, 0, -50331, 2695, 0, 0, 39, '2694'),
	(377, 1, 0, -50331, 2696, 0, 0, 39, '2695'),
	(377, 1, 0, -50331, 2697, 0, 0, 39, '2696'),
	(377, 1, 0, -50331, 2698, 0, 0, 39, '2697'),
	(377, 1, 0, -50331, 2699, 0, 0, 39, '2698'),
	(377, 1, 0, -50331, 2700, 0, 0, 39, '2699'),
	(377, 1, 0, -50331, 2701, 0, 0, 39, '2700'),
	(377, 1, 0, -50331, 2702, 0, 0, 39, '2701'),
	(377, 1, 0, -50331, 2703, 0, 0, 39, '2702'),
	(377, 1, 0, -50331, 2704, 0, 0, 39, '2703'),
	(377, 1, 0, -50331, 2705, 0, 0, 39, '2704'),
	(377, 1, 0, -50331, 2706, 0, 0, 39, '2705'),
	(377, 1, 0, -50331, 2707, 0, 0, 39, '2706'),
	(377, 1, 0, -50331, 2708, 0, 0, 39, '2707'),
	(377, 1, 0, -50331, 2709, 0, 0, 39, '2708'),
	(377, 1, 0, -50331, 2710, 0, 0, 39, '2709'),
	(377, 1, 0, -50331, 2711, 0, 0, 39, '2710'),
	(377, 1, 0, -50331, 2712, 0, 0, 39, '2711'),
	(377, 1, 0, -50331, 2713, 0, 0, 39, '2712'),
	(377, 1, 0, -50331, 2714, 0, 0, 39, '2713'),
	(377, 1, 0, -50331, 2715, 0, 0, 39, '2714'),
	(377, 1, 0, -50331, 2716, 0, 0, 39, '2715'),
	(377, 1, 0, -50331, 2717, 0, 0, 39, '2716'),
	(377, 1, 0, -50331, 2718, 0, 0, 39, '2717'),
	(377, 1, 0, -50331, 2719, 0, 0, 39, '2718'),
	(377, 1, 0, -50331, 2720, 0, 0, 39, '2719'),
	(377, 1, 0, -50331, 2721, 0, 0, 39, '2720'),
	(377, 1, 0, -50331, 2722, 0, 0, 39, '2721'),
	(377, 1, 0, -50331, 2723, 0, 0, 39, '2722'),
	(377, 1, 0, -50331, 2724, 0, 0, 39, '2723'),
	(377, 1, 0, -50331, 2725, 0, 0, 39, '2724'),
	(377, 1, 0, -50331, 2726, 0, 0, 39, '2725'),
	(377, 1, 0, -50331, 2727, 0, 0, 39, '2726'),
	(377, 1, 0, -50331, 2728, 0, 0, 39, '2727'),
	(377, 1, 0, -50331, 2729, 0, 0, 39, '2728'),
	(377, 1, 0, -50331, 2730, 0, 0, 39, '2729'),
	(377, 1, 0, -50331, 2731, 0, 0, 39, '2730'),
	(377, 1, 0, -50331, 2732, 0, 0, 39, '2731'),
	(377, 1, 0, -50331, 2733, 0, 0, 39, '2732'),
	(377, 1, 0, -50331, 2734, 0, 0, 39, '2733'),
	(377, 1, 0, -50331, 2735, 0, 0, 39, '2734'),
	(377, 1, 0, -50331, 2736, 0, 0, 39, '2735'),
	(377, 1, 0, -50331, 2737, 0, 0, 39, '2736'),
	(377, 1, 0, -50331, 2738, 0, 0, 39, '2737'),
	(377, 1, 0, -50331, 2739, 0, 0, 39, '2738'),
	(377, 1, 0, -50331, 2740, 0, 0, 39, '2739'),
	(377, 1, 0, -50331, 2741, 0, 0, 39, '2740'),
	(377, 1, 0, -50331, 2742, 0, 0, 39, '2741'),
	(377, 1, 0, -50331, 2743, 0, 0, 39, '2742'),
	(377, 1, 0, -50331, 2744, 0, 0, 39, '2743'),
	(377, 1, 0, -50331, 2745, 0, 0, 39, '2744'),
	(377, 1, 0, -50331, 2746, 0, 0, 39, '2745'),
	(377, 1, 0, -50331, 2747, 0, 0, 39, '2746'),
	(377, 1, 0, -50331, 2748, 0, 0, 39, '2747'),
	(377, 1, 0, -50331, 2749, 0, 0, 39, '2748'),
	(377, 1, 0, -50331, 2750, 0, 0, 39, '2749'),
	(377, 1, 0, -50331, 2751, 0, 0, 39, '2750'),
	(377, 1, 0, -50331, 2752, 0, 0, 39, '2751'),
	(377, 1, 0, -50331, 2753, 0, 0, 39, '2752'),
	(377, 1, 0, -50331, 2754, 0, 0, 39, '2753'),
	(377, 1, 0, -50331, 2755, 0, 0, 39, '2754'),
	(377, 1, 0, -50331, 2756, 0, 0, 39, '2755'),
	(377, 1, 0, -50331, 2757, 0, 0, 39, '2756'),
	(377, 1, 0, -50331, 2758, 0, 0, 39, '2757'),
	(377, 1, 0, -50331, 2759, 0, 0, 39, '2758'),
	(377, 1, 0, -50331, 2760, 0, 0, 39, '2759'),
	(377, 1, 0, -50331, 2761, 0, 0, 39, '2760'),
	(377, 1, 0, -50331, 2762, 0, 0, 39, '2761'),
	(377, 1, 0, -50331, 2763, 0, 0, 39, '2762'),
	(377, 1, 0, -50331, 2764, 0, 0, 39, '2763'),
	(377, 1, 0, -50331, 2765, 0, 0, 39, '2764'),
	(377, 1, 0, -50331, 2766, 0, 0, 39, '2765'),
	(377, 1, 0, -50331, 2767, 0, 0, 39, '2766'),
	(377, 1, 0, -50331, 2768, 0, 0, 39, '2767'),
	(377, 1, 0, -50331, 2769, 0, 0, 39, '2768'),
	(377, 1, 0, -50331, 2770, 0, 0, 39, '2769'),
	(377, 1, 0, -50331, 2771, 0, 0, 39, '2770'),
	(377, 1, 0, -50331, 2772, 0, 0, 39, '2771'),
	(377, 1, 0, -50331, 2773, 0, 0, 39, '2772'),
	(377, 1, 0, -50331, 2774, 0, 0, 39, '2773'),
	(377, 1, 0, -50331, 2775, 0, 0, 39, '2774'),
	(377, 1, 0, -50331, 2776, 0, 0, 39, '2775'),
	(377, 1, 0, -50331, 2777, 0, 0, 39, '2776'),
	(377, 1, 0, -50331, 2778, 0, 0, 39, '2777'),
	(377, 1, 0, -50331, 2779, 0, 0, 39, '2778'),
	(377, 1, 0, -50331, 2780, 0, 0, 39, '2779'),
	(377, 1, 0, -50331, 2781, 0, 0, 39, '2780'),
	(377, 1, 0, -50331, 2782, 0, 0, 39, '2781'),
	(377, 1, 0, -50331, 2783, 0, 0, 39, '2782'),
	(377, 1, 0, -50331, 2784, 0, 0, 39, '2783'),
	(377, 1, 0, -50331, 2785, 0, 0, 39, '2784'),
	(377, 1, 0, -50331, 2786, 0, 0, 39, '2785'),
	(377, 1, 0, -50331, 2787, 0, 0, 39, '2786'),
	(377, 1, 0, -50331, 2788, 0, 0, 39, '2787'),
	(377, 1, 0, -50331, 2789, 0, 0, 39, '2788'),
	(377, 1, 0, -50331, 2790, 0, 0, 39, '2789'),
	(377, 1, 0, -50331, 2791, 0, 0, 39, '2790'),
	(377, 1, 0, -50331, 2792, 0, 0, 39, '2791'),
	(377, 1, 0, -50331, 2793, 0, 0, 39, '2792'),
	(377, 1, 0, -50331, 2794, 0, 0, 39, '2793'),
	(377, 1, 0, -50331, 2795, 0, 0, 39, '2794'),
	(377, 1, 0, -50331, 2796, 0, 0, 39, '2795'),
	(377, 1, 0, -50331, 2797, 0, 0, 39, '2796'),
	(377, 1, 0, -50331, 2798, 0, 0, 39, '2797'),
	(377, 1, 0, -50331, 2799, 0, 0, 39, '2798'),
	(377, 1, 0, -50331, 2800, 0, 0, 39, '2799'),
	(377, 1, 0, -50331, 2801, 0, 0, 39, '2800'),
	(377, 1, 0, -50331, 2802, 0, 0, 39, '2801'),
	(377, 1, 0, -50331, 2803, 0, 0, 39, '2802'),
	(377, 1, 0, -50331, 2804, 0, 0, 39, '2803'),
	(377, 1, 0, -50331, 2805, 0, 0, 39, '2804'),
	(377, 1, 0, -50331, 2806, 0, 0, 39, '2805'),
	(377, 1, 0, -50331, 2807, 0, 0, 39, '2806'),
	(377, 1, 0, -50331, 2808, 0, 0, 39, '2807'),
	(377, 1, 0, -50331, 2809, 0, 0, 39, '2808'),
	(377, 1, 0, -50331, 2810, 0, 0, 39, '2809'),
	(377, 1, 0, -50331, 2811, 0, 0, 39, '2810'),
	(377, 1, 0, -50331, 2812, 0, 0, 39, '2811'),
	(377, 1, 0, -50331, 2813, 0, 0, 39, '2812'),
	(377, 1, 0, -50331, 2814, 0, 0, 39, '2813'),
	(377, 1, 0, -50331, 2815, 0, 0, 39, '2814'),
	(377, 1, 0, -50331, 2816, 0, 0, 39, '2815'),
	(377, 1, 0, -50331, 2817, 0, 0, 39, '2816'),
	(377, 1, 0, -50331, 2818, 0, 0, 39, '2817'),
	(377, 1, 0, -50331, 2819, 0, 0, 39, '2818'),
	(377, 1, 0, -50331, 2820, 0, 0, 39, '2819'),
	(377, 1, 0, -50331, 2821, 0, 0, 39, '2820'),
	(377, 1, 0, -50331, 2822, 0, 0, 39, '2821'),
	(377, 1, 0, -50331, 2823, 0, 0, 39, '2822'),
	(377, 1, 0, -50331, 2824, 0, 0, 39, '2823'),
	(377, 1, 0, -50331, 2825, 0, 0, 39, '2824'),
	(377, 1, 0, -50331, 2826, 0, 0, 39, '2825'),
	(377, 1, 0, -50331, 2827, 0, 0, 39, '2826'),
	(377, 1, 0, -50331, 2828, 0, 0, 39, '2827'),
	(377, 1, 0, -50331, 2829, 0, 0, 39, '2828'),
	(377, 1, 0, -50331, 2830, 0, 0, 39, '2829'),
	(377, 1, 0, -50331, 2831, 0, 0, 39, '2830'),
	(377, 1, 0, -50331, 2832, 0, 0, 39, '2831'),
	(377, 1, 0, -50331, 2833, 0, 0, 39, '2832'),
	(377, 1, 0, -50331, 2834, 0, 0, 39, '2833'),
	(377, 1, 0, -50331, 2835, 0, 0, 39, '2834'),
	(377, 1, 0, -50331, 2836, 0, 0, 39, '2835'),
	(377, 1, 0, -50331, 2837, 0, 0, 39, '2836'),
	(377, 1, 0, -50331, 2838, 0, 0, 39, '2837'),
	(377, 1, 0, -50331, 2839, 0, 0, 39, '2838'),
	(377, 1, 0, -50331, 2840, 0, 0, 39, '2839'),
	(377, 1, 0, -50331, 2841, 0, 0, 39, '2840'),
	(377, 1, 0, -50331, 2842, 0, 0, 39, '2841'),
	(377, 1, 0, -50331, 2843, 0, 0, 39, '2842'),
	(377, 1, 0, -50331, 2844, 0, 0, 39, '2843'),
	(377, 1, 0, -50331, 2845, 0, 0, 39, '2844'),
	(377, 1, 0, -50331, 2846, 0, 0, 39, '2845'),
	(377, 1, 0, -50331, 2847, 0, 0, 39, '2846'),
	(377, 1, 0, -50331, 2848, 0, 0, 39, '2847'),
	(377, 1, 0, -50331, 2849, 0, 0, 39, '2848'),
	(377, 1, 0, -50331, 2850, 0, 0, 39, '2849'),
	(377, 1, 0, -50331, 2851, 0, 0, 39, '2850'),
	(377, 1, 0, -50331, 2852, 0, 0, 39, '2851'),
	(377, 1, 0, -50331, 2853, 0, 0, 39, '2852'),
	(377, 1, 0, -50331, 2854, 0, 0, 39, '2853'),
	(377, 1, 0, -50331, 2855, 0, 0, 39, '2854'),
	(377, 1, 0, -50331, 2856, 0, 0, 39, '2855'),
	(377, 1, 0, -50331, 2857, 0, 0, 39, '2856'),
	(377, 1, 0, -50331, 2858, 0, 0, 39, '2857'),
	(377, 1, 0, -50331, 2859, 0, 0, 39, '2858'),
	(377, 1, 0, -50331, 2860, 0, 0, 39, '2859'),
	(377, 1, 0, -50331, 2861, 0, 0, 39, '2860'),
	(377, 1, 0, -50331, 2862, 0, 0, 39, '2861'),
	(377, 1, 0, -50331, 2863, 0, 0, 39, '2862'),
	(377, 1, 0, -50331, 2864, 0, 0, 39, '2863'),
	(377, 1, 0, -50331, 2865, 0, 0, 39, '2864'),
	(377, 1, 0, -50331, 2866, 0, 0, 39, '2865'),
	(377, 1, 0, -50331, 2867, 0, 0, 39, '2866'),
	(377, 1, 0, -50331, 2868, 0, 0, 39, '2867'),
	(377, 1, 0, -50331, 2869, 0, 0, 39, '2868'),
	(377, 1, 0, -50331, 2870, 0, 0, 39, '2869'),
	(377, 1, 0, -50331, 2871, 0, 0, 39, '2870'),
	(377, 1, 0, -50331, 2872, 0, 0, 39, '2871'),
	(377, 1, 0, -50331, 2873, 0, 0, 39, '2872'),
	(377, 1, 0, -50331, 2874, 0, 0, 39, '2873'),
	(377, 1, 0, -50331, 2875, 0, 0, 39, '2874'),
	(377, 1, 0, -50331, 2876, 0, 0, 39, '2875'),
	(377, 1, 0, -50331, 2877, 0, 0, 39, '2876'),
	(377, 1, 0, -50331, 2878, 0, 0, 39, '2877'),
	(377, 1, 0, -50331, 2879, 0, 0, 39, '2878'),
	(377, 1, 0, -50331, 2880, 0, 0, 39, '2879'),
	(377, 1, 0, -50331, 2881, 0, 0, 39, '2880'),
	(377, 1, 0, -50331, 2882, 0, 0, 39, '2881'),
	(377, 1, 0, -50331, 2883, 0, 0, 39, '2882'),
	(377, 1, 0, -50331, 2884, 0, 0, 39, '2883'),
	(377, 1, 0, -50331, 2885, 0, 0, 39, '2884'),
	(377, 1, 0, -50331, 2886, 0, 0, 39, '2885'),
	(377, 1, 0, -50331, 2887, 0, 0, 39, '2886'),
	(377, 1, 0, -50331, 2888, 0, 0, 39, '2887'),
	(377, 1, 0, -50331, 2889, 0, 0, 39, '2888'),
	(377, 1, 0, -50331, 2890, 0, 0, 39, '2889'),
	(377, 1, 0, -50331, 2891, 0, 0, 39, '2890'),
	(377, 1, 0, -50331, 2892, 0, 0, 39, '2891'),
	(377, 1, 0, -50331, 2893, 0, 0, 39, '2892'),
	(377, 1, 0, -50331, 2894, 0, 0, 39, '2893'),
	(377, 1, 0, -50331, 2895, 0, 0, 39, '2894'),
	(377, 1, 0, -50331, 2896, 0, 0, 39, '2895'),
	(377, 1, 0, -50331, 2897, 0, 0, 39, '2896'),
	(377, 1, 0, -50331, 2898, 0, 0, 39, '2897'),
	(377, 1, 0, -50331, 2899, 0, 0, 39, '2898'),
	(377, 1, 0, -50331, 2900, 0, 0, 39, '2899'),
	(377, 1, 0, -50331, 2901, 0, 0, 39, '2900'),
	(377, 1, 0, -50331, 2902, 0, 0, 39, '2901'),
	(377, 1, 0, -50331, 2903, 0, 0, 39, '2902'),
	(377, 1, 0, -50331, 2904, 0, 0, 39, '2903'),
	(377, 1, 0, -50331, 2905, 0, 0, 39, '2904'),
	(377, 1, 0, -50331, 2906, 0, 0, 39, '2905'),
	(377, 1, 0, -50331, 2907, 0, 0, 39, '2906'),
	(377, 1, 0, -50331, 2908, 0, 0, 39, '2907'),
	(377, 1, 0, -50331, 2909, 0, 0, 39, '2908'),
	(377, 1, 0, -50331, 2910, 0, 0, 39, '2909'),
	(377, 1, 0, -50331, 2911, 0, 0, 39, '2910'),
	(377, 1, 0, -50331, 2912, 0, 0, 39, '2911'),
	(377, 1, 0, -50331, 2913, 0, 0, 39, '2912'),
	(377, 1, 0, -50331, 2914, 0, 0, 39, '2913'),
	(377, 1, 0, -50331, 2915, 0, 0, 39, '2914'),
	(377, 1, 0, -50331, 2916, 0, 0, 39, '2915'),
	(377, 1, 0, -50331, 2917, 0, 0, 39, '2916'),
	(377, 1, 0, -50331, 2918, 0, 0, 39, '2917'),
	(377, 1, 0, -50331, 2919, 0, 0, 39, '2918'),
	(377, 1, 0, -50331, 2920, 0, 0, 39, '2919'),
	(377, 1, 0, -50331, 2921, 0, 0, 39, '2920'),
	(377, 1, 0, -50331, 2922, 0, 0, 39, '2921'),
	(377, 1, 0, -50331, 2923, 0, 0, 39, '2922'),
	(377, 1, 0, -50331, 2924, 0, 0, 39, '2923'),
	(377, 1, 0, -50331, 2925, 0, 0, 39, '2924'),
	(377, 1, 0, -50331, 2926, 0, 0, 39, '2925'),
	(377, 1, 0, -50331, 2927, 0, 0, 39, '2926'),
	(377, 1, 0, -50331, 2928, 0, 0, 39, '2927'),
	(377, 1, 0, -50331, 2929, 0, 0, 39, '2928'),
	(377, 1, 0, -50331, 2930, 0, 0, 39, '2929'),
	(377, 1, 0, -50331, 2931, 0, 0, 39, '2930'),
	(377, 1, 0, -50331, 2932, 0, 0, 39, '2931'),
	(377, 1, 0, -50331, 2933, 0, 0, 39, '2932'),
	(377, 1, 0, -50331, 2934, 0, 0, 39, '2933'),
	(377, 1, 0, -50331, 2935, 0, 0, 39, '2934'),
	(377, 1, 0, -50331, 2936, 0, 0, 39, '2935'),
	(377, 1, 0, -50331, 2937, 0, 0, 39, '2936'),
	(377, 1, 0, -50331, 2938, 0, 0, 39, '2937'),
	(377, 1, 0, -50331, 2939, 0, 0, 39, '2938'),
	(377, 1, 0, -50331, 2940, 0, 0, 39, '2939'),
	(377, 1, 0, -50331, 2941, 0, 0, 39, '2940'),
	(377, 1, 0, -50331, 2942, 0, 0, 39, '2941'),
	(377, 1, 0, -50331, 2943, 0, 0, 39, '2942'),
	(377, 1, 0, -50331, 2944, 0, 0, 39, '2943'),
	(377, 1, 0, -50331, 2945, 0, 0, 39, '2944'),
	(377, 1, 0, -50331, 2946, 0, 0, 39, '2945'),
	(377, 1, 0, -50331, 2947, 0, 0, 39, '2946'),
	(377, 1, 0, -50331, 2948, 0, 0, 39, '2947'),
	(377, 1, 0, -50331, 2949, 0, 0, 39, '2948'),
	(377, 1, 0, -50331, 2950, 0, 0, 39, '2949'),
	(377, 1, 0, -50331, 2951, 0, 0, 39, '2950'),
	(377, 1, 0, -50331, 2952, 0, 0, 39, '2951'),
	(377, 1, 0, -50331, 2953, 0, 0, 39, '2952'),
	(377, 1, 0, -50331, 2954, 0, 0, 39, '2953'),
	(377, 1, 0, -50331, 2955, 0, 0, 39, '2954'),
	(377, 1, 0, -50331, 2956, 0, 0, 39, '2955'),
	(377, 1, 0, -50331, 2957, 0, 0, 39, '2956'),
	(377, 1, 0, -50331, 2958, 0, 0, 39, '2957'),
	(377, 1, 0, -50331, 2959, 0, 0, 39, '2958'),
	(377, 1, 0, -50331, 2960, 0, 0, 39, '2959'),
	(377, 1, 0, -50331, 2961, 0, 0, 39, '2960'),
	(377, 1, 0, -50331, 2962, 0, 0, 39, '2961'),
	(377, 1, 0, -50331, 2963, 0, 0, 39, '2962'),
	(377, 1, 0, -50331, 2964, 0, 0, 39, '2963'),
	(377, 1, 0, -50331, 2965, 0, 0, 39, '2964'),
	(377, 1, 0, -50331, 2966, 0, 0, 39, '2965'),
	(377, 1, 0, -50331, 2967, 0, 0, 39, '2966'),
	(377, 1, 0, -50331, 2968, 0, 0, 39, '2967'),
	(377, 1, 0, -50331, 2969, 0, 0, 39, '2968'),
	(377, 1, 0, -50331, 2970, 0, 0, 39, '2969'),
	(377, 1, 0, -50331, 2971, 0, 0, 39, '2970'),
	(377, 1, 0, -50331, 2972, 0, 0, 39, '2971'),
	(377, 1, 0, -50331, 2973, 0, 0, 39, '2972'),
	(377, 1, 0, -50331, 2974, 0, 0, 39, '2973'),
	(377, 1, 0, -50331, 2975, 0, 0, 39, '2974'),
	(377, 1, 0, -50331, 2976, 0, 0, 39, '2975'),
	(377, 1, 0, -50331, 2977, 0, 0, 39, '2976'),
	(377, 1, 0, -50331, 2978, 0, 0, 39, '2977'),
	(377, 1, 0, -50331, 2979, 0, 0, 39, '2978'),
	(377, 1, 0, -50331, 2980, 0, 0, 39, '2979'),
	(377, 1, 0, -50331, 2981, 0, 0, 39, '2980'),
	(377, 1, 0, -50331, 2982, 0, 0, 39, '2981'),
	(377, 1, 0, -50331, 2983, 0, 0, 39, '2982'),
	(377, 1, 0, -50331, 2984, 0, 0, 39, '2983'),
	(377, 1, 0, -50331, 2985, 0, 0, 39, '2984'),
	(377, 1, 0, -50331, 2986, 0, 0, 39, '2985'),
	(377, 1, 0, -50331, 2987, 0, 0, 39, '2986'),
	(377, 1, 0, -50331, 2988, 0, 0, 39, '2987'),
	(377, 1, 0, -50331, 2989, 0, 0, 39, '2988'),
	(377, 1, 0, -50331, 2990, 0, 0, 39, '2989'),
	(377, 1, 0, -50331, 2991, 0, 0, 39, '2990'),
	(377, 1, 0, -50331, 2992, 0, 0, 39, '2991'),
	(377, 1, 0, -50331, 2993, 0, 0, 39, '2992'),
	(377, 1, 0, -50331, 2994, 0, 0, 39, '2993'),
	(377, 1, 0, -50331, 2995, 0, 0, 39, '2994'),
	(377, 1, 0, -50331, 2996, 0, 0, 39, '2995'),
	(377, 1, 0, -50331, 2997, 0, 0, 39, '2996'),
	(377, 1, 0, -50331, 2998, 0, 0, 39, '2997'),
	(377, 1, 0, -50331, 2999, 0, 0, 39, '2998'),
	(377, 1, 0, -50331, 3000, 0, 0, 39, '2999'),
	(377, 1, 0, -50331, 3001, 0, 0, 39, '3000'),
	(377, 1, 0, -50331, 3002, 0, 0, 39, '3001'),
	(377, 1, 0, -50331, 3003, 0, 0, 39, '3002'),
	(377, 1, 0, -50331, 3004, 0, 0, 39, '3003'),
	(377, 1, 0, -50331, 3005, 0, 0, 39, '3004'),
	(377, 1, 0, -50331, 3006, 0, 0, 39, '3005'),
	(377, 1, 0, -50331, 3007, 0, 0, 39, '3006'),
	(377, 1, 0, -50331, 3008, 0, 0, 39, '3007'),
	(377, 1, 0, -50331, 3009, 0, 0, 39, '3008'),
	(377, 1, 0, -50331, 3010, 0, 0, 39, '3009'),
	(377, 1, 0, -50331, 3011, 0, 0, 39, '3010'),
	(377, 1, 0, -50331, 3012, 0, 0, 39, '3011'),
	(377, 1, 0, -50331, 3013, 0, 0, 39, '3012'),
	(377, 1, 0, -50331, 3014, 0, 0, 39, '3013'),
	(377, 1, 0, -50331, 3015, 0, 0, 39, '3014'),
	(377, 1, 0, -50331, 3016, 0, 0, 39, '3015'),
	(377, 1, 0, -50331, 3017, 0, 0, 39, '3016'),
	(377, 1, 0, -50331, 3018, 0, 0, 39, '3017'),
	(377, 1, 0, -50331, 3019, 0, 0, 39, '3018'),
	(377, 1, 0, -50331, 3020, 0, 0, 39, '3019'),
	(377, 1, 0, -50331, 3021, 0, 0, 39, '3020'),
	(377, 1, 0, -50331, 3022, 0, 0, 39, '3021'),
	(377, 1, 0, -50331, 3023, 0, 0, 39, '3022'),
	(377, 1, 0, -50331, 3024, 0, 0, 39, '3023'),
	(377, 1, 0, -50331, 3025, 0, 0, 39, '3024'),
	(377, 1, 0, -50331, 3026, 0, 0, 39, '3025'),
	(377, 1, 0, -50331, 3027, 0, 0, 39, '3026'),
	(377, 1, 0, -50331, 3028, 0, 0, 39, '3027'),
	(377, 1, 0, -50331, 3029, 0, 0, 39, '3028'),
	(377, 1, 0, -50331, 3030, 0, 0, 39, '3029'),
	(377, 1, 0, -50331, 3031, 0, 0, 39, '3030'),
	(377, 1, 0, -50331, 3032, 0, 0, 39, '3031'),
	(377, 1, 0, -50331, 3033, 0, 0, 39, '3032'),
	(377, 1, 0, -50331, 3034, 0, 0, 39, '3033'),
	(377, 1, 0, -50331, 3035, 0, 0, 39, '3034'),
	(377, 1, 0, -50331, 3036, 0, 0, 39, '3035'),
	(377, 1, 0, -50331, 3037, 0, 0, 39, '3036'),
	(377, 1, 0, -50331, 3038, 0, 0, 39, '3037'),
	(377, 1, 0, -50331, 3039, 0, 0, 39, '3038'),
	(377, 1, 0, -50331, 3040, 0, 0, 39, '3039'),
	(377, 1, 0, -50331, 3041, 0, 0, 39, '3040'),
	(377, 1, 0, -50331, 3042, 0, 0, 39, '3041'),
	(377, 1, 0, -50331, 3043, 0, 0, 39, '3042'),
	(377, 1, 0, -50331, 3044, 0, 0, 39, '3043'),
	(377, 1, 0, -50331, 3045, 0, 0, 39, '3044'),
	(377, 1, 0, -50331, 3046, 0, 0, 39, '3045'),
	(377, 1, 0, -50331, 3047, 0, 0, 39, '3046'),
	(377, 1, 0, -50331, 3048, 0, 0, 39, '3047'),
	(377, 1, 0, -50331, 3049, 0, 0, 39, '3048'),
	(377, 1, 0, -50331, 3050, 0, 0, 39, '3049'),
	(377, 1, 0, -50331, 3051, 0, 0, 39, '3050'),
	(377, 1, 0, -50331, 3052, 0, 0, 39, '3051'),
	(377, 1, 0, -50331, 3053, 0, 0, 39, '3052'),
	(377, 1, 0, -50331, 3054, 0, 0, 39, '3053'),
	(377, 1, 0, -50331, 3055, 0, 0, 39, '3054'),
	(377, 1, 0, -50331, 3056, 0, 0, 39, '3055'),
	(377, 1, 0, -50331, 3057, 0, 0, 39, '3056'),
	(377, 1, 0, -50331, 3058, 0, 0, 39, '3057'),
	(377, 1, 0, -50331, 3059, 0, 0, 39, '3058'),
	(377, 1, 0, -50331, 3060, 0, 0, 39, '3059'),
	(377, 1, 0, -50331, 3061, 0, 0, 39, '3060'),
	(377, 1, 0, -50331, 3062, 0, 0, 39, '3061'),
	(377, 1, 0, -50331, 3063, 0, 0, 39, '3062'),
	(377, 1, 0, -50331, 3064, 0, 0, 39, '3063'),
	(377, 1, 0, -50331, 3065, 0, 0, 39, '3064'),
	(377, 1, 0, -50331, 3066, 0, 0, 39, '3065'),
	(377, 1, 0, -50331, 3067, 0, 0, 39, '3066'),
	(377, 1, 0, -50331, 3068, 0, 0, 39, '3067'),
	(377, 1, 0, -50331, 3069, 0, 0, 39, '3068'),
	(377, 1, 0, -50331, 3070, 0, 0, 39, '3069'),
	(377, 1, 0, -50331, 3071, 0, 0, 39, '3070'),
	(377, 1, 0, -50331, 3072, 0, 0, 39, '3071'),
	(377, 1, 0, -50331, 3073, 0, 0, 39, '3072'),
	(377, 1, 0, -50331, 3074, 0, 0, 39, '3073'),
	(377, 1, 0, -50331, 3075, 0, 0, 39, '3074'),
	(377, 1, 0, -50331, 3076, 0, 0, 39, '3075'),
	(377, 1, 0, -50331, 3077, 0, 0, 39, '3076'),
	(377, 1, 0, -50331, 3078, 0, 0, 39, '3077'),
	(377, 1, 0, -50331, 3079, 0, 0, 39, '3078'),
	(377, 1, 0, -50331, 3080, 0, 0, 39, '3079'),
	(377, 1, 0, -50331, 3081, 0, 0, 39, '3080'),
	(377, 1, 0, -50331, 3082, 0, 0, 39, '3081'),
	(377, 1, 0, -50331, 3083, 0, 0, 39, '3082'),
	(377, 1, 0, -50331, 3084, 0, 0, 39, '3083'),
	(377, 1, 0, -50331, 3085, 0, 0, 39, '3084'),
	(377, 1, 0, -50331, 3086, 0, 0, 39, '3085'),
	(377, 1, 0, -50331, 3087, 0, 0, 39, '3086'),
	(377, 1, 0, -50331, 3088, 0, 0, 39, '3087'),
	(377, 1, 0, -50331, 3089, 0, 0, 39, '3088'),
	(377, 1, 0, -50331, 3090, 0, 0, 39, '3089'),
	(377, 1, 0, -50331, 3091, 0, 0, 39, '3090'),
	(377, 1, 0, -50331, 3092, 0, 0, 39, '3091'),
	(377, 1, 0, -50331, 3093, 0, 0, 39, '3092'),
	(377, 1, 0, -50331, 3094, 0, 0, 39, '3093'),
	(377, 1, 0, -50331, 3095, 0, 0, 39, '3094'),
	(377, 1, 0, -50331, 3096, 0, 0, 39, '3095'),
	(377, 1, 0, -50331, 3097, 0, 0, 39, '3096'),
	(377, 1, 0, -50331, 3098, 0, 0, 39, '3097'),
	(377, 1, 0, -50331, 3099, 0, 0, 39, '3098'),
	(377, 1, 0, -50331, 3100, 0, 0, 39, '3099'),
	(377, 1, 0, -50331, 3101, 0, 0, 39, '3100'),
	(377, 1, 0, -50331, 3102, 0, 0, 39, '3101'),
	(377, 1, 0, -50331, 3103, 0, 0, 39, '3102'),
	(377, 1, 0, -50331, 3104, 0, 0, 39, '3103'),
	(377, 1, 0, -50331, 3105, 0, 0, 39, '3104'),
	(377, 1, 0, -50331, 3106, 0, 0, 39, '3105'),
	(377, 1, 0, -50331, 3107, 0, 0, 39, '3106'),
	(377, 1, 0, -50331, 3108, 0, 0, 39, '3107'),
	(377, 1, 0, -50331, 3109, 0, 0, 39, '3108'),
	(377, 1, 0, -50331, 3110, 0, 0, 39, '3109'),
	(377, 1, 0, -50331, 3111, 0, 0, 39, '3110'),
	(377, 1, 0, -50331, 3112, 0, 0, 39, '3111'),
	(377, 1, 0, -50331, 3113, 0, 0, 39, '3112'),
	(377, 1, 0, -50331, 3114, 0, 0, 39, '3113'),
	(377, 1, 0, -50331, 3115, 0, 0, 39, '3114'),
	(377, 1, 0, -50331, 3116, 0, 0, 39, '3115'),
	(377, 1, 0, -50331, 3117, 0, 0, 39, '3116'),
	(377, 1, 0, -50331, 3118, 0, 0, 39, '3117'),
	(377, 1, 0, -50331, 3119, 0, 0, 39, '3118'),
	(377, 1, 0, -50331, 3120, 0, 0, 39, '3119'),
	(377, 1, 0, -50331, 3121, 0, 0, 39, '3120'),
	(377, 1, 0, -50331, 3122, 0, 0, 39, '3121'),
	(377, 1, 0, -50331, 3123, 0, 0, 39, '3122'),
	(377, 1, 0, -50331, 3124, 0, 0, 39, '3123'),
	(377, 1, 0, -50331, 3125, 0, 0, 39, '3124'),
	(377, 1, 0, -50331, 3126, 0, 0, 39, '3125'),
	(377, 1, 0, -50331, 3127, 0, 0, 39, '3126'),
	(377, 1, 0, -50331, 3128, 0, 0, 39, '3127'),
	(377, 1, 0, -50331, 3129, 0, 0, 39, '3128'),
	(377, 1, 0, -50331, 3130, 0, 0, 39, '3129'),
	(377, 1, 0, -50331, 3131, 0, 0, 39, '3130'),
	(377, 1, 0, -50331, 3132, 0, 0, 39, '3131'),
	(377, 1, 0, -50331, 3133, 0, 0, 39, '3132'),
	(377, 1, 0, -50331, 3134, 0, 0, 39, '3133'),
	(377, 1, 0, -50331, 3135, 0, 0, 39, '3134'),
	(377, 1, 0, -50331, 3136, 0, 0, 39, '3135'),
	(377, 1, 0, -50331, 3137, 0, 0, 39, '3136'),
	(377, 1, 0, -50331, 3138, 0, 0, 39, '3137'),
	(377, 1, 0, -50331, 3139, 0, 0, 39, '3138'),
	(377, 1, 0, -50331, 3140, 0, 0, 39, '3139'),
	(377, 1, 0, -50331, 3141, 0, 0, 39, '3140'),
	(377, 1, 0, -50331, 3142, 0, 0, 39, '3141'),
	(377, 1, 0, -50331, 3143, 0, 0, 39, '3142'),
	(377, 1, 0, -50331, 3144, 0, 0, 39, '3143'),
	(377, 1, 0, -50331, 3145, 0, 0, 39, '3144'),
	(377, 1, 0, -50331, 3146, 0, 0, 39, '3145'),
	(377, 1, 0, -50331, 3147, 0, 0, 39, '3146'),
	(377, 1, 0, -50331, 3148, 0, 0, 39, '3147'),
	(377, 1, 0, -50331, 3149, 0, 0, 39, '3148'),
	(377, 1, 0, -50331, 3150, 0, 0, 39, '3149'),
	(377, 1, 0, -50331, 3151, 0, 0, 39, '3150'),
	(377, 1, 0, -50331, 3152, 0, 0, 39, '3151'),
	(377, 1, 0, -50331, 3153, 0, 0, 39, '3152'),
	(377, 1, 0, -50331, 3154, 0, 0, 39, '3153'),
	(377, 1, 0, -50331, 3155, 0, 0, 39, '3154'),
	(377, 1, 0, -50331, 3156, 0, 0, 39, '3155'),
	(377, 1, 0, -50331, 3157, 0, 0, 39, '3156'),
	(377, 1, 0, -50331, 3158, 0, 0, 39, '3157'),
	(377, 1, 0, -50331, 3159, 0, 0, 39, '3158'),
	(377, 1, 0, -50331, 3160, 0, 0, 39, '3159'),
	(377, 1, 0, -50331, 3161, 0, 0, 39, '3160'),
	(377, 1, 0, -50331, 3162, 0, 0, 39, '3161'),
	(377, 1, 0, -50331, 3163, 0, 0, 39, '3162'),
	(377, 1, 0, -50331, 3164, 0, 0, 39, '3163'),
	(377, 1, 0, -50331, 3165, 0, 0, 39, '3164'),
	(377, 1, 0, -50331, 3166, 0, 0, 39, '3165'),
	(377, 1, 0, -50331, 3167, 0, 0, 39, '3166'),
	(377, 1, 0, -50331, 3168, 0, 0, 39, '3167'),
	(377, 1, 0, -50331, 3169, 0, 0, 39, '3168'),
	(377, 1, 0, -50331, 3170, 0, 0, 39, '3169'),
	(377, 1, 0, -50331, 3171, 0, 0, 39, '3170'),
	(377, 1, 0, -50331, 3172, 0, 0, 39, '3171'),
	(377, 1, 0, -50331, 3173, 0, 0, 39, '3172'),
	(377, 1, 0, -50331, 3174, 0, 0, 39, '3173'),
	(377, 1, 0, -50331, 3175, 0, 0, 39, '3174'),
	(377, 1, 0, -50331, 3176, 0, 0, 39, '3175'),
	(377, 1, 0, -50331, 3177, 0, 0, 39, '3176'),
	(377, 1, 0, -50331, 3178, 0, 0, 39, '3177'),
	(377, 1, 0, -50331, 3179, 0, 0, 39, '3178'),
	(377, 1, 0, -50331, 3180, 0, 0, 39, '3179'),
	(377, 1, 0, -50331, 3181, 0, 0, 39, '3180'),
	(377, 1, 0, -50331, 3182, 0, 0, 39, '3181'),
	(377, 1, 0, -50331, 3183, 0, 0, 39, '3182'),
	(377, 1, 0, -50331, 3184, 0, 0, 39, '3183'),
	(377, 1, 0, -50331, 3185, 0, 0, 39, '3184'),
	(377, 1, 0, -50331, 3186, 0, 0, 39, '3185'),
	(377, 1, 0, -50331, 3187, 0, 0, 39, '3186'),
	(377, 1, 0, -50331, 3188, 0, 0, 39, '3187'),
	(377, 1, 0, -50331, 3189, 0, 0, 39, '3188'),
	(377, 1, 0, -50331, 3190, 0, 0, 39, '3189'),
	(377, 1, 0, -50331, 3191, 0, 0, 39, '3190'),
	(377, 1, 0, -50331, 3192, 0, 0, 39, '3191'),
	(377, 1, 0, -50331, 3193, 0, 0, 39, '3192'),
	(377, 1, 0, -50331, 3194, 0, 0, 39, '3193'),
	(377, 1, 0, -50331, 3195, 0, 0, 39, '3194'),
	(377, 1, 0, -50331, 3196, 0, 0, 39, '3195'),
	(377, 1, 0, -50331, 3197, 0, 0, 39, '3196'),
	(377, 1, 0, -50331, 3198, 0, 0, 39, '3197'),
	(377, 1, 0, -50331, 3199, 0, 0, 39, '3198'),
	(377, 1, 0, -50331, 3200, 0, 0, 39, '3199'),
	(377, 1, 0, -50331, 3201, 0, 0, 39, '3200'),
	(377, 1, 0, -50331, 3202, 0, 0, 39, '3201'),
	(377, 1, 0, -50331, 3203, 0, 0, 39, '3202'),
	(377, 1, 0, -50331, 3204, 0, 0, 39, '3203'),
	(377, 1, 0, -50331, 3205, 0, 0, 39, '3204'),
	(377, 1, 0, -50331, 3206, 0, 0, 39, '3205'),
	(377, 1, 0, -50331, 3207, 0, 0, 39, '3206'),
	(377, 1, 0, -50331, 3208, 0, 0, 39, '3207'),
	(377, 1, 0, -50331, 3209, 0, 0, 39, '3208'),
	(377, 1, 0, -50331, 3210, 0, 0, 39, '3209'),
	(377, 1, 0, -50331, 3211, 0, 0, 39, '3210'),
	(377, 1, 0, -50331, 3212, 0, 0, 39, '3211'),
	(377, 1, 0, -50331, 3213, 0, 0, 39, '3212'),
	(377, 1, 0, -50331, 3214, 0, 0, 39, '3213'),
	(377, 1, 0, -50331, 3215, 0, 0, 39, '3214'),
	(377, 1, 0, -50331, 3216, 0, 0, 39, '3215'),
	(377, 1, 0, -50331, 3217, 0, 0, 39, '3216'),
	(377, 1, 0, -50331, 3218, 0, 0, 39, '3217'),
	(377, 1, 0, -50331, 3219, 0, 0, 39, '3218'),
	(377, 1, 0, -50331, 3220, 0, 0, 39, '3219'),
	(377, 1, 0, -50331, 3221, 0, 0, 39, '3220'),
	(377, 1, 0, -50331, 3222, 0, 0, 39, '3221'),
	(377, 1, 0, -50331, 3223, 0, 0, 39, '3222'),
	(377, 1, 0, -50331, 3224, 0, 0, 39, '3223'),
	(377, 1, 0, -50331, 3225, 0, 0, 39, '3224'),
	(377, 1, 0, -50331, 3226, 0, 0, 39, '3225'),
	(377, 1, 0, -50331, 3227, 0, 0, 39, '3226'),
	(377, 1, 0, -50331, 3228, 0, 0, 39, '3227'),
	(377, 1, 0, -50331, 3229, 0, 0, 39, '3228'),
	(377, 1, 0, -50331, 3230, 0, 0, 39, '3229'),
	(377, 1, 0, -50331, 3231, 0, 0, 39, '3230'),
	(377, 1, 0, -50331, 3232, 0, 0, 39, '3231'),
	(377, 1, 0, -50331, 3233, 0, 0, 39, '3232'),
	(377, 1, 0, -50331, 3234, 0, 0, 39, '3233'),
	(377, 1, 0, -50331, 3235, 0, 0, 39, '3234'),
	(377, 1, 0, -50331, 3236, 0, 0, 39, '3235'),
	(377, 1, 0, -50331, 3237, 0, 0, 39, '3236'),
	(377, 1, 0, -50331, 3238, 0, 0, 39, '3237'),
	(377, 1, 0, -50331, 3239, 0, 0, 39, '3238'),
	(377, 1, 0, -50331, 3240, 0, 0, 39, '3239'),
	(377, 1, 0, -50331, 3241, 0, 0, 39, '3240'),
	(377, 1, 0, -50331, 3242, 0, 0, 39, '3241'),
	(377, 1, 0, -50331, 3243, 0, 0, 39, '3242'),
	(377, 1, 0, -50331, 3244, 0, 0, 39, '3243'),
	(377, 1, 0, -50331, 3245, 0, 0, 39, '3244'),
	(377, 1, 0, -50331, 3246, 0, 0, 39, '3245'),
	(377, 1, 0, -50331, 3247, 0, 0, 39, '3246'),
	(377, 1, 0, -50331, 3248, 0, 0, 39, '3247'),
	(377, 1, 0, -50331, 3249, 0, 0, 39, '3248'),
	(377, 1, 0, -50331, 3250, 0, 0, 39, '3249'),
	(377, 1, 0, -50331, 3251, 0, 0, 39, '3250'),
	(377, 1, 0, -50331, 3252, 0, 0, 39, '3251'),
	(377, 1, 0, -50331, 3253, 0, 0, 39, '3252'),
	(377, 1, 0, -50331, 3254, 0, 0, 39, '3253'),
	(377, 1, 0, -50331, 3255, 0, 0, 39, '3254'),
	(377, 1, 0, -50331, 3256, 0, 0, 39, '3255'),
	(377, 1, 0, -50331, 3257, 0, 0, 39, '3256'),
	(377, 1, 0, -50331, 3258, 0, 0, 39, '3257'),
	(377, 1, 0, -50331, 3259, 0, 0, 39, '3258'),
	(377, 1, 0, -50331, 3260, 0, 0, 39, '3259'),
	(377, 1, 0, -50331, 3261, 0, 0, 39, '3260'),
	(377, 1, 0, -50331, 3262, 0, 0, 39, '3261'),
	(377, 1, 0, -50331, 3263, 0, 0, 39, '3262'),
	(377, 1, 0, -50331, 3264, 0, 0, 39, '3263'),
	(377, 1, 0, -50331, 3265, 0, 0, 39, '3264'),
	(377, 1, 0, -50331, 3266, 0, 0, 39, '3265'),
	(377, 1, 0, -50331, 3267, 0, 0, 39, '3266'),
	(377, 1, 0, -50331, 3268, 0, 0, 39, '3267'),
	(377, 1, 0, -50331, 3269, 0, 0, 39, '3268'),
	(377, 1, 0, -50331, 3270, 0, 0, 39, '3269'),
	(377, 1, 0, -50331, 3271, 0, 0, 39, '3270'),
	(377, 1, 0, -50331, 3272, 0, 0, 39, '3271'),
	(377, 1, 0, -50331, 3273, 0, 0, 39, '3272'),
	(377, 1, 0, -50331, 3274, 0, 0, 39, '3273'),
	(377, 1, 0, -50331, 3275, 0, 0, 39, '3274'),
	(377, 1, 0, -50331, 3276, 0, 0, 39, '3275'),
	(377, 1, 0, -50331, 3277, 0, 0, 39, '3276'),
	(377, 1, 0, -50331, 3278, 0, 0, 39, '3277'),
	(377, 1, 0, -50331, 3279, 0, 0, 39, '3278'),
	(377, 1, 0, -50331, 3280, 0, 0, 39, '3279'),
	(377, 1, 0, -50331, 3281, 0, 0, 39, '3280'),
	(377, 1, 0, -50331, 3282, 0, 0, 39, '3281'),
	(377, 1, 0, -50331, 3283, 0, 0, 39, '3282'),
	(377, 1, 0, -50331, 3284, 0, 0, 39, '3283'),
	(377, 1, 0, -50331, 3285, 0, 0, 39, '3284'),
	(377, 1, 0, -50331, 3286, 0, 0, 39, '3285'),
	(377, 1, 0, -50331, 3287, 0, 0, 39, '3286'),
	(377, 1, 0, -50331, 3288, 0, 0, 39, '3287'),
	(377, 1, 0, -50331, 3289, 0, 0, 39, '3288'),
	(377, 1, 0, -50331, 3290, 0, 0, 39, '3289'),
	(377, 1, 0, -50331, 3291, 0, 0, 39, '3290'),
	(377, 1, 0, -50331, 3292, 0, 0, 39, '3291'),
	(377, 1, 0, -50331, 3293, 0, 0, 39, '3292'),
	(377, 1, 0, -50331, 3294, 0, 0, 39, '3293'),
	(377, 1, 0, -50331, 3295, 0, 0, 39, '3294'),
	(377, 1, 0, -50331, 3296, 0, 0, 39, '3295'),
	(377, 1, 0, -50331, 3297, 0, 0, 39, '3296'),
	(377, 1, 0, -50331, 3298, 0, 0, 39, '3297'),
	(377, 1, 0, -50331, 3299, 0, 0, 39, '3298'),
	(377, 1, 0, -50331, 3300, 0, 0, 39, '3299'),
	(377, 1, 0, -50331, 3301, 0, 0, 39, '3300'),
	(377, 1, 0, -50331, 3302, 0, 0, 39, '3301'),
	(377, 1, 0, -50331, 3303, 0, 0, 39, '3302'),
	(377, 1, 0, -50331, 3304, 0, 0, 39, '3303'),
	(377, 1, 0, -50331, 3305, 0, 0, 39, '3304'),
	(377, 1, 0, -50331, 3306, 0, 0, 39, '3305'),
	(377, 1, 0, -50331, 3307, 0, 0, 39, '3306'),
	(377, 1, 0, -50331, 3308, 0, 0, 39, '3307'),
	(377, 1, 0, -50331, 3309, 0, 0, 39, '3308'),
	(377, 1, 0, -50331, 3310, 0, 0, 39, '3309'),
	(377, 1, 0, -50331, 3311, 0, 0, 39, '3310'),
	(377, 1, 0, -50331, 3312, 0, 0, 39, '3311'),
	(377, 1, 0, -50331, 3313, 0, 0, 39, '3312'),
	(377, 1, 0, -50331, 3314, 0, 0, 39, '3313'),
	(377, 1, 0, -50331, 3315, 0, 0, 39, '3314'),
	(377, 1, 0, -50331, 3316, 0, 0, 39, '3315'),
	(377, 1, 0, -50331, 3317, 0, 0, 39, '3316'),
	(377, 1, 0, -50331, 3318, 0, 0, 39, '3317'),
	(377, 1, 0, -50331, 3319, 0, 0, 39, '3318'),
	(377, 1, 0, -50331, 3320, 0, 0, 39, '3319'),
	(377, 1, 0, -50331, 3321, 0, 0, 39, '3320'),
	(377, 1, 0, -50331, 3322, 0, 0, 39, '3321'),
	(377, 1, 0, -50331, 3323, 0, 0, 39, '3322'),
	(377, 1, 0, -50331, 3324, 0, 0, 39, '3323'),
	(377, 1, 0, -50331, 3325, 0, 0, 39, '3324'),
	(377, 1, 0, -50331, 3326, 0, 0, 39, '3325'),
	(377, 1, 0, -50331, 3327, 0, 0, 39, '3326'),
	(377, 1, 0, -50331, 3328, 0, 0, 39, '3327'),
	(377, 1, 0, -50331, 3329, 0, 0, 39, '3328'),
	(377, 1, 0, -50331, 3330, 0, 0, 39, '3329'),
	(377, 1, 0, -50331, 3331, 0, 0, 39, '3330'),
	(377, 1, 0, -50331, 3332, 0, 0, 39, '3331'),
	(377, 1, 0, -50331, 3333, 0, 0, 39, '3332'),
	(377, 1, 0, -50331, 3334, 0, 0, 39, '3333'),
	(377, 1, 0, -50331, 3335, 0, 0, 39, '3334'),
	(377, 1, 0, -50331, 3336, 0, 0, 39, '3335'),
	(377, 1, 0, -50331, 3337, 0, 0, 39, '3336'),
	(377, 1, 0, -50331, 3338, 0, 0, 39, '3337'),
	(377, 1, 0, -50331, 3339, 0, 0, 39, '3338'),
	(377, 1, 0, -50331, 3340, 0, 0, 39, '3339'),
	(377, 1, 0, -50331, 3341, 0, 0, 39, '3340'),
	(377, 1, 0, -50331, 3342, 0, 0, 39, '3341'),
	(377, 1, 0, -50331, 3343, 0, 0, 39, '3342'),
	(377, 1, 0, -50331, 3344, 0, 0, 39, '3343'),
	(377, 1, 0, -50331, 3345, 0, 0, 39, '3344'),
	(377, 1, 0, -50331, 3346, 0, 0, 39, '3345'),
	(377, 1, 0, -50331, 3347, 0, 0, 39, '3346'),
	(377, 1, 0, -50331, 3348, 0, 0, 39, '3347'),
	(377, 1, 0, -50331, 3349, 0, 0, 39, '3348'),
	(377, 1, 0, -50331, 3350, 0, 0, 39, '3349'),
	(377, 1, 0, -50331, 3351, 0, 0, 39, '3350'),
	(377, 1, 0, -50331, 3352, 0, 0, 39, '3351'),
	(377, 1, 0, -50331, 3353, 0, 0, 39, '3352'),
	(377, 1, 0, -50331, 3354, 0, 0, 39, '3353'),
	(377, 1, 0, -50331, 3355, 0, 0, 39, '3354'),
	(377, 1, 0, -50331, 3356, 0, 0, 39, '3355'),
	(377, 1, 0, -50331, 3357, 0, 0, 39, '3356'),
	(377, 1, 0, -50331, 3358, 0, 0, 39, '3357'),
	(377, 1, 0, -50331, 3359, 0, 0, 39, '3358'),
	(377, 1, 0, -50331, 3360, 0, 0, 39, '3359'),
	(377, 1, 0, -50331, 3361, 0, 0, 39, '3360'),
	(377, 1, 0, -50331, 3362, 0, 0, 39, '3361'),
	(377, 1, 0, -50331, 3363, 0, 0, 39, '3362'),
	(377, 1, 0, -50331, 3364, 0, 0, 39, '3363'),
	(377, 1, 0, -50331, 3365, 0, 0, 39, '3364'),
	(377, 1, 0, -50331, 3366, 0, 0, 39, '3365'),
	(377, 1, 0, -50331, 3367, 0, 0, 39, '3366'),
	(377, 1, 0, -50331, 3368, 0, 0, 39, '3367'),
	(377, 1, 0, -50331, 3369, 0, 0, 39, '3368'),
	(377, 1, 0, -50331, 3370, 0, 0, 39, '3369'),
	(377, 1, 0, -50331, 3371, 0, 0, 39, '3370'),
	(377, 1, 0, -50331, 3372, 0, 0, 39, '3371'),
	(377, 1, 0, -50331, 3373, 0, 0, 39, '3372'),
	(377, 1, 0, -50331, 3374, 0, 0, 39, '3373'),
	(377, 1, 0, -50331, 3375, 0, 0, 39, '3374'),
	(377, 1, 0, -50331, 3376, 0, 0, 39, '3375'),
	(377, 1, 0, -50331, 3377, 0, 0, 39, '3376'),
	(377, 1, 0, -50331, 3378, 0, 0, 39, '3377'),
	(377, 1, 0, -50331, 3379, 0, 0, 39, '3378'),
	(377, 1, 0, -50331, 3380, 0, 0, 39, '3379'),
	(377, 1, 0, -50331, 3381, 0, 0, 39, '3380'),
	(377, 1, 0, -50331, 3382, 0, 0, 39, '3381'),
	(377, 1, 0, -50331, 3383, 0, 0, 39, '3382'),
	(377, 1, 0, -50331, 3384, 0, 0, 39, '3383'),
	(377, 1, 0, -50331, 3385, 0, 0, 39, '3384'),
	(377, 1, 0, -50331, 3386, 0, 0, 39, '3385'),
	(377, 1, 0, -50331, 3387, 0, 0, 39, '3386'),
	(377, 1, 0, -50331, 3388, 0, 0, 39, '3387'),
	(377, 1, 0, -50331, 3389, 0, 0, 39, '3388'),
	(377, 1, 0, -50331, 3390, 0, 0, 39, '3389'),
	(377, 1, 0, -50331, 3391, 0, 0, 39, '3390'),
	(377, 1, 0, -50331, 3392, 0, 0, 39, '3391'),
	(377, 1, 0, -50331, 3393, 0, 0, 39, '3392'),
	(377, 1, 0, -50331, 3394, 0, 0, 39, '3393'),
	(377, 1, 0, -50331, 3395, 0, 0, 39, '3394'),
	(377, 1, 0, -50331, 3396, 0, 0, 39, '3395'),
	(377, 1, 0, -50331, 3397, 0, 0, 39, '3396'),
	(377, 1, 0, -50331, 3398, 0, 0, 39, '3397'),
	(377, 1, 0, -50331, 3399, 0, 0, 39, '3398'),
	(377, 1, 0, -50331, 3400, 0, 0, 39, '3399'),
	(377, 1, 0, -50331, 3401, 0, 0, 39, '3400'),
	(377, 1, 0, -50331, 3402, 0, 0, 39, '3401'),
	(377, 1, 0, -50331, 3403, 0, 0, 39, '3402'),
	(377, 1, 0, -50331, 3404, 0, 0, 39, '3403'),
	(377, 1, 0, -50331, 3405, 0, 0, 39, '3404'),
	(377, 1, 0, -50331, 3406, 0, 0, 39, '3405'),
	(377, 1, 0, -50331, 3407, 0, 0, 39, '3406'),
	(377, 1, 0, -50331, 3408, 0, 0, 39, '3407'),
	(377, 1, 0, -50331, 3409, 0, 0, 39, '3408'),
	(377, 1, 0, -50331, 3410, 0, 0, 39, '3409'),
	(377, 1, 0, -50331, 3411, 0, 0, 39, '3410'),
	(377, 1, 0, -50331, 3412, 0, 0, 39, '3411'),
	(377, 1, 0, -50331, 3413, 0, 0, 39, '3412'),
	(377, 1, 0, -50331, 3414, 0, 0, 39, '3413'),
	(377, 1, 0, -50331, 3415, 0, 0, 39, '3414'),
	(377, 1, 0, -50331, 3416, 0, 0, 39, '3415'),
	(377, 1, 0, -50331, 3417, 0, 0, 39, '3416'),
	(377, 1, 0, -50331, 3418, 0, 0, 39, '3417'),
	(377, 1, 0, -50331, 3419, 0, 0, 39, '3418'),
	(377, 1, 0, -50331, 3420, 0, 0, 39, '3419'),
	(377, 1, 0, -50331, 3421, 0, 0, 39, '3420'),
	(377, 1, 0, -50331, 3422, 0, 0, 39, '3421'),
	(377, 1, 0, -50331, 3423, 0, 0, 39, '3422'),
	(377, 1, 0, -50331, 3424, 0, 0, 39, '3423'),
	(377, 1, 0, -50331, 3425, 0, 0, 39, '3424'),
	(377, 1, 0, -50331, 3426, 0, 0, 39, '3425'),
	(377, 1, 0, -50331, 3427, 0, 0, 39, '3426'),
	(377, 1, 0, -50331, 3428, 0, 0, 39, '3427'),
	(377, 1, 0, -50331, 3429, 0, 0, 39, '3428'),
	(377, 1, 0, -50331, 3430, 0, 0, 39, '3429'),
	(377, 1, 0, -50331, 3431, 0, 0, 39, '3430'),
	(377, 1, 0, -50331, 3432, 0, 0, 39, '3431'),
	(377, 1, 0, -50331, 3433, 0, 0, 39, '3432'),
	(377, 1, 0, -50331, 3434, 0, 0, 39, '3433'),
	(377, 1, 0, -50331, 3435, 0, 0, 39, '3434'),
	(377, 1, 0, -50331, 3436, 0, 0, 39, '3435'),
	(377, 1, 0, -50331, 3437, 0, 0, 39, '3436'),
	(377, 1, 0, -50331, 3438, 0, 0, 39, '3437'),
	(377, 1, 0, -50331, 3439, 0, 0, 39, '3438'),
	(377, 1, 0, -50331, 3440, 0, 0, 39, '3439'),
	(377, 1, 0, -50331, 3441, 0, 0, 39, '3440'),
	(377, 1, 0, -50331, 3442, 0, 0, 39, '3441'),
	(377, 1, 0, -50331, 3443, 0, 0, 39, '3442'),
	(377, 1, 0, -50331, 3444, 0, 0, 39, '3443'),
	(377, 1, 0, -50331, 3445, 0, 0, 39, '3444'),
	(377, 1, 0, -50331, 3446, 0, 0, 39, '3445'),
	(377, 1, 0, -50331, 3447, 0, 0, 39, '3446'),
	(377, 1, 0, -50331, 3448, 0, 0, 39, '3447'),
	(377, 1, 0, -50331, 3449, 0, 0, 39, '3448'),
	(377, 1, 0, -50331, 3450, 0, 0, 39, '3449'),
	(377, 1, 0, -50331, 3451, 0, 0, 39, '3450'),
	(377, 1, 0, -50331, 3452, 0, 0, 39, '3451'),
	(377, 1, 0, -50331, 3453, 0, 0, 39, '3452'),
	(377, 1, 0, -50331, 3454, 0, 0, 39, '3453'),
	(377, 1, 0, -50331, 3455, 0, 0, 39, '3454'),
	(377, 1, 0, -50331, 3456, 0, 0, 39, '3455'),
	(377, 1, 0, -50331, 3457, 0, 0, 39, '3456'),
	(377, 1, 0, -50331, 3458, 0, 0, 39, '3457'),
	(377, 1, 0, -50331, 3459, 0, 0, 39, '3458'),
	(377, 1, 0, -50331, 3460, 0, 0, 39, '3459'),
	(377, 1, 0, -50331, 3461, 0, 0, 39, '3460'),
	(377, 1, 0, -50331, 3462, 0, 0, 39, '3461'),
	(377, 1, 0, -50331, 3463, 0, 0, 39, '3462'),
	(377, 1, 0, -50331, 3464, 0, 0, 39, '3463'),
	(377, 1, 0, -50331, 3465, 0, 0, 39, '3464'),
	(377, 1, 0, -50331, 3466, 0, 0, 39, '3465'),
	(377, 1, 0, -50331, 3467, 0, 0, 39, '3466'),
	(377, 1, 0, -50331, 3468, 0, 0, 39, '3467'),
	(377, 1, 0, -50331, 3469, 0, 0, 39, '3468'),
	(377, 1, 0, -50331, 3470, 0, 0, 39, '3469'),
	(377, 1, 0, -50331, 3471, 0, 0, 39, '3470'),
	(377, 1, 0, -50331, 3472, 0, 0, 39, '3471'),
	(377, 1, 0, -50331, 3473, 0, 0, 39, '3472'),
	(377, 1, 0, -50331, 3474, 0, 0, 39, '3473'),
	(377, 1, 0, -50331, 3475, 0, 0, 39, '3474'),
	(377, 1, 0, -50331, 3476, 0, 0, 39, '3475'),
	(377, 1, 0, -50331, 3477, 0, 0, 39, '3476'),
	(377, 1, 0, -50331, 3478, 0, 0, 39, '3477'),
	(377, 1, 0, -50331, 3479, 0, 0, 39, '3478'),
	(377, 1, 0, -50331, 3480, 0, 0, 39, '3479'),
	(377, 1, 0, -50331, 3481, 0, 0, 39, '3480'),
	(377, 1, 0, -50331, 3482, 0, 0, 39, '3481'),
	(377, 1, 0, -50331, 3483, 0, 0, 39, '3482'),
	(377, 1, 0, -50331, 3484, 0, 0, 39, '3483'),
	(377, 1, 0, -50331, 3485, 0, 0, 39, '3484'),
	(377, 1, 0, -50331, 3486, 0, 0, 39, '3485'),
	(377, 1, 0, -50331, 3487, 0, 0, 39, '3486'),
	(377, 1, 0, -50331, 3488, 0, 0, 39, '3487'),
	(377, 1, 0, -50331, 3489, 0, 0, 39, '3488'),
	(377, 1, 0, -50331, 3490, 0, 0, 39, '3489'),
	(377, 1, 0, -50331, 3491, 0, 0, 39, '3490'),
	(377, 1, 0, -50331, 3492, 0, 0, 39, '3491'),
	(377, 1, 0, -50331, 3493, 0, 0, 39, '3492'),
	(377, 1, 0, -50331, 3494, 0, 0, 39, '3493'),
	(377, 1, 0, -50331, 3495, 0, 0, 39, '3494'),
	(377, 1, 0, -50331, 3496, 0, 0, 39, '3495'),
	(377, 1, 0, -50331, 3497, 0, 0, 39, '3496'),
	(377, 1, 0, -50331, 3498, 0, 0, 39, '3497'),
	(377, 1, 0, -50331, 3499, 0, 0, 39, '3498'),
	(377, 1, 0, -50331, 3500, 0, 0, 39, '3499'),
	(377, 1, 0, -50331, 3501, 0, 0, 39, '3500'),
	(377, 1, 0, -50331, 3502, 0, 0, 39, '3501'),
	(377, 1, 0, -50331, 3503, 0, 0, 39, '3502'),
	(377, 1, 0, -50331, 3504, 0, 0, 39, '3503'),
	(377, 1, 0, -50331, 3505, 0, 0, 39, '3504'),
	(377, 1, 0, -50331, 3506, 0, 0, 39, '3505'),
	(377, 1, 0, -50331, 3507, 0, 0, 39, '3506'),
	(377, 1, 0, -50331, 3508, 0, 0, 39, '3507'),
	(377, 1, 0, -50331, 3509, 0, 0, 39, '3508'),
	(377, 1, 0, -50331, 3510, 0, 0, 39, '3509'),
	(377, 1, 0, -50331, 3511, 0, 0, 39, '3510'),
	(377, 1, 0, -50331, 3512, 0, 0, 39, '3511'),
	(377, 1, 0, -50331, 3513, 0, 0, 39, '3512'),
	(377, 1, 0, -50331, 3514, 0, 0, 39, '3513'),
	(377, 1, 0, -50331, 3515, 0, 0, 39, '3514'),
	(377, 1, 0, -50331, 3516, 0, 0, 39, '3515'),
	(377, 1, 0, -50331, 3517, 0, 0, 39, '3516'),
	(377, 1, 0, -50331, 3518, 0, 0, 39, '3517'),
	(377, 1, 0, -50331, 3519, 0, 0, 39, '3518'),
	(377, 1, 0, -50331, 3520, 0, 0, 39, '3519'),
	(377, 1, 0, -50331, 3521, 0, 0, 39, '3520'),
	(377, 1, 0, -50331, 3522, 0, 0, 39, '3521'),
	(377, 1, 0, -50331, 3523, 0, 0, 39, '3522'),
	(377, 1, 0, -50331, 3524, 0, 0, 39, '3523'),
	(377, 1, 0, -50331, 3525, 0, 0, 39, '3524'),
	(377, 1, 0, -50331, 3526, 0, 0, 39, '3525'),
	(377, 1, 0, -50331, 3527, 0, 0, 39, '3526'),
	(377, 1, 0, -50331, 3528, 0, 0, 39, '3527'),
	(377, 1, 0, -50331, 3529, 0, 0, 39, '3528'),
	(377, 1, 0, -50331, 3530, 0, 0, 39, '3529'),
	(377, 1, 0, -50331, 3531, 0, 0, 39, '3530'),
	(377, 1, 0, -50331, 3532, 0, 0, 39, '3531'),
	(377, 1, 0, -50331, 3533, 0, 0, 39, '3532'),
	(377, 1, 0, -50331, 3534, 0, 0, 39, '3533'),
	(377, 1, 0, -50331, 3535, 0, 0, 39, '3534'),
	(377, 1, 0, -50331, 3536, 0, 0, 39, '3535'),
	(377, 1, 0, -50331, 3537, 0, 0, 39, '3536'),
	(377, 1, 0, -50331, 3538, 0, 0, 39, '3537'),
	(377, 1, 0, -50331, 3539, 0, 0, 39, '3538'),
	(377, 1, 0, -50331, 3540, 0, 0, 39, '3539'),
	(377, 1, 0, -50331, 3541, 0, 0, 39, '3540'),
	(377, 1, 0, -50331, 3542, 0, 0, 39, '3541'),
	(377, 1, 0, -50331, 3543, 0, 0, 39, '3542'),
	(377, 1, 0, -50331, 3544, 0, 0, 39, '3543'),
	(377, 1, 0, -50331, 3545, 0, 0, 39, '3544'),
	(377, 1, 0, -50331, 3546, 0, 0, 39, '3545'),
	(377, 1, 0, -50331, 3547, 0, 0, 39, '3546'),
	(377, 1, 0, -50331, 3548, 0, 0, 39, '3547'),
	(377, 1, 0, -50331, 3549, 0, 0, 39, '3548'),
	(377, 1, 0, -50331, 3550, 0, 0, 39, '3549'),
	(377, 1, 0, -50331, 3551, 0, 0, 39, '3550'),
	(377, 1, 0, -50331, 3552, 0, 0, 39, '3551'),
	(377, 1, 0, -50331, 3553, 0, 0, 39, '3552'),
	(377, 1, 0, -50331, 3554, 0, 0, 39, '3553'),
	(377, 1, 0, -50331, 3555, 0, 0, 39, '3554'),
	(377, 1, 0, -50331, 3556, 0, 0, 39, '3555'),
	(377, 1, 0, -50331, 3557, 0, 0, 39, '3556'),
	(377, 1, 0, -50331, 3558, 0, 0, 39, '3557'),
	(377, 1, 0, -50331, 3559, 0, 0, 39, '3558'),
	(377, 1, 0, -50331, 3560, 0, 0, 39, '3559'),
	(377, 1, 0, -50331, 3561, 0, 0, 39, '3560'),
	(377, 1, 0, -50331, 3562, 0, 0, 39, '3561'),
	(377, 1, 0, -50331, 3563, 0, 0, 39, '3562'),
	(377, 1, 0, -50331, 3564, 0, 0, 39, '3563'),
	(377, 1, 0, -50331, 3565, 0, 0, 39, '3564'),
	(377, 1, 0, -50331, 3566, 0, 0, 39, '3565'),
	(377, 1, 0, -50331, 3567, 0, 0, 39, '3566'),
	(377, 1, 0, -50331, 3568, 0, 0, 39, '3567'),
	(377, 1, 0, -50331, 3569, 0, 0, 39, '3568'),
	(377, 1, 0, -50331, 3570, 0, 0, 39, '3569'),
	(377, 1, 0, -50331, 3571, 0, 0, 39, '3570'),
	(377, 1, 0, -50331, 3572, 0, 0, 39, '3571'),
	(377, 1, 0, -50331, 3573, 0, 0, 39, '3572'),
	(377, 1, 0, -50331, 3574, 0, 0, 39, '3573'),
	(377, 1, 0, -50331, 3575, 0, 0, 39, '3574'),
	(377, 1, 0, -50331, 3576, 0, 0, 39, '3575'),
	(377, 1, 0, -50331, 3577, 0, 0, 39, '3576'),
	(377, 1, 0, -50331, 3578, 0, 0, 39, '3577'),
	(377, 1, 0, -50331, 3579, 0, 0, 39, '3578'),
	(377, 1, 0, -50331, 3580, 0, 0, 39, '3579'),
	(377, 1, 0, -50331, 3581, 0, 0, 39, '3580'),
	(377, 1, 0, -50331, 3582, 0, 0, 39, '3581'),
	(377, 1, 0, -50331, 3583, 0, 0, 39, '3582'),
	(377, 1, 0, -50331, 3584, 0, 0, 39, '3583'),
	(377, 1, 0, -50331, 3585, 0, 0, 39, '3584'),
	(377, 1, 0, -50331, 3586, 0, 0, 39, '3585'),
	(377, 1, 0, -50331, 3587, 0, 0, 39, '3586'),
	(377, 1, 0, -50331, 3588, 0, 0, 39, '3587'),
	(377, 1, 0, -50331, 3589, 0, 0, 39, '3588'),
	(377, 1, 0, -50331, 3590, 0, 0, 39, '3589'),
	(377, 1, 0, -50331, 3591, 0, 0, 39, '3590'),
	(377, 1, 0, -50331, 3592, 0, 0, 39, '3591'),
	(377, 1, 0, -50331, 3593, 0, 0, 39, '3592'),
	(377, 1, 0, -50331, 3594, 0, 0, 39, '3593'),
	(377, 1, 0, -50331, 3595, 0, 0, 39, '3594'),
	(377, 1, 0, -50331, 3596, 0, 0, 39, '3595'),
	(377, 1, 0, -50331, 3597, 0, 0, 39, '3596'),
	(377, 1, 0, -50331, 3598, 0, 0, 39, '3597'),
	(377, 1, 0, -50331, 3599, 0, 0, 39, '3598'),
	(377, 1, 0, -50331, 3600, 0, 0, 39, '3599'),
	(377, 1, 0, -50331, 3601, 0, 0, 39, '3600'),
	(377, 1, 0, -50331, 3602, 0, 0, 39, '3601'),
	(377, 1, 0, -50331, 3603, 0, 0, 39, '3602'),
	(377, 1, 0, -50331, 3604, 0, 0, 39, '3603'),
	(377, 1, 0, -50331, 3605, 0, 0, 39, '3604'),
	(377, 1, 0, -50331, 3606, 0, 0, 39, '3605'),
	(377, 1, 0, -50331, 3607, 0, 0, 39, '3606'),
	(377, 1, 0, -50331, 3608, 0, 0, 39, '3607'),
	(377, 1, 0, -50331, 3609, 0, 0, 39, '3608'),
	(377, 1, 0, -50331, 3610, 0, 0, 39, '3609'),
	(377, 1, 0, -50331, 3611, 0, 0, 39, '3610'),
	(377, 1, 0, -50331, 3612, 0, 0, 39, '3611'),
	(377, 1, 0, -50331, 3613, 0, 0, 39, '3612'),
	(377, 1, 0, -50331, 3614, 0, 0, 39, '3613'),
	(377, 1, 0, -50331, 3615, 0, 0, 39, '3614'),
	(377, 1, 0, -50331, 3616, 0, 0, 39, '3615'),
	(377, 1, 0, -50331, 3617, 0, 0, 39, '3616'),
	(377, 1, 0, -50331, 3618, 0, 0, 39, '3617'),
	(377, 1, 0, -50331, 3619, 0, 0, 39, '3618'),
	(377, 1, 0, -50331, 3620, 0, 0, 39, '3619'),
	(377, 1, 0, -50331, 3621, 0, 0, 39, '3620'),
	(377, 1, 0, -50331, 3622, 0, 0, 39, '3621'),
	(377, 1, 0, -50331, 3623, 0, 0, 39, '3622'),
	(377, 1, 0, -50331, 3624, 0, 0, 39, '3623'),
	(377, 1, 0, -50331, 3625, 0, 0, 39, '3624'),
	(377, 1, 0, -50331, 3626, 0, 0, 39, '3625'),
	(377, 1, 0, -50331, 3627, 0, 0, 39, '3626'),
	(377, 1, 0, -50331, 3628, 0, 0, 39, '3627'),
	(377, 1, 0, -50331, 3629, 0, 0, 39, '3628'),
	(377, 1, 0, -50331, 3630, 0, 0, 39, '3629'),
	(377, 1, 0, -50331, 3631, 0, 0, 39, '3630'),
	(377, 1, 0, -50331, 3632, 0, 0, 39, '3631'),
	(377, 1, 0, -50331, 3633, 0, 0, 39, '3632'),
	(377, 1, 0, -50331, 3634, 0, 0, 39, '3633'),
	(377, 1, 0, -50331, 3635, 0, 0, 39, '3634'),
	(377, 1, 0, -50331, 3636, 0, 0, 39, '3635'),
	(377, 1, 0, -50331, 3637, 0, 0, 39, '3636'),
	(377, 1, 0, -50331, 3638, 0, 0, 39, '3637'),
	(377, 1, 0, -50331, 3639, 0, 0, 39, '3638'),
	(377, 1, 0, -50331, 3640, 0, 0, 39, '3639'),
	(377, 1, 0, -50331, 3641, 0, 0, 39, '3640'),
	(377, 1, 0, -50331, 3642, 0, 0, 39, '3641'),
	(377, 1, 0, -50331, 3643, 0, 0, 39, '3642'),
	(377, 1, 0, -50331, 3644, 0, 0, 39, '3643'),
	(377, 1, 0, -50331, 3645, 0, 0, 39, '3644'),
	(377, 1, 0, -50331, 3646, 0, 0, 39, '3645'),
	(377, 1, 0, -50331, 3647, 0, 0, 39, '3646'),
	(377, 1, 0, -50331, 3648, 0, 0, 39, '3647'),
	(377, 1, 0, -50331, 3649, 0, 0, 39, '3648'),
	(377, 1, 0, -50331, 3650, 0, 0, 39, '3649'),
	(377, 1, 0, -50331, 3651, 0, 0, 39, '3650'),
	(377, 1, 0, -50331, 3652, 0, 0, 39, '3651'),
	(377, 1, 0, -50331, 3653, 0, 0, 39, '3652'),
	(377, 1, 0, -50331, 3654, 0, 0, 39, '3653'),
	(377, 1, 0, -50331, 3655, 0, 0, 39, '3654'),
	(377, 1, 0, -50331, 3656, 0, 0, 39, '3655'),
	(377, 1, 0, -50331, 3657, 0, 0, 39, '3656'),
	(377, 1, 0, -50331, 3658, 0, 0, 39, '3657'),
	(377, 1, 0, -50331, 3659, 0, 0, 39, '3658'),
	(377, 1, 0, -50331, 3660, 0, 0, 39, '3659'),
	(377, 1, 0, -50331, 3661, 0, 0, 39, '3660'),
	(377, 1, 0, -50331, 3662, 0, 0, 39, '3661'),
	(377, 1, 0, -50331, 3663, 0, 0, 39, '3662'),
	(377, 1, 0, -50331, 3664, 0, 0, 39, '3663'),
	(377, 1, 0, -50331, 3665, 0, 0, 39, '3664'),
	(377, 1, 0, -50331, 3666, 0, 0, 39, '3665'),
	(377, 1, 0, -50331, 3667, 0, 0, 39, '3666'),
	(377, 1, 0, -50331, 3668, 0, 0, 39, '3667'),
	(377, 1, 0, -50331, 3669, 0, 0, 39, '3668'),
	(377, 1, 0, -50331, 3670, 0, 0, 39, '3669'),
	(377, 1, 0, -50331, 3671, 0, 0, 39, '3670'),
	(377, 1, 0, -50331, 3672, 0, 0, 39, '3671'),
	(377, 1, 0, -50331, 3673, 0, 0, 39, '3672'),
	(377, 1, 0, -50331, 3674, 0, 0, 39, '3673'),
	(377, 1, 0, -50331, 3675, 0, 0, 39, '3674'),
	(377, 1, 0, -50331, 3676, 0, 0, 39, '3675'),
	(377, 1, 0, -50331, 3677, 0, 0, 39, '3676'),
	(377, 1, 0, -50331, 3678, 0, 0, 39, '3677'),
	(377, 1, 0, -50331, 3679, 0, 0, 39, '3678'),
	(377, 1, 0, -50331, 3680, 0, 0, 39, '3679'),
	(377, 1, 0, -50331, 3681, 0, 0, 39, '3680'),
	(377, 1, 0, -50331, 3682, 0, 0, 39, '3681'),
	(377, 1, 0, -50331, 3683, 0, 0, 39, '3682'),
	(377, 1, 0, -50331, 3684, 0, 0, 39, '3683'),
	(377, 1, 0, -50331, 3685, 0, 0, 39, '3684'),
	(377, 1, 0, -50331, 3686, 0, 0, 39, '3685'),
	(377, 1, 0, -50331, 3687, 0, 0, 39, '3686'),
	(377, 1, 0, -50331, 3688, 0, 0, 39, '3687'),
	(377, 1, 0, -50331, 3689, 0, 0, 39, '3688'),
	(377, 1, 0, -50331, 3690, 0, 0, 39, '3689'),
	(377, 1, 0, -50331, 3691, 0, 0, 39, '3690'),
	(377, 1, 0, -50331, 3692, 0, 0, 39, '3691'),
	(377, 1, 0, -50331, 3693, 0, 0, 39, '3692'),
	(377, 1, 0, -50331, 3694, 0, 0, 39, '3693'),
	(377, 1, 0, -50331, 3695, 0, 0, 39, '3694'),
	(377, 1, 0, -50331, 3696, 0, 0, 39, '3695'),
	(377, 1, 0, -50331, 3697, 0, 0, 39, '3696'),
	(377, 1, 0, -50331, 3698, 0, 0, 39, '3697'),
	(377, 1, 0, -50331, 3699, 0, 0, 39, '3698'),
	(377, 1, 0, -50331, 3700, 0, 0, 39, '3699'),
	(377, 1, 0, -50331, 3701, 0, 0, 39, '3700'),
	(377, 1, 0, -50331, 3702, 0, 0, 39, '3701'),
	(377, 1, 0, -50331, 3703, 0, 0, 39, '3702'),
	(377, 1, 0, -50331, 3704, 0, 0, 39, '3703'),
	(377, 1, 0, -50331, 3705, 0, 0, 39, '3704'),
	(377, 1, 0, -50331, 3706, 0, 0, 39, '3705'),
	(377, 1, 0, -50331, 3707, 0, 0, 39, '3706'),
	(377, 1, 0, -50331, 3708, 0, 0, 39, '3707'),
	(377, 1, 0, -50331, 3709, 0, 0, 39, '3708'),
	(377, 1, 0, -50331, 3710, 0, 0, 39, '3709'),
	(377, 1, 0, -50331, 3711, 0, 0, 39, '3710'),
	(377, 1, 0, -50331, 3712, 0, 0, 39, '3711'),
	(377, 1, 0, -50331, 3713, 0, 0, 39, '3712'),
	(377, 1, 0, -50331, 3714, 0, 0, 39, '3713'),
	(377, 1, 0, -50331, 3715, 0, 0, 39, '3714'),
	(377, 1, 0, -50331, 3716, 0, 0, 39, '3715'),
	(377, 1, 0, -50331, 3717, 0, 0, 39, '3716'),
	(377, 1, 0, -50331, 3718, 0, 0, 39, '3717'),
	(377, 1, 0, -50331, 3719, 0, 0, 39, '3718'),
	(377, 1, 0, -50331, 3720, 0, 0, 39, '3719'),
	(377, 1, 0, -50331, 3721, 0, 0, 39, '3720'),
	(377, 1, 0, -50331, 3722, 0, 0, 39, '3721'),
	(377, 1, 0, -50331, 3723, 0, 0, 39, '3722'),
	(377, 1, 0, -50331, 3724, 0, 0, 39, '3723'),
	(377, 1, 0, -50331, 3725, 0, 0, 39, '3724'),
	(377, 1, 0, -50331, 3726, 0, 0, 39, '3725'),
	(377, 1, 0, -50331, 3727, 0, 0, 39, '3726'),
	(377, 1, 0, -50331, 3728, 0, 0, 39, '3727'),
	(377, 1, 0, -50331, 3729, 0, 0, 39, '3728'),
	(377, 1, 0, -50331, 3730, 0, 0, 39, '3729'),
	(377, 1, 0, -50331, 3731, 0, 0, 39, '3730'),
	(377, 1, 0, -50331, 3732, 0, 0, 39, '3731'),
	(377, 1, 0, -50331, 3733, 0, 0, 39, '3732'),
	(377, 1, 0, -50331, 3734, 0, 0, 39, '3733'),
	(377, 1, 0, -50331, 3735, 0, 0, 39, '3734'),
	(377, 1, 0, -50331, 3736, 0, 0, 39, '3735'),
	(377, 1, 0, -50331, 3737, 0, 0, 39, '3736'),
	(377, 1, 0, -50331, 3738, 0, 0, 39, '3737'),
	(377, 1, 0, -50331, 3739, 0, 0, 39, '3738'),
	(377, 1, 0, -50331, 3740, 0, 0, 39, '3739'),
	(377, 1, 0, -50331, 3741, 0, 0, 39, '3740'),
	(377, 1, 0, -50331, 3742, 0, 0, 39, '3741'),
	(377, 1, 0, -50331, 3743, 0, 0, 39, '3742'),
	(377, 1, 0, -50331, 3744, 0, 0, 39, '3743'),
	(377, 1, 0, -50331, 3745, 0, 0, 39, '3744'),
	(377, 1, 0, -50331, 3746, 0, 0, 39, '3745'),
	(377, 1, 0, -50331, 3747, 0, 0, 39, '3746'),
	(377, 1, 0, -50331, 3748, 0, 0, 39, '3747'),
	(377, 1, 0, -50331, 3749, 0, 0, 39, '3748'),
	(377, 1, 0, -50331, 3750, 0, 0, 39, '3749'),
	(377, 1, 0, -50331, 3751, 0, 0, 39, '3750'),
	(377, 1, 0, -50331, 3752, 0, 0, 39, '3751'),
	(377, 1, 0, -50331, 3753, 0, 0, 39, '3752'),
	(377, 1, 0, -50331, 3754, 0, 0, 39, '3753'),
	(377, 1, 0, -50331, 3755, 0, 0, 39, '3754'),
	(377, 1, 0, -50331, 3756, 0, 0, 39, '3755'),
	(377, 1, 0, -50331, 3757, 0, 0, 39, '3756'),
	(377, 1, 0, -50331, 3758, 0, 0, 39, '3757'),
	(377, 1, 0, -50331, 3759, 0, 0, 39, '3758'),
	(377, 1, 0, -50331, 3760, 0, 0, 39, '3759'),
	(377, 1, 0, -50331, 3761, 0, 0, 39, '3760'),
	(377, 1, 0, -50331, 3762, 0, 0, 39, '3761'),
	(377, 1, 0, -50331, 3763, 0, 0, 39, '3762'),
	(377, 1, 0, -50331, 3764, 0, 0, 39, '3763'),
	(377, 1, 0, -50331, 3765, 0, 0, 39, '3764'),
	(377, 1, 0, -50331, 3766, 0, 0, 39, '3765'),
	(377, 1, 0, -50331, 3767, 0, 0, 39, '3766'),
	(377, 1, 0, -50331, 3768, 0, 0, 39, '3767'),
	(377, 1, 0, -50331, 3769, 0, 0, 39, '3768'),
	(377, 1, 0, -50331, 3770, 0, 0, 39, '3769'),
	(377, 1, 0, -50331, 3771, 0, 0, 39, '3770'),
	(377, 1, 0, -50331, 3772, 0, 0, 39, '3771'),
	(377, 1, 0, -50331, 3773, 0, 0, 39, '3772'),
	(377, 1, 0, -50331, 3774, 0, 0, 39, '3773'),
	(377, 1, 0, -50331, 3775, 0, 0, 39, '3774'),
	(377, 1, 0, -50331, 3776, 0, 0, 39, '3775'),
	(377, 1, 0, -50331, 3777, 0, 0, 39, '3776'),
	(377, 1, 0, -50331, 3778, 0, 0, 39, '3777'),
	(377, 1, 0, -50331, 3779, 0, 0, 39, '3778'),
	(377, 1, 0, -50331, 3780, 0, 0, 39, '3779'),
	(377, 1, 0, -50331, 3781, 0, 0, 39, '3780'),
	(377, 1, 0, -50331, 3782, 0, 0, 39, '3781'),
	(377, 1, 0, -50331, 3783, 0, 0, 39, '3782'),
	(377, 1, 0, -50331, 3784, 0, 0, 39, '3783'),
	(377, 1, 0, -50331, 3785, 0, 0, 39, '3784'),
	(377, 1, 0, -50331, 3786, 0, 0, 39, '3785'),
	(377, 1, 0, -50331, 3787, 0, 0, 39, '3786'),
	(377, 1, 0, -50331, 3788, 0, 0, 39, '3787'),
	(377, 1, 0, -50331, 3789, 0, 0, 39, '3788'),
	(377, 1, 0, -50331, 3790, 0, 0, 39, '3789'),
	(377, 1, 0, -50331, 3791, 0, 0, 39, '3790'),
	(377, 1, 0, -50331, 3792, 0, 0, 39, '3791'),
	(377, 1, 0, -50331, 3793, 0, 0, 39, '3792'),
	(377, 1, 0, -50331, 3794, 0, 0, 39, '3793'),
	(377, 1, 0, -50331, 3795, 0, 0, 39, '3794'),
	(377, 1, 0, -50331, 3796, 0, 0, 39, '3795'),
	(377, 1, 0, -50331, 3797, 0, 0, 39, '3796'),
	(377, 1, 0, -50331, 3798, 0, 0, 39, '3797'),
	(377, 1, 0, -50331, 3799, 0, 0, 39, '3798'),
	(377, 1, 0, -50331, 3800, 0, 0, 39, '3799'),
	(377, 1, 0, -50331, 3801, 0, 0, 39, '3800'),
	(377, 1, 0, -50331, 3802, 0, 0, 39, '3801'),
	(377, 1, 0, -50331, 3803, 0, 0, 39, '3802'),
	(377, 1, 0, -50331, 3804, 0, 0, 39, '3803'),
	(377, 1, 0, -50331, 3805, 0, 0, 39, '3804'),
	(377, 1, 0, -50331, 3806, 0, 0, 39, '3805'),
	(377, 1, 0, -50331, 3807, 0, 0, 39, '3806'),
	(377, 1, 0, -50331, 3808, 0, 0, 39, '3807'),
	(377, 1, 0, -50331, 3809, 0, 0, 39, '3808'),
	(377, 1, 0, -50331, 3810, 0, 0, 39, '3809'),
	(377, 1, 0, -50331, 3811, 0, 0, 39, '3810'),
	(377, 1, 0, -50331, 3812, 0, 0, 39, '3811'),
	(377, 1, 0, -50331, 3813, 0, 0, 39, '3812'),
	(377, 1, 0, -50331, 3814, 0, 0, 39, '3813'),
	(377, 1, 0, -50331, 3815, 0, 0, 39, '3814'),
	(377, 1, 0, -50331, 3816, 0, 0, 39, '3815'),
	(377, 1, 0, -50331, 3817, 0, 0, 39, '3816'),
	(377, 1, 0, -50331, 3818, 0, 0, 39, '3817'),
	(377, 1, 0, -50331, 3819, 0, 0, 39, '3818'),
	(377, 1, 0, -50331, 3820, 0, 0, 39, '3819'),
	(377, 1, 0, -50331, 3821, 0, 0, 39, '3820'),
	(377, 1, 0, -50331, 3822, 0, 0, 39, '3821'),
	(377, 1, 0, -50331, 3823, 0, 0, 39, '3822'),
	(377, 1, 0, -50331, 3824, 0, 0, 39, '3823'),
	(377, 1, 0, -50331, 3825, 0, 0, 39, '3824'),
	(377, 1, 0, -50331, 3826, 0, 0, 39, '3825'),
	(377, 1, 0, -50331, 3827, 0, 0, 39, '3826'),
	(377, 1, 0, -50331, 3828, 0, 0, 39, '3827'),
	(377, 1, 0, -50331, 3829, 0, 0, 39, '3828'),
	(377, 1, 0, -50331, 3830, 0, 0, 39, '3829'),
	(377, 1, 0, -50331, 3831, 0, 0, 39, '3830'),
	(377, 1, 0, -50331, 3832, 0, 0, 39, '3831'),
	(377, 1, 0, -50331, 3833, 0, 0, 39, '3832'),
	(377, 1, 0, -50331, 3834, 0, 0, 39, '3833'),
	(377, 1, 0, -50331, 3835, 0, 0, 39, '3834'),
	(377, 1, 0, -50331, 3836, 0, 0, 39, '3835'),
	(377, 1, 0, -50331, 3837, 0, 0, 39, '3836'),
	(377, 1, 0, -50331, 3838, 0, 0, 39, '3837'),
	(377, 1, 0, -50331, 3839, 0, 0, 39, '3838'),
	(377, 1, 0, -50331, 3840, 0, 0, 39, '3839'),
	(377, 1, 0, -50331, 3841, 0, 0, 39, '3840'),
	(377, 1, 0, -50331, 3842, 0, 0, 39, '3841'),
	(377, 1, 0, -50331, 3843, 0, 0, 39, '3842'),
	(377, 1, 0, -50331, 3844, 0, 0, 39, '3843'),
	(377, 1, 0, -50331, 3845, 0, 0, 39, '3844'),
	(377, 1, 0, -50331, 3846, 0, 0, 39, '3845'),
	(377, 1, 0, -50331, 3847, 0, 0, 39, '3846'),
	(377, 1, 0, -50331, 3848, 0, 0, 39, '3847'),
	(377, 1, 0, -50331, 3849, 0, 0, 39, '3848'),
	(377, 1, 0, -50331, 3850, 0, 0, 39, '3849'),
	(377, 1, 0, -50331, 3851, 0, 0, 39, '3850'),
	(377, 1, 0, -50331, 3852, 0, 0, 39, '3851'),
	(377, 1, 0, -50331, 3853, 0, 0, 39, '3852'),
	(377, 1, 0, -50331, 3854, 0, 0, 39, '3853'),
	(377, 1, 0, -50331, 3855, 0, 0, 39, '3854'),
	(377, 1, 0, -50331, 3856, 0, 0, 39, '3855'),
	(377, 1, 0, -50331, 3857, 0, 0, 39, '3856'),
	(377, 1, 0, -50331, 3858, 0, 0, 39, '3857'),
	(377, 1, 0, -50331, 3859, 0, 0, 39, '3858'),
	(377, 1, 0, -50331, 3860, 0, 0, 39, '3859'),
	(377, 1, 0, -50331, 3861, 0, 0, 39, '3860'),
	(377, 1, 0, -50331, 3862, 0, 0, 39, '3861'),
	(377, 1, 0, -50331, 3863, 0, 0, 39, '3862'),
	(377, 1, 0, -50331, 3864, 0, 0, 39, '3863'),
	(377, 1, 0, -50331, 3865, 0, 0, 39, '3864'),
	(377, 1, 0, -50331, 3866, 0, 0, 39, '3865'),
	(377, 1, 0, -50331, 3867, 0, 0, 39, '3866'),
	(377, 1, 0, -50331, 3868, 0, 0, 39, '3867'),
	(377, 1, 0, -50331, 3869, 0, 0, 39, '3868'),
	(377, 1, 0, -50331, 3870, 0, 0, 39, '3869'),
	(377, 1, 0, -50331, 3871, 0, 0, 39, '3870'),
	(377, 1, 0, -50331, 3872, 0, 0, 39, '3871'),
	(377, 1, 0, -50331, 3873, 0, 0, 39, '3872'),
	(377, 1, 0, -50331, 3874, 0, 0, 39, '3873'),
	(377, 1, 0, -50331, 3875, 0, 0, 39, '3874'),
	(377, 1, 0, -50331, 3876, 0, 0, 39, '3875'),
	(377, 1, 0, -50331, 3877, 0, 0, 39, '3876'),
	(377, 1, 0, -50331, 3878, 0, 0, 39, '3877'),
	(377, 1, 0, -50331, 3879, 0, 0, 39, '3878'),
	(377, 1, 0, -50331, 3880, 0, 0, 39, '3879'),
	(377, 1, 0, -50331, 3881, 0, 0, 39, '3880'),
	(377, 1, 0, -50331, 3882, 0, 0, 39, '3881'),
	(377, 1, 0, -50331, 3883, 0, 0, 39, '3882'),
	(377, 1, 0, -50331, 3884, 0, 0, 39, '3883'),
	(377, 1, 0, -50331, 3885, 0, 0, 39, '3884'),
	(377, 1, 0, -50331, 3886, 0, 0, 39, '3885'),
	(377, 1, 0, -50331, 3887, 0, 0, 39, '3886'),
	(377, 1, 0, -50331, 3888, 0, 0, 39, '3887'),
	(377, 1, 0, -50331, 3889, 0, 0, 39, '3888'),
	(377, 1, 0, -50331, 3890, 0, 0, 39, '3889'),
	(377, 1, 0, -50331, 3891, 0, 0, 39, '3890'),
	(377, 1, 0, -50331, 3892, 0, 0, 39, '3891'),
	(377, 1, 0, -50331, 3893, 0, 0, 39, '3892'),
	(377, 1, 0, -50331, 3894, 0, 0, 39, '3893'),
	(377, 1, 0, -50331, 3895, 0, 0, 39, '3894'),
	(377, 1, 0, -50331, 3896, 0, 0, 39, '3895'),
	(377, 1, 0, -50331, 3897, 0, 0, 39, '3896'),
	(377, 1, 0, -50331, 3898, 0, 0, 39, '3897'),
	(377, 1, 0, -50331, 3899, 0, 0, 39, '3898'),
	(377, 1, 0, -50331, 3900, 0, 0, 39, '3899'),
	(377, 1, 0, -50331, 3901, 0, 0, 39, '3900'),
	(377, 1, 0, -50331, 3902, 0, 0, 39, '3901'),
	(377, 1, 0, -50331, 3903, 0, 0, 39, '3902'),
	(377, 1, 0, -50331, 3904, 0, 0, 39, '3903'),
	(377, 1, 0, -50331, 3905, 0, 0, 39, '3904'),
	(377, 1, 0, -50331, 3906, 0, 0, 39, '3905'),
	(377, 1, 0, -50331, 3907, 0, 0, 39, '3906'),
	(377, 1, 0, -50331, 3908, 0, 0, 39, '3907'),
	(377, 1, 0, -50331, 3909, 0, 0, 39, '3908'),
	(377, 1, 0, -50331, 3910, 0, 0, 39, '3909'),
	(377, 1, 0, -50331, 3911, 0, 0, 39, '3910'),
	(377, 1, 0, -50331, 3912, 0, 0, 39, '3911'),
	(377, 1, 0, -50331, 3913, 0, 0, 39, '3912'),
	(377, 1, 0, -50331, 3914, 0, 0, 39, '3913'),
	(377, 1, 0, -50331, 3915, 0, 0, 39, '3914'),
	(377, 1, 0, -50331, 3916, 0, 0, 39, '3915'),
	(377, 1, 0, -50331, 3917, 0, 0, 39, '3916'),
	(377, 1, 0, -50331, 3918, 0, 0, 39, '3917'),
	(377, 1, 0, -50331, 3919, 0, 0, 39, '3918'),
	(377, 1, 0, -50331, 3920, 0, 0, 39, '3919'),
	(377, 1, 0, -50331, 3921, 0, 0, 39, '3920'),
	(377, 1, 0, -50331, 3922, 0, 0, 39, '3921'),
	(377, 1, 0, -50331, 3923, 0, 0, 39, '3922'),
	(377, 1, 0, -50331, 3924, 0, 0, 39, '3923'),
	(377, 1, 0, -50331, 3925, 0, 0, 39, '3924'),
	(377, 1, 0, -50331, 3926, 0, 0, 39, '3925'),
	(377, 1, 0, -50331, 3927, 0, 0, 39, '3926'),
	(377, 1, 0, -50331, 3928, 0, 0, 39, '3927'),
	(377, 1, 0, -50331, 3929, 0, 0, 39, '3928'),
	(377, 1, 0, -50331, 3930, 0, 0, 39, '3929'),
	(377, 1, 0, -50331, 3931, 0, 0, 39, '3930'),
	(377, 1, 0, -50331, 3932, 0, 0, 39, '3931'),
	(377, 1, 0, -50331, 3933, 0, 0, 39, '3932'),
	(377, 1, 0, -50331, 3934, 0, 0, 39, '3933'),
	(377, 1, 0, -50331, 3935, 0, 0, 39, '3934'),
	(377, 1, 0, -50331, 3936, 0, 0, 39, '3935'),
	(377, 1, 0, -50331, 3937, 0, 0, 39, '3936'),
	(377, 1, 0, -50331, 3938, 0, 0, 39, '3937'),
	(377, 1, 0, -50331, 3939, 0, 0, 39, '3938'),
	(377, 1, 0, -50331, 3940, 0, 0, 39, '3939'),
	(377, 1, 0, -50331, 3941, 0, 0, 39, '3940'),
	(377, 1, 0, -50331, 3942, 0, 0, 39, '3941'),
	(377, 1, 0, -50331, 3943, 0, 0, 39, '3942'),
	(377, 1, 0, -50331, 3944, 0, 0, 39, '3943'),
	(377, 1, 0, -50331, 3945, 0, 0, 39, '3944'),
	(377, 1, 0, -50331, 3946, 0, 0, 39, '3945'),
	(377, 1, 0, -50331, 3947, 0, 0, 39, '3946'),
	(377, 1, 0, -50331, 3948, 0, 0, 39, '3947'),
	(377, 1, 0, -50331, 3949, 0, 0, 39, '3948'),
	(377, 1, 0, -50331, 3950, 0, 0, 39, '3949'),
	(377, 1, 0, -50331, 3951, 0, 0, 39, '3950'),
	(377, 1, 0, -50331, 3952, 0, 0, 39, '3951'),
	(377, 1, 0, -50331, 3953, 0, 0, 39, '3952'),
	(377, 1, 0, -50331, 3954, 0, 0, 39, '3953'),
	(377, 1, 0, -50331, 3955, 0, 0, 39, '3954'),
	(377, 1, 0, -50331, 3956, 0, 0, 39, '3955'),
	(377, 1, 0, -50331, 3957, 0, 0, 39, '3956'),
	(377, 1, 0, -50331, 3958, 0, 0, 39, '3957'),
	(377, 1, 0, -50331, 3959, 0, 0, 39, '3958'),
	(377, 1, 0, -50331, 3960, 0, 0, 39, '3959'),
	(377, 1, 0, -50331, 3961, 0, 0, 39, '3960'),
	(377, 1, 0, -50331, 3962, 0, 0, 39, '3961'),
	(377, 1, 0, -50331, 3963, 0, 0, 39, '3962'),
	(377, 1, 0, -50331, 3964, 0, 0, 39, '3963'),
	(377, 1, 0, -50331, 3965, 0, 0, 39, '3964'),
	(377, 1, 0, -50331, 3966, 0, 0, 39, '3965'),
	(377, 1, 0, -50331, 3967, 0, 0, 39, '3966'),
	(377, 1, 0, -50331, 3968, 0, 0, 39, '3967'),
	(377, 1, 0, -50331, 3969, 0, 0, 39, '3968'),
	(377, 1, 0, -50331, 3970, 0, 0, 39, '3969'),
	(377, 1, 0, -50331, 3971, 0, 0, 39, '3970'),
	(377, 1, 0, -50331, 3972, 0, 0, 39, '3971'),
	(377, 1, 0, -50331, 3973, 0, 0, 39, '3972'),
	(377, 1, 0, -50331, 3974, 0, 0, 39, '3973'),
	(377, 1, 0, -50331, 3975, 0, 0, 39, '3974'),
	(377, 1, 0, -50331, 3976, 0, 0, 39, '3975'),
	(377, 1, 0, -50331, 3977, 0, 0, 39, '3976'),
	(377, 1, 0, -50331, 3978, 0, 0, 39, '3977'),
	(377, 1, 0, -50331, 3979, 0, 0, 39, '3978'),
	(377, 1, 0, -50331, 3980, 0, 0, 39, '3979'),
	(377, 1, 0, -50331, 3981, 0, 0, 39, '3980'),
	(377, 1, 0, -50331, 3982, 0, 0, 39, '3981'),
	(377, 1, 0, -50331, 3983, 0, 0, 39, '3982'),
	(377, 1, 0, -50331, 3984, 0, 0, 39, '3983'),
	(377, 1, 0, -50331, 3985, 0, 0, 39, '3984'),
	(377, 1, 0, -50331, 3986, 0, 0, 39, '3985'),
	(377, 1, 0, -50331, 3987, 0, 0, 39, '3986'),
	(377, 1, 0, -50331, 3988, 0, 0, 39, '3987'),
	(377, 1, 0, -50331, 3989, 0, 0, 39, '3988'),
	(377, 1, 0, -50331, 3990, 0, 0, 39, '3989'),
	(377, 1, 0, -50331, 3991, 0, 0, 39, '3990'),
	(377, 1, 0, -50331, 3992, 0, 0, 39, '3991'),
	(377, 1, 0, -50331, 3993, 0, 0, 39, '3992'),
	(377, 1, 0, -50331, 3994, 0, 0, 39, '3993'),
	(377, 1, 0, -50331, 3995, 0, 0, 39, '3994'),
	(377, 1, 0, -50331, 3996, 0, 0, 39, '3995'),
	(377, 1, 0, -50331, 3997, 0, 0, 39, '3996'),
	(377, 1, 0, -50331, 3998, 0, 0, 39, '3997'),
	(377, 1, 0, -50331, 3999, 0, 0, 39, '3998'),
	(377, 1, 0, -50331, 4000, 0, 0, 39, '3999'),
	(377, 1, 0, -50295, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50295, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50295, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50295, 4, 0, 0, 39, '3'),
	(377, 1, 0, -50295, 5, 0, 0, 39, '4'),
	(377, 1, 0, -50295, 6, 0, 0, 39, '5'),
	(377, 1, 0, -50295, 7, 0, 0, 39, '6'),
	(377, 1, 0, -50295, 8, 0, 0, 39, '7'),
	(377, 1, 0, -50295, 9, 0, 0, 39, '8'),
	(377, 1, 0, -50295, 10, 0, 0, 39, '9'),
	(377, 1, 0, -50295, 11, 0, 0, 39, '10'),
	(377, 1, 0, -50295, 12, 0, 0, 39, '11'),
	(377, 1, 0, -50295, 13, 0, 0, 39, '12'),
	(377, 1, 0, -50295, 14, 0, 0, 39, '13'),
	(377, 1, 0, -50295, 15, 0, 0, 39, '14'),
	(377, 1, 0, -50295, 16, 0, 0, 39, '15'),
	(377, 1, 0, -50282, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50282, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50282, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50282, 4, 0, 0, 39, '3'),
	(377, 1, 0, -50282, 5, 0, 0, 39, '4'),
	(377, 1, 0, -50282, 6, 0, 0, 39, '5'),
	(377, 1, 0, -50282, 7, 0, 0, 39, '6'),
	(377, 1, 0, -50282, 8, 0, 0, 39, '7'),
	(377, 1, 0, -50282, 9, 0, 0, 39, '8'),
	(377, 1, 0, -50282, 10, 0, 0, 39, '9'),
	(377, 1, 0, -50282, 11, 0, 0, 39, '10'),
	(377, 1, 0, -50282, 12, 0, 0, 39, '11'),
	(377, 1, 0, -50282, 13, 0, 0, 39, '12'),
	(377, 1, 0, -50282, 14, 0, 0, 39, '13'),
	(377, 1, 0, -50282, 15, 0, 0, 39, '14'),
	(377, 1, 0, -50282, 16, 0, 0, 39, '15'),
	(377, 1, 0, -50282, 17, 0, 0, 39, '16'),
	(377, 1, 0, -50282, 18, 0, 0, 39, '17'),
	(377, 1, 0, -50282, 19, 0, 0, 39, '18'),
	(377, 1, 0, -50282, 20, 0, 0, 39, '19'),
	(377, 1, 0, -50282, 21, 0, 0, 39, '20'),
	(377, 1, 0, -50282, 22, 0, 0, 39, '21'),
	(377, 1, 0, -50282, 23, 0, 0, 39, '22'),
	(377, 1, 0, -50282, 24, 0, 0, 39, '23'),
	(377, 1, 0, -50282, 25, 0, 0, 39, '24'),
	(377, 1, 0, -50282, 26, 0, 0, 39, '25'),
	(377, 1, 0, -50282, 27, 0, 0, 39, '26'),
	(377, 1, 0, -50282, 28, 0, 0, 39, '27'),
	(377, 1, 0, -50282, 29, 0, 0, 39, '28'),
	(377, 1, 0, -50282, 30, 0, 0, 39, '29'),
	(377, 1, 0, -50282, 31, 0, 0, 39, '30'),
	(377, 1, 0, -50282, 32, 0, 0, 39, '31'),
	(377, 1, 0, -50282, 33, 0, 0, 39, '32'),
	(377, 1, 0, -50282, 34, 0, 0, 39, '33'),
	(377, 1, 0, -50282, 35, 0, 0, 39, '34'),
	(377, 1, 0, -50282, 36, 0, 0, 39, '35'),
	(377, 1, 0, -50282, 37, 0, 0, 39, '36'),
	(377, 1, 0, -50282, 38, 0, 0, 39, '37'),
	(377, 1, 0, -50282, 39, 0, 0, 39, '38'),
	(377, 1, 0, -50282, 40, 0, 0, 39, '39'),
	(377, 1, 0, -50282, 41, 0, 0, 39, '40'),
	(377, 1, 0, -50282, 42, 0, 0, 39, '41'),
	(377, 1, 0, -50282, 43, 0, 0, 39, '42'),
	(377, 1, 0, -50282, 44, 0, 0, 39, '43'),
	(377, 1, 0, -50282, 45, 0, 0, 39, '44'),
	(377, 1, 0, -50282, 46, 0, 0, 39, '45'),
	(377, 1, 0, -50282, 47, 0, 0, 39, '46'),
	(377, 1, 0, -50282, 48, 0, 0, 39, '47'),
	(377, 1, 0, -50282, 49, 0, 0, 39, '48'),
	(377, 1, 0, -50282, 50, 0, 0, 39, '49'),
	(377, 1, 0, -50282, 51, 0, 0, 39, '50'),
	(377, 1, 0, -50282, 52, 0, 0, 39, '51'),
	(377, 1, 0, -50282, 53, 0, 0, 39, '52'),
	(377, 1, 0, -50282, 54, 0, 0, 39, '53'),
	(377, 1, 0, -50282, 55, 0, 0, 39, '54'),
	(377, 1, 0, -50282, 56, 0, 0, 39, '55'),
	(377, 1, 0, -50282, 57, 0, 0, 39, '56'),
	(377, 1, 0, -50282, 58, 0, 0, 39, '57'),
	(377, 1, 0, -50282, 59, 0, 0, 39, '58'),
	(377, 1, 0, -50282, 60, 0, 0, 39, '59'),
	(377, 1, 0, -50282, 61, 0, 0, 39, '60'),
	(377, 1, 0, -50282, 62, 0, 0, 39, '61'),
	(377, 1, 0, -50282, 63, 0, 0, 39, '62'),
	(377, 1, 0, -50282, 64, 0, 0, 39, '63'),
	(377, 1, 0, -50282, 65, 0, 0, 39, '64'),
	(377, 1, 0, -50282, 66, 0, 0, 39, '65'),
	(377, 1, 0, -50282, 67, 0, 0, 39, '66'),
	(377, 1, 0, -50282, 68, 0, 0, 39, '67'),
	(377, 1, 0, -50282, 69, 0, 0, 39, '68'),
	(377, 1, 0, -50282, 70, 0, 0, 39, '69'),
	(377, 1, 0, -50282, 71, 0, 0, 39, '70'),
	(377, 1, 0, -50282, 72, 0, 0, 39, '71'),
	(377, 1, 0, -50282, 73, 0, 0, 39, '72'),
	(377, 1, 0, -50282, 74, 0, 0, 39, '73'),
	(377, 1, 0, -50282, 75, 0, 0, 39, '74'),
	(377, 1, 0, -50282, 76, 0, 0, 39, '75'),
	(377, 1, 0, -50282, 77, 0, 0, 39, '76'),
	(377, 1, 0, -50282, 78, 0, 0, 39, '77'),
	(377, 1, 0, -50282, 79, 0, 0, 39, '78'),
	(377, 1, 0, -50282, 80, 0, 0, 39, '79'),
	(377, 1, 0, -50282, 81, 0, 0, 39, '80'),
	(377, 1, 0, -50282, 82, 0, 0, 39, '81'),
	(377, 1, 0, -50282, 83, 0, 0, 39, '82'),
	(377, 1, 0, -50282, 84, 0, 0, 39, '83'),
	(377, 1, 0, -50282, 85, 0, 0, 39, '84'),
	(377, 1, 0, -50282, 86, 0, 0, 39, '85'),
	(377, 1, 0, -50282, 87, 0, 0, 39, '86'),
	(377, 1, 0, -50282, 88, 0, 0, 39, '87'),
	(377, 1, 0, -50282, 89, 0, 0, 39, '88'),
	(377, 1, 0, -50282, 90, 0, 0, 39, '89'),
	(377, 1, 0, -50282, 91, 0, 0, 39, '90'),
	(377, 1, 0, -50282, 92, 0, 0, 39, '91'),
	(377, 1, 0, -50282, 93, 0, 0, 39, '92'),
	(377, 1, 0, -50282, 94, 0, 0, 39, '93'),
	(377, 1, 0, -50282, 95, 0, 0, 39, '94'),
	(377, 1, 0, -50282, 96, 0, 0, 39, '95'),
	(377, 1, 0, -50282, 97, 0, 0, 39, '96'),
	(377, 1, 0, -50282, 98, 0, 0, 39, '97'),
	(377, 1, 0, -50282, 99, 0, 0, 39, '98'),
	(377, 1, 0, -50282, 100, 0, 0, 39, '99'),
	(377, 1, 0, -50282, 101, 0, 0, 39, '100'),
	(377, 1, 0, -50282, 102, 0, 0, 39, '101'),
	(377, 1, 0, -50282, 103, 0, 0, 39, '102'),
	(377, 1, 0, -50282, 104, 0, 0, 39, '103'),
	(377, 1, 0, -50282, 105, 0, 0, 39, '104'),
	(377, 1, 0, -50282, 106, 0, 0, 39, '105'),
	(377, 1, 0, -50282, 107, 0, 0, 39, '106'),
	(377, 1, 0, -50282, 108, 0, 0, 39, '107'),
	(377, 1, 0, -50282, 109, 0, 0, 39, '108'),
	(377, 1, 0, -50282, 110, 0, 0, 39, '109'),
	(377, 1, 0, -50282, 111, 0, 0, 39, '110'),
	(377, 1, 0, -50282, 112, 0, 0, 39, '111'),
	(377, 1, 0, -50282, 113, 0, 0, 39, '112'),
	(377, 1, 0, -50282, 114, 0, 0, 39, '113'),
	(377, 1, 0, -50282, 115, 0, 0, 39, '114'),
	(377, 1, 0, -50282, 116, 0, 0, 39, '115'),
	(377, 1, 0, -50282, 117, 0, 0, 39, '116'),
	(377, 1, 0, -50282, 118, 0, 0, 39, '117'),
	(377, 1, 0, -50282, 119, 0, 0, 39, '118'),
	(377, 1, 0, -50282, 120, 0, 0, 39, '119'),
	(377, 1, 0, -50282, 121, 0, 0, 39, '120'),
	(377, 1, 0, -50282, 122, 0, 0, 39, '121'),
	(377, 1, 0, -50282, 123, 0, 0, 39, '122'),
	(377, 1, 0, -50282, 124, 0, 0, 39, '123'),
	(377, 1, 0, -50282, 125, 0, 0, 39, '124'),
	(377, 1, 0, -50282, 126, 0, 0, 39, '125'),
	(377, 1, 0, -50282, 127, 0, 0, 39, '126'),
	(377, 1, 0, -50282, 128, 0, 0, 39, '127'),
	(377, 1, 0, -50282, 129, 0, 0, 39, '128'),
	(377, 1, 0, -50282, 130, 0, 0, 39, '129'),
	(377, 1, 0, -50282, 131, 0, 0, 39, '130'),
	(377, 1, 0, -50282, 132, 0, 0, 39, '131'),
	(377, 1, 0, -50282, 133, 0, 0, 39, '132'),
	(377, 1, 0, -50282, 134, 0, 0, 39, '133'),
	(377, 1, 0, -50282, 135, 0, 0, 39, '134'),
	(377, 1, 0, -50282, 136, 0, 0, 39, '135'),
	(377, 1, 0, -50282, 137, 0, 0, 39, '136'),
	(377, 1, 0, -50282, 138, 0, 0, 39, '137'),
	(377, 1, 0, -50282, 139, 0, 0, 39, '138'),
	(377, 1, 0, -50282, 140, 0, 0, 39, '139'),
	(377, 1, 0, -50282, 141, 0, 0, 39, '140'),
	(377, 1, 0, -50282, 142, 0, 0, 39, '141'),
	(377, 1, 0, -50282, 143, 0, 0, 39, '142'),
	(377, 1, 0, -50282, 144, 0, 0, 39, '143'),
	(377, 1, 0, -50282, 145, 0, 0, 39, '144'),
	(377, 1, 0, -50282, 146, 0, 0, 39, '145'),
	(377, 1, 0, -50282, 147, 0, 0, 39, '146'),
	(377, 1, 0, -50282, 148, 0, 0, 39, '147'),
	(377, 1, 0, -50282, 149, 0, 0, 39, '148'),
	(377, 1, 0, -50282, 150, 0, 0, 39, '149'),
	(377, 1, 0, -50282, 151, 0, 0, 39, '150'),
	(377, 1, 0, -50282, 152, 0, 0, 39, '151'),
	(377, 1, 0, -50282, 153, 0, 0, 39, '152'),
	(377, 1, 0, -50282, 154, 0, 0, 39, '153'),
	(377, 1, 0, -50282, 155, 0, 0, 39, '154'),
	(377, 1, 0, -50282, 156, 0, 0, 39, '155'),
	(377, 1, 0, -50282, 157, 0, 0, 39, '156'),
	(377, 1, 0, -50282, 158, 0, 0, 39, '157'),
	(377, 1, 0, -50282, 159, 0, 0, 39, '158'),
	(377, 1, 0, -50282, 160, 0, 0, 39, '159'),
	(377, 1, 0, -50282, 161, 0, 0, 39, '160'),
	(377, 1, 0, -50282, 162, 0, 0, 39, '161'),
	(377, 1, 0, -50282, 163, 0, 0, 39, '162'),
	(377, 1, 0, -50282, 164, 0, 0, 39, '163'),
	(377, 1, 0, -50282, 165, 0, 0, 39, '164'),
	(377, 1, 0, -50282, 166, 0, 0, 39, '165'),
	(377, 1, 0, -50282, 167, 0, 0, 39, '166'),
	(377, 1, 0, -50282, 168, 0, 0, 39, '167'),
	(377, 1, 0, -50282, 169, 0, 0, 39, '168'),
	(377, 1, 0, -50282, 170, 0, 0, 39, '169'),
	(377, 1, 0, -50282, 171, 0, 0, 39, '170'),
	(377, 1, 0, -50282, 172, 0, 0, 39, '171'),
	(377, 1, 0, -50282, 173, 0, 0, 39, '172'),
	(377, 1, 0, -50282, 174, 0, 0, 39, '173'),
	(377, 1, 0, -50282, 175, 0, 0, 39, '174'),
	(377, 1, 0, -50282, 176, 0, 0, 39, '175'),
	(377, 1, 0, -50282, 177, 0, 0, 39, '176'),
	(377, 1, 0, -50282, 178, 0, 0, 39, '177'),
	(377, 1, 0, -50282, 179, 0, 0, 39, '178'),
	(377, 1, 0, -50282, 180, 0, 0, 39, '179'),
	(377, 1, 0, -50282, 181, 0, 0, 39, '180'),
	(377, 1, 0, -50282, 182, 0, 0, 39, '181'),
	(377, 1, 0, -50282, 183, 0, 0, 39, '182'),
	(377, 1, 0, -50282, 184, 0, 0, 39, '183'),
	(377, 1, 0, -50282, 185, 0, 0, 39, '184'),
	(377, 1, 0, -50282, 186, 0, 0, 39, '185'),
	(377, 1, 0, -50282, 187, 0, 0, 39, '186'),
	(377, 1, 0, -50282, 188, 0, 0, 39, '187'),
	(377, 1, 0, -50282, 189, 0, 0, 39, '188'),
	(377, 1, 0, -50282, 190, 0, 0, 39, '189'),
	(377, 1, 0, -50282, 191, 0, 0, 39, '190'),
	(377, 1, 0, -50282, 192, 0, 0, 39, '191'),
	(377, 1, 0, -50282, 193, 0, 0, 39, '192'),
	(377, 1, 0, -50282, 194, 0, 0, 39, '193'),
	(377, 1, 0, -50282, 195, 0, 0, 39, '194'),
	(377, 1, 0, -50282, 196, 0, 0, 39, '195'),
	(377, 1, 0, -50282, 197, 0, 0, 39, '196'),
	(377, 1, 0, -50282, 198, 0, 0, 39, '197'),
	(377, 1, 0, -50282, 199, 0, 0, 39, '198'),
	(377, 1, 0, -50282, 200, 0, 0, 39, '199'),
	(377, 1, 0, -50282, 201, 0, 0, 39, '200'),
	(377, 1, 0, -50282, 202, 0, 0, 39, '201'),
	(377, 1, 0, -50282, 203, 0, 0, 39, '202'),
	(377, 1, 0, -50282, 204, 0, 0, 39, '203'),
	(377, 1, 0, -50282, 205, 0, 0, 39, '204'),
	(377, 1, 0, -50282, 206, 0, 0, 39, '205'),
	(377, 1, 0, -50282, 207, 0, 0, 39, '206'),
	(377, 1, 0, -50282, 208, 0, 0, 39, '207'),
	(377, 1, 0, -50282, 209, 0, 0, 39, '208'),
	(377, 1, 0, -50282, 210, 0, 0, 39, '209'),
	(377, 1, 0, -50282, 211, 0, 0, 39, '210'),
	(377, 1, 0, -50282, 212, 0, 0, 39, '211'),
	(377, 1, 0, -50282, 213, 0, 0, 39, '212'),
	(377, 1, 0, -50282, 214, 0, 0, 39, '213'),
	(377, 1, 0, -50282, 215, 0, 0, 39, '214'),
	(377, 1, 0, -50282, 216, 0, 0, 39, '215'),
	(377, 1, 0, -50282, 217, 0, 0, 39, '216'),
	(377, 1, 0, -50282, 218, 0, 0, 39, '217'),
	(377, 1, 0, -50282, 219, 0, 0, 39, '218'),
	(377, 1, 0, -50282, 220, 0, 0, 39, '219'),
	(377, 1, 0, -50282, 221, 0, 0, 39, '220'),
	(377, 1, 0, -50282, 222, 0, 0, 39, '221'),
	(377, 1, 0, -50282, 223, 0, 0, 39, '222'),
	(377, 1, 0, -50282, 224, 0, 0, 39, '223'),
	(377, 1, 0, -50282, 225, 0, 0, 39, '224'),
	(377, 1, 0, -50282, 226, 0, 0, 39, '225'),
	(377, 1, 0, -50282, 227, 0, 0, 39, '226'),
	(377, 1, 0, -50282, 228, 0, 0, 39, '227'),
	(377, 1, 0, -50282, 229, 0, 0, 39, '228'),
	(377, 1, 0, -50282, 230, 0, 0, 39, '229'),
	(377, 1, 0, -50282, 231, 0, 0, 39, '230'),
	(377, 1, 0, -50282, 232, 0, 0, 39, '231'),
	(377, 1, 0, -50282, 233, 0, 0, 39, '232'),
	(377, 1, 0, -50282, 234, 0, 0, 39, '233'),
	(377, 1, 0, -50282, 235, 0, 0, 39, '234'),
	(377, 1, 0, -50282, 236, 0, 0, 39, '235'),
	(377, 1, 0, -50282, 237, 0, 0, 39, '236'),
	(377, 1, 0, -50282, 238, 0, 0, 39, '237'),
	(377, 1, 0, -50282, 239, 0, 0, 39, '238'),
	(377, 1, 0, -50282, 240, 0, 0, 39, '239'),
	(377, 1, 0, -50282, 241, 0, 0, 39, '240'),
	(377, 1, 0, -50282, 242, 0, 0, 39, '241'),
	(377, 1, 0, -50282, 243, 0, 0, 39, '242'),
	(377, 1, 0, -50282, 244, 0, 0, 39, '243'),
	(377, 1, 0, -50282, 245, 0, 0, 39, '244'),
	(377, 1, 0, -50282, 246, 0, 0, 39, '245'),
	(377, 1, 0, -50282, 247, 0, 0, 39, '246'),
	(377, 1, 0, -50282, 248, 0, 0, 39, '247'),
	(377, 1, 0, -50282, 249, 0, 0, 39, '248'),
	(377, 1, 0, -50282, 250, 0, 0, 39, '249'),
	(377, 1, 0, -50282, 251, 0, 0, 39, '250'),
	(377, 1, 0, -50282, 252, 0, 0, 39, '251'),
	(377, 1, 0, -50282, 253, 0, 0, 39, '252'),
	(377, 1, 0, -50282, 254, 0, 0, 39, '253'),
	(377, 1, 0, -50282, 255, 0, 0, 39, '254'),
	(377, 1, 0, -50282, 256, 0, 0, 39, '255'),
	(377, 1, 0, -50282, 257, 0, 0, 39, '256'),
	(377, 1, 0, -50282, 258, 0, 0, 39, '257'),
	(377, 1, 0, -50282, 259, 0, 0, 39, '258'),
	(377, 1, 0, -50282, 260, 0, 0, 39, '259'),
	(377, 1, 0, -50282, 261, 0, 0, 39, '260'),
	(377, 1, 0, -50282, 262, 0, 0, 39, '261'),
	(377, 1, 0, -50282, 263, 0, 0, 39, '262'),
	(377, 1, 0, -50282, 264, 0, 0, 39, '263'),
	(377, 1, 0, -50282, 265, 0, 0, 39, '264'),
	(377, 1, 0, -50282, 266, 0, 0, 39, '265'),
	(377, 1, 0, -50282, 267, 0, 0, 39, '266'),
	(377, 1, 0, -50282, 268, 0, 0, 39, '267'),
	(377, 1, 0, -50282, 269, 0, 0, 39, '268'),
	(377, 1, 0, -50282, 270, 0, 0, 39, '269'),
	(377, 1, 0, -50282, 271, 0, 0, 39, '270'),
	(377, 1, 0, -50282, 272, 0, 0, 39, '271'),
	(377, 1, 0, -50282, 273, 0, 0, 39, '272'),
	(377, 1, 0, -50282, 274, 0, 0, 39, '273'),
	(377, 1, 0, -50282, 275, 0, 0, 39, '274'),
	(377, 1, 0, -50282, 276, 0, 0, 39, '275'),
	(377, 1, 0, -50282, 277, 0, 0, 39, '276'),
	(377, 1, 0, -50282, 278, 0, 0, 39, '277'),
	(377, 1, 0, -50282, 279, 0, 0, 39, '278'),
	(377, 1, 0, -50282, 280, 0, 0, 39, '279'),
	(377, 1, 0, -50282, 281, 0, 0, 39, '280'),
	(377, 1, 0, -50282, 282, 0, 0, 39, '281'),
	(377, 1, 0, -50282, 283, 0, 0, 39, '282'),
	(377, 1, 0, -50282, 284, 0, 0, 39, '283'),
	(377, 1, 0, -50282, 285, 0, 0, 39, '284'),
	(377, 1, 0, -50282, 286, 0, 0, 39, '285'),
	(377, 1, 0, -50282, 287, 0, 0, 39, '286'),
	(377, 1, 0, -50282, 288, 0, 0, 39, '287'),
	(377, 1, 0, -50282, 289, 0, 0, 39, '288'),
	(377, 1, 0, -50282, 290, 0, 0, 39, '289'),
	(377, 1, 0, -50282, 291, 0, 0, 39, '290'),
	(377, 1, 0, -50282, 292, 0, 0, 39, '291'),
	(377, 1, 0, -50282, 293, 0, 0, 39, '292'),
	(377, 1, 0, -50282, 294, 0, 0, 39, '293'),
	(377, 1, 0, -50282, 295, 0, 0, 39, '294'),
	(377, 1, 0, -50282, 296, 0, 0, 39, '295'),
	(377, 1, 0, -50282, 297, 0, 0, 39, '296'),
	(377, 1, 0, -50282, 298, 0, 0, 39, '297'),
	(377, 1, 0, -50282, 299, 0, 0, 39, '298'),
	(377, 1, 0, -50282, 300, 0, 0, 39, '299'),
	(377, 1, 0, -50282, 301, 0, 0, 39, '300'),
	(377, 1, 0, -50282, 302, 0, 0, 39, '301'),
	(377, 1, 0, -50282, 303, 0, 0, 39, '302'),
	(377, 1, 0, -50282, 304, 0, 0, 39, '303'),
	(377, 1, 0, -50282, 305, 0, 0, 39, '304'),
	(377, 1, 0, -50282, 306, 0, 0, 39, '305'),
	(377, 1, 0, -50282, 307, 0, 0, 39, '306'),
	(377, 1, 0, -50282, 308, 0, 0, 39, '307'),
	(377, 1, 0, -50282, 309, 0, 0, 39, '308'),
	(377, 1, 0, -50282, 310, 0, 0, 39, '309'),
	(377, 1, 0, -50282, 311, 0, 0, 39, '310'),
	(377, 1, 0, -50282, 312, 0, 0, 39, '311'),
	(377, 1, 0, -50282, 313, 0, 0, 39, '312'),
	(377, 1, 0, -50282, 314, 0, 0, 39, '313'),
	(377, 1, 0, -50282, 315, 0, 0, 39, '314'),
	(377, 1, 0, -50282, 316, 0, 0, 39, '315'),
	(377, 1, 0, -50282, 317, 0, 0, 39, '316'),
	(377, 1, 0, -50282, 318, 0, 0, 39, '317'),
	(377, 1, 0, -50282, 319, 0, 0, 39, '318'),
	(377, 1, 0, -50282, 320, 0, 0, 39, '319'),
	(377, 1, 0, -50282, 321, 0, 0, 39, '320'),
	(377, 1, 0, -50282, 322, 0, 0, 39, '321'),
	(377, 1, 0, -50282, 323, 0, 0, 39, '322'),
	(377, 1, 0, -50282, 324, 0, 0, 39, '323'),
	(377, 1, 0, -50282, 325, 0, 0, 39, '324'),
	(377, 1, 0, -50282, 326, 0, 0, 39, '325'),
	(377, 1, 0, -50282, 327, 0, 0, 39, '326'),
	(377, 1, 0, -50282, 328, 0, 0, 39, '327'),
	(377, 1, 0, -50282, 329, 0, 0, 39, '328'),
	(377, 1, 0, -50282, 330, 0, 0, 39, '329'),
	(377, 1, 0, -50282, 331, 0, 0, 39, '330'),
	(377, 1, 0, -50282, 332, 0, 0, 39, '331'),
	(377, 1, 0, -50282, 333, 0, 0, 39, '332'),
	(377, 1, 0, -50282, 334, 0, 0, 39, '333'),
	(377, 1, 0, -50282, 335, 0, 0, 39, '334'),
	(377, 1, 0, -50282, 336, 0, 0, 39, '335'),
	(377, 1, 0, -50282, 337, 0, 0, 39, '336'),
	(377, 1, 0, -50282, 338, 0, 0, 39, '337'),
	(377, 1, 0, -50282, 339, 0, 0, 39, '338'),
	(377, 1, 0, -50282, 340, 0, 0, 39, '339'),
	(377, 1, 0, -50282, 341, 0, 0, 39, '340'),
	(377, 1, 0, -50282, 342, 0, 0, 39, '341'),
	(377, 1, 0, -50282, 343, 0, 0, 39, '342'),
	(377, 1, 0, -50282, 344, 0, 0, 39, '343'),
	(377, 1, 0, -50282, 345, 0, 0, 39, '344'),
	(377, 1, 0, -50282, 346, 0, 0, 39, '345'),
	(377, 1, 0, -50282, 347, 0, 0, 39, '346'),
	(377, 1, 0, -50282, 348, 0, 0, 39, '347'),
	(377, 1, 0, -50282, 349, 0, 0, 39, '348'),
	(377, 1, 0, -50282, 350, 0, 0, 39, '349'),
	(377, 1, 0, -50282, 351, 0, 0, 39, '350'),
	(377, 1, 0, -50282, 352, 0, 0, 39, '351'),
	(377, 1, 0, -50282, 353, 0, 0, 39, '352'),
	(377, 1, 0, -50282, 354, 0, 0, 39, '353'),
	(377, 1, 0, -50282, 355, 0, 0, 39, '354'),
	(377, 1, 0, -50282, 356, 0, 0, 39, '355'),
	(377, 1, 0, -50282, 357, 0, 0, 39, '356'),
	(377, 1, 0, -50282, 358, 0, 0, 39, '357'),
	(377, 1, 0, -50282, 359, 0, 0, 39, '358'),
	(377, 1, 0, -50282, 360, 0, 0, 39, '359'),
	(377, 1, 0, -50282, 361, 0, 0, 39, '360'),
	(377, 1, 0, -50282, 362, 0, 0, 39, '361'),
	(377, 1, 0, -50282, 363, 0, 0, 39, '362'),
	(377, 1, 0, -50282, 364, 0, 0, 39, '363'),
	(377, 1, 0, -50282, 365, 0, 0, 39, '364'),
	(377, 1, 0, -50282, 366, 0, 0, 39, '365'),
	(377, 1, 0, -50282, 367, 0, 0, 39, '366'),
	(377, 1, 0, -50282, 368, 0, 0, 39, '367'),
	(377, 1, 0, -50282, 369, 0, 0, 39, '368'),
	(377, 1, 0, -50282, 370, 0, 0, 39, '369'),
	(377, 1, 0, -50282, 371, 0, 0, 39, '370'),
	(377, 1, 0, -50282, 372, 0, 0, 39, '371'),
	(377, 1, 0, -50282, 373, 0, 0, 39, '372'),
	(377, 1, 0, -50282, 374, 0, 0, 39, '373'),
	(377, 1, 0, -50282, 375, 0, 0, 39, '374'),
	(377, 1, 0, -50282, 376, 0, 0, 39, '375'),
	(377, 1, 0, -50282, 377, 0, 0, 39, '376'),
	(377, 1, 0, -50282, 378, 0, 0, 39, '377'),
	(377, 1, 0, -50282, 379, 0, 0, 39, '378'),
	(377, 1, 0, -50282, 380, 0, 0, 39, '379'),
	(377, 1, 0, -50282, 381, 0, 0, 39, '380'),
	(377, 1, 0, -50282, 382, 0, 0, 39, '381'),
	(377, 1, 0, -50282, 383, 0, 0, 39, '382'),
	(377, 1, 0, -50282, 384, 0, 0, 39, '383'),
	(377, 1, 0, -50282, 385, 0, 0, 39, '384'),
	(377, 1, 0, -50282, 386, 0, 0, 39, '385'),
	(377, 1, 0, -50282, 387, 0, 0, 39, '386'),
	(377, 1, 0, -50282, 388, 0, 0, 39, '387'),
	(377, 1, 0, -50282, 389, 0, 0, 39, '388'),
	(377, 1, 0, -50282, 390, 0, 0, 39, '389'),
	(377, 1, 0, -50282, 391, 0, 0, 39, '390'),
	(377, 1, 0, -50282, 392, 0, 0, 39, '391'),
	(377, 1, 0, -50282, 393, 0, 0, 39, '392'),
	(377, 1, 0, -50282, 394, 0, 0, 39, '393'),
	(377, 1, 0, -50282, 395, 0, 0, 39, '394'),
	(377, 1, 0, -50282, 396, 0, 0, 39, '395'),
	(377, 1, 0, -50282, 397, 0, 0, 39, '396'),
	(377, 1, 0, -50282, 398, 0, 0, 39, '397'),
	(377, 1, 0, -50282, 399, 0, 0, 39, '398'),
	(377, 1, 0, -50282, 400, 0, 0, 39, '399'),
	(377, 1, 0, -50282, 401, 0, 0, 39, '400'),
	(377, 1, 0, -50282, 402, 0, 0, 39, '401'),
	(377, 1, 0, -50282, 403, 0, 0, 39, '402'),
	(377, 1, 0, -50282, 404, 0, 0, 39, '403'),
	(377, 1, 0, -50282, 405, 0, 0, 39, '404'),
	(377, 1, 0, -50282, 406, 0, 0, 39, '405'),
	(377, 1, 0, -50282, 407, 0, 0, 39, '406'),
	(377, 1, 0, -50282, 408, 0, 0, 39, '407'),
	(377, 1, 0, -50282, 409, 0, 0, 39, '408'),
	(377, 1, 0, -50282, 410, 0, 0, 39, '409'),
	(377, 1, 0, -50282, 411, 0, 0, 39, '410'),
	(377, 1, 0, -50282, 412, 0, 0, 39, '411'),
	(377, 1, 0, -50282, 413, 0, 0, 39, '412'),
	(377, 1, 0, -50282, 414, 0, 0, 39, '413'),
	(377, 1, 0, -50282, 415, 0, 0, 39, '414'),
	(377, 1, 0, -50282, 416, 0, 0, 39, '415'),
	(377, 1, 0, -50282, 417, 0, 0, 39, '416'),
	(377, 1, 0, -50282, 418, 0, 0, 39, '417'),
	(377, 1, 0, -50282, 419, 0, 0, 39, '418'),
	(377, 1, 0, -50282, 420, 0, 0, 39, '419'),
	(377, 1, 0, -50282, 421, 0, 0, 39, '420'),
	(377, 1, 0, -50282, 422, 0, 0, 39, '421'),
	(377, 1, 0, -50282, 423, 0, 0, 39, '422'),
	(377, 1, 0, -50282, 424, 0, 0, 39, '423'),
	(377, 1, 0, -50282, 425, 0, 0, 39, '424'),
	(377, 1, 0, -50282, 426, 0, 0, 39, '425'),
	(377, 1, 0, -50282, 427, 0, 0, 39, '426'),
	(377, 1, 0, -50282, 428, 0, 0, 39, '427'),
	(377, 1, 0, -50282, 429, 0, 0, 39, '428'),
	(377, 1, 0, -50282, 430, 0, 0, 39, '429'),
	(377, 1, 0, -50282, 431, 0, 0, 39, '430'),
	(377, 1, 0, -50282, 432, 0, 0, 39, '431'),
	(377, 1, 0, -50282, 433, 0, 0, 39, '432'),
	(377, 1, 0, -50282, 434, 0, 0, 39, '433'),
	(377, 1, 0, -50282, 435, 0, 0, 39, '434'),
	(377, 1, 0, -50282, 436, 0, 0, 39, '435'),
	(377, 1, 0, -50282, 437, 0, 0, 39, '436'),
	(377, 1, 0, -50282, 438, 0, 0, 39, '437'),
	(377, 1, 0, -50282, 439, 0, 0, 39, '438'),
	(377, 1, 0, -50282, 440, 0, 0, 39, '439'),
	(377, 1, 0, -50282, 441, 0, 0, 39, '440'),
	(377, 1, 0, -50282, 442, 0, 0, 39, '441'),
	(377, 1, 0, -50282, 443, 0, 0, 39, '442'),
	(377, 1, 0, -50282, 444, 0, 0, 39, '443'),
	(377, 1, 0, -50282, 445, 0, 0, 39, '444'),
	(377, 1, 0, -50282, 446, 0, 0, 39, '445'),
	(377, 1, 0, -50282, 447, 0, 0, 39, '446'),
	(377, 1, 0, -50282, 448, 0, 0, 39, '447'),
	(377, 1, 0, -50282, 449, 0, 0, 39, '448'),
	(377, 1, 0, -50282, 450, 0, 0, 39, '449'),
	(377, 1, 0, -50282, 451, 0, 0, 39, '450'),
	(377, 1, 0, -50282, 452, 0, 0, 39, '451'),
	(377, 1, 0, -50282, 453, 0, 0, 39, '452'),
	(377, 1, 0, -50282, 454, 0, 0, 39, '453'),
	(377, 1, 0, -50282, 455, 0, 0, 39, '454'),
	(377, 1, 0, -50282, 456, 0, 0, 39, '455'),
	(377, 1, 0, -50282, 457, 0, 0, 39, '456'),
	(377, 1, 0, -50282, 458, 0, 0, 39, '457'),
	(377, 1, 0, -50282, 459, 0, 0, 39, '458'),
	(377, 1, 0, -50282, 460, 0, 0, 39, '459'),
	(377, 1, 0, -50282, 461, 0, 0, 39, '460'),
	(377, 1, 0, -50282, 462, 0, 0, 39, '461'),
	(377, 1, 0, -50282, 463, 0, 0, 39, '462'),
	(377, 1, 0, -50282, 464, 0, 0, 39, '463'),
	(377, 1, 0, -50282, 465, 0, 0, 39, '464'),
	(377, 1, 0, -50282, 466, 0, 0, 39, '465'),
	(377, 1, 0, -50282, 467, 0, 0, 39, '466'),
	(377, 1, 0, -50282, 468, 0, 0, 39, '467'),
	(377, 1, 0, -50282, 469, 0, 0, 39, '468'),
	(377, 1, 0, -50282, 470, 0, 0, 39, '469'),
	(377, 1, 0, -50282, 471, 0, 0, 39, '470'),
	(377, 1, 0, -50282, 472, 0, 0, 39, '471'),
	(377, 1, 0, -50282, 473, 0, 0, 39, '472'),
	(377, 1, 0, -50282, 474, 0, 0, 39, '473'),
	(377, 1, 0, -50282, 475, 0, 0, 39, '474'),
	(377, 1, 0, -50282, 476, 0, 0, 39, '475'),
	(377, 1, 0, -50282, 477, 0, 0, 39, '476'),
	(377, 1, 0, -50282, 478, 0, 0, 39, '477'),
	(377, 1, 0, -50282, 479, 0, 0, 39, '478'),
	(377, 1, 0, -50282, 480, 0, 0, 39, '479'),
	(377, 1, 0, -50282, 481, 0, 0, 39, '480'),
	(377, 1, 0, -50282, 482, 0, 0, 39, '481'),
	(377, 1, 0, -50282, 483, 0, 0, 39, '482'),
	(377, 1, 0, -50282, 484, 0, 0, 39, '483'),
	(377, 1, 0, -50282, 485, 0, 0, 39, '484'),
	(377, 1, 0, -50282, 486, 0, 0, 39, '485'),
	(377, 1, 0, -50282, 487, 0, 0, 39, '486'),
	(377, 1, 0, -50282, 488, 0, 0, 39, '487'),
	(377, 1, 0, -50282, 489, 0, 0, 39, '488'),
	(377, 1, 0, -50282, 490, 0, 0, 39, '489'),
	(377, 1, 0, -50282, 491, 0, 0, 39, '490'),
	(377, 1, 0, -50282, 492, 0, 0, 39, '491'),
	(377, 1, 0, -50282, 493, 0, 0, 39, '492'),
	(377, 1, 0, -50282, 494, 0, 0, 39, '493'),
	(377, 1, 0, -50282, 495, 0, 0, 39, '494'),
	(377, 1, 0, -50282, 496, 0, 0, 39, '495'),
	(377, 1, 0, -50282, 497, 0, 0, 39, '496'),
	(377, 1, 0, -50282, 498, 0, 0, 39, '497'),
	(377, 1, 0, -50282, 499, 0, 0, 39, '498'),
	(377, 1, 0, -50282, 500, 0, 0, 39, '499'),
	(377, 1, 0, -50282, 501, 0, 0, 39, '500'),
	(377, 1, 0, -50282, 502, 0, 0, 39, '501'),
	(377, 1, 0, -50282, 503, 0, 0, 39, '502'),
	(377, 1, 0, -50282, 504, 0, 0, 39, '503'),
	(377, 1, 0, -50282, 505, 0, 0, 39, '504'),
	(377, 1, 0, -50282, 506, 0, 0, 39, '505'),
	(377, 1, 0, -50282, 507, 0, 0, 39, '506'),
	(377, 1, 0, -50282, 508, 0, 0, 39, '507'),
	(377, 1, 0, -50282, 509, 0, 0, 39, '508'),
	(377, 1, 0, -50282, 510, 0, 0, 39, '509'),
	(377, 1, 0, -50282, 511, 0, 0, 39, '510'),
	(377, 1, 0, -50282, 512, 0, 0, 39, '511'),
	(377, 1, 0, -50282, 513, 0, 0, 39, '512'),
	(377, 1, 0, -50282, 514, 0, 0, 39, '513'),
	(377, 1, 0, -50282, 515, 0, 0, 39, '514'),
	(377, 1, 0, -50282, 516, 0, 0, 39, '515'),
	(377, 1, 0, -50282, 517, 0, 0, 39, '516'),
	(377, 1, 0, -50282, 518, 0, 0, 39, '517'),
	(377, 1, 0, -50282, 519, 0, 0, 39, '518'),
	(377, 1, 0, -50282, 520, 0, 0, 39, '519'),
	(377, 1, 0, -50282, 521, 0, 0, 39, '520'),
	(377, 1, 0, -50282, 522, 0, 0, 39, '521'),
	(377, 1, 0, -50282, 523, 0, 0, 39, '522'),
	(377, 1, 0, -50282, 524, 0, 0, 39, '523'),
	(377, 1, 0, -50282, 525, 0, 0, 39, '524'),
	(377, 1, 0, -50282, 526, 0, 0, 39, '525'),
	(377, 1, 0, -50282, 527, 0, 0, 39, '526'),
	(377, 1, 0, -50282, 528, 0, 0, 39, '527'),
	(377, 1, 0, -50282, 529, 0, 0, 39, '528'),
	(377, 1, 0, -50282, 530, 0, 0, 39, '529'),
	(377, 1, 0, -50282, 531, 0, 0, 39, '530'),
	(377, 1, 0, -50282, 532, 0, 0, 39, '531'),
	(377, 1, 0, -50282, 533, 0, 0, 39, '532'),
	(377, 1, 0, -50282, 534, 0, 0, 39, '533'),
	(377, 1, 0, -50282, 535, 0, 0, 39, '534'),
	(377, 1, 0, -50282, 536, 0, 0, 39, '535'),
	(377, 1, 0, -50282, 537, 0, 0, 39, '536'),
	(377, 1, 0, -50282, 538, 0, 0, 39, '537'),
	(377, 1, 0, -50282, 539, 0, 0, 39, '538'),
	(377, 1, 0, -50282, 540, 0, 0, 39, '539'),
	(377, 1, 0, -50282, 541, 0, 0, 39, '540'),
	(377, 1, 0, -50282, 542, 0, 0, 39, '541'),
	(377, 1, 0, -50282, 543, 0, 0, 39, '542'),
	(377, 1, 0, -50282, 544, 0, 0, 39, '543'),
	(377, 1, 0, -50282, 545, 0, 0, 39, '544'),
	(377, 1, 0, -50282, 546, 0, 0, 39, '545'),
	(377, 1, 0, -50282, 547, 0, 0, 39, '546'),
	(377, 1, 0, -50282, 548, 0, 0, 39, '547'),
	(377, 1, 0, -50282, 549, 0, 0, 39, '548'),
	(377, 1, 0, -50282, 550, 0, 0, 39, '549'),
	(377, 1, 0, -50282, 551, 0, 0, 39, '550'),
	(377, 1, 0, -50282, 552, 0, 0, 39, '551'),
	(377, 1, 0, -50282, 553, 0, 0, 39, '552'),
	(377, 1, 0, -50282, 554, 0, 0, 39, '553'),
	(377, 1, 0, -50282, 555, 0, 0, 39, '554'),
	(377, 1, 0, -50282, 556, 0, 0, 39, '555'),
	(377, 1, 0, -50282, 557, 0, 0, 39, '556'),
	(377, 1, 0, -50282, 558, 0, 0, 39, '557'),
	(377, 1, 0, -50282, 559, 0, 0, 39, '558'),
	(377, 1, 0, -50282, 560, 0, 0, 39, '559'),
	(377, 1, 0, -50282, 561, 0, 0, 39, '560'),
	(377, 1, 0, -50282, 562, 0, 0, 39, '561'),
	(377, 1, 0, -50282, 563, 0, 0, 39, '562'),
	(377, 1, 0, -50282, 564, 0, 0, 39, '563'),
	(377, 1, 0, -50282, 565, 0, 0, 39, '564'),
	(377, 1, 0, -50282, 566, 0, 0, 39, '565'),
	(377, 1, 0, -50282, 567, 0, 0, 39, '566'),
	(377, 1, 0, -50282, 568, 0, 0, 39, '567'),
	(377, 1, 0, -50282, 569, 0, 0, 39, '568'),
	(377, 1, 0, -50282, 570, 0, 0, 39, '569'),
	(377, 1, 0, -50282, 571, 0, 0, 39, '570'),
	(377, 1, 0, -50282, 572, 0, 0, 39, '571'),
	(377, 1, 0, -50282, 573, 0, 0, 39, '572'),
	(377, 1, 0, -50282, 574, 0, 0, 39, '573'),
	(377, 1, 0, -50282, 575, 0, 0, 39, '574'),
	(377, 1, 0, -50282, 576, 0, 0, 39, '575'),
	(377, 1, 0, -50282, 577, 0, 0, 39, '576'),
	(377, 1, 0, -50282, 578, 0, 0, 39, '577'),
	(377, 1, 0, -50282, 579, 0, 0, 39, '578'),
	(377, 1, 0, -50282, 580, 0, 0, 39, '579'),
	(377, 1, 0, -50282, 581, 0, 0, 39, '580'),
	(377, 1, 0, -50282, 582, 0, 0, 39, '581'),
	(377, 1, 0, -50282, 583, 0, 0, 39, '582'),
	(377, 1, 0, -50282, 584, 0, 0, 39, '583'),
	(377, 1, 0, -50282, 585, 0, 0, 39, '584'),
	(377, 1, 0, -50282, 586, 0, 0, 39, '585'),
	(377, 1, 0, -50282, 587, 0, 0, 39, '586'),
	(377, 1, 0, -50282, 588, 0, 0, 39, '587'),
	(377, 1, 0, -50282, 589, 0, 0, 39, '588'),
	(377, 1, 0, -50282, 590, 0, 0, 39, '589'),
	(377, 1, 0, -50282, 591, 0, 0, 39, '590'),
	(377, 1, 0, -50282, 592, 0, 0, 39, '591'),
	(377, 1, 0, -50282, 593, 0, 0, 39, '592'),
	(377, 1, 0, -50282, 594, 0, 0, 39, '593'),
	(377, 1, 0, -50282, 595, 0, 0, 39, '594'),
	(377, 1, 0, -50282, 596, 0, 0, 39, '595'),
	(377, 1, 0, -50282, 597, 0, 0, 39, '596'),
	(377, 1, 0, -50282, 598, 0, 0, 39, '597'),
	(377, 1, 0, -50282, 599, 0, 0, 39, '598'),
	(377, 1, 0, -50282, 600, 0, 0, 39, '599'),
	(377, 1, 0, -50282, 601, 0, 0, 39, '600'),
	(377, 1, 0, -50282, 602, 0, 0, 39, '601'),
	(377, 1, 0, -50282, 603, 0, 0, 39, '602'),
	(377, 1, 0, -50282, 604, 0, 0, 39, '603'),
	(377, 1, 0, -50282, 605, 0, 0, 39, '604'),
	(377, 1, 0, -50282, 606, 0, 0, 39, '605'),
	(377, 1, 0, -50282, 607, 0, 0, 39, '606'),
	(377, 1, 0, -50282, 608, 0, 0, 39, '607'),
	(377, 1, 0, -50282, 609, 0, 0, 39, '608'),
	(377, 1, 0, -50282, 610, 0, 0, 39, '609'),
	(377, 1, 0, -50282, 611, 0, 0, 39, '610'),
	(377, 1, 0, -50282, 612, 0, 0, 39, '611'),
	(377, 1, 0, -50282, 613, 0, 0, 39, '612'),
	(377, 1, 0, -50282, 614, 0, 0, 39, '613'),
	(377, 1, 0, -50282, 615, 0, 0, 39, '614'),
	(377, 1, 0, -50282, 616, 0, 0, 39, '615'),
	(377, 1, 0, -50282, 617, 0, 0, 39, '616'),
	(377, 1, 0, -50282, 618, 0, 0, 39, '617'),
	(377, 1, 0, -50282, 619, 0, 0, 39, '618'),
	(377, 1, 0, -50282, 620, 0, 0, 39, '619'),
	(377, 1, 0, -50282, 621, 0, 0, 39, '620'),
	(377, 1, 0, -50282, 622, 0, 0, 39, '621'),
	(377, 1, 0, -50282, 623, 0, 0, 39, '622'),
	(377, 1, 0, -50282, 624, 0, 0, 39, '623'),
	(377, 1, 0, -50282, 625, 0, 0, 39, '624'),
	(377, 1, 0, -50282, 626, 0, 0, 39, '625'),
	(377, 1, 0, -50282, 627, 0, 0, 39, '626'),
	(377, 1, 0, -50282, 628, 0, 0, 39, '627'),
	(377, 1, 0, -50282, 629, 0, 0, 39, '628'),
	(377, 1, 0, -50282, 630, 0, 0, 39, '629'),
	(377, 1, 0, -50282, 631, 0, 0, 39, '630'),
	(377, 1, 0, -50282, 632, 0, 0, 39, '631'),
	(377, 1, 0, -50282, 633, 0, 0, 39, '632'),
	(377, 1, 0, -50282, 634, 0, 0, 39, '633'),
	(377, 1, 0, -50282, 635, 0, 0, 39, '634'),
	(377, 1, 0, -50282, 636, 0, 0, 39, '635'),
	(377, 1, 0, -50282, 637, 0, 0, 39, '636'),
	(377, 1, 0, -50282, 638, 0, 0, 39, '637'),
	(377, 1, 0, -50282, 639, 0, 0, 39, '638'),
	(377, 1, 0, -50282, 640, 0, 0, 39, '639'),
	(377, 1, 0, -50282, 641, 0, 0, 39, '640'),
	(377, 1, 0, -50282, 642, 0, 0, 39, '641'),
	(377, 1, 0, -50282, 643, 0, 0, 39, '642'),
	(377, 1, 0, -50282, 644, 0, 0, 39, '643'),
	(377, 1, 0, -50282, 645, 0, 0, 39, '644'),
	(377, 1, 0, -50282, 646, 0, 0, 39, '645'),
	(377, 1, 0, -50282, 647, 0, 0, 39, '646'),
	(377, 1, 0, -50282, 648, 0, 0, 39, '647'),
	(377, 1, 0, -50282, 649, 0, 0, 39, '648'),
	(377, 1, 0, -50282, 650, 0, 0, 39, '649'),
	(377, 1, 0, -50282, 651, 0, 0, 39, '650'),
	(377, 1, 0, -50282, 652, 0, 0, 39, '651'),
	(377, 1, 0, -50282, 653, 0, 0, 39, '652'),
	(377, 1, 0, -50282, 654, 0, 0, 39, '653'),
	(377, 1, 0, -50282, 655, 0, 0, 39, '654'),
	(377, 1, 0, -50282, 656, 0, 0, 39, '655'),
	(377, 1, 0, -50282, 657, 0, 0, 39, '656'),
	(377, 1, 0, -50282, 658, 0, 0, 39, '657'),
	(377, 1, 0, -50282, 659, 0, 0, 39, '658'),
	(377, 1, 0, -50282, 660, 0, 0, 39, '659'),
	(377, 1, 0, -50282, 661, 0, 0, 39, '660'),
	(377, 1, 0, -50282, 662, 0, 0, 39, '661'),
	(377, 1, 0, -50282, 663, 0, 0, 39, '662'),
	(377, 1, 0, -50282, 664, 0, 0, 39, '663'),
	(377, 1, 0, -50282, 665, 0, 0, 39, '664'),
	(377, 1, 0, -50282, 666, 0, 0, 39, '665'),
	(377, 1, 0, -50282, 667, 0, 0, 39, '666'),
	(377, 1, 0, -50282, 668, 0, 0, 39, '667'),
	(377, 1, 0, -50282, 669, 0, 0, 39, '668'),
	(377, 1, 0, -50282, 670, 0, 0, 39, '669'),
	(377, 1, 0, -50282, 671, 0, 0, 39, '670'),
	(377, 1, 0, -50282, 672, 0, 0, 39, '671'),
	(377, 1, 0, -50282, 673, 0, 0, 39, '672'),
	(377, 1, 0, -50282, 674, 0, 0, 39, '673'),
	(377, 1, 0, -50282, 675, 0, 0, 39, '674'),
	(377, 1, 0, -50282, 676, 0, 0, 39, '675'),
	(377, 1, 0, -50282, 677, 0, 0, 39, '676'),
	(377, 1, 0, -50282, 678, 0, 0, 39, '677'),
	(377, 1, 0, -50282, 679, 0, 0, 39, '678'),
	(377, 1, 0, -50282, 680, 0, 0, 39, '679'),
	(377, 1, 0, -50282, 681, 0, 0, 39, '680'),
	(377, 1, 0, -50282, 682, 0, 0, 39, '681'),
	(377, 1, 0, -50282, 683, 0, 0, 39, '682'),
	(377, 1, 0, -50282, 684, 0, 0, 39, '683'),
	(377, 1, 0, -50282, 685, 0, 0, 39, '684'),
	(377, 1, 0, -50282, 686, 0, 0, 39, '685'),
	(377, 1, 0, -50282, 687, 0, 0, 39, '686'),
	(377, 1, 0, -50282, 688, 0, 0, 39, '687'),
	(377, 1, 0, -50282, 689, 0, 0, 39, '688'),
	(377, 1, 0, -50282, 690, 0, 0, 39, '689'),
	(377, 1, 0, -50282, 691, 0, 0, 39, '690'),
	(377, 1, 0, -50282, 692, 0, 0, 39, '691'),
	(377, 1, 0, -50282, 693, 0, 0, 39, '692'),
	(377, 1, 0, -50282, 694, 0, 0, 39, '693'),
	(377, 1, 0, -50282, 695, 0, 0, 39, '694'),
	(377, 1, 0, -50282, 696, 0, 0, 39, '695'),
	(377, 1, 0, -50282, 697, 0, 0, 39, '696'),
	(377, 1, 0, -50282, 698, 0, 0, 39, '697'),
	(377, 1, 0, -50282, 699, 0, 0, 39, '698'),
	(377, 1, 0, -50282, 700, 0, 0, 39, '699'),
	(377, 1, 0, -50282, 701, 0, 0, 39, '700'),
	(377, 1, 0, -50282, 702, 0, 0, 39, '701'),
	(377, 1, 0, -50282, 703, 0, 0, 39, '702'),
	(377, 1, 0, -50282, 704, 0, 0, 39, '703'),
	(377, 1, 0, -50282, 705, 0, 0, 39, '704'),
	(377, 1, 0, -50282, 706, 0, 0, 39, '705'),
	(377, 1, 0, -50282, 707, 0, 0, 39, '706'),
	(377, 1, 0, -50282, 708, 0, 0, 39, '707'),
	(377, 1, 0, -50282, 709, 0, 0, 39, '708'),
	(377, 1, 0, -50282, 710, 0, 0, 39, '709'),
	(377, 1, 0, -50282, 711, 0, 0, 39, '710'),
	(377, 1, 0, -50282, 712, 0, 0, 39, '711'),
	(377, 1, 0, -50282, 713, 0, 0, 39, '712'),
	(377, 1, 0, -50282, 714, 0, 0, 39, '713'),
	(377, 1, 0, -50282, 715, 0, 0, 39, '714'),
	(377, 1, 0, -50282, 716, 0, 0, 39, '715'),
	(377, 1, 0, -50282, 717, 0, 0, 39, '716'),
	(377, 1, 0, -50282, 718, 0, 0, 39, '717'),
	(377, 1, 0, -50282, 719, 0, 0, 39, '718'),
	(377, 1, 0, -50282, 720, 0, 0, 39, '719'),
	(377, 1, 0, -50282, 721, 0, 0, 39, '720'),
	(377, 1, 0, -50282, 722, 0, 0, 39, '721'),
	(377, 1, 0, -50282, 723, 0, 0, 39, '722'),
	(377, 1, 0, -50282, 724, 0, 0, 39, '723'),
	(377, 1, 0, -50282, 725, 0, 0, 39, '724'),
	(377, 1, 0, -50282, 726, 0, 0, 39, '725'),
	(377, 1, 0, -50282, 727, 0, 0, 39, '726'),
	(377, 1, 0, -50282, 728, 0, 0, 39, '727'),
	(377, 1, 0, -50282, 729, 0, 0, 39, '728'),
	(377, 1, 0, -50282, 730, 0, 0, 39, '729'),
	(377, 1, 0, -50282, 731, 0, 0, 39, '730'),
	(377, 1, 0, -50282, 732, 0, 0, 39, '731'),
	(377, 1, 0, -50282, 733, 0, 0, 39, '732'),
	(377, 1, 0, -50282, 734, 0, 0, 39, '733'),
	(377, 1, 0, -50282, 735, 0, 0, 39, '734'),
	(377, 1, 0, -50282, 736, 0, 0, 39, '735'),
	(377, 1, 0, -50282, 737, 0, 0, 39, '736'),
	(377, 1, 0, -50282, 738, 0, 0, 39, '737'),
	(377, 1, 0, -50282, 739, 0, 0, 39, '738'),
	(377, 1, 0, -50282, 740, 0, 0, 39, '739'),
	(377, 1, 0, -50282, 741, 0, 0, 39, '740'),
	(377, 1, 0, -50282, 742, 0, 0, 39, '741'),
	(377, 1, 0, -50282, 743, 0, 0, 39, '742'),
	(377, 1, 0, -50282, 744, 0, 0, 39, '743'),
	(377, 1, 0, -50282, 745, 0, 0, 39, '744'),
	(377, 1, 0, -50282, 746, 0, 0, 39, '745'),
	(377, 1, 0, -50282, 747, 0, 0, 39, '746'),
	(377, 1, 0, -50282, 748, 0, 0, 39, '747'),
	(377, 1, 0, -50282, 749, 0, 0, 39, '748'),
	(377, 1, 0, -50282, 750, 0, 0, 39, '749'),
	(377, 1, 0, -50282, 751, 0, 0, 39, '750'),
	(377, 1, 0, -50282, 752, 0, 0, 39, '751'),
	(377, 1, 0, -50282, 753, 0, 0, 39, '752'),
	(377, 1, 0, -50282, 754, 0, 0, 39, '753'),
	(377, 1, 0, -50282, 755, 0, 0, 39, '754'),
	(377, 1, 0, -50282, 756, 0, 0, 39, '755'),
	(377, 1, 0, -50282, 757, 0, 0, 39, '756'),
	(377, 1, 0, -50282, 758, 0, 0, 39, '757'),
	(377, 1, 0, -50282, 759, 0, 0, 39, '758'),
	(377, 1, 0, -50282, 760, 0, 0, 39, '759'),
	(377, 1, 0, -50282, 761, 0, 0, 39, '760'),
	(377, 1, 0, -50282, 762, 0, 0, 39, '761'),
	(377, 1, 0, -50282, 763, 0, 0, 39, '762'),
	(377, 1, 0, -50282, 764, 0, 0, 39, '763'),
	(377, 1, 0, -50282, 765, 0, 0, 39, '764'),
	(377, 1, 0, -50282, 766, 0, 0, 39, '765'),
	(377, 1, 0, -50282, 767, 0, 0, 39, '766'),
	(377, 1, 0, -50282, 768, 0, 0, 39, '767'),
	(377, 1, 0, -50282, 769, 0, 0, 39, '768'),
	(377, 1, 0, -50282, 770, 0, 0, 39, '769'),
	(377, 1, 0, -50282, 771, 0, 0, 39, '770'),
	(377, 1, 0, -50282, 772, 0, 0, 39, '771'),
	(377, 1, 0, -50282, 773, 0, 0, 39, '772'),
	(377, 1, 0, -50282, 774, 0, 0, 39, '773'),
	(377, 1, 0, -50282, 775, 0, 0, 39, '774'),
	(377, 1, 0, -50282, 776, 0, 0, 39, '775'),
	(377, 1, 0, -50282, 777, 0, 0, 39, '776'),
	(377, 1, 0, -50282, 778, 0, 0, 39, '777'),
	(377, 1, 0, -50282, 779, 0, 0, 39, '778'),
	(377, 1, 0, -50282, 780, 0, 0, 39, '779'),
	(377, 1, 0, -50282, 781, 0, 0, 39, '780'),
	(377, 1, 0, -50282, 782, 0, 0, 39, '781'),
	(377, 1, 0, -50282, 783, 0, 0, 39, '782'),
	(377, 1, 0, -50282, 784, 0, 0, 39, '783'),
	(377, 1, 0, -50282, 785, 0, 0, 39, '784'),
	(377, 1, 0, -50282, 786, 0, 0, 39, '785'),
	(377, 1, 0, -50282, 787, 0, 0, 39, '786'),
	(377, 1, 0, -50282, 788, 0, 0, 39, '787'),
	(377, 1, 0, -50282, 789, 0, 0, 39, '788'),
	(377, 1, 0, -50282, 790, 0, 0, 39, '789'),
	(377, 1, 0, -50282, 791, 0, 0, 39, '790'),
	(377, 1, 0, -50282, 792, 0, 0, 39, '791'),
	(377, 1, 0, -50282, 793, 0, 0, 39, '792'),
	(377, 1, 0, -50282, 794, 0, 0, 39, '793'),
	(377, 1, 0, -50282, 795, 0, 0, 39, '794'),
	(377, 1, 0, -50282, 796, 0, 0, 39, '795'),
	(377, 1, 0, -50282, 797, 0, 0, 39, '796'),
	(377, 1, 0, -50282, 798, 0, 0, 39, '797'),
	(377, 1, 0, -50282, 799, 0, 0, 39, '798'),
	(377, 1, 0, -50282, 800, 0, 0, 39, '799'),
	(377, 1, 0, -50282, 801, 0, 0, 39, '800'),
	(377, 1, 0, -50282, 802, 0, 0, 39, '801'),
	(377, 1, 0, -50282, 803, 0, 0, 39, '802'),
	(377, 1, 0, -50282, 804, 0, 0, 39, '803'),
	(377, 1, 0, -50282, 805, 0, 0, 39, '804'),
	(377, 1, 0, -50282, 806, 0, 0, 39, '805'),
	(377, 1, 0, -50282, 807, 0, 0, 39, '806'),
	(377, 1, 0, -50282, 808, 0, 0, 39, '807'),
	(377, 1, 0, -50282, 809, 0, 0, 39, '808'),
	(377, 1, 0, -50282, 810, 0, 0, 39, '809'),
	(377, 1, 0, -50282, 811, 0, 0, 39, '810'),
	(377, 1, 0, -50282, 812, 0, 0, 39, '811'),
	(377, 1, 0, -50282, 813, 0, 0, 39, '812'),
	(377, 1, 0, -50282, 814, 0, 0, 39, '813'),
	(377, 1, 0, -50282, 815, 0, 0, 39, '814'),
	(377, 1, 0, -50282, 816, 0, 0, 39, '815'),
	(377, 1, 0, -50282, 817, 0, 0, 39, '816'),
	(377, 1, 0, -50282, 818, 0, 0, 39, '817'),
	(377, 1, 0, -50282, 819, 0, 0, 39, '818'),
	(377, 1, 0, -50282, 820, 0, 0, 39, '819'),
	(377, 1, 0, -50282, 821, 0, 0, 39, '820'),
	(377, 1, 0, -50282, 822, 0, 0, 39, '821'),
	(377, 1, 0, -50282, 823, 0, 0, 39, '822'),
	(377, 1, 0, -50282, 824, 0, 0, 39, '823'),
	(377, 1, 0, -50282, 825, 0, 0, 39, '824'),
	(377, 1, 0, -50282, 826, 0, 0, 39, '825'),
	(377, 1, 0, -50282, 827, 0, 0, 39, '826'),
	(377, 1, 0, -50282, 828, 0, 0, 39, '827'),
	(377, 1, 0, -50282, 829, 0, 0, 39, '828'),
	(377, 1, 0, -50282, 830, 0, 0, 39, '829'),
	(377, 1, 0, -50282, 831, 0, 0, 39, '830'),
	(377, 1, 0, -50282, 832, 0, 0, 39, '831'),
	(377, 1, 0, -50282, 833, 0, 0, 39, '832'),
	(377, 1, 0, -50282, 834, 0, 0, 39, '833'),
	(377, 1, 0, -50282, 835, 0, 0, 39, '834'),
	(377, 1, 0, -50282, 836, 0, 0, 39, '835'),
	(377, 1, 0, -50282, 837, 0, 0, 39, '836'),
	(377, 1, 0, -50282, 838, 0, 0, 39, '837'),
	(377, 1, 0, -50282, 839, 0, 0, 39, '838'),
	(377, 1, 0, -50282, 840, 0, 0, 39, '839'),
	(377, 1, 0, -50282, 841, 0, 0, 39, '840'),
	(377, 1, 0, -50282, 842, 0, 0, 39, '841'),
	(377, 1, 0, -50282, 843, 0, 0, 39, '842'),
	(377, 1, 0, -50282, 844, 0, 0, 39, '843'),
	(377, 1, 0, -50282, 845, 0, 0, 39, '844'),
	(377, 1, 0, -50282, 846, 0, 0, 39, '845'),
	(377, 1, 0, -50282, 847, 0, 0, 39, '846'),
	(377, 1, 0, -50282, 848, 0, 0, 39, '847'),
	(377, 1, 0, -50282, 849, 0, 0, 39, '848'),
	(377, 1, 0, -50282, 850, 0, 0, 39, '849'),
	(377, 1, 0, -50282, 851, 0, 0, 39, '850'),
	(377, 1, 0, -50282, 852, 0, 0, 39, '851'),
	(377, 1, 0, -50282, 853, 0, 0, 39, '852'),
	(377, 1, 0, -50282, 854, 0, 0, 39, '853'),
	(377, 1, 0, -50282, 855, 0, 0, 39, '854'),
	(377, 1, 0, -50282, 856, 0, 0, 39, '855'),
	(377, 1, 0, -50282, 857, 0, 0, 39, '856'),
	(377, 1, 0, -50282, 858, 0, 0, 39, '857'),
	(377, 1, 0, -50282, 859, 0, 0, 39, '858'),
	(377, 1, 0, -50282, 860, 0, 0, 39, '859'),
	(377, 1, 0, -50282, 861, 0, 0, 39, '860'),
	(377, 1, 0, -50282, 862, 0, 0, 39, '861'),
	(377, 1, 0, -50282, 863, 0, 0, 39, '862'),
	(377, 1, 0, -50282, 864, 0, 0, 39, '863'),
	(377, 1, 0, -50282, 865, 0, 0, 39, '864'),
	(377, 1, 0, -50282, 866, 0, 0, 39, '865'),
	(377, 1, 0, -50282, 867, 0, 0, 39, '866'),
	(377, 1, 0, -50282, 868, 0, 0, 39, '867'),
	(377, 1, 0, -50282, 869, 0, 0, 39, '868'),
	(377, 1, 0, -50282, 870, 0, 0, 39, '869'),
	(377, 1, 0, -50282, 871, 0, 0, 39, '870'),
	(377, 1, 0, -50282, 872, 0, 0, 39, '871'),
	(377, 1, 0, -50282, 873, 0, 0, 39, '872'),
	(377, 1, 0, -50282, 874, 0, 0, 39, '873'),
	(377, 1, 0, -50282, 875, 0, 0, 39, '874'),
	(377, 1, 0, -50282, 876, 0, 0, 39, '875'),
	(377, 1, 0, -50282, 877, 0, 0, 39, '876'),
	(377, 1, 0, -50282, 878, 0, 0, 39, '877'),
	(377, 1, 0, -50282, 879, 0, 0, 39, '878'),
	(377, 1, 0, -50282, 880, 0, 0, 39, '879'),
	(377, 1, 0, -50282, 881, 0, 0, 39, '880'),
	(377, 1, 0, -50282, 882, 0, 0, 39, '881'),
	(377, 1, 0, -50282, 883, 0, 0, 39, '882'),
	(377, 1, 0, -50282, 884, 0, 0, 39, '883'),
	(377, 1, 0, -50282, 885, 0, 0, 39, '884'),
	(377, 1, 0, -50282, 886, 0, 0, 39, '885'),
	(377, 1, 0, -50282, 887, 0, 0, 39, '886'),
	(377, 1, 0, -50282, 888, 0, 0, 39, '887'),
	(377, 1, 0, -50282, 889, 0, 0, 39, '888'),
	(377, 1, 0, -50282, 890, 0, 0, 39, '889'),
	(377, 1, 0, -50282, 891, 0, 0, 39, '890'),
	(377, 1, 0, -50282, 892, 0, 0, 39, '891'),
	(377, 1, 0, -50282, 893, 0, 0, 39, '892'),
	(377, 1, 0, -50282, 894, 0, 0, 39, '893'),
	(377, 1, 0, -50282, 895, 0, 0, 39, '894'),
	(377, 1, 0, -50282, 896, 0, 0, 39, '895'),
	(377, 1, 0, -50282, 897, 0, 0, 39, '896'),
	(377, 1, 0, -50282, 898, 0, 0, 39, '897'),
	(377, 1, 0, -50282, 899, 0, 0, 39, '898'),
	(377, 1, 0, -50282, 900, 0, 0, 39, '899'),
	(377, 1, 0, -50282, 901, 0, 0, 39, '900'),
	(377, 1, 0, -50282, 902, 0, 0, 39, '901'),
	(377, 1, 0, -50282, 903, 0, 0, 39, '902'),
	(377, 1, 0, -50282, 904, 0, 0, 39, '903'),
	(377, 1, 0, -50282, 905, 0, 0, 39, '904'),
	(377, 1, 0, -50282, 906, 0, 0, 39, '905'),
	(377, 1, 0, -50282, 907, 0, 0, 39, '906'),
	(377, 1, 0, -50282, 908, 0, 0, 39, '907'),
	(377, 1, 0, -50282, 909, 0, 0, 39, '908'),
	(377, 1, 0, -50282, 910, 0, 0, 39, '909'),
	(377, 1, 0, -50282, 911, 0, 0, 39, '910'),
	(377, 1, 0, -50282, 912, 0, 0, 39, '911'),
	(377, 1, 0, -50282, 913, 0, 0, 39, '912'),
	(377, 1, 0, -50282, 914, 0, 0, 39, '913'),
	(377, 1, 0, -50282, 915, 0, 0, 39, '914'),
	(377, 1, 0, -50282, 916, 0, 0, 39, '915'),
	(377, 1, 0, -50282, 917, 0, 0, 39, '916'),
	(377, 1, 0, -50282, 918, 0, 0, 39, '917'),
	(377, 1, 0, -50282, 919, 0, 0, 39, '918'),
	(377, 1, 0, -50282, 920, 0, 0, 39, '919'),
	(377, 1, 0, -50282, 921, 0, 0, 39, '920'),
	(377, 1, 0, -50282, 922, 0, 0, 39, '921'),
	(377, 1, 0, -50282, 923, 0, 0, 39, '922'),
	(377, 1, 0, -50282, 924, 0, 0, 39, '923'),
	(377, 1, 0, -50282, 925, 0, 0, 39, '924'),
	(377, 1, 0, -50282, 926, 0, 0, 39, '925'),
	(377, 1, 0, -50282, 927, 0, 0, 39, '926'),
	(377, 1, 0, -50282, 928, 0, 0, 39, '927'),
	(377, 1, 0, -50282, 929, 0, 0, 39, '928'),
	(377, 1, 0, -50282, 930, 0, 0, 39, '929'),
	(377, 1, 0, -50282, 931, 0, 0, 39, '930'),
	(377, 1, 0, -50282, 932, 0, 0, 39, '931'),
	(377, 1, 0, -50282, 933, 0, 0, 39, '932'),
	(377, 1, 0, -50282, 934, 0, 0, 39, '933'),
	(377, 1, 0, -50282, 935, 0, 0, 39, '934'),
	(377, 1, 0, -50282, 936, 0, 0, 39, '935'),
	(377, 1, 0, -50282, 937, 0, 0, 39, '936'),
	(377, 1, 0, -50282, 938, 0, 0, 39, '937'),
	(377, 1, 0, -50282, 939, 0, 0, 39, '938'),
	(377, 1, 0, -50282, 940, 0, 0, 39, '939'),
	(377, 1, 0, -50282, 941, 0, 0, 39, '940'),
	(377, 1, 0, -50282, 942, 0, 0, 39, '941'),
	(377, 1, 0, -50282, 943, 0, 0, 39, '942'),
	(377, 1, 0, -50282, 944, 0, 0, 39, '943'),
	(377, 1, 0, -50282, 945, 0, 0, 39, '944'),
	(377, 1, 0, -50282, 946, 0, 0, 39, '945'),
	(377, 1, 0, -50282, 947, 0, 0, 39, '946'),
	(377, 1, 0, -50282, 948, 0, 0, 39, '947'),
	(377, 1, 0, -50282, 949, 0, 0, 39, '948'),
	(377, 1, 0, -50282, 950, 0, 0, 39, '949'),
	(377, 1, 0, -50282, 951, 0, 0, 39, '950'),
	(377, 1, 0, -50282, 952, 0, 0, 39, '951'),
	(377, 1, 0, -50282, 953, 0, 0, 39, '952'),
	(377, 1, 0, -50282, 954, 0, 0, 39, '953'),
	(377, 1, 0, -50282, 955, 0, 0, 39, '954'),
	(377, 1, 0, -50282, 956, 0, 0, 39, '955'),
	(377, 1, 0, -50282, 957, 0, 0, 39, '956'),
	(377, 1, 0, -50282, 958, 0, 0, 39, '957'),
	(377, 1, 0, -50282, 959, 0, 0, 39, '958'),
	(377, 1, 0, -50282, 960, 0, 0, 39, '959'),
	(377, 1, 0, -50282, 961, 0, 0, 39, '960'),
	(377, 1, 0, -50282, 962, 0, 0, 39, '961'),
	(377, 1, 0, -50282, 963, 0, 0, 39, '962'),
	(377, 1, 0, -50282, 964, 0, 0, 39, '963'),
	(377, 1, 0, -50282, 965, 0, 0, 39, '964'),
	(377, 1, 0, -50282, 966, 0, 0, 39, '965'),
	(377, 1, 0, -50282, 967, 0, 0, 39, '966'),
	(377, 1, 0, -50282, 968, 0, 0, 39, '967'),
	(377, 1, 0, -50282, 969, 0, 0, 39, '968'),
	(377, 1, 0, -50282, 970, 0, 0, 39, '969'),
	(377, 1, 0, -50282, 971, 0, 0, 39, '970'),
	(377, 1, 0, -50282, 972, 0, 0, 39, '971'),
	(377, 1, 0, -50282, 973, 0, 0, 39, '972'),
	(377, 1, 0, -50282, 974, 0, 0, 39, '973'),
	(377, 1, 0, -50282, 975, 0, 0, 39, '974'),
	(377, 1, 0, -50282, 976, 0, 0, 39, '975'),
	(377, 1, 0, -50282, 977, 0, 0, 39, '976'),
	(377, 1, 0, -50282, 978, 0, 0, 39, '977'),
	(377, 1, 0, -50282, 979, 0, 0, 39, '978'),
	(377, 1, 0, -50282, 980, 0, 0, 39, '979'),
	(377, 1, 0, -50282, 981, 0, 0, 39, '980'),
	(377, 1, 0, -50282, 982, 0, 0, 39, '981'),
	(377, 1, 0, -50282, 983, 0, 0, 39, '982'),
	(377, 1, 0, -50282, 984, 0, 0, 39, '983'),
	(377, 1, 0, -50282, 985, 0, 0, 39, '984'),
	(377, 1, 0, -50282, 986, 0, 0, 39, '985'),
	(377, 1, 0, -50282, 987, 0, 0, 39, '986'),
	(377, 1, 0, -50282, 988, 0, 0, 39, '987'),
	(377, 1, 0, -50282, 989, 0, 0, 39, '988'),
	(377, 1, 0, -50282, 990, 0, 0, 39, '989'),
	(377, 1, 0, -50282, 991, 0, 0, 39, '990'),
	(377, 1, 0, -50282, 992, 0, 0, 39, '991'),
	(377, 1, 0, -50282, 993, 0, 0, 39, '992'),
	(377, 1, 0, -50282, 994, 0, 0, 39, '993'),
	(377, 1, 0, -50282, 995, 0, 0, 39, '994'),
	(377, 1, 0, -50282, 996, 0, 0, 39, '995'),
	(377, 1, 0, -50282, 997, 0, 0, 39, '996'),
	(377, 1, 0, -50282, 998, 0, 0, 39, '997'),
	(377, 1, 0, -50282, 999, 0, 0, 39, '998'),
	(377, 1, 0, -50282, 1000, 0, 0, 39, '999'),
	(377, 1, 0, -50282, 1001, 0, 0, 39, '1000'),
	(377, 1, 0, -50282, 1002, 0, 0, 39, '1001'),
	(377, 1, 0, -50282, 1003, 0, 0, 39, '1002'),
	(377, 1, 0, -50282, 1004, 0, 0, 39, '1003'),
	(377, 1, 0, -50282, 1005, 0, 0, 39, '1004'),
	(377, 1, 0, -50282, 1006, 0, 0, 39, '1005'),
	(377, 1, 0, -50282, 1007, 0, 0, 39, '1006'),
	(377, 1, 0, -50282, 1008, 0, 0, 39, '1007'),
	(377, 1, 0, -50282, 1009, 0, 0, 39, '1008'),
	(377, 1, 0, -50282, 1010, 0, 0, 39, '1009'),
	(377, 1, 0, -50282, 1011, 0, 0, 39, '1010'),
	(377, 1, 0, -50282, 1012, 0, 0, 39, '1011'),
	(377, 1, 0, -50282, 1013, 0, 0, 39, '1012'),
	(377, 1, 0, -50282, 1014, 0, 0, 39, '1013'),
	(377, 1, 0, -50282, 1015, 0, 0, 39, '1014'),
	(377, 1, 0, -50282, 1016, 0, 0, 39, '1015'),
	(377, 1, 0, -50282, 1017, 0, 0, 39, '1016'),
	(377, 1, 0, -50282, 1018, 0, 0, 39, '1017'),
	(377, 1, 0, -50282, 1019, 0, 0, 39, '1018'),
	(377, 1, 0, -50282, 1020, 0, 0, 39, '1019'),
	(377, 1, 0, -50282, 1021, 0, 0, 39, '1020'),
	(377, 1, 0, -50282, 1022, 0, 0, 39, '1021'),
	(377, 1, 0, -50282, 1023, 0, 0, 39, '1022'),
	(377, 1, 0, -50282, 1024, 0, 0, 39, '1023'),
	(377, 1, 0, -50282, 1025, 0, 0, 39, '1024'),
	(377, 1, 0, -50282, 1026, 0, 0, 39, '1025'),
	(377, 1, 0, -50282, 1027, 0, 0, 39, '1026'),
	(377, 1, 0, -50282, 1028, 0, 0, 39, '1027'),
	(377, 1, 0, -50282, 1029, 0, 0, 39, '1028'),
	(377, 1, 0, -50282, 1030, 0, 0, 39, '1029'),
	(377, 1, 0, -50282, 1031, 0, 0, 39, '1030'),
	(377, 1, 0, -50282, 1032, 0, 0, 39, '1031'),
	(377, 1, 0, -50282, 1033, 0, 0, 39, '1032'),
	(377, 1, 0, -50282, 1034, 0, 0, 39, '1033'),
	(377, 1, 0, -50282, 1035, 0, 0, 39, '1034'),
	(377, 1, 0, -50282, 1036, 0, 0, 39, '1035'),
	(377, 1, 0, -50282, 1037, 0, 0, 39, '1036'),
	(377, 1, 0, -50282, 1038, 0, 0, 39, '1037'),
	(377, 1, 0, -50282, 1039, 0, 0, 39, '1038'),
	(377, 1, 0, -50282, 1040, 0, 0, 39, '1039'),
	(377, 1, 0, -50282, 1041, 0, 0, 39, '1040'),
	(377, 1, 0, -50282, 1042, 0, 0, 39, '1041'),
	(377, 1, 0, -50282, 1043, 0, 0, 39, '1042'),
	(377, 1, 0, -50282, 1044, 0, 0, 39, '1043'),
	(377, 1, 0, -50282, 1045, 0, 0, 39, '1044'),
	(377, 1, 0, -50282, 1046, 0, 0, 39, '1045'),
	(377, 1, 0, -50282, 1047, 0, 0, 39, '1046'),
	(377, 1, 0, -50282, 1048, 0, 0, 39, '1047'),
	(377, 1, 0, -50282, 1049, 0, 0, 39, '1048'),
	(377, 1, 0, -50282, 1050, 0, 0, 39, '1049'),
	(377, 1, 0, -50282, 1051, 0, 0, 39, '1050'),
	(377, 1, 0, -50282, 1052, 0, 0, 39, '1051'),
	(377, 1, 0, -50282, 1053, 0, 0, 39, '1052'),
	(377, 1, 0, -50282, 1054, 0, 0, 39, '1053'),
	(377, 1, 0, -50282, 1055, 0, 0, 39, '1054'),
	(377, 1, 0, -50282, 1056, 0, 0, 39, '1055'),
	(377, 1, 0, -50282, 1057, 0, 0, 39, '1056'),
	(377, 1, 0, -50282, 1058, 0, 0, 39, '1057'),
	(377, 1, 0, -50282, 1059, 0, 0, 39, '1058'),
	(377, 1, 0, -50282, 1060, 0, 0, 39, '1059'),
	(377, 1, 0, -50282, 1061, 0, 0, 39, '1060'),
	(377, 1, 0, -50282, 1062, 0, 0, 39, '1061'),
	(377, 1, 0, -50282, 1063, 0, 0, 39, '1062'),
	(377, 1, 0, -50282, 1064, 0, 0, 39, '1063'),
	(377, 1, 0, -50282, 1065, 0, 0, 39, '1064'),
	(377, 1, 0, -50282, 1066, 0, 0, 39, '1065'),
	(377, 1, 0, -50282, 1067, 0, 0, 39, '1066'),
	(377, 1, 0, -50282, 1068, 0, 0, 39, '1067'),
	(377, 1, 0, -50282, 1069, 0, 0, 39, '1068'),
	(377, 1, 0, -50282, 1070, 0, 0, 39, '1069'),
	(377, 1, 0, -50282, 1071, 0, 0, 39, '1070'),
	(377, 1, 0, -50282, 1072, 0, 0, 39, '1071'),
	(377, 1, 0, -50282, 1073, 0, 0, 39, '1072'),
	(377, 1, 0, -50282, 1074, 0, 0, 39, '1073'),
	(377, 1, 0, -50282, 1075, 0, 0, 39, '1074'),
	(377, 1, 0, -50282, 1076, 0, 0, 39, '1075'),
	(377, 1, 0, -50282, 1077, 0, 0, 39, '1076'),
	(377, 1, 0, -50282, 1078, 0, 0, 39, '1077'),
	(377, 1, 0, -50282, 1079, 0, 0, 39, '1078'),
	(377, 1, 0, -50282, 1080, 0, 0, 39, '1079'),
	(377, 1, 0, -50282, 1081, 0, 0, 39, '1080'),
	(377, 1, 0, -50282, 1082, 0, 0, 39, '1081'),
	(377, 1, 0, -50282, 1083, 0, 0, 39, '1082'),
	(377, 1, 0, -50282, 1084, 0, 0, 39, '1083'),
	(377, 1, 0, -50282, 1085, 0, 0, 39, '1084'),
	(377, 1, 0, -50282, 1086, 0, 0, 39, '1085'),
	(377, 1, 0, -50282, 1087, 0, 0, 39, '1086'),
	(377, 1, 0, -50282, 1088, 0, 0, 39, '1087'),
	(377, 1, 0, -50282, 1089, 0, 0, 39, '1088'),
	(377, 1, 0, -50282, 1090, 0, 0, 39, '1089'),
	(377, 1, 0, -50282, 1091, 0, 0, 39, '1090'),
	(377, 1, 0, -50282, 1092, 0, 0, 39, '1091'),
	(377, 1, 0, -50282, 1093, 0, 0, 39, '1092'),
	(377, 1, 0, -50282, 1094, 0, 0, 39, '1093'),
	(377, 1, 0, -50282, 1095, 0, 0, 39, '1094'),
	(377, 1, 0, -50282, 1096, 0, 0, 39, '1095'),
	(377, 1, 0, -50282, 1097, 0, 0, 39, '1096'),
	(377, 1, 0, -50282, 1098, 0, 0, 39, '1097'),
	(377, 1, 0, -50282, 1099, 0, 0, 39, '1098'),
	(377, 1, 0, -50282, 1100, 0, 0, 39, '1099'),
	(377, 1, 0, -50282, 1101, 0, 0, 39, '1100'),
	(377, 1, 0, -50282, 1102, 0, 0, 39, '1101'),
	(377, 1, 0, -50282, 1103, 0, 0, 39, '1102'),
	(377, 1, 0, -50282, 1104, 0, 0, 39, '1103'),
	(377, 1, 0, -50282, 1105, 0, 0, 39, '1104'),
	(377, 1, 0, -50282, 1106, 0, 0, 39, '1105'),
	(377, 1, 0, -50282, 1107, 0, 0, 39, '1106'),
	(377, 1, 0, -50282, 1108, 0, 0, 39, '1107'),
	(377, 1, 0, -50282, 1109, 0, 0, 39, '1108'),
	(377, 1, 0, -50282, 1110, 0, 0, 39, '1109'),
	(377, 1, 0, -50282, 1111, 0, 0, 39, '1110'),
	(377, 1, 0, -50282, 1112, 0, 0, 39, '1111'),
	(377, 1, 0, -50282, 1113, 0, 0, 39, '1112'),
	(377, 1, 0, -50282, 1114, 0, 0, 39, '1113'),
	(377, 1, 0, -50282, 1115, 0, 0, 39, '1114'),
	(377, 1, 0, -50282, 1116, 0, 0, 39, '1115'),
	(377, 1, 0, -50282, 1117, 0, 0, 39, '1116'),
	(377, 1, 0, -50282, 1118, 0, 0, 39, '1117'),
	(377, 1, 0, -50282, 1119, 0, 0, 39, '1118'),
	(377, 1, 0, -50282, 1120, 0, 0, 39, '1119'),
	(377, 1, 0, -50282, 1121, 0, 0, 39, '1120'),
	(377, 1, 0, -50282, 1122, 0, 0, 39, '1121'),
	(377, 1, 0, -50282, 1123, 0, 0, 39, '1122'),
	(377, 1, 0, -50282, 1124, 0, 0, 39, '1123'),
	(377, 1, 0, -50282, 1125, 0, 0, 39, '1124'),
	(377, 1, 0, -50282, 1126, 0, 0, 39, '1125'),
	(377, 1, 0, -50282, 1127, 0, 0, 39, '1126'),
	(377, 1, 0, -50282, 1128, 0, 0, 39, '1127'),
	(377, 1, 0, -50282, 1129, 0, 0, 39, '1128'),
	(377, 1, 0, -50282, 1130, 0, 0, 39, '1129'),
	(377, 1, 0, -50282, 1131, 0, 0, 39, '1130'),
	(377, 1, 0, -50282, 1132, 0, 0, 39, '1131'),
	(377, 1, 0, -50282, 1133, 0, 0, 39, '1132'),
	(377, 1, 0, -50282, 1134, 0, 0, 39, '1133'),
	(377, 1, 0, -50282, 1135, 0, 0, 39, '1134'),
	(377, 1, 0, -50282, 1136, 0, 0, 39, '1135'),
	(377, 1, 0, -50282, 1137, 0, 0, 39, '1136'),
	(377, 1, 0, -50282, 1138, 0, 0, 39, '1137'),
	(377, 1, 0, -50282, 1139, 0, 0, 39, '1138'),
	(377, 1, 0, -50282, 1140, 0, 0, 39, '1139'),
	(377, 1, 0, -50282, 1141, 0, 0, 39, '1140'),
	(377, 1, 0, -50282, 1142, 0, 0, 39, '1141'),
	(377, 1, 0, -50282, 1143, 0, 0, 39, '1142'),
	(377, 1, 0, -50282, 1144, 0, 0, 39, '1143'),
	(377, 1, 0, -50282, 1145, 0, 0, 39, '1144'),
	(377, 1, 0, -50282, 1146, 0, 0, 39, '1145'),
	(377, 1, 0, -50282, 1147, 0, 0, 39, '1146'),
	(377, 1, 0, -50282, 1148, 0, 0, 39, '1147'),
	(377, 1, 0, -50282, 1149, 0, 0, 39, '1148'),
	(377, 1, 0, -50282, 1150, 0, 0, 39, '1149'),
	(377, 1, 0, -50282, 1151, 0, 0, 39, '1150'),
	(377, 1, 0, -50282, 1152, 0, 0, 39, '1151'),
	(377, 1, 0, -50282, 1153, 0, 0, 39, '1152'),
	(377, 1, 0, -50282, 1154, 0, 0, 39, '1153'),
	(377, 1, 0, -50282, 1155, 0, 0, 39, '1154'),
	(377, 1, 0, -50282, 1156, 0, 0, 39, '1155'),
	(377, 1, 0, -50282, 1157, 0, 0, 39, '1156'),
	(377, 1, 0, -50282, 1158, 0, 0, 39, '1157'),
	(377, 1, 0, -50282, 1159, 0, 0, 39, '1158'),
	(377, 1, 0, -50282, 1160, 0, 0, 39, '1159'),
	(377, 1, 0, -50282, 1161, 0, 0, 39, '1160'),
	(377, 1, 0, -50282, 1162, 0, 0, 39, '1161'),
	(377, 1, 0, -50282, 1163, 0, 0, 39, '1162'),
	(377, 1, 0, -50282, 1164, 0, 0, 39, '1163'),
	(377, 1, 0, -50282, 1165, 0, 0, 39, '1164'),
	(377, 1, 0, -50282, 1166, 0, 0, 39, '1165'),
	(377, 1, 0, -50282, 1167, 0, 0, 39, '1166'),
	(377, 1, 0, -50282, 1168, 0, 0, 39, '1167'),
	(377, 1, 0, -50282, 1169, 0, 0, 39, '1168'),
	(377, 1, 0, -50282, 1170, 0, 0, 39, '1169'),
	(377, 1, 0, -50282, 1171, 0, 0, 39, '1170'),
	(377, 1, 0, -50282, 1172, 0, 0, 39, '1171'),
	(377, 1, 0, -50282, 1173, 0, 0, 39, '1172'),
	(377, 1, 0, -50282, 1174, 0, 0, 39, '1173'),
	(377, 1, 0, -50282, 1175, 0, 0, 39, '1174'),
	(377, 1, 0, -50282, 1176, 0, 0, 39, '1175'),
	(377, 1, 0, -50282, 1177, 0, 0, 39, '1176'),
	(377, 1, 0, -50282, 1178, 0, 0, 39, '1177'),
	(377, 1, 0, -50282, 1179, 0, 0, 39, '1178'),
	(377, 1, 0, -50282, 1180, 0, 0, 39, '1179'),
	(377, 1, 0, -50282, 1181, 0, 0, 39, '1180'),
	(377, 1, 0, -50282, 1182, 0, 0, 39, '1181'),
	(377, 1, 0, -50282, 1183, 0, 0, 39, '1182'),
	(377, 1, 0, -50282, 1184, 0, 0, 39, '1183'),
	(377, 1, 0, -50282, 1185, 0, 0, 39, '1184'),
	(377, 1, 0, -50282, 1186, 0, 0, 39, '1185'),
	(377, 1, 0, -50282, 1187, 0, 0, 39, '1186'),
	(377, 1, 0, -50282, 1188, 0, 0, 39, '1187'),
	(377, 1, 0, -50282, 1189, 0, 0, 39, '1188'),
	(377, 1, 0, -50282, 1190, 0, 0, 39, '1189'),
	(377, 1, 0, -50282, 1191, 0, 0, 39, '1190'),
	(377, 1, 0, -50282, 1192, 0, 0, 39, '1191'),
	(377, 1, 0, -50282, 1193, 0, 0, 39, '1192'),
	(377, 1, 0, -50282, 1194, 0, 0, 39, '1193'),
	(377, 1, 0, -50282, 1195, 0, 0, 39, '1194'),
	(377, 1, 0, -50282, 1196, 0, 0, 39, '1195'),
	(377, 1, 0, -50282, 1197, 0, 0, 39, '1196'),
	(377, 1, 0, -50282, 1198, 0, 0, 39, '1197'),
	(377, 1, 0, -50282, 1199, 0, 0, 39, '1198'),
	(377, 1, 0, -50282, 1200, 0, 0, 39, '1199'),
	(377, 1, 0, -50282, 1201, 0, 0, 39, '1200'),
	(377, 1, 0, -50282, 1202, 0, 0, 39, '1201'),
	(377, 1, 0, -50282, 1203, 0, 0, 39, '1202'),
	(377, 1, 0, -50282, 1204, 0, 0, 39, '1203'),
	(377, 1, 0, -50282, 1205, 0, 0, 39, '1204'),
	(377, 1, 0, -50282, 1206, 0, 0, 39, '1205'),
	(377, 1, 0, -50282, 1207, 0, 0, 39, '1206'),
	(377, 1, 0, -50282, 1208, 0, 0, 39, '1207'),
	(377, 1, 0, -50282, 1209, 0, 0, 39, '1208'),
	(377, 1, 0, -50282, 1210, 0, 0, 39, '1209'),
	(377, 1, 0, -50282, 1211, 0, 0, 39, '1210'),
	(377, 1, 0, -50282, 1212, 0, 0, 39, '1211'),
	(377, 1, 0, -50282, 1213, 0, 0, 39, '1212'),
	(377, 1, 0, -50282, 1214, 0, 0, 39, '1213'),
	(377, 1, 0, -50282, 1215, 0, 0, 39, '1214'),
	(377, 1, 0, -50282, 1216, 0, 0, 39, '1215'),
	(377, 1, 0, -50282, 1217, 0, 0, 39, '1216'),
	(377, 1, 0, -50282, 1218, 0, 0, 39, '1217'),
	(377, 1, 0, -50282, 1219, 0, 0, 39, '1218'),
	(377, 1, 0, -50282, 1220, 0, 0, 39, '1219'),
	(377, 1, 0, -50282, 1221, 0, 0, 39, '1220'),
	(377, 1, 0, -50282, 1222, 0, 0, 39, '1221'),
	(377, 1, 0, -50282, 1223, 0, 0, 39, '1222'),
	(377, 1, 0, -50282, 1224, 0, 0, 39, '1223'),
	(377, 1, 0, -50282, 1225, 0, 0, 39, '1224'),
	(377, 1, 0, -50282, 1226, 0, 0, 39, '1225'),
	(377, 1, 0, -50282, 1227, 0, 0, 39, '1226'),
	(377, 1, 0, -50282, 1228, 0, 0, 39, '1227'),
	(377, 1, 0, -50282, 1229, 0, 0, 39, '1228'),
	(377, 1, 0, -50282, 1230, 0, 0, 39, '1229'),
	(377, 1, 0, -50282, 1231, 0, 0, 39, '1230'),
	(377, 1, 0, -50282, 1232, 0, 0, 39, '1231'),
	(377, 1, 0, -50282, 1233, 0, 0, 39, '1232'),
	(377, 1, 0, -50282, 1234, 0, 0, 39, '1233'),
	(377, 1, 0, -50282, 1235, 0, 0, 39, '1234'),
	(377, 1, 0, -50282, 1236, 0, 0, 39, '1235'),
	(377, 1, 0, -50282, 1237, 0, 0, 39, '1236'),
	(377, 1, 0, -50282, 1238, 0, 0, 39, '1237'),
	(377, 1, 0, -50282, 1239, 0, 0, 39, '1238'),
	(377, 1, 0, -50282, 1240, 0, 0, 39, '1239'),
	(377, 1, 0, -50282, 1241, 0, 0, 39, '1240'),
	(377, 1, 0, -50282, 1242, 0, 0, 39, '1241'),
	(377, 1, 0, -50282, 1243, 0, 0, 39, '1242'),
	(377, 1, 0, -50282, 1244, 0, 0, 39, '1243'),
	(377, 1, 0, -50282, 1245, 0, 0, 39, '1244'),
	(377, 1, 0, -50282, 1246, 0, 0, 39, '1245'),
	(377, 1, 0, -50282, 1247, 0, 0, 39, '1246'),
	(377, 1, 0, -50282, 1248, 0, 0, 39, '1247'),
	(377, 1, 0, -50282, 1249, 0, 0, 39, '1248'),
	(377, 1, 0, -50282, 1250, 0, 0, 39, '1249'),
	(377, 1, 0, -50282, 1251, 0, 0, 39, '1250'),
	(377, 1, 0, -50282, 1252, 0, 0, 39, '1251'),
	(377, 1, 0, -50282, 1253, 0, 0, 39, '1252'),
	(377, 1, 0, -50282, 1254, 0, 0, 39, '1253'),
	(377, 1, 0, -50282, 1255, 0, 0, 39, '1254'),
	(377, 1, 0, -50282, 1256, 0, 0, 39, '1255'),
	(377, 1, 0, -50282, 1257, 0, 0, 39, '1256'),
	(377, 1, 0, -50282, 1258, 0, 0, 39, '1257'),
	(377, 1, 0, -50282, 1259, 0, 0, 39, '1258'),
	(377, 1, 0, -50282, 1260, 0, 0, 39, '1259'),
	(377, 1, 0, -50282, 1261, 0, 0, 39, '1260'),
	(377, 1, 0, -50282, 1262, 0, 0, 39, '1261'),
	(377, 1, 0, -50282, 1263, 0, 0, 39, '1262'),
	(377, 1, 0, -50282, 1264, 0, 0, 39, '1263'),
	(377, 1, 0, -50282, 1265, 0, 0, 39, '1264'),
	(377, 1, 0, -50282, 1266, 0, 0, 39, '1265'),
	(377, 1, 0, -50282, 1267, 0, 0, 39, '1266'),
	(377, 1, 0, -50282, 1268, 0, 0, 39, '1267'),
	(377, 1, 0, -50282, 1269, 0, 0, 39, '1268'),
	(377, 1, 0, -50282, 1270, 0, 0, 39, '1269'),
	(377, 1, 0, -50282, 1271, 0, 0, 39, '1270'),
	(377, 1, 0, -50282, 1272, 0, 0, 39, '1271'),
	(377, 1, 0, -50282, 1273, 0, 0, 39, '1272'),
	(377, 1, 0, -50282, 1274, 0, 0, 39, '1273'),
	(377, 1, 0, -50282, 1275, 0, 0, 39, '1274'),
	(377, 1, 0, -50282, 1276, 0, 0, 39, '1275'),
	(377, 1, 0, -50282, 1277, 0, 0, 39, '1276'),
	(377, 1, 0, -50282, 1278, 0, 0, 39, '1277'),
	(377, 1, 0, -50282, 1279, 0, 0, 39, '1278'),
	(377, 1, 0, -50282, 1280, 0, 0, 39, '1279'),
	(377, 1, 0, -50282, 1281, 0, 0, 39, '1280'),
	(377, 1, 0, -50282, 1282, 0, 0, 39, '1281'),
	(377, 1, 0, -50282, 1283, 0, 0, 39, '1282'),
	(377, 1, 0, -50282, 1284, 0, 0, 39, '1283'),
	(377, 1, 0, -50282, 1285, 0, 0, 39, '1284'),
	(377, 1, 0, -50282, 1286, 0, 0, 39, '1285'),
	(377, 1, 0, -50282, 1287, 0, 0, 39, '1286'),
	(377, 1, 0, -50282, 1288, 0, 0, 39, '1287'),
	(377, 1, 0, -50282, 1289, 0, 0, 39, '1288'),
	(377, 1, 0, -50282, 1290, 0, 0, 39, '1289'),
	(377, 1, 0, -50282, 1291, 0, 0, 39, '1290'),
	(377, 1, 0, -50282, 1292, 0, 0, 39, '1291'),
	(377, 1, 0, -50282, 1293, 0, 0, 39, '1292'),
	(377, 1, 0, -50282, 1294, 0, 0, 39, '1293'),
	(377, 1, 0, -50282, 1295, 0, 0, 39, '1294'),
	(377, 1, 0, -50282, 1296, 0, 0, 39, '1295'),
	(377, 1, 0, -50282, 1297, 0, 0, 39, '1296'),
	(377, 1, 0, -50282, 1298, 0, 0, 39, '1297'),
	(377, 1, 0, -50282, 1299, 0, 0, 39, '1298'),
	(377, 1, 0, -50282, 1300, 0, 0, 39, '1299'),
	(377, 1, 0, -50282, 1301, 0, 0, 39, '1300'),
	(377, 1, 0, -50282, 1302, 0, 0, 39, '1301'),
	(377, 1, 0, -50282, 1303, 0, 0, 39, '1302'),
	(377, 1, 0, -50282, 1304, 0, 0, 39, '1303'),
	(377, 1, 0, -50282, 1305, 0, 0, 39, '1304'),
	(377, 1, 0, -50282, 1306, 0, 0, 39, '1305'),
	(377, 1, 0, -50282, 1307, 0, 0, 39, '1306'),
	(377, 1, 0, -50282, 1308, 0, 0, 39, '1307'),
	(377, 1, 0, -50282, 1309, 0, 0, 39, '1308'),
	(377, 1, 0, -50282, 1310, 0, 0, 39, '1309'),
	(377, 1, 0, -50282, 1311, 0, 0, 39, '1310'),
	(377, 1, 0, -50282, 1312, 0, 0, 39, '1311'),
	(377, 1, 0, -50282, 1313, 0, 0, 39, '1312'),
	(377, 1, 0, -50282, 1314, 0, 0, 39, '1313'),
	(377, 1, 0, -50282, 1315, 0, 0, 39, '1314'),
	(377, 1, 0, -50282, 1316, 0, 0, 39, '1315'),
	(377, 1, 0, -50282, 1317, 0, 0, 39, '1316'),
	(377, 1, 0, -50282, 1318, 0, 0, 39, '1317'),
	(377, 1, 0, -50282, 1319, 0, 0, 39, '1318'),
	(377, 1, 0, -50282, 1320, 0, 0, 39, '1319'),
	(377, 1, 0, -50282, 1321, 0, 0, 39, '1320'),
	(377, 1, 0, -50282, 1322, 0, 0, 39, '1321'),
	(377, 1, 0, -50282, 1323, 0, 0, 39, '1322'),
	(377, 1, 0, -50282, 1324, 0, 0, 39, '1323'),
	(377, 1, 0, -50282, 1325, 0, 0, 39, '1324'),
	(377, 1, 0, -50282, 1326, 0, 0, 39, '1325'),
	(377, 1, 0, -50282, 1327, 0, 0, 39, '1326'),
	(377, 1, 0, -50282, 1328, 0, 0, 39, '1327'),
	(377, 1, 0, -50282, 1329, 0, 0, 39, '1328'),
	(377, 1, 0, -50282, 1330, 0, 0, 39, '1329'),
	(377, 1, 0, -50282, 1331, 0, 0, 39, '1330'),
	(377, 1, 0, -50282, 1332, 0, 0, 39, '1331'),
	(377, 1, 0, -50282, 1333, 0, 0, 39, '1332'),
	(377, 1, 0, -50282, 1334, 0, 0, 39, '1333'),
	(377, 1, 0, -50282, 1335, 0, 0, 39, '1334'),
	(377, 1, 0, -50282, 1336, 0, 0, 39, '1335'),
	(377, 1, 0, -50282, 1337, 0, 0, 39, '1336'),
	(377, 1, 0, -50282, 1338, 0, 0, 39, '1337'),
	(377, 1, 0, -50282, 1339, 0, 0, 39, '1338'),
	(377, 1, 0, -50282, 1340, 0, 0, 39, '1339'),
	(377, 1, 0, -50282, 1341, 0, 0, 39, '1340'),
	(377, 1, 0, -50282, 1342, 0, 0, 39, '1341'),
	(377, 1, 0, -50282, 1343, 0, 0, 39, '1342'),
	(377, 1, 0, -50282, 1344, 0, 0, 39, '1343'),
	(377, 1, 0, -50282, 1345, 0, 0, 39, '1344'),
	(377, 1, 0, -50282, 1346, 0, 0, 39, '1345'),
	(377, 1, 0, -50282, 1347, 0, 0, 39, '1346'),
	(377, 1, 0, -50282, 1348, 0, 0, 39, '1347'),
	(377, 1, 0, -50282, 1349, 0, 0, 39, '1348'),
	(377, 1, 0, -50282, 1350, 0, 0, 39, '1349'),
	(377, 1, 0, -50282, 1351, 0, 0, 39, '1350'),
	(377, 1, 0, -50282, 1352, 0, 0, 39, '1351'),
	(377, 1, 0, -50282, 1353, 0, 0, 39, '1352'),
	(377, 1, 0, -50282, 1354, 0, 0, 39, '1353'),
	(377, 1, 0, -50282, 1355, 0, 0, 39, '1354'),
	(377, 1, 0, -50282, 1356, 0, 0, 39, '1355'),
	(377, 1, 0, -50282, 1357, 0, 0, 39, '1356'),
	(377, 1, 0, -50282, 1358, 0, 0, 39, '1357'),
	(377, 1, 0, -50282, 1359, 0, 0, 39, '1358'),
	(377, 1, 0, -50282, 1360, 0, 0, 39, '1359'),
	(377, 1, 0, -50282, 1361, 0, 0, 39, '1360'),
	(377, 1, 0, -50282, 1362, 0, 0, 39, '1361'),
	(377, 1, 0, -50282, 1363, 0, 0, 39, '1362'),
	(377, 1, 0, -50282, 1364, 0, 0, 39, '1363'),
	(377, 1, 0, -50282, 1365, 0, 0, 39, '1364'),
	(377, 1, 0, -50282, 1366, 0, 0, 39, '1365'),
	(377, 1, 0, -50282, 1367, 0, 0, 39, '1366'),
	(377, 1, 0, -50282, 1368, 0, 0, 39, '1367'),
	(377, 1, 0, -50282, 1369, 0, 0, 39, '1368'),
	(377, 1, 0, -50282, 1370, 0, 0, 39, '1369'),
	(377, 1, 0, -50282, 1371, 0, 0, 39, '1370'),
	(377, 1, 0, -50282, 1372, 0, 0, 39, '1371'),
	(377, 1, 0, -50282, 1373, 0, 0, 39, '1372'),
	(377, 1, 0, -50282, 1374, 0, 0, 39, '1373'),
	(377, 1, 0, -50282, 1375, 0, 0, 39, '1374'),
	(377, 1, 0, -50282, 1376, 0, 0, 39, '1375'),
	(377, 1, 0, -50282, 1377, 0, 0, 39, '1376'),
	(377, 1, 0, -50282, 1378, 0, 0, 39, '1377'),
	(377, 1, 0, -50282, 1379, 0, 0, 39, '1378'),
	(377, 1, 0, -50282, 1380, 0, 0, 39, '1379'),
	(377, 1, 0, -50282, 1381, 0, 0, 39, '1380'),
	(377, 1, 0, -50282, 1382, 0, 0, 39, '1381'),
	(377, 1, 0, -50282, 1383, 0, 0, 39, '1382'),
	(377, 1, 0, -50282, 1384, 0, 0, 39, '1383'),
	(377, 1, 0, -50282, 1385, 0, 0, 39, '1384'),
	(377, 1, 0, -50282, 1386, 0, 0, 39, '1385'),
	(377, 1, 0, -50282, 1387, 0, 0, 39, '1386'),
	(377, 1, 0, -50282, 1388, 0, 0, 39, '1387'),
	(377, 1, 0, -50282, 1389, 0, 0, 39, '1388'),
	(377, 1, 0, -50282, 1390, 0, 0, 39, '1389'),
	(377, 1, 0, -50282, 1391, 0, 0, 39, '1390'),
	(377, 1, 0, -50282, 1392, 0, 0, 39, '1391'),
	(377, 1, 0, -50282, 1393, 0, 0, 39, '1392'),
	(377, 1, 0, -50282, 1394, 0, 0, 39, '1393'),
	(377, 1, 0, -50282, 1395, 0, 0, 39, '1394'),
	(377, 1, 0, -50282, 1396, 0, 0, 39, '1395'),
	(377, 1, 0, -50282, 1397, 0, 0, 39, '1396'),
	(377, 1, 0, -50282, 1398, 0, 0, 39, '1397'),
	(377, 1, 0, -50282, 1399, 0, 0, 39, '1398'),
	(377, 1, 0, -50282, 1400, 0, 0, 39, '1399'),
	(377, 1, 0, -50282, 1401, 0, 0, 39, '1400'),
	(377, 1, 0, -50282, 1402, 0, 0, 39, '1401'),
	(377, 1, 0, -50282, 1403, 0, 0, 39, '1402'),
	(377, 1, 0, -50282, 1404, 0, 0, 39, '1403'),
	(377, 1, 0, -50282, 1405, 0, 0, 39, '1404'),
	(377, 1, 0, -50282, 1406, 0, 0, 39, '1405'),
	(377, 1, 0, -50282, 1407, 0, 0, 39, '1406'),
	(377, 1, 0, -50282, 1408, 0, 0, 39, '1407'),
	(377, 1, 0, -50282, 1409, 0, 0, 39, '1408'),
	(377, 1, 0, -50282, 1410, 0, 0, 39, '1409'),
	(377, 1, 0, -50282, 1411, 0, 0, 39, '1410'),
	(377, 1, 0, -50282, 1412, 0, 0, 39, '1411'),
	(377, 1, 0, -50282, 1413, 0, 0, 39, '1412'),
	(377, 1, 0, -50282, 1414, 0, 0, 39, '1413'),
	(377, 1, 0, -50282, 1415, 0, 0, 39, '1414'),
	(377, 1, 0, -50282, 1416, 0, 0, 39, '1415'),
	(377, 1, 0, -50282, 1417, 0, 0, 39, '1416'),
	(377, 1, 0, -50282, 1418, 0, 0, 39, '1417'),
	(377, 1, 0, -50282, 1419, 0, 0, 39, '1418'),
	(377, 1, 0, -50282, 1420, 0, 0, 39, '1419'),
	(377, 1, 0, -50282, 1421, 0, 0, 39, '1420'),
	(377, 1, 0, -50282, 1422, 0, 0, 39, '1421'),
	(377, 1, 0, -50282, 1423, 0, 0, 39, '1422'),
	(377, 1, 0, -50282, 1424, 0, 0, 39, '1423'),
	(377, 1, 0, -50282, 1425, 0, 0, 39, '1424'),
	(377, 1, 0, -50282, 1426, 0, 0, 39, '1425'),
	(377, 1, 0, -50282, 1427, 0, 0, 39, '1426'),
	(377, 1, 0, -50282, 1428, 0, 0, 39, '1427'),
	(377, 1, 0, -50282, 1429, 0, 0, 39, '1428'),
	(377, 1, 0, -50282, 1430, 0, 0, 39, '1429'),
	(377, 1, 0, -50282, 1431, 0, 0, 39, '1430'),
	(377, 1, 0, -50282, 1432, 0, 0, 39, '1431'),
	(377, 1, 0, -50282, 1433, 0, 0, 39, '1432'),
	(377, 1, 0, -50282, 1434, 0, 0, 39, '1433'),
	(377, 1, 0, -50282, 1435, 0, 0, 39, '1434'),
	(377, 1, 0, -50282, 1436, 0, 0, 39, '1435'),
	(377, 1, 0, -50282, 1437, 0, 0, 39, '1436'),
	(377, 1, 0, -50282, 1438, 0, 0, 39, '1437'),
	(377, 1, 0, -50282, 1439, 0, 0, 39, '1438'),
	(377, 1, 0, -50282, 1440, 0, 0, 39, '1439'),
	(377, 1, 0, -50282, 1441, 0, 0, 39, '1440'),
	(377, 1, 0, -50282, 1442, 0, 0, 39, '1441'),
	(377, 1, 0, -50282, 1443, 0, 0, 39, '1442'),
	(377, 1, 0, -50282, 1444, 0, 0, 39, '1443'),
	(377, 1, 0, -50282, 1445, 0, 0, 39, '1444'),
	(377, 1, 0, -50282, 1446, 0, 0, 39, '1445'),
	(377, 1, 0, -50282, 1447, 0, 0, 39, '1446'),
	(377, 1, 0, -50282, 1448, 0, 0, 39, '1447'),
	(377, 1, 0, -50282, 1449, 0, 0, 39, '1448'),
	(377, 1, 0, -50282, 1450, 0, 0, 39, '1449'),
	(377, 1, 0, -50282, 1451, 0, 0, 39, '1450'),
	(377, 1, 0, -50282, 1452, 0, 0, 39, '1451'),
	(377, 1, 0, -50282, 1453, 0, 0, 39, '1452'),
	(377, 1, 0, -50282, 1454, 0, 0, 39, '1453'),
	(377, 1, 0, -50282, 1455, 0, 0, 39, '1454'),
	(377, 1, 0, -50282, 1456, 0, 0, 39, '1455'),
	(377, 1, 0, -50282, 1457, 0, 0, 39, '1456'),
	(377, 1, 0, -50282, 1458, 0, 0, 39, '1457'),
	(377, 1, 0, -50282, 1459, 0, 0, 39, '1458'),
	(377, 1, 0, -50282, 1460, 0, 0, 39, '1459'),
	(377, 1, 0, -50282, 1461, 0, 0, 39, '1460'),
	(377, 1, 0, -50282, 1462, 0, 0, 39, '1461'),
	(377, 1, 0, -50282, 1463, 0, 0, 39, '1462'),
	(377, 1, 0, -50282, 1464, 0, 0, 39, '1463'),
	(377, 1, 0, -50282, 1465, 0, 0, 39, '1464'),
	(377, 1, 0, -50282, 1466, 0, 0, 39, '1465'),
	(377, 1, 0, -50282, 1467, 0, 0, 39, '1466'),
	(377, 1, 0, -50282, 1468, 0, 0, 39, '1467'),
	(377, 1, 0, -50282, 1469, 0, 0, 39, '1468'),
	(377, 1, 0, -50282, 1470, 0, 0, 39, '1469'),
	(377, 1, 0, -50282, 1471, 0, 0, 39, '1470'),
	(377, 1, 0, -50282, 1472, 0, 0, 39, '1471'),
	(377, 1, 0, -50282, 1473, 0, 0, 39, '1472'),
	(377, 1, 0, -50282, 1474, 0, 0, 39, '1473'),
	(377, 1, 0, -50282, 1475, 0, 0, 39, '1474'),
	(377, 1, 0, -50282, 1476, 0, 0, 39, '1475'),
	(377, 1, 0, -50282, 1477, 0, 0, 39, '1476'),
	(377, 1, 0, -50282, 1478, 0, 0, 39, '1477'),
	(377, 1, 0, -50282, 1479, 0, 0, 39, '1478'),
	(377, 1, 0, -50282, 1480, 0, 0, 39, '1479'),
	(377, 1, 0, -50282, 1481, 0, 0, 39, '1480'),
	(377, 1, 0, -50282, 1482, 0, 0, 39, '1481'),
	(377, 1, 0, -50282, 1483, 0, 0, 39, '1482'),
	(377, 1, 0, -50282, 1484, 0, 0, 39, '1483'),
	(377, 1, 0, -50282, 1485, 0, 0, 39, '1484'),
	(377, 1, 0, -50282, 1486, 0, 0, 39, '1485'),
	(377, 1, 0, -50282, 1487, 0, 0, 39, '1486'),
	(377, 1, 0, -50282, 1488, 0, 0, 39, '1487'),
	(377, 1, 0, -50282, 1489, 0, 0, 39, '1488'),
	(377, 1, 0, -50282, 1490, 0, 0, 39, '1489'),
	(377, 1, 0, -50282, 1491, 0, 0, 39, '1490'),
	(377, 1, 0, -50282, 1492, 0, 0, 39, '1491'),
	(377, 1, 0, -50282, 1493, 0, 0, 39, '1492'),
	(377, 1, 0, -50282, 1494, 0, 0, 39, '1493'),
	(377, 1, 0, -50282, 1495, 0, 0, 39, '1494'),
	(377, 1, 0, -50282, 1496, 0, 0, 39, '1495'),
	(377, 1, 0, -50282, 1497, 0, 0, 39, '1496'),
	(377, 1, 0, -50282, 1498, 0, 0, 39, '1497'),
	(377, 1, 0, -50282, 1499, 0, 0, 39, '1498'),
	(377, 1, 0, -50282, 1500, 0, 0, 39, '1499'),
	(377, 1, 0, -50282, 1501, 0, 0, 39, '1500'),
	(377, 1, 0, -50282, 1502, 0, 0, 39, '1501'),
	(377, 1, 0, -50282, 1503, 0, 0, 39, '1502'),
	(377, 1, 0, -50282, 1504, 0, 0, 39, '1503'),
	(377, 1, 0, -50282, 1505, 0, 0, 39, '1504'),
	(377, 1, 0, -50282, 1506, 0, 0, 39, '1505'),
	(377, 1, 0, -50282, 1507, 0, 0, 39, '1506'),
	(377, 1, 0, -50282, 1508, 0, 0, 39, '1507'),
	(377, 1, 0, -50282, 1509, 0, 0, 39, '1508'),
	(377, 1, 0, -50282, 1510, 0, 0, 39, '1509'),
	(377, 1, 0, -50282, 1511, 0, 0, 39, '1510'),
	(377, 1, 0, -50282, 1512, 0, 0, 39, '1511'),
	(377, 1, 0, -50282, 1513, 0, 0, 39, '1512'),
	(377, 1, 0, -50282, 1514, 0, 0, 39, '1513'),
	(377, 1, 0, -50282, 1515, 0, 0, 39, '1514'),
	(377, 1, 0, -50282, 1516, 0, 0, 39, '1515'),
	(377, 1, 0, -50282, 1517, 0, 0, 39, '1516'),
	(377, 1, 0, -50282, 1518, 0, 0, 39, '1517'),
	(377, 1, 0, -50282, 1519, 0, 0, 39, '1518'),
	(377, 1, 0, -50282, 1520, 0, 0, 39, '1519'),
	(377, 1, 0, -50282, 1521, 0, 0, 39, '1520'),
	(377, 1, 0, -50282, 1522, 0, 0, 39, '1521'),
	(377, 1, 0, -50282, 1523, 0, 0, 39, '1522'),
	(377, 1, 0, -50282, 1524, 0, 0, 39, '1523'),
	(377, 1, 0, -50282, 1525, 0, 0, 39, '1524'),
	(377, 1, 0, -50282, 1526, 0, 0, 39, '1525'),
	(377, 1, 0, -50282, 1527, 0, 0, 39, '1526'),
	(377, 1, 0, -50282, 1528, 0, 0, 39, '1527'),
	(377, 1, 0, -50282, 1529, 0, 0, 39, '1528'),
	(377, 1, 0, -50282, 1530, 0, 0, 39, '1529'),
	(377, 1, 0, -50282, 1531, 0, 0, 39, '1530'),
	(377, 1, 0, -50282, 1532, 0, 0, 39, '1531'),
	(377, 1, 0, -50282, 1533, 0, 0, 39, '1532'),
	(377, 1, 0, -50282, 1534, 0, 0, 39, '1533'),
	(377, 1, 0, -50282, 1535, 0, 0, 39, '1534'),
	(377, 1, 0, -50282, 1536, 0, 0, 39, '1535'),
	(377, 1, 0, -50282, 1537, 0, 0, 39, '1536'),
	(377, 1, 0, -50282, 1538, 0, 0, 39, '1537'),
	(377, 1, 0, -50282, 1539, 0, 0, 39, '1538'),
	(377, 1, 0, -50282, 1540, 0, 0, 39, '1539'),
	(377, 1, 0, -50282, 1541, 0, 0, 39, '1540'),
	(377, 1, 0, -50282, 1542, 0, 0, 39, '1541'),
	(377, 1, 0, -50282, 1543, 0, 0, 39, '1542'),
	(377, 1, 0, -50282, 1544, 0, 0, 39, '1543'),
	(377, 1, 0, -50282, 1545, 0, 0, 39, '1544'),
	(377, 1, 0, -50282, 1546, 0, 0, 39, '1545'),
	(377, 1, 0, -50282, 1547, 0, 0, 39, '1546'),
	(377, 1, 0, -50282, 1548, 0, 0, 39, '1547'),
	(377, 1, 0, -50282, 1549, 0, 0, 39, '1548'),
	(377, 1, 0, -50282, 1550, 0, 0, 39, '1549'),
	(377, 1, 0, -50282, 1551, 0, 0, 39, '1550'),
	(377, 1, 0, -50282, 1552, 0, 0, 39, '1551'),
	(377, 1, 0, -50282, 1553, 0, 0, 39, '1552'),
	(377, 1, 0, -50282, 1554, 0, 0, 39, '1553'),
	(377, 1, 0, -50282, 1555, 0, 0, 39, '1554'),
	(377, 1, 0, -50282, 1556, 0, 0, 39, '1555'),
	(377, 1, 0, -50282, 1557, 0, 0, 39, '1556'),
	(377, 1, 0, -50282, 1558, 0, 0, 39, '1557'),
	(377, 1, 0, -50282, 1559, 0, 0, 39, '1558'),
	(377, 1, 0, -50282, 1560, 0, 0, 39, '1559'),
	(377, 1, 0, -50282, 1561, 0, 0, 39, '1560'),
	(377, 1, 0, -50282, 1562, 0, 0, 39, '1561'),
	(377, 1, 0, -50282, 1563, 0, 0, 39, '1562'),
	(377, 1, 0, -50282, 1564, 0, 0, 39, '1563'),
	(377, 1, 0, -50282, 1565, 0, 0, 39, '1564'),
	(377, 1, 0, -50282, 1566, 0, 0, 39, '1565'),
	(377, 1, 0, -50282, 1567, 0, 0, 39, '1566'),
	(377, 1, 0, -50282, 1568, 0, 0, 39, '1567'),
	(377, 1, 0, -50282, 1569, 0, 0, 39, '1568'),
	(377, 1, 0, -50282, 1570, 0, 0, 39, '1569'),
	(377, 1, 0, -50282, 1571, 0, 0, 39, '1570'),
	(377, 1, 0, -50282, 1572, 0, 0, 39, '1571'),
	(377, 1, 0, -50282, 1573, 0, 0, 39, '1572'),
	(377, 1, 0, -50282, 1574, 0, 0, 39, '1573'),
	(377, 1, 0, -50282, 1575, 0, 0, 39, '1574'),
	(377, 1, 0, -50282, 1576, 0, 0, 39, '1575'),
	(377, 1, 0, -50282, 1577, 0, 0, 39, '1576'),
	(377, 1, 0, -50282, 1578, 0, 0, 39, '1577'),
	(377, 1, 0, -50282, 1579, 0, 0, 39, '1578'),
	(377, 1, 0, -50282, 1580, 0, 0, 39, '1579'),
	(377, 1, 0, -50282, 1581, 0, 0, 39, '1580'),
	(377, 1, 0, -50282, 1582, 0, 0, 39, '1581'),
	(377, 1, 0, -50282, 1583, 0, 0, 39, '1582'),
	(377, 1, 0, -50282, 1584, 0, 0, 39, '1583'),
	(377, 1, 0, -50282, 1585, 0, 0, 39, '1584'),
	(377, 1, 0, -50282, 1586, 0, 0, 39, '1585'),
	(377, 1, 0, -50282, 1587, 0, 0, 39, '1586'),
	(377, 1, 0, -50282, 1588, 0, 0, 39, '1587'),
	(377, 1, 0, -50282, 1589, 0, 0, 39, '1588'),
	(377, 1, 0, -50282, 1590, 0, 0, 39, '1589'),
	(377, 1, 0, -50282, 1591, 0, 0, 39, '1590'),
	(377, 1, 0, -50282, 1592, 0, 0, 39, '1591'),
	(377, 1, 0, -50282, 1593, 0, 0, 39, '1592'),
	(377, 1, 0, -50282, 1594, 0, 0, 39, '1593'),
	(377, 1, 0, -50282, 1595, 0, 0, 39, '1594'),
	(377, 1, 0, -50282, 1596, 0, 0, 39, '1595'),
	(377, 1, 0, -50282, 1597, 0, 0, 39, '1596'),
	(377, 1, 0, -50282, 1598, 0, 0, 39, '1597'),
	(377, 1, 0, -50282, 1599, 0, 0, 39, '1598'),
	(377, 1, 0, -50282, 1600, 0, 0, 39, '1599'),
	(377, 1, 0, -50282, 1601, 0, 0, 39, '1600'),
	(377, 1, 0, -50282, 1602, 0, 0, 39, '1601'),
	(377, 1, 0, -50282, 1603, 0, 0, 39, '1602'),
	(377, 1, 0, -50282, 1604, 0, 0, 39, '1603'),
	(377, 1, 0, -50282, 1605, 0, 0, 39, '1604'),
	(377, 1, 0, -50282, 1606, 0, 0, 39, '1605'),
	(377, 1, 0, -50282, 1607, 0, 0, 39, '1606'),
	(377, 1, 0, -50282, 1608, 0, 0, 39, '1607'),
	(377, 1, 0, -50282, 1609, 0, 0, 39, '1608'),
	(377, 1, 0, -50282, 1610, 0, 0, 39, '1609'),
	(377, 1, 0, -50282, 1611, 0, 0, 39, '1610'),
	(377, 1, 0, -50282, 1612, 0, 0, 39, '1611'),
	(377, 1, 0, -50282, 1613, 0, 0, 39, '1612'),
	(377, 1, 0, -50282, 1614, 0, 0, 39, '1613'),
	(377, 1, 0, -50282, 1615, 0, 0, 39, '1614'),
	(377, 1, 0, -50282, 1616, 0, 0, 39, '1615'),
	(377, 1, 0, -50282, 1617, 0, 0, 39, '1616'),
	(377, 1, 0, -50282, 1618, 0, 0, 39, '1617'),
	(377, 1, 0, -50282, 1619, 0, 0, 39, '1618'),
	(377, 1, 0, -50282, 1620, 0, 0, 39, '1619'),
	(377, 1, 0, -50282, 1621, 0, 0, 39, '1620'),
	(377, 1, 0, -50282, 1622, 0, 0, 39, '1621'),
	(377, 1, 0, -50282, 1623, 0, 0, 39, '1622'),
	(377, 1, 0, -50282, 1624, 0, 0, 39, '1623'),
	(377, 1, 0, -50282, 1625, 0, 0, 39, '1624'),
	(377, 1, 0, -50282, 1626, 0, 0, 39, '1625'),
	(377, 1, 0, -50282, 1627, 0, 0, 39, '1626'),
	(377, 1, 0, -50282, 1628, 0, 0, 39, '1627'),
	(377, 1, 0, -50282, 1629, 0, 0, 39, '1628'),
	(377, 1, 0, -50282, 1630, 0, 0, 39, '1629'),
	(377, 1, 0, -50282, 1631, 0, 0, 39, '1630'),
	(377, 1, 0, -50282, 1632, 0, 0, 39, '1631'),
	(377, 1, 0, -50282, 1633, 0, 0, 39, '1632'),
	(377, 1, 0, -50282, 1634, 0, 0, 39, '1633'),
	(377, 1, 0, -50282, 1635, 0, 0, 39, '1634'),
	(377, 1, 0, -50282, 1636, 0, 0, 39, '1635'),
	(377, 1, 0, -50282, 1637, 0, 0, 39, '1636'),
	(377, 1, 0, -50282, 1638, 0, 0, 39, '1637'),
	(377, 1, 0, -50282, 1639, 0, 0, 39, '1638'),
	(377, 1, 0, -50282, 1640, 0, 0, 39, '1639'),
	(377, 1, 0, -50282, 1641, 0, 0, 39, '1640'),
	(377, 1, 0, -50282, 1642, 0, 0, 39, '1641'),
	(377, 1, 0, -50282, 1643, 0, 0, 39, '1642'),
	(377, 1, 0, -50282, 1644, 0, 0, 39, '1643'),
	(377, 1, 0, -50282, 1645, 0, 0, 39, '1644'),
	(377, 1, 0, -50282, 1646, 0, 0, 39, '1645'),
	(377, 1, 0, -50282, 1647, 0, 0, 39, '1646'),
	(377, 1, 0, -50282, 1648, 0, 0, 39, '1647'),
	(377, 1, 0, -50282, 1649, 0, 0, 39, '1648'),
	(377, 1, 0, -50282, 1650, 0, 0, 39, '1649'),
	(377, 1, 0, -50282, 1651, 0, 0, 39, '1650'),
	(377, 1, 0, -50282, 1652, 0, 0, 39, '1651'),
	(377, 1, 0, -50282, 1653, 0, 0, 39, '1652'),
	(377, 1, 0, -50282, 1654, 0, 0, 39, '1653'),
	(377, 1, 0, -50282, 1655, 0, 0, 39, '1654'),
	(377, 1, 0, -50282, 1656, 0, 0, 39, '1655'),
	(377, 1, 0, -50282, 1657, 0, 0, 39, '1656'),
	(377, 1, 0, -50282, 1658, 0, 0, 39, '1657'),
	(377, 1, 0, -50282, 1659, 0, 0, 39, '1658'),
	(377, 1, 0, -50282, 1660, 0, 0, 39, '1659'),
	(377, 1, 0, -50282, 1661, 0, 0, 39, '1660'),
	(377, 1, 0, -50282, 1662, 0, 0, 39, '1661'),
	(377, 1, 0, -50282, 1663, 0, 0, 39, '1662'),
	(377, 1, 0, -50282, 1664, 0, 0, 39, '1663'),
	(377, 1, 0, -50282, 1665, 0, 0, 39, '1664'),
	(377, 1, 0, -50282, 1666, 0, 0, 39, '1665'),
	(377, 1, 0, -50282, 1667, 0, 0, 39, '1666'),
	(377, 1, 0, -50282, 1668, 0, 0, 39, '1667'),
	(377, 1, 0, -50282, 1669, 0, 0, 39, '1668'),
	(377, 1, 0, -50282, 1670, 0, 0, 39, '1669'),
	(377, 1, 0, -50282, 1671, 0, 0, 39, '1670'),
	(377, 1, 0, -50282, 1672, 0, 0, 39, '1671'),
	(377, 1, 0, -50282, 1673, 0, 0, 39, '1672'),
	(377, 1, 0, -50282, 1674, 0, 0, 39, '1673'),
	(377, 1, 0, -50282, 1675, 0, 0, 39, '1674'),
	(377, 1, 0, -50282, 1676, 0, 0, 39, '1675'),
	(377, 1, 0, -50282, 1677, 0, 0, 39, '1676'),
	(377, 1, 0, -50282, 1678, 0, 0, 39, '1677'),
	(377, 1, 0, -50282, 1679, 0, 0, 39, '1678'),
	(377, 1, 0, -50282, 1680, 0, 0, 39, '1679'),
	(377, 1, 0, -50282, 1681, 0, 0, 39, '1680'),
	(377, 1, 0, -50282, 1682, 0, 0, 39, '1681'),
	(377, 1, 0, -50282, 1683, 0, 0, 39, '1682'),
	(377, 1, 0, -50282, 1684, 0, 0, 39, '1683'),
	(377, 1, 0, -50282, 1685, 0, 0, 39, '1684'),
	(377, 1, 0, -50282, 1686, 0, 0, 39, '1685'),
	(377, 1, 0, -50282, 1687, 0, 0, 39, '1686'),
	(377, 1, 0, -50282, 1688, 0, 0, 39, '1687'),
	(377, 1, 0, -50282, 1689, 0, 0, 39, '1688'),
	(377, 1, 0, -50282, 1690, 0, 0, 39, '1689'),
	(377, 1, 0, -50282, 1691, 0, 0, 39, '1690'),
	(377, 1, 0, -50282, 1692, 0, 0, 39, '1691'),
	(377, 1, 0, -50282, 1693, 0, 0, 39, '1692'),
	(377, 1, 0, -50282, 1694, 0, 0, 39, '1693'),
	(377, 1, 0, -50282, 1695, 0, 0, 39, '1694'),
	(377, 1, 0, -50282, 1696, 0, 0, 39, '1695'),
	(377, 1, 0, -50282, 1697, 0, 0, 39, '1696'),
	(377, 1, 0, -50282, 1698, 0, 0, 39, '1697'),
	(377, 1, 0, -50282, 1699, 0, 0, 39, '1698'),
	(377, 1, 0, -50282, 1700, 0, 0, 39, '1699'),
	(377, 1, 0, -50282, 1701, 0, 0, 39, '1700'),
	(377, 1, 0, -50282, 1702, 0, 0, 39, '1701'),
	(377, 1, 0, -50282, 1703, 0, 0, 39, '1702'),
	(377, 1, 0, -50282, 1704, 0, 0, 39, '1703'),
	(377, 1, 0, -50282, 1705, 0, 0, 39, '1704'),
	(377, 1, 0, -50282, 1706, 0, 0, 39, '1705'),
	(377, 1, 0, -50282, 1707, 0, 0, 39, '1706'),
	(377, 1, 0, -50282, 1708, 0, 0, 39, '1707'),
	(377, 1, 0, -50282, 1709, 0, 0, 39, '1708'),
	(377, 1, 0, -50282, 1710, 0, 0, 39, '1709'),
	(377, 1, 0, -50282, 1711, 0, 0, 39, '1710'),
	(377, 1, 0, -50282, 1712, 0, 0, 39, '1711'),
	(377, 1, 0, -50282, 1713, 0, 0, 39, '1712'),
	(377, 1, 0, -50282, 1714, 0, 0, 39, '1713'),
	(377, 1, 0, -50282, 1715, 0, 0, 39, '1714'),
	(377, 1, 0, -50282, 1716, 0, 0, 39, '1715'),
	(377, 1, 0, -50282, 1717, 0, 0, 39, '1716'),
	(377, 1, 0, -50282, 1718, 0, 0, 39, '1717'),
	(377, 1, 0, -50282, 1719, 0, 0, 39, '1718'),
	(377, 1, 0, -50282, 1720, 0, 0, 39, '1719'),
	(377, 1, 0, -50282, 1721, 0, 0, 39, '1720'),
	(377, 1, 0, -50282, 1722, 0, 0, 39, '1721'),
	(377, 1, 0, -50282, 1723, 0, 0, 39, '1722'),
	(377, 1, 0, -50282, 1724, 0, 0, 39, '1723'),
	(377, 1, 0, -50282, 1725, 0, 0, 39, '1724'),
	(377, 1, 0, -50282, 1726, 0, 0, 39, '1725'),
	(377, 1, 0, -50282, 1727, 0, 0, 39, '1726'),
	(377, 1, 0, -50282, 1728, 0, 0, 39, '1727'),
	(377, 1, 0, -50282, 1729, 0, 0, 39, '1728'),
	(377, 1, 0, -50282, 1730, 0, 0, 39, '1729'),
	(377, 1, 0, -50282, 1731, 0, 0, 39, '1730'),
	(377, 1, 0, -50282, 1732, 0, 0, 39, '1731'),
	(377, 1, 0, -50282, 1733, 0, 0, 39, '1732'),
	(377, 1, 0, -50282, 1734, 0, 0, 39, '1733'),
	(377, 1, 0, -50282, 1735, 0, 0, 39, '1734'),
	(377, 1, 0, -50282, 1736, 0, 0, 39, '1735'),
	(377, 1, 0, -50282, 1737, 0, 0, 39, '1736'),
	(377, 1, 0, -50282, 1738, 0, 0, 39, '1737'),
	(377, 1, 0, -50282, 1739, 0, 0, 39, '1738'),
	(377, 1, 0, -50282, 1740, 0, 0, 39, '1739'),
	(377, 1, 0, -50282, 1741, 0, 0, 39, '1740'),
	(377, 1, 0, -50282, 1742, 0, 0, 39, '1741'),
	(377, 1, 0, -50282, 1743, 0, 0, 39, '1742'),
	(377, 1, 0, -50282, 1744, 0, 0, 39, '1743'),
	(377, 1, 0, -50282, 1745, 0, 0, 39, '1744'),
	(377, 1, 0, -50282, 1746, 0, 0, 39, '1745'),
	(377, 1, 0, -50282, 1747, 0, 0, 39, '1746'),
	(377, 1, 0, -50282, 1748, 0, 0, 39, '1747'),
	(377, 1, 0, -50282, 1749, 0, 0, 39, '1748'),
	(377, 1, 0, -50282, 1750, 0, 0, 39, '1749'),
	(377, 1, 0, -50282, 1751, 0, 0, 39, '1750'),
	(377, 1, 0, -50282, 1752, 0, 0, 39, '1751'),
	(377, 1, 0, -50282, 1753, 0, 0, 39, '1752'),
	(377, 1, 0, -50282, 1754, 0, 0, 39, '1753'),
	(377, 1, 0, -50282, 1755, 0, 0, 39, '1754'),
	(377, 1, 0, -50282, 1756, 0, 0, 39, '1755'),
	(377, 1, 0, -50282, 1757, 0, 0, 39, '1756'),
	(377, 1, 0, -50282, 1758, 0, 0, 39, '1757'),
	(377, 1, 0, -50282, 1759, 0, 0, 39, '1758'),
	(377, 1, 0, -50282, 1760, 0, 0, 39, '1759'),
	(377, 1, 0, -50282, 1761, 0, 0, 39, '1760'),
	(377, 1, 0, -50282, 1762, 0, 0, 39, '1761'),
	(377, 1, 0, -50282, 1763, 0, 0, 39, '1762'),
	(377, 1, 0, -50282, 1764, 0, 0, 39, '1763'),
	(377, 1, 0, -50282, 1765, 0, 0, 39, '1764'),
	(377, 1, 0, -50282, 1766, 0, 0, 39, '1765'),
	(377, 1, 0, -50282, 1767, 0, 0, 39, '1766'),
	(377, 1, 0, -50282, 1768, 0, 0, 39, '1767'),
	(377, 1, 0, -50282, 1769, 0, 0, 39, '1768'),
	(377, 1, 0, -50282, 1770, 0, 0, 39, '1769'),
	(377, 1, 0, -50282, 1771, 0, 0, 39, '1770'),
	(377, 1, 0, -50282, 1772, 0, 0, 39, '1771'),
	(377, 1, 0, -50282, 1773, 0, 0, 39, '1772'),
	(377, 1, 0, -50282, 1774, 0, 0, 39, '1773'),
	(377, 1, 0, -50282, 1775, 0, 0, 39, '1774'),
	(377, 1, 0, -50282, 1776, 0, 0, 39, '1775'),
	(377, 1, 0, -50282, 1777, 0, 0, 39, '1776'),
	(377, 1, 0, -50282, 1778, 0, 0, 39, '1777'),
	(377, 1, 0, -50282, 1779, 0, 0, 39, '1778'),
	(377, 1, 0, -50282, 1780, 0, 0, 39, '1779'),
	(377, 1, 0, -50282, 1781, 0, 0, 39, '1780'),
	(377, 1, 0, -50282, 1782, 0, 0, 39, '1781'),
	(377, 1, 0, -50282, 1783, 0, 0, 39, '1782'),
	(377, 1, 0, -50282, 1784, 0, 0, 39, '1783'),
	(377, 1, 0, -50282, 1785, 0, 0, 39, '1784'),
	(377, 1, 0, -50282, 1786, 0, 0, 39, '1785'),
	(377, 1, 0, -50282, 1787, 0, 0, 39, '1786'),
	(377, 1, 0, -50282, 1788, 0, 0, 39, '1787'),
	(377, 1, 0, -50282, 1789, 0, 0, 39, '1788'),
	(377, 1, 0, -50282, 1790, 0, 0, 39, '1789'),
	(377, 1, 0, -50282, 1791, 0, 0, 39, '1790'),
	(377, 1, 0, -50282, 1792, 0, 0, 39, '1791'),
	(377, 1, 0, -50282, 1793, 0, 0, 39, '1792'),
	(377, 1, 0, -50282, 1794, 0, 0, 39, '1793'),
	(377, 1, 0, -50282, 1795, 0, 0, 39, '1794'),
	(377, 1, 0, -50282, 1796, 0, 0, 39, '1795'),
	(377, 1, 0, -50282, 1797, 0, 0, 39, '1796'),
	(377, 1, 0, -50282, 1798, 0, 0, 39, '1797'),
	(377, 1, 0, -50282, 1799, 0, 0, 39, '1798'),
	(377, 1, 0, -50282, 1800, 0, 0, 39, '1799'),
	(377, 1, 0, -50282, 1801, 0, 0, 39, '1800'),
	(377, 1, 0, -50282, 1802, 0, 0, 39, '1801'),
	(377, 1, 0, -50282, 1803, 0, 0, 39, '1802'),
	(377, 1, 0, -50282, 1804, 0, 0, 39, '1803'),
	(377, 1, 0, -50282, 1805, 0, 0, 39, '1804'),
	(377, 1, 0, -50282, 1806, 0, 0, 39, '1805'),
	(377, 1, 0, -50282, 1807, 0, 0, 39, '1806'),
	(377, 1, 0, -50282, 1808, 0, 0, 39, '1807'),
	(377, 1, 0, -50282, 1809, 0, 0, 39, '1808'),
	(377, 1, 0, -50282, 1810, 0, 0, 39, '1809'),
	(377, 1, 0, -50282, 1811, 0, 0, 39, '1810'),
	(377, 1, 0, -50282, 1812, 0, 0, 39, '1811'),
	(377, 1, 0, -50282, 1813, 0, 0, 39, '1812'),
	(377, 1, 0, -50282, 1814, 0, 0, 39, '1813'),
	(377, 1, 0, -50282, 1815, 0, 0, 39, '1814'),
	(377, 1, 0, -50282, 1816, 0, 0, 39, '1815'),
	(377, 1, 0, -50282, 1817, 0, 0, 39, '1816'),
	(377, 1, 0, -50282, 1818, 0, 0, 39, '1817'),
	(377, 1, 0, -50282, 1819, 0, 0, 39, '1818'),
	(377, 1, 0, -50282, 1820, 0, 0, 39, '1819'),
	(377, 1, 0, -50282, 1821, 0, 0, 39, '1820'),
	(377, 1, 0, -50282, 1822, 0, 0, 39, '1821'),
	(377, 1, 0, -50282, 1823, 0, 0, 39, '1822'),
	(377, 1, 0, -50282, 1824, 0, 0, 39, '1823'),
	(377, 1, 0, -50282, 1825, 0, 0, 39, '1824'),
	(377, 1, 0, -50282, 1826, 0, 0, 39, '1825'),
	(377, 1, 0, -50282, 1827, 0, 0, 39, '1826'),
	(377, 1, 0, -50282, 1828, 0, 0, 39, '1827'),
	(377, 1, 0, -50282, 1829, 0, 0, 39, '1828'),
	(377, 1, 0, -50282, 1830, 0, 0, 39, '1829'),
	(377, 1, 0, -50282, 1831, 0, 0, 39, '1830'),
	(377, 1, 0, -50282, 1832, 0, 0, 39, '1831'),
	(377, 1, 0, -50282, 1833, 0, 0, 39, '1832'),
	(377, 1, 0, -50282, 1834, 0, 0, 39, '1833'),
	(377, 1, 0, -50282, 1835, 0, 0, 39, '1834'),
	(377, 1, 0, -50282, 1836, 0, 0, 39, '1835'),
	(377, 1, 0, -50282, 1837, 0, 0, 39, '1836'),
	(377, 1, 0, -50282, 1838, 0, 0, 39, '1837'),
	(377, 1, 0, -50282, 1839, 0, 0, 39, '1838'),
	(377, 1, 0, -50282, 1840, 0, 0, 39, '1839'),
	(377, 1, 0, -50282, 1841, 0, 0, 39, '1840'),
	(377, 1, 0, -50282, 1842, 0, 0, 39, '1841'),
	(377, 1, 0, -50282, 1843, 0, 0, 39, '1842'),
	(377, 1, 0, -50282, 1844, 0, 0, 39, '1843'),
	(377, 1, 0, -50282, 1845, 0, 0, 39, '1844'),
	(377, 1, 0, -50282, 1846, 0, 0, 39, '1845'),
	(377, 1, 0, -50282, 1847, 0, 0, 39, '1846'),
	(377, 1, 0, -50282, 1848, 0, 0, 39, '1847'),
	(377, 1, 0, -50282, 1849, 0, 0, 39, '1848'),
	(377, 1, 0, -50282, 1850, 0, 0, 39, '1849'),
	(377, 1, 0, -50282, 1851, 0, 0, 39, '1850'),
	(377, 1, 0, -50282, 1852, 0, 0, 39, '1851'),
	(377, 1, 0, -50282, 1853, 0, 0, 39, '1852'),
	(377, 1, 0, -50282, 1854, 0, 0, 39, '1853'),
	(377, 1, 0, -50282, 1855, 0, 0, 39, '1854'),
	(377, 1, 0, -50282, 1856, 0, 0, 39, '1855'),
	(377, 1, 0, -50282, 1857, 0, 0, 39, '1856'),
	(377, 1, 0, -50282, 1858, 0, 0, 39, '1857'),
	(377, 1, 0, -50282, 1859, 0, 0, 39, '1858'),
	(377, 1, 0, -50282, 1860, 0, 0, 39, '1859'),
	(377, 1, 0, -50282, 1861, 0, 0, 39, '1860'),
	(377, 1, 0, -50282, 1862, 0, 0, 39, '1861'),
	(377, 1, 0, -50282, 1863, 0, 0, 39, '1862'),
	(377, 1, 0, -50282, 1864, 0, 0, 39, '1863'),
	(377, 1, 0, -50282, 1865, 0, 0, 39, '1864'),
	(377, 1, 0, -50282, 1866, 0, 0, 39, '1865'),
	(377, 1, 0, -50282, 1867, 0, 0, 39, '1866'),
	(377, 1, 0, -50282, 1868, 0, 0, 39, '1867'),
	(377, 1, 0, -50282, 1869, 0, 0, 39, '1868'),
	(377, 1, 0, -50282, 1870, 0, 0, 39, '1869'),
	(377, 1, 0, -50282, 1871, 0, 0, 39, '1870'),
	(377, 1, 0, -50282, 1872, 0, 0, 39, '1871'),
	(377, 1, 0, -50282, 1873, 0, 0, 39, '1872'),
	(377, 1, 0, -50282, 1874, 0, 0, 39, '1873'),
	(377, 1, 0, -50282, 1875, 0, 0, 39, '1874'),
	(377, 1, 0, -50282, 1876, 0, 0, 39, '1875'),
	(377, 1, 0, -50282, 1877, 0, 0, 39, '1876'),
	(377, 1, 0, -50282, 1878, 0, 0, 39, '1877'),
	(377, 1, 0, -50282, 1879, 0, 0, 39, '1878'),
	(377, 1, 0, -50282, 1880, 0, 0, 39, '1879'),
	(377, 1, 0, -50282, 1881, 0, 0, 39, '1880'),
	(377, 1, 0, -50282, 1882, 0, 0, 39, '1881'),
	(377, 1, 0, -50282, 1883, 0, 0, 39, '1882'),
	(377, 1, 0, -50282, 1884, 0, 0, 39, '1883'),
	(377, 1, 0, -50282, 1885, 0, 0, 39, '1884'),
	(377, 1, 0, -50282, 1886, 0, 0, 39, '1885'),
	(377, 1, 0, -50282, 1887, 0, 0, 39, '1886'),
	(377, 1, 0, -50282, 1888, 0, 0, 39, '1887'),
	(377, 1, 0, -50282, 1889, 0, 0, 39, '1888'),
	(377, 1, 0, -50282, 1890, 0, 0, 39, '1889'),
	(377, 1, 0, -50282, 1891, 0, 0, 39, '1890'),
	(377, 1, 0, -50282, 1892, 0, 0, 39, '1891'),
	(377, 1, 0, -50282, 1893, 0, 0, 39, '1892'),
	(377, 1, 0, -50282, 1894, 0, 0, 39, '1893'),
	(377, 1, 0, -50282, 1895, 0, 0, 39, '1894'),
	(377, 1, 0, -50282, 1896, 0, 0, 39, '1895'),
	(377, 1, 0, -50282, 1897, 0, 0, 39, '1896'),
	(377, 1, 0, -50282, 1898, 0, 0, 39, '1897'),
	(377, 1, 0, -50282, 1899, 0, 0, 39, '1898'),
	(377, 1, 0, -50282, 1900, 0, 0, 39, '1899'),
	(377, 1, 0, -50282, 1901, 0, 0, 39, '1900'),
	(377, 1, 0, -50282, 1902, 0, 0, 39, '1901'),
	(377, 1, 0, -50282, 1903, 0, 0, 39, '1902'),
	(377, 1, 0, -50282, 1904, 0, 0, 39, '1903'),
	(377, 1, 0, -50282, 1905, 0, 0, 39, '1904'),
	(377, 1, 0, -50282, 1906, 0, 0, 39, '1905'),
	(377, 1, 0, -50282, 1907, 0, 0, 39, '1906'),
	(377, 1, 0, -50282, 1908, 0, 0, 39, '1907'),
	(377, 1, 0, -50282, 1909, 0, 0, 39, '1908'),
	(377, 1, 0, -50282, 1910, 0, 0, 39, '1909'),
	(377, 1, 0, -50282, 1911, 0, 0, 39, '1910'),
	(377, 1, 0, -50282, 1912, 0, 0, 39, '1911'),
	(377, 1, 0, -50282, 1913, 0, 0, 39, '1912'),
	(377, 1, 0, -50282, 1914, 0, 0, 39, '1913'),
	(377, 1, 0, -50282, 1915, 0, 0, 39, '1914'),
	(377, 1, 0, -50282, 1916, 0, 0, 39, '1915'),
	(377, 1, 0, -50282, 1917, 0, 0, 39, '1916'),
	(377, 1, 0, -50282, 1918, 0, 0, 39, '1917'),
	(377, 1, 0, -50282, 1919, 0, 0, 39, '1918'),
	(377, 1, 0, -50282, 1920, 0, 0, 39, '1919'),
	(377, 1, 0, -50282, 1921, 0, 0, 39, '1920'),
	(377, 1, 0, -50282, 1922, 0, 0, 39, '1921'),
	(377, 1, 0, -50282, 1923, 0, 0, 39, '1922'),
	(377, 1, 0, -50282, 1924, 0, 0, 39, '1923'),
	(377, 1, 0, -50282, 1925, 0, 0, 39, '1924'),
	(377, 1, 0, -50282, 1926, 0, 0, 39, '1925'),
	(377, 1, 0, -50282, 1927, 0, 0, 39, '1926'),
	(377, 1, 0, -50282, 1928, 0, 0, 39, '1927'),
	(377, 1, 0, -50282, 1929, 0, 0, 39, '1928'),
	(377, 1, 0, -50282, 1930, 0, 0, 39, '1929'),
	(377, 1, 0, -50282, 1931, 0, 0, 39, '1930'),
	(377, 1, 0, -50282, 1932, 0, 0, 39, '1931'),
	(377, 1, 0, -50282, 1933, 0, 0, 39, '1932'),
	(377, 1, 0, -50282, 1934, 0, 0, 39, '1933'),
	(377, 1, 0, -50282, 1935, 0, 0, 39, '1934'),
	(377, 1, 0, -50282, 1936, 0, 0, 39, '1935'),
	(377, 1, 0, -50282, 1937, 0, 0, 39, '1936'),
	(377, 1, 0, -50282, 1938, 0, 0, 39, '1937'),
	(377, 1, 0, -50282, 1939, 0, 0, 39, '1938'),
	(377, 1, 0, -50282, 1940, 0, 0, 39, '1939'),
	(377, 1, 0, -50282, 1941, 0, 0, 39, '1940'),
	(377, 1, 0, -50282, 1942, 0, 0, 39, '1941'),
	(377, 1, 0, -50282, 1943, 0, 0, 39, '1942'),
	(377, 1, 0, -50282, 1944, 0, 0, 39, '1943'),
	(377, 1, 0, -50282, 1945, 0, 0, 39, '1944'),
	(377, 1, 0, -50282, 1946, 0, 0, 39, '1945'),
	(377, 1, 0, -50282, 1947, 0, 0, 39, '1946'),
	(377, 1, 0, -50282, 1948, 0, 0, 39, '1947'),
	(377, 1, 0, -50282, 1949, 0, 0, 39, '1948'),
	(377, 1, 0, -50282, 1950, 0, 0, 39, '1949'),
	(377, 1, 0, -50282, 1951, 0, 0, 39, '1950'),
	(377, 1, 0, -50282, 1952, 0, 0, 39, '1951'),
	(377, 1, 0, -50282, 1953, 0, 0, 39, '1952'),
	(377, 1, 0, -50282, 1954, 0, 0, 39, '1953'),
	(377, 1, 0, -50282, 1955, 0, 0, 39, '1954'),
	(377, 1, 0, -50282, 1956, 0, 0, 39, '1955'),
	(377, 1, 0, -50282, 1957, 0, 0, 39, '1956'),
	(377, 1, 0, -50282, 1958, 0, 0, 39, '1957'),
	(377, 1, 0, -50282, 1959, 0, 0, 39, '1958'),
	(377, 1, 0, -50282, 1960, 0, 0, 39, '1959'),
	(377, 1, 0, -50282, 1961, 0, 0, 39, '1960'),
	(377, 1, 0, -50282, 1962, 0, 0, 39, '1961'),
	(377, 1, 0, -50282, 1963, 0, 0, 39, '1962'),
	(377, 1, 0, -50282, 1964, 0, 0, 39, '1963'),
	(377, 1, 0, -50282, 1965, 0, 0, 39, '1964'),
	(377, 1, 0, -50282, 1966, 0, 0, 39, '1965'),
	(377, 1, 0, -50282, 1967, 0, 0, 39, '1966'),
	(377, 1, 0, -50282, 1968, 0, 0, 39, '1967'),
	(377, 1, 0, -50282, 1969, 0, 0, 39, '1968'),
	(377, 1, 0, -50282, 1970, 0, 0, 39, '1969'),
	(377, 1, 0, -50282, 1971, 0, 0, 39, '1970'),
	(377, 1, 0, -50282, 1972, 0, 0, 39, '1971'),
	(377, 1, 0, -50282, 1973, 0, 0, 39, '1972'),
	(377, 1, 0, -50282, 1974, 0, 0, 39, '1973'),
	(377, 1, 0, -50282, 1975, 0, 0, 39, '1974'),
	(377, 1, 0, -50282, 1976, 0, 0, 39, '1975'),
	(377, 1, 0, -50282, 1977, 0, 0, 39, '1976'),
	(377, 1, 0, -50282, 1978, 0, 0, 39, '1977'),
	(377, 1, 0, -50282, 1979, 0, 0, 39, '1978'),
	(377, 1, 0, -50282, 1980, 0, 0, 39, '1979'),
	(377, 1, 0, -50282, 1981, 0, 0, 39, '1980'),
	(377, 1, 0, -50282, 1982, 0, 0, 39, '1981'),
	(377, 1, 0, -50282, 1983, 0, 0, 39, '1982'),
	(377, 1, 0, -50282, 1984, 0, 0, 39, '1983'),
	(377, 1, 0, -50282, 1985, 0, 0, 39, '1984'),
	(377, 1, 0, -50282, 1986, 0, 0, 39, '1985'),
	(377, 1, 0, -50282, 1987, 0, 0, 39, '1986'),
	(377, 1, 0, -50282, 1988, 0, 0, 39, '1987'),
	(377, 1, 0, -50282, 1989, 0, 0, 39, '1988'),
	(377, 1, 0, -50282, 1990, 0, 0, 39, '1989'),
	(377, 1, 0, -50282, 1991, 0, 0, 39, '1990'),
	(377, 1, 0, -50282, 1992, 0, 0, 39, '1991'),
	(377, 1, 0, -50282, 1993, 0, 0, 39, '1992'),
	(377, 1, 0, -50282, 1994, 0, 0, 39, '1993'),
	(377, 1, 0, -50282, 1995, 0, 0, 39, '1994'),
	(377, 1, 0, -50282, 1996, 0, 0, 39, '1995'),
	(377, 1, 0, -50282, 1997, 0, 0, 39, '1996'),
	(377, 1, 0, -50282, 1998, 0, 0, 39, '1997'),
	(377, 1, 0, -50282, 1999, 0, 0, 39, '1998'),
	(377, 1, 0, -50282, 2000, 0, 0, 39, '1999'),
	(377, 1, 0, -50282, 2001, 0, 0, 39, '2000'),
	(377, 1, 0, -50282, 2002, 0, 0, 39, '2001'),
	(377, 1, 0, -50282, 2003, 0, 0, 39, '2002'),
	(377, 1, 0, -50282, 2004, 0, 0, 39, '2003'),
	(377, 1, 0, -50282, 2005, 0, 0, 39, '2004'),
	(377, 1, 0, -50282, 2006, 0, 0, 39, '2005'),
	(377, 1, 0, -50282, 2007, 0, 0, 39, '2006'),
	(377, 1, 0, -50282, 2008, 0, 0, 39, '2007'),
	(377, 1, 0, -50282, 2009, 0, 0, 39, '2008'),
	(377, 1, 0, -50282, 2010, 0, 0, 39, '2009'),
	(377, 1, 0, -50282, 2011, 0, 0, 39, '2010'),
	(377, 1, 0, -50282, 2012, 0, 0, 39, '2011'),
	(377, 1, 0, -50282, 2013, 0, 0, 39, '2012'),
	(377, 1, 0, -50282, 2014, 0, 0, 39, '2013'),
	(377, 1, 0, -50282, 2015, 0, 0, 39, '2014'),
	(377, 1, 0, -50282, 2016, 0, 0, 39, '2015'),
	(377, 1, 0, -50282, 2017, 0, 0, 39, '2016'),
	(377, 1, 0, -50282, 2018, 0, 0, 39, '2017'),
	(377, 1, 0, -50282, 2019, 0, 0, 39, '2018'),
	(377, 1, 0, -50282, 2020, 0, 0, 39, '2019'),
	(377, 1, 0, -50282, 2021, 0, 0, 39, '2020'),
	(377, 1, 0, -50282, 2022, 0, 0, 39, '2021'),
	(377, 1, 0, -50282, 2023, 0, 0, 39, '2022'),
	(377, 1, 0, -50282, 2024, 0, 0, 39, '2023'),
	(377, 1, 0, -50282, 2025, 0, 0, 39, '2024'),
	(377, 1, 0, -50282, 2026, 0, 0, 39, '2025'),
	(377, 1, 0, -50282, 2027, 0, 0, 39, '2026'),
	(377, 1, 0, -50282, 2028, 0, 0, 39, '2027'),
	(377, 1, 0, -50282, 2029, 0, 0, 39, '2028'),
	(377, 1, 0, -50282, 2030, 0, 0, 39, '2029'),
	(377, 1, 0, -50282, 2031, 0, 0, 39, '2030'),
	(377, 1, 0, -50282, 2032, 0, 0, 39, '2031'),
	(377, 1, 0, -50282, 2033, 0, 0, 39, '2032'),
	(377, 1, 0, -50282, 2034, 0, 0, 39, '2033'),
	(377, 1, 0, -50282, 2035, 0, 0, 39, '2034'),
	(377, 1, 0, -50282, 2036, 0, 0, 39, '2035'),
	(377, 1, 0, -50282, 2037, 0, 0, 39, '2036'),
	(377, 1, 0, -50282, 2038, 0, 0, 39, '2037'),
	(377, 1, 0, -50282, 2039, 0, 0, 39, '2038'),
	(377, 1, 0, -50282, 2040, 0, 0, 39, '2039'),
	(377, 1, 0, -50282, 2041, 0, 0, 39, '2040'),
	(377, 1, 0, -50282, 2042, 0, 0, 39, '2041'),
	(377, 1, 0, -50282, 2043, 0, 0, 39, '2042'),
	(377, 1, 0, -50282, 2044, 0, 0, 39, '2043'),
	(377, 1, 0, -50282, 2045, 0, 0, 39, '2044'),
	(377, 1, 0, -50282, 2046, 0, 0, 39, '2045'),
	(377, 1, 0, -50282, 2047, 0, 0, 39, '2046'),
	(377, 1, 0, -50282, 2048, 0, 0, 39, '2047'),
	(377, 1, 0, -50282, 2049, 0, 0, 39, '2048'),
	(377, 1, 0, -50282, 2050, 0, 0, 39, '2049'),
	(377, 1, 0, -50282, 2051, 0, 0, 39, '2050'),
	(377, 1, 0, -50282, 2052, 0, 0, 39, '2051'),
	(377, 1, 0, -50282, 2053, 0, 0, 39, '2052'),
	(377, 1, 0, -50282, 2054, 0, 0, 39, '2053'),
	(377, 1, 0, -50282, 2055, 0, 0, 39, '2054'),
	(377, 1, 0, -50282, 2056, 0, 0, 39, '2055'),
	(377, 1, 0, -50282, 2057, 0, 0, 39, '2056'),
	(377, 1, 0, -50282, 2058, 0, 0, 39, '2057'),
	(377, 1, 0, -50282, 2059, 0, 0, 39, '2058'),
	(377, 1, 0, -50282, 2060, 0, 0, 39, '2059'),
	(377, 1, 0, -50282, 2061, 0, 0, 39, '2060'),
	(377, 1, 0, -50282, 2062, 0, 0, 39, '2061'),
	(377, 1, 0, -50282, 2063, 0, 0, 39, '2062'),
	(377, 1, 0, -50282, 2064, 0, 0, 39, '2063'),
	(377, 1, 0, -50282, 2065, 0, 0, 39, '2064'),
	(377, 1, 0, -50282, 2066, 0, 0, 39, '2065'),
	(377, 1, 0, -50282, 2067, 0, 0, 39, '2066'),
	(377, 1, 0, -50282, 2068, 0, 0, 39, '2067'),
	(377, 1, 0, -50282, 2069, 0, 0, 39, '2068'),
	(377, 1, 0, -50282, 2070, 0, 0, 39, '2069'),
	(377, 1, 0, -50282, 2071, 0, 0, 39, '2070'),
	(377, 1, 0, -50282, 2072, 0, 0, 39, '2071'),
	(377, 1, 0, -50282, 2073, 0, 0, 39, '2072'),
	(377, 1, 0, -50282, 2074, 0, 0, 39, '2073'),
	(377, 1, 0, -50282, 2075, 0, 0, 39, '2074'),
	(377, 1, 0, -50282, 2076, 0, 0, 39, '2075'),
	(377, 1, 0, -50282, 2077, 0, 0, 39, '2076'),
	(377, 1, 0, -50282, 2078, 0, 0, 39, '2077'),
	(377, 1, 0, -50282, 2079, 0, 0, 39, '2078'),
	(377, 1, 0, -50282, 2080, 0, 0, 39, '2079'),
	(377, 1, 0, -50282, 2081, 0, 0, 39, '2080'),
	(377, 1, 0, -50282, 2082, 0, 0, 39, '2081'),
	(377, 1, 0, -50282, 2083, 0, 0, 39, '2082'),
	(377, 1, 0, -50282, 2084, 0, 0, 39, '2083'),
	(377, 1, 0, -50282, 2085, 0, 0, 39, '2084'),
	(377, 1, 0, -50282, 2086, 0, 0, 39, '2085'),
	(377, 1, 0, -50282, 2087, 0, 0, 39, '2086'),
	(377, 1, 0, -50282, 2088, 0, 0, 39, '2087'),
	(377, 1, 0, -50282, 2089, 0, 0, 39, '2088'),
	(377, 1, 0, -50282, 2090, 0, 0, 39, '2089'),
	(377, 1, 0, -50282, 2091, 0, 0, 39, '2090'),
	(377, 1, 0, -50282, 2092, 0, 0, 39, '2091'),
	(377, 1, 0, -50282, 2093, 0, 0, 39, '2092'),
	(377, 1, 0, -50282, 2094, 0, 0, 39, '2093'),
	(377, 1, 0, -50282, 2095, 0, 0, 39, '2094'),
	(377, 1, 0, -50282, 2096, 0, 0, 39, '2095'),
	(377, 1, 0, -50282, 2097, 0, 0, 39, '2096'),
	(377, 1, 0, -50282, 2098, 0, 0, 39, '2097'),
	(377, 1, 0, -50282, 2099, 0, 0, 39, '2098'),
	(377, 1, 0, -50282, 2100, 0, 0, 39, '2099'),
	(377, 1, 0, -50282, 2101, 0, 0, 39, '2100'),
	(377, 1, 0, -50282, 2102, 0, 0, 39, '2101'),
	(377, 1, 0, -50282, 2103, 0, 0, 39, '2102'),
	(377, 1, 0, -50282, 2104, 0, 0, 39, '2103'),
	(377, 1, 0, -50282, 2105, 0, 0, 39, '2104'),
	(377, 1, 0, -50282, 2106, 0, 0, 39, '2105'),
	(377, 1, 0, -50282, 2107, 0, 0, 39, '2106'),
	(377, 1, 0, -50282, 2108, 0, 0, 39, '2107'),
	(377, 1, 0, -50282, 2109, 0, 0, 39, '2108'),
	(377, 1, 0, -50282, 2110, 0, 0, 39, '2109'),
	(377, 1, 0, -50282, 2111, 0, 0, 39, '2110'),
	(377, 1, 0, -50282, 2112, 0, 0, 39, '2111'),
	(377, 1, 0, -50282, 2113, 0, 0, 39, '2112'),
	(377, 1, 0, -50282, 2114, 0, 0, 39, '2113'),
	(377, 1, 0, -50282, 2115, 0, 0, 39, '2114'),
	(377, 1, 0, -50282, 2116, 0, 0, 39, '2115'),
	(377, 1, 0, -50282, 2117, 0, 0, 39, '2116'),
	(377, 1, 0, -50282, 2118, 0, 0, 39, '2117'),
	(377, 1, 0, -50282, 2119, 0, 0, 39, '2118'),
	(377, 1, 0, -50282, 2120, 0, 0, 39, '2119'),
	(377, 1, 0, -50282, 2121, 0, 0, 39, '2120'),
	(377, 1, 0, -50282, 2122, 0, 0, 39, '2121'),
	(377, 1, 0, -50282, 2123, 0, 0, 39, '2122'),
	(377, 1, 0, -50282, 2124, 0, 0, 39, '2123'),
	(377, 1, 0, -50282, 2125, 0, 0, 39, '2124'),
	(377, 1, 0, -50282, 2126, 0, 0, 39, '2125'),
	(377, 1, 0, -50282, 2127, 0, 0, 39, '2126'),
	(377, 1, 0, -50282, 2128, 0, 0, 39, '2127'),
	(377, 1, 0, -50282, 2129, 0, 0, 39, '2128'),
	(377, 1, 0, -50282, 2130, 0, 0, 39, '2129'),
	(377, 1, 0, -50282, 2131, 0, 0, 39, '2130'),
	(377, 1, 0, -50282, 2132, 0, 0, 39, '2131'),
	(377, 1, 0, -50282, 2133, 0, 0, 39, '2132'),
	(377, 1, 0, -50282, 2134, 0, 0, 39, '2133'),
	(377, 1, 0, -50282, 2135, 0, 0, 39, '2134'),
	(377, 1, 0, -50282, 2136, 0, 0, 39, '2135'),
	(377, 1, 0, -50282, 2137, 0, 0, 39, '2136'),
	(377, 1, 0, -50282, 2138, 0, 0, 39, '2137'),
	(377, 1, 0, -50282, 2139, 0, 0, 39, '2138'),
	(377, 1, 0, -50282, 2140, 0, 0, 39, '2139'),
	(377, 1, 0, -50282, 2141, 0, 0, 39, '2140'),
	(377, 1, 0, -50282, 2142, 0, 0, 39, '2141'),
	(377, 1, 0, -50282, 2143, 0, 0, 39, '2142'),
	(377, 1, 0, -50282, 2144, 0, 0, 39, '2143'),
	(377, 1, 0, -50282, 2145, 0, 0, 39, '2144'),
	(377, 1, 0, -50282, 2146, 0, 0, 39, '2145'),
	(377, 1, 0, -50282, 2147, 0, 0, 39, '2146'),
	(377, 1, 0, -50282, 2148, 0, 0, 39, '2147'),
	(377, 1, 0, -50282, 2149, 0, 0, 39, '2148'),
	(377, 1, 0, -50282, 2150, 0, 0, 39, '2149'),
	(377, 1, 0, -50282, 2151, 0, 0, 39, '2150'),
	(377, 1, 0, -50282, 2152, 0, 0, 39, '2151'),
	(377, 1, 0, -50282, 2153, 0, 0, 39, '2152'),
	(377, 1, 0, -50282, 2154, 0, 0, 39, '2153'),
	(377, 1, 0, -50282, 2155, 0, 0, 39, '2154'),
	(377, 1, 0, -50282, 2156, 0, 0, 39, '2155'),
	(377, 1, 0, -50282, 2157, 0, 0, 39, '2156'),
	(377, 1, 0, -50282, 2158, 0, 0, 39, '2157'),
	(377, 1, 0, -50282, 2159, 0, 0, 39, '2158'),
	(377, 1, 0, -50282, 2160, 0, 0, 39, '2159'),
	(377, 1, 0, -50282, 2161, 0, 0, 39, '2160'),
	(377, 1, 0, -50282, 2162, 0, 0, 39, '2161'),
	(377, 1, 0, -50282, 2163, 0, 0, 39, '2162'),
	(377, 1, 0, -50282, 2164, 0, 0, 39, '2163'),
	(377, 1, 0, -50282, 2165, 0, 0, 39, '2164'),
	(377, 1, 0, -50282, 2166, 0, 0, 39, '2165'),
	(377, 1, 0, -50282, 2167, 0, 0, 39, '2166'),
	(377, 1, 0, -50282, 2168, 0, 0, 39, '2167'),
	(377, 1, 0, -50282, 2169, 0, 0, 39, '2168'),
	(377, 1, 0, -50282, 2170, 0, 0, 39, '2169'),
	(377, 1, 0, -50282, 2171, 0, 0, 39, '2170'),
	(377, 1, 0, -50282, 2172, 0, 0, 39, '2171'),
	(377, 1, 0, -50282, 2173, 0, 0, 39, '2172'),
	(377, 1, 0, -50282, 2174, 0, 0, 39, '2173'),
	(377, 1, 0, -50282, 2175, 0, 0, 39, '2174'),
	(377, 1, 0, -50282, 2176, 0, 0, 39, '2175'),
	(377, 1, 0, -50282, 2177, 0, 0, 39, '2176'),
	(377, 1, 0, -50282, 2178, 0, 0, 39, '2177'),
	(377, 1, 0, -50282, 2179, 0, 0, 39, '2178'),
	(377, 1, 0, -50282, 2180, 0, 0, 39, '2179'),
	(377, 1, 0, -50282, 2181, 0, 0, 39, '2180'),
	(377, 1, 0, -50282, 2182, 0, 0, 39, '2181'),
	(377, 1, 0, -50282, 2183, 0, 0, 39, '2182'),
	(377, 1, 0, -50282, 2184, 0, 0, 39, '2183'),
	(377, 1, 0, -50282, 2185, 0, 0, 39, '2184'),
	(377, 1, 0, -50282, 2186, 0, 0, 39, '2185'),
	(377, 1, 0, -50282, 2187, 0, 0, 39, '2186'),
	(377, 1, 0, -50282, 2188, 0, 0, 39, '2187'),
	(377, 1, 0, -50282, 2189, 0, 0, 39, '2188'),
	(377, 1, 0, -50282, 2190, 0, 0, 39, '2189'),
	(377, 1, 0, -50282, 2191, 0, 0, 39, '2190'),
	(377, 1, 0, -50282, 2192, 0, 0, 39, '2191'),
	(377, 1, 0, -50282, 2193, 0, 0, 39, '2192'),
	(377, 1, 0, -50282, 2194, 0, 0, 39, '2193'),
	(377, 1, 0, -50282, 2195, 0, 0, 39, '2194'),
	(377, 1, 0, -50282, 2196, 0, 0, 39, '2195'),
	(377, 1, 0, -50282, 2197, 0, 0, 39, '2196'),
	(377, 1, 0, -50282, 2198, 0, 0, 39, '2197'),
	(377, 1, 0, -50282, 2199, 0, 0, 39, '2198'),
	(377, 1, 0, -50282, 2200, 0, 0, 39, '2199'),
	(377, 1, 0, -50282, 2201, 0, 0, 39, '2200'),
	(377, 1, 0, -50282, 2202, 0, 0, 39, '2201'),
	(377, 1, 0, -50282, 2203, 0, 0, 39, '2202'),
	(377, 1, 0, -50282, 2204, 0, 0, 39, '2203'),
	(377, 1, 0, -50282, 2205, 0, 0, 39, '2204'),
	(377, 1, 0, -50282, 2206, 0, 0, 39, '2205'),
	(377, 1, 0, -50282, 2207, 0, 0, 39, '2206'),
	(377, 1, 0, -50282, 2208, 0, 0, 39, '2207'),
	(377, 1, 0, -50282, 2209, 0, 0, 39, '2208'),
	(377, 1, 0, -50282, 2210, 0, 0, 39, '2209'),
	(377, 1, 0, -50282, 2211, 0, 0, 39, '2210'),
	(377, 1, 0, -50282, 2212, 0, 0, 39, '2211'),
	(377, 1, 0, -50282, 2213, 0, 0, 39, '2212'),
	(377, 1, 0, -50282, 2214, 0, 0, 39, '2213'),
	(377, 1, 0, -50282, 2215, 0, 0, 39, '2214'),
	(377, 1, 0, -50282, 2216, 0, 0, 39, '2215'),
	(377, 1, 0, -50282, 2217, 0, 0, 39, '2216'),
	(377, 1, 0, -50282, 2218, 0, 0, 39, '2217'),
	(377, 1, 0, -50282, 2219, 0, 0, 39, '2218'),
	(377, 1, 0, -50282, 2220, 0, 0, 39, '2219'),
	(377, 1, 0, -50282, 2221, 0, 0, 39, '2220'),
	(377, 1, 0, -50282, 2222, 0, 0, 39, '2221'),
	(377, 1, 0, -50282, 2223, 0, 0, 39, '2222'),
	(377, 1, 0, -50282, 2224, 0, 0, 39, '2223'),
	(377, 1, 0, -50282, 2225, 0, 0, 39, '2224'),
	(377, 1, 0, -50282, 2226, 0, 0, 39, '2225'),
	(377, 1, 0, -50282, 2227, 0, 0, 39, '2226'),
	(377, 1, 0, -50282, 2228, 0, 0, 39, '2227'),
	(377, 1, 0, -50282, 2229, 0, 0, 39, '2228'),
	(377, 1, 0, -50282, 2230, 0, 0, 39, '2229'),
	(377, 1, 0, -50282, 2231, 0, 0, 39, '2230'),
	(377, 1, 0, -50282, 2232, 0, 0, 39, '2231'),
	(377, 1, 0, -50282, 2233, 0, 0, 39, '2232'),
	(377, 1, 0, -50282, 2234, 0, 0, 39, '2233'),
	(377, 1, 0, -50282, 2235, 0, 0, 39, '2234'),
	(377, 1, 0, -50282, 2236, 0, 0, 39, '2235'),
	(377, 1, 0, -50282, 2237, 0, 0, 39, '2236'),
	(377, 1, 0, -50282, 2238, 0, 0, 39, '2237'),
	(377, 1, 0, -50282, 2239, 0, 0, 39, '2238'),
	(377, 1, 0, -50282, 2240, 0, 0, 39, '2239'),
	(377, 1, 0, -50282, 2241, 0, 0, 39, '2240'),
	(377, 1, 0, -50282, 2242, 0, 0, 39, '2241'),
	(377, 1, 0, -50282, 2243, 0, 0, 39, '2242'),
	(377, 1, 0, -50282, 2244, 0, 0, 39, '2243'),
	(377, 1, 0, -50282, 2245, 0, 0, 39, '2244'),
	(377, 1, 0, -50282, 2246, 0, 0, 39, '2245'),
	(377, 1, 0, -50282, 2247, 0, 0, 39, '2246'),
	(377, 1, 0, -50282, 2248, 0, 0, 39, '2247'),
	(377, 1, 0, -50282, 2249, 0, 0, 39, '2248'),
	(377, 1, 0, -50282, 2250, 0, 0, 39, '2249'),
	(377, 1, 0, -50282, 2251, 0, 0, 39, '2250'),
	(377, 1, 0, -50282, 2252, 0, 0, 39, '2251'),
	(377, 1, 0, -50282, 2253, 0, 0, 39, '2252'),
	(377, 1, 0, -50282, 2254, 0, 0, 39, '2253'),
	(377, 1, 0, -50282, 2255, 0, 0, 39, '2254'),
	(377, 1, 0, -50282, 2256, 0, 0, 39, '2255'),
	(377, 1, 0, -50282, 2257, 0, 0, 39, '2256'),
	(377, 1, 0, -50282, 2258, 0, 0, 39, '2257'),
	(377, 1, 0, -50282, 2259, 0, 0, 39, '2258'),
	(377, 1, 0, -50282, 2260, 0, 0, 39, '2259'),
	(377, 1, 0, -50282, 2261, 0, 0, 39, '2260'),
	(377, 1, 0, -50282, 2262, 0, 0, 39, '2261'),
	(377, 1, 0, -50282, 2263, 0, 0, 39, '2262'),
	(377, 1, 0, -50282, 2264, 0, 0, 39, '2263'),
	(377, 1, 0, -50282, 2265, 0, 0, 39, '2264'),
	(377, 1, 0, -50282, 2266, 0, 0, 39, '2265'),
	(377, 1, 0, -50282, 2267, 0, 0, 39, '2266'),
	(377, 1, 0, -50282, 2268, 0, 0, 39, '2267'),
	(377, 1, 0, -50282, 2269, 0, 0, 39, '2268'),
	(377, 1, 0, -50282, 2270, 0, 0, 39, '2269'),
	(377, 1, 0, -50282, 2271, 0, 0, 39, '2270'),
	(377, 1, 0, -50282, 2272, 0, 0, 39, '2271'),
	(377, 1, 0, -50282, 2273, 0, 0, 39, '2272'),
	(377, 1, 0, -50282, 2274, 0, 0, 39, '2273'),
	(377, 1, 0, -50282, 2275, 0, 0, 39, '2274'),
	(377, 1, 0, -50282, 2276, 0, 0, 39, '2275'),
	(377, 1, 0, -50282, 2277, 0, 0, 39, '2276'),
	(377, 1, 0, -50282, 2278, 0, 0, 39, '2277'),
	(377, 1, 0, -50282, 2279, 0, 0, 39, '2278'),
	(377, 1, 0, -50282, 2280, 0, 0, 39, '2279'),
	(377, 1, 0, -50282, 2281, 0, 0, 39, '2280'),
	(377, 1, 0, -50282, 2282, 0, 0, 39, '2281'),
	(377, 1, 0, -50282, 2283, 0, 0, 39, '2282'),
	(377, 1, 0, -50282, 2284, 0, 0, 39, '2283'),
	(377, 1, 0, -50282, 2285, 0, 0, 39, '2284'),
	(377, 1, 0, -50282, 2286, 0, 0, 39, '2285'),
	(377, 1, 0, -50282, 2287, 0, 0, 39, '2286'),
	(377, 1, 0, -50282, 2288, 0, 0, 39, '2287'),
	(377, 1, 0, -50282, 2289, 0, 0, 39, '2288'),
	(377, 1, 0, -50282, 2290, 0, 0, 39, '2289'),
	(377, 1, 0, -50282, 2291, 0, 0, 39, '2290'),
	(377, 1, 0, -50282, 2292, 0, 0, 39, '2291'),
	(377, 1, 0, -50282, 2293, 0, 0, 39, '2292'),
	(377, 1, 0, -50282, 2294, 0, 0, 39, '2293'),
	(377, 1, 0, -50282, 2295, 0, 0, 39, '2294'),
	(377, 1, 0, -50282, 2296, 0, 0, 39, '2295'),
	(377, 1, 0, -50282, 2297, 0, 0, 39, '2296'),
	(377, 1, 0, -50282, 2298, 0, 0, 39, '2297'),
	(377, 1, 0, -50282, 2299, 0, 0, 39, '2298'),
	(377, 1, 0, -50282, 2300, 0, 0, 39, '2299'),
	(377, 1, 0, -50282, 2301, 0, 0, 39, '2300'),
	(377, 1, 0, -50282, 2302, 0, 0, 39, '2301'),
	(377, 1, 0, -50282, 2303, 0, 0, 39, '2302'),
	(377, 1, 0, -50282, 2304, 0, 0, 39, '2303'),
	(377, 1, 0, -50282, 2305, 0, 0, 39, '2304'),
	(377, 1, 0, -50282, 2306, 0, 0, 39, '2305'),
	(377, 1, 0, -50282, 2307, 0, 0, 39, '2306'),
	(377, 1, 0, -50282, 2308, 0, 0, 39, '2307'),
	(377, 1, 0, -50282, 2309, 0, 0, 39, '2308'),
	(377, 1, 0, -50282, 2310, 0, 0, 39, '2309'),
	(377, 1, 0, -50282, 2311, 0, 0, 39, '2310'),
	(377, 1, 0, -50282, 2312, 0, 0, 39, '2311'),
	(377, 1, 0, -50282, 2313, 0, 0, 39, '2312'),
	(377, 1, 0, -50282, 2314, 0, 0, 39, '2313'),
	(377, 1, 0, -50282, 2315, 0, 0, 39, '2314'),
	(377, 1, 0, -50282, 2316, 0, 0, 39, '2315'),
	(377, 1, 0, -50282, 2317, 0, 0, 39, '2316'),
	(377, 1, 0, -50282, 2318, 0, 0, 39, '2317'),
	(377, 1, 0, -50282, 2319, 0, 0, 39, '2318'),
	(377, 1, 0, -50282, 2320, 0, 0, 39, '2319'),
	(377, 1, 0, -50282, 2321, 0, 0, 39, '2320'),
	(377, 1, 0, -50282, 2322, 0, 0, 39, '2321'),
	(377, 1, 0, -50282, 2323, 0, 0, 39, '2322'),
	(377, 1, 0, -50282, 2324, 0, 0, 39, '2323'),
	(377, 1, 0, -50282, 2325, 0, 0, 39, '2324'),
	(377, 1, 0, -50282, 2326, 0, 0, 39, '2325'),
	(377, 1, 0, -50282, 2327, 0, 0, 39, '2326'),
	(377, 1, 0, -50282, 2328, 0, 0, 39, '2327'),
	(377, 1, 0, -50282, 2329, 0, 0, 39, '2328'),
	(377, 1, 0, -50282, 2330, 0, 0, 39, '2329'),
	(377, 1, 0, -50282, 2331, 0, 0, 39, '2330'),
	(377, 1, 0, -50282, 2332, 0, 0, 39, '2331'),
	(377, 1, 0, -50282, 2333, 0, 0, 39, '2332'),
	(377, 1, 0, -50282, 2334, 0, 0, 39, '2333'),
	(377, 1, 0, -50282, 2335, 0, 0, 39, '2334'),
	(377, 1, 0, -50282, 2336, 0, 0, 39, '2335'),
	(377, 1, 0, -50282, 2337, 0, 0, 39, '2336'),
	(377, 1, 0, -50282, 2338, 0, 0, 39, '2337'),
	(377, 1, 0, -50282, 2339, 0, 0, 39, '2338'),
	(377, 1, 0, -50282, 2340, 0, 0, 39, '2339'),
	(377, 1, 0, -50282, 2341, 0, 0, 39, '2340'),
	(377, 1, 0, -50282, 2342, 0, 0, 39, '2341'),
	(377, 1, 0, -50282, 2343, 0, 0, 39, '2342'),
	(377, 1, 0, -50282, 2344, 0, 0, 39, '2343'),
	(377, 1, 0, -50282, 2345, 0, 0, 39, '2344'),
	(377, 1, 0, -50282, 2346, 0, 0, 39, '2345'),
	(377, 1, 0, -50282, 2347, 0, 0, 39, '2346'),
	(377, 1, 0, -50282, 2348, 0, 0, 39, '2347'),
	(377, 1, 0, -50282, 2349, 0, 0, 39, '2348'),
	(377, 1, 0, -50282, 2350, 0, 0, 39, '2349'),
	(377, 1, 0, -50282, 2351, 0, 0, 39, '2350'),
	(377, 1, 0, -50282, 2352, 0, 0, 39, '2351'),
	(377, 1, 0, -50282, 2353, 0, 0, 39, '2352'),
	(377, 1, 0, -50282, 2354, 0, 0, 39, '2353'),
	(377, 1, 0, -50282, 2355, 0, 0, 39, '2354'),
	(377, 1, 0, -50282, 2356, 0, 0, 39, '2355'),
	(377, 1, 0, -50282, 2357, 0, 0, 39, '2356'),
	(377, 1, 0, -50282, 2358, 0, 0, 39, '2357'),
	(377, 1, 0, -50282, 2359, 0, 0, 39, '2358'),
	(377, 1, 0, -50282, 2360, 0, 0, 39, '2359'),
	(377, 1, 0, -50282, 2361, 0, 0, 39, '2360'),
	(377, 1, 0, -50282, 2362, 0, 0, 39, '2361'),
	(377, 1, 0, -50282, 2363, 0, 0, 39, '2362'),
	(377, 1, 0, -50282, 2364, 0, 0, 39, '2363'),
	(377, 1, 0, -50282, 2365, 0, 0, 39, '2364'),
	(377, 1, 0, -50282, 2366, 0, 0, 39, '2365'),
	(377, 1, 0, -50282, 2367, 0, 0, 39, '2366'),
	(377, 1, 0, -50282, 2368, 0, 0, 39, '2367'),
	(377, 1, 0, -50282, 2369, 0, 0, 39, '2368'),
	(377, 1, 0, -50282, 2370, 0, 0, 39, '2369'),
	(377, 1, 0, -50282, 2371, 0, 0, 39, '2370'),
	(377, 1, 0, -50282, 2372, 0, 0, 39, '2371'),
	(377, 1, 0, -50282, 2373, 0, 0, 39, '2372'),
	(377, 1, 0, -50282, 2374, 0, 0, 39, '2373'),
	(377, 1, 0, -50282, 2375, 0, 0, 39, '2374'),
	(377, 1, 0, -50282, 2376, 0, 0, 39, '2375'),
	(377, 1, 0, -50282, 2377, 0, 0, 39, '2376'),
	(377, 1, 0, -50282, 2378, 0, 0, 39, '2377'),
	(377, 1, 0, -50282, 2379, 0, 0, 39, '2378'),
	(377, 1, 0, -50282, 2380, 0, 0, 39, '2379'),
	(377, 1, 0, -50282, 2381, 0, 0, 39, '2380'),
	(377, 1, 0, -50282, 2382, 0, 0, 39, '2381'),
	(377, 1, 0, -50282, 2383, 0, 0, 39, '2382'),
	(377, 1, 0, -50282, 2384, 0, 0, 39, '2383'),
	(377, 1, 0, -50282, 2385, 0, 0, 39, '2384'),
	(377, 1, 0, -50282, 2386, 0, 0, 39, '2385'),
	(377, 1, 0, -50282, 2387, 0, 0, 39, '2386'),
	(377, 1, 0, -50282, 2388, 0, 0, 39, '2387'),
	(377, 1, 0, -50282, 2389, 0, 0, 39, '2388'),
	(377, 1, 0, -50282, 2390, 0, 0, 39, '2389'),
	(377, 1, 0, -50282, 2391, 0, 0, 39, '2390'),
	(377, 1, 0, -50282, 2392, 0, 0, 39, '2391'),
	(377, 1, 0, -50282, 2393, 0, 0, 39, '2392'),
	(377, 1, 0, -50282, 2394, 0, 0, 39, '2393'),
	(377, 1, 0, -50282, 2395, 0, 0, 39, '2394'),
	(377, 1, 0, -50282, 2396, 0, 0, 39, '2395'),
	(377, 1, 0, -50282, 2397, 0, 0, 39, '2396'),
	(377, 1, 0, -50282, 2398, 0, 0, 39, '2397'),
	(377, 1, 0, -50282, 2399, 0, 0, 39, '2398'),
	(377, 1, 0, -50282, 2400, 0, 0, 39, '2399'),
	(377, 1, 0, -50282, 2401, 0, 0, 39, '2400'),
	(377, 1, 0, -50282, 2402, 0, 0, 39, '2401'),
	(377, 1, 0, -50282, 2403, 0, 0, 39, '2402'),
	(377, 1, 0, -50282, 2404, 0, 0, 39, '2403'),
	(377, 1, 0, -50282, 2405, 0, 0, 39, '2404'),
	(377, 1, 0, -50282, 2406, 0, 0, 39, '2405'),
	(377, 1, 0, -50282, 2407, 0, 0, 39, '2406'),
	(377, 1, 0, -50282, 2408, 0, 0, 39, '2407'),
	(377, 1, 0, -50282, 2409, 0, 0, 39, '2408'),
	(377, 1, 0, -50282, 2410, 0, 0, 39, '2409'),
	(377, 1, 0, -50282, 2411, 0, 0, 39, '2410'),
	(377, 1, 0, -50282, 2412, 0, 0, 39, '2411'),
	(377, 1, 0, -50282, 2413, 0, 0, 39, '2412'),
	(377, 1, 0, -50282, 2414, 0, 0, 39, '2413'),
	(377, 1, 0, -50282, 2415, 0, 0, 39, '2414'),
	(377, 1, 0, -50282, 2416, 0, 0, 39, '2415'),
	(377, 1, 0, -50282, 2417, 0, 0, 39, '2416'),
	(377, 1, 0, -50282, 2418, 0, 0, 39, '2417'),
	(377, 1, 0, -50282, 2419, 0, 0, 39, '2418'),
	(377, 1, 0, -50282, 2420, 0, 0, 39, '2419'),
	(377, 1, 0, -50282, 2421, 0, 0, 39, '2420'),
	(377, 1, 0, -50282, 2422, 0, 0, 39, '2421'),
	(377, 1, 0, -50282, 2423, 0, 0, 39, '2422'),
	(377, 1, 0, -50282, 2424, 0, 0, 39, '2423'),
	(377, 1, 0, -50282, 2425, 0, 0, 39, '2424'),
	(377, 1, 0, -50282, 2426, 0, 0, 39, '2425'),
	(377, 1, 0, -50282, 2427, 0, 0, 39, '2426'),
	(377, 1, 0, -50282, 2428, 0, 0, 39, '2427'),
	(377, 1, 0, -50282, 2429, 0, 0, 39, '2428'),
	(377, 1, 0, -50282, 2430, 0, 0, 39, '2429'),
	(377, 1, 0, -50282, 2431, 0, 0, 39, '2430'),
	(377, 1, 0, -50282, 2432, 0, 0, 39, '2431'),
	(377, 1, 0, -50282, 2433, 0, 0, 39, '2432'),
	(377, 1, 0, -50282, 2434, 0, 0, 39, '2433'),
	(377, 1, 0, -50282, 2435, 0, 0, 39, '2434'),
	(377, 1, 0, -50282, 2436, 0, 0, 39, '2435'),
	(377, 1, 0, -50282, 2437, 0, 0, 39, '2436'),
	(377, 1, 0, -50282, 2438, 0, 0, 39, '2437'),
	(377, 1, 0, -50282, 2439, 0, 0, 39, '2438'),
	(377, 1, 0, -50282, 2440, 0, 0, 39, '2439'),
	(377, 1, 0, -50282, 2441, 0, 0, 39, '2440'),
	(377, 1, 0, -50282, 2442, 0, 0, 39, '2441'),
	(377, 1, 0, -50282, 2443, 0, 0, 39, '2442'),
	(377, 1, 0, -50282, 2444, 0, 0, 39, '2443'),
	(377, 1, 0, -50282, 2445, 0, 0, 39, '2444'),
	(377, 1, 0, -50282, 2446, 0, 0, 39, '2445'),
	(377, 1, 0, -50282, 2447, 0, 0, 39, '2446'),
	(377, 1, 0, -50282, 2448, 0, 0, 39, '2447'),
	(377, 1, 0, -50282, 2449, 0, 0, 39, '2448'),
	(377, 1, 0, -50282, 2450, 0, 0, 39, '2449'),
	(377, 1, 0, -50282, 2451, 0, 0, 39, '2450'),
	(377, 1, 0, -50282, 2452, 0, 0, 39, '2451'),
	(377, 1, 0, -50282, 2453, 0, 0, 39, '2452'),
	(377, 1, 0, -50282, 2454, 0, 0, 39, '2453'),
	(377, 1, 0, -50282, 2455, 0, 0, 39, '2454'),
	(377, 1, 0, -50282, 2456, 0, 0, 39, '2455'),
	(377, 1, 0, -50282, 2457, 0, 0, 39, '2456'),
	(377, 1, 0, -50282, 2458, 0, 0, 39, '2457'),
	(377, 1, 0, -50282, 2459, 0, 0, 39, '2458'),
	(377, 1, 0, -50282, 2460, 0, 0, 39, '2459'),
	(377, 1, 0, -50282, 2461, 0, 0, 39, '2460'),
	(377, 1, 0, -50282, 2462, 0, 0, 39, '2461'),
	(377, 1, 0, -50282, 2463, 0, 0, 39, '2462'),
	(377, 1, 0, -50282, 2464, 0, 0, 39, '2463'),
	(377, 1, 0, -50282, 2465, 0, 0, 39, '2464'),
	(377, 1, 0, -50282, 2466, 0, 0, 39, '2465'),
	(377, 1, 0, -50282, 2467, 0, 0, 39, '2466'),
	(377, 1, 0, -50282, 2468, 0, 0, 39, '2467'),
	(377, 1, 0, -50282, 2469, 0, 0, 39, '2468'),
	(377, 1, 0, -50282, 2470, 0, 0, 39, '2469'),
	(377, 1, 0, -50282, 2471, 0, 0, 39, '2470'),
	(377, 1, 0, -50282, 2472, 0, 0, 39, '2471'),
	(377, 1, 0, -50282, 2473, 0, 0, 39, '2472'),
	(377, 1, 0, -50282, 2474, 0, 0, 39, '2473'),
	(377, 1, 0, -50282, 2475, 0, 0, 39, '2474'),
	(377, 1, 0, -50282, 2476, 0, 0, 39, '2475'),
	(377, 1, 0, -50282, 2477, 0, 0, 39, '2476'),
	(377, 1, 0, -50282, 2478, 0, 0, 39, '2477'),
	(377, 1, 0, -50282, 2479, 0, 0, 39, '2478'),
	(377, 1, 0, -50282, 2480, 0, 0, 39, '2479'),
	(377, 1, 0, -50282, 2481, 0, 0, 39, '2480'),
	(377, 1, 0, -50282, 2482, 0, 0, 39, '2481'),
	(377, 1, 0, -50282, 2483, 0, 0, 39, '2482'),
	(377, 1, 0, -50282, 2484, 0, 0, 39, '2483'),
	(377, 1, 0, -50282, 2485, 0, 0, 39, '2484'),
	(377, 1, 0, -50282, 2486, 0, 0, 39, '2485'),
	(377, 1, 0, -50282, 2487, 0, 0, 39, '2486'),
	(377, 1, 0, -50282, 2488, 0, 0, 39, '2487'),
	(377, 1, 0, -50282, 2489, 0, 0, 39, '2488'),
	(377, 1, 0, -50282, 2490, 0, 0, 39, '2489'),
	(377, 1, 0, -50282, 2491, 0, 0, 39, '2490'),
	(377, 1, 0, -50282, 2492, 0, 0, 39, '2491'),
	(377, 1, 0, -50282, 2493, 0, 0, 39, '2492'),
	(377, 1, 0, -50282, 2494, 0, 0, 39, '2493'),
	(377, 1, 0, -50282, 2495, 0, 0, 39, '2494'),
	(377, 1, 0, -50282, 2496, 0, 0, 39, '2495'),
	(377, 1, 0, -50282, 2497, 0, 0, 39, '2496'),
	(377, 1, 0, -50282, 2498, 0, 0, 39, '2497'),
	(377, 1, 0, -50282, 2499, 0, 0, 39, '2498'),
	(377, 1, 0, -50282, 2500, 0, 0, 39, '2499'),
	(377, 1, 0, -50282, 2501, 0, 0, 39, '2500'),
	(377, 1, 0, -50282, 2502, 0, 0, 39, '2501'),
	(377, 1, 0, -50282, 2503, 0, 0, 39, '2502'),
	(377, 1, 0, -50282, 2504, 0, 0, 39, '2503'),
	(377, 1, 0, -50282, 2505, 0, 0, 39, '2504'),
	(377, 1, 0, -50282, 2506, 0, 0, 39, '2505'),
	(377, 1, 0, -50282, 2507, 0, 0, 39, '2506'),
	(377, 1, 0, -50282, 2508, 0, 0, 39, '2507'),
	(377, 1, 0, -50282, 2509, 0, 0, 39, '2508'),
	(377, 1, 0, -50282, 2510, 0, 0, 39, '2509'),
	(377, 1, 0, -50282, 2511, 0, 0, 39, '2510'),
	(377, 1, 0, -50282, 2512, 0, 0, 39, '2511'),
	(377, 1, 0, -50282, 2513, 0, 0, 39, '2512'),
	(377, 1, 0, -50282, 2514, 0, 0, 39, '2513'),
	(377, 1, 0, -50282, 2515, 0, 0, 39, '2514'),
	(377, 1, 0, -50282, 2516, 0, 0, 39, '2515'),
	(377, 1, 0, -50282, 2517, 0, 0, 39, '2516'),
	(377, 1, 0, -50282, 2518, 0, 0, 39, '2517'),
	(377, 1, 0, -50282, 2519, 0, 0, 39, '2518'),
	(377, 1, 0, -50282, 2520, 0, 0, 39, '2519'),
	(377, 1, 0, -50282, 2521, 0, 0, 39, '2520'),
	(377, 1, 0, -50282, 2522, 0, 0, 39, '2521'),
	(377, 1, 0, -50282, 2523, 0, 0, 39, '2522'),
	(377, 1, 0, -50282, 2524, 0, 0, 39, '2523'),
	(377, 1, 0, -50282, 2525, 0, 0, 39, '2524'),
	(377, 1, 0, -50282, 2526, 0, 0, 39, '2525'),
	(377, 1, 0, -50282, 2527, 0, 0, 39, '2526'),
	(377, 1, 0, -50282, 2528, 0, 0, 39, '2527'),
	(377, 1, 0, -50282, 2529, 0, 0, 39, '2528'),
	(377, 1, 0, -50282, 2530, 0, 0, 39, '2529'),
	(377, 1, 0, -50282, 2531, 0, 0, 39, '2530'),
	(377, 1, 0, -50282, 2532, 0, 0, 39, '2531'),
	(377, 1, 0, -50282, 2533, 0, 0, 39, '2532'),
	(377, 1, 0, -50282, 2534, 0, 0, 39, '2533'),
	(377, 1, 0, -50282, 2535, 0, 0, 39, '2534'),
	(377, 1, 0, -50282, 2536, 0, 0, 39, '2535'),
	(377, 1, 0, -50282, 2537, 0, 0, 39, '2536'),
	(377, 1, 0, -50282, 2538, 0, 0, 39, '2537'),
	(377, 1, 0, -50282, 2539, 0, 0, 39, '2538'),
	(377, 1, 0, -50282, 2540, 0, 0, 39, '2539'),
	(377, 1, 0, -50282, 2541, 0, 0, 39, '2540'),
	(377, 1, 0, -50282, 2542, 0, 0, 39, '2541'),
	(377, 1, 0, -50282, 2543, 0, 0, 39, '2542'),
	(377, 1, 0, -50282, 2544, 0, 0, 39, '2543'),
	(377, 1, 0, -50282, 2545, 0, 0, 39, '2544'),
	(377, 1, 0, -50282, 2546, 0, 0, 39, '2545'),
	(377, 1, 0, -50282, 2547, 0, 0, 39, '2546'),
	(377, 1, 0, -50282, 2548, 0, 0, 39, '2547'),
	(377, 1, 0, -50282, 2549, 0, 0, 39, '2548'),
	(377, 1, 0, -50282, 2550, 0, 0, 39, '2549'),
	(377, 1, 0, -50282, 2551, 0, 0, 39, '2550'),
	(377, 1, 0, -50282, 2552, 0, 0, 39, '2551'),
	(377, 1, 0, -50282, 2553, 0, 0, 39, '2552'),
	(377, 1, 0, -50282, 2554, 0, 0, 39, '2553'),
	(377, 1, 0, -50282, 2555, 0, 0, 39, '2554'),
	(377, 1, 0, -50282, 2556, 0, 0, 39, '2555'),
	(377, 1, 0, -50282, 2557, 0, 0, 39, '2556'),
	(377, 1, 0, -50282, 2558, 0, 0, 39, '2557'),
	(377, 1, 0, -50282, 2559, 0, 0, 39, '2558'),
	(377, 1, 0, -50282, 2560, 0, 0, 39, '2559'),
	(377, 1, 0, -50282, 2561, 0, 0, 39, '2560'),
	(377, 1, 0, -50282, 2562, 0, 0, 39, '2561'),
	(377, 1, 0, -50282, 2563, 0, 0, 39, '2562'),
	(377, 1, 0, -50282, 2564, 0, 0, 39, '2563'),
	(377, 1, 0, -50282, 2565, 0, 0, 39, '2564'),
	(377, 1, 0, -50282, 2566, 0, 0, 39, '2565'),
	(377, 1, 0, -50282, 2567, 0, 0, 39, '2566'),
	(377, 1, 0, -50282, 2568, 0, 0, 39, '2567'),
	(377, 1, 0, -50282, 2569, 0, 0, 39, '2568'),
	(377, 1, 0, -50282, 2570, 0, 0, 39, '2569'),
	(377, 1, 0, -50282, 2571, 0, 0, 39, '2570'),
	(377, 1, 0, -50282, 2572, 0, 0, 39, '2571'),
	(377, 1, 0, -50282, 2573, 0, 0, 39, '2572'),
	(377, 1, 0, -50282, 2574, 0, 0, 39, '2573'),
	(377, 1, 0, -50282, 2575, 0, 0, 39, '2574'),
	(377, 1, 0, -50282, 2576, 0, 0, 39, '2575'),
	(377, 1, 0, -50282, 2577, 0, 0, 39, '2576'),
	(377, 1, 0, -50282, 2578, 0, 0, 39, '2577'),
	(377, 1, 0, -50282, 2579, 0, 0, 39, '2578'),
	(377, 1, 0, -50282, 2580, 0, 0, 39, '2579'),
	(377, 1, 0, -50282, 2581, 0, 0, 39, '2580'),
	(377, 1, 0, -50282, 2582, 0, 0, 39, '2581'),
	(377, 1, 0, -50282, 2583, 0, 0, 39, '2582'),
	(377, 1, 0, -50282, 2584, 0, 0, 39, '2583'),
	(377, 1, 0, -50282, 2585, 0, 0, 39, '2584'),
	(377, 1, 0, -50282, 2586, 0, 0, 39, '2585'),
	(377, 1, 0, -50282, 2587, 0, 0, 39, '2586'),
	(377, 1, 0, -50282, 2588, 0, 0, 39, '2587'),
	(377, 1, 0, -50282, 2589, 0, 0, 39, '2588'),
	(377, 1, 0, -50282, 2590, 0, 0, 39, '2589'),
	(377, 1, 0, -50282, 2591, 0, 0, 39, '2590'),
	(377, 1, 0, -50282, 2592, 0, 0, 39, '2591'),
	(377, 1, 0, -50282, 2593, 0, 0, 39, '2592'),
	(377, 1, 0, -50282, 2594, 0, 0, 39, '2593'),
	(377, 1, 0, -50282, 2595, 0, 0, 39, '2594'),
	(377, 1, 0, -50282, 2596, 0, 0, 39, '2595'),
	(377, 1, 0, -50282, 2597, 0, 0, 39, '2596'),
	(377, 1, 0, -50282, 2598, 0, 0, 39, '2597'),
	(377, 1, 0, -50282, 2599, 0, 0, 39, '2598'),
	(377, 1, 0, -50282, 2600, 0, 0, 39, '2599'),
	(377, 1, 0, -50282, 2601, 0, 0, 39, '2600'),
	(377, 1, 0, -50282, 2602, 0, 0, 39, '2601'),
	(377, 1, 0, -50282, 2603, 0, 0, 39, '2602'),
	(377, 1, 0, -50282, 2604, 0, 0, 39, '2603'),
	(377, 1, 0, -50282, 2605, 0, 0, 39, '2604'),
	(377, 1, 0, -50282, 2606, 0, 0, 39, '2605'),
	(377, 1, 0, -50282, 2607, 0, 0, 39, '2606'),
	(377, 1, 0, -50282, 2608, 0, 0, 39, '2607'),
	(377, 1, 0, -50282, 2609, 0, 0, 39, '2608'),
	(377, 1, 0, -50282, 2610, 0, 0, 39, '2609'),
	(377, 1, 0, -50282, 2611, 0, 0, 39, '2610'),
	(377, 1, 0, -50282, 2612, 0, 0, 39, '2611'),
	(377, 1, 0, -50282, 2613, 0, 0, 39, '2612'),
	(377, 1, 0, -50282, 2614, 0, 0, 39, '2613'),
	(377, 1, 0, -50282, 2615, 0, 0, 39, '2614'),
	(377, 1, 0, -50282, 2616, 0, 0, 39, '2615'),
	(377, 1, 0, -50282, 2617, 0, 0, 39, '2616'),
	(377, 1, 0, -50282, 2618, 0, 0, 39, '2617'),
	(377, 1, 0, -50282, 2619, 0, 0, 39, '2618'),
	(377, 1, 0, -50282, 2620, 0, 0, 39, '2619'),
	(377, 1, 0, -50282, 2621, 0, 0, 39, '2620'),
	(377, 1, 0, -50282, 2622, 0, 0, 39, '2621'),
	(377, 1, 0, -50282, 2623, 0, 0, 39, '2622'),
	(377, 1, 0, -50282, 2624, 0, 0, 39, '2623'),
	(377, 1, 0, -50282, 2625, 0, 0, 39, '2624'),
	(377, 1, 0, -50282, 2626, 0, 0, 39, '2625'),
	(377, 1, 0, -50282, 2627, 0, 0, 39, '2626'),
	(377, 1, 0, -50282, 2628, 0, 0, 39, '2627'),
	(377, 1, 0, -50282, 2629, 0, 0, 39, '2628'),
	(377, 1, 0, -50282, 2630, 0, 0, 39, '2629'),
	(377, 1, 0, -50282, 2631, 0, 0, 39, '2630'),
	(377, 1, 0, -50282, 2632, 0, 0, 39, '2631'),
	(377, 1, 0, -50282, 2633, 0, 0, 39, '2632'),
	(377, 1, 0, -50282, 2634, 0, 0, 39, '2633'),
	(377, 1, 0, -50282, 2635, 0, 0, 39, '2634'),
	(377, 1, 0, -50282, 2636, 0, 0, 39, '2635'),
	(377, 1, 0, -50282, 2637, 0, 0, 39, '2636'),
	(377, 1, 0, -50282, 2638, 0, 0, 39, '2637'),
	(377, 1, 0, -50282, 2639, 0, 0, 39, '2638'),
	(377, 1, 0, -50282, 2640, 0, 0, 39, '2639'),
	(377, 1, 0, -50282, 2641, 0, 0, 39, '2640'),
	(377, 1, 0, -50282, 2642, 0, 0, 39, '2641'),
	(377, 1, 0, -50282, 2643, 0, 0, 39, '2642'),
	(377, 1, 0, -50282, 2644, 0, 0, 39, '2643'),
	(377, 1, 0, -50282, 2645, 0, 0, 39, '2644'),
	(377, 1, 0, -50282, 2646, 0, 0, 39, '2645'),
	(377, 1, 0, -50282, 2647, 0, 0, 39, '2646'),
	(377, 1, 0, -50282, 2648, 0, 0, 39, '2647'),
	(377, 1, 0, -50282, 2649, 0, 0, 39, '2648'),
	(377, 1, 0, -50282, 2650, 0, 0, 39, '2649'),
	(377, 1, 0, -50282, 2651, 0, 0, 39, '2650'),
	(377, 1, 0, -50282, 2652, 0, 0, 39, '2651'),
	(377, 1, 0, -50282, 2653, 0, 0, 39, '2652'),
	(377, 1, 0, -50282, 2654, 0, 0, 39, '2653'),
	(377, 1, 0, -50282, 2655, 0, 0, 39, '2654'),
	(377, 1, 0, -50282, 2656, 0, 0, 39, '2655'),
	(377, 1, 0, -50282, 2657, 0, 0, 39, '2656'),
	(377, 1, 0, -50282, 2658, 0, 0, 39, '2657'),
	(377, 1, 0, -50282, 2659, 0, 0, 39, '2658'),
	(377, 1, 0, -50282, 2660, 0, 0, 39, '2659'),
	(377, 1, 0, -50282, 2661, 0, 0, 39, '2660'),
	(377, 1, 0, -50282, 2662, 0, 0, 39, '2661'),
	(377, 1, 0, -50282, 2663, 0, 0, 39, '2662'),
	(377, 1, 0, -50282, 2664, 0, 0, 39, '2663'),
	(377, 1, 0, -50282, 2665, 0, 0, 39, '2664'),
	(377, 1, 0, -50282, 2666, 0, 0, 39, '2665'),
	(377, 1, 0, -50282, 2667, 0, 0, 39, '2666'),
	(377, 1, 0, -50282, 2668, 0, 0, 39, '2667'),
	(377, 1, 0, -50282, 2669, 0, 0, 39, '2668'),
	(377, 1, 0, -50282, 2670, 0, 0, 39, '2669'),
	(377, 1, 0, -50282, 2671, 0, 0, 39, '2670'),
	(377, 1, 0, -50282, 2672, 0, 0, 39, '2671'),
	(377, 1, 0, -50282, 2673, 0, 0, 39, '2672'),
	(377, 1, 0, -50282, 2674, 0, 0, 39, '2673'),
	(377, 1, 0, -50282, 2675, 0, 0, 39, '2674'),
	(377, 1, 0, -50282, 2676, 0, 0, 39, '2675'),
	(377, 1, 0, -50282, 2677, 0, 0, 39, '2676'),
	(377, 1, 0, -50282, 2678, 0, 0, 39, '2677'),
	(377, 1, 0, -50282, 2679, 0, 0, 39, '2678'),
	(377, 1, 0, -50282, 2680, 0, 0, 39, '2679'),
	(377, 1, 0, -50282, 2681, 0, 0, 39, '2680'),
	(377, 1, 0, -50282, 2682, 0, 0, 39, '2681'),
	(377, 1, 0, -50282, 2683, 0, 0, 39, '2682'),
	(377, 1, 0, -50282, 2684, 0, 0, 39, '2683'),
	(377, 1, 0, -50282, 2685, 0, 0, 39, '2684'),
	(377, 1, 0, -50282, 2686, 0, 0, 39, '2685'),
	(377, 1, 0, -50282, 2687, 0, 0, 39, '2686'),
	(377, 1, 0, -50282, 2688, 0, 0, 39, '2687'),
	(377, 1, 0, -50282, 2689, 0, 0, 39, '2688'),
	(377, 1, 0, -50282, 2690, 0, 0, 39, '2689'),
	(377, 1, 0, -50282, 2691, 0, 0, 39, '2690'),
	(377, 1, 0, -50282, 2692, 0, 0, 39, '2691'),
	(377, 1, 0, -50282, 2693, 0, 0, 39, '2692'),
	(377, 1, 0, -50282, 2694, 0, 0, 39, '2693'),
	(377, 1, 0, -50282, 2695, 0, 0, 39, '2694'),
	(377, 1, 0, -50282, 2696, 0, 0, 39, '2695'),
	(377, 1, 0, -50282, 2697, 0, 0, 39, '2696'),
	(377, 1, 0, -50282, 2698, 0, 0, 39, '2697'),
	(377, 1, 0, -50282, 2699, 0, 0, 39, '2698'),
	(377, 1, 0, -50282, 2700, 0, 0, 39, '2699'),
	(377, 1, 0, -50282, 2701, 0, 0, 39, '2700'),
	(377, 1, 0, -50282, 2702, 0, 0, 39, '2701'),
	(377, 1, 0, -50282, 2703, 0, 0, 39, '2702'),
	(377, 1, 0, -50282, 2704, 0, 0, 39, '2703'),
	(377, 1, 0, -50282, 2705, 0, 0, 39, '2704'),
	(377, 1, 0, -50282, 2706, 0, 0, 39, '2705'),
	(377, 1, 0, -50282, 2707, 0, 0, 39, '2706'),
	(377, 1, 0, -50282, 2708, 0, 0, 39, '2707'),
	(377, 1, 0, -50282, 2709, 0, 0, 39, '2708'),
	(377, 1, 0, -50282, 2710, 0, 0, 39, '2709'),
	(377, 1, 0, -50282, 2711, 0, 0, 39, '2710'),
	(377, 1, 0, -50282, 2712, 0, 0, 39, '2711'),
	(377, 1, 0, -50282, 2713, 0, 0, 39, '2712'),
	(377, 1, 0, -50282, 2714, 0, 0, 39, '2713'),
	(377, 1, 0, -50282, 2715, 0, 0, 39, '2714'),
	(377, 1, 0, -50282, 2716, 0, 0, 39, '2715'),
	(377, 1, 0, -50282, 2717, 0, 0, 39, '2716'),
	(377, 1, 0, -50282, 2718, 0, 0, 39, '2717'),
	(377, 1, 0, -50282, 2719, 0, 0, 39, '2718'),
	(377, 1, 0, -50282, 2720, 0, 0, 39, '2719'),
	(377, 1, 0, -50282, 2721, 0, 0, 39, '2720'),
	(377, 1, 0, -50282, 2722, 0, 0, 39, '2721'),
	(377, 1, 0, -50282, 2723, 0, 0, 39, '2722'),
	(377, 1, 0, -50282, 2724, 0, 0, 39, '2723'),
	(377, 1, 0, -50282, 2725, 0, 0, 39, '2724'),
	(377, 1, 0, -50282, 2726, 0, 0, 39, '2725'),
	(377, 1, 0, -50282, 2727, 0, 0, 39, '2726'),
	(377, 1, 0, -50282, 2728, 0, 0, 39, '2727'),
	(377, 1, 0, -50282, 2729, 0, 0, 39, '2728'),
	(377, 1, 0, -50282, 2730, 0, 0, 39, '2729'),
	(377, 1, 0, -50282, 2731, 0, 0, 39, '2730'),
	(377, 1, 0, -50282, 2732, 0, 0, 39, '2731'),
	(377, 1, 0, -50282, 2733, 0, 0, 39, '2732'),
	(377, 1, 0, -50282, 2734, 0, 0, 39, '2733'),
	(377, 1, 0, -50282, 2735, 0, 0, 39, '2734'),
	(377, 1, 0, -50282, 2736, 0, 0, 39, '2735'),
	(377, 1, 0, -50282, 2737, 0, 0, 39, '2736'),
	(377, 1, 0, -50282, 2738, 0, 0, 39, '2737'),
	(377, 1, 0, -50282, 2739, 0, 0, 39, '2738'),
	(377, 1, 0, -50282, 2740, 0, 0, 39, '2739'),
	(377, 1, 0, -50282, 2741, 0, 0, 39, '2740'),
	(377, 1, 0, -50282, 2742, 0, 0, 39, '2741'),
	(377, 1, 0, -50282, 2743, 0, 0, 39, '2742'),
	(377, 1, 0, -50282, 2744, 0, 0, 39, '2743'),
	(377, 1, 0, -50282, 2745, 0, 0, 39, '2744'),
	(377, 1, 0, -50282, 2746, 0, 0, 39, '2745'),
	(377, 1, 0, -50282, 2747, 0, 0, 39, '2746'),
	(377, 1, 0, -50282, 2748, 0, 0, 39, '2747'),
	(377, 1, 0, -50282, 2749, 0, 0, 39, '2748'),
	(377, 1, 0, -50282, 2750, 0, 0, 39, '2749'),
	(377, 1, 0, -50282, 2751, 0, 0, 39, '2750'),
	(377, 1, 0, -50282, 2752, 0, 0, 39, '2751'),
	(377, 1, 0, -50282, 2753, 0, 0, 39, '2752'),
	(377, 1, 0, -50282, 2754, 0, 0, 39, '2753'),
	(377, 1, 0, -50282, 2755, 0, 0, 39, '2754'),
	(377, 1, 0, -50282, 2756, 0, 0, 39, '2755'),
	(377, 1, 0, -50282, 2757, 0, 0, 39, '2756'),
	(377, 1, 0, -50282, 2758, 0, 0, 39, '2757'),
	(377, 1, 0, -50282, 2759, 0, 0, 39, '2758'),
	(377, 1, 0, -50282, 2760, 0, 0, 39, '2759'),
	(377, 1, 0, -50282, 2761, 0, 0, 39, '2760'),
	(377, 1, 0, -50282, 2762, 0, 0, 39, '2761'),
	(377, 1, 0, -50282, 2763, 0, 0, 39, '2762'),
	(377, 1, 0, -50282, 2764, 0, 0, 39, '2763'),
	(377, 1, 0, -50282, 2765, 0, 0, 39, '2764'),
	(377, 1, 0, -50282, 2766, 0, 0, 39, '2765'),
	(377, 1, 0, -50282, 2767, 0, 0, 39, '2766'),
	(377, 1, 0, -50282, 2768, 0, 0, 39, '2767'),
	(377, 1, 0, -50282, 2769, 0, 0, 39, '2768'),
	(377, 1, 0, -50282, 2770, 0, 0, 39, '2769'),
	(377, 1, 0, -50282, 2771, 0, 0, 39, '2770'),
	(377, 1, 0, -50282, 2772, 0, 0, 39, '2771'),
	(377, 1, 0, -50282, 2773, 0, 0, 39, '2772'),
	(377, 1, 0, -50282, 2774, 0, 0, 39, '2773'),
	(377, 1, 0, -50282, 2775, 0, 0, 39, '2774'),
	(377, 1, 0, -50282, 2776, 0, 0, 39, '2775'),
	(377, 1, 0, -50282, 2777, 0, 0, 39, '2776'),
	(377, 1, 0, -50282, 2778, 0, 0, 39, '2777'),
	(377, 1, 0, -50282, 2779, 0, 0, 39, '2778'),
	(377, 1, 0, -50282, 2780, 0, 0, 39, '2779'),
	(377, 1, 0, -50282, 2781, 0, 0, 39, '2780'),
	(377, 1, 0, -50282, 2782, 0, 0, 39, '2781'),
	(377, 1, 0, -50282, 2783, 0, 0, 39, '2782'),
	(377, 1, 0, -50282, 2784, 0, 0, 39, '2783'),
	(377, 1, 0, -50282, 2785, 0, 0, 39, '2784'),
	(377, 1, 0, -50282, 2786, 0, 0, 39, '2785'),
	(377, 1, 0, -50282, 2787, 0, 0, 39, '2786'),
	(377, 1, 0, -50282, 2788, 0, 0, 39, '2787'),
	(377, 1, 0, -50282, 2789, 0, 0, 39, '2788'),
	(377, 1, 0, -50282, 2790, 0, 0, 39, '2789'),
	(377, 1, 0, -50282, 2791, 0, 0, 39, '2790'),
	(377, 1, 0, -50282, 2792, 0, 0, 39, '2791'),
	(377, 1, 0, -50282, 2793, 0, 0, 39, '2792'),
	(377, 1, 0, -50282, 2794, 0, 0, 39, '2793'),
	(377, 1, 0, -50282, 2795, 0, 0, 39, '2794'),
	(377, 1, 0, -50282, 2796, 0, 0, 39, '2795'),
	(377, 1, 0, -50282, 2797, 0, 0, 39, '2796'),
	(377, 1, 0, -50282, 2798, 0, 0, 39, '2797'),
	(377, 1, 0, -50282, 2799, 0, 0, 39, '2798'),
	(377, 1, 0, -50282, 2800, 0, 0, 39, '2799'),
	(377, 1, 0, -50282, 2801, 0, 0, 39, '2800'),
	(377, 1, 0, -50282, 2802, 0, 0, 39, '2801'),
	(377, 1, 0, -50282, 2803, 0, 0, 39, '2802'),
	(377, 1, 0, -50282, 2804, 0, 0, 39, '2803'),
	(377, 1, 0, -50282, 2805, 0, 0, 39, '2804'),
	(377, 1, 0, -50282, 2806, 0, 0, 39, '2805'),
	(377, 1, 0, -50282, 2807, 0, 0, 39, '2806'),
	(377, 1, 0, -50282, 2808, 0, 0, 39, '2807'),
	(377, 1, 0, -50282, 2809, 0, 0, 39, '2808'),
	(377, 1, 0, -50282, 2810, 0, 0, 39, '2809'),
	(377, 1, 0, -50282, 2811, 0, 0, 39, '2810'),
	(377, 1, 0, -50282, 2812, 0, 0, 39, '2811'),
	(377, 1, 0, -50282, 2813, 0, 0, 39, '2812'),
	(377, 1, 0, -50282, 2814, 0, 0, 39, '2813'),
	(377, 1, 0, -50282, 2815, 0, 0, 39, '2814'),
	(377, 1, 0, -50282, 2816, 0, 0, 39, '2815'),
	(377, 1, 0, -50282, 2817, 0, 0, 39, '2816'),
	(377, 1, 0, -50282, 2818, 0, 0, 39, '2817'),
	(377, 1, 0, -50282, 2819, 0, 0, 39, '2818'),
	(377, 1, 0, -50282, 2820, 0, 0, 39, '2819'),
	(377, 1, 0, -50282, 2821, 0, 0, 39, '2820'),
	(377, 1, 0, -50282, 2822, 0, 0, 39, '2821'),
	(377, 1, 0, -50282, 2823, 0, 0, 39, '2822'),
	(377, 1, 0, -50282, 2824, 0, 0, 39, '2823'),
	(377, 1, 0, -50282, 2825, 0, 0, 39, '2824'),
	(377, 1, 0, -50282, 2826, 0, 0, 39, '2825'),
	(377, 1, 0, -50282, 2827, 0, 0, 39, '2826'),
	(377, 1, 0, -50282, 2828, 0, 0, 39, '2827'),
	(377, 1, 0, -50282, 2829, 0, 0, 39, '2828'),
	(377, 1, 0, -50282, 2830, 0, 0, 39, '2829'),
	(377, 1, 0, -50282, 2831, 0, 0, 39, '2830'),
	(377, 1, 0, -50282, 2832, 0, 0, 39, '2831'),
	(377, 1, 0, -50282, 2833, 0, 0, 39, '2832'),
	(377, 1, 0, -50282, 2834, 0, 0, 39, '2833'),
	(377, 1, 0, -50282, 2835, 0, 0, 39, '2834'),
	(377, 1, 0, -50282, 2836, 0, 0, 39, '2835'),
	(377, 1, 0, -50282, 2837, 0, 0, 39, '2836'),
	(377, 1, 0, -50282, 2838, 0, 0, 39, '2837'),
	(377, 1, 0, -50282, 2839, 0, 0, 39, '2838'),
	(377, 1, 0, -50282, 2840, 0, 0, 39, '2839'),
	(377, 1, 0, -50282, 2841, 0, 0, 39, '2840'),
	(377, 1, 0, -50282, 2842, 0, 0, 39, '2841'),
	(377, 1, 0, -50282, 2843, 0, 0, 39, '2842'),
	(377, 1, 0, -50282, 2844, 0, 0, 39, '2843'),
	(377, 1, 0, -50282, 2845, 0, 0, 39, '2844'),
	(377, 1, 0, -50282, 2846, 0, 0, 39, '2845'),
	(377, 1, 0, -50282, 2847, 0, 0, 39, '2846'),
	(377, 1, 0, -50282, 2848, 0, 0, 39, '2847'),
	(377, 1, 0, -50282, 2849, 0, 0, 39, '2848'),
	(377, 1, 0, -50282, 2850, 0, 0, 39, '2849'),
	(377, 1, 0, -50282, 2851, 0, 0, 39, '2850'),
	(377, 1, 0, -50282, 2852, 0, 0, 39, '2851'),
	(377, 1, 0, -50282, 2853, 0, 0, 39, '2852'),
	(377, 1, 0, -50282, 2854, 0, 0, 39, '2853'),
	(377, 1, 0, -50282, 2855, 0, 0, 39, '2854'),
	(377, 1, 0, -50282, 2856, 0, 0, 39, '2855'),
	(377, 1, 0, -50282, 2857, 0, 0, 39, '2856'),
	(377, 1, 0, -50282, 2858, 0, 0, 39, '2857'),
	(377, 1, 0, -50282, 2859, 0, 0, 39, '2858'),
	(377, 1, 0, -50282, 2860, 0, 0, 39, '2859'),
	(377, 1, 0, -50282, 2861, 0, 0, 39, '2860'),
	(377, 1, 0, -50282, 2862, 0, 0, 39, '2861'),
	(377, 1, 0, -50282, 2863, 0, 0, 39, '2862'),
	(377, 1, 0, -50282, 2864, 0, 0, 39, '2863'),
	(377, 1, 0, -50282, 2865, 0, 0, 39, '2864'),
	(377, 1, 0, -50282, 2866, 0, 0, 39, '2865'),
	(377, 1, 0, -50282, 2867, 0, 0, 39, '2866'),
	(377, 1, 0, -50282, 2868, 0, 0, 39, '2867'),
	(377, 1, 0, -50282, 2869, 0, 0, 39, '2868'),
	(377, 1, 0, -50282, 2870, 0, 0, 39, '2869'),
	(377, 1, 0, -50282, 2871, 0, 0, 39, '2870'),
	(377, 1, 0, -50282, 2872, 0, 0, 39, '2871'),
	(377, 1, 0, -50282, 2873, 0, 0, 39, '2872'),
	(377, 1, 0, -50282, 2874, 0, 0, 39, '2873'),
	(377, 1, 0, -50282, 2875, 0, 0, 39, '2874'),
	(377, 1, 0, -50282, 2876, 0, 0, 39, '2875'),
	(377, 1, 0, -50282, 2877, 0, 0, 39, '2876'),
	(377, 1, 0, -50282, 2878, 0, 0, 39, '2877'),
	(377, 1, 0, -50282, 2879, 0, 0, 39, '2878'),
	(377, 1, 0, -50282, 2880, 0, 0, 39, '2879'),
	(377, 1, 0, -50282, 2881, 0, 0, 39, '2880'),
	(377, 1, 0, -50282, 2882, 0, 0, 39, '2881'),
	(377, 1, 0, -50282, 2883, 0, 0, 39, '2882'),
	(377, 1, 0, -50282, 2884, 0, 0, 39, '2883'),
	(377, 1, 0, -50282, 2885, 0, 0, 39, '2884'),
	(377, 1, 0, -50282, 2886, 0, 0, 39, '2885'),
	(377, 1, 0, -50282, 2887, 0, 0, 39, '2886'),
	(377, 1, 0, -50282, 2888, 0, 0, 39, '2887'),
	(377, 1, 0, -50282, 2889, 0, 0, 39, '2888'),
	(377, 1, 0, -50282, 2890, 0, 0, 39, '2889'),
	(377, 1, 0, -50282, 2891, 0, 0, 39, '2890'),
	(377, 1, 0, -50282, 2892, 0, 0, 39, '2891'),
	(377, 1, 0, -50282, 2893, 0, 0, 39, '2892'),
	(377, 1, 0, -50282, 2894, 0, 0, 39, '2893'),
	(377, 1, 0, -50282, 2895, 0, 0, 39, '2894'),
	(377, 1, 0, -50282, 2896, 0, 0, 39, '2895'),
	(377, 1, 0, -50282, 2897, 0, 0, 39, '2896'),
	(377, 1, 0, -50282, 2898, 0, 0, 39, '2897'),
	(377, 1, 0, -50282, 2899, 0, 0, 39, '2898'),
	(377, 1, 0, -50282, 2900, 0, 0, 39, '2899'),
	(377, 1, 0, -50282, 2901, 0, 0, 39, '2900'),
	(377, 1, 0, -50282, 2902, 0, 0, 39, '2901'),
	(377, 1, 0, -50282, 2903, 0, 0, 39, '2902'),
	(377, 1, 0, -50282, 2904, 0, 0, 39, '2903'),
	(377, 1, 0, -50282, 2905, 0, 0, 39, '2904'),
	(377, 1, 0, -50282, 2906, 0, 0, 39, '2905'),
	(377, 1, 0, -50282, 2907, 0, 0, 39, '2906'),
	(377, 1, 0, -50282, 2908, 0, 0, 39, '2907'),
	(377, 1, 0, -50282, 2909, 0, 0, 39, '2908'),
	(377, 1, 0, -50282, 2910, 0, 0, 39, '2909'),
	(377, 1, 0, -50282, 2911, 0, 0, 39, '2910'),
	(377, 1, 0, -50282, 2912, 0, 0, 39, '2911'),
	(377, 1, 0, -50282, 2913, 0, 0, 39, '2912'),
	(377, 1, 0, -50282, 2914, 0, 0, 39, '2913'),
	(377, 1, 0, -50282, 2915, 0, 0, 39, '2914'),
	(377, 1, 0, -50282, 2916, 0, 0, 39, '2915'),
	(377, 1, 0, -50282, 2917, 0, 0, 39, '2916'),
	(377, 1, 0, -50282, 2918, 0, 0, 39, '2917'),
	(377, 1, 0, -50282, 2919, 0, 0, 39, '2918'),
	(377, 1, 0, -50282, 2920, 0, 0, 39, '2919'),
	(377, 1, 0, -50282, 2921, 0, 0, 39, '2920'),
	(377, 1, 0, -50282, 2922, 0, 0, 39, '2921'),
	(377, 1, 0, -50282, 2923, 0, 0, 39, '2922'),
	(377, 1, 0, -50282, 2924, 0, 0, 39, '2923'),
	(377, 1, 0, -50282, 2925, 0, 0, 39, '2924'),
	(377, 1, 0, -50282, 2926, 0, 0, 39, '2925'),
	(377, 1, 0, -50282, 2927, 0, 0, 39, '2926'),
	(377, 1, 0, -50282, 2928, 0, 0, 39, '2927'),
	(377, 1, 0, -50282, 2929, 0, 0, 39, '2928'),
	(377, 1, 0, -50282, 2930, 0, 0, 39, '2929'),
	(377, 1, 0, -50282, 2931, 0, 0, 39, '2930'),
	(377, 1, 0, -50282, 2932, 0, 0, 39, '2931'),
	(377, 1, 0, -50282, 2933, 0, 0, 39, '2932'),
	(377, 1, 0, -50282, 2934, 0, 0, 39, '2933'),
	(377, 1, 0, -50282, 2935, 0, 0, 39, '2934'),
	(377, 1, 0, -50282, 2936, 0, 0, 39, '2935'),
	(377, 1, 0, -50282, 2937, 0, 0, 39, '2936'),
	(377, 1, 0, -50282, 2938, 0, 0, 39, '2937'),
	(377, 1, 0, -50282, 2939, 0, 0, 39, '2938'),
	(377, 1, 0, -50282, 2940, 0, 0, 39, '2939'),
	(377, 1, 0, -50282, 2941, 0, 0, 39, '2940'),
	(377, 1, 0, -50282, 2942, 0, 0, 39, '2941'),
	(377, 1, 0, -50282, 2943, 0, 0, 39, '2942'),
	(377, 1, 0, -50282, 2944, 0, 0, 39, '2943'),
	(377, 1, 0, -50282, 2945, 0, 0, 39, '2944'),
	(377, 1, 0, -50282, 2946, 0, 0, 39, '2945'),
	(377, 1, 0, -50282, 2947, 0, 0, 39, '2946'),
	(377, 1, 0, -50282, 2948, 0, 0, 39, '2947'),
	(377, 1, 0, -50282, 2949, 0, 0, 39, '2948'),
	(377, 1, 0, -50282, 2950, 0, 0, 39, '2949'),
	(377, 1, 0, -50282, 2951, 0, 0, 39, '2950'),
	(377, 1, 0, -50282, 2952, 0, 0, 39, '2951'),
	(377, 1, 0, -50282, 2953, 0, 0, 39, '2952'),
	(377, 1, 0, -50282, 2954, 0, 0, 39, '2953'),
	(377, 1, 0, -50282, 2955, 0, 0, 39, '2954'),
	(377, 1, 0, -50282, 2956, 0, 0, 39, '2955'),
	(377, 1, 0, -50282, 2957, 0, 0, 39, '2956'),
	(377, 1, 0, -50282, 2958, 0, 0, 39, '2957'),
	(377, 1, 0, -50282, 2959, 0, 0, 39, '2958'),
	(377, 1, 0, -50282, 2960, 0, 0, 39, '2959'),
	(377, 1, 0, -50282, 2961, 0, 0, 39, '2960'),
	(377, 1, 0, -50282, 2962, 0, 0, 39, '2961'),
	(377, 1, 0, -50282, 2963, 0, 0, 39, '2962'),
	(377, 1, 0, -50282, 2964, 0, 0, 39, '2963'),
	(377, 1, 0, -50282, 2965, 0, 0, 39, '2964'),
	(377, 1, 0, -50282, 2966, 0, 0, 39, '2965'),
	(377, 1, 0, -50282, 2967, 0, 0, 39, '2966'),
	(377, 1, 0, -50282, 2968, 0, 0, 39, '2967'),
	(377, 1, 0, -50282, 2969, 0, 0, 39, '2968'),
	(377, 1, 0, -50282, 2970, 0, 0, 39, '2969'),
	(377, 1, 0, -50282, 2971, 0, 0, 39, '2970'),
	(377, 1, 0, -50282, 2972, 0, 0, 39, '2971'),
	(377, 1, 0, -50282, 2973, 0, 0, 39, '2972'),
	(377, 1, 0, -50282, 2974, 0, 0, 39, '2973'),
	(377, 1, 0, -50282, 2975, 0, 0, 39, '2974'),
	(377, 1, 0, -50282, 2976, 0, 0, 39, '2975'),
	(377, 1, 0, -50282, 2977, 0, 0, 39, '2976'),
	(377, 1, 0, -50282, 2978, 0, 0, 39, '2977'),
	(377, 1, 0, -50282, 2979, 0, 0, 39, '2978'),
	(377, 1, 0, -50282, 2980, 0, 0, 39, '2979'),
	(377, 1, 0, -50282, 2981, 0, 0, 39, '2980'),
	(377, 1, 0, -50282, 2982, 0, 0, 39, '2981'),
	(377, 1, 0, -50282, 2983, 0, 0, 39, '2982'),
	(377, 1, 0, -50282, 2984, 0, 0, 39, '2983'),
	(377, 1, 0, -50282, 2985, 0, 0, 39, '2984'),
	(377, 1, 0, -50282, 2986, 0, 0, 39, '2985'),
	(377, 1, 0, -50282, 2987, 0, 0, 39, '2986'),
	(377, 1, 0, -50282, 2988, 0, 0, 39, '2987'),
	(377, 1, 0, -50282, 2989, 0, 0, 39, '2988'),
	(377, 1, 0, -50282, 2990, 0, 0, 39, '2989'),
	(377, 1, 0, -50282, 2991, 0, 0, 39, '2990'),
	(377, 1, 0, -50282, 2992, 0, 0, 39, '2991'),
	(377, 1, 0, -50282, 2993, 0, 0, 39, '2992'),
	(377, 1, 0, -50282, 2994, 0, 0, 39, '2993'),
	(377, 1, 0, -50282, 2995, 0, 0, 39, '2994'),
	(377, 1, 0, -50282, 2996, 0, 0, 39, '2995'),
	(377, 1, 0, -50282, 2997, 0, 0, 39, '2996'),
	(377, 1, 0, -50282, 2998, 0, 0, 39, '2997'),
	(377, 1, 0, -50282, 2999, 0, 0, 39, '2998'),
	(377, 1, 0, -50282, 3000, 0, 0, 39, '2999'),
	(377, 1, 0, -50282, 3001, 0, 0, 39, '3000'),
	(377, 1, 0, -50282, 3002, 0, 0, 39, '3001'),
	(377, 1, 0, -50282, 3003, 0, 0, 39, '3002'),
	(377, 1, 0, -50282, 3004, 0, 0, 39, '3003'),
	(377, 1, 0, -50282, 3005, 0, 0, 39, '3004'),
	(377, 1, 0, -50282, 3006, 0, 0, 39, '3005'),
	(377, 1, 0, -50282, 3007, 0, 0, 39, '3006'),
	(377, 1, 0, -50282, 3008, 0, 0, 39, '3007'),
	(377, 1, 0, -50282, 3009, 0, 0, 39, '3008'),
	(377, 1, 0, -50282, 3010, 0, 0, 39, '3009'),
	(377, 1, 0, -50282, 3011, 0, 0, 39, '3010'),
	(377, 1, 0, -50282, 3012, 0, 0, 39, '3011'),
	(377, 1, 0, -50282, 3013, 0, 0, 39, '3012'),
	(377, 1, 0, -50282, 3014, 0, 0, 39, '3013'),
	(377, 1, 0, -50282, 3015, 0, 0, 39, '3014'),
	(377, 1, 0, -50282, 3016, 0, 0, 39, '3015'),
	(377, 1, 0, -50282, 3017, 0, 0, 39, '3016'),
	(377, 1, 0, -50282, 3018, 0, 0, 39, '3017'),
	(377, 1, 0, -50282, 3019, 0, 0, 39, '3018'),
	(377, 1, 0, -50282, 3020, 0, 0, 39, '3019'),
	(377, 1, 0, -50282, 3021, 0, 0, 39, '3020'),
	(377, 1, 0, -50282, 3022, 0, 0, 39, '3021'),
	(377, 1, 0, -50282, 3023, 0, 0, 39, '3022'),
	(377, 1, 0, -50282, 3024, 0, 0, 39, '3023'),
	(377, 1, 0, -50282, 3025, 0, 0, 39, '3024'),
	(377, 1, 0, -50282, 3026, 0, 0, 39, '3025'),
	(377, 1, 0, -50282, 3027, 0, 0, 39, '3026'),
	(377, 1, 0, -50282, 3028, 0, 0, 39, '3027'),
	(377, 1, 0, -50282, 3029, 0, 0, 39, '3028'),
	(377, 1, 0, -50282, 3030, 0, 0, 39, '3029'),
	(377, 1, 0, -50282, 3031, 0, 0, 39, '3030'),
	(377, 1, 0, -50282, 3032, 0, 0, 39, '3031'),
	(377, 1, 0, -50282, 3033, 0, 0, 39, '3032'),
	(377, 1, 0, -50282, 3034, 0, 0, 39, '3033'),
	(377, 1, 0, -50282, 3035, 0, 0, 39, '3034'),
	(377, 1, 0, -50282, 3036, 0, 0, 39, '3035'),
	(377, 1, 0, -50282, 3037, 0, 0, 39, '3036'),
	(377, 1, 0, -50282, 3038, 0, 0, 39, '3037'),
	(377, 1, 0, -50282, 3039, 0, 0, 39, '3038'),
	(377, 1, 0, -50282, 3040, 0, 0, 39, '3039'),
	(377, 1, 0, -50282, 3041, 0, 0, 39, '3040'),
	(377, 1, 0, -50282, 3042, 0, 0, 39, '3041'),
	(377, 1, 0, -50282, 3043, 0, 0, 39, '3042'),
	(377, 1, 0, -50282, 3044, 0, 0, 39, '3043'),
	(377, 1, 0, -50282, 3045, 0, 0, 39, '3044'),
	(377, 1, 0, -50282, 3046, 0, 0, 39, '3045'),
	(377, 1, 0, -50282, 3047, 0, 0, 39, '3046'),
	(377, 1, 0, -50282, 3048, 0, 0, 39, '3047'),
	(377, 1, 0, -50282, 3049, 0, 0, 39, '3048'),
	(377, 1, 0, -50282, 3050, 0, 0, 39, '3049'),
	(377, 1, 0, -50282, 3051, 0, 0, 39, '3050'),
	(377, 1, 0, -50282, 3052, 0, 0, 39, '3051'),
	(377, 1, 0, -50282, 3053, 0, 0, 39, '3052'),
	(377, 1, 0, -50282, 3054, 0, 0, 39, '3053'),
	(377, 1, 0, -50282, 3055, 0, 0, 39, '3054'),
	(377, 1, 0, -50282, 3056, 0, 0, 39, '3055'),
	(377, 1, 0, -50282, 3057, 0, 0, 39, '3056'),
	(377, 1, 0, -50282, 3058, 0, 0, 39, '3057'),
	(377, 1, 0, -50282, 3059, 0, 0, 39, '3058'),
	(377, 1, 0, -50282, 3060, 0, 0, 39, '3059'),
	(377, 1, 0, -50282, 3061, 0, 0, 39, '3060'),
	(377, 1, 0, -50282, 3062, 0, 0, 39, '3061'),
	(377, 1, 0, -50282, 3063, 0, 0, 39, '3062'),
	(377, 1, 0, -50282, 3064, 0, 0, 39, '3063'),
	(377, 1, 0, -50282, 3065, 0, 0, 39, '3064'),
	(377, 1, 0, -50282, 3066, 0, 0, 39, '3065'),
	(377, 1, 0, -50282, 3067, 0, 0, 39, '3066'),
	(377, 1, 0, -50282, 3068, 0, 0, 39, '3067'),
	(377, 1, 0, -50282, 3069, 0, 0, 39, '3068'),
	(377, 1, 0, -50282, 3070, 0, 0, 39, '3069'),
	(377, 1, 0, -50282, 3071, 0, 0, 39, '3070'),
	(377, 1, 0, -50282, 3072, 0, 0, 39, '3071'),
	(377, 1, 0, -50282, 3073, 0, 0, 39, '3072'),
	(377, 1, 0, -50282, 3074, 0, 0, 39, '3073'),
	(377, 1, 0, -50282, 3075, 0, 0, 39, '3074'),
	(377, 1, 0, -50282, 3076, 0, 0, 39, '3075'),
	(377, 1, 0, -50282, 3077, 0, 0, 39, '3076'),
	(377, 1, 0, -50282, 3078, 0, 0, 39, '3077'),
	(377, 1, 0, -50282, 3079, 0, 0, 39, '3078'),
	(377, 1, 0, -50282, 3080, 0, 0, 39, '3079'),
	(377, 1, 0, -50282, 3081, 0, 0, 39, '3080'),
	(377, 1, 0, -50282, 3082, 0, 0, 39, '3081'),
	(377, 1, 0, -50282, 3083, 0, 0, 39, '3082'),
	(377, 1, 0, -50282, 3084, 0, 0, 39, '3083'),
	(377, 1, 0, -50282, 3085, 0, 0, 39, '3084'),
	(377, 1, 0, -50282, 3086, 0, 0, 39, '3085'),
	(377, 1, 0, -50282, 3087, 0, 0, 39, '3086'),
	(377, 1, 0, -50282, 3088, 0, 0, 39, '3087'),
	(377, 1, 0, -50282, 3089, 0, 0, 39, '3088'),
	(377, 1, 0, -50282, 3090, 0, 0, 39, '3089'),
	(377, 1, 0, -50282, 3091, 0, 0, 39, '3090'),
	(377, 1, 0, -50282, 3092, 0, 0, 39, '3091'),
	(377, 1, 0, -50282, 3093, 0, 0, 39, '3092'),
	(377, 1, 0, -50282, 3094, 0, 0, 39, '3093'),
	(377, 1, 0, -50282, 3095, 0, 0, 39, '3094'),
	(377, 1, 0, -50282, 3096, 0, 0, 39, '3095'),
	(377, 1, 0, -50282, 3097, 0, 0, 39, '3096'),
	(377, 1, 0, -50282, 3098, 0, 0, 39, '3097'),
	(377, 1, 0, -50282, 3099, 0, 0, 39, '3098'),
	(377, 1, 0, -50282, 3100, 0, 0, 39, '3099'),
	(377, 1, 0, -50282, 3101, 0, 0, 39, '3100'),
	(377, 1, 0, -50282, 3102, 0, 0, 39, '3101'),
	(377, 1, 0, -50282, 3103, 0, 0, 39, '3102'),
	(377, 1, 0, -50282, 3104, 0, 0, 39, '3103'),
	(377, 1, 0, -50282, 3105, 0, 0, 39, '3104'),
	(377, 1, 0, -50282, 3106, 0, 0, 39, '3105'),
	(377, 1, 0, -50282, 3107, 0, 0, 39, '3106'),
	(377, 1, 0, -50282, 3108, 0, 0, 39, '3107'),
	(377, 1, 0, -50282, 3109, 0, 0, 39, '3108'),
	(377, 1, 0, -50282, 3110, 0, 0, 39, '3109'),
	(377, 1, 0, -50282, 3111, 0, 0, 39, '3110'),
	(377, 1, 0, -50282, 3112, 0, 0, 39, '3111'),
	(377, 1, 0, -50282, 3113, 0, 0, 39, '3112'),
	(377, 1, 0, -50282, 3114, 0, 0, 39, '3113'),
	(377, 1, 0, -50282, 3115, 0, 0, 39, '3114'),
	(377, 1, 0, -50282, 3116, 0, 0, 39, '3115'),
	(377, 1, 0, -50282, 3117, 0, 0, 39, '3116'),
	(377, 1, 0, -50282, 3118, 0, 0, 39, '3117'),
	(377, 1, 0, -50282, 3119, 0, 0, 39, '3118'),
	(377, 1, 0, -50282, 3120, 0, 0, 39, '3119'),
	(377, 1, 0, -50282, 3121, 0, 0, 39, '3120'),
	(377, 1, 0, -50282, 3122, 0, 0, 39, '3121'),
	(377, 1, 0, -50282, 3123, 0, 0, 39, '3122'),
	(377, 1, 0, -50282, 3124, 0, 0, 39, '3123'),
	(377, 1, 0, -50282, 3125, 0, 0, 39, '3124'),
	(377, 1, 0, -50282, 3126, 0, 0, 39, '3125'),
	(377, 1, 0, -50282, 3127, 0, 0, 39, '3126'),
	(377, 1, 0, -50282, 3128, 0, 0, 39, '3127'),
	(377, 1, 0, -50282, 3129, 0, 0, 39, '3128'),
	(377, 1, 0, -50282, 3130, 0, 0, 39, '3129'),
	(377, 1, 0, -50282, 3131, 0, 0, 39, '3130'),
	(377, 1, 0, -50282, 3132, 0, 0, 39, '3131'),
	(377, 1, 0, -50282, 3133, 0, 0, 39, '3132'),
	(377, 1, 0, -50282, 3134, 0, 0, 39, '3133'),
	(377, 1, 0, -50282, 3135, 0, 0, 39, '3134'),
	(377, 1, 0, -50282, 3136, 0, 0, 39, '3135'),
	(377, 1, 0, -50282, 3137, 0, 0, 39, '3136'),
	(377, 1, 0, -50282, 3138, 0, 0, 39, '3137'),
	(377, 1, 0, -50282, 3139, 0, 0, 39, '3138'),
	(377, 1, 0, -50282, 3140, 0, 0, 39, '3139'),
	(377, 1, 0, -50282, 3141, 0, 0, 39, '3140'),
	(377, 1, 0, -50282, 3142, 0, 0, 39, '3141'),
	(377, 1, 0, -50282, 3143, 0, 0, 39, '3142'),
	(377, 1, 0, -50282, 3144, 0, 0, 39, '3143'),
	(377, 1, 0, -50282, 3145, 0, 0, 39, '3144'),
	(377, 1, 0, -50282, 3146, 0, 0, 39, '3145'),
	(377, 1, 0, -50282, 3147, 0, 0, 39, '3146'),
	(377, 1, 0, -50282, 3148, 0, 0, 39, '3147'),
	(377, 1, 0, -50282, 3149, 0, 0, 39, '3148'),
	(377, 1, 0, -50282, 3150, 0, 0, 39, '3149'),
	(377, 1, 0, -50282, 3151, 0, 0, 39, '3150'),
	(377, 1, 0, -50282, 3152, 0, 0, 39, '3151'),
	(377, 1, 0, -50282, 3153, 0, 0, 39, '3152'),
	(377, 1, 0, -50282, 3154, 0, 0, 39, '3153'),
	(377, 1, 0, -50282, 3155, 0, 0, 39, '3154'),
	(377, 1, 0, -50282, 3156, 0, 0, 39, '3155'),
	(377, 1, 0, -50282, 3157, 0, 0, 39, '3156'),
	(377, 1, 0, -50282, 3158, 0, 0, 39, '3157'),
	(377, 1, 0, -50282, 3159, 0, 0, 39, '3158'),
	(377, 1, 0, -50282, 3160, 0, 0, 39, '3159'),
	(377, 1, 0, -50282, 3161, 0, 0, 39, '3160'),
	(377, 1, 0, -50282, 3162, 0, 0, 39, '3161'),
	(377, 1, 0, -50282, 3163, 0, 0, 39, '3162'),
	(377, 1, 0, -50282, 3164, 0, 0, 39, '3163'),
	(377, 1, 0, -50282, 3165, 0, 0, 39, '3164'),
	(377, 1, 0, -50282, 3166, 0, 0, 39, '3165'),
	(377, 1, 0, -50282, 3167, 0, 0, 39, '3166'),
	(377, 1, 0, -50282, 3168, 0, 0, 39, '3167'),
	(377, 1, 0, -50282, 3169, 0, 0, 39, '3168'),
	(377, 1, 0, -50282, 3170, 0, 0, 39, '3169'),
	(377, 1, 0, -50282, 3171, 0, 0, 39, '3170'),
	(377, 1, 0, -50282, 3172, 0, 0, 39, '3171'),
	(377, 1, 0, -50282, 3173, 0, 0, 39, '3172'),
	(377, 1, 0, -50282, 3174, 0, 0, 39, '3173'),
	(377, 1, 0, -50282, 3175, 0, 0, 39, '3174'),
	(377, 1, 0, -50282, 3176, 0, 0, 39, '3175'),
	(377, 1, 0, -50282, 3177, 0, 0, 39, '3176'),
	(377, 1, 0, -50282, 3178, 0, 0, 39, '3177'),
	(377, 1, 0, -50282, 3179, 0, 0, 39, '3178'),
	(377, 1, 0, -50282, 3180, 0, 0, 39, '3179'),
	(377, 1, 0, -50282, 3181, 0, 0, 39, '3180'),
	(377, 1, 0, -50282, 3182, 0, 0, 39, '3181'),
	(377, 1, 0, -50282, 3183, 0, 0, 39, '3182'),
	(377, 1, 0, -50282, 3184, 0, 0, 39, '3183'),
	(377, 1, 0, -50282, 3185, 0, 0, 39, '3184'),
	(377, 1, 0, -50282, 3186, 0, 0, 39, '3185'),
	(377, 1, 0, -50282, 3187, 0, 0, 39, '3186'),
	(377, 1, 0, -50282, 3188, 0, 0, 39, '3187'),
	(377, 1, 0, -50282, 3189, 0, 0, 39, '3188'),
	(377, 1, 0, -50282, 3190, 0, 0, 39, '3189'),
	(377, 1, 0, -50282, 3191, 0, 0, 39, '3190'),
	(377, 1, 0, -50282, 3192, 0, 0, 39, '3191'),
	(377, 1, 0, -50282, 3193, 0, 0, 39, '3192'),
	(377, 1, 0, -50282, 3194, 0, 0, 39, '3193'),
	(377, 1, 0, -50282, 3195, 0, 0, 39, '3194'),
	(377, 1, 0, -50282, 3196, 0, 0, 39, '3195'),
	(377, 1, 0, -50282, 3197, 0, 0, 39, '3196'),
	(377, 1, 0, -50282, 3198, 0, 0, 39, '3197'),
	(377, 1, 0, -50282, 3199, 0, 0, 39, '3198'),
	(377, 1, 0, -50282, 3200, 0, 0, 39, '3199'),
	(377, 1, 0, -50282, 3201, 0, 0, 39, '3200'),
	(377, 1, 0, -50282, 3202, 0, 0, 39, '3201'),
	(377, 1, 0, -50282, 3203, 0, 0, 39, '3202'),
	(377, 1, 0, -50282, 3204, 0, 0, 39, '3203'),
	(377, 1, 0, -50282, 3205, 0, 0, 39, '3204'),
	(377, 1, 0, -50282, 3206, 0, 0, 39, '3205'),
	(377, 1, 0, -50282, 3207, 0, 0, 39, '3206'),
	(377, 1, 0, -50282, 3208, 0, 0, 39, '3207'),
	(377, 1, 0, -50282, 3209, 0, 0, 39, '3208'),
	(377, 1, 0, -50282, 3210, 0, 0, 39, '3209'),
	(377, 1, 0, -50282, 3211, 0, 0, 39, '3210'),
	(377, 1, 0, -50282, 3212, 0, 0, 39, '3211'),
	(377, 1, 0, -50282, 3213, 0, 0, 39, '3212'),
	(377, 1, 0, -50282, 3214, 0, 0, 39, '3213'),
	(377, 1, 0, -50282, 3215, 0, 0, 39, '3214'),
	(377, 1, 0, -50282, 3216, 0, 0, 39, '3215'),
	(377, 1, 0, -50282, 3217, 0, 0, 39, '3216'),
	(377, 1, 0, -50282, 3218, 0, 0, 39, '3217'),
	(377, 1, 0, -50282, 3219, 0, 0, 39, '3218'),
	(377, 1, 0, -50282, 3220, 0, 0, 39, '3219'),
	(377, 1, 0, -50282, 3221, 0, 0, 39, '3220'),
	(377, 1, 0, -50282, 3222, 0, 0, 39, '3221'),
	(377, 1, 0, -50282, 3223, 0, 0, 39, '3222'),
	(377, 1, 0, -50282, 3224, 0, 0, 39, '3223'),
	(377, 1, 0, -50282, 3225, 0, 0, 39, '3224'),
	(377, 1, 0, -50282, 3226, 0, 0, 39, '3225'),
	(377, 1, 0, -50282, 3227, 0, 0, 39, '3226'),
	(377, 1, 0, -50282, 3228, 0, 0, 39, '3227'),
	(377, 1, 0, -50282, 3229, 0, 0, 39, '3228'),
	(377, 1, 0, -50282, 3230, 0, 0, 39, '3229'),
	(377, 1, 0, -50282, 3231, 0, 0, 39, '3230'),
	(377, 1, 0, -50282, 3232, 0, 0, 39, '3231'),
	(377, 1, 0, -50282, 3233, 0, 0, 39, '3232'),
	(377, 1, 0, -50282, 3234, 0, 0, 39, '3233'),
	(377, 1, 0, -50282, 3235, 0, 0, 39, '3234'),
	(377, 1, 0, -50282, 3236, 0, 0, 39, '3235'),
	(377, 1, 0, -50282, 3237, 0, 0, 39, '3236'),
	(377, 1, 0, -50282, 3238, 0, 0, 39, '3237'),
	(377, 1, 0, -50282, 3239, 0, 0, 39, '3238'),
	(377, 1, 0, -50282, 3240, 0, 0, 39, '3239'),
	(377, 1, 0, -50282, 3241, 0, 0, 39, '3240'),
	(377, 1, 0, -50282, 3242, 0, 0, 39, '3241'),
	(377, 1, 0, -50282, 3243, 0, 0, 39, '3242'),
	(377, 1, 0, -50282, 3244, 0, 0, 39, '3243'),
	(377, 1, 0, -50282, 3245, 0, 0, 39, '3244'),
	(377, 1, 0, -50282, 3246, 0, 0, 39, '3245'),
	(377, 1, 0, -50282, 3247, 0, 0, 39, '3246'),
	(377, 1, 0, -50282, 3248, 0, 0, 39, '3247'),
	(377, 1, 0, -50282, 3249, 0, 0, 39, '3248'),
	(377, 1, 0, -50282, 3250, 0, 0, 39, '3249'),
	(377, 1, 0, -50282, 3251, 0, 0, 39, '3250'),
	(377, 1, 0, -50282, 3252, 0, 0, 39, '3251'),
	(377, 1, 0, -50282, 3253, 0, 0, 39, '3252'),
	(377, 1, 0, -50282, 3254, 0, 0, 39, '3253'),
	(377, 1, 0, -50282, 3255, 0, 0, 39, '3254'),
	(377, 1, 0, -50282, 3256, 0, 0, 39, '3255'),
	(377, 1, 0, -50282, 3257, 0, 0, 39, '3256'),
	(377, 1, 0, -50282, 3258, 0, 0, 39, '3257'),
	(377, 1, 0, -50282, 3259, 0, 0, 39, '3258'),
	(377, 1, 0, -50282, 3260, 0, 0, 39, '3259'),
	(377, 1, 0, -50282, 3261, 0, 0, 39, '3260'),
	(377, 1, 0, -50282, 3262, 0, 0, 39, '3261'),
	(377, 1, 0, -50282, 3263, 0, 0, 39, '3262'),
	(377, 1, 0, -50282, 3264, 0, 0, 39, '3263'),
	(377, 1, 0, -50282, 3265, 0, 0, 39, '3264'),
	(377, 1, 0, -50282, 3266, 0, 0, 39, '3265'),
	(377, 1, 0, -50282, 3267, 0, 0, 39, '3266'),
	(377, 1, 0, -50282, 3268, 0, 0, 39, '3267'),
	(377, 1, 0, -50282, 3269, 0, 0, 39, '3268'),
	(377, 1, 0, -50282, 3270, 0, 0, 39, '3269'),
	(377, 1, 0, -50282, 3271, 0, 0, 39, '3270'),
	(377, 1, 0, -50282, 3272, 0, 0, 39, '3271'),
	(377, 1, 0, -50282, 3273, 0, 0, 39, '3272'),
	(377, 1, 0, -50282, 3274, 0, 0, 39, '3273'),
	(377, 1, 0, -50282, 3275, 0, 0, 39, '3274'),
	(377, 1, 0, -50282, 3276, 0, 0, 39, '3275'),
	(377, 1, 0, -50282, 3277, 0, 0, 39, '3276'),
	(377, 1, 0, -50282, 3278, 0, 0, 39, '3277'),
	(377, 1, 0, -50282, 3279, 0, 0, 39, '3278'),
	(377, 1, 0, -50282, 3280, 0, 0, 39, '3279'),
	(377, 1, 0, -50282, 3281, 0, 0, 39, '3280'),
	(377, 1, 0, -50282, 3282, 0, 0, 39, '3281'),
	(377, 1, 0, -50282, 3283, 0, 0, 39, '3282'),
	(377, 1, 0, -50282, 3284, 0, 0, 39, '3283'),
	(377, 1, 0, -50282, 3285, 0, 0, 39, '3284'),
	(377, 1, 0, -50282, 3286, 0, 0, 39, '3285'),
	(377, 1, 0, -50282, 3287, 0, 0, 39, '3286'),
	(377, 1, 0, -50282, 3288, 0, 0, 39, '3287'),
	(377, 1, 0, -50282, 3289, 0, 0, 39, '3288'),
	(377, 1, 0, -50282, 3290, 0, 0, 39, '3289'),
	(377, 1, 0, -50282, 3291, 0, 0, 39, '3290'),
	(377, 1, 0, -50282, 3292, 0, 0, 39, '3291'),
	(377, 1, 0, -50282, 3293, 0, 0, 39, '3292'),
	(377, 1, 0, -50282, 3294, 0, 0, 39, '3293'),
	(377, 1, 0, -50282, 3295, 0, 0, 39, '3294'),
	(377, 1, 0, -50282, 3296, 0, 0, 39, '3295'),
	(377, 1, 0, -50282, 3297, 0, 0, 39, '3296'),
	(377, 1, 0, -50282, 3298, 0, 0, 39, '3297'),
	(377, 1, 0, -50282, 3299, 0, 0, 39, '3298'),
	(377, 1, 0, -50282, 3300, 0, 0, 39, '3299'),
	(377, 1, 0, -50282, 3301, 0, 0, 39, '3300'),
	(377, 1, 0, -50282, 3302, 0, 0, 39, '3301'),
	(377, 1, 0, -50282, 3303, 0, 0, 39, '3302'),
	(377, 1, 0, -50282, 3304, 0, 0, 39, '3303'),
	(377, 1, 0, -50282, 3305, 0, 0, 39, '3304'),
	(377, 1, 0, -50282, 3306, 0, 0, 39, '3305'),
	(377, 1, 0, -50282, 3307, 0, 0, 39, '3306'),
	(377, 1, 0, -50282, 3308, 0, 0, 39, '3307'),
	(377, 1, 0, -50282, 3309, 0, 0, 39, '3308'),
	(377, 1, 0, -50282, 3310, 0, 0, 39, '3309'),
	(377, 1, 0, -50282, 3311, 0, 0, 39, '3310'),
	(377, 1, 0, -50282, 3312, 0, 0, 39, '3311'),
	(377, 1, 0, -50282, 3313, 0, 0, 39, '3312'),
	(377, 1, 0, -50282, 3314, 0, 0, 39, '3313'),
	(377, 1, 0, -50282, 3315, 0, 0, 39, '3314'),
	(377, 1, 0, -50282, 3316, 0, 0, 39, '3315'),
	(377, 1, 0, -50282, 3317, 0, 0, 39, '3316'),
	(377, 1, 0, -50282, 3318, 0, 0, 39, '3317'),
	(377, 1, 0, -50282, 3319, 0, 0, 39, '3318'),
	(377, 1, 0, -50282, 3320, 0, 0, 39, '3319'),
	(377, 1, 0, -50282, 3321, 0, 0, 39, '3320'),
	(377, 1, 0, -50282, 3322, 0, 0, 39, '3321'),
	(377, 1, 0, -50282, 3323, 0, 0, 39, '3322'),
	(377, 1, 0, -50282, 3324, 0, 0, 39, '3323'),
	(377, 1, 0, -50282, 3325, 0, 0, 39, '3324'),
	(377, 1, 0, -50282, 3326, 0, 0, 39, '3325'),
	(377, 1, 0, -50282, 3327, 0, 0, 39, '3326'),
	(377, 1, 0, -50282, 3328, 0, 0, 39, '3327'),
	(377, 1, 0, -50282, 3329, 0, 0, 39, '3328'),
	(377, 1, 0, -50282, 3330, 0, 0, 39, '3329'),
	(377, 1, 0, -50282, 3331, 0, 0, 39, '3330'),
	(377, 1, 0, -50282, 3332, 0, 0, 39, '3331'),
	(377, 1, 0, -50282, 3333, 0, 0, 39, '3332'),
	(377, 1, 0, -50282, 3334, 0, 0, 39, '3333'),
	(377, 1, 0, -50282, 3335, 0, 0, 39, '3334'),
	(377, 1, 0, -50282, 3336, 0, 0, 39, '3335'),
	(377, 1, 0, -50282, 3337, 0, 0, 39, '3336'),
	(377, 1, 0, -50282, 3338, 0, 0, 39, '3337'),
	(377, 1, 0, -50282, 3339, 0, 0, 39, '3338'),
	(377, 1, 0, -50282, 3340, 0, 0, 39, '3339'),
	(377, 1, 0, -50282, 3341, 0, 0, 39, '3340'),
	(377, 1, 0, -50282, 3342, 0, 0, 39, '3341'),
	(377, 1, 0, -50282, 3343, 0, 0, 39, '3342'),
	(377, 1, 0, -50282, 3344, 0, 0, 39, '3343'),
	(377, 1, 0, -50282, 3345, 0, 0, 39, '3344'),
	(377, 1, 0, -50282, 3346, 0, 0, 39, '3345'),
	(377, 1, 0, -50282, 3347, 0, 0, 39, '3346'),
	(377, 1, 0, -50282, 3348, 0, 0, 39, '3347'),
	(377, 1, 0, -50282, 3349, 0, 0, 39, '3348'),
	(377, 1, 0, -50282, 3350, 0, 0, 39, '3349'),
	(377, 1, 0, -50282, 3351, 0, 0, 39, '3350'),
	(377, 1, 0, -50282, 3352, 0, 0, 39, '3351'),
	(377, 1, 0, -50282, 3353, 0, 0, 39, '3352'),
	(377, 1, 0, -50282, 3354, 0, 0, 39, '3353'),
	(377, 1, 0, -50282, 3355, 0, 0, 39, '3354'),
	(377, 1, 0, -50282, 3356, 0, 0, 39, '3355'),
	(377, 1, 0, -50282, 3357, 0, 0, 39, '3356'),
	(377, 1, 0, -50282, 3358, 0, 0, 39, '3357'),
	(377, 1, 0, -50282, 3359, 0, 0, 39, '3358'),
	(377, 1, 0, -50282, 3360, 0, 0, 39, '3359'),
	(377, 1, 0, -50282, 3361, 0, 0, 39, '3360'),
	(377, 1, 0, -50282, 3362, 0, 0, 39, '3361'),
	(377, 1, 0, -50282, 3363, 0, 0, 39, '3362'),
	(377, 1, 0, -50282, 3364, 0, 0, 39, '3363'),
	(377, 1, 0, -50282, 3365, 0, 0, 39, '3364'),
	(377, 1, 0, -50282, 3366, 0, 0, 39, '3365'),
	(377, 1, 0, -50282, 3367, 0, 0, 39, '3366'),
	(377, 1, 0, -50282, 3368, 0, 0, 39, '3367'),
	(377, 1, 0, -50282, 3369, 0, 0, 39, '3368'),
	(377, 1, 0, -50282, 3370, 0, 0, 39, '3369'),
	(377, 1, 0, -50282, 3371, 0, 0, 39, '3370'),
	(377, 1, 0, -50282, 3372, 0, 0, 39, '3371'),
	(377, 1, 0, -50282, 3373, 0, 0, 39, '3372'),
	(377, 1, 0, -50282, 3374, 0, 0, 39, '3373'),
	(377, 1, 0, -50282, 3375, 0, 0, 39, '3374'),
	(377, 1, 0, -50282, 3376, 0, 0, 39, '3375'),
	(377, 1, 0, -50282, 3377, 0, 0, 39, '3376'),
	(377, 1, 0, -50282, 3378, 0, 0, 39, '3377'),
	(377, 1, 0, -50282, 3379, 0, 0, 39, '3378'),
	(377, 1, 0, -50282, 3380, 0, 0, 39, '3379'),
	(377, 1, 0, -50282, 3381, 0, 0, 39, '3380'),
	(377, 1, 0, -50282, 3382, 0, 0, 39, '3381'),
	(377, 1, 0, -50282, 3383, 0, 0, 39, '3382'),
	(377, 1, 0, -50282, 3384, 0, 0, 39, '3383'),
	(377, 1, 0, -50282, 3385, 0, 0, 39, '3384'),
	(377, 1, 0, -50282, 3386, 0, 0, 39, '3385'),
	(377, 1, 0, -50282, 3387, 0, 0, 39, '3386'),
	(377, 1, 0, -50282, 3388, 0, 0, 39, '3387'),
	(377, 1, 0, -50282, 3389, 0, 0, 39, '3388'),
	(377, 1, 0, -50282, 3390, 0, 0, 39, '3389'),
	(377, 1, 0, -50282, 3391, 0, 0, 39, '3390'),
	(377, 1, 0, -50282, 3392, 0, 0, 39, '3391'),
	(377, 1, 0, -50282, 3393, 0, 0, 39, '3392'),
	(377, 1, 0, -50282, 3394, 0, 0, 39, '3393'),
	(377, 1, 0, -50282, 3395, 0, 0, 39, '3394'),
	(377, 1, 0, -50282, 3396, 0, 0, 39, '3395'),
	(377, 1, 0, -50282, 3397, 0, 0, 39, '3396'),
	(377, 1, 0, -50282, 3398, 0, 0, 39, '3397'),
	(377, 1, 0, -50282, 3399, 0, 0, 39, '3398'),
	(377, 1, 0, -50282, 3400, 0, 0, 39, '3399'),
	(377, 1, 0, -50282, 3401, 0, 0, 39, '3400'),
	(377, 1, 0, -50282, 3402, 0, 0, 39, '3401'),
	(377, 1, 0, -50282, 3403, 0, 0, 39, '3402'),
	(377, 1, 0, -50282, 3404, 0, 0, 39, '3403'),
	(377, 1, 0, -50282, 3405, 0, 0, 39, '3404'),
	(377, 1, 0, -50282, 3406, 0, 0, 39, '3405'),
	(377, 1, 0, -50282, 3407, 0, 0, 39, '3406'),
	(377, 1, 0, -50282, 3408, 0, 0, 39, '3407'),
	(377, 1, 0, -50282, 3409, 0, 0, 39, '3408'),
	(377, 1, 0, -50282, 3410, 0, 0, 39, '3409'),
	(377, 1, 0, -50282, 3411, 0, 0, 39, '3410'),
	(377, 1, 0, -50282, 3412, 0, 0, 39, '3411'),
	(377, 1, 0, -50282, 3413, 0, 0, 39, '3412'),
	(377, 1, 0, -50282, 3414, 0, 0, 39, '3413'),
	(377, 1, 0, -50282, 3415, 0, 0, 39, '3414'),
	(377, 1, 0, -50282, 3416, 0, 0, 39, '3415'),
	(377, 1, 0, -50282, 3417, 0, 0, 39, '3416'),
	(377, 1, 0, -50282, 3418, 0, 0, 39, '3417'),
	(377, 1, 0, -50282, 3419, 0, 0, 39, '3418'),
	(377, 1, 0, -50282, 3420, 0, 0, 39, '3419'),
	(377, 1, 0, -50282, 3421, 0, 0, 39, '3420'),
	(377, 1, 0, -50282, 3422, 0, 0, 39, '3421'),
	(377, 1, 0, -50282, 3423, 0, 0, 39, '3422'),
	(377, 1, 0, -50282, 3424, 0, 0, 39, '3423'),
	(377, 1, 0, -50282, 3425, 0, 0, 39, '3424'),
	(377, 1, 0, -50282, 3426, 0, 0, 39, '3425'),
	(377, 1, 0, -50282, 3427, 0, 0, 39, '3426'),
	(377, 1, 0, -50282, 3428, 0, 0, 39, '3427'),
	(377, 1, 0, -50282, 3429, 0, 0, 39, '3428'),
	(377, 1, 0, -50282, 3430, 0, 0, 39, '3429'),
	(377, 1, 0, -50282, 3431, 0, 0, 39, '3430'),
	(377, 1, 0, -50282, 3432, 0, 0, 39, '3431'),
	(377, 1, 0, -50282, 3433, 0, 0, 39, '3432'),
	(377, 1, 0, -50282, 3434, 0, 0, 39, '3433'),
	(377, 1, 0, -50282, 3435, 0, 0, 39, '3434'),
	(377, 1, 0, -50282, 3436, 0, 0, 39, '3435'),
	(377, 1, 0, -50282, 3437, 0, 0, 39, '3436'),
	(377, 1, 0, -50282, 3438, 0, 0, 39, '3437'),
	(377, 1, 0, -50282, 3439, 0, 0, 39, '3438'),
	(377, 1, 0, -50282, 3440, 0, 0, 39, '3439'),
	(377, 1, 0, -50282, 3441, 0, 0, 39, '3440'),
	(377, 1, 0, -50282, 3442, 0, 0, 39, '3441'),
	(377, 1, 0, -50282, 3443, 0, 0, 39, '3442'),
	(377, 1, 0, -50282, 3444, 0, 0, 39, '3443'),
	(377, 1, 0, -50282, 3445, 0, 0, 39, '3444'),
	(377, 1, 0, -50282, 3446, 0, 0, 39, '3445'),
	(377, 1, 0, -50282, 3447, 0, 0, 39, '3446'),
	(377, 1, 0, -50282, 3448, 0, 0, 39, '3447'),
	(377, 1, 0, -50282, 3449, 0, 0, 39, '3448'),
	(377, 1, 0, -50282, 3450, 0, 0, 39, '3449'),
	(377, 1, 0, -50282, 3451, 0, 0, 39, '3450'),
	(377, 1, 0, -50282, 3452, 0, 0, 39, '3451'),
	(377, 1, 0, -50282, 3453, 0, 0, 39, '3452'),
	(377, 1, 0, -50282, 3454, 0, 0, 39, '3453'),
	(377, 1, 0, -50282, 3455, 0, 0, 39, '3454'),
	(377, 1, 0, -50282, 3456, 0, 0, 39, '3455'),
	(377, 1, 0, -50282, 3457, 0, 0, 39, '3456'),
	(377, 1, 0, -50282, 3458, 0, 0, 39, '3457'),
	(377, 1, 0, -50282, 3459, 0, 0, 39, '3458'),
	(377, 1, 0, -50282, 3460, 0, 0, 39, '3459'),
	(377, 1, 0, -50282, 3461, 0, 0, 39, '3460'),
	(377, 1, 0, -50282, 3462, 0, 0, 39, '3461'),
	(377, 1, 0, -50282, 3463, 0, 0, 39, '3462'),
	(377, 1, 0, -50282, 3464, 0, 0, 39, '3463'),
	(377, 1, 0, -50282, 3465, 0, 0, 39, '3464'),
	(377, 1, 0, -50282, 3466, 0, 0, 39, '3465'),
	(377, 1, 0, -50282, 3467, 0, 0, 39, '3466'),
	(377, 1, 0, -50282, 3468, 0, 0, 39, '3467'),
	(377, 1, 0, -50282, 3469, 0, 0, 39, '3468'),
	(377, 1, 0, -50282, 3470, 0, 0, 39, '3469'),
	(377, 1, 0, -50282, 3471, 0, 0, 39, '3470'),
	(377, 1, 0, -50282, 3472, 0, 0, 39, '3471'),
	(377, 1, 0, -50282, 3473, 0, 0, 39, '3472'),
	(377, 1, 0, -50282, 3474, 0, 0, 39, '3473'),
	(377, 1, 0, -50282, 3475, 0, 0, 39, '3474'),
	(377, 1, 0, -50282, 3476, 0, 0, 39, '3475'),
	(377, 1, 0, -50282, 3477, 0, 0, 39, '3476'),
	(377, 1, 0, -50282, 3478, 0, 0, 39, '3477'),
	(377, 1, 0, -50282, 3479, 0, 0, 39, '3478'),
	(377, 1, 0, -50282, 3480, 0, 0, 39, '3479'),
	(377, 1, 0, -50282, 3481, 0, 0, 39, '3480'),
	(377, 1, 0, -50282, 3482, 0, 0, 39, '3481'),
	(377, 1, 0, -50282, 3483, 0, 0, 39, '3482'),
	(377, 1, 0, -50282, 3484, 0, 0, 39, '3483'),
	(377, 1, 0, -50282, 3485, 0, 0, 39, '3484'),
	(377, 1, 0, -50282, 3486, 0, 0, 39, '3485'),
	(377, 1, 0, -50282, 3487, 0, 0, 39, '3486'),
	(377, 1, 0, -50282, 3488, 0, 0, 39, '3487'),
	(377, 1, 0, -50282, 3489, 0, 0, 39, '3488'),
	(377, 1, 0, -50282, 3490, 0, 0, 39, '3489'),
	(377, 1, 0, -50282, 3491, 0, 0, 39, '3490'),
	(377, 1, 0, -50282, 3492, 0, 0, 39, '3491'),
	(377, 1, 0, -50282, 3493, 0, 0, 39, '3492'),
	(377, 1, 0, -50282, 3494, 0, 0, 39, '3493'),
	(377, 1, 0, -50282, 3495, 0, 0, 39, '3494'),
	(377, 1, 0, -50282, 3496, 0, 0, 39, '3495'),
	(377, 1, 0, -50282, 3497, 0, 0, 39, '3496'),
	(377, 1, 0, -50282, 3498, 0, 0, 39, '3497'),
	(377, 1, 0, -50282, 3499, 0, 0, 39, '3498'),
	(377, 1, 0, -50282, 3500, 0, 0, 39, '3499'),
	(377, 1, 0, -50282, 3501, 0, 0, 39, '3500'),
	(377, 1, 0, -50282, 3502, 0, 0, 39, '3501'),
	(377, 1, 0, -50282, 3503, 0, 0, 39, '3502'),
	(377, 1, 0, -50282, 3504, 0, 0, 39, '3503'),
	(377, 1, 0, -50282, 3505, 0, 0, 39, '3504'),
	(377, 1, 0, -50282, 3506, 0, 0, 39, '3505'),
	(377, 1, 0, -50282, 3507, 0, 0, 39, '3506'),
	(377, 1, 0, -50282, 3508, 0, 0, 39, '3507'),
	(377, 1, 0, -50282, 3509, 0, 0, 39, '3508'),
	(377, 1, 0, -50282, 3510, 0, 0, 39, '3509'),
	(377, 1, 0, -50282, 3511, 0, 0, 39, '3510'),
	(377, 1, 0, -50282, 3512, 0, 0, 39, '3511'),
	(377, 1, 0, -50282, 3513, 0, 0, 39, '3512'),
	(377, 1, 0, -50282, 3514, 0, 0, 39, '3513'),
	(377, 1, 0, -50282, 3515, 0, 0, 39, '3514'),
	(377, 1, 0, -50282, 3516, 0, 0, 39, '3515'),
	(377, 1, 0, -50282, 3517, 0, 0, 39, '3516'),
	(377, 1, 0, -50282, 3518, 0, 0, 39, '3517'),
	(377, 1, 0, -50282, 3519, 0, 0, 39, '3518'),
	(377, 1, 0, -50282, 3520, 0, 0, 39, '3519'),
	(377, 1, 0, -50282, 3521, 0, 0, 39, '3520'),
	(377, 1, 0, -50282, 3522, 0, 0, 39, '3521'),
	(377, 1, 0, -50282, 3523, 0, 0, 39, '3522'),
	(377, 1, 0, -50282, 3524, 0, 0, 39, '3523'),
	(377, 1, 0, -50282, 3525, 0, 0, 39, '3524'),
	(377, 1, 0, -50282, 3526, 0, 0, 39, '3525'),
	(377, 1, 0, -50282, 3527, 0, 0, 39, '3526'),
	(377, 1, 0, -50282, 3528, 0, 0, 39, '3527'),
	(377, 1, 0, -50282, 3529, 0, 0, 39, '3528'),
	(377, 1, 0, -50282, 3530, 0, 0, 39, '3529'),
	(377, 1, 0, -50282, 3531, 0, 0, 39, '3530'),
	(377, 1, 0, -50282, 3532, 0, 0, 39, '3531'),
	(377, 1, 0, -50282, 3533, 0, 0, 39, '3532'),
	(377, 1, 0, -50282, 3534, 0, 0, 39, '3533'),
	(377, 1, 0, -50282, 3535, 0, 0, 39, '3534'),
	(377, 1, 0, -50282, 3536, 0, 0, 39, '3535'),
	(377, 1, 0, -50282, 3537, 0, 0, 39, '3536'),
	(377, 1, 0, -50282, 3538, 0, 0, 39, '3537'),
	(377, 1, 0, -50282, 3539, 0, 0, 39, '3538'),
	(377, 1, 0, -50282, 3540, 0, 0, 39, '3539'),
	(377, 1, 0, -50282, 3541, 0, 0, 39, '3540'),
	(377, 1, 0, -50282, 3542, 0, 0, 39, '3541'),
	(377, 1, 0, -50282, 3543, 0, 0, 39, '3542'),
	(377, 1, 0, -50282, 3544, 0, 0, 39, '3543'),
	(377, 1, 0, -50282, 3545, 0, 0, 39, '3544'),
	(377, 1, 0, -50282, 3546, 0, 0, 39, '3545'),
	(377, 1, 0, -50282, 3547, 0, 0, 39, '3546'),
	(377, 1, 0, -50282, 3548, 0, 0, 39, '3547'),
	(377, 1, 0, -50282, 3549, 0, 0, 39, '3548'),
	(377, 1, 0, -50282, 3550, 0, 0, 39, '3549'),
	(377, 1, 0, -50282, 3551, 0, 0, 39, '3550'),
	(377, 1, 0, -50282, 3552, 0, 0, 39, '3551'),
	(377, 1, 0, -50282, 3553, 0, 0, 39, '3552'),
	(377, 1, 0, -50282, 3554, 0, 0, 39, '3553'),
	(377, 1, 0, -50282, 3555, 0, 0, 39, '3554'),
	(377, 1, 0, -50282, 3556, 0, 0, 39, '3555'),
	(377, 1, 0, -50282, 3557, 0, 0, 39, '3556'),
	(377, 1, 0, -50282, 3558, 0, 0, 39, '3557'),
	(377, 1, 0, -50282, 3559, 0, 0, 39, '3558'),
	(377, 1, 0, -50282, 3560, 0, 0, 39, '3559'),
	(377, 1, 0, -50282, 3561, 0, 0, 39, '3560'),
	(377, 1, 0, -50282, 3562, 0, 0, 39, '3561'),
	(377, 1, 0, -50282, 3563, 0, 0, 39, '3562'),
	(377, 1, 0, -50282, 3564, 0, 0, 39, '3563'),
	(377, 1, 0, -50282, 3565, 0, 0, 39, '3564'),
	(377, 1, 0, -50282, 3566, 0, 0, 39, '3565'),
	(377, 1, 0, -50282, 3567, 0, 0, 39, '3566'),
	(377, 1, 0, -50282, 3568, 0, 0, 39, '3567'),
	(377, 1, 0, -50282, 3569, 0, 0, 39, '3568'),
	(377, 1, 0, -50282, 3570, 0, 0, 39, '3569'),
	(377, 1, 0, -50282, 3571, 0, 0, 39, '3570'),
	(377, 1, 0, -50282, 3572, 0, 0, 39, '3571'),
	(377, 1, 0, -50282, 3573, 0, 0, 39, '3572'),
	(377, 1, 0, -50282, 3574, 0, 0, 39, '3573'),
	(377, 1, 0, -50282, 3575, 0, 0, 39, '3574'),
	(377, 1, 0, -50282, 3576, 0, 0, 39, '3575'),
	(377, 1, 0, -50282, 3577, 0, 0, 39, '3576'),
	(377, 1, 0, -50282, 3578, 0, 0, 39, '3577'),
	(377, 1, 0, -50282, 3579, 0, 0, 39, '3578'),
	(377, 1, 0, -50282, 3580, 0, 0, 39, '3579'),
	(377, 1, 0, -50282, 3581, 0, 0, 39, '3580'),
	(377, 1, 0, -50282, 3582, 0, 0, 39, '3581'),
	(377, 1, 0, -50282, 3583, 0, 0, 39, '3582'),
	(377, 1, 0, -50282, 3584, 0, 0, 39, '3583'),
	(377, 1, 0, -50282, 3585, 0, 0, 39, '3584'),
	(377, 1, 0, -50282, 3586, 0, 0, 39, '3585'),
	(377, 1, 0, -50282, 3587, 0, 0, 39, '3586'),
	(377, 1, 0, -50282, 3588, 0, 0, 39, '3587'),
	(377, 1, 0, -50282, 3589, 0, 0, 39, '3588'),
	(377, 1, 0, -50282, 3590, 0, 0, 39, '3589'),
	(377, 1, 0, -50282, 3591, 0, 0, 39, '3590'),
	(377, 1, 0, -50282, 3592, 0, 0, 39, '3591'),
	(377, 1, 0, -50282, 3593, 0, 0, 39, '3592'),
	(377, 1, 0, -50282, 3594, 0, 0, 39, '3593'),
	(377, 1, 0, -50282, 3595, 0, 0, 39, '3594'),
	(377, 1, 0, -50282, 3596, 0, 0, 39, '3595'),
	(377, 1, 0, -50282, 3597, 0, 0, 39, '3596'),
	(377, 1, 0, -50282, 3598, 0, 0, 39, '3597'),
	(377, 1, 0, -50282, 3599, 0, 0, 39, '3598'),
	(377, 1, 0, -50282, 3600, 0, 0, 39, '3599'),
	(377, 1, 0, -50282, 3601, 0, 0, 39, '3600'),
	(377, 1, 0, -50282, 3602, 0, 0, 39, '3601'),
	(377, 1, 0, -50282, 3603, 0, 0, 39, '3602'),
	(377, 1, 0, -50282, 3604, 0, 0, 39, '3603'),
	(377, 1, 0, -50282, 3605, 0, 0, 39, '3604'),
	(377, 1, 0, -50282, 3606, 0, 0, 39, '3605'),
	(377, 1, 0, -50282, 3607, 0, 0, 39, '3606'),
	(377, 1, 0, -50282, 3608, 0, 0, 39, '3607'),
	(377, 1, 0, -50282, 3609, 0, 0, 39, '3608'),
	(377, 1, 0, -50282, 3610, 0, 0, 39, '3609'),
	(377, 1, 0, -50282, 3611, 0, 0, 39, '3610'),
	(377, 1, 0, -50282, 3612, 0, 0, 39, '3611'),
	(377, 1, 0, -50282, 3613, 0, 0, 39, '3612'),
	(377, 1, 0, -50282, 3614, 0, 0, 39, '3613'),
	(377, 1, 0, -50282, 3615, 0, 0, 39, '3614'),
	(377, 1, 0, -50282, 3616, 0, 0, 39, '3615'),
	(377, 1, 0, -50282, 3617, 0, 0, 39, '3616'),
	(377, 1, 0, -50282, 3618, 0, 0, 39, '3617'),
	(377, 1, 0, -50282, 3619, 0, 0, 39, '3618'),
	(377, 1, 0, -50282, 3620, 0, 0, 39, '3619'),
	(377, 1, 0, -50282, 3621, 0, 0, 39, '3620'),
	(377, 1, 0, -50282, 3622, 0, 0, 39, '3621'),
	(377, 1, 0, -50282, 3623, 0, 0, 39, '3622'),
	(377, 1, 0, -50282, 3624, 0, 0, 39, '3623'),
	(377, 1, 0, -50282, 3625, 0, 0, 39, '3624'),
	(377, 1, 0, -50282, 3626, 0, 0, 39, '3625'),
	(377, 1, 0, -50282, 3627, 0, 0, 39, '3626'),
	(377, 1, 0, -50282, 3628, 0, 0, 39, '3627'),
	(377, 1, 0, -50282, 3629, 0, 0, 39, '3628'),
	(377, 1, 0, -50282, 3630, 0, 0, 39, '3629'),
	(377, 1, 0, -50282, 3631, 0, 0, 39, '3630'),
	(377, 1, 0, -50282, 3632, 0, 0, 39, '3631'),
	(377, 1, 0, -50282, 3633, 0, 0, 39, '3632'),
	(377, 1, 0, -50282, 3634, 0, 0, 39, '3633'),
	(377, 1, 0, -50282, 3635, 0, 0, 39, '3634'),
	(377, 1, 0, -50282, 3636, 0, 0, 39, '3635'),
	(377, 1, 0, -50282, 3637, 0, 0, 39, '3636'),
	(377, 1, 0, -50282, 3638, 0, 0, 39, '3637'),
	(377, 1, 0, -50282, 3639, 0, 0, 39, '3638'),
	(377, 1, 0, -50282, 3640, 0, 0, 39, '3639'),
	(377, 1, 0, -50282, 3641, 0, 0, 39, '3640'),
	(377, 1, 0, -50282, 3642, 0, 0, 39, '3641'),
	(377, 1, 0, -50282, 3643, 0, 0, 39, '3642'),
	(377, 1, 0, -50282, 3644, 0, 0, 39, '3643'),
	(377, 1, 0, -50282, 3645, 0, 0, 39, '3644'),
	(377, 1, 0, -50282, 3646, 0, 0, 39, '3645'),
	(377, 1, 0, -50282, 3647, 0, 0, 39, '3646'),
	(377, 1, 0, -50282, 3648, 0, 0, 39, '3647'),
	(377, 1, 0, -50282, 3649, 0, 0, 39, '3648'),
	(377, 1, 0, -50282, 3650, 0, 0, 39, '3649'),
	(377, 1, 0, -50282, 3651, 0, 0, 39, '3650'),
	(377, 1, 0, -50282, 3652, 0, 0, 39, '3651'),
	(377, 1, 0, -50282, 3653, 0, 0, 39, '3652'),
	(377, 1, 0, -50282, 3654, 0, 0, 39, '3653'),
	(377, 1, 0, -50282, 3655, 0, 0, 39, '3654'),
	(377, 1, 0, -50282, 3656, 0, 0, 39, '3655'),
	(377, 1, 0, -50282, 3657, 0, 0, 39, '3656'),
	(377, 1, 0, -50282, 3658, 0, 0, 39, '3657'),
	(377, 1, 0, -50282, 3659, 0, 0, 39, '3658'),
	(377, 1, 0, -50282, 3660, 0, 0, 39, '3659'),
	(377, 1, 0, -50282, 3661, 0, 0, 39, '3660'),
	(377, 1, 0, -50282, 3662, 0, 0, 39, '3661'),
	(377, 1, 0, -50282, 3663, 0, 0, 39, '3662'),
	(377, 1, 0, -50282, 3664, 0, 0, 39, '3663'),
	(377, 1, 0, -50282, 3665, 0, 0, 39, '3664'),
	(377, 1, 0, -50282, 3666, 0, 0, 39, '3665'),
	(377, 1, 0, -50282, 3667, 0, 0, 39, '3666'),
	(377, 1, 0, -50282, 3668, 0, 0, 39, '3667'),
	(377, 1, 0, -50282, 3669, 0, 0, 39, '3668'),
	(377, 1, 0, -50282, 3670, 0, 0, 39, '3669'),
	(377, 1, 0, -50282, 3671, 0, 0, 39, '3670'),
	(377, 1, 0, -50282, 3672, 0, 0, 39, '3671'),
	(377, 1, 0, -50282, 3673, 0, 0, 39, '3672'),
	(377, 1, 0, -50282, 3674, 0, 0, 39, '3673'),
	(377, 1, 0, -50282, 3675, 0, 0, 39, '3674'),
	(377, 1, 0, -50282, 3676, 0, 0, 39, '3675'),
	(377, 1, 0, -50282, 3677, 0, 0, 39, '3676'),
	(377, 1, 0, -50282, 3678, 0, 0, 39, '3677'),
	(377, 1, 0, -50282, 3679, 0, 0, 39, '3678'),
	(377, 1, 0, -50282, 3680, 0, 0, 39, '3679'),
	(377, 1, 0, -50282, 3681, 0, 0, 39, '3680'),
	(377, 1, 0, -50282, 3682, 0, 0, 39, '3681'),
	(377, 1, 0, -50282, 3683, 0, 0, 39, '3682'),
	(377, 1, 0, -50282, 3684, 0, 0, 39, '3683'),
	(377, 1, 0, -50282, 3685, 0, 0, 39, '3684'),
	(377, 1, 0, -50282, 3686, 0, 0, 39, '3685'),
	(377, 1, 0, -50282, 3687, 0, 0, 39, '3686'),
	(377, 1, 0, -50282, 3688, 0, 0, 39, '3687'),
	(377, 1, 0, -50282, 3689, 0, 0, 39, '3688'),
	(377, 1, 0, -50282, 3690, 0, 0, 39, '3689'),
	(377, 1, 0, -50282, 3691, 0, 0, 39, '3690'),
	(377, 1, 0, -50282, 3692, 0, 0, 39, '3691'),
	(377, 1, 0, -50282, 3693, 0, 0, 39, '3692'),
	(377, 1, 0, -50282, 3694, 0, 0, 39, '3693'),
	(377, 1, 0, -50282, 3695, 0, 0, 39, '3694'),
	(377, 1, 0, -50282, 3696, 0, 0, 39, '3695'),
	(377, 1, 0, -50282, 3697, 0, 0, 39, '3696'),
	(377, 1, 0, -50282, 3698, 0, 0, 39, '3697'),
	(377, 1, 0, -50282, 3699, 0, 0, 39, '3698'),
	(377, 1, 0, -50282, 3700, 0, 0, 39, '3699'),
	(377, 1, 0, -50282, 3701, 0, 0, 39, '3700'),
	(377, 1, 0, -50282, 3702, 0, 0, 39, '3701'),
	(377, 1, 0, -50282, 3703, 0, 0, 39, '3702'),
	(377, 1, 0, -50282, 3704, 0, 0, 39, '3703'),
	(377, 1, 0, -50282, 3705, 0, 0, 39, '3704'),
	(377, 1, 0, -50282, 3706, 0, 0, 39, '3705'),
	(377, 1, 0, -50282, 3707, 0, 0, 39, '3706'),
	(377, 1, 0, -50282, 3708, 0, 0, 39, '3707'),
	(377, 1, 0, -50282, 3709, 0, 0, 39, '3708'),
	(377, 1, 0, -50282, 3710, 0, 0, 39, '3709'),
	(377, 1, 0, -50282, 3711, 0, 0, 39, '3710'),
	(377, 1, 0, -50282, 3712, 0, 0, 39, '3711'),
	(377, 1, 0, -50282, 3713, 0, 0, 39, '3712'),
	(377, 1, 0, -50282, 3714, 0, 0, 39, '3713'),
	(377, 1, 0, -50282, 3715, 0, 0, 39, '3714'),
	(377, 1, 0, -50282, 3716, 0, 0, 39, '3715'),
	(377, 1, 0, -50282, 3717, 0, 0, 39, '3716'),
	(377, 1, 0, -50282, 3718, 0, 0, 39, '3717'),
	(377, 1, 0, -50282, 3719, 0, 0, 39, '3718'),
	(377, 1, 0, -50282, 3720, 0, 0, 39, '3719'),
	(377, 1, 0, -50282, 3721, 0, 0, 39, '3720'),
	(377, 1, 0, -50282, 3722, 0, 0, 39, '3721'),
	(377, 1, 0, -50282, 3723, 0, 0, 39, '3722'),
	(377, 1, 0, -50282, 3724, 0, 0, 39, '3723'),
	(377, 1, 0, -50282, 3725, 0, 0, 39, '3724'),
	(377, 1, 0, -50282, 3726, 0, 0, 39, '3725'),
	(377, 1, 0, -50282, 3727, 0, 0, 39, '3726'),
	(377, 1, 0, -50282, 3728, 0, 0, 39, '3727'),
	(377, 1, 0, -50282, 3729, 0, 0, 39, '3728'),
	(377, 1, 0, -50282, 3730, 0, 0, 39, '3729'),
	(377, 1, 0, -50282, 3731, 0, 0, 39, '3730'),
	(377, 1, 0, -50282, 3732, 0, 0, 39, '3731'),
	(377, 1, 0, -50282, 3733, 0, 0, 39, '3732'),
	(377, 1, 0, -50282, 3734, 0, 0, 39, '3733'),
	(377, 1, 0, -50282, 3735, 0, 0, 39, '3734'),
	(377, 1, 0, -50282, 3736, 0, 0, 39, '3735'),
	(377, 1, 0, -50282, 3737, 0, 0, 39, '3736'),
	(377, 1, 0, -50282, 3738, 0, 0, 39, '3737'),
	(377, 1, 0, -50282, 3739, 0, 0, 39, '3738'),
	(377, 1, 0, -50282, 3740, 0, 0, 39, '3739'),
	(377, 1, 0, -50282, 3741, 0, 0, 39, '3740'),
	(377, 1, 0, -50282, 3742, 0, 0, 39, '3741'),
	(377, 1, 0, -50282, 3743, 0, 0, 39, '3742'),
	(377, 1, 0, -50282, 3744, 0, 0, 39, '3743'),
	(377, 1, 0, -50282, 3745, 0, 0, 39, '3744'),
	(377, 1, 0, -50282, 3746, 0, 0, 39, '3745'),
	(377, 1, 0, -50282, 3747, 0, 0, 39, '3746'),
	(377, 1, 0, -50282, 3748, 0, 0, 39, '3747'),
	(377, 1, 0, -50282, 3749, 0, 0, 39, '3748'),
	(377, 1, 0, -50282, 3750, 0, 0, 39, '3749'),
	(377, 1, 0, -50282, 3751, 0, 0, 39, '3750'),
	(377, 1, 0, -50282, 3752, 0, 0, 39, '3751'),
	(377, 1, 0, -50282, 3753, 0, 0, 39, '3752'),
	(377, 1, 0, -50282, 3754, 0, 0, 39, '3753'),
	(377, 1, 0, -50282, 3755, 0, 0, 39, '3754'),
	(377, 1, 0, -50282, 3756, 0, 0, 39, '3755'),
	(377, 1, 0, -50282, 3757, 0, 0, 39, '3756'),
	(377, 1, 0, -50282, 3758, 0, 0, 39, '3757'),
	(377, 1, 0, -50282, 3759, 0, 0, 39, '3758'),
	(377, 1, 0, -50282, 3760, 0, 0, 39, '3759'),
	(377, 1, 0, -50282, 3761, 0, 0, 39, '3760'),
	(377, 1, 0, -50282, 3762, 0, 0, 39, '3761'),
	(377, 1, 0, -50282, 3763, 0, 0, 39, '3762'),
	(377, 1, 0, -50282, 3764, 0, 0, 39, '3763'),
	(377, 1, 0, -50282, 3765, 0, 0, 39, '3764'),
	(377, 1, 0, -50282, 3766, 0, 0, 39, '3765'),
	(377, 1, 0, -50282, 3767, 0, 0, 39, '3766'),
	(377, 1, 0, -50282, 3768, 0, 0, 39, '3767'),
	(377, 1, 0, -50282, 3769, 0, 0, 39, '3768'),
	(377, 1, 0, -50282, 3770, 0, 0, 39, '3769'),
	(377, 1, 0, -50282, 3771, 0, 0, 39, '3770'),
	(377, 1, 0, -50282, 3772, 0, 0, 39, '3771'),
	(377, 1, 0, -50282, 3773, 0, 0, 39, '3772'),
	(377, 1, 0, -50282, 3774, 0, 0, 39, '3773'),
	(377, 1, 0, -50282, 3775, 0, 0, 39, '3774'),
	(377, 1, 0, -50282, 3776, 0, 0, 39, '3775'),
	(377, 1, 0, -50282, 3777, 0, 0, 39, '3776'),
	(377, 1, 0, -50282, 3778, 0, 0, 39, '3777'),
	(377, 1, 0, -50282, 3779, 0, 0, 39, '3778'),
	(377, 1, 0, -50282, 3780, 0, 0, 39, '3779'),
	(377, 1, 0, -50282, 3781, 0, 0, 39, '3780'),
	(377, 1, 0, -50282, 3782, 0, 0, 39, '3781'),
	(377, 1, 0, -50282, 3783, 0, 0, 39, '3782'),
	(377, 1, 0, -50282, 3784, 0, 0, 39, '3783'),
	(377, 1, 0, -50282, 3785, 0, 0, 39, '3784'),
	(377, 1, 0, -50282, 3786, 0, 0, 39, '3785'),
	(377, 1, 0, -50282, 3787, 0, 0, 39, '3786'),
	(377, 1, 0, -50282, 3788, 0, 0, 39, '3787'),
	(377, 1, 0, -50282, 3789, 0, 0, 39, '3788'),
	(377, 1, 0, -50282, 3790, 0, 0, 39, '3789'),
	(377, 1, 0, -50282, 3791, 0, 0, 39, '3790'),
	(377, 1, 0, -50282, 3792, 0, 0, 39, '3791'),
	(377, 1, 0, -50282, 3793, 0, 0, 39, '3792'),
	(377, 1, 0, -50282, 3794, 0, 0, 39, '3793'),
	(377, 1, 0, -50282, 3795, 0, 0, 39, '3794'),
	(377, 1, 0, -50282, 3796, 0, 0, 39, '3795'),
	(377, 1, 0, -50282, 3797, 0, 0, 39, '3796'),
	(377, 1, 0, -50282, 3798, 0, 0, 39, '3797'),
	(377, 1, 0, -50282, 3799, 0, 0, 39, '3798'),
	(377, 1, 0, -50282, 3800, 0, 0, 39, '3799'),
	(377, 1, 0, -50282, 3801, 0, 0, 39, '3800'),
	(377, 1, 0, -50282, 3802, 0, 0, 39, '3801'),
	(377, 1, 0, -50282, 3803, 0, 0, 39, '3802'),
	(377, 1, 0, -50282, 3804, 0, 0, 39, '3803'),
	(377, 1, 0, -50282, 3805, 0, 0, 39, '3804'),
	(377, 1, 0, -50282, 3806, 0, 0, 39, '3805'),
	(377, 1, 0, -50282, 3807, 0, 0, 39, '3806'),
	(377, 1, 0, -50282, 3808, 0, 0, 39, '3807'),
	(377, 1, 0, -50282, 3809, 0, 0, 39, '3808'),
	(377, 1, 0, -50282, 3810, 0, 0, 39, '3809'),
	(377, 1, 0, -50282, 3811, 0, 0, 39, '3810'),
	(377, 1, 0, -50282, 3812, 0, 0, 39, '3811'),
	(377, 1, 0, -50282, 3813, 0, 0, 39, '3812'),
	(377, 1, 0, -50282, 3814, 0, 0, 39, '3813'),
	(377, 1, 0, -50282, 3815, 0, 0, 39, '3814'),
	(377, 1, 0, -50282, 3816, 0, 0, 39, '3815'),
	(377, 1, 0, -50282, 3817, 0, 0, 39, '3816'),
	(377, 1, 0, -50282, 3818, 0, 0, 39, '3817'),
	(377, 1, 0, -50282, 3819, 0, 0, 39, '3818'),
	(377, 1, 0, -50282, 3820, 0, 0, 39, '3819'),
	(377, 1, 0, -50282, 3821, 0, 0, 39, '3820'),
	(377, 1, 0, -50282, 3822, 0, 0, 39, '3821'),
	(377, 1, 0, -50282, 3823, 0, 0, 39, '3822'),
	(377, 1, 0, -50282, 3824, 0, 0, 39, '3823'),
	(377, 1, 0, -50282, 3825, 0, 0, 39, '3824'),
	(377, 1, 0, -50282, 3826, 0, 0, 39, '3825'),
	(377, 1, 0, -50282, 3827, 0, 0, 39, '3826'),
	(377, 1, 0, -50282, 3828, 0, 0, 39, '3827'),
	(377, 1, 0, -50282, 3829, 0, 0, 39, '3828'),
	(377, 1, 0, -50282, 3830, 0, 0, 39, '3829'),
	(377, 1, 0, -50282, 3831, 0, 0, 39, '3830'),
	(377, 1, 0, -50282, 3832, 0, 0, 39, '3831'),
	(377, 1, 0, -50282, 3833, 0, 0, 39, '3832'),
	(377, 1, 0, -50282, 3834, 0, 0, 39, '3833'),
	(377, 1, 0, -50282, 3835, 0, 0, 39, '3834'),
	(377, 1, 0, -50282, 3836, 0, 0, 39, '3835'),
	(377, 1, 0, -50282, 3837, 0, 0, 39, '3836'),
	(377, 1, 0, -50282, 3838, 0, 0, 39, '3837'),
	(377, 1, 0, -50282, 3839, 0, 0, 39, '3838'),
	(377, 1, 0, -50282, 3840, 0, 0, 39, '3839'),
	(377, 1, 0, -50282, 3841, 0, 0, 39, '3840'),
	(377, 1, 0, -50282, 3842, 0, 0, 39, '3841'),
	(377, 1, 0, -50282, 3843, 0, 0, 39, '3842'),
	(377, 1, 0, -50282, 3844, 0, 0, 39, '3843'),
	(377, 1, 0, -50282, 3845, 0, 0, 39, '3844'),
	(377, 1, 0, -50282, 3846, 0, 0, 39, '3845'),
	(377, 1, 0, -50282, 3847, 0, 0, 39, '3846'),
	(377, 1, 0, -50282, 3848, 0, 0, 39, '3847'),
	(377, 1, 0, -50282, 3849, 0, 0, 39, '3848'),
	(377, 1, 0, -50282, 3850, 0, 0, 39, '3849'),
	(377, 1, 0, -50282, 3851, 0, 0, 39, '3850'),
	(377, 1, 0, -50282, 3852, 0, 0, 39, '3851'),
	(377, 1, 0, -50282, 3853, 0, 0, 39, '3852'),
	(377, 1, 0, -50282, 3854, 0, 0, 39, '3853'),
	(377, 1, 0, -50282, 3855, 0, 0, 39, '3854'),
	(377, 1, 0, -50282, 3856, 0, 0, 39, '3855'),
	(377, 1, 0, -50282, 3857, 0, 0, 39, '3856'),
	(377, 1, 0, -50282, 3858, 0, 0, 39, '3857'),
	(377, 1, 0, -50282, 3859, 0, 0, 39, '3858'),
	(377, 1, 0, -50282, 3860, 0, 0, 39, '3859'),
	(377, 1, 0, -50282, 3861, 0, 0, 39, '3860'),
	(377, 1, 0, -50282, 3862, 0, 0, 39, '3861'),
	(377, 1, 0, -50282, 3863, 0, 0, 39, '3862'),
	(377, 1, 0, -50282, 3864, 0, 0, 39, '3863'),
	(377, 1, 0, -50282, 3865, 0, 0, 39, '3864'),
	(377, 1, 0, -50282, 3866, 0, 0, 39, '3865'),
	(377, 1, 0, -50282, 3867, 0, 0, 39, '3866'),
	(377, 1, 0, -50282, 3868, 0, 0, 39, '3867'),
	(377, 1, 0, -50282, 3869, 0, 0, 39, '3868'),
	(377, 1, 0, -50282, 3870, 0, 0, 39, '3869'),
	(377, 1, 0, -50282, 3871, 0, 0, 39, '3870'),
	(377, 1, 0, -50282, 3872, 0, 0, 39, '3871'),
	(377, 1, 0, -50282, 3873, 0, 0, 39, '3872'),
	(377, 1, 0, -50282, 3874, 0, 0, 39, '3873'),
	(377, 1, 0, -50282, 3875, 0, 0, 39, '3874'),
	(377, 1, 0, -50282, 3876, 0, 0, 39, '3875'),
	(377, 1, 0, -50282, 3877, 0, 0, 39, '3876'),
	(377, 1, 0, -50282, 3878, 0, 0, 39, '3877'),
	(377, 1, 0, -50282, 3879, 0, 0, 39, '3878'),
	(377, 1, 0, -50282, 3880, 0, 0, 39, '3879'),
	(377, 1, 0, -50282, 3881, 0, 0, 39, '3880'),
	(377, 1, 0, -50282, 3882, 0, 0, 39, '3881'),
	(377, 1, 0, -50282, 3883, 0, 0, 39, '3882'),
	(377, 1, 0, -50282, 3884, 0, 0, 39, '3883'),
	(377, 1, 0, -50282, 3885, 0, 0, 39, '3884'),
	(377, 1, 0, -50282, 3886, 0, 0, 39, '3885'),
	(377, 1, 0, -50282, 3887, 0, 0, 39, '3886'),
	(377, 1, 0, -50282, 3888, 0, 0, 39, '3887'),
	(377, 1, 0, -50282, 3889, 0, 0, 39, '3888'),
	(377, 1, 0, -50282, 3890, 0, 0, 39, '3889'),
	(377, 1, 0, -50282, 3891, 0, 0, 39, '3890'),
	(377, 1, 0, -50282, 3892, 0, 0, 39, '3891'),
	(377, 1, 0, -50282, 3893, 0, 0, 39, '3892'),
	(377, 1, 0, -50282, 3894, 0, 0, 39, '3893'),
	(377, 1, 0, -50282, 3895, 0, 0, 39, '3894'),
	(377, 1, 0, -50282, 3896, 0, 0, 39, '3895'),
	(377, 1, 0, -50282, 3897, 0, 0, 39, '3896'),
	(377, 1, 0, -50282, 3898, 0, 0, 39, '3897'),
	(377, 1, 0, -50282, 3899, 0, 0, 39, '3898'),
	(377, 1, 0, -50282, 3900, 0, 0, 39, '3899'),
	(377, 1, 0, -50282, 3901, 0, 0, 39, '3900'),
	(377, 1, 0, -50282, 3902, 0, 0, 39, '3901'),
	(377, 1, 0, -50282, 3903, 0, 0, 39, '3902'),
	(377, 1, 0, -50282, 3904, 0, 0, 39, '3903'),
	(377, 1, 0, -50282, 3905, 0, 0, 39, '3904'),
	(377, 1, 0, -50282, 3906, 0, 0, 39, '3905'),
	(377, 1, 0, -50282, 3907, 0, 0, 39, '3906'),
	(377, 1, 0, -50282, 3908, 0, 0, 39, '3907'),
	(377, 1, 0, -50282, 3909, 0, 0, 39, '3908'),
	(377, 1, 0, -50282, 3910, 0, 0, 39, '3909'),
	(377, 1, 0, -50282, 3911, 0, 0, 39, '3910'),
	(377, 1, 0, -50282, 3912, 0, 0, 39, '3911'),
	(377, 1, 0, -50282, 3913, 0, 0, 39, '3912'),
	(377, 1, 0, -50282, 3914, 0, 0, 39, '3913'),
	(377, 1, 0, -50282, 3915, 0, 0, 39, '3914'),
	(377, 1, 0, -50282, 3916, 0, 0, 39, '3915'),
	(377, 1, 0, -50282, 3917, 0, 0, 39, '3916'),
	(377, 1, 0, -50282, 3918, 0, 0, 39, '3917'),
	(377, 1, 0, -50282, 3919, 0, 0, 39, '3918'),
	(377, 1, 0, -50282, 3920, 0, 0, 39, '3919'),
	(377, 1, 0, -50282, 3921, 0, 0, 39, '3920'),
	(377, 1, 0, -50282, 3922, 0, 0, 39, '3921'),
	(377, 1, 0, -50282, 3923, 0, 0, 39, '3922'),
	(377, 1, 0, -50282, 3924, 0, 0, 39, '3923'),
	(377, 1, 0, -50282, 3925, 0, 0, 39, '3924'),
	(377, 1, 0, -50282, 3926, 0, 0, 39, '3925'),
	(377, 1, 0, -50282, 3927, 0, 0, 39, '3926'),
	(377, 1, 0, -50282, 3928, 0, 0, 39, '3927'),
	(377, 1, 0, -50282, 3929, 0, 0, 39, '3928'),
	(377, 1, 0, -50282, 3930, 0, 0, 39, '3929'),
	(377, 1, 0, -50282, 3931, 0, 0, 39, '3930'),
	(377, 1, 0, -50282, 3932, 0, 0, 39, '3931'),
	(377, 1, 0, -50282, 3933, 0, 0, 39, '3932'),
	(377, 1, 0, -50282, 3934, 0, 0, 39, '3933'),
	(377, 1, 0, -50282, 3935, 0, 0, 39, '3934'),
	(377, 1, 0, -50282, 3936, 0, 0, 39, '3935'),
	(377, 1, 0, -50282, 3937, 0, 0, 39, '3936'),
	(377, 1, 0, -50282, 3938, 0, 0, 39, '3937'),
	(377, 1, 0, -50282, 3939, 0, 0, 39, '3938'),
	(377, 1, 0, -50282, 3940, 0, 0, 39, '3939'),
	(377, 1, 0, -50282, 3941, 0, 0, 39, '3940'),
	(377, 1, 0, -50282, 3942, 0, 0, 39, '3941'),
	(377, 1, 0, -50282, 3943, 0, 0, 39, '3942'),
	(377, 1, 0, -50282, 3944, 0, 0, 39, '3943'),
	(377, 1, 0, -50282, 3945, 0, 0, 39, '3944'),
	(377, 1, 0, -50282, 3946, 0, 0, 39, '3945'),
	(377, 1, 0, -50282, 3947, 0, 0, 39, '3946'),
	(377, 1, 0, -50282, 3948, 0, 0, 39, '3947'),
	(377, 1, 0, -50282, 3949, 0, 0, 39, '3948'),
	(377, 1, 0, -50282, 3950, 0, 0, 39, '3949'),
	(377, 1, 0, -50282, 3951, 0, 0, 39, '3950'),
	(377, 1, 0, -50282, 3952, 0, 0, 39, '3951'),
	(377, 1, 0, -50282, 3953, 0, 0, 39, '3952'),
	(377, 1, 0, -50282, 3954, 0, 0, 39, '3953'),
	(377, 1, 0, -50282, 3955, 0, 0, 39, '3954'),
	(377, 1, 0, -50282, 3956, 0, 0, 39, '3955'),
	(377, 1, 0, -50282, 3957, 0, 0, 39, '3956'),
	(377, 1, 0, -50282, 3958, 0, 0, 39, '3957'),
	(377, 1, 0, -50282, 3959, 0, 0, 39, '3958'),
	(377, 1, 0, -50282, 3960, 0, 0, 39, '3959'),
	(377, 1, 0, -50282, 3961, 0, 0, 39, '3960'),
	(377, 1, 0, -50282, 3962, 0, 0, 39, '3961'),
	(377, 1, 0, -50282, 3963, 0, 0, 39, '3962'),
	(377, 1, 0, -50282, 3964, 0, 0, 39, '3963'),
	(377, 1, 0, -50282, 3965, 0, 0, 39, '3964'),
	(377, 1, 0, -50282, 3966, 0, 0, 39, '3965'),
	(377, 1, 0, -50282, 3967, 0, 0, 39, '3966'),
	(377, 1, 0, -50282, 3968, 0, 0, 39, '3967'),
	(377, 1, 0, -50282, 3969, 0, 0, 39, '3968'),
	(377, 1, 0, -50282, 3970, 0, 0, 39, '3969'),
	(377, 1, 0, -50282, 3971, 0, 0, 39, '3970'),
	(377, 1, 0, -50282, 3972, 0, 0, 39, '3971'),
	(377, 1, 0, -50282, 3973, 0, 0, 39, '3972'),
	(377, 1, 0, -50282, 3974, 0, 0, 39, '3973'),
	(377, 1, 0, -50282, 3975, 0, 0, 39, '3974'),
	(377, 1, 0, -50282, 3976, 0, 0, 39, '3975'),
	(377, 1, 0, -50282, 3977, 0, 0, 39, '3976'),
	(377, 1, 0, -50282, 3978, 0, 0, 39, '3977'),
	(377, 1, 0, -50282, 3979, 0, 0, 39, '3978'),
	(377, 1, 0, -50282, 3980, 0, 0, 39, '3979'),
	(377, 1, 0, -50282, 3981, 0, 0, 39, '3980'),
	(377, 1, 0, -50282, 3982, 0, 0, 39, '3981'),
	(377, 1, 0, -50282, 3983, 0, 0, 39, '3982'),
	(377, 1, 0, -50282, 3984, 0, 0, 39, '3983'),
	(377, 1, 0, -50282, 3985, 0, 0, 39, '3984'),
	(377, 1, 0, -50282, 3986, 0, 0, 39, '3985'),
	(377, 1, 0, -50282, 3987, 0, 0, 39, '3986'),
	(377, 1, 0, -50282, 3988, 0, 0, 39, '3987'),
	(377, 1, 0, -50282, 3989, 0, 0, 39, '3988'),
	(377, 1, 0, -50282, 3990, 0, 0, 39, '3989'),
	(377, 1, 0, -50282, 3991, 0, 0, 39, '3990'),
	(377, 1, 0, -50282, 3992, 0, 0, 39, '3991'),
	(377, 1, 0, -50282, 3993, 0, 0, 39, '3992'),
	(377, 1, 0, -50282, 3994, 0, 0, 39, '3993'),
	(377, 1, 0, -50282, 3995, 0, 0, 39, '3994'),
	(377, 1, 0, -50282, 3996, 0, 0, 39, '3995'),
	(377, 1, 0, -50282, 3997, 0, 0, 39, '3996'),
	(377, 1, 0, -50282, 3998, 0, 0, 39, '3997'),
	(377, 1, 0, -50282, 3999, 0, 0, 39, '3998'),
	(377, 1, 0, -50282, 4000, 0, 0, 39, '3999'),
	(377, 1, 0, -50246, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50246, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50246, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50246, 4, 0, 0, 39, '3'),
	(377, 1, 0, -50246, 5, 0, 0, 39, '4'),
	(377, 1, 0, -50246, 6, 0, 0, 39, '5'),
	(377, 1, 0, -50246, 7, 0, 0, 39, '6'),
	(377, 1, 0, -50246, 8, 0, 0, 39, '7'),
	(377, 1, 0, -50246, 9, 0, 0, 39, '8'),
	(377, 1, 0, -50246, 10, 0, 0, 39, '9'),
	(377, 1, 0, -50246, 11, 0, 0, 39, '10'),
	(377, 1, 0, -50246, 12, 0, 0, 39, '11'),
	(377, 1, 0, -50246, 13, 0, 0, 39, '12'),
	(377, 1, 0, -50246, 14, 0, 0, 39, '13'),
	(377, 1, 0, -50246, 15, 0, 0, 39, '14'),
	(377, 1, 0, -50246, 16, 0, 0, 39, '15'),
	(377, 1, 0, -50246, 17, 0, 0, 39, '16'),
	(377, 1, 0, -50246, 18, 0, 0, 39, '17'),
	(377, 1, 0, -50246, 19, 0, 0, 39, '18'),
	(377, 1, 0, -50246, 20, 0, 0, 39, '19'),
	(377, 1, 0, -50246, 21, 0, 0, 39, '20'),
	(377, 1, 0, -50246, 22, 0, 0, 39, '21'),
	(377, 1, 0, -50246, 23, 0, 0, 39, '22'),
	(377, 1, 0, -50246, 24, 0, 0, 39, '23'),
	(377, 1, 0, -50246, 25, 0, 0, 39, '24'),
	(377, 1, 0, -50246, 26, 0, 0, 39, '25'),
	(377, 1, 0, -50246, 27, 0, 0, 39, '26'),
	(377, 1, 0, -50246, 28, 0, 0, 39, '27'),
	(377, 1, 0, -50246, 29, 0, 0, 39, '28'),
	(377, 1, 0, -50246, 30, 0, 0, 39, '29'),
	(377, 1, 0, -50246, 31, 0, 0, 39, '30'),
	(377, 1, 0, -50246, 32, 0, 0, 39, '31'),
	(377, 1, 0, -50246, 33, 0, 0, 39, '32'),
	(377, 1, 0, -50246, 34, 0, 0, 39, '33'),
	(377, 1, 0, -50246, 35, 0, 0, 39, '34'),
	(377, 1, 0, -50246, 36, 0, 0, 39, '35'),
	(377, 1, 0, -50246, 37, 0, 0, 39, '36'),
	(377, 1, 0, -50246, 38, 0, 0, 39, '37'),
	(377, 1, 0, -50246, 39, 0, 0, 39, '38'),
	(377, 1, 0, -50246, 40, 0, 0, 39, '39'),
	(377, 1, 0, -50246, 41, 0, 0, 39, '40'),
	(377, 1, 0, -50246, 42, 0, 0, 39, '41'),
	(377, 1, 0, -50246, 43, 0, 0, 39, '42'),
	(377, 1, 0, -50246, 44, 0, 0, 39, '43'),
	(377, 1, 0, -50246, 45, 0, 0, 39, '44'),
	(377, 1, 0, -50246, 46, 0, 0, 39, '45'),
	(377, 1, 0, -50246, 47, 0, 0, 39, '46'),
	(377, 1, 0, -50246, 48, 0, 0, 39, '47'),
	(377, 1, 0, -50246, 49, 0, 0, 39, '48'),
	(377, 1, 0, -50246, 50, 0, 0, 39, '49'),
	(377, 1, 0, -50246, 51, 0, 0, 39, '50'),
	(377, 1, 0, -50246, 52, 0, 0, 39, '51'),
	(377, 1, 0, -50246, 53, 0, 0, 39, '52'),
	(377, 1, 0, -50246, 54, 0, 0, 39, '53'),
	(377, 1, 0, -50246, 55, 0, 0, 39, '54'),
	(377, 1, 0, -50246, 56, 0, 0, 39, '55'),
	(377, 1, 0, -50246, 57, 0, 0, 39, '56'),
	(377, 1, 0, -50246, 58, 0, 0, 39, '57'),
	(377, 1, 0, -50246, 59, 0, 0, 39, '58'),
	(377, 1, 0, -50246, 60, 0, 0, 39, '59'),
	(377, 1, 0, -50246, 61, 0, 0, 39, '60'),
	(377, 1, 0, -50246, 62, 0, 0, 39, '61'),
	(377, 1, 0, -50246, 63, 0, 0, 39, '62'),
	(377, 1, 0, -50246, 64, 0, 0, 39, '63'),
	(377, 1, 0, -50246, 65, 0, 0, 39, '64'),
	(377, 1, 0, -50246, 66, 0, 0, 39, '65'),
	(377, 1, 0, -50246, 67, 0, 0, 39, '66'),
	(377, 1, 0, -50246, 68, 0, 0, 39, '67'),
	(377, 1, 0, -50246, 69, 0, 0, 39, '68'),
	(377, 1, 0, -50246, 70, 0, 0, 39, '69'),
	(377, 1, 0, -50246, 71, 0, 0, 39, '70'),
	(377, 1, 0, -50246, 72, 0, 0, 39, '71'),
	(377, 1, 0, -50246, 73, 0, 0, 39, '72'),
	(377, 1, 0, -50246, 74, 0, 0, 39, '73'),
	(377, 1, 0, -50246, 75, 0, 0, 39, '74'),
	(377, 1, 0, -50246, 76, 0, 0, 39, '75'),
	(377, 1, 0, -50246, 77, 0, 0, 39, '76'),
	(377, 1, 0, -50246, 78, 0, 0, 39, '77'),
	(377, 1, 0, -50246, 79, 0, 0, 39, '78'),
	(377, 1, 0, -50246, 80, 0, 0, 39, '79'),
	(377, 1, 0, -50246, 81, 0, 0, 39, '80'),
	(377, 1, 0, -50246, 82, 0, 0, 39, '81'),
	(377, 1, 0, -50246, 83, 0, 0, 39, '82'),
	(377, 1, 0, -50246, 84, 0, 0, 39, '83'),
	(377, 1, 0, -50246, 85, 0, 0, 39, '84'),
	(377, 1, 0, -50246, 86, 0, 0, 39, '85'),
	(377, 1, 0, -50246, 87, 0, 0, 39, '86'),
	(377, 1, 0, -50246, 88, 0, 0, 39, '87'),
	(377, 1, 0, -50246, 89, 0, 0, 39, '88'),
	(377, 1, 0, -50246, 90, 0, 0, 39, '89'),
	(377, 1, 0, -50246, 91, 0, 0, 39, '90'),
	(377, 1, 0, -50246, 92, 0, 0, 39, '91'),
	(377, 1, 0, -50246, 93, 0, 0, 39, '92'),
	(377, 1, 0, -50246, 94, 0, 0, 39, '93'),
	(377, 1, 0, -50246, 95, 0, 0, 39, '94'),
	(377, 1, 0, -50246, 96, 0, 0, 39, '95'),
	(377, 1, 0, -50246, 97, 0, 0, 39, '96'),
	(377, 1, 0, -50246, 98, 0, 0, 39, '97'),
	(377, 1, 0, -50246, 99, 0, 0, 39, '98'),
	(377, 1, 0, -50246, 100, 0, 0, 39, '99'),
	(377, 1, 0, -50246, 101, 0, 0, 39, '100'),
	(377, 1, 0, -50246, 102, 0, 0, 39, '101'),
	(377, 1, 0, -50246, 103, 0, 0, 39, '102'),
	(377, 1, 0, -50246, 104, 0, 0, 39, '103'),
	(377, 1, 0, -50246, 105, 0, 0, 39, '104'),
	(377, 1, 0, -50246, 106, 0, 0, 39, '105'),
	(377, 1, 0, -50246, 107, 0, 0, 39, '106'),
	(377, 1, 0, -50246, 108, 0, 0, 39, '107'),
	(377, 1, 0, -50246, 109, 0, 0, 39, '108'),
	(377, 1, 0, -50246, 110, 0, 0, 39, '109'),
	(377, 1, 0, -50246, 111, 0, 0, 39, '110'),
	(377, 1, 0, -50246, 112, 0, 0, 39, '111'),
	(377, 1, 0, -50246, 113, 0, 0, 39, '112'),
	(377, 1, 0, -50246, 114, 0, 0, 39, '113'),
	(377, 1, 0, -50246, 115, 0, 0, 39, '114'),
	(377, 1, 0, -50246, 116, 0, 0, 39, '115'),
	(377, 1, 0, -50246, 117, 0, 0, 39, '116'),
	(377, 1, 0, -50246, 118, 0, 0, 39, '117'),
	(377, 1, 0, -50246, 119, 0, 0, 39, '118'),
	(377, 1, 0, -50246, 120, 0, 0, 39, '119'),
	(377, 1, 0, -50246, 121, 0, 0, 39, '120'),
	(377, 1, 0, -50246, 122, 0, 0, 39, '121'),
	(377, 1, 0, -50246, 123, 0, 0, 39, '122'),
	(377, 1, 0, -50246, 124, 0, 0, 39, '123'),
	(377, 1, 0, -50246, 125, 0, 0, 39, '124'),
	(377, 1, 0, -50246, 126, 0, 0, 39, '125'),
	(377, 1, 0, -50246, 127, 0, 0, 39, '126'),
	(377, 1, 0, -50246, 128, 0, 0, 39, '127'),
	(377, 1, 0, -50246, 129, 0, 0, 39, '128'),
	(377, 1, 0, -50246, 130, 0, 0, 39, '129'),
	(377, 1, 0, -50246, 131, 0, 0, 39, '130'),
	(377, 1, 0, -50246, 132, 0, 0, 39, '131'),
	(377, 1, 0, -50246, 133, 0, 0, 39, '132'),
	(377, 1, 0, -50246, 134, 0, 0, 39, '133'),
	(377, 1, 0, -50246, 135, 0, 0, 39, '134'),
	(377, 1, 0, -50246, 136, 0, 0, 39, '135'),
	(377, 1, 0, -50246, 137, 0, 0, 39, '136'),
	(377, 1, 0, -50246, 138, 0, 0, 39, '137'),
	(377, 1, 0, -50246, 139, 0, 0, 39, '138'),
	(377, 1, 0, -50246, 140, 0, 0, 39, '139'),
	(377, 1, 0, -50246, 141, 0, 0, 39, '140'),
	(377, 1, 0, -50246, 142, 0, 0, 39, '141'),
	(377, 1, 0, -50246, 143, 0, 0, 39, '142'),
	(377, 1, 0, -50246, 144, 0, 0, 39, '143'),
	(377, 1, 0, -50246, 145, 0, 0, 39, '144'),
	(377, 1, 0, -50246, 146, 0, 0, 39, '145'),
	(377, 1, 0, -50246, 147, 0, 0, 39, '146'),
	(377, 1, 0, -50246, 148, 0, 0, 39, '147'),
	(377, 1, 0, -50246, 149, 0, 0, 39, '148'),
	(377, 1, 0, -50246, 150, 0, 0, 39, '149'),
	(377, 1, 0, -50246, 151, 0, 0, 39, '150'),
	(377, 1, 0, -50246, 152, 0, 0, 39, '151'),
	(377, 1, 0, -50246, 153, 0, 0, 39, '152'),
	(377, 1, 0, -50246, 154, 0, 0, 39, '153'),
	(377, 1, 0, -50246, 155, 0, 0, 39, '154'),
	(377, 1, 0, -50246, 156, 0, 0, 39, '155'),
	(377, 1, 0, -50246, 157, 0, 0, 39, '156'),
	(377, 1, 0, -50246, 158, 0, 0, 39, '157'),
	(377, 1, 0, -50246, 159, 0, 0, 39, '158'),
	(377, 1, 0, -50246, 160, 0, 0, 39, '159'),
	(377, 1, 0, -50246, 161, 0, 0, 39, '160'),
	(377, 1, 0, -50246, 162, 0, 0, 39, '161'),
	(377, 1, 0, -50246, 163, 0, 0, 39, '162'),
	(377, 1, 0, -50246, 164, 0, 0, 39, '163'),
	(377, 1, 0, -50246, 165, 0, 0, 39, '164'),
	(377, 1, 0, -50246, 166, 0, 0, 39, '165'),
	(377, 1, 0, -50246, 167, 0, 0, 39, '166'),
	(377, 1, 0, -50246, 168, 0, 0, 39, '167'),
	(377, 1, 0, -50246, 169, 0, 0, 39, '168'),
	(377, 1, 0, -50246, 170, 0, 0, 39, '169'),
	(377, 1, 0, -50246, 171, 0, 0, 39, '170'),
	(377, 1, 0, -50246, 172, 0, 0, 39, '171'),
	(377, 1, 0, -50246, 173, 0, 0, 39, '172'),
	(377, 1, 0, -50246, 174, 0, 0, 39, '173'),
	(377, 1, 0, -50246, 175, 0, 0, 39, '174'),
	(377, 1, 0, -50246, 176, 0, 0, 39, '175'),
	(377, 1, 0, -50246, 177, 0, 0, 39, '176'),
	(377, 1, 0, -50246, 178, 0, 0, 39, '177'),
	(377, 1, 0, -50246, 179, 0, 0, 39, '178'),
	(377, 1, 0, -50246, 180, 0, 0, 39, '179'),
	(377, 1, 0, -50246, 181, 0, 0, 39, '180'),
	(377, 1, 0, -50246, 182, 0, 0, 39, '181'),
	(377, 1, 0, -50246, 183, 0, 0, 39, '182'),
	(377, 1, 0, -50246, 184, 0, 0, 39, '183'),
	(377, 1, 0, -50246, 185, 0, 0, 39, '184'),
	(377, 1, 0, -50246, 186, 0, 0, 39, '185'),
	(377, 1, 0, -50246, 187, 0, 0, 39, '186'),
	(377, 1, 0, -50246, 188, 0, 0, 39, '187'),
	(377, 1, 0, -50246, 189, 0, 0, 39, '188'),
	(377, 1, 0, -50246, 190, 0, 0, 39, '189'),
	(377, 1, 0, -50246, 191, 0, 0, 39, '190'),
	(377, 1, 0, -50246, 192, 0, 0, 39, '191'),
	(377, 1, 0, -50246, 193, 0, 0, 39, '192'),
	(377, 1, 0, -50246, 194, 0, 0, 39, '193'),
	(377, 1, 0, -50246, 195, 0, 0, 39, '194'),
	(377, 1, 0, -50246, 196, 0, 0, 39, '195'),
	(377, 1, 0, -50246, 197, 0, 0, 39, '196'),
	(377, 1, 0, -50246, 198, 0, 0, 39, '197'),
	(377, 1, 0, -50246, 199, 0, 0, 39, '198'),
	(377, 1, 0, -50246, 200, 0, 0, 39, '199'),
	(377, 1, 0, -50246, 201, 0, 0, 39, '200'),
	(377, 1, 0, -50246, 202, 0, 0, 39, '201'),
	(377, 1, 0, -50246, 203, 0, 0, 39, '202'),
	(377, 1, 0, -50246, 204, 0, 0, 39, '203'),
	(377, 1, 0, -50246, 205, 0, 0, 39, '204'),
	(377, 1, 0, -50246, 206, 0, 0, 39, '205'),
	(377, 1, 0, -50246, 207, 0, 0, 39, '206'),
	(377, 1, 0, -50246, 208, 0, 0, 39, '207'),
	(377, 1, 0, -50246, 209, 0, 0, 39, '208'),
	(377, 1, 0, -50246, 210, 0, 0, 39, '209'),
	(377, 1, 0, -50246, 211, 0, 0, 39, '210'),
	(377, 1, 0, -50246, 212, 0, 0, 39, '211'),
	(377, 1, 0, -50246, 213, 0, 0, 39, '212'),
	(377, 1, 0, -50246, 214, 0, 0, 39, '213'),
	(377, 1, 0, -50246, 215, 0, 0, 39, '214'),
	(377, 1, 0, -50246, 216, 0, 0, 39, '215'),
	(377, 1, 0, -50246, 217, 0, 0, 39, '216'),
	(377, 1, 0, -50246, 218, 0, 0, 39, '217'),
	(377, 1, 0, -50246, 219, 0, 0, 39, '218'),
	(377, 1, 0, -50246, 220, 0, 0, 39, '219'),
	(377, 1, 0, -50246, 221, 0, 0, 39, '220'),
	(377, 1, 0, -50246, 222, 0, 0, 39, '221'),
	(377, 1, 0, -50246, 223, 0, 0, 39, '222'),
	(377, 1, 0, -50246, 224, 0, 0, 39, '223'),
	(377, 1, 0, -50246, 225, 0, 0, 39, '224'),
	(377, 1, 0, -50246, 226, 0, 0, 39, '225'),
	(377, 1, 0, -50246, 227, 0, 0, 39, '226'),
	(377, 1, 0, -50246, 228, 0, 0, 39, '227'),
	(377, 1, 0, -50246, 229, 0, 0, 39, '228'),
	(377, 1, 0, -50246, 230, 0, 0, 39, '229'),
	(377, 1, 0, -50246, 231, 0, 0, 39, '230'),
	(377, 1, 0, -50246, 232, 0, 0, 39, '231'),
	(377, 1, 0, -50246, 233, 0, 0, 39, '232'),
	(377, 1, 0, -50246, 234, 0, 0, 39, '233'),
	(377, 1, 0, -50246, 235, 0, 0, 39, '234'),
	(377, 1, 0, -50246, 236, 0, 0, 39, '235'),
	(377, 1, 0, -50246, 237, 0, 0, 39, '236'),
	(377, 1, 0, -50246, 238, 0, 0, 39, '237'),
	(377, 1, 0, -50246, 239, 0, 0, 39, '238'),
	(377, 1, 0, -50246, 240, 0, 0, 39, '239'),
	(377, 1, 0, -50246, 241, 0, 0, 39, '240'),
	(377, 1, 0, -50246, 242, 0, 0, 39, '241'),
	(377, 1, 0, -50246, 243, 0, 0, 39, '242'),
	(377, 1, 0, -50246, 244, 0, 0, 39, '243'),
	(377, 1, 0, -50246, 245, 0, 0, 39, '244'),
	(377, 1, 0, -50246, 246, 0, 0, 39, '245'),
	(377, 1, 0, -50246, 247, 0, 0, 39, '246'),
	(377, 1, 0, -50246, 248, 0, 0, 39, '247'),
	(377, 1, 0, -50246, 249, 0, 0, 39, '248'),
	(377, 1, 0, -50246, 250, 0, 0, 39, '249'),
	(377, 1, 0, -50246, 251, 0, 0, 39, '250'),
	(377, 1, 0, -50246, 252, 0, 0, 39, '251'),
	(377, 1, 0, -50246, 253, 0, 0, 39, '252'),
	(377, 1, 0, -50246, 254, 0, 0, 39, '253'),
	(377, 1, 0, -50246, 255, 0, 0, 39, '254'),
	(377, 1, 0, -50246, 256, 0, 0, 39, '255'),
	(377, 1, 0, -50246, 257, 0, 0, 39, '256'),
	(377, 1, 0, -50246, 258, 0, 0, 39, '257'),
	(377, 1, 0, -50246, 259, 0, 0, 39, '258'),
	(377, 1, 0, -50246, 260, 0, 0, 39, '259'),
	(377, 1, 0, -50246, 261, 0, 0, 39, '260'),
	(377, 1, 0, -50246, 262, 0, 0, 39, '261'),
	(377, 1, 0, -50246, 263, 0, 0, 39, '262'),
	(377, 1, 0, -50246, 264, 0, 0, 39, '263'),
	(377, 1, 0, -50246, 265, 0, 0, 39, '264'),
	(377, 1, 0, -50246, 266, 0, 0, 39, '265'),
	(377, 1, 0, -50246, 267, 0, 0, 39, '266'),
	(377, 1, 0, -50246, 268, 0, 0, 39, '267'),
	(377, 1, 0, -50246, 269, 0, 0, 39, '268'),
	(377, 1, 0, -50246, 270, 0, 0, 39, '269'),
	(377, 1, 0, -50246, 271, 0, 0, 39, '270'),
	(377, 1, 0, -50246, 272, 0, 0, 39, '271'),
	(377, 1, 0, -50246, 273, 0, 0, 39, '272'),
	(377, 1, 0, -50246, 274, 0, 0, 39, '273'),
	(377, 1, 0, -50246, 275, 0, 0, 39, '274'),
	(377, 1, 0, -50246, 276, 0, 0, 39, '275'),
	(377, 1, 0, -50246, 277, 0, 0, 39, '276'),
	(377, 1, 0, -50246, 278, 0, 0, 39, '277'),
	(377, 1, 0, -50246, 279, 0, 0, 39, '278'),
	(377, 1, 0, -50246, 280, 0, 0, 39, '279'),
	(377, 1, 0, -50246, 281, 0, 0, 39, '280'),
	(377, 1, 0, -50246, 282, 0, 0, 39, '281'),
	(377, 1, 0, -50246, 283, 0, 0, 39, '282'),
	(377, 1, 0, -50246, 284, 0, 0, 39, '283'),
	(377, 1, 0, -50246, 285, 0, 0, 39, '284'),
	(377, 1, 0, -50246, 286, 0, 0, 39, '285'),
	(377, 1, 0, -50246, 287, 0, 0, 39, '286'),
	(377, 1, 0, -50246, 288, 0, 0, 39, '287'),
	(377, 1, 0, -50246, 289, 0, 0, 39, '288'),
	(377, 1, 0, -50246, 290, 0, 0, 39, '289'),
	(377, 1, 0, -50246, 291, 0, 0, 39, '290'),
	(377, 1, 0, -50246, 292, 0, 0, 39, '291'),
	(377, 1, 0, -50246, 293, 0, 0, 39, '292'),
	(377, 1, 0, -50246, 294, 0, 0, 39, '293'),
	(377, 1, 0, -50246, 295, 0, 0, 39, '294'),
	(377, 1, 0, -50246, 296, 0, 0, 39, '295'),
	(377, 1, 0, -50246, 297, 0, 0, 39, '296'),
	(377, 1, 0, -50246, 298, 0, 0, 39, '297'),
	(377, 1, 0, -50246, 299, 0, 0, 39, '298'),
	(377, 1, 0, -50246, 300, 0, 0, 39, '299'),
	(377, 1, 0, -50246, 301, 0, 0, 39, '300'),
	(377, 1, 0, -50246, 302, 0, 0, 39, '301'),
	(377, 1, 0, -50246, 303, 0, 0, 39, '302'),
	(377, 1, 0, -50246, 304, 0, 0, 39, '303'),
	(377, 1, 0, -50246, 305, 0, 0, 39, '304'),
	(377, 1, 0, -50246, 306, 0, 0, 39, '305'),
	(377, 1, 0, -50246, 307, 0, 0, 39, '306'),
	(377, 1, 0, -50246, 308, 0, 0, 39, '307'),
	(377, 1, 0, -50246, 309, 0, 0, 39, '308'),
	(377, 1, 0, -50246, 310, 0, 0, 39, '309'),
	(377, 1, 0, -50246, 311, 0, 0, 39, '310'),
	(377, 1, 0, -50246, 312, 0, 0, 39, '311'),
	(377, 1, 0, -50246, 313, 0, 0, 39, '312'),
	(377, 1, 0, -50246, 314, 0, 0, 39, '313'),
	(377, 1, 0, -50246, 315, 0, 0, 39, '314'),
	(377, 1, 0, -50246, 316, 0, 0, 39, '315'),
	(377, 1, 0, -50246, 317, 0, 0, 39, '316'),
	(377, 1, 0, -50246, 318, 0, 0, 39, '317'),
	(377, 1, 0, -50246, 319, 0, 0, 39, '318'),
	(377, 1, 0, -50246, 320, 0, 0, 39, '319'),
	(377, 1, 0, -50246, 321, 0, 0, 39, '320'),
	(377, 1, 0, -50246, 322, 0, 0, 39, '321'),
	(377, 1, 0, -50246, 323, 0, 0, 39, '322'),
	(377, 1, 0, -50246, 324, 0, 0, 39, '323'),
	(377, 1, 0, -50246, 325, 0, 0, 39, '324'),
	(377, 1, 0, -50246, 326, 0, 0, 39, '325'),
	(377, 1, 0, -50246, 327, 0, 0, 39, '326'),
	(377, 1, 0, -50246, 328, 0, 0, 39, '327'),
	(377, 1, 0, -50246, 329, 0, 0, 39, '328'),
	(377, 1, 0, -50246, 330, 0, 0, 39, '329'),
	(377, 1, 0, -50246, 331, 0, 0, 39, '330'),
	(377, 1, 0, -50246, 332, 0, 0, 39, '331'),
	(377, 1, 0, -50246, 333, 0, 0, 39, '332'),
	(377, 1, 0, -50246, 334, 0, 0, 39, '333'),
	(377, 1, 0, -50246, 335, 0, 0, 39, '334'),
	(377, 1, 0, -50246, 336, 0, 0, 39, '335'),
	(377, 1, 0, -50246, 337, 0, 0, 39, '336'),
	(377, 1, 0, -50246, 338, 0, 0, 39, '337'),
	(377, 1, 0, -50246, 339, 0, 0, 39, '338'),
	(377, 1, 0, -50246, 340, 0, 0, 39, '339'),
	(377, 1, 0, -50246, 341, 0, 0, 39, '340'),
	(377, 1, 0, -50246, 342, 0, 0, 39, '341'),
	(377, 1, 0, -50246, 343, 0, 0, 39, '342'),
	(377, 1, 0, -50246, 344, 0, 0, 39, '343'),
	(377, 1, 0, -50246, 345, 0, 0, 39, '344'),
	(377, 1, 0, -50246, 346, 0, 0, 39, '345'),
	(377, 1, 0, -50246, 347, 0, 0, 39, '346'),
	(377, 1, 0, -50246, 348, 0, 0, 39, '347'),
	(377, 1, 0, -50246, 349, 0, 0, 39, '348'),
	(377, 1, 0, -50246, 350, 0, 0, 39, '349'),
	(377, 1, 0, -50246, 351, 0, 0, 39, '350'),
	(377, 1, 0, -50246, 352, 0, 0, 39, '351'),
	(377, 1, 0, -50246, 353, 0, 0, 39, '352'),
	(377, 1, 0, -50246, 354, 0, 0, 39, '353'),
	(377, 1, 0, -50246, 355, 0, 0, 39, '354'),
	(377, 1, 0, -50246, 356, 0, 0, 39, '355'),
	(377, 1, 0, -50246, 357, 0, 0, 39, '356'),
	(377, 1, 0, -50246, 358, 0, 0, 39, '357'),
	(377, 1, 0, -50246, 359, 0, 0, 39, '358'),
	(377, 1, 0, -50246, 360, 0, 0, 39, '359'),
	(377, 1, 0, -50246, 361, 0, 0, 39, '360'),
	(377, 1, 0, -50246, 362, 0, 0, 39, '361'),
	(377, 1, 0, -50246, 363, 0, 0, 39, '362'),
	(377, 1, 0, -50246, 364, 0, 0, 39, '363'),
	(377, 1, 0, -50246, 365, 0, 0, 39, '364'),
	(377, 1, 0, -50246, 366, 0, 0, 39, '365'),
	(377, 1, 0, -50246, 367, 0, 0, 39, '366'),
	(377, 1, 0, -50246, 368, 0, 0, 39, '367'),
	(377, 1, 0, -50246, 369, 0, 0, 39, '368'),
	(377, 1, 0, -50246, 370, 0, 0, 39, '369'),
	(377, 1, 0, -50246, 371, 0, 0, 39, '370'),
	(377, 1, 0, -50246, 372, 0, 0, 39, '371'),
	(377, 1, 0, -50246, 373, 0, 0, 39, '372'),
	(377, 1, 0, -50246, 374, 0, 0, 39, '373'),
	(377, 1, 0, -50246, 375, 0, 0, 39, '374'),
	(377, 1, 0, -50246, 376, 0, 0, 39, '375'),
	(377, 1, 0, -50246, 377, 0, 0, 39, '376'),
	(377, 1, 0, -50246, 378, 0, 0, 39, '377'),
	(377, 1, 0, -50246, 379, 0, 0, 39, '378'),
	(377, 1, 0, -50246, 380, 0, 0, 39, '379'),
	(377, 1, 0, -50246, 381, 0, 0, 39, '380'),
	(377, 1, 0, -50246, 382, 0, 0, 39, '381'),
	(377, 1, 0, -50246, 383, 0, 0, 39, '382'),
	(377, 1, 0, -50246, 384, 0, 0, 39, '383'),
	(377, 1, 0, -50246, 385, 0, 0, 39, '384'),
	(377, 1, 0, -50246, 386, 0, 0, 39, '385'),
	(377, 1, 0, -50246, 387, 0, 0, 39, '386'),
	(377, 1, 0, -50246, 388, 0, 0, 39, '387'),
	(377, 1, 0, -50246, 389, 0, 0, 39, '388'),
	(377, 1, 0, -50246, 390, 0, 0, 39, '389'),
	(377, 1, 0, -50246, 391, 0, 0, 39, '390'),
	(377, 1, 0, -50246, 392, 0, 0, 39, '391'),
	(377, 1, 0, -50246, 393, 0, 0, 39, '392'),
	(377, 1, 0, -50246, 394, 0, 0, 39, '393'),
	(377, 1, 0, -50246, 395, 0, 0, 39, '394'),
	(377, 1, 0, -50246, 396, 0, 0, 39, '395'),
	(377, 1, 0, -50246, 397, 0, 0, 39, '396'),
	(377, 1, 0, -50246, 398, 0, 0, 39, '397'),
	(377, 1, 0, -50246, 399, 0, 0, 39, '398'),
	(377, 1, 0, -50246, 400, 0, 0, 39, '399'),
	(377, 1, 0, -50246, 401, 0, 0, 39, '400'),
	(377, 1, 0, -50246, 402, 0, 0, 39, '401'),
	(377, 1, 0, -50246, 403, 0, 0, 39, '402'),
	(377, 1, 0, -50246, 404, 0, 0, 39, '403'),
	(377, 1, 0, -50246, 405, 0, 0, 39, '404'),
	(377, 1, 0, -50246, 406, 0, 0, 39, '405'),
	(377, 1, 0, -50246, 407, 0, 0, 39, '406'),
	(377, 1, 0, -50246, 408, 0, 0, 39, '407'),
	(377, 1, 0, -50246, 409, 0, 0, 39, '408'),
	(377, 1, 0, -50246, 410, 0, 0, 39, '409'),
	(377, 1, 0, -50246, 411, 0, 0, 39, '410'),
	(377, 1, 0, -50246, 412, 0, 0, 39, '411'),
	(377, 1, 0, -50246, 413, 0, 0, 39, '412'),
	(377, 1, 0, -50246, 414, 0, 0, 39, '413'),
	(377, 1, 0, -50246, 415, 0, 0, 39, '414'),
	(377, 1, 0, -50246, 416, 0, 0, 39, '415'),
	(377, 1, 0, -50246, 417, 0, 0, 39, '416'),
	(377, 1, 0, -50246, 418, 0, 0, 39, '417'),
	(377, 1, 0, -50246, 419, 0, 0, 39, '418'),
	(377, 1, 0, -50246, 420, 0, 0, 39, '419'),
	(377, 1, 0, -50246, 421, 0, 0, 39, '420'),
	(377, 1, 0, -50246, 422, 0, 0, 39, '421'),
	(377, 1, 0, -50246, 423, 0, 0, 39, '422'),
	(377, 1, 0, -50246, 424, 0, 0, 39, '423'),
	(377, 1, 0, -50246, 425, 0, 0, 39, '424'),
	(377, 1, 0, -50246, 426, 0, 0, 39, '425'),
	(377, 1, 0, -50246, 427, 0, 0, 39, '426'),
	(377, 1, 0, -50246, 428, 0, 0, 39, '427'),
	(377, 1, 0, -50246, 429, 0, 0, 39, '428'),
	(377, 1, 0, -50246, 430, 0, 0, 39, '429'),
	(377, 1, 0, -50246, 431, 0, 0, 39, '430'),
	(377, 1, 0, -50246, 432, 0, 0, 39, '431'),
	(377, 1, 0, -50246, 433, 0, 0, 39, '432'),
	(377, 1, 0, -50246, 434, 0, 0, 39, '433'),
	(377, 1, 0, -50246, 435, 0, 0, 39, '434'),
	(377, 1, 0, -50246, 436, 0, 0, 39, '435'),
	(377, 1, 0, -50246, 437, 0, 0, 39, '436'),
	(377, 1, 0, -50246, 438, 0, 0, 39, '437'),
	(377, 1, 0, -50246, 439, 0, 0, 39, '438'),
	(377, 1, 0, -50246, 440, 0, 0, 39, '439'),
	(377, 1, 0, -50246, 441, 0, 0, 39, '440'),
	(377, 1, 0, -50246, 442, 0, 0, 39, '441'),
	(377, 1, 0, -50246, 443, 0, 0, 39, '442'),
	(377, 1, 0, -50246, 444, 0, 0, 39, '443'),
	(377, 1, 0, -50246, 445, 0, 0, 39, '444'),
	(377, 1, 0, -50246, 446, 0, 0, 39, '445'),
	(377, 1, 0, -50246, 447, 0, 0, 39, '446'),
	(377, 1, 0, -50246, 448, 0, 0, 39, '447'),
	(377, 1, 0, -50246, 449, 0, 0, 39, '448'),
	(377, 1, 0, -50246, 450, 0, 0, 39, '449'),
	(377, 1, 0, -50246, 451, 0, 0, 39, '450'),
	(377, 1, 0, -50246, 452, 0, 0, 39, '451'),
	(377, 1, 0, -50246, 453, 0, 0, 39, '452'),
	(377, 1, 0, -50246, 454, 0, 0, 39, '453'),
	(377, 1, 0, -50246, 455, 0, 0, 39, '454'),
	(377, 1, 0, -50246, 456, 0, 0, 39, '455'),
	(377, 1, 0, -50246, 457, 0, 0, 39, '456'),
	(377, 1, 0, -50246, 458, 0, 0, 39, '457'),
	(377, 1, 0, -50246, 459, 0, 0, 39, '458'),
	(377, 1, 0, -50246, 460, 0, 0, 39, '459'),
	(377, 1, 0, -50246, 461, 0, 0, 39, '460'),
	(377, 1, 0, -50246, 462, 0, 0, 39, '461'),
	(377, 1, 0, -50246, 463, 0, 0, 39, '462'),
	(377, 1, 0, -50246, 464, 0, 0, 39, '463'),
	(377, 1, 0, -50246, 465, 0, 0, 39, '464'),
	(377, 1, 0, -50246, 466, 0, 0, 39, '465'),
	(377, 1, 0, -50246, 467, 0, 0, 39, '466'),
	(377, 1, 0, -50246, 468, 0, 0, 39, '467'),
	(377, 1, 0, -50246, 469, 0, 0, 39, '468'),
	(377, 1, 0, -50246, 470, 0, 0, 39, '469'),
	(377, 1, 0, -50246, 471, 0, 0, 39, '470'),
	(377, 1, 0, -50246, 472, 0, 0, 39, '471'),
	(377, 1, 0, -50246, 473, 0, 0, 39, '472'),
	(377, 1, 0, -50246, 474, 0, 0, 39, '473'),
	(377, 1, 0, -50246, 475, 0, 0, 39, '474'),
	(377, 1, 0, -50246, 476, 0, 0, 39, '475'),
	(377, 1, 0, -50246, 477, 0, 0, 39, '476'),
	(377, 1, 0, -50246, 478, 0, 0, 39, '477'),
	(377, 1, 0, -50246, 479, 0, 0, 39, '478'),
	(377, 1, 0, -50246, 480, 0, 0, 39, '479'),
	(377, 1, 0, -50246, 481, 0, 0, 39, '480'),
	(377, 1, 0, -50246, 482, 0, 0, 39, '481'),
	(377, 1, 0, -50246, 483, 0, 0, 39, '482'),
	(377, 1, 0, -50246, 484, 0, 0, 39, '483'),
	(377, 1, 0, -50246, 485, 0, 0, 39, '484'),
	(377, 1, 0, -50246, 486, 0, 0, 39, '485'),
	(377, 1, 0, -50246, 487, 0, 0, 39, '486'),
	(377, 1, 0, -50246, 488, 0, 0, 39, '487'),
	(377, 1, 0, -50246, 489, 0, 0, 39, '488'),
	(377, 1, 0, -50246, 490, 0, 0, 39, '489'),
	(377, 1, 0, -50246, 491, 0, 0, 39, '490'),
	(377, 1, 0, -50246, 492, 0, 0, 39, '491'),
	(377, 1, 0, -50246, 493, 0, 0, 39, '492'),
	(377, 1, 0, -50246, 494, 0, 0, 39, '493'),
	(377, 1, 0, -50246, 495, 0, 0, 39, '494'),
	(377, 1, 0, -50246, 496, 0, 0, 39, '495'),
	(377, 1, 0, -50246, 497, 0, 0, 39, '496'),
	(377, 1, 0, -50246, 498, 0, 0, 39, '497'),
	(377, 1, 0, -50246, 499, 0, 0, 39, '498'),
	(377, 1, 0, -50246, 500, 0, 0, 39, '499'),
	(377, 1, 0, -50246, 501, 0, 0, 39, '500'),
	(377, 1, 0, -50246, 502, 0, 0, 39, '501'),
	(377, 1, 0, -50246, 503, 0, 0, 39, '502'),
	(377, 1, 0, -50246, 504, 0, 0, 39, '503'),
	(377, 1, 0, -50246, 505, 0, 0, 39, '504'),
	(377, 1, 0, -50246, 506, 0, 0, 39, '505'),
	(377, 1, 0, -50246, 507, 0, 0, 39, '506'),
	(377, 1, 0, -50246, 508, 0, 0, 39, '507'),
	(377, 1, 0, -50246, 509, 0, 0, 39, '508'),
	(377, 1, 0, -50246, 510, 0, 0, 39, '509'),
	(377, 1, 0, -50246, 511, 0, 0, 39, '510'),
	(377, 1, 0, -50246, 512, 0, 0, 39, '511'),
	(377, 1, 0, -50246, 513, 0, 0, 39, '512'),
	(377, 1, 0, -50246, 514, 0, 0, 39, '513'),
	(377, 1, 0, -50246, 515, 0, 0, 39, '514'),
	(377, 1, 0, -50246, 516, 0, 0, 39, '515'),
	(377, 1, 0, -50246, 517, 0, 0, 39, '516'),
	(377, 1, 0, -50246, 518, 0, 0, 39, '517'),
	(377, 1, 0, -50246, 519, 0, 0, 39, '518'),
	(377, 1, 0, -50246, 520, 0, 0, 39, '519'),
	(377, 1, 0, -50246, 521, 0, 0, 39, '520'),
	(377, 1, 0, -50246, 522, 0, 0, 39, '521'),
	(377, 1, 0, -50246, 523, 0, 0, 39, '522'),
	(377, 1, 0, -50246, 524, 0, 0, 39, '523'),
	(377, 1, 0, -50246, 525, 0, 0, 39, '524'),
	(377, 1, 0, -50246, 526, 0, 0, 39, '525'),
	(377, 1, 0, -50246, 527, 0, 0, 39, '526'),
	(377, 1, 0, -50246, 528, 0, 0, 39, '527'),
	(377, 1, 0, -50246, 529, 0, 0, 39, '528'),
	(377, 1, 0, -50246, 530, 0, 0, 39, '529'),
	(377, 1, 0, -50246, 531, 0, 0, 39, '530'),
	(377, 1, 0, -50246, 532, 0, 0, 39, '531'),
	(377, 1, 0, -50246, 533, 0, 0, 39, '532'),
	(377, 1, 0, -50246, 534, 0, 0, 39, '533'),
	(377, 1, 0, -50246, 535, 0, 0, 39, '534'),
	(377, 1, 0, -50246, 536, 0, 0, 39, '535'),
	(377, 1, 0, -50246, 537, 0, 0, 39, '536'),
	(377, 1, 0, -50246, 538, 0, 0, 39, '537'),
	(377, 1, 0, -50246, 539, 0, 0, 39, '538'),
	(377, 1, 0, -50246, 540, 0, 0, 39, '539'),
	(377, 1, 0, -50246, 541, 0, 0, 39, '540'),
	(377, 1, 0, -50246, 542, 0, 0, 39, '541'),
	(377, 1, 0, -50246, 543, 0, 0, 39, '542'),
	(377, 1, 0, -50246, 544, 0, 0, 39, '543'),
	(377, 1, 0, -50246, 545, 0, 0, 39, '544'),
	(377, 1, 0, -50246, 546, 0, 0, 39, '545'),
	(377, 1, 0, -50246, 547, 0, 0, 39, '546'),
	(377, 1, 0, -50246, 548, 0, 0, 39, '547'),
	(377, 1, 0, -50246, 549, 0, 0, 39, '548'),
	(377, 1, 0, -50246, 550, 0, 0, 39, '549'),
	(377, 1, 0, -50246, 551, 0, 0, 39, '550'),
	(377, 1, 0, -50246, 552, 0, 0, 39, '551'),
	(377, 1, 0, -50246, 553, 0, 0, 39, '552'),
	(377, 1, 0, -50246, 554, 0, 0, 39, '553'),
	(377, 1, 0, -50246, 555, 0, 0, 39, '554'),
	(377, 1, 0, -50246, 556, 0, 0, 39, '555'),
	(377, 1, 0, -50246, 557, 0, 0, 39, '556'),
	(377, 1, 0, -50246, 558, 0, 0, 39, '557'),
	(377, 1, 0, -50246, 559, 0, 0, 39, '558'),
	(377, 1, 0, -50246, 560, 0, 0, 39, '559'),
	(377, 1, 0, -50246, 561, 0, 0, 39, '560'),
	(377, 1, 0, -50246, 562, 0, 0, 39, '561'),
	(377, 1, 0, -50246, 563, 0, 0, 39, '562'),
	(377, 1, 0, -50246, 564, 0, 0, 39, '563'),
	(377, 1, 0, -50246, 565, 0, 0, 39, '564'),
	(377, 1, 0, -50246, 566, 0, 0, 39, '565'),
	(377, 1, 0, -50246, 567, 0, 0, 39, '566'),
	(377, 1, 0, -50246, 568, 0, 0, 39, '567'),
	(377, 1, 0, -50246, 569, 0, 0, 39, '568'),
	(377, 1, 0, -50246, 570, 0, 0, 39, '569'),
	(377, 1, 0, -50246, 571, 0, 0, 39, '570'),
	(377, 1, 0, -50246, 572, 0, 0, 39, '571'),
	(377, 1, 0, -50246, 573, 0, 0, 39, '572'),
	(377, 1, 0, -50246, 574, 0, 0, 39, '573'),
	(377, 1, 0, -50246, 575, 0, 0, 39, '574'),
	(377, 1, 0, -50246, 576, 0, 0, 39, '575'),
	(377, 1, 0, -50246, 577, 0, 0, 39, '576'),
	(377, 1, 0, -50246, 578, 0, 0, 39, '577'),
	(377, 1, 0, -50246, 579, 0, 0, 39, '578'),
	(377, 1, 0, -50246, 580, 0, 0, 39, '579'),
	(377, 1, 0, -50246, 581, 0, 0, 39, '580'),
	(377, 1, 0, -50246, 582, 0, 0, 39, '581'),
	(377, 1, 0, -50246, 583, 0, 0, 39, '582'),
	(377, 1, 0, -50246, 584, 0, 0, 39, '583'),
	(377, 1, 0, -50246, 585, 0, 0, 39, '584'),
	(377, 1, 0, -50246, 586, 0, 0, 39, '585'),
	(377, 1, 0, -50246, 587, 0, 0, 39, '586'),
	(377, 1, 0, -50246, 588, 0, 0, 39, '587'),
	(377, 1, 0, -50246, 589, 0, 0, 39, '588'),
	(377, 1, 0, -50246, 590, 0, 0, 39, '589'),
	(377, 1, 0, -50246, 591, 0, 0, 39, '590'),
	(377, 1, 0, -50246, 592, 0, 0, 39, '591'),
	(377, 1, 0, -50246, 593, 0, 0, 39, '592'),
	(377, 1, 0, -50246, 594, 0, 0, 39, '593'),
	(377, 1, 0, -50246, 595, 0, 0, 39, '594'),
	(377, 1, 0, -50246, 596, 0, 0, 39, '595'),
	(377, 1, 0, -50246, 597, 0, 0, 39, '596'),
	(377, 1, 0, -50246, 598, 0, 0, 39, '597'),
	(377, 1, 0, -50246, 599, 0, 0, 39, '598'),
	(377, 1, 0, -50246, 600, 0, 0, 39, '599'),
	(377, 1, 0, -50246, 601, 0, 0, 39, '600'),
	(377, 1, 0, -50246, 602, 0, 0, 39, '601'),
	(377, 1, 0, -50246, 603, 0, 0, 39, '602'),
	(377, 1, 0, -50246, 604, 0, 0, 39, '603'),
	(377, 1, 0, -50246, 605, 0, 0, 39, '604'),
	(377, 1, 0, -50246, 606, 0, 0, 39, '605'),
	(377, 1, 0, -50246, 607, 0, 0, 39, '606'),
	(377, 1, 0, -50246, 608, 0, 0, 39, '607'),
	(377, 1, 0, -50246, 609, 0, 0, 39, '608'),
	(377, 1, 0, -50246, 610, 0, 0, 39, '609'),
	(377, 1, 0, -50246, 611, 0, 0, 39, '610'),
	(377, 1, 0, -50246, 612, 0, 0, 39, '611'),
	(377, 1, 0, -50246, 613, 0, 0, 39, '612'),
	(377, 1, 0, -50246, 614, 0, 0, 39, '613'),
	(377, 1, 0, -50246, 615, 0, 0, 39, '614'),
	(377, 1, 0, -50246, 616, 0, 0, 39, '615'),
	(377, 1, 0, -50246, 617, 0, 0, 39, '616'),
	(377, 1, 0, -50246, 618, 0, 0, 39, '617'),
	(377, 1, 0, -50246, 619, 0, 0, 39, '618'),
	(377, 1, 0, -50246, 620, 0, 0, 39, '619'),
	(377, 1, 0, -50246, 621, 0, 0, 39, '620'),
	(377, 1, 0, -50246, 622, 0, 0, 39, '621'),
	(377, 1, 0, -50246, 623, 0, 0, 39, '622'),
	(377, 1, 0, -50246, 624, 0, 0, 39, '623'),
	(377, 1, 0, -50246, 625, 0, 0, 39, '624'),
	(377, 1, 0, -50246, 626, 0, 0, 39, '625'),
	(377, 1, 0, -50246, 627, 0, 0, 39, '626'),
	(377, 1, 0, -50246, 628, 0, 0, 39, '627'),
	(377, 1, 0, -50246, 629, 0, 0, 39, '628'),
	(377, 1, 0, -50246, 630, 0, 0, 39, '629'),
	(377, 1, 0, -50246, 631, 0, 0, 39, '630'),
	(377, 1, 0, -50246, 632, 0, 0, 39, '631'),
	(377, 1, 0, -50246, 633, 0, 0, 39, '632'),
	(377, 1, 0, -50246, 634, 0, 0, 39, '633'),
	(377, 1, 0, -50246, 635, 0, 0, 39, '634'),
	(377, 1, 0, -50246, 636, 0, 0, 39, '635'),
	(377, 1, 0, -50246, 637, 0, 0, 39, '636'),
	(377, 1, 0, -50246, 638, 0, 0, 39, '637'),
	(377, 1, 0, -50246, 639, 0, 0, 39, '638'),
	(377, 1, 0, -50246, 640, 0, 0, 39, '639'),
	(377, 1, 0, -50246, 641, 0, 0, 39, '640'),
	(377, 1, 0, -50246, 642, 0, 0, 39, '641'),
	(377, 1, 0, -50246, 643, 0, 0, 39, '642'),
	(377, 1, 0, -50246, 644, 0, 0, 39, '643'),
	(377, 1, 0, -50246, 645, 0, 0, 39, '644'),
	(377, 1, 0, -50246, 646, 0, 0, 39, '645'),
	(377, 1, 0, -50246, 647, 0, 0, 39, '646'),
	(377, 1, 0, -50246, 648, 0, 0, 39, '647'),
	(377, 1, 0, -50246, 649, 0, 0, 39, '648'),
	(377, 1, 0, -50246, 650, 0, 0, 39, '649'),
	(377, 1, 0, -50246, 651, 0, 0, 39, '650'),
	(377, 1, 0, -50246, 652, 0, 0, 39, '651'),
	(377, 1, 0, -50246, 653, 0, 0, 39, '652'),
	(377, 1, 0, -50246, 654, 0, 0, 39, '653'),
	(377, 1, 0, -50246, 655, 0, 0, 39, '654'),
	(377, 1, 0, -50246, 656, 0, 0, 39, '655'),
	(377, 1, 0, -50246, 657, 0, 0, 39, '656'),
	(377, 1, 0, -50246, 658, 0, 0, 39, '657'),
	(377, 1, 0, -50246, 659, 0, 0, 39, '658'),
	(377, 1, 0, -50246, 660, 0, 0, 39, '659'),
	(377, 1, 0, -50246, 661, 0, 0, 39, '660'),
	(377, 1, 0, -50246, 662, 0, 0, 39, '661'),
	(377, 1, 0, -50246, 663, 0, 0, 39, '662'),
	(377, 1, 0, -50246, 664, 0, 0, 39, '663'),
	(377, 1, 0, -50246, 665, 0, 0, 39, '664'),
	(377, 1, 0, -50246, 666, 0, 0, 39, '665'),
	(377, 1, 0, -50246, 667, 0, 0, 39, '666'),
	(377, 1, 0, -50246, 668, 0, 0, 39, '667'),
	(377, 1, 0, -50246, 669, 0, 0, 39, '668'),
	(377, 1, 0, -50246, 670, 0, 0, 39, '669'),
	(377, 1, 0, -50246, 671, 0, 0, 39, '670'),
	(377, 1, 0, -50246, 672, 0, 0, 39, '671'),
	(377, 1, 0, -50246, 673, 0, 0, 39, '672'),
	(377, 1, 0, -50246, 674, 0, 0, 39, '673'),
	(377, 1, 0, -50246, 675, 0, 0, 39, '674'),
	(377, 1, 0, -50246, 676, 0, 0, 39, '675'),
	(377, 1, 0, -50246, 677, 0, 0, 39, '676'),
	(377, 1, 0, -50246, 678, 0, 0, 39, '677'),
	(377, 1, 0, -50246, 679, 0, 0, 39, '678'),
	(377, 1, 0, -50246, 680, 0, 0, 39, '679'),
	(377, 1, 0, -50246, 681, 0, 0, 39, '680'),
	(377, 1, 0, -50246, 682, 0, 0, 39, '681'),
	(377, 1, 0, -50246, 683, 0, 0, 39, '682'),
	(377, 1, 0, -50246, 684, 0, 0, 39, '683'),
	(377, 1, 0, -50246, 685, 0, 0, 39, '684'),
	(377, 1, 0, -50246, 686, 0, 0, 39, '685'),
	(377, 1, 0, -50246, 687, 0, 0, 39, '686'),
	(377, 1, 0, -50246, 688, 0, 0, 39, '687'),
	(377, 1, 0, -50246, 689, 0, 0, 39, '688'),
	(377, 1, 0, -50246, 690, 0, 0, 39, '689'),
	(377, 1, 0, -50246, 691, 0, 0, 39, '690'),
	(377, 1, 0, -50246, 692, 0, 0, 39, '691'),
	(377, 1, 0, -50246, 693, 0, 0, 39, '692'),
	(377, 1, 0, -50246, 694, 0, 0, 39, '693'),
	(377, 1, 0, -50246, 695, 0, 0, 39, '694'),
	(377, 1, 0, -50246, 696, 0, 0, 39, '695'),
	(377, 1, 0, -50246, 697, 0, 0, 39, '696'),
	(377, 1, 0, -50246, 698, 0, 0, 39, '697'),
	(377, 1, 0, -50246, 699, 0, 0, 39, '698'),
	(377, 1, 0, -50246, 700, 0, 0, 39, '699'),
	(377, 1, 0, -50246, 701, 0, 0, 39, '700'),
	(377, 1, 0, -50246, 702, 0, 0, 39, '701'),
	(377, 1, 0, -50246, 703, 0, 0, 39, '702'),
	(377, 1, 0, -50246, 704, 0, 0, 39, '703'),
	(377, 1, 0, -50246, 705, 0, 0, 39, '704'),
	(377, 1, 0, -50246, 706, 0, 0, 39, '705'),
	(377, 1, 0, -50246, 707, 0, 0, 39, '706'),
	(377, 1, 0, -50246, 708, 0, 0, 39, '707'),
	(377, 1, 0, -50246, 709, 0, 0, 39, '708'),
	(377, 1, 0, -50246, 710, 0, 0, 39, '709'),
	(377, 1, 0, -50246, 711, 0, 0, 39, '710'),
	(377, 1, 0, -50246, 712, 0, 0, 39, '711'),
	(377, 1, 0, -50246, 713, 0, 0, 39, '712'),
	(377, 1, 0, -50246, 714, 0, 0, 39, '713'),
	(377, 1, 0, -50246, 715, 0, 0, 39, '714'),
	(377, 1, 0, -50246, 716, 0, 0, 39, '715'),
	(377, 1, 0, -50246, 717, 0, 0, 39, '716'),
	(377, 1, 0, -50246, 718, 0, 0, 39, '717'),
	(377, 1, 0, -50246, 719, 0, 0, 39, '718'),
	(377, 1, 0, -50246, 720, 0, 0, 39, '719'),
	(377, 1, 0, -50246, 721, 0, 0, 39, '720'),
	(377, 1, 0, -50246, 722, 0, 0, 39, '721'),
	(377, 1, 0, -50246, 723, 0, 0, 39, '722'),
	(377, 1, 0, -50246, 724, 0, 0, 39, '723'),
	(377, 1, 0, -50246, 725, 0, 0, 39, '724'),
	(377, 1, 0, -50246, 726, 0, 0, 39, '725'),
	(377, 1, 0, -50246, 727, 0, 0, 39, '726'),
	(377, 1, 0, -50246, 728, 0, 0, 39, '727'),
	(377, 1, 0, -50246, 729, 0, 0, 39, '728'),
	(377, 1, 0, -50246, 730, 0, 0, 39, '729'),
	(377, 1, 0, -50246, 731, 0, 0, 39, '730'),
	(377, 1, 0, -50246, 732, 0, 0, 39, '731'),
	(377, 1, 0, -50246, 733, 0, 0, 39, '732'),
	(377, 1, 0, -50246, 734, 0, 0, 39, '733'),
	(377, 1, 0, -50246, 735, 0, 0, 39, '734'),
	(377, 1, 0, -50246, 736, 0, 0, 39, '735'),
	(377, 1, 0, -50246, 737, 0, 0, 39, '736'),
	(377, 1, 0, -50246, 738, 0, 0, 39, '737'),
	(377, 1, 0, -50246, 739, 0, 0, 39, '738'),
	(377, 1, 0, -50246, 740, 0, 0, 39, '739'),
	(377, 1, 0, -50246, 741, 0, 0, 39, '740'),
	(377, 1, 0, -50246, 742, 0, 0, 39, '741'),
	(377, 1, 0, -50246, 743, 0, 0, 39, '742'),
	(377, 1, 0, -50246, 744, 0, 0, 39, '743'),
	(377, 1, 0, -50246, 745, 0, 0, 39, '744'),
	(377, 1, 0, -50246, 746, 0, 0, 39, '745'),
	(377, 1, 0, -50246, 747, 0, 0, 39, '746'),
	(377, 1, 0, -50246, 748, 0, 0, 39, '747'),
	(377, 1, 0, -50246, 749, 0, 0, 39, '748'),
	(377, 1, 0, -50246, 750, 0, 0, 39, '749'),
	(377, 1, 0, -50246, 751, 0, 0, 39, '750'),
	(377, 1, 0, -50246, 752, 0, 0, 39, '751'),
	(377, 1, 0, -50246, 753, 0, 0, 39, '752'),
	(377, 1, 0, -50246, 754, 0, 0, 39, '753'),
	(377, 1, 0, -50246, 755, 0, 0, 39, '754'),
	(377, 1, 0, -50246, 756, 0, 0, 39, '755'),
	(377, 1, 0, -50246, 757, 0, 0, 39, '756'),
	(377, 1, 0, -50246, 758, 0, 0, 39, '757'),
	(377, 1, 0, -50246, 759, 0, 0, 39, '758'),
	(377, 1, 0, -50246, 760, 0, 0, 39, '759'),
	(377, 1, 0, -50246, 761, 0, 0, 39, '760'),
	(377, 1, 0, -50246, 762, 0, 0, 39, '761'),
	(377, 1, 0, -50246, 763, 0, 0, 39, '762'),
	(377, 1, 0, -50246, 764, 0, 0, 39, '763'),
	(377, 1, 0, -50246, 765, 0, 0, 39, '764'),
	(377, 1, 0, -50246, 766, 0, 0, 39, '765'),
	(377, 1, 0, -50246, 767, 0, 0, 39, '766'),
	(377, 1, 0, -50246, 768, 0, 0, 39, '767'),
	(377, 1, 0, -50246, 769, 0, 0, 39, '768'),
	(377, 1, 0, -50246, 770, 0, 0, 39, '769'),
	(377, 1, 0, -50246, 771, 0, 0, 39, '770'),
	(377, 1, 0, -50246, 772, 0, 0, 39, '771'),
	(377, 1, 0, -50246, 773, 0, 0, 39, '772'),
	(377, 1, 0, -50246, 774, 0, 0, 39, '773'),
	(377, 1, 0, -50246, 775, 0, 0, 39, '774'),
	(377, 1, 0, -50246, 776, 0, 0, 39, '775'),
	(377, 1, 0, -50246, 777, 0, 0, 39, '776'),
	(377, 1, 0, -50246, 778, 0, 0, 39, '777'),
	(377, 1, 0, -50246, 779, 0, 0, 39, '778'),
	(377, 1, 0, -50246, 780, 0, 0, 39, '779'),
	(377, 1, 0, -50246, 781, 0, 0, 39, '780'),
	(377, 1, 0, -50246, 782, 0, 0, 39, '781'),
	(377, 1, 0, -50246, 783, 0, 0, 39, '782'),
	(377, 1, 0, -50246, 784, 0, 0, 39, '783'),
	(377, 1, 0, -50246, 785, 0, 0, 39, '784'),
	(377, 1, 0, -50246, 786, 0, 0, 39, '785'),
	(377, 1, 0, -50246, 787, 0, 0, 39, '786'),
	(377, 1, 0, -50246, 788, 0, 0, 39, '787'),
	(377, 1, 0, -50246, 789, 0, 0, 39, '788'),
	(377, 1, 0, -50246, 790, 0, 0, 39, '789'),
	(377, 1, 0, -50246, 791, 0, 0, 39, '790'),
	(377, 1, 0, -50246, 792, 0, 0, 39, '791'),
	(377, 1, 0, -50246, 793, 0, 0, 39, '792'),
	(377, 1, 0, -50246, 794, 0, 0, 39, '793'),
	(377, 1, 0, -50246, 795, 0, 0, 39, '794'),
	(377, 1, 0, -50246, 796, 0, 0, 39, '795'),
	(377, 1, 0, -50246, 797, 0, 0, 39, '796'),
	(377, 1, 0, -50246, 798, 0, 0, 39, '797'),
	(377, 1, 0, -50246, 799, 0, 0, 39, '798'),
	(377, 1, 0, -50246, 800, 0, 0, 39, '799'),
	(377, 1, 0, -50246, 801, 0, 0, 39, '800'),
	(377, 1, 0, -50246, 802, 0, 0, 39, '801'),
	(377, 1, 0, -50246, 803, 0, 0, 39, '802'),
	(377, 1, 0, -50246, 804, 0, 0, 39, '803'),
	(377, 1, 0, -50246, 805, 0, 0, 39, '804'),
	(377, 1, 0, -50246, 806, 0, 0, 39, '805'),
	(377, 1, 0, -50246, 807, 0, 0, 39, '806'),
	(377, 1, 0, -50246, 808, 0, 0, 39, '807'),
	(377, 1, 0, -50246, 809, 0, 0, 39, '808'),
	(377, 1, 0, -50246, 810, 0, 0, 39, '809'),
	(377, 1, 0, -50246, 811, 0, 0, 39, '810'),
	(377, 1, 0, -50246, 812, 0, 0, 39, '811'),
	(377, 1, 0, -50246, 813, 0, 0, 39, '812'),
	(377, 1, 0, -50246, 814, 0, 0, 39, '813'),
	(377, 1, 0, -50246, 815, 0, 0, 39, '814'),
	(377, 1, 0, -50246, 816, 0, 0, 39, '815'),
	(377, 1, 0, -50246, 817, 0, 0, 39, '816'),
	(377, 1, 0, -50246, 818, 0, 0, 39, '817'),
	(377, 1, 0, -50246, 819, 0, 0, 39, '818'),
	(377, 1, 0, -50246, 820, 0, 0, 39, '819'),
	(377, 1, 0, -50246, 821, 0, 0, 39, '820'),
	(377, 1, 0, -50246, 822, 0, 0, 39, '821'),
	(377, 1, 0, -50246, 823, 0, 0, 39, '822'),
	(377, 1, 0, -50246, 824, 0, 0, 39, '823'),
	(377, 1, 0, -50246, 825, 0, 0, 39, '824'),
	(377, 1, 0, -50246, 826, 0, 0, 39, '825'),
	(377, 1, 0, -50246, 827, 0, 0, 39, '826'),
	(377, 1, 0, -50246, 828, 0, 0, 39, '827'),
	(377, 1, 0, -50246, 829, 0, 0, 39, '828'),
	(377, 1, 0, -50246, 830, 0, 0, 39, '829'),
	(377, 1, 0, -50246, 831, 0, 0, 39, '830'),
	(377, 1, 0, -50246, 832, 0, 0, 39, '831'),
	(377, 1, 0, -50246, 833, 0, 0, 39, '832'),
	(377, 1, 0, -50246, 834, 0, 0, 39, '833'),
	(377, 1, 0, -50246, 835, 0, 0, 39, '834'),
	(377, 1, 0, -50246, 836, 0, 0, 39, '835'),
	(377, 1, 0, -50246, 837, 0, 0, 39, '836'),
	(377, 1, 0, -50246, 838, 0, 0, 39, '837'),
	(377, 1, 0, -50246, 839, 0, 0, 39, '838'),
	(377, 1, 0, -50246, 840, 0, 0, 39, '839'),
	(377, 1, 0, -50246, 841, 0, 0, 39, '840'),
	(377, 1, 0, -50246, 842, 0, 0, 39, '841'),
	(377, 1, 0, -50246, 843, 0, 0, 39, '842'),
	(377, 1, 0, -50246, 844, 0, 0, 39, '843'),
	(377, 1, 0, -50246, 845, 0, 0, 39, '844'),
	(377, 1, 0, -50246, 846, 0, 0, 39, '845'),
	(377, 1, 0, -50246, 847, 0, 0, 39, '846'),
	(377, 1, 0, -50246, 848, 0, 0, 39, '847'),
	(377, 1, 0, -50246, 849, 0, 0, 39, '848'),
	(377, 1, 0, -50246, 850, 0, 0, 39, '849'),
	(377, 1, 0, -50246, 851, 0, 0, 39, '850'),
	(377, 1, 0, -50246, 852, 0, 0, 39, '851'),
	(377, 1, 0, -50246, 853, 0, 0, 39, '852'),
	(377, 1, 0, -50246, 854, 0, 0, 39, '853'),
	(377, 1, 0, -50246, 855, 0, 0, 39, '854'),
	(377, 1, 0, -50246, 856, 0, 0, 39, '855'),
	(377, 1, 0, -50246, 857, 0, 0, 39, '856'),
	(377, 1, 0, -50246, 858, 0, 0, 39, '857'),
	(377, 1, 0, -50246, 859, 0, 0, 39, '858'),
	(377, 1, 0, -50246, 860, 0, 0, 39, '859'),
	(377, 1, 0, -50246, 861, 0, 0, 39, '860'),
	(377, 1, 0, -50246, 862, 0, 0, 39, '861'),
	(377, 1, 0, -50246, 863, 0, 0, 39, '862'),
	(377, 1, 0, -50246, 864, 0, 0, 39, '863'),
	(377, 1, 0, -50246, 865, 0, 0, 39, '864'),
	(377, 1, 0, -50246, 866, 0, 0, 39, '865'),
	(377, 1, 0, -50246, 867, 0, 0, 39, '866'),
	(377, 1, 0, -50246, 868, 0, 0, 39, '867'),
	(377, 1, 0, -50246, 869, 0, 0, 39, '868'),
	(377, 1, 0, -50246, 870, 0, 0, 39, '869'),
	(377, 1, 0, -50246, 871, 0, 0, 39, '870'),
	(377, 1, 0, -50246, 872, 0, 0, 39, '871'),
	(377, 1, 0, -50246, 873, 0, 0, 39, '872'),
	(377, 1, 0, -50246, 874, 0, 0, 39, '873'),
	(377, 1, 0, -50246, 875, 0, 0, 39, '874'),
	(377, 1, 0, -50246, 876, 0, 0, 39, '875'),
	(377, 1, 0, -50246, 877, 0, 0, 39, '876'),
	(377, 1, 0, -50246, 878, 0, 0, 39, '877'),
	(377, 1, 0, -50246, 879, 0, 0, 39, '878'),
	(377, 1, 0, -50246, 880, 0, 0, 39, '879'),
	(377, 1, 0, -50246, 881, 0, 0, 39, '880'),
	(377, 1, 0, -50246, 882, 0, 0, 39, '881'),
	(377, 1, 0, -50246, 883, 0, 0, 39, '882'),
	(377, 1, 0, -50246, 884, 0, 0, 39, '883'),
	(377, 1, 0, -50246, 885, 0, 0, 39, '884'),
	(377, 1, 0, -50246, 886, 0, 0, 39, '885'),
	(377, 1, 0, -50246, 887, 0, 0, 39, '886'),
	(377, 1, 0, -50246, 888, 0, 0, 39, '887'),
	(377, 1, 0, -50246, 889, 0, 0, 39, '888'),
	(377, 1, 0, -50246, 890, 0, 0, 39, '889'),
	(377, 1, 0, -50246, 891, 0, 0, 39, '890'),
	(377, 1, 0, -50246, 892, 0, 0, 39, '891'),
	(377, 1, 0, -50246, 893, 0, 0, 39, '892'),
	(377, 1, 0, -50246, 894, 0, 0, 39, '893'),
	(377, 1, 0, -50246, 895, 0, 0, 39, '894'),
	(377, 1, 0, -50246, 896, 0, 0, 39, '895'),
	(377, 1, 0, -50246, 897, 0, 0, 39, '896'),
	(377, 1, 0, -50246, 898, 0, 0, 39, '897'),
	(377, 1, 0, -50246, 899, 0, 0, 39, '898'),
	(377, 1, 0, -50246, 900, 0, 0, 39, '899'),
	(377, 1, 0, -50246, 901, 0, 0, 39, '900'),
	(377, 1, 0, -50246, 902, 0, 0, 39, '901'),
	(377, 1, 0, -50246, 903, 0, 0, 39, '902'),
	(377, 1, 0, -50246, 904, 0, 0, 39, '903'),
	(377, 1, 0, -50246, 905, 0, 0, 39, '904'),
	(377, 1, 0, -50246, 906, 0, 0, 39, '905'),
	(377, 1, 0, -50246, 907, 0, 0, 39, '906'),
	(377, 1, 0, -50246, 908, 0, 0, 39, '907'),
	(377, 1, 0, -50246, 909, 0, 0, 39, '908'),
	(377, 1, 0, -50246, 910, 0, 0, 39, '909'),
	(377, 1, 0, -50246, 911, 0, 0, 39, '910'),
	(377, 1, 0, -50246, 912, 0, 0, 39, '911'),
	(377, 1, 0, -50246, 913, 0, 0, 39, '912'),
	(377, 1, 0, -50246, 914, 0, 0, 39, '913'),
	(377, 1, 0, -50246, 915, 0, 0, 39, '914'),
	(377, 1, 0, -50246, 916, 0, 0, 39, '915'),
	(377, 1, 0, -50246, 917, 0, 0, 39, '916'),
	(377, 1, 0, -50246, 918, 0, 0, 39, '917'),
	(377, 1, 0, -50246, 919, 0, 0, 39, '918'),
	(377, 1, 0, -50246, 920, 0, 0, 39, '919'),
	(377, 1, 0, -50246, 921, 0, 0, 39, '920'),
	(377, 1, 0, -50246, 922, 0, 0, 39, '921'),
	(377, 1, 0, -50246, 923, 0, 0, 39, '922'),
	(377, 1, 0, -50246, 924, 0, 0, 39, '923'),
	(377, 1, 0, -50246, 925, 0, 0, 39, '924'),
	(377, 1, 0, -50246, 926, 0, 0, 39, '925'),
	(377, 1, 0, -50246, 927, 0, 0, 39, '926'),
	(377, 1, 0, -50246, 928, 0, 0, 39, '927'),
	(377, 1, 0, -50246, 929, 0, 0, 39, '928'),
	(377, 1, 0, -50246, 930, 0, 0, 39, '929'),
	(377, 1, 0, -50246, 931, 0, 0, 39, '930'),
	(377, 1, 0, -50246, 932, 0, 0, 39, '931'),
	(377, 1, 0, -50246, 933, 0, 0, 39, '932'),
	(377, 1, 0, -50246, 934, 0, 0, 39, '933'),
	(377, 1, 0, -50246, 935, 0, 0, 39, '934'),
	(377, 1, 0, -50246, 936, 0, 0, 39, '935'),
	(377, 1, 0, -50246, 937, 0, 0, 39, '936'),
	(377, 1, 0, -50246, 938, 0, 0, 39, '937'),
	(377, 1, 0, -50246, 939, 0, 0, 39, '938'),
	(377, 1, 0, -50246, 940, 0, 0, 39, '939'),
	(377, 1, 0, -50246, 941, 0, 0, 39, '940'),
	(377, 1, 0, -50246, 942, 0, 0, 39, '941'),
	(377, 1, 0, -50246, 943, 0, 0, 39, '942'),
	(377, 1, 0, -50246, 944, 0, 0, 39, '943'),
	(377, 1, 0, -50246, 945, 0, 0, 39, '944'),
	(377, 1, 0, -50246, 946, 0, 0, 39, '945'),
	(377, 1, 0, -50246, 947, 0, 0, 39, '946'),
	(377, 1, 0, -50246, 948, 0, 0, 39, '947'),
	(377, 1, 0, -50246, 949, 0, 0, 39, '948'),
	(377, 1, 0, -50246, 950, 0, 0, 39, '949'),
	(377, 1, 0, -50246, 951, 0, 0, 39, '950'),
	(377, 1, 0, -50246, 952, 0, 0, 39, '951'),
	(377, 1, 0, -50246, 953, 0, 0, 39, '952'),
	(377, 1, 0, -50246, 954, 0, 0, 39, '953'),
	(377, 1, 0, -50246, 955, 0, 0, 39, '954'),
	(377, 1, 0, -50246, 956, 0, 0, 39, '955'),
	(377, 1, 0, -50246, 957, 0, 0, 39, '956'),
	(377, 1, 0, -50246, 958, 0, 0, 39, '957'),
	(377, 1, 0, -50246, 959, 0, 0, 39, '958'),
	(377, 1, 0, -50246, 960, 0, 0, 39, '959'),
	(377, 1, 0, -50246, 961, 0, 0, 39, '960'),
	(377, 1, 0, -50246, 962, 0, 0, 39, '961'),
	(377, 1, 0, -50246, 963, 0, 0, 39, '962'),
	(377, 1, 0, -50246, 964, 0, 0, 39, '963'),
	(377, 1, 0, -50246, 965, 0, 0, 39, '964'),
	(377, 1, 0, -50246, 966, 0, 0, 39, '965'),
	(377, 1, 0, -50246, 967, 0, 0, 39, '966'),
	(377, 1, 0, -50246, 968, 0, 0, 39, '967'),
	(377, 1, 0, -50246, 969, 0, 0, 39, '968'),
	(377, 1, 0, -50246, 970, 0, 0, 39, '969'),
	(377, 1, 0, -50246, 971, 0, 0, 39, '970'),
	(377, 1, 0, -50246, 972, 0, 0, 39, '971'),
	(377, 1, 0, -50246, 973, 0, 0, 39, '972'),
	(377, 1, 0, -50246, 974, 0, 0, 39, '973'),
	(377, 1, 0, -50246, 975, 0, 0, 39, '974'),
	(377, 1, 0, -50246, 976, 0, 0, 39, '975'),
	(377, 1, 0, -50246, 977, 0, 0, 39, '976'),
	(377, 1, 0, -50246, 978, 0, 0, 39, '977'),
	(377, 1, 0, -50246, 979, 0, 0, 39, '978'),
	(377, 1, 0, -50246, 980, 0, 0, 39, '979'),
	(377, 1, 0, -50246, 981, 0, 0, 39, '980'),
	(377, 1, 0, -50246, 982, 0, 0, 39, '981'),
	(377, 1, 0, -50246, 983, 0, 0, 39, '982'),
	(377, 1, 0, -50246, 984, 0, 0, 39, '983'),
	(377, 1, 0, -50246, 985, 0, 0, 39, '984'),
	(377, 1, 0, -50246, 986, 0, 0, 39, '985'),
	(377, 1, 0, -50246, 987, 0, 0, 39, '986'),
	(377, 1, 0, -50246, 988, 0, 0, 39, '987'),
	(377, 1, 0, -50246, 989, 0, 0, 39, '988'),
	(377, 1, 0, -50246, 990, 0, 0, 39, '989'),
	(377, 1, 0, -50246, 991, 0, 0, 39, '990'),
	(377, 1, 0, -50246, 992, 0, 0, 39, '991'),
	(377, 1, 0, -50246, 993, 0, 0, 39, '992'),
	(377, 1, 0, -50246, 994, 0, 0, 39, '993'),
	(377, 1, 0, -50246, 995, 0, 0, 39, '994'),
	(377, 1, 0, -50246, 996, 0, 0, 39, '995'),
	(377, 1, 0, -50246, 997, 0, 0, 39, '996'),
	(377, 1, 0, -50246, 998, 0, 0, 39, '997'),
	(377, 1, 0, -50246, 999, 0, 0, 39, '998'),
	(377, 1, 0, -50246, 1000, 0, 0, 39, '999'),
	(377, 1, 0, -50246, 1001, 0, 0, 39, '1000'),
	(377, 1, 0, -50246, 1002, 0, 0, 39, '1001'),
	(377, 1, 0, -50246, 1003, 0, 0, 39, '1002'),
	(377, 1, 0, -50246, 1004, 0, 0, 39, '1003'),
	(377, 1, 0, -50246, 1005, 0, 0, 39, '1004'),
	(377, 1, 0, -50246, 1006, 0, 0, 39, '1005'),
	(377, 1, 0, -50246, 1007, 0, 0, 39, '1006'),
	(377, 1, 0, -50246, 1008, 0, 0, 39, '1007'),
	(377, 1, 0, -50246, 1009, 0, 0, 39, '1008'),
	(377, 1, 0, -50246, 1010, 0, 0, 39, '1009'),
	(377, 1, 0, -50246, 1011, 0, 0, 39, '1010'),
	(377, 1, 0, -50246, 1012, 0, 0, 39, '1011'),
	(377, 1, 0, -50246, 1013, 0, 0, 39, '1012'),
	(377, 1, 0, -50246, 1014, 0, 0, 39, '1013'),
	(377, 1, 0, -50246, 1015, 0, 0, 39, '1014'),
	(377, 1, 0, -50246, 1016, 0, 0, 39, '1015'),
	(377, 1, 0, -50246, 1017, 0, 0, 39, '1016'),
	(377, 1, 0, -50246, 1018, 0, 0, 39, '1017'),
	(377, 1, 0, -50246, 1019, 0, 0, 39, '1018'),
	(377, 1, 0, -50246, 1020, 0, 0, 39, '1019'),
	(377, 1, 0, -50246, 1021, 0, 0, 39, '1020'),
	(377, 1, 0, -50246, 1022, 0, 0, 39, '1021'),
	(377, 1, 0, -50246, 1023, 0, 0, 39, '1022'),
	(377, 1, 0, -50246, 1024, 0, 0, 39, '1023'),
	(377, 1, 0, -50246, 1025, 0, 0, 39, '1024'),
	(377, 1, 0, -50246, 1026, 0, 0, 39, '1025'),
	(377, 1, 0, -50246, 1027, 0, 0, 39, '1026'),
	(377, 1, 0, -50246, 1028, 0, 0, 39, '1027'),
	(377, 1, 0, -50246, 1029, 0, 0, 39, '1028'),
	(377, 1, 0, -50246, 1030, 0, 0, 39, '1029'),
	(377, 1, 0, -50246, 1031, 0, 0, 39, '1030'),
	(377, 1, 0, -50246, 1032, 0, 0, 39, '1031'),
	(377, 1, 0, -50246, 1033, 0, 0, 39, '1032'),
	(377, 1, 0, -50246, 1034, 0, 0, 39, '1033'),
	(377, 1, 0, -50246, 1035, 0, 0, 39, '1034'),
	(377, 1, 0, -50246, 1036, 0, 0, 39, '1035'),
	(377, 1, 0, -50246, 1037, 0, 0, 39, '1036'),
	(377, 1, 0, -50246, 1038, 0, 0, 39, '1037'),
	(377, 1, 0, -50246, 1039, 0, 0, 39, '1038'),
	(377, 1, 0, -50246, 1040, 0, 0, 39, '1039'),
	(377, 1, 0, -50246, 1041, 0, 0, 39, '1040'),
	(377, 1, 0, -50246, 1042, 0, 0, 39, '1041'),
	(377, 1, 0, -50246, 1043, 0, 0, 39, '1042'),
	(377, 1, 0, -50246, 1044, 0, 0, 39, '1043'),
	(377, 1, 0, -50246, 1045, 0, 0, 39, '1044'),
	(377, 1, 0, -50246, 1046, 0, 0, 39, '1045'),
	(377, 1, 0, -50246, 1047, 0, 0, 39, '1046'),
	(377, 1, 0, -50246, 1048, 0, 0, 39, '1047'),
	(377, 1, 0, -50246, 1049, 0, 0, 39, '1048'),
	(377, 1, 0, -50246, 1050, 0, 0, 39, '1049'),
	(377, 1, 0, -50246, 1051, 0, 0, 39, '1050'),
	(377, 1, 0, -50246, 1052, 0, 0, 39, '1051'),
	(377, 1, 0, -50246, 1053, 0, 0, 39, '1052'),
	(377, 1, 0, -50246, 1054, 0, 0, 39, '1053'),
	(377, 1, 0, -50246, 1055, 0, 0, 39, '1054'),
	(377, 1, 0, -50246, 1056, 0, 0, 39, '1055'),
	(377, 1, 0, -50246, 1057, 0, 0, 39, '1056'),
	(377, 1, 0, -50246, 1058, 0, 0, 39, '1057'),
	(377, 1, 0, -50246, 1059, 0, 0, 39, '1058'),
	(377, 1, 0, -50246, 1060, 0, 0, 39, '1059'),
	(377, 1, 0, -50246, 1061, 0, 0, 39, '1060'),
	(377, 1, 0, -50246, 1062, 0, 0, 39, '1061'),
	(377, 1, 0, -50246, 1063, 0, 0, 39, '1062'),
	(377, 1, 0, -50246, 1064, 0, 0, 39, '1063'),
	(377, 1, 0, -50246, 1065, 0, 0, 39, '1064'),
	(377, 1, 0, -50246, 1066, 0, 0, 39, '1065'),
	(377, 1, 0, -50246, 1067, 0, 0, 39, '1066'),
	(377, 1, 0, -50246, 1068, 0, 0, 39, '1067'),
	(377, 1, 0, -50246, 1069, 0, 0, 39, '1068'),
	(377, 1, 0, -50246, 1070, 0, 0, 39, '1069'),
	(377, 1, 0, -50246, 1071, 0, 0, 39, '1070'),
	(377, 1, 0, -50246, 1072, 0, 0, 39, '1071'),
	(377, 1, 0, -50246, 1073, 0, 0, 39, '1072'),
	(377, 1, 0, -50246, 1074, 0, 0, 39, '1073'),
	(377, 1, 0, -50246, 1075, 0, 0, 39, '1074'),
	(377, 1, 0, -50246, 1076, 0, 0, 39, '1075'),
	(377, 1, 0, -50246, 1077, 0, 0, 39, '1076'),
	(377, 1, 0, -50246, 1078, 0, 0, 39, '1077'),
	(377, 1, 0, -50246, 1079, 0, 0, 39, '1078'),
	(377, 1, 0, -50246, 1080, 0, 0, 39, '1079'),
	(377, 1, 0, -50246, 1081, 0, 0, 39, '1080'),
	(377, 1, 0, -50246, 1082, 0, 0, 39, '1081'),
	(377, 1, 0, -50246, 1083, 0, 0, 39, '1082'),
	(377, 1, 0, -50246, 1084, 0, 0, 39, '1083'),
	(377, 1, 0, -50246, 1085, 0, 0, 39, '1084'),
	(377, 1, 0, -50246, 1086, 0, 0, 39, '1085'),
	(377, 1, 0, -50246, 1087, 0, 0, 39, '1086'),
	(377, 1, 0, -50246, 1088, 0, 0, 39, '1087'),
	(377, 1, 0, -50246, 1089, 0, 0, 39, '1088'),
	(377, 1, 0, -50246, 1090, 0, 0, 39, '1089'),
	(377, 1, 0, -50246, 1091, 0, 0, 39, '1090'),
	(377, 1, 0, -50246, 1092, 0, 0, 39, '1091'),
	(377, 1, 0, -50246, 1093, 0, 0, 39, '1092'),
	(377, 1, 0, -50246, 1094, 0, 0, 39, '1093'),
	(377, 1, 0, -50246, 1095, 0, 0, 39, '1094'),
	(377, 1, 0, -50246, 1096, 0, 0, 39, '1095'),
	(377, 1, 0, -50246, 1097, 0, 0, 39, '1096'),
	(377, 1, 0, -50246, 1098, 0, 0, 39, '1097'),
	(377, 1, 0, -50246, 1099, 0, 0, 39, '1098'),
	(377, 1, 0, -50246, 1100, 0, 0, 39, '1099'),
	(377, 1, 0, -50246, 1101, 0, 0, 39, '1100'),
	(377, 1, 0, -50246, 1102, 0, 0, 39, '1101'),
	(377, 1, 0, -50246, 1103, 0, 0, 39, '1102'),
	(377, 1, 0, -50246, 1104, 0, 0, 39, '1103'),
	(377, 1, 0, -50246, 1105, 0, 0, 39, '1104'),
	(377, 1, 0, -50246, 1106, 0, 0, 39, '1105'),
	(377, 1, 0, -50246, 1107, 0, 0, 39, '1106'),
	(377, 1, 0, -50246, 1108, 0, 0, 39, '1107'),
	(377, 1, 0, -50246, 1109, 0, 0, 39, '1108'),
	(377, 1, 0, -50246, 1110, 0, 0, 39, '1109'),
	(377, 1, 0, -50246, 1111, 0, 0, 39, '1110'),
	(377, 1, 0, -50246, 1112, 0, 0, 39, '1111'),
	(377, 1, 0, -50246, 1113, 0, 0, 39, '1112'),
	(377, 1, 0, -50246, 1114, 0, 0, 39, '1113'),
	(377, 1, 0, -50246, 1115, 0, 0, 39, '1114'),
	(377, 1, 0, -50246, 1116, 0, 0, 39, '1115'),
	(377, 1, 0, -50246, 1117, 0, 0, 39, '1116'),
	(377, 1, 0, -50246, 1118, 0, 0, 39, '1117'),
	(377, 1, 0, -50246, 1119, 0, 0, 39, '1118'),
	(377, 1, 0, -50246, 1120, 0, 0, 39, '1119'),
	(377, 1, 0, -50246, 1121, 0, 0, 39, '1120'),
	(377, 1, 0, -50246, 1122, 0, 0, 39, '1121'),
	(377, 1, 0, -50246, 1123, 0, 0, 39, '1122'),
	(377, 1, 0, -50246, 1124, 0, 0, 39, '1123'),
	(377, 1, 0, -50246, 1125, 0, 0, 39, '1124'),
	(377, 1, 0, -50246, 1126, 0, 0, 39, '1125'),
	(377, 1, 0, -50246, 1127, 0, 0, 39, '1126'),
	(377, 1, 0, -50246, 1128, 0, 0, 39, '1127'),
	(377, 1, 0, -50246, 1129, 0, 0, 39, '1128'),
	(377, 1, 0, -50246, 1130, 0, 0, 39, '1129'),
	(377, 1, 0, -50246, 1131, 0, 0, 39, '1130'),
	(377, 1, 0, -50246, 1132, 0, 0, 39, '1131'),
	(377, 1, 0, -50246, 1133, 0, 0, 39, '1132'),
	(377, 1, 0, -50246, 1134, 0, 0, 39, '1133'),
	(377, 1, 0, -50246, 1135, 0, 0, 39, '1134'),
	(377, 1, 0, -50246, 1136, 0, 0, 39, '1135'),
	(377, 1, 0, -50246, 1137, 0, 0, 39, '1136'),
	(377, 1, 0, -50246, 1138, 0, 0, 39, '1137'),
	(377, 1, 0, -50246, 1139, 0, 0, 39, '1138'),
	(377, 1, 0, -50246, 1140, 0, 0, 39, '1139'),
	(377, 1, 0, -50246, 1141, 0, 0, 39, '1140'),
	(377, 1, 0, -50246, 1142, 0, 0, 39, '1141'),
	(377, 1, 0, -50246, 1143, 0, 0, 39, '1142'),
	(377, 1, 0, -50246, 1144, 0, 0, 39, '1143'),
	(377, 1, 0, -50246, 1145, 0, 0, 39, '1144'),
	(377, 1, 0, -50246, 1146, 0, 0, 39, '1145'),
	(377, 1, 0, -50246, 1147, 0, 0, 39, '1146'),
	(377, 1, 0, -50246, 1148, 0, 0, 39, '1147'),
	(377, 1, 0, -50246, 1149, 0, 0, 39, '1148'),
	(377, 1, 0, -50246, 1150, 0, 0, 39, '1149'),
	(377, 1, 0, -50246, 1151, 0, 0, 39, '1150'),
	(377, 1, 0, -50246, 1152, 0, 0, 39, '1151'),
	(377, 1, 0, -50246, 1153, 0, 0, 39, '1152'),
	(377, 1, 0, -50246, 1154, 0, 0, 39, '1153'),
	(377, 1, 0, -50246, 1155, 0, 0, 39, '1154'),
	(377, 1, 0, -50246, 1156, 0, 0, 39, '1155'),
	(377, 1, 0, -50246, 1157, 0, 0, 39, '1156'),
	(377, 1, 0, -50246, 1158, 0, 0, 39, '1157'),
	(377, 1, 0, -50246, 1159, 0, 0, 39, '1158'),
	(377, 1, 0, -50246, 1160, 0, 0, 39, '1159'),
	(377, 1, 0, -50246, 1161, 0, 0, 39, '1160'),
	(377, 1, 0, -50246, 1162, 0, 0, 39, '1161'),
	(377, 1, 0, -50246, 1163, 0, 0, 39, '1162'),
	(377, 1, 0, -50246, 1164, 0, 0, 39, '1163'),
	(377, 1, 0, -50246, 1165, 0, 0, 39, '1164'),
	(377, 1, 0, -50246, 1166, 0, 0, 39, '1165'),
	(377, 1, 0, -50246, 1167, 0, 0, 39, '1166'),
	(377, 1, 0, -50246, 1168, 0, 0, 39, '1167'),
	(377, 1, 0, -50246, 1169, 0, 0, 39, '1168'),
	(377, 1, 0, -50246, 1170, 0, 0, 39, '1169'),
	(377, 1, 0, -50246, 1171, 0, 0, 39, '1170'),
	(377, 1, 0, -50246, 1172, 0, 0, 39, '1171'),
	(377, 1, 0, -50246, 1173, 0, 0, 39, '1172'),
	(377, 1, 0, -50246, 1174, 0, 0, 39, '1173'),
	(377, 1, 0, -50246, 1175, 0, 0, 39, '1174'),
	(377, 1, 0, -50246, 1176, 0, 0, 39, '1175'),
	(377, 1, 0, -50246, 1177, 0, 0, 39, '1176'),
	(377, 1, 0, -50246, 1178, 0, 0, 39, '1177'),
	(377, 1, 0, -50246, 1179, 0, 0, 39, '1178'),
	(377, 1, 0, -50246, 1180, 0, 0, 39, '1179'),
	(377, 1, 0, -50246, 1181, 0, 0, 39, '1180'),
	(377, 1, 0, -50246, 1182, 0, 0, 39, '1181'),
	(377, 1, 0, -50246, 1183, 0, 0, 39, '1182'),
	(377, 1, 0, -50246, 1184, 0, 0, 39, '1183'),
	(377, 1, 0, -50246, 1185, 0, 0, 39, '1184'),
	(377, 1, 0, -50246, 1186, 0, 0, 39, '1185'),
	(377, 1, 0, -50246, 1187, 0, 0, 39, '1186'),
	(377, 1, 0, -50246, 1188, 0, 0, 39, '1187'),
	(377, 1, 0, -50246, 1189, 0, 0, 39, '1188'),
	(377, 1, 0, -50246, 1190, 0, 0, 39, '1189'),
	(377, 1, 0, -50246, 1191, 0, 0, 39, '1190'),
	(377, 1, 0, -50246, 1192, 0, 0, 39, '1191'),
	(377, 1, 0, -50246, 1193, 0, 0, 39, '1192'),
	(377, 1, 0, -50246, 1194, 0, 0, 39, '1193'),
	(377, 1, 0, -50246, 1195, 0, 0, 39, '1194'),
	(377, 1, 0, -50246, 1196, 0, 0, 39, '1195'),
	(377, 1, 0, -50246, 1197, 0, 0, 39, '1196'),
	(377, 1, 0, -50246, 1198, 0, 0, 39, '1197'),
	(377, 1, 0, -50246, 1199, 0, 0, 39, '1198'),
	(377, 1, 0, -50246, 1200, 0, 0, 39, '1199'),
	(377, 1, 0, -50246, 1201, 0, 0, 39, '1200'),
	(377, 1, 0, -50246, 1202, 0, 0, 39, '1201'),
	(377, 1, 0, -50246, 1203, 0, 0, 39, '1202'),
	(377, 1, 0, -50246, 1204, 0, 0, 39, '1203'),
	(377, 1, 0, -50246, 1205, 0, 0, 39, '1204'),
	(377, 1, 0, -50246, 1206, 0, 0, 39, '1205'),
	(377, 1, 0, -50246, 1207, 0, 0, 39, '1206'),
	(377, 1, 0, -50246, 1208, 0, 0, 39, '1207'),
	(377, 1, 0, -50246, 1209, 0, 0, 39, '1208'),
	(377, 1, 0, -50246, 1210, 0, 0, 39, '1209'),
	(377, 1, 0, -50246, 1211, 0, 0, 39, '1210'),
	(377, 1, 0, -50246, 1212, 0, 0, 39, '1211'),
	(377, 1, 0, -50246, 1213, 0, 0, 39, '1212'),
	(377, 1, 0, -50246, 1214, 0, 0, 39, '1213'),
	(377, 1, 0, -50246, 1215, 0, 0, 39, '1214'),
	(377, 1, 0, -50246, 1216, 0, 0, 39, '1215'),
	(377, 1, 0, -50246, 1217, 0, 0, 39, '1216'),
	(377, 1, 0, -50246, 1218, 0, 0, 39, '1217'),
	(377, 1, 0, -50246, 1219, 0, 0, 39, '1218'),
	(377, 1, 0, -50246, 1220, 0, 0, 39, '1219'),
	(377, 1, 0, -50246, 1221, 0, 0, 39, '1220'),
	(377, 1, 0, -50246, 1222, 0, 0, 39, '1221'),
	(377, 1, 0, -50246, 1223, 0, 0, 39, '1222'),
	(377, 1, 0, -50246, 1224, 0, 0, 39, '1223'),
	(377, 1, 0, -50246, 1225, 0, 0, 39, '1224'),
	(377, 1, 0, -50246, 1226, 0, 0, 39, '1225'),
	(377, 1, 0, -50246, 1227, 0, 0, 39, '1226'),
	(377, 1, 0, -50246, 1228, 0, 0, 39, '1227'),
	(377, 1, 0, -50246, 1229, 0, 0, 39, '1228'),
	(377, 1, 0, -50246, 1230, 0, 0, 39, '1229'),
	(377, 1, 0, -50246, 1231, 0, 0, 39, '1230'),
	(377, 1, 0, -50246, 1232, 0, 0, 39, '1231'),
	(377, 1, 0, -50246, 1233, 0, 0, 39, '1232'),
	(377, 1, 0, -50246, 1234, 0, 0, 39, '1233'),
	(377, 1, 0, -50246, 1235, 0, 0, 39, '1234'),
	(377, 1, 0, -50246, 1236, 0, 0, 39, '1235'),
	(377, 1, 0, -50246, 1237, 0, 0, 39, '1236'),
	(377, 1, 0, -50246, 1238, 0, 0, 39, '1237'),
	(377, 1, 0, -50246, 1239, 0, 0, 39, '1238'),
	(377, 1, 0, -50246, 1240, 0, 0, 39, '1239'),
	(377, 1, 0, -50246, 1241, 0, 0, 39, '1240'),
	(377, 1, 0, -50246, 1242, 0, 0, 39, '1241'),
	(377, 1, 0, -50246, 1243, 0, 0, 39, '1242'),
	(377, 1, 0, -50246, 1244, 0, 0, 39, '1243'),
	(377, 1, 0, -50246, 1245, 0, 0, 39, '1244'),
	(377, 1, 0, -50246, 1246, 0, 0, 39, '1245'),
	(377, 1, 0, -50246, 1247, 0, 0, 39, '1246'),
	(377, 1, 0, -50246, 1248, 0, 0, 39, '1247'),
	(377, 1, 0, -50246, 1249, 0, 0, 39, '1248'),
	(377, 1, 0, -50246, 1250, 0, 0, 39, '1249'),
	(377, 1, 0, -50246, 1251, 0, 0, 39, '1250'),
	(377, 1, 0, -50246, 1252, 0, 0, 39, '1251'),
	(377, 1, 0, -50246, 1253, 0, 0, 39, '1252'),
	(377, 1, 0, -50246, 1254, 0, 0, 39, '1253'),
	(377, 1, 0, -50246, 1255, 0, 0, 39, '1254'),
	(377, 1, 0, -50246, 1256, 0, 0, 39, '1255'),
	(377, 1, 0, -50246, 1257, 0, 0, 39, '1256'),
	(377, 1, 0, -50246, 1258, 0, 0, 39, '1257'),
	(377, 1, 0, -50246, 1259, 0, 0, 39, '1258'),
	(377, 1, 0, -50246, 1260, 0, 0, 39, '1259'),
	(377, 1, 0, -50246, 1261, 0, 0, 39, '1260'),
	(377, 1, 0, -50246, 1262, 0, 0, 39, '1261'),
	(377, 1, 0, -50246, 1263, 0, 0, 39, '1262'),
	(377, 1, 0, -50246, 1264, 0, 0, 39, '1263'),
	(377, 1, 0, -50246, 1265, 0, 0, 39, '1264'),
	(377, 1, 0, -50246, 1266, 0, 0, 39, '1265'),
	(377, 1, 0, -50246, 1267, 0, 0, 39, '1266'),
	(377, 1, 0, -50246, 1268, 0, 0, 39, '1267'),
	(377, 1, 0, -50246, 1269, 0, 0, 39, '1268'),
	(377, 1, 0, -50246, 1270, 0, 0, 39, '1269'),
	(377, 1, 0, -50246, 1271, 0, 0, 39, '1270'),
	(377, 1, 0, -50246, 1272, 0, 0, 39, '1271'),
	(377, 1, 0, -50246, 1273, 0, 0, 39, '1272'),
	(377, 1, 0, -50246, 1274, 0, 0, 39, '1273'),
	(377, 1, 0, -50246, 1275, 0, 0, 39, '1274'),
	(377, 1, 0, -50246, 1276, 0, 0, 39, '1275'),
	(377, 1, 0, -50246, 1277, 0, 0, 39, '1276'),
	(377, 1, 0, -50246, 1278, 0, 0, 39, '1277'),
	(377, 1, 0, -50246, 1279, 0, 0, 39, '1278'),
	(377, 1, 0, -50246, 1280, 0, 0, 39, '1279'),
	(377, 1, 0, -50246, 1281, 0, 0, 39, '1280'),
	(377, 1, 0, -50246, 1282, 0, 0, 39, '1281'),
	(377, 1, 0, -50246, 1283, 0, 0, 39, '1282'),
	(377, 1, 0, -50246, 1284, 0, 0, 39, '1283'),
	(377, 1, 0, -50246, 1285, 0, 0, 39, '1284'),
	(377, 1, 0, -50246, 1286, 0, 0, 39, '1285'),
	(377, 1, 0, -50246, 1287, 0, 0, 39, '1286'),
	(377, 1, 0, -50246, 1288, 0, 0, 39, '1287'),
	(377, 1, 0, -50246, 1289, 0, 0, 39, '1288'),
	(377, 1, 0, -50246, 1290, 0, 0, 39, '1289'),
	(377, 1, 0, -50246, 1291, 0, 0, 39, '1290'),
	(377, 1, 0, -50246, 1292, 0, 0, 39, '1291'),
	(377, 1, 0, -50246, 1293, 0, 0, 39, '1292'),
	(377, 1, 0, -50246, 1294, 0, 0, 39, '1293'),
	(377, 1, 0, -50246, 1295, 0, 0, 39, '1294'),
	(377, 1, 0, -50246, 1296, 0, 0, 39, '1295'),
	(377, 1, 0, -50246, 1297, 0, 0, 39, '1296'),
	(377, 1, 0, -50246, 1298, 0, 0, 39, '1297'),
	(377, 1, 0, -50246, 1299, 0, 0, 39, '1298'),
	(377, 1, 0, -50246, 1300, 0, 0, 39, '1299'),
	(377, 1, 0, -50246, 1301, 0, 0, 39, '1300'),
	(377, 1, 0, -50246, 1302, 0, 0, 39, '1301'),
	(377, 1, 0, -50246, 1303, 0, 0, 39, '1302'),
	(377, 1, 0, -50246, 1304, 0, 0, 39, '1303'),
	(377, 1, 0, -50246, 1305, 0, 0, 39, '1304'),
	(377, 1, 0, -50246, 1306, 0, 0, 39, '1305'),
	(377, 1, 0, -50246, 1307, 0, 0, 39, '1306'),
	(377, 1, 0, -50246, 1308, 0, 0, 39, '1307'),
	(377, 1, 0, -50246, 1309, 0, 0, 39, '1308'),
	(377, 1, 0, -50246, 1310, 0, 0, 39, '1309'),
	(377, 1, 0, -50246, 1311, 0, 0, 39, '1310'),
	(377, 1, 0, -50246, 1312, 0, 0, 39, '1311'),
	(377, 1, 0, -50246, 1313, 0, 0, 39, '1312'),
	(377, 1, 0, -50246, 1314, 0, 0, 39, '1313'),
	(377, 1, 0, -50246, 1315, 0, 0, 39, '1314'),
	(377, 1, 0, -50246, 1316, 0, 0, 39, '1315'),
	(377, 1, 0, -50246, 1317, 0, 0, 39, '1316'),
	(377, 1, 0, -50246, 1318, 0, 0, 39, '1317'),
	(377, 1, 0, -50246, 1319, 0, 0, 39, '1318'),
	(377, 1, 0, -50246, 1320, 0, 0, 39, '1319'),
	(377, 1, 0, -50246, 1321, 0, 0, 39, '1320'),
	(377, 1, 0, -50246, 1322, 0, 0, 39, '1321'),
	(377, 1, 0, -50246, 1323, 0, 0, 39, '1322'),
	(377, 1, 0, -50246, 1324, 0, 0, 39, '1323'),
	(377, 1, 0, -50246, 1325, 0, 0, 39, '1324'),
	(377, 1, 0, -50246, 1326, 0, 0, 39, '1325'),
	(377, 1, 0, -50246, 1327, 0, 0, 39, '1326'),
	(377, 1, 0, -50246, 1328, 0, 0, 39, '1327'),
	(377, 1, 0, -50246, 1329, 0, 0, 39, '1328'),
	(377, 1, 0, -50246, 1330, 0, 0, 39, '1329'),
	(377, 1, 0, -50246, 1331, 0, 0, 39, '1330'),
	(377, 1, 0, -50246, 1332, 0, 0, 39, '1331'),
	(377, 1, 0, -50246, 1333, 0, 0, 39, '1332'),
	(377, 1, 0, -50246, 1334, 0, 0, 39, '1333'),
	(377, 1, 0, -50246, 1335, 0, 0, 39, '1334'),
	(377, 1, 0, -50246, 1336, 0, 0, 39, '1335'),
	(377, 1, 0, -50246, 1337, 0, 0, 39, '1336'),
	(377, 1, 0, -50246, 1338, 0, 0, 39, '1337'),
	(377, 1, 0, -50246, 1339, 0, 0, 39, '1338'),
	(377, 1, 0, -50246, 1340, 0, 0, 39, '1339'),
	(377, 1, 0, -50246, 1341, 0, 0, 39, '1340'),
	(377, 1, 0, -50246, 1342, 0, 0, 39, '1341'),
	(377, 1, 0, -50246, 1343, 0, 0, 39, '1342'),
	(377, 1, 0, -50246, 1344, 0, 0, 39, '1343'),
	(377, 1, 0, -50246, 1345, 0, 0, 39, '1344'),
	(377, 1, 0, -50246, 1346, 0, 0, 39, '1345'),
	(377, 1, 0, -50246, 1347, 0, 0, 39, '1346'),
	(377, 1, 0, -50246, 1348, 0, 0, 39, '1347'),
	(377, 1, 0, -50246, 1349, 0, 0, 39, '1348'),
	(377, 1, 0, -50246, 1350, 0, 0, 39, '1349'),
	(377, 1, 0, -50246, 1351, 0, 0, 39, '1350'),
	(377, 1, 0, -50246, 1352, 0, 0, 39, '1351'),
	(377, 1, 0, -50246, 1353, 0, 0, 39, '1352'),
	(377, 1, 0, -50246, 1354, 0, 0, 39, '1353'),
	(377, 1, 0, -50246, 1355, 0, 0, 39, '1354'),
	(377, 1, 0, -50246, 1356, 0, 0, 39, '1355'),
	(377, 1, 0, -50246, 1357, 0, 0, 39, '1356'),
	(377, 1, 0, -50246, 1358, 0, 0, 39, '1357'),
	(377, 1, 0, -50246, 1359, 0, 0, 39, '1358'),
	(377, 1, 0, -50246, 1360, 0, 0, 39, '1359'),
	(377, 1, 0, -50246, 1361, 0, 0, 39, '1360'),
	(377, 1, 0, -50246, 1362, 0, 0, 39, '1361'),
	(377, 1, 0, -50246, 1363, 0, 0, 39, '1362'),
	(377, 1, 0, -50246, 1364, 0, 0, 39, '1363'),
	(377, 1, 0, -50246, 1365, 0, 0, 39, '1364'),
	(377, 1, 0, -50246, 1366, 0, 0, 39, '1365'),
	(377, 1, 0, -50246, 1367, 0, 0, 39, '1366'),
	(377, 1, 0, -50246, 1368, 0, 0, 39, '1367'),
	(377, 1, 0, -50246, 1369, 0, 0, 39, '1368'),
	(377, 1, 0, -50246, 1370, 0, 0, 39, '1369'),
	(377, 1, 0, -50246, 1371, 0, 0, 39, '1370'),
	(377, 1, 0, -50246, 1372, 0, 0, 39, '1371'),
	(377, 1, 0, -50246, 1373, 0, 0, 39, '1372'),
	(377, 1, 0, -50246, 1374, 0, 0, 39, '1373'),
	(377, 1, 0, -50246, 1375, 0, 0, 39, '1374'),
	(377, 1, 0, -50246, 1376, 0, 0, 39, '1375'),
	(377, 1, 0, -50246, 1377, 0, 0, 39, '1376'),
	(377, 1, 0, -50246, 1378, 0, 0, 39, '1377'),
	(377, 1, 0, -50246, 1379, 0, 0, 39, '1378'),
	(377, 1, 0, -50246, 1380, 0, 0, 39, '1379'),
	(377, 1, 0, -50246, 1381, 0, 0, 39, '1380'),
	(377, 1, 0, -50246, 1382, 0, 0, 39, '1381'),
	(377, 1, 0, -50246, 1383, 0, 0, 39, '1382'),
	(377, 1, 0, -50246, 1384, 0, 0, 39, '1383'),
	(377, 1, 0, -50246, 1385, 0, 0, 39, '1384'),
	(377, 1, 0, -50246, 1386, 0, 0, 39, '1385'),
	(377, 1, 0, -50246, 1387, 0, 0, 39, '1386'),
	(377, 1, 0, -50246, 1388, 0, 0, 39, '1387'),
	(377, 1, 0, -50246, 1389, 0, 0, 39, '1388'),
	(377, 1, 0, -50246, 1390, 0, 0, 39, '1389'),
	(377, 1, 0, -50246, 1391, 0, 0, 39, '1390'),
	(377, 1, 0, -50246, 1392, 0, 0, 39, '1391'),
	(377, 1, 0, -50246, 1393, 0, 0, 39, '1392'),
	(377, 1, 0, -50246, 1394, 0, 0, 39, '1393'),
	(377, 1, 0, -50246, 1395, 0, 0, 39, '1394'),
	(377, 1, 0, -50246, 1396, 0, 0, 39, '1395'),
	(377, 1, 0, -50246, 1397, 0, 0, 39, '1396'),
	(377, 1, 0, -50246, 1398, 0, 0, 39, '1397'),
	(377, 1, 0, -50246, 1399, 0, 0, 39, '1398'),
	(377, 1, 0, -50246, 1400, 0, 0, 39, '1399'),
	(377, 1, 0, -50246, 1401, 0, 0, 39, '1400'),
	(377, 1, 0, -50246, 1402, 0, 0, 39, '1401'),
	(377, 1, 0, -50246, 1403, 0, 0, 39, '1402'),
	(377, 1, 0, -50246, 1404, 0, 0, 39, '1403'),
	(377, 1, 0, -50246, 1405, 0, 0, 39, '1404'),
	(377, 1, 0, -50246, 1406, 0, 0, 39, '1405'),
	(377, 1, 0, -50246, 1407, 0, 0, 39, '1406'),
	(377, 1, 0, -50246, 1408, 0, 0, 39, '1407'),
	(377, 1, 0, -50246, 1409, 0, 0, 39, '1408'),
	(377, 1, 0, -50246, 1410, 0, 0, 39, '1409'),
	(377, 1, 0, -50246, 1411, 0, 0, 39, '1410'),
	(377, 1, 0, -50246, 1412, 0, 0, 39, '1411'),
	(377, 1, 0, -50246, 1413, 0, 0, 39, '1412'),
	(377, 1, 0, -50246, 1414, 0, 0, 39, '1413'),
	(377, 1, 0, -50246, 1415, 0, 0, 39, '1414'),
	(377, 1, 0, -50246, 1416, 0, 0, 39, '1415'),
	(377, 1, 0, -50246, 1417, 0, 0, 39, '1416'),
	(377, 1, 0, -50246, 1418, 0, 0, 39, '1417'),
	(377, 1, 0, -50246, 1419, 0, 0, 39, '1418'),
	(377, 1, 0, -50246, 1420, 0, 0, 39, '1419'),
	(377, 1, 0, -50246, 1421, 0, 0, 39, '1420'),
	(377, 1, 0, -50246, 1422, 0, 0, 39, '1421'),
	(377, 1, 0, -50246, 1423, 0, 0, 39, '1422'),
	(377, 1, 0, -50246, 1424, 0, 0, 39, '1423'),
	(377, 1, 0, -50246, 1425, 0, 0, 39, '1424'),
	(377, 1, 0, -50246, 1426, 0, 0, 39, '1425'),
	(377, 1, 0, -50246, 1427, 0, 0, 39, '1426'),
	(377, 1, 0, -50246, 1428, 0, 0, 39, '1427'),
	(377, 1, 0, -50246, 1429, 0, 0, 39, '1428'),
	(377, 1, 0, -50246, 1430, 0, 0, 39, '1429'),
	(377, 1, 0, -50246, 1431, 0, 0, 39, '1430'),
	(377, 1, 0, -50246, 1432, 0, 0, 39, '1431'),
	(377, 1, 0, -50246, 1433, 0, 0, 39, '1432'),
	(377, 1, 0, -50246, 1434, 0, 0, 39, '1433'),
	(377, 1, 0, -50246, 1435, 0, 0, 39, '1434'),
	(377, 1, 0, -50246, 1436, 0, 0, 39, '1435'),
	(377, 1, 0, -50246, 1437, 0, 0, 39, '1436'),
	(377, 1, 0, -50246, 1438, 0, 0, 39, '1437'),
	(377, 1, 0, -50246, 1439, 0, 0, 39, '1438'),
	(377, 1, 0, -50246, 1440, 0, 0, 39, '1439'),
	(377, 1, 0, -50246, 1441, 0, 0, 39, '1440'),
	(377, 1, 0, -50246, 1442, 0, 0, 39, '1441'),
	(377, 1, 0, -50246, 1443, 0, 0, 39, '1442'),
	(377, 1, 0, -50246, 1444, 0, 0, 39, '1443'),
	(377, 1, 0, -50246, 1445, 0, 0, 39, '1444'),
	(377, 1, 0, -50246, 1446, 0, 0, 39, '1445'),
	(377, 1, 0, -50246, 1447, 0, 0, 39, '1446'),
	(377, 1, 0, -50246, 1448, 0, 0, 39, '1447'),
	(377, 1, 0, -50246, 1449, 0, 0, 39, '1448'),
	(377, 1, 0, -50246, 1450, 0, 0, 39, '1449'),
	(377, 1, 0, -50246, 1451, 0, 0, 39, '1450'),
	(377, 1, 0, -50246, 1452, 0, 0, 39, '1451'),
	(377, 1, 0, -50246, 1453, 0, 0, 39, '1452'),
	(377, 1, 0, -50246, 1454, 0, 0, 39, '1453'),
	(377, 1, 0, -50246, 1455, 0, 0, 39, '1454'),
	(377, 1, 0, -50246, 1456, 0, 0, 39, '1455'),
	(377, 1, 0, -50246, 1457, 0, 0, 39, '1456'),
	(377, 1, 0, -50246, 1458, 0, 0, 39, '1457'),
	(377, 1, 0, -50246, 1459, 0, 0, 39, '1458'),
	(377, 1, 0, -50246, 1460, 0, 0, 39, '1459'),
	(377, 1, 0, -50246, 1461, 0, 0, 39, '1460'),
	(377, 1, 0, -50246, 1462, 0, 0, 39, '1461'),
	(377, 1, 0, -50246, 1463, 0, 0, 39, '1462'),
	(377, 1, 0, -50246, 1464, 0, 0, 39, '1463'),
	(377, 1, 0, -50246, 1465, 0, 0, 39, '1464'),
	(377, 1, 0, -50246, 1466, 0, 0, 39, '1465'),
	(377, 1, 0, -50246, 1467, 0, 0, 39, '1466'),
	(377, 1, 0, -50246, 1468, 0, 0, 39, '1467'),
	(377, 1, 0, -50246, 1469, 0, 0, 39, '1468'),
	(377, 1, 0, -50246, 1470, 0, 0, 39, '1469'),
	(377, 1, 0, -50246, 1471, 0, 0, 39, '1470'),
	(377, 1, 0, -50246, 1472, 0, 0, 39, '1471'),
	(377, 1, 0, -50246, 1473, 0, 0, 39, '1472'),
	(377, 1, 0, -50246, 1474, 0, 0, 39, '1473'),
	(377, 1, 0, -50246, 1475, 0, 0, 39, '1474'),
	(377, 1, 0, -50246, 1476, 0, 0, 39, '1475'),
	(377, 1, 0, -50246, 1477, 0, 0, 39, '1476'),
	(377, 1, 0, -50246, 1478, 0, 0, 39, '1477'),
	(377, 1, 0, -50246, 1479, 0, 0, 39, '1478'),
	(377, 1, 0, -50246, 1480, 0, 0, 39, '1479'),
	(377, 1, 0, -50246, 1481, 0, 0, 39, '1480'),
	(377, 1, 0, -50246, 1482, 0, 0, 39, '1481'),
	(377, 1, 0, -50246, 1483, 0, 0, 39, '1482'),
	(377, 1, 0, -50246, 1484, 0, 0, 39, '1483'),
	(377, 1, 0, -50246, 1485, 0, 0, 39, '1484'),
	(377, 1, 0, -50246, 1486, 0, 0, 39, '1485'),
	(377, 1, 0, -50246, 1487, 0, 0, 39, '1486'),
	(377, 1, 0, -50246, 1488, 0, 0, 39, '1487'),
	(377, 1, 0, -50246, 1489, 0, 0, 39, '1488'),
	(377, 1, 0, -50246, 1490, 0, 0, 39, '1489'),
	(377, 1, 0, -50246, 1491, 0, 0, 39, '1490'),
	(377, 1, 0, -50246, 1492, 0, 0, 39, '1491'),
	(377, 1, 0, -50246, 1493, 0, 0, 39, '1492'),
	(377, 1, 0, -50246, 1494, 0, 0, 39, '1493'),
	(377, 1, 0, -50246, 1495, 0, 0, 39, '1494'),
	(377, 1, 0, -50246, 1496, 0, 0, 39, '1495'),
	(377, 1, 0, -50246, 1497, 0, 0, 39, '1496'),
	(377, 1, 0, -50246, 1498, 0, 0, 39, '1497'),
	(377, 1, 0, -50246, 1499, 0, 0, 39, '1498'),
	(377, 1, 0, -50246, 1500, 0, 0, 39, '1499'),
	(377, 1, 0, -50246, 1501, 0, 0, 39, '1500'),
	(377, 1, 0, -50246, 1502, 0, 0, 39, '1501'),
	(377, 1, 0, -50246, 1503, 0, 0, 39, '1502'),
	(377, 1, 0, -50246, 1504, 0, 0, 39, '1503'),
	(377, 1, 0, -50246, 1505, 0, 0, 39, '1504'),
	(377, 1, 0, -50246, 1506, 0, 0, 39, '1505'),
	(377, 1, 0, -50246, 1507, 0, 0, 39, '1506'),
	(377, 1, 0, -50246, 1508, 0, 0, 39, '1507'),
	(377, 1, 0, -50246, 1509, 0, 0, 39, '1508'),
	(377, 1, 0, -50246, 1510, 0, 0, 39, '1509'),
	(377, 1, 0, -50246, 1511, 0, 0, 39, '1510'),
	(377, 1, 0, -50246, 1512, 0, 0, 39, '1511'),
	(377, 1, 0, -50246, 1513, 0, 0, 39, '1512'),
	(377, 1, 0, -50246, 1514, 0, 0, 39, '1513'),
	(377, 1, 0, -50246, 1515, 0, 0, 39, '1514'),
	(377, 1, 0, -50246, 1516, 0, 0, 39, '1515'),
	(377, 1, 0, -50246, 1517, 0, 0, 39, '1516'),
	(377, 1, 0, -50246, 1518, 0, 0, 39, '1517'),
	(377, 1, 0, -50246, 1519, 0, 0, 39, '1518'),
	(377, 1, 0, -50246, 1520, 0, 0, 39, '1519'),
	(377, 1, 0, -50246, 1521, 0, 0, 39, '1520'),
	(377, 1, 0, -50246, 1522, 0, 0, 39, '1521'),
	(377, 1, 0, -50246, 1523, 0, 0, 39, '1522'),
	(377, 1, 0, -50246, 1524, 0, 0, 39, '1523'),
	(377, 1, 0, -50246, 1525, 0, 0, 39, '1524'),
	(377, 1, 0, -50246, 1526, 0, 0, 39, '1525'),
	(377, 1, 0, -50246, 1527, 0, 0, 39, '1526'),
	(377, 1, 0, -50246, 1528, 0, 0, 39, '1527'),
	(377, 1, 0, -50246, 1529, 0, 0, 39, '1528'),
	(377, 1, 0, -50246, 1530, 0, 0, 39, '1529'),
	(377, 1, 0, -50246, 1531, 0, 0, 39, '1530'),
	(377, 1, 0, -50246, 1532, 0, 0, 39, '1531'),
	(377, 1, 0, -50246, 1533, 0, 0, 39, '1532'),
	(377, 1, 0, -50246, 1534, 0, 0, 39, '1533'),
	(377, 1, 0, -50246, 1535, 0, 0, 39, '1534'),
	(377, 1, 0, -50246, 1536, 0, 0, 39, '1535'),
	(377, 1, 0, -50246, 1537, 0, 0, 39, '1536'),
	(377, 1, 0, -50246, 1538, 0, 0, 39, '1537'),
	(377, 1, 0, -50246, 1539, 0, 0, 39, '1538'),
	(377, 1, 0, -50246, 1540, 0, 0, 39, '1539'),
	(377, 1, 0, -50246, 1541, 0, 0, 39, '1540'),
	(377, 1, 0, -50246, 1542, 0, 0, 39, '1541'),
	(377, 1, 0, -50246, 1543, 0, 0, 39, '1542'),
	(377, 1, 0, -50246, 1544, 0, 0, 39, '1543'),
	(377, 1, 0, -50246, 1545, 0, 0, 39, '1544'),
	(377, 1, 0, -50246, 1546, 0, 0, 39, '1545'),
	(377, 1, 0, -50246, 1547, 0, 0, 39, '1546'),
	(377, 1, 0, -50246, 1548, 0, 0, 39, '1547'),
	(377, 1, 0, -50246, 1549, 0, 0, 39, '1548'),
	(377, 1, 0, -50246, 1550, 0, 0, 39, '1549'),
	(377, 1, 0, -50246, 1551, 0, 0, 39, '1550'),
	(377, 1, 0, -50246, 1552, 0, 0, 39, '1551'),
	(377, 1, 0, -50246, 1553, 0, 0, 39, '1552'),
	(377, 1, 0, -50246, 1554, 0, 0, 39, '1553'),
	(377, 1, 0, -50246, 1555, 0, 0, 39, '1554'),
	(377, 1, 0, -50246, 1556, 0, 0, 39, '1555'),
	(377, 1, 0, -50246, 1557, 0, 0, 39, '1556'),
	(377, 1, 0, -50246, 1558, 0, 0, 39, '1557'),
	(377, 1, 0, -50246, 1559, 0, 0, 39, '1558'),
	(377, 1, 0, -50246, 1560, 0, 0, 39, '1559'),
	(377, 1, 0, -50246, 1561, 0, 0, 39, '1560'),
	(377, 1, 0, -50246, 1562, 0, 0, 39, '1561'),
	(377, 1, 0, -50246, 1563, 0, 0, 39, '1562'),
	(377, 1, 0, -50246, 1564, 0, 0, 39, '1563'),
	(377, 1, 0, -50246, 1565, 0, 0, 39, '1564'),
	(377, 1, 0, -50246, 1566, 0, 0, 39, '1565'),
	(377, 1, 0, -50246, 1567, 0, 0, 39, '1566'),
	(377, 1, 0, -50246, 1568, 0, 0, 39, '1567'),
	(377, 1, 0, -50246, 1569, 0, 0, 39, '1568'),
	(377, 1, 0, -50246, 1570, 0, 0, 39, '1569'),
	(377, 1, 0, -50246, 1571, 0, 0, 39, '1570'),
	(377, 1, 0, -50246, 1572, 0, 0, 39, '1571'),
	(377, 1, 0, -50246, 1573, 0, 0, 39, '1572'),
	(377, 1, 0, -50246, 1574, 0, 0, 39, '1573'),
	(377, 1, 0, -50246, 1575, 0, 0, 39, '1574'),
	(377, 1, 0, -50246, 1576, 0, 0, 39, '1575'),
	(377, 1, 0, -50246, 1577, 0, 0, 39, '1576'),
	(377, 1, 0, -50246, 1578, 0, 0, 39, '1577'),
	(377, 1, 0, -50246, 1579, 0, 0, 39, '1578'),
	(377, 1, 0, -50246, 1580, 0, 0, 39, '1579'),
	(377, 1, 0, -50246, 1581, 0, 0, 39, '1580'),
	(377, 1, 0, -50246, 1582, 0, 0, 39, '1581'),
	(377, 1, 0, -50246, 1583, 0, 0, 39, '1582'),
	(377, 1, 0, -50246, 1584, 0, 0, 39, '1583'),
	(377, 1, 0, -50246, 1585, 0, 0, 39, '1584'),
	(377, 1, 0, -50246, 1586, 0, 0, 39, '1585'),
	(377, 1, 0, -50246, 1587, 0, 0, 39, '1586'),
	(377, 1, 0, -50246, 1588, 0, 0, 39, '1587'),
	(377, 1, 0, -50246, 1589, 0, 0, 39, '1588'),
	(377, 1, 0, -50246, 1590, 0, 0, 39, '1589'),
	(377, 1, 0, -50246, 1591, 0, 0, 39, '1590'),
	(377, 1, 0, -50246, 1592, 0, 0, 39, '1591'),
	(377, 1, 0, -50246, 1593, 0, 0, 39, '1592'),
	(377, 1, 0, -50246, 1594, 0, 0, 39, '1593'),
	(377, 1, 0, -50246, 1595, 0, 0, 39, '1594'),
	(377, 1, 0, -50246, 1596, 0, 0, 39, '1595'),
	(377, 1, 0, -50246, 1597, 0, 0, 39, '1596'),
	(377, 1, 0, -50246, 1598, 0, 0, 39, '1597'),
	(377, 1, 0, -50246, 1599, 0, 0, 39, '1598'),
	(377, 1, 0, -50246, 1600, 0, 0, 39, '1599'),
	(377, 1, 0, -50246, 1601, 0, 0, 39, '1600'),
	(377, 1, 0, -50246, 1602, 0, 0, 39, '1601'),
	(377, 1, 0, -50246, 1603, 0, 0, 39, '1602'),
	(377, 1, 0, -50246, 1604, 0, 0, 39, '1603'),
	(377, 1, 0, -50246, 1605, 0, 0, 39, '1604'),
	(377, 1, 0, -50246, 1606, 0, 0, 39, '1605'),
	(377, 1, 0, -50246, 1607, 0, 0, 39, '1606'),
	(377, 1, 0, -50246, 1608, 0, 0, 39, '1607'),
	(377, 1, 0, -50246, 1609, 0, 0, 39, '1608'),
	(377, 1, 0, -50246, 1610, 0, 0, 39, '1609'),
	(377, 1, 0, -50246, 1611, 0, 0, 39, '1610'),
	(377, 1, 0, -50246, 1612, 0, 0, 39, '1611'),
	(377, 1, 0, -50246, 1613, 0, 0, 39, '1612'),
	(377, 1, 0, -50246, 1614, 0, 0, 39, '1613'),
	(377, 1, 0, -50246, 1615, 0, 0, 39, '1614'),
	(377, 1, 0, -50246, 1616, 0, 0, 39, '1615'),
	(377, 1, 0, -50246, 1617, 0, 0, 39, '1616'),
	(377, 1, 0, -50246, 1618, 0, 0, 39, '1617'),
	(377, 1, 0, -50246, 1619, 0, 0, 39, '1618'),
	(377, 1, 0, -50246, 1620, 0, 0, 39, '1619'),
	(377, 1, 0, -50246, 1621, 0, 0, 39, '1620'),
	(377, 1, 0, -50246, 1622, 0, 0, 39, '1621'),
	(377, 1, 0, -50246, 1623, 0, 0, 39, '1622'),
	(377, 1, 0, -50246, 1624, 0, 0, 39, '1623'),
	(377, 1, 0, -50246, 1625, 0, 0, 39, '1624'),
	(377, 1, 0, -50246, 1626, 0, 0, 39, '1625'),
	(377, 1, 0, -50246, 1627, 0, 0, 39, '1626'),
	(377, 1, 0, -50246, 1628, 0, 0, 39, '1627'),
	(377, 1, 0, -50246, 1629, 0, 0, 39, '1628'),
	(377, 1, 0, -50246, 1630, 0, 0, 39, '1629'),
	(377, 1, 0, -50246, 1631, 0, 0, 39, '1630'),
	(377, 1, 0, -50246, 1632, 0, 0, 39, '1631'),
	(377, 1, 0, -50246, 1633, 0, 0, 39, '1632'),
	(377, 1, 0, -50246, 1634, 0, 0, 39, '1633'),
	(377, 1, 0, -50246, 1635, 0, 0, 39, '1634'),
	(377, 1, 0, -50246, 1636, 0, 0, 39, '1635'),
	(377, 1, 0, -50246, 1637, 0, 0, 39, '1636'),
	(377, 1, 0, -50246, 1638, 0, 0, 39, '1637'),
	(377, 1, 0, -50246, 1639, 0, 0, 39, '1638'),
	(377, 1, 0, -50246, 1640, 0, 0, 39, '1639'),
	(377, 1, 0, -50246, 1641, 0, 0, 39, '1640'),
	(377, 1, 0, -50246, 1642, 0, 0, 39, '1641'),
	(377, 1, 0, -50246, 1643, 0, 0, 39, '1642'),
	(377, 1, 0, -50246, 1644, 0, 0, 39, '1643'),
	(377, 1, 0, -50246, 1645, 0, 0, 39, '1644'),
	(377, 1, 0, -50246, 1646, 0, 0, 39, '1645'),
	(377, 1, 0, -50246, 1647, 0, 0, 39, '1646'),
	(377, 1, 0, -50246, 1648, 0, 0, 39, '1647'),
	(377, 1, 0, -50246, 1649, 0, 0, 39, '1648'),
	(377, 1, 0, -50246, 1650, 0, 0, 39, '1649'),
	(377, 1, 0, -50246, 1651, 0, 0, 39, '1650'),
	(377, 1, 0, -50246, 1652, 0, 0, 39, '1651'),
	(377, 1, 0, -50246, 1653, 0, 0, 39, '1652'),
	(377, 1, 0, -50246, 1654, 0, 0, 39, '1653'),
	(377, 1, 0, -50246, 1655, 0, 0, 39, '1654'),
	(377, 1, 0, -50246, 1656, 0, 0, 39, '1655'),
	(377, 1, 0, -50246, 1657, 0, 0, 39, '1656'),
	(377, 1, 0, -50246, 1658, 0, 0, 39, '1657'),
	(377, 1, 0, -50246, 1659, 0, 0, 39, '1658'),
	(377, 1, 0, -50246, 1660, 0, 0, 39, '1659'),
	(377, 1, 0, -50246, 1661, 0, 0, 39, '1660'),
	(377, 1, 0, -50246, 1662, 0, 0, 39, '1661'),
	(377, 1, 0, -50246, 1663, 0, 0, 39, '1662'),
	(377, 1, 0, -50246, 1664, 0, 0, 39, '1663'),
	(377, 1, 0, -50246, 1665, 0, 0, 39, '1664'),
	(377, 1, 0, -50246, 1666, 0, 0, 39, '1665'),
	(377, 1, 0, -50246, 1667, 0, 0, 39, '1666'),
	(377, 1, 0, -50246, 1668, 0, 0, 39, '1667'),
	(377, 1, 0, -50246, 1669, 0, 0, 39, '1668'),
	(377, 1, 0, -50246, 1670, 0, 0, 39, '1669'),
	(377, 1, 0, -50246, 1671, 0, 0, 39, '1670'),
	(377, 1, 0, -50246, 1672, 0, 0, 39, '1671'),
	(377, 1, 0, -50246, 1673, 0, 0, 39, '1672'),
	(377, 1, 0, -50246, 1674, 0, 0, 39, '1673'),
	(377, 1, 0, -50246, 1675, 0, 0, 39, '1674'),
	(377, 1, 0, -50246, 1676, 0, 0, 39, '1675'),
	(377, 1, 0, -50246, 1677, 0, 0, 39, '1676'),
	(377, 1, 0, -50246, 1678, 0, 0, 39, '1677'),
	(377, 1, 0, -50246, 1679, 0, 0, 39, '1678'),
	(377, 1, 0, -50246, 1680, 0, 0, 39, '1679'),
	(377, 1, 0, -50246, 1681, 0, 0, 39, '1680'),
	(377, 1, 0, -50246, 1682, 0, 0, 39, '1681'),
	(377, 1, 0, -50246, 1683, 0, 0, 39, '1682'),
	(377, 1, 0, -50246, 1684, 0, 0, 39, '1683'),
	(377, 1, 0, -50246, 1685, 0, 0, 39, '1684'),
	(377, 1, 0, -50246, 1686, 0, 0, 39, '1685'),
	(377, 1, 0, -50246, 1687, 0, 0, 39, '1686'),
	(377, 1, 0, -50246, 1688, 0, 0, 39, '1687'),
	(377, 1, 0, -50246, 1689, 0, 0, 39, '1688'),
	(377, 1, 0, -50246, 1690, 0, 0, 39, '1689'),
	(377, 1, 0, -50246, 1691, 0, 0, 39, '1690'),
	(377, 1, 0, -50246, 1692, 0, 0, 39, '1691'),
	(377, 1, 0, -50246, 1693, 0, 0, 39, '1692'),
	(377, 1, 0, -50246, 1694, 0, 0, 39, '1693'),
	(377, 1, 0, -50246, 1695, 0, 0, 39, '1694'),
	(377, 1, 0, -50246, 1696, 0, 0, 39, '1695'),
	(377, 1, 0, -50246, 1697, 0, 0, 39, '1696'),
	(377, 1, 0, -50246, 1698, 0, 0, 39, '1697'),
	(377, 1, 0, -50246, 1699, 0, 0, 39, '1698'),
	(377, 1, 0, -50246, 1700, 0, 0, 39, '1699'),
	(377, 1, 0, -50246, 1701, 0, 0, 39, '1700'),
	(377, 1, 0, -50246, 1702, 0, 0, 39, '1701'),
	(377, 1, 0, -50246, 1703, 0, 0, 39, '1702'),
	(377, 1, 0, -50246, 1704, 0, 0, 39, '1703'),
	(377, 1, 0, -50246, 1705, 0, 0, 39, '1704'),
	(377, 1, 0, -50246, 1706, 0, 0, 39, '1705'),
	(377, 1, 0, -50246, 1707, 0, 0, 39, '1706'),
	(377, 1, 0, -50246, 1708, 0, 0, 39, '1707'),
	(377, 1, 0, -50246, 1709, 0, 0, 39, '1708'),
	(377, 1, 0, -50246, 1710, 0, 0, 39, '1709'),
	(377, 1, 0, -50246, 1711, 0, 0, 39, '1710'),
	(377, 1, 0, -50246, 1712, 0, 0, 39, '1711'),
	(377, 1, 0, -50246, 1713, 0, 0, 39, '1712'),
	(377, 1, 0, -50246, 1714, 0, 0, 39, '1713'),
	(377, 1, 0, -50246, 1715, 0, 0, 39, '1714'),
	(377, 1, 0, -50246, 1716, 0, 0, 39, '1715'),
	(377, 1, 0, -50246, 1717, 0, 0, 39, '1716'),
	(377, 1, 0, -50246, 1718, 0, 0, 39, '1717'),
	(377, 1, 0, -50246, 1719, 0, 0, 39, '1718'),
	(377, 1, 0, -50246, 1720, 0, 0, 39, '1719'),
	(377, 1, 0, -50246, 1721, 0, 0, 39, '1720'),
	(377, 1, 0, -50246, 1722, 0, 0, 39, '1721'),
	(377, 1, 0, -50246, 1723, 0, 0, 39, '1722'),
	(377, 1, 0, -50246, 1724, 0, 0, 39, '1723'),
	(377, 1, 0, -50246, 1725, 0, 0, 39, '1724'),
	(377, 1, 0, -50246, 1726, 0, 0, 39, '1725'),
	(377, 1, 0, -50246, 1727, 0, 0, 39, '1726'),
	(377, 1, 0, -50246, 1728, 0, 0, 39, '1727'),
	(377, 1, 0, -50246, 1729, 0, 0, 39, '1728'),
	(377, 1, 0, -50246, 1730, 0, 0, 39, '1729'),
	(377, 1, 0, -50246, 1731, 0, 0, 39, '1730'),
	(377, 1, 0, -50246, 1732, 0, 0, 39, '1731'),
	(377, 1, 0, -50246, 1733, 0, 0, 39, '1732'),
	(377, 1, 0, -50246, 1734, 0, 0, 39, '1733'),
	(377, 1, 0, -50246, 1735, 0, 0, 39, '1734'),
	(377, 1, 0, -50246, 1736, 0, 0, 39, '1735'),
	(377, 1, 0, -50246, 1737, 0, 0, 39, '1736'),
	(377, 1, 0, -50246, 1738, 0, 0, 39, '1737'),
	(377, 1, 0, -50246, 1739, 0, 0, 39, '1738'),
	(377, 1, 0, -50246, 1740, 0, 0, 39, '1739'),
	(377, 1, 0, -50246, 1741, 0, 0, 39, '1740'),
	(377, 1, 0, -50246, 1742, 0, 0, 39, '1741'),
	(377, 1, 0, -50246, 1743, 0, 0, 39, '1742'),
	(377, 1, 0, -50246, 1744, 0, 0, 39, '1743'),
	(377, 1, 0, -50246, 1745, 0, 0, 39, '1744'),
	(377, 1, 0, -50246, 1746, 0, 0, 39, '1745'),
	(377, 1, 0, -50246, 1747, 0, 0, 39, '1746'),
	(377, 1, 0, -50246, 1748, 0, 0, 39, '1747'),
	(377, 1, 0, -50246, 1749, 0, 0, 39, '1748'),
	(377, 1, 0, -50246, 1750, 0, 0, 39, '1749'),
	(377, 1, 0, -50246, 1751, 0, 0, 39, '1750'),
	(377, 1, 0, -50246, 1752, 0, 0, 39, '1751'),
	(377, 1, 0, -50246, 1753, 0, 0, 39, '1752'),
	(377, 1, 0, -50246, 1754, 0, 0, 39, '1753'),
	(377, 1, 0, -50246, 1755, 0, 0, 39, '1754'),
	(377, 1, 0, -50246, 1756, 0, 0, 39, '1755'),
	(377, 1, 0, -50246, 1757, 0, 0, 39, '1756'),
	(377, 1, 0, -50246, 1758, 0, 0, 39, '1757'),
	(377, 1, 0, -50246, 1759, 0, 0, 39, '1758'),
	(377, 1, 0, -50246, 1760, 0, 0, 39, '1759'),
	(377, 1, 0, -50246, 1761, 0, 0, 39, '1760'),
	(377, 1, 0, -50246, 1762, 0, 0, 39, '1761'),
	(377, 1, 0, -50246, 1763, 0, 0, 39, '1762'),
	(377, 1, 0, -50246, 1764, 0, 0, 39, '1763'),
	(377, 1, 0, -50246, 1765, 0, 0, 39, '1764'),
	(377, 1, 0, -50246, 1766, 0, 0, 39, '1765'),
	(377, 1, 0, -50246, 1767, 0, 0, 39, '1766'),
	(377, 1, 0, -50246, 1768, 0, 0, 39, '1767'),
	(377, 1, 0, -50246, 1769, 0, 0, 39, '1768'),
	(377, 1, 0, -50246, 1770, 0, 0, 39, '1769'),
	(377, 1, 0, -50246, 1771, 0, 0, 39, '1770'),
	(377, 1, 0, -50246, 1772, 0, 0, 39, '1771'),
	(377, 1, 0, -50246, 1773, 0, 0, 39, '1772'),
	(377, 1, 0, -50246, 1774, 0, 0, 39, '1773'),
	(377, 1, 0, -50246, 1775, 0, 0, 39, '1774'),
	(377, 1, 0, -50246, 1776, 0, 0, 39, '1775'),
	(377, 1, 0, -50246, 1777, 0, 0, 39, '1776'),
	(377, 1, 0, -50246, 1778, 0, 0, 39, '1777'),
	(377, 1, 0, -50246, 1779, 0, 0, 39, '1778'),
	(377, 1, 0, -50246, 1780, 0, 0, 39, '1779'),
	(377, 1, 0, -50246, 1781, 0, 0, 39, '1780'),
	(377, 1, 0, -50246, 1782, 0, 0, 39, '1781'),
	(377, 1, 0, -50246, 1783, 0, 0, 39, '1782'),
	(377, 1, 0, -50246, 1784, 0, 0, 39, '1783'),
	(377, 1, 0, -50246, 1785, 0, 0, 39, '1784'),
	(377, 1, 0, -50246, 1786, 0, 0, 39, '1785'),
	(377, 1, 0, -50246, 1787, 0, 0, 39, '1786'),
	(377, 1, 0, -50246, 1788, 0, 0, 39, '1787'),
	(377, 1, 0, -50246, 1789, 0, 0, 39, '1788'),
	(377, 1, 0, -50246, 1790, 0, 0, 39, '1789'),
	(377, 1, 0, -50246, 1791, 0, 0, 39, '1790'),
	(377, 1, 0, -50246, 1792, 0, 0, 39, '1791'),
	(377, 1, 0, -50246, 1793, 0, 0, 39, '1792'),
	(377, 1, 0, -50246, 1794, 0, 0, 39, '1793'),
	(377, 1, 0, -50246, 1795, 0, 0, 39, '1794'),
	(377, 1, 0, -50246, 1796, 0, 0, 39, '1795'),
	(377, 1, 0, -50246, 1797, 0, 0, 39, '1796'),
	(377, 1, 0, -50246, 1798, 0, 0, 39, '1797'),
	(377, 1, 0, -50246, 1799, 0, 0, 39, '1798'),
	(377, 1, 0, -50246, 1800, 0, 0, 39, '1799'),
	(377, 1, 0, -50246, 1801, 0, 0, 39, '1800'),
	(377, 1, 0, -50246, 1802, 0, 0, 39, '1801'),
	(377, 1, 0, -50246, 1803, 0, 0, 39, '1802'),
	(377, 1, 0, -50246, 1804, 0, 0, 39, '1803'),
	(377, 1, 0, -50246, 1805, 0, 0, 39, '1804'),
	(377, 1, 0, -50246, 1806, 0, 0, 39, '1805'),
	(377, 1, 0, -50246, 1807, 0, 0, 39, '1806'),
	(377, 1, 0, -50246, 1808, 0, 0, 39, '1807'),
	(377, 1, 0, -50246, 1809, 0, 0, 39, '1808'),
	(377, 1, 0, -50246, 1810, 0, 0, 39, '1809'),
	(377, 1, 0, -50246, 1811, 0, 0, 39, '1810'),
	(377, 1, 0, -50246, 1812, 0, 0, 39, '1811'),
	(377, 1, 0, -50246, 1813, 0, 0, 39, '1812'),
	(377, 1, 0, -50246, 1814, 0, 0, 39, '1813'),
	(377, 1, 0, -50246, 1815, 0, 0, 39, '1814'),
	(377, 1, 0, -50246, 1816, 0, 0, 39, '1815'),
	(377, 1, 0, -50246, 1817, 0, 0, 39, '1816'),
	(377, 1, 0, -50246, 1818, 0, 0, 39, '1817'),
	(377, 1, 0, -50246, 1819, 0, 0, 39, '1818'),
	(377, 1, 0, -50246, 1820, 0, 0, 39, '1819'),
	(377, 1, 0, -50246, 1821, 0, 0, 39, '1820'),
	(377, 1, 0, -50246, 1822, 0, 0, 39, '1821'),
	(377, 1, 0, -50246, 1823, 0, 0, 39, '1822'),
	(377, 1, 0, -50246, 1824, 0, 0, 39, '1823'),
	(377, 1, 0, -50246, 1825, 0, 0, 39, '1824'),
	(377, 1, 0, -50246, 1826, 0, 0, 39, '1825'),
	(377, 1, 0, -50246, 1827, 0, 0, 39, '1826'),
	(377, 1, 0, -50246, 1828, 0, 0, 39, '1827'),
	(377, 1, 0, -50246, 1829, 0, 0, 39, '1828'),
	(377, 1, 0, -50246, 1830, 0, 0, 39, '1829'),
	(377, 1, 0, -50246, 1831, 0, 0, 39, '1830'),
	(377, 1, 0, -50246, 1832, 0, 0, 39, '1831'),
	(377, 1, 0, -50246, 1833, 0, 0, 39, '1832'),
	(377, 1, 0, -50246, 1834, 0, 0, 39, '1833'),
	(377, 1, 0, -50246, 1835, 0, 0, 39, '1834'),
	(377, 1, 0, -50246, 1836, 0, 0, 39, '1835'),
	(377, 1, 0, -50246, 1837, 0, 0, 39, '1836'),
	(377, 1, 0, -50246, 1838, 0, 0, 39, '1837'),
	(377, 1, 0, -50246, 1839, 0, 0, 39, '1838'),
	(377, 1, 0, -50246, 1840, 0, 0, 39, '1839'),
	(377, 1, 0, -50246, 1841, 0, 0, 39, '1840'),
	(377, 1, 0, -50246, 1842, 0, 0, 39, '1841'),
	(377, 1, 0, -50246, 1843, 0, 0, 39, '1842'),
	(377, 1, 0, -50246, 1844, 0, 0, 39, '1843'),
	(377, 1, 0, -50246, 1845, 0, 0, 39, '1844'),
	(377, 1, 0, -50246, 1846, 0, 0, 39, '1845'),
	(377, 1, 0, -50246, 1847, 0, 0, 39, '1846'),
	(377, 1, 0, -50246, 1848, 0, 0, 39, '1847'),
	(377, 1, 0, -50246, 1849, 0, 0, 39, '1848'),
	(377, 1, 0, -50246, 1850, 0, 0, 39, '1849'),
	(377, 1, 0, -50246, 1851, 0, 0, 39, '1850'),
	(377, 1, 0, -50246, 1852, 0, 0, 39, '1851'),
	(377, 1, 0, -50246, 1853, 0, 0, 39, '1852'),
	(377, 1, 0, -50246, 1854, 0, 0, 39, '1853'),
	(377, 1, 0, -50246, 1855, 0, 0, 39, '1854'),
	(377, 1, 0, -50246, 1856, 0, 0, 39, '1855'),
	(377, 1, 0, -50246, 1857, 0, 0, 39, '1856'),
	(377, 1, 0, -50246, 1858, 0, 0, 39, '1857'),
	(377, 1, 0, -50246, 1859, 0, 0, 39, '1858'),
	(377, 1, 0, -50246, 1860, 0, 0, 39, '1859'),
	(377, 1, 0, -50246, 1861, 0, 0, 39, '1860'),
	(377, 1, 0, -50246, 1862, 0, 0, 39, '1861'),
	(377, 1, 0, -50246, 1863, 0, 0, 39, '1862'),
	(377, 1, 0, -50246, 1864, 0, 0, 39, '1863'),
	(377, 1, 0, -50246, 1865, 0, 0, 39, '1864'),
	(377, 1, 0, -50246, 1866, 0, 0, 39, '1865'),
	(377, 1, 0, -50246, 1867, 0, 0, 39, '1866'),
	(377, 1, 0, -50246, 1868, 0, 0, 39, '1867'),
	(377, 1, 0, -50246, 1869, 0, 0, 39, '1868'),
	(377, 1, 0, -50246, 1870, 0, 0, 39, '1869'),
	(377, 1, 0, -50246, 1871, 0, 0, 39, '1870'),
	(377, 1, 0, -50246, 1872, 0, 0, 39, '1871'),
	(377, 1, 0, -50246, 1873, 0, 0, 39, '1872'),
	(377, 1, 0, -50246, 1874, 0, 0, 39, '1873'),
	(377, 1, 0, -50246, 1875, 0, 0, 39, '1874'),
	(377, 1, 0, -50246, 1876, 0, 0, 39, '1875'),
	(377, 1, 0, -50246, 1877, 0, 0, 39, '1876'),
	(377, 1, 0, -50246, 1878, 0, 0, 39, '1877'),
	(377, 1, 0, -50246, 1879, 0, 0, 39, '1878'),
	(377, 1, 0, -50246, 1880, 0, 0, 39, '1879'),
	(377, 1, 0, -50246, 1881, 0, 0, 39, '1880'),
	(377, 1, 0, -50246, 1882, 0, 0, 39, '1881'),
	(377, 1, 0, -50246, 1883, 0, 0, 39, '1882'),
	(377, 1, 0, -50246, 1884, 0, 0, 39, '1883'),
	(377, 1, 0, -50246, 1885, 0, 0, 39, '1884'),
	(377, 1, 0, -50246, 1886, 0, 0, 39, '1885'),
	(377, 1, 0, -50246, 1887, 0, 0, 39, '1886'),
	(377, 1, 0, -50246, 1888, 0, 0, 39, '1887'),
	(377, 1, 0, -50246, 1889, 0, 0, 39, '1888'),
	(377, 1, 0, -50246, 1890, 0, 0, 39, '1889'),
	(377, 1, 0, -50246, 1891, 0, 0, 39, '1890'),
	(377, 1, 0, -50246, 1892, 0, 0, 39, '1891'),
	(377, 1, 0, -50246, 1893, 0, 0, 39, '1892'),
	(377, 1, 0, -50246, 1894, 0, 0, 39, '1893'),
	(377, 1, 0, -50246, 1895, 0, 0, 39, '1894'),
	(377, 1, 0, -50246, 1896, 0, 0, 39, '1895'),
	(377, 1, 0, -50246, 1897, 0, 0, 39, '1896'),
	(377, 1, 0, -50246, 1898, 0, 0, 39, '1897'),
	(377, 1, 0, -50246, 1899, 0, 0, 39, '1898'),
	(377, 1, 0, -50246, 1900, 0, 0, 39, '1899'),
	(377, 1, 0, -50246, 1901, 0, 0, 39, '1900'),
	(377, 1, 0, -50246, 1902, 0, 0, 39, '1901'),
	(377, 1, 0, -50246, 1903, 0, 0, 39, '1902'),
	(377, 1, 0, -50246, 1904, 0, 0, 39, '1903'),
	(377, 1, 0, -50246, 1905, 0, 0, 39, '1904'),
	(377, 1, 0, -50246, 1906, 0, 0, 39, '1905'),
	(377, 1, 0, -50246, 1907, 0, 0, 39, '1906'),
	(377, 1, 0, -50246, 1908, 0, 0, 39, '1907'),
	(377, 1, 0, -50246, 1909, 0, 0, 39, '1908'),
	(377, 1, 0, -50246, 1910, 0, 0, 39, '1909'),
	(377, 1, 0, -50246, 1911, 0, 0, 39, '1910'),
	(377, 1, 0, -50246, 1912, 0, 0, 39, '1911'),
	(377, 1, 0, -50246, 1913, 0, 0, 39, '1912'),
	(377, 1, 0, -50246, 1914, 0, 0, 39, '1913'),
	(377, 1, 0, -50246, 1915, 0, 0, 39, '1914'),
	(377, 1, 0, -50246, 1916, 0, 0, 39, '1915'),
	(377, 1, 0, -50246, 1917, 0, 0, 39, '1916'),
	(377, 1, 0, -50246, 1918, 0, 0, 39, '1917'),
	(377, 1, 0, -50246, 1919, 0, 0, 39, '1918'),
	(377, 1, 0, -50246, 1920, 0, 0, 39, '1919'),
	(377, 1, 0, -50246, 1921, 0, 0, 39, '1920'),
	(377, 1, 0, -50246, 1922, 0, 0, 39, '1921'),
	(377, 1, 0, -50246, 1923, 0, 0, 39, '1922'),
	(377, 1, 0, -50246, 1924, 0, 0, 39, '1923'),
	(377, 1, 0, -50246, 1925, 0, 0, 39, '1924'),
	(377, 1, 0, -50246, 1926, 0, 0, 39, '1925'),
	(377, 1, 0, -50246, 1927, 0, 0, 39, '1926'),
	(377, 1, 0, -50246, 1928, 0, 0, 39, '1927'),
	(377, 1, 0, -50246, 1929, 0, 0, 39, '1928'),
	(377, 1, 0, -50246, 1930, 0, 0, 39, '1929'),
	(377, 1, 0, -50246, 1931, 0, 0, 39, '1930'),
	(377, 1, 0, -50246, 1932, 0, 0, 39, '1931'),
	(377, 1, 0, -50246, 1933, 0, 0, 39, '1932'),
	(377, 1, 0, -50246, 1934, 0, 0, 39, '1933'),
	(377, 1, 0, -50246, 1935, 0, 0, 39, '1934'),
	(377, 1, 0, -50246, 1936, 0, 0, 39, '1935'),
	(377, 1, 0, -50246, 1937, 0, 0, 39, '1936'),
	(377, 1, 0, -50246, 1938, 0, 0, 39, '1937'),
	(377, 1, 0, -50246, 1939, 0, 0, 39, '1938'),
	(377, 1, 0, -50246, 1940, 0, 0, 39, '1939'),
	(377, 1, 0, -50246, 1941, 0, 0, 39, '1940'),
	(377, 1, 0, -50246, 1942, 0, 0, 39, '1941'),
	(377, 1, 0, -50246, 1943, 0, 0, 39, '1942'),
	(377, 1, 0, -50246, 1944, 0, 0, 39, '1943'),
	(377, 1, 0, -50246, 1945, 0, 0, 39, '1944'),
	(377, 1, 0, -50246, 1946, 0, 0, 39, '1945'),
	(377, 1, 0, -50246, 1947, 0, 0, 39, '1946'),
	(377, 1, 0, -50246, 1948, 0, 0, 39, '1947'),
	(377, 1, 0, -50246, 1949, 0, 0, 39, '1948'),
	(377, 1, 0, -50246, 1950, 0, 0, 39, '1949'),
	(377, 1, 0, -50246, 1951, 0, 0, 39, '1950'),
	(377, 1, 0, -50246, 1952, 0, 0, 39, '1951'),
	(377, 1, 0, -50246, 1953, 0, 0, 39, '1952'),
	(377, 1, 0, -50246, 1954, 0, 0, 39, '1953'),
	(377, 1, 0, -50246, 1955, 0, 0, 39, '1954'),
	(377, 1, 0, -50246, 1956, 0, 0, 39, '1955'),
	(377, 1, 0, -50246, 1957, 0, 0, 39, '1956'),
	(377, 1, 0, -50246, 1958, 0, 0, 39, '1957'),
	(377, 1, 0, -50246, 1959, 0, 0, 39, '1958'),
	(377, 1, 0, -50246, 1960, 0, 0, 39, '1959'),
	(377, 1, 0, -50246, 1961, 0, 0, 39, '1960'),
	(377, 1, 0, -50246, 1962, 0, 0, 39, '1961'),
	(377, 1, 0, -50246, 1963, 0, 0, 39, '1962'),
	(377, 1, 0, -50246, 1964, 0, 0, 39, '1963'),
	(377, 1, 0, -50246, 1965, 0, 0, 39, '1964'),
	(377, 1, 0, -50246, 1966, 0, 0, 39, '1965'),
	(377, 1, 0, -50246, 1967, 0, 0, 39, '1966'),
	(377, 1, 0, -50246, 1968, 0, 0, 39, '1967'),
	(377, 1, 0, -50246, 1969, 0, 0, 39, '1968'),
	(377, 1, 0, -50246, 1970, 0, 0, 39, '1969'),
	(377, 1, 0, -50246, 1971, 0, 0, 39, '1970'),
	(377, 1, 0, -50246, 1972, 0, 0, 39, '1971'),
	(377, 1, 0, -50246, 1973, 0, 0, 39, '1972'),
	(377, 1, 0, -50246, 1974, 0, 0, 39, '1973'),
	(377, 1, 0, -50246, 1975, 0, 0, 39, '1974'),
	(377, 1, 0, -50246, 1976, 0, 0, 39, '1975'),
	(377, 1, 0, -50246, 1977, 0, 0, 39, '1976'),
	(377, 1, 0, -50246, 1978, 0, 0, 39, '1977'),
	(377, 1, 0, -50246, 1979, 0, 0, 39, '1978'),
	(377, 1, 0, -50246, 1980, 0, 0, 39, '1979'),
	(377, 1, 0, -50246, 1981, 0, 0, 39, '1980'),
	(377, 1, 0, -50246, 1982, 0, 0, 39, '1981'),
	(377, 1, 0, -50246, 1983, 0, 0, 39, '1982'),
	(377, 1, 0, -50246, 1984, 0, 0, 39, '1983'),
	(377, 1, 0, -50246, 1985, 0, 0, 39, '1984'),
	(377, 1, 0, -50246, 1986, 0, 0, 39, '1985'),
	(377, 1, 0, -50246, 1987, 0, 0, 39, '1986'),
	(377, 1, 0, -50246, 1988, 0, 0, 39, '1987'),
	(377, 1, 0, -50246, 1989, 0, 0, 39, '1988'),
	(377, 1, 0, -50246, 1990, 0, 0, 39, '1989'),
	(377, 1, 0, -50246, 1991, 0, 0, 39, '1990'),
	(377, 1, 0, -50246, 1992, 0, 0, 39, '1991'),
	(377, 1, 0, -50246, 1993, 0, 0, 39, '1992'),
	(377, 1, 0, -50246, 1994, 0, 0, 39, '1993'),
	(377, 1, 0, -50246, 1995, 0, 0, 39, '1994'),
	(377, 1, 0, -50246, 1996, 0, 0, 39, '1995'),
	(377, 1, 0, -50246, 1997, 0, 0, 39, '1996'),
	(377, 1, 0, -50246, 1998, 0, 0, 39, '1997'),
	(377, 1, 0, -50246, 1999, 0, 0, 39, '1998'),
	(377, 1, 0, -50246, 2000, 0, 0, 39, '1999'),
	(377, 1, 0, -50246, 2001, 0, 0, 39, '2000'),
	(377, 1, 0, -50246, 2002, 0, 0, 39, '2001'),
	(377, 1, 0, -50246, 2003, 0, 0, 39, '2002'),
	(377, 1, 0, -50246, 2004, 0, 0, 39, '2003'),
	(377, 1, 0, -50246, 2005, 0, 0, 39, '2004'),
	(377, 1, 0, -50246, 2006, 0, 0, 39, '2005'),
	(377, 1, 0, -50246, 2007, 0, 0, 39, '2006'),
	(377, 1, 0, -50246, 2008, 0, 0, 39, '2007'),
	(377, 1, 0, -50246, 2009, 0, 0, 39, '2008'),
	(377, 1, 0, -50246, 2010, 0, 0, 39, '2009'),
	(377, 1, 0, -50246, 2011, 0, 0, 39, '2010'),
	(377, 1, 0, -50246, 2012, 0, 0, 39, '2011'),
	(377, 1, 0, -50246, 2013, 0, 0, 39, '2012'),
	(377, 1, 0, -50246, 2014, 0, 0, 39, '2013'),
	(377, 1, 0, -50246, 2015, 0, 0, 39, '2014'),
	(377, 1, 0, -50246, 2016, 0, 0, 39, '2015'),
	(377, 1, 0, -50246, 2017, 0, 0, 39, '2016'),
	(377, 1, 0, -50246, 2018, 0, 0, 39, '2017'),
	(377, 1, 0, -50246, 2019, 0, 0, 39, '2018'),
	(377, 1, 0, -50246, 2020, 0, 0, 39, '2019'),
	(377, 1, 0, -50246, 2021, 0, 0, 39, '2020'),
	(377, 1, 0, -50246, 2022, 0, 0, 39, '2021'),
	(377, 1, 0, -50246, 2023, 0, 0, 39, '2022'),
	(377, 1, 0, -50246, 2024, 0, 0, 39, '2023'),
	(377, 1, 0, -50246, 2025, 0, 0, 39, '2024'),
	(377, 1, 0, -50246, 2026, 0, 0, 39, '2025'),
	(377, 1, 0, -50246, 2027, 0, 0, 39, '2026'),
	(377, 1, 0, -50246, 2028, 0, 0, 39, '2027'),
	(377, 1, 0, -50246, 2029, 0, 0, 39, '2028'),
	(377, 1, 0, -50246, 2030, 0, 0, 39, '2029'),
	(377, 1, 0, -50246, 2031, 0, 0, 39, '2030'),
	(377, 1, 0, -50246, 2032, 0, 0, 39, '2031'),
	(377, 1, 0, -50246, 2033, 0, 0, 39, '2032'),
	(377, 1, 0, -50246, 2034, 0, 0, 39, '2033'),
	(377, 1, 0, -50246, 2035, 0, 0, 39, '2034'),
	(377, 1, 0, -50246, 2036, 0, 0, 39, '2035'),
	(377, 1, 0, -50246, 2037, 0, 0, 39, '2036'),
	(377, 1, 0, -50246, 2038, 0, 0, 39, '2037'),
	(377, 1, 0, -50246, 2039, 0, 0, 39, '2038'),
	(377, 1, 0, -50246, 2040, 0, 0, 39, '2039'),
	(377, 1, 0, -50246, 2041, 0, 0, 39, '2040'),
	(377, 1, 0, -50246, 2042, 0, 0, 39, '2041'),
	(377, 1, 0, -50246, 2043, 0, 0, 39, '2042'),
	(377, 1, 0, -50246, 2044, 0, 0, 39, '2043'),
	(377, 1, 0, -50246, 2045, 0, 0, 39, '2044'),
	(377, 1, 0, -50246, 2046, 0, 0, 39, '2045'),
	(377, 1, 0, -50246, 2047, 0, 0, 39, '2046'),
	(377, 1, 0, -50246, 2048, 0, 0, 39, '2047'),
	(377, 1, 0, -50246, 2049, 0, 0, 39, '2048'),
	(377, 1, 0, -50246, 2050, 0, 0, 39, '2049'),
	(377, 1, 0, -50246, 2051, 0, 0, 39, '2050'),
	(377, 1, 0, -50246, 2052, 0, 0, 39, '2051'),
	(377, 1, 0, -50246, 2053, 0, 0, 39, '2052'),
	(377, 1, 0, -50246, 2054, 0, 0, 39, '2053'),
	(377, 1, 0, -50246, 2055, 0, 0, 39, '2054'),
	(377, 1, 0, -50246, 2056, 0, 0, 39, '2055'),
	(377, 1, 0, -50246, 2057, 0, 0, 39, '2056'),
	(377, 1, 0, -50246, 2058, 0, 0, 39, '2057'),
	(377, 1, 0, -50246, 2059, 0, 0, 39, '2058'),
	(377, 1, 0, -50246, 2060, 0, 0, 39, '2059'),
	(377, 1, 0, -50246, 2061, 0, 0, 39, '2060'),
	(377, 1, 0, -50246, 2062, 0, 0, 39, '2061'),
	(377, 1, 0, -50246, 2063, 0, 0, 39, '2062'),
	(377, 1, 0, -50246, 2064, 0, 0, 39, '2063'),
	(377, 1, 0, -50246, 2065, 0, 0, 39, '2064'),
	(377, 1, 0, -50246, 2066, 0, 0, 39, '2065'),
	(377, 1, 0, -50246, 2067, 0, 0, 39, '2066'),
	(377, 1, 0, -50246, 2068, 0, 0, 39, '2067'),
	(377, 1, 0, -50246, 2069, 0, 0, 39, '2068'),
	(377, 1, 0, -50246, 2070, 0, 0, 39, '2069'),
	(377, 1, 0, -50246, 2071, 0, 0, 39, '2070'),
	(377, 1, 0, -50246, 2072, 0, 0, 39, '2071'),
	(377, 1, 0, -50246, 2073, 0, 0, 39, '2072'),
	(377, 1, 0, -50246, 2074, 0, 0, 39, '2073'),
	(377, 1, 0, -50246, 2075, 0, 0, 39, '2074'),
	(377, 1, 0, -50246, 2076, 0, 0, 39, '2075'),
	(377, 1, 0, -50246, 2077, 0, 0, 39, '2076'),
	(377, 1, 0, -50246, 2078, 0, 0, 39, '2077'),
	(377, 1, 0, -50246, 2079, 0, 0, 39, '2078'),
	(377, 1, 0, -50246, 2080, 0, 0, 39, '2079'),
	(377, 1, 0, -50246, 2081, 0, 0, 39, '2080'),
	(377, 1, 0, -50246, 2082, 0, 0, 39, '2081'),
	(377, 1, 0, -50246, 2083, 0, 0, 39, '2082'),
	(377, 1, 0, -50246, 2084, 0, 0, 39, '2083'),
	(377, 1, 0, -50246, 2085, 0, 0, 39, '2084'),
	(377, 1, 0, -50246, 2086, 0, 0, 39, '2085'),
	(377, 1, 0, -50246, 2087, 0, 0, 39, '2086'),
	(377, 1, 0, -50246, 2088, 0, 0, 39, '2087'),
	(377, 1, 0, -50246, 2089, 0, 0, 39, '2088'),
	(377, 1, 0, -50246, 2090, 0, 0, 39, '2089'),
	(377, 1, 0, -50246, 2091, 0, 0, 39, '2090'),
	(377, 1, 0, -50246, 2092, 0, 0, 39, '2091'),
	(377, 1, 0, -50246, 2093, 0, 0, 39, '2092'),
	(377, 1, 0, -50246, 2094, 0, 0, 39, '2093'),
	(377, 1, 0, -50246, 2095, 0, 0, 39, '2094'),
	(377, 1, 0, -50246, 2096, 0, 0, 39, '2095'),
	(377, 1, 0, -50246, 2097, 0, 0, 39, '2096'),
	(377, 1, 0, -50246, 2098, 0, 0, 39, '2097'),
	(377, 1, 0, -50246, 2099, 0, 0, 39, '2098'),
	(377, 1, 0, -50246, 2100, 0, 0, 39, '2099'),
	(377, 1, 0, -50246, 2101, 0, 0, 39, '2100'),
	(377, 1, 0, -50246, 2102, 0, 0, 39, '2101'),
	(377, 1, 0, -50246, 2103, 0, 0, 39, '2102'),
	(377, 1, 0, -50246, 2104, 0, 0, 39, '2103'),
	(377, 1, 0, -50246, 2105, 0, 0, 39, '2104'),
	(377, 1, 0, -50246, 2106, 0, 0, 39, '2105'),
	(377, 1, 0, -50246, 2107, 0, 0, 39, '2106'),
	(377, 1, 0, -50246, 2108, 0, 0, 39, '2107'),
	(377, 1, 0, -50246, 2109, 0, 0, 39, '2108'),
	(377, 1, 0, -50246, 2110, 0, 0, 39, '2109'),
	(377, 1, 0, -50246, 2111, 0, 0, 39, '2110'),
	(377, 1, 0, -50246, 2112, 0, 0, 39, '2111'),
	(377, 1, 0, -50246, 2113, 0, 0, 39, '2112'),
	(377, 1, 0, -50246, 2114, 0, 0, 39, '2113'),
	(377, 1, 0, -50246, 2115, 0, 0, 39, '2114'),
	(377, 1, 0, -50246, 2116, 0, 0, 39, '2115'),
	(377, 1, 0, -50246, 2117, 0, 0, 39, '2116'),
	(377, 1, 0, -50246, 2118, 0, 0, 39, '2117'),
	(377, 1, 0, -50246, 2119, 0, 0, 39, '2118'),
	(377, 1, 0, -50246, 2120, 0, 0, 39, '2119'),
	(377, 1, 0, -50246, 2121, 0, 0, 39, '2120'),
	(377, 1, 0, -50246, 2122, 0, 0, 39, '2121'),
	(377, 1, 0, -50246, 2123, 0, 0, 39, '2122'),
	(377, 1, 0, -50246, 2124, 0, 0, 39, '2123'),
	(377, 1, 0, -50246, 2125, 0, 0, 39, '2124'),
	(377, 1, 0, -50246, 2126, 0, 0, 39, '2125'),
	(377, 1, 0, -50246, 2127, 0, 0, 39, '2126'),
	(377, 1, 0, -50246, 2128, 0, 0, 39, '2127'),
	(377, 1, 0, -50246, 2129, 0, 0, 39, '2128'),
	(377, 1, 0, -50246, 2130, 0, 0, 39, '2129'),
	(377, 1, 0, -50246, 2131, 0, 0, 39, '2130'),
	(377, 1, 0, -50246, 2132, 0, 0, 39, '2131'),
	(377, 1, 0, -50246, 2133, 0, 0, 39, '2132'),
	(377, 1, 0, -50246, 2134, 0, 0, 39, '2133'),
	(377, 1, 0, -50246, 2135, 0, 0, 39, '2134'),
	(377, 1, 0, -50246, 2136, 0, 0, 39, '2135'),
	(377, 1, 0, -50246, 2137, 0, 0, 39, '2136'),
	(377, 1, 0, -50246, 2138, 0, 0, 39, '2137'),
	(377, 1, 0, -50246, 2139, 0, 0, 39, '2138'),
	(377, 1, 0, -50246, 2140, 0, 0, 39, '2139'),
	(377, 1, 0, -50246, 2141, 0, 0, 39, '2140'),
	(377, 1, 0, -50246, 2142, 0, 0, 39, '2141'),
	(377, 1, 0, -50246, 2143, 0, 0, 39, '2142'),
	(377, 1, 0, -50246, 2144, 0, 0, 39, '2143'),
	(377, 1, 0, -50246, 2145, 0, 0, 39, '2144'),
	(377, 1, 0, -50246, 2146, 0, 0, 39, '2145'),
	(377, 1, 0, -50246, 2147, 0, 0, 39, '2146'),
	(377, 1, 0, -50246, 2148, 0, 0, 39, '2147'),
	(377, 1, 0, -50246, 2149, 0, 0, 39, '2148'),
	(377, 1, 0, -50246, 2150, 0, 0, 39, '2149'),
	(377, 1, 0, -50246, 2151, 0, 0, 39, '2150'),
	(377, 1, 0, -50246, 2152, 0, 0, 39, '2151'),
	(377, 1, 0, -50246, 2153, 0, 0, 39, '2152'),
	(377, 1, 0, -50246, 2154, 0, 0, 39, '2153'),
	(377, 1, 0, -50246, 2155, 0, 0, 39, '2154'),
	(377, 1, 0, -50246, 2156, 0, 0, 39, '2155'),
	(377, 1, 0, -50246, 2157, 0, 0, 39, '2156'),
	(377, 1, 0, -50246, 2158, 0, 0, 39, '2157'),
	(377, 1, 0, -50246, 2159, 0, 0, 39, '2158'),
	(377, 1, 0, -50246, 2160, 0, 0, 39, '2159'),
	(377, 1, 0, -50246, 2161, 0, 0, 39, '2160'),
	(377, 1, 0, -50246, 2162, 0, 0, 39, '2161'),
	(377, 1, 0, -50246, 2163, 0, 0, 39, '2162'),
	(377, 1, 0, -50246, 2164, 0, 0, 39, '2163'),
	(377, 1, 0, -50246, 2165, 0, 0, 39, '2164'),
	(377, 1, 0, -50246, 2166, 0, 0, 39, '2165'),
	(377, 1, 0, -50246, 2167, 0, 0, 39, '2166'),
	(377, 1, 0, -50246, 2168, 0, 0, 39, '2167'),
	(377, 1, 0, -50246, 2169, 0, 0, 39, '2168'),
	(377, 1, 0, -50246, 2170, 0, 0, 39, '2169'),
	(377, 1, 0, -50246, 2171, 0, 0, 39, '2170'),
	(377, 1, 0, -50246, 2172, 0, 0, 39, '2171'),
	(377, 1, 0, -50246, 2173, 0, 0, 39, '2172'),
	(377, 1, 0, -50246, 2174, 0, 0, 39, '2173'),
	(377, 1, 0, -50246, 2175, 0, 0, 39, '2174'),
	(377, 1, 0, -50246, 2176, 0, 0, 39, '2175'),
	(377, 1, 0, -50246, 2177, 0, 0, 39, '2176'),
	(377, 1, 0, -50246, 2178, 0, 0, 39, '2177'),
	(377, 1, 0, -50246, 2179, 0, 0, 39, '2178'),
	(377, 1, 0, -50246, 2180, 0, 0, 39, '2179'),
	(377, 1, 0, -50246, 2181, 0, 0, 39, '2180'),
	(377, 1, 0, -50246, 2182, 0, 0, 39, '2181'),
	(377, 1, 0, -50246, 2183, 0, 0, 39, '2182'),
	(377, 1, 0, -50246, 2184, 0, 0, 39, '2183'),
	(377, 1, 0, -50246, 2185, 0, 0, 39, '2184'),
	(377, 1, 0, -50246, 2186, 0, 0, 39, '2185'),
	(377, 1, 0, -50246, 2187, 0, 0, 39, '2186'),
	(377, 1, 0, -50246, 2188, 0, 0, 39, '2187'),
	(377, 1, 0, -50246, 2189, 0, 0, 39, '2188'),
	(377, 1, 0, -50246, 2190, 0, 0, 39, '2189'),
	(377, 1, 0, -50246, 2191, 0, 0, 39, '2190'),
	(377, 1, 0, -50246, 2192, 0, 0, 39, '2191'),
	(377, 1, 0, -50246, 2193, 0, 0, 39, '2192'),
	(377, 1, 0, -50246, 2194, 0, 0, 39, '2193'),
	(377, 1, 0, -50246, 2195, 0, 0, 39, '2194'),
	(377, 1, 0, -50246, 2196, 0, 0, 39, '2195'),
	(377, 1, 0, -50246, 2197, 0, 0, 39, '2196'),
	(377, 1, 0, -50246, 2198, 0, 0, 39, '2197'),
	(377, 1, 0, -50246, 2199, 0, 0, 39, '2198'),
	(377, 1, 0, -50246, 2200, 0, 0, 39, '2199'),
	(377, 1, 0, -50246, 2201, 0, 0, 39, '2200'),
	(377, 1, 0, -50246, 2202, 0, 0, 39, '2201'),
	(377, 1, 0, -50246, 2203, 0, 0, 39, '2202'),
	(377, 1, 0, -50246, 2204, 0, 0, 39, '2203'),
	(377, 1, 0, -50246, 2205, 0, 0, 39, '2204'),
	(377, 1, 0, -50246, 2206, 0, 0, 39, '2205'),
	(377, 1, 0, -50246, 2207, 0, 0, 39, '2206'),
	(377, 1, 0, -50246, 2208, 0, 0, 39, '2207'),
	(377, 1, 0, -50246, 2209, 0, 0, 39, '2208'),
	(377, 1, 0, -50246, 2210, 0, 0, 39, '2209'),
	(377, 1, 0, -50246, 2211, 0, 0, 39, '2210'),
	(377, 1, 0, -50246, 2212, 0, 0, 39, '2211'),
	(377, 1, 0, -50246, 2213, 0, 0, 39, '2212'),
	(377, 1, 0, -50246, 2214, 0, 0, 39, '2213'),
	(377, 1, 0, -50246, 2215, 0, 0, 39, '2214'),
	(377, 1, 0, -50246, 2216, 0, 0, 39, '2215'),
	(377, 1, 0, -50246, 2217, 0, 0, 39, '2216'),
	(377, 1, 0, -50246, 2218, 0, 0, 39, '2217'),
	(377, 1, 0, -50246, 2219, 0, 0, 39, '2218'),
	(377, 1, 0, -50246, 2220, 0, 0, 39, '2219'),
	(377, 1, 0, -50246, 2221, 0, 0, 39, '2220'),
	(377, 1, 0, -50246, 2222, 0, 0, 39, '2221'),
	(377, 1, 0, -50246, 2223, 0, 0, 39, '2222'),
	(377, 1, 0, -50246, 2224, 0, 0, 39, '2223'),
	(377, 1, 0, -50246, 2225, 0, 0, 39, '2224'),
	(377, 1, 0, -50246, 2226, 0, 0, 39, '2225'),
	(377, 1, 0, -50246, 2227, 0, 0, 39, '2226'),
	(377, 1, 0, -50246, 2228, 0, 0, 39, '2227'),
	(377, 1, 0, -50246, 2229, 0, 0, 39, '2228'),
	(377, 1, 0, -50246, 2230, 0, 0, 39, '2229'),
	(377, 1, 0, -50246, 2231, 0, 0, 39, '2230'),
	(377, 1, 0, -50246, 2232, 0, 0, 39, '2231'),
	(377, 1, 0, -50246, 2233, 0, 0, 39, '2232'),
	(377, 1, 0, -50246, 2234, 0, 0, 39, '2233'),
	(377, 1, 0, -50246, 2235, 0, 0, 39, '2234'),
	(377, 1, 0, -50246, 2236, 0, 0, 39, '2235'),
	(377, 1, 0, -50246, 2237, 0, 0, 39, '2236'),
	(377, 1, 0, -50246, 2238, 0, 0, 39, '2237'),
	(377, 1, 0, -50246, 2239, 0, 0, 39, '2238'),
	(377, 1, 0, -50246, 2240, 0, 0, 39, '2239'),
	(377, 1, 0, -50246, 2241, 0, 0, 39, '2240'),
	(377, 1, 0, -50246, 2242, 0, 0, 39, '2241'),
	(377, 1, 0, -50246, 2243, 0, 0, 39, '2242'),
	(377, 1, 0, -50246, 2244, 0, 0, 39, '2243'),
	(377, 1, 0, -50246, 2245, 0, 0, 39, '2244'),
	(377, 1, 0, -50246, 2246, 0, 0, 39, '2245'),
	(377, 1, 0, -50246, 2247, 0, 0, 39, '2246'),
	(377, 1, 0, -50246, 2248, 0, 0, 39, '2247'),
	(377, 1, 0, -50246, 2249, 0, 0, 39, '2248'),
	(377, 1, 0, -50246, 2250, 0, 0, 39, '2249'),
	(377, 1, 0, -50246, 2251, 0, 0, 39, '2250'),
	(377, 1, 0, -50246, 2252, 0, 0, 39, '2251'),
	(377, 1, 0, -50246, 2253, 0, 0, 39, '2252'),
	(377, 1, 0, -50246, 2254, 0, 0, 39, '2253'),
	(377, 1, 0, -50246, 2255, 0, 0, 39, '2254'),
	(377, 1, 0, -50246, 2256, 0, 0, 39, '2255'),
	(377, 1, 0, -50246, 2257, 0, 0, 39, '2256'),
	(377, 1, 0, -50246, 2258, 0, 0, 39, '2257'),
	(377, 1, 0, -50246, 2259, 0, 0, 39, '2258'),
	(377, 1, 0, -50246, 2260, 0, 0, 39, '2259'),
	(377, 1, 0, -50246, 2261, 0, 0, 39, '2260'),
	(377, 1, 0, -50246, 2262, 0, 0, 39, '2261'),
	(377, 1, 0, -50246, 2263, 0, 0, 39, '2262'),
	(377, 1, 0, -50246, 2264, 0, 0, 39, '2263'),
	(377, 1, 0, -50246, 2265, 0, 0, 39, '2264'),
	(377, 1, 0, -50246, 2266, 0, 0, 39, '2265'),
	(377, 1, 0, -50246, 2267, 0, 0, 39, '2266'),
	(377, 1, 0, -50246, 2268, 0, 0, 39, '2267'),
	(377, 1, 0, -50246, 2269, 0, 0, 39, '2268'),
	(377, 1, 0, -50246, 2270, 0, 0, 39, '2269'),
	(377, 1, 0, -50246, 2271, 0, 0, 39, '2270'),
	(377, 1, 0, -50246, 2272, 0, 0, 39, '2271'),
	(377, 1, 0, -50246, 2273, 0, 0, 39, '2272'),
	(377, 1, 0, -50246, 2274, 0, 0, 39, '2273'),
	(377, 1, 0, -50246, 2275, 0, 0, 39, '2274'),
	(377, 1, 0, -50246, 2276, 0, 0, 39, '2275'),
	(377, 1, 0, -50246, 2277, 0, 0, 39, '2276'),
	(377, 1, 0, -50246, 2278, 0, 0, 39, '2277'),
	(377, 1, 0, -50246, 2279, 0, 0, 39, '2278'),
	(377, 1, 0, -50246, 2280, 0, 0, 39, '2279'),
	(377, 1, 0, -50246, 2281, 0, 0, 39, '2280'),
	(377, 1, 0, -50246, 2282, 0, 0, 39, '2281'),
	(377, 1, 0, -50246, 2283, 0, 0, 39, '2282'),
	(377, 1, 0, -50246, 2284, 0, 0, 39, '2283'),
	(377, 1, 0, -50246, 2285, 0, 0, 39, '2284'),
	(377, 1, 0, -50246, 2286, 0, 0, 39, '2285'),
	(377, 1, 0, -50246, 2287, 0, 0, 39, '2286'),
	(377, 1, 0, -50246, 2288, 0, 0, 39, '2287'),
	(377, 1, 0, -50246, 2289, 0, 0, 39, '2288'),
	(377, 1, 0, -50246, 2290, 0, 0, 39, '2289'),
	(377, 1, 0, -50246, 2291, 0, 0, 39, '2290'),
	(377, 1, 0, -50246, 2292, 0, 0, 39, '2291'),
	(377, 1, 0, -50246, 2293, 0, 0, 39, '2292'),
	(377, 1, 0, -50246, 2294, 0, 0, 39, '2293'),
	(377, 1, 0, -50246, 2295, 0, 0, 39, '2294'),
	(377, 1, 0, -50246, 2296, 0, 0, 39, '2295'),
	(377, 1, 0, -50246, 2297, 0, 0, 39, '2296'),
	(377, 1, 0, -50246, 2298, 0, 0, 39, '2297'),
	(377, 1, 0, -50246, 2299, 0, 0, 39, '2298'),
	(377, 1, 0, -50246, 2300, 0, 0, 39, '2299'),
	(377, 1, 0, -50246, 2301, 0, 0, 39, '2300'),
	(377, 1, 0, -50246, 2302, 0, 0, 39, '2301'),
	(377, 1, 0, -50246, 2303, 0, 0, 39, '2302'),
	(377, 1, 0, -50246, 2304, 0, 0, 39, '2303'),
	(377, 1, 0, -50246, 2305, 0, 0, 39, '2304'),
	(377, 1, 0, -50246, 2306, 0, 0, 39, '2305'),
	(377, 1, 0, -50246, 2307, 0, 0, 39, '2306'),
	(377, 1, 0, -50246, 2308, 0, 0, 39, '2307'),
	(377, 1, 0, -50246, 2309, 0, 0, 39, '2308'),
	(377, 1, 0, -50246, 2310, 0, 0, 39, '2309'),
	(377, 1, 0, -50246, 2311, 0, 0, 39, '2310'),
	(377, 1, 0, -50246, 2312, 0, 0, 39, '2311'),
	(377, 1, 0, -50246, 2313, 0, 0, 39, '2312'),
	(377, 1, 0, -50246, 2314, 0, 0, 39, '2313'),
	(377, 1, 0, -50246, 2315, 0, 0, 39, '2314'),
	(377, 1, 0, -50246, 2316, 0, 0, 39, '2315'),
	(377, 1, 0, -50246, 2317, 0, 0, 39, '2316'),
	(377, 1, 0, -50246, 2318, 0, 0, 39, '2317'),
	(377, 1, 0, -50246, 2319, 0, 0, 39, '2318'),
	(377, 1, 0, -50246, 2320, 0, 0, 39, '2319'),
	(377, 1, 0, -50246, 2321, 0, 0, 39, '2320'),
	(377, 1, 0, -50246, 2322, 0, 0, 39, '2321'),
	(377, 1, 0, -50246, 2323, 0, 0, 39, '2322'),
	(377, 1, 0, -50246, 2324, 0, 0, 39, '2323'),
	(377, 1, 0, -50246, 2325, 0, 0, 39, '2324'),
	(377, 1, 0, -50246, 2326, 0, 0, 39, '2325'),
	(377, 1, 0, -50246, 2327, 0, 0, 39, '2326'),
	(377, 1, 0, -50246, 2328, 0, 0, 39, '2327'),
	(377, 1, 0, -50246, 2329, 0, 0, 39, '2328'),
	(377, 1, 0, -50246, 2330, 0, 0, 39, '2329'),
	(377, 1, 0, -50246, 2331, 0, 0, 39, '2330'),
	(377, 1, 0, -50246, 2332, 0, 0, 39, '2331'),
	(377, 1, 0, -50246, 2333, 0, 0, 39, '2332'),
	(377, 1, 0, -50246, 2334, 0, 0, 39, '2333'),
	(377, 1, 0, -50246, 2335, 0, 0, 39, '2334'),
	(377, 1, 0, -50246, 2336, 0, 0, 39, '2335'),
	(377, 1, 0, -50246, 2337, 0, 0, 39, '2336'),
	(377, 1, 0, -50246, 2338, 0, 0, 39, '2337'),
	(377, 1, 0, -50246, 2339, 0, 0, 39, '2338'),
	(377, 1, 0, -50246, 2340, 0, 0, 39, '2339'),
	(377, 1, 0, -50246, 2341, 0, 0, 39, '2340'),
	(377, 1, 0, -50246, 2342, 0, 0, 39, '2341'),
	(377, 1, 0, -50246, 2343, 0, 0, 39, '2342'),
	(377, 1, 0, -50246, 2344, 0, 0, 39, '2343'),
	(377, 1, 0, -50246, 2345, 0, 0, 39, '2344'),
	(377, 1, 0, -50246, 2346, 0, 0, 39, '2345'),
	(377, 1, 0, -50246, 2347, 0, 0, 39, '2346'),
	(377, 1, 0, -50246, 2348, 0, 0, 39, '2347'),
	(377, 1, 0, -50246, 2349, 0, 0, 39, '2348'),
	(377, 1, 0, -50246, 2350, 0, 0, 39, '2349'),
	(377, 1, 0, -50246, 2351, 0, 0, 39, '2350'),
	(377, 1, 0, -50246, 2352, 0, 0, 39, '2351'),
	(377, 1, 0, -50246, 2353, 0, 0, 39, '2352'),
	(377, 1, 0, -50246, 2354, 0, 0, 39, '2353'),
	(377, 1, 0, -50246, 2355, 0, 0, 39, '2354'),
	(377, 1, 0, -50246, 2356, 0, 0, 39, '2355'),
	(377, 1, 0, -50246, 2357, 0, 0, 39, '2356'),
	(377, 1, 0, -50246, 2358, 0, 0, 39, '2357'),
	(377, 1, 0, -50246, 2359, 0, 0, 39, '2358'),
	(377, 1, 0, -50246, 2360, 0, 0, 39, '2359'),
	(377, 1, 0, -50246, 2361, 0, 0, 39, '2360'),
	(377, 1, 0, -50246, 2362, 0, 0, 39, '2361'),
	(377, 1, 0, -50246, 2363, 0, 0, 39, '2362'),
	(377, 1, 0, -50246, 2364, 0, 0, 39, '2363'),
	(377, 1, 0, -50246, 2365, 0, 0, 39, '2364'),
	(377, 1, 0, -50246, 2366, 0, 0, 39, '2365'),
	(377, 1, 0, -50246, 2367, 0, 0, 39, '2366'),
	(377, 1, 0, -50246, 2368, 0, 0, 39, '2367'),
	(377, 1, 0, -50246, 2369, 0, 0, 39, '2368'),
	(377, 1, 0, -50246, 2370, 0, 0, 39, '2369'),
	(377, 1, 0, -50246, 2371, 0, 0, 39, '2370'),
	(377, 1, 0, -50246, 2372, 0, 0, 39, '2371'),
	(377, 1, 0, -50246, 2373, 0, 0, 39, '2372'),
	(377, 1, 0, -50246, 2374, 0, 0, 39, '2373'),
	(377, 1, 0, -50246, 2375, 0, 0, 39, '2374'),
	(377, 1, 0, -50246, 2376, 0, 0, 39, '2375'),
	(377, 1, 0, -50246, 2377, 0, 0, 39, '2376'),
	(377, 1, 0, -50246, 2378, 0, 0, 39, '2377'),
	(377, 1, 0, -50246, 2379, 0, 0, 39, '2378'),
	(377, 1, 0, -50246, 2380, 0, 0, 39, '2379'),
	(377, 1, 0, -50246, 2381, 0, 0, 39, '2380'),
	(377, 1, 0, -50246, 2382, 0, 0, 39, '2381'),
	(377, 1, 0, -50246, 2383, 0, 0, 39, '2382'),
	(377, 1, 0, -50246, 2384, 0, 0, 39, '2383'),
	(377, 1, 0, -50246, 2385, 0, 0, 39, '2384'),
	(377, 1, 0, -50246, 2386, 0, 0, 39, '2385'),
	(377, 1, 0, -50246, 2387, 0, 0, 39, '2386'),
	(377, 1, 0, -50246, 2388, 0, 0, 39, '2387'),
	(377, 1, 0, -50246, 2389, 0, 0, 39, '2388'),
	(377, 1, 0, -50246, 2390, 0, 0, 39, '2389'),
	(377, 1, 0, -50246, 2391, 0, 0, 39, '2390'),
	(377, 1, 0, -50246, 2392, 0, 0, 39, '2391'),
	(377, 1, 0, -50246, 2393, 0, 0, 39, '2392'),
	(377, 1, 0, -50246, 2394, 0, 0, 39, '2393'),
	(377, 1, 0, -50246, 2395, 0, 0, 39, '2394'),
	(377, 1, 0, -50246, 2396, 0, 0, 39, '2395'),
	(377, 1, 0, -50246, 2397, 0, 0, 39, '2396'),
	(377, 1, 0, -50246, 2398, 0, 0, 39, '2397'),
	(377, 1, 0, -50246, 2399, 0, 0, 39, '2398'),
	(377, 1, 0, -50246, 2400, 0, 0, 39, '2399'),
	(377, 1, 0, -50246, 2401, 0, 0, 39, '2400'),
	(377, 1, 0, -50246, 2402, 0, 0, 39, '2401'),
	(377, 1, 0, -50246, 2403, 0, 0, 39, '2402'),
	(377, 1, 0, -50246, 2404, 0, 0, 39, '2403'),
	(377, 1, 0, -50246, 2405, 0, 0, 39, '2404'),
	(377, 1, 0, -50246, 2406, 0, 0, 39, '2405'),
	(377, 1, 0, -50246, 2407, 0, 0, 39, '2406'),
	(377, 1, 0, -50246, 2408, 0, 0, 39, '2407'),
	(377, 1, 0, -50246, 2409, 0, 0, 39, '2408'),
	(377, 1, 0, -50246, 2410, 0, 0, 39, '2409'),
	(377, 1, 0, -50246, 2411, 0, 0, 39, '2410'),
	(377, 1, 0, -50246, 2412, 0, 0, 39, '2411'),
	(377, 1, 0, -50246, 2413, 0, 0, 39, '2412'),
	(377, 1, 0, -50246, 2414, 0, 0, 39, '2413'),
	(377, 1, 0, -50246, 2415, 0, 0, 39, '2414'),
	(377, 1, 0, -50246, 2416, 0, 0, 39, '2415'),
	(377, 1, 0, -50246, 2417, 0, 0, 39, '2416'),
	(377, 1, 0, -50246, 2418, 0, 0, 39, '2417'),
	(377, 1, 0, -50246, 2419, 0, 0, 39, '2418'),
	(377, 1, 0, -50246, 2420, 0, 0, 39, '2419'),
	(377, 1, 0, -50246, 2421, 0, 0, 39, '2420'),
	(377, 1, 0, -50246, 2422, 0, 0, 39, '2421'),
	(377, 1, 0, -50246, 2423, 0, 0, 39, '2422'),
	(377, 1, 0, -50246, 2424, 0, 0, 39, '2423'),
	(377, 1, 0, -50246, 2425, 0, 0, 39, '2424'),
	(377, 1, 0, -50246, 2426, 0, 0, 39, '2425'),
	(377, 1, 0, -50246, 2427, 0, 0, 39, '2426'),
	(377, 1, 0, -50246, 2428, 0, 0, 39, '2427'),
	(377, 1, 0, -50246, 2429, 0, 0, 39, '2428'),
	(377, 1, 0, -50246, 2430, 0, 0, 39, '2429'),
	(377, 1, 0, -50246, 2431, 0, 0, 39, '2430'),
	(377, 1, 0, -50246, 2432, 0, 0, 39, '2431'),
	(377, 1, 0, -50246, 2433, 0, 0, 39, '2432'),
	(377, 1, 0, -50246, 2434, 0, 0, 39, '2433'),
	(377, 1, 0, -50246, 2435, 0, 0, 39, '2434'),
	(377, 1, 0, -50246, 2436, 0, 0, 39, '2435'),
	(377, 1, 0, -50246, 2437, 0, 0, 39, '2436'),
	(377, 1, 0, -50246, 2438, 0, 0, 39, '2437'),
	(377, 1, 0, -50246, 2439, 0, 0, 39, '2438'),
	(377, 1, 0, -50246, 2440, 0, 0, 39, '2439'),
	(377, 1, 0, -50246, 2441, 0, 0, 39, '2440'),
	(377, 1, 0, -50246, 2442, 0, 0, 39, '2441'),
	(377, 1, 0, -50246, 2443, 0, 0, 39, '2442'),
	(377, 1, 0, -50246, 2444, 0, 0, 39, '2443'),
	(377, 1, 0, -50246, 2445, 0, 0, 39, '2444'),
	(377, 1, 0, -50246, 2446, 0, 0, 39, '2445'),
	(377, 1, 0, -50246, 2447, 0, 0, 39, '2446'),
	(377, 1, 0, -50246, 2448, 0, 0, 39, '2447'),
	(377, 1, 0, -50246, 2449, 0, 0, 39, '2448'),
	(377, 1, 0, -50246, 2450, 0, 0, 39, '2449'),
	(377, 1, 0, -50246, 2451, 0, 0, 39, '2450'),
	(377, 1, 0, -50246, 2452, 0, 0, 39, '2451'),
	(377, 1, 0, -50246, 2453, 0, 0, 39, '2452'),
	(377, 1, 0, -50246, 2454, 0, 0, 39, '2453'),
	(377, 1, 0, -50246, 2455, 0, 0, 39, '2454'),
	(377, 1, 0, -50246, 2456, 0, 0, 39, '2455'),
	(377, 1, 0, -50246, 2457, 0, 0, 39, '2456'),
	(377, 1, 0, -50246, 2458, 0, 0, 39, '2457'),
	(377, 1, 0, -50246, 2459, 0, 0, 39, '2458'),
	(377, 1, 0, -50246, 2460, 0, 0, 39, '2459'),
	(377, 1, 0, -50246, 2461, 0, 0, 39, '2460'),
	(377, 1, 0, -50246, 2462, 0, 0, 39, '2461'),
	(377, 1, 0, -50246, 2463, 0, 0, 39, '2462'),
	(377, 1, 0, -50246, 2464, 0, 0, 39, '2463'),
	(377, 1, 0, -50246, 2465, 0, 0, 39, '2464'),
	(377, 1, 0, -50246, 2466, 0, 0, 39, '2465'),
	(377, 1, 0, -50246, 2467, 0, 0, 39, '2466'),
	(377, 1, 0, -50246, 2468, 0, 0, 39, '2467'),
	(377, 1, 0, -50246, 2469, 0, 0, 39, '2468'),
	(377, 1, 0, -50246, 2470, 0, 0, 39, '2469'),
	(377, 1, 0, -50246, 2471, 0, 0, 39, '2470'),
	(377, 1, 0, -50246, 2472, 0, 0, 39, '2471'),
	(377, 1, 0, -50246, 2473, 0, 0, 39, '2472'),
	(377, 1, 0, -50246, 2474, 0, 0, 39, '2473'),
	(377, 1, 0, -50246, 2475, 0, 0, 39, '2474'),
	(377, 1, 0, -50246, 2476, 0, 0, 39, '2475'),
	(377, 1, 0, -50246, 2477, 0, 0, 39, '2476'),
	(377, 1, 0, -50246, 2478, 0, 0, 39, '2477'),
	(377, 1, 0, -50246, 2479, 0, 0, 39, '2478'),
	(377, 1, 0, -50246, 2480, 0, 0, 39, '2479'),
	(377, 1, 0, -50246, 2481, 0, 0, 39, '2480'),
	(377, 1, 0, -50246, 2482, 0, 0, 39, '2481'),
	(377, 1, 0, -50246, 2483, 0, 0, 39, '2482'),
	(377, 1, 0, -50246, 2484, 0, 0, 39, '2483'),
	(377, 1, 0, -50246, 2485, 0, 0, 39, '2484'),
	(377, 1, 0, -50246, 2486, 0, 0, 39, '2485'),
	(377, 1, 0, -50246, 2487, 0, 0, 39, '2486'),
	(377, 1, 0, -50246, 2488, 0, 0, 39, '2487'),
	(377, 1, 0, -50246, 2489, 0, 0, 39, '2488'),
	(377, 1, 0, -50246, 2490, 0, 0, 39, '2489'),
	(377, 1, 0, -50246, 2491, 0, 0, 39, '2490'),
	(377, 1, 0, -50246, 2492, 0, 0, 39, '2491'),
	(377, 1, 0, -50246, 2493, 0, 0, 39, '2492'),
	(377, 1, 0, -50246, 2494, 0, 0, 39, '2493'),
	(377, 1, 0, -50246, 2495, 0, 0, 39, '2494'),
	(377, 1, 0, -50246, 2496, 0, 0, 39, '2495'),
	(377, 1, 0, -50246, 2497, 0, 0, 39, '2496'),
	(377, 1, 0, -50246, 2498, 0, 0, 39, '2497'),
	(377, 1, 0, -50246, 2499, 0, 0, 39, '2498'),
	(377, 1, 0, -50246, 2500, 0, 0, 39, '2499'),
	(377, 1, 0, -50246, 2501, 0, 0, 39, '2500'),
	(377, 1, 0, -50246, 2502, 0, 0, 39, '2501'),
	(377, 1, 0, -50246, 2503, 0, 0, 39, '2502'),
	(377, 1, 0, -50246, 2504, 0, 0, 39, '2503'),
	(377, 1, 0, -50246, 2505, 0, 0, 39, '2504'),
	(377, 1, 0, -50246, 2506, 0, 0, 39, '2505'),
	(377, 1, 0, -50246, 2507, 0, 0, 39, '2506'),
	(377, 1, 0, -50246, 2508, 0, 0, 39, '2507'),
	(377, 1, 0, -50246, 2509, 0, 0, 39, '2508'),
	(377, 1, 0, -50246, 2510, 0, 0, 39, '2509'),
	(377, 1, 0, -50246, 2511, 0, 0, 39, '2510'),
	(377, 1, 0, -50246, 2512, 0, 0, 39, '2511'),
	(377, 1, 0, -50246, 2513, 0, 0, 39, '2512'),
	(377, 1, 0, -50246, 2514, 0, 0, 39, '2513'),
	(377, 1, 0, -50246, 2515, 0, 0, 39, '2514'),
	(377, 1, 0, -50246, 2516, 0, 0, 39, '2515'),
	(377, 1, 0, -50246, 2517, 0, 0, 39, '2516'),
	(377, 1, 0, -50246, 2518, 0, 0, 39, '2517'),
	(377, 1, 0, -50246, 2519, 0, 0, 39, '2518'),
	(377, 1, 0, -50246, 2520, 0, 0, 39, '2519'),
	(377, 1, 0, -50246, 2521, 0, 0, 39, '2520'),
	(377, 1, 0, -50246, 2522, 0, 0, 39, '2521'),
	(377, 1, 0, -50246, 2523, 0, 0, 39, '2522'),
	(377, 1, 0, -50246, 2524, 0, 0, 39, '2523'),
	(377, 1, 0, -50246, 2525, 0, 0, 39, '2524'),
	(377, 1, 0, -50246, 2526, 0, 0, 39, '2525'),
	(377, 1, 0, -50246, 2527, 0, 0, 39, '2526'),
	(377, 1, 0, -50246, 2528, 0, 0, 39, '2527'),
	(377, 1, 0, -50246, 2529, 0, 0, 39, '2528'),
	(377, 1, 0, -50246, 2530, 0, 0, 39, '2529'),
	(377, 1, 0, -50246, 2531, 0, 0, 39, '2530'),
	(377, 1, 0, -50246, 2532, 0, 0, 39, '2531'),
	(377, 1, 0, -50246, 2533, 0, 0, 39, '2532'),
	(377, 1, 0, -50246, 2534, 0, 0, 39, '2533'),
	(377, 1, 0, -50246, 2535, 0, 0, 39, '2534'),
	(377, 1, 0, -50246, 2536, 0, 0, 39, '2535'),
	(377, 1, 0, -50246, 2537, 0, 0, 39, '2536'),
	(377, 1, 0, -50246, 2538, 0, 0, 39, '2537'),
	(377, 1, 0, -50246, 2539, 0, 0, 39, '2538'),
	(377, 1, 0, -50246, 2540, 0, 0, 39, '2539'),
	(377, 1, 0, -50246, 2541, 0, 0, 39, '2540'),
	(377, 1, 0, -50246, 2542, 0, 0, 39, '2541'),
	(377, 1, 0, -50246, 2543, 0, 0, 39, '2542'),
	(377, 1, 0, -50246, 2544, 0, 0, 39, '2543'),
	(377, 1, 0, -50246, 2545, 0, 0, 39, '2544'),
	(377, 1, 0, -50246, 2546, 0, 0, 39, '2545'),
	(377, 1, 0, -50246, 2547, 0, 0, 39, '2546'),
	(377, 1, 0, -50246, 2548, 0, 0, 39, '2547'),
	(377, 1, 0, -50246, 2549, 0, 0, 39, '2548'),
	(377, 1, 0, -50246, 2550, 0, 0, 39, '2549'),
	(377, 1, 0, -50246, 2551, 0, 0, 39, '2550'),
	(377, 1, 0, -50246, 2552, 0, 0, 39, '2551'),
	(377, 1, 0, -50246, 2553, 0, 0, 39, '2552'),
	(377, 1, 0, -50246, 2554, 0, 0, 39, '2553'),
	(377, 1, 0, -50246, 2555, 0, 0, 39, '2554'),
	(377, 1, 0, -50246, 2556, 0, 0, 39, '2555'),
	(377, 1, 0, -50246, 2557, 0, 0, 39, '2556'),
	(377, 1, 0, -50246, 2558, 0, 0, 39, '2557'),
	(377, 1, 0, -50246, 2559, 0, 0, 39, '2558'),
	(377, 1, 0, -50246, 2560, 0, 0, 39, '2559'),
	(377, 1, 0, -50246, 2561, 0, 0, 39, '2560'),
	(377, 1, 0, -50246, 2562, 0, 0, 39, '2561'),
	(377, 1, 0, -50246, 2563, 0, 0, 39, '2562'),
	(377, 1, 0, -50246, 2564, 0, 0, 39, '2563'),
	(377, 1, 0, -50246, 2565, 0, 0, 39, '2564'),
	(377, 1, 0, -50246, 2566, 0, 0, 39, '2565'),
	(377, 1, 0, -50246, 2567, 0, 0, 39, '2566'),
	(377, 1, 0, -50246, 2568, 0, 0, 39, '2567'),
	(377, 1, 0, -50246, 2569, 0, 0, 39, '2568'),
	(377, 1, 0, -50246, 2570, 0, 0, 39, '2569'),
	(377, 1, 0, -50246, 2571, 0, 0, 39, '2570'),
	(377, 1, 0, -50246, 2572, 0, 0, 39, '2571'),
	(377, 1, 0, -50246, 2573, 0, 0, 39, '2572'),
	(377, 1, 0, -50246, 2574, 0, 0, 39, '2573'),
	(377, 1, 0, -50246, 2575, 0, 0, 39, '2574'),
	(377, 1, 0, -50246, 2576, 0, 0, 39, '2575'),
	(377, 1, 0, -50246, 2577, 0, 0, 39, '2576'),
	(377, 1, 0, -50246, 2578, 0, 0, 39, '2577'),
	(377, 1, 0, -50246, 2579, 0, 0, 39, '2578'),
	(377, 1, 0, -50246, 2580, 0, 0, 39, '2579'),
	(377, 1, 0, -50246, 2581, 0, 0, 39, '2580'),
	(377, 1, 0, -50246, 2582, 0, 0, 39, '2581'),
	(377, 1, 0, -50246, 2583, 0, 0, 39, '2582'),
	(377, 1, 0, -50246, 2584, 0, 0, 39, '2583'),
	(377, 1, 0, -50246, 2585, 0, 0, 39, '2584'),
	(377, 1, 0, -50246, 2586, 0, 0, 39, '2585'),
	(377, 1, 0, -50246, 2587, 0, 0, 39, '2586'),
	(377, 1, 0, -50246, 2588, 0, 0, 39, '2587'),
	(377, 1, 0, -50246, 2589, 0, 0, 39, '2588'),
	(377, 1, 0, -50246, 2590, 0, 0, 39, '2589'),
	(377, 1, 0, -50246, 2591, 0, 0, 39, '2590'),
	(377, 1, 0, -50246, 2592, 0, 0, 39, '2591'),
	(377, 1, 0, -50246, 2593, 0, 0, 39, '2592'),
	(377, 1, 0, -50246, 2594, 0, 0, 39, '2593'),
	(377, 1, 0, -50246, 2595, 0, 0, 39, '2594'),
	(377, 1, 0, -50246, 2596, 0, 0, 39, '2595'),
	(377, 1, 0, -50246, 2597, 0, 0, 39, '2596'),
	(377, 1, 0, -50246, 2598, 0, 0, 39, '2597'),
	(377, 1, 0, -50246, 2599, 0, 0, 39, '2598'),
	(377, 1, 0, -50246, 2600, 0, 0, 39, '2599'),
	(377, 1, 0, -50246, 2601, 0, 0, 39, '2600'),
	(377, 1, 0, -50246, 2602, 0, 0, 39, '2601'),
	(377, 1, 0, -50246, 2603, 0, 0, 39, '2602'),
	(377, 1, 0, -50246, 2604, 0, 0, 39, '2603'),
	(377, 1, 0, -50246, 2605, 0, 0, 39, '2604'),
	(377, 1, 0, -50246, 2606, 0, 0, 39, '2605'),
	(377, 1, 0, -50246, 2607, 0, 0, 39, '2606'),
	(377, 1, 0, -50246, 2608, 0, 0, 39, '2607'),
	(377, 1, 0, -50246, 2609, 0, 0, 39, '2608'),
	(377, 1, 0, -50246, 2610, 0, 0, 39, '2609'),
	(377, 1, 0, -50246, 2611, 0, 0, 39, '2610'),
	(377, 1, 0, -50246, 2612, 0, 0, 39, '2611'),
	(377, 1, 0, -50246, 2613, 0, 0, 39, '2612'),
	(377, 1, 0, -50246, 2614, 0, 0, 39, '2613'),
	(377, 1, 0, -50246, 2615, 0, 0, 39, '2614'),
	(377, 1, 0, -50246, 2616, 0, 0, 39, '2615'),
	(377, 1, 0, -50246, 2617, 0, 0, 39, '2616'),
	(377, 1, 0, -50246, 2618, 0, 0, 39, '2617'),
	(377, 1, 0, -50246, 2619, 0, 0, 39, '2618'),
	(377, 1, 0, -50246, 2620, 0, 0, 39, '2619'),
	(377, 1, 0, -50246, 2621, 0, 0, 39, '2620'),
	(377, 1, 0, -50246, 2622, 0, 0, 39, '2621'),
	(377, 1, 0, -50246, 2623, 0, 0, 39, '2622'),
	(377, 1, 0, -50246, 2624, 0, 0, 39, '2623'),
	(377, 1, 0, -50246, 2625, 0, 0, 39, '2624'),
	(377, 1, 0, -50246, 2626, 0, 0, 39, '2625'),
	(377, 1, 0, -50246, 2627, 0, 0, 39, '2626'),
	(377, 1, 0, -50246, 2628, 0, 0, 39, '2627'),
	(377, 1, 0, -50246, 2629, 0, 0, 39, '2628'),
	(377, 1, 0, -50246, 2630, 0, 0, 39, '2629'),
	(377, 1, 0, -50246, 2631, 0, 0, 39, '2630'),
	(377, 1, 0, -50246, 2632, 0, 0, 39, '2631'),
	(377, 1, 0, -50246, 2633, 0, 0, 39, '2632'),
	(377, 1, 0, -50246, 2634, 0, 0, 39, '2633'),
	(377, 1, 0, -50246, 2635, 0, 0, 39, '2634'),
	(377, 1, 0, -50246, 2636, 0, 0, 39, '2635'),
	(377, 1, 0, -50246, 2637, 0, 0, 39, '2636'),
	(377, 1, 0, -50246, 2638, 0, 0, 39, '2637'),
	(377, 1, 0, -50246, 2639, 0, 0, 39, '2638'),
	(377, 1, 0, -50246, 2640, 0, 0, 39, '2639'),
	(377, 1, 0, -50246, 2641, 0, 0, 39, '2640'),
	(377, 1, 0, -50246, 2642, 0, 0, 39, '2641'),
	(377, 1, 0, -50246, 2643, 0, 0, 39, '2642'),
	(377, 1, 0, -50246, 2644, 0, 0, 39, '2643'),
	(377, 1, 0, -50246, 2645, 0, 0, 39, '2644'),
	(377, 1, 0, -50246, 2646, 0, 0, 39, '2645'),
	(377, 1, 0, -50246, 2647, 0, 0, 39, '2646'),
	(377, 1, 0, -50246, 2648, 0, 0, 39, '2647'),
	(377, 1, 0, -50246, 2649, 0, 0, 39, '2648'),
	(377, 1, 0, -50246, 2650, 0, 0, 39, '2649'),
	(377, 1, 0, -50246, 2651, 0, 0, 39, '2650'),
	(377, 1, 0, -50246, 2652, 0, 0, 39, '2651'),
	(377, 1, 0, -50246, 2653, 0, 0, 39, '2652'),
	(377, 1, 0, -50246, 2654, 0, 0, 39, '2653'),
	(377, 1, 0, -50246, 2655, 0, 0, 39, '2654'),
	(377, 1, 0, -50246, 2656, 0, 0, 39, '2655'),
	(377, 1, 0, -50246, 2657, 0, 0, 39, '2656'),
	(377, 1, 0, -50246, 2658, 0, 0, 39, '2657'),
	(377, 1, 0, -50246, 2659, 0, 0, 39, '2658'),
	(377, 1, 0, -50246, 2660, 0, 0, 39, '2659'),
	(377, 1, 0, -50246, 2661, 0, 0, 39, '2660'),
	(377, 1, 0, -50246, 2662, 0, 0, 39, '2661'),
	(377, 1, 0, -50246, 2663, 0, 0, 39, '2662'),
	(377, 1, 0, -50246, 2664, 0, 0, 39, '2663'),
	(377, 1, 0, -50246, 2665, 0, 0, 39, '2664'),
	(377, 1, 0, -50246, 2666, 0, 0, 39, '2665'),
	(377, 1, 0, -50246, 2667, 0, 0, 39, '2666'),
	(377, 1, 0, -50246, 2668, 0, 0, 39, '2667'),
	(377, 1, 0, -50246, 2669, 0, 0, 39, '2668'),
	(377, 1, 0, -50246, 2670, 0, 0, 39, '2669'),
	(377, 1, 0, -50246, 2671, 0, 0, 39, '2670'),
	(377, 1, 0, -50246, 2672, 0, 0, 39, '2671'),
	(377, 1, 0, -50246, 2673, 0, 0, 39, '2672'),
	(377, 1, 0, -50246, 2674, 0, 0, 39, '2673'),
	(377, 1, 0, -50246, 2675, 0, 0, 39, '2674'),
	(377, 1, 0, -50246, 2676, 0, 0, 39, '2675'),
	(377, 1, 0, -50246, 2677, 0, 0, 39, '2676'),
	(377, 1, 0, -50246, 2678, 0, 0, 39, '2677'),
	(377, 1, 0, -50246, 2679, 0, 0, 39, '2678'),
	(377, 1, 0, -50246, 2680, 0, 0, 39, '2679'),
	(377, 1, 0, -50246, 2681, 0, 0, 39, '2680'),
	(377, 1, 0, -50246, 2682, 0, 0, 39, '2681'),
	(377, 1, 0, -50246, 2683, 0, 0, 39, '2682'),
	(377, 1, 0, -50246, 2684, 0, 0, 39, '2683'),
	(377, 1, 0, -50246, 2685, 0, 0, 39, '2684'),
	(377, 1, 0, -50246, 2686, 0, 0, 39, '2685'),
	(377, 1, 0, -50246, 2687, 0, 0, 39, '2686'),
	(377, 1, 0, -50246, 2688, 0, 0, 39, '2687'),
	(377, 1, 0, -50246, 2689, 0, 0, 39, '2688'),
	(377, 1, 0, -50246, 2690, 0, 0, 39, '2689'),
	(377, 1, 0, -50246, 2691, 0, 0, 39, '2690'),
	(377, 1, 0, -50246, 2692, 0, 0, 39, '2691'),
	(377, 1, 0, -50246, 2693, 0, 0, 39, '2692'),
	(377, 1, 0, -50246, 2694, 0, 0, 39, '2693'),
	(377, 1, 0, -50246, 2695, 0, 0, 39, '2694'),
	(377, 1, 0, -50246, 2696, 0, 0, 39, '2695'),
	(377, 1, 0, -50246, 2697, 0, 0, 39, '2696'),
	(377, 1, 0, -50246, 2698, 0, 0, 39, '2697'),
	(377, 1, 0, -50246, 2699, 0, 0, 39, '2698'),
	(377, 1, 0, -50246, 2700, 0, 0, 39, '2699'),
	(377, 1, 0, -50246, 2701, 0, 0, 39, '2700'),
	(377, 1, 0, -50246, 2702, 0, 0, 39, '2701'),
	(377, 1, 0, -50246, 2703, 0, 0, 39, '2702'),
	(377, 1, 0, -50246, 2704, 0, 0, 39, '2703'),
	(377, 1, 0, -50246, 2705, 0, 0, 39, '2704'),
	(377, 1, 0, -50246, 2706, 0, 0, 39, '2705'),
	(377, 1, 0, -50246, 2707, 0, 0, 39, '2706'),
	(377, 1, 0, -50246, 2708, 0, 0, 39, '2707'),
	(377, 1, 0, -50246, 2709, 0, 0, 39, '2708'),
	(377, 1, 0, -50246, 2710, 0, 0, 39, '2709'),
	(377, 1, 0, -50246, 2711, 0, 0, 39, '2710'),
	(377, 1, 0, -50246, 2712, 0, 0, 39, '2711'),
	(377, 1, 0, -50246, 2713, 0, 0, 39, '2712'),
	(377, 1, 0, -50246, 2714, 0, 0, 39, '2713'),
	(377, 1, 0, -50246, 2715, 0, 0, 39, '2714'),
	(377, 1, 0, -50246, 2716, 0, 0, 39, '2715'),
	(377, 1, 0, -50246, 2717, 0, 0, 39, '2716'),
	(377, 1, 0, -50246, 2718, 0, 0, 39, '2717'),
	(377, 1, 0, -50246, 2719, 0, 0, 39, '2718'),
	(377, 1, 0, -50246, 2720, 0, 0, 39, '2719'),
	(377, 1, 0, -50246, 2721, 0, 0, 39, '2720'),
	(377, 1, 0, -50246, 2722, 0, 0, 39, '2721'),
	(377, 1, 0, -50246, 2723, 0, 0, 39, '2722'),
	(377, 1, 0, -50246, 2724, 0, 0, 39, '2723'),
	(377, 1, 0, -50246, 2725, 0, 0, 39, '2724'),
	(377, 1, 0, -50246, 2726, 0, 0, 39, '2725'),
	(377, 1, 0, -50246, 2727, 0, 0, 39, '2726'),
	(377, 1, 0, -50246, 2728, 0, 0, 39, '2727'),
	(377, 1, 0, -50246, 2729, 0, 0, 39, '2728'),
	(377, 1, 0, -50246, 2730, 0, 0, 39, '2729'),
	(377, 1, 0, -50246, 2731, 0, 0, 39, '2730'),
	(377, 1, 0, -50246, 2732, 0, 0, 39, '2731'),
	(377, 1, 0, -50246, 2733, 0, 0, 39, '2732'),
	(377, 1, 0, -50246, 2734, 0, 0, 39, '2733'),
	(377, 1, 0, -50246, 2735, 0, 0, 39, '2734'),
	(377, 1, 0, -50246, 2736, 0, 0, 39, '2735'),
	(377, 1, 0, -50246, 2737, 0, 0, 39, '2736'),
	(377, 1, 0, -50246, 2738, 0, 0, 39, '2737'),
	(377, 1, 0, -50246, 2739, 0, 0, 39, '2738'),
	(377, 1, 0, -50246, 2740, 0, 0, 39, '2739'),
	(377, 1, 0, -50246, 2741, 0, 0, 39, '2740'),
	(377, 1, 0, -50246, 2742, 0, 0, 39, '2741'),
	(377, 1, 0, -50246, 2743, 0, 0, 39, '2742'),
	(377, 1, 0, -50246, 2744, 0, 0, 39, '2743'),
	(377, 1, 0, -50246, 2745, 0, 0, 39, '2744'),
	(377, 1, 0, -50246, 2746, 0, 0, 39, '2745'),
	(377, 1, 0, -50246, 2747, 0, 0, 39, '2746'),
	(377, 1, 0, -50246, 2748, 0, 0, 39, '2747'),
	(377, 1, 0, -50246, 2749, 0, 0, 39, '2748'),
	(377, 1, 0, -50246, 2750, 0, 0, 39, '2749'),
	(377, 1, 0, -50246, 2751, 0, 0, 39, '2750'),
	(377, 1, 0, -50246, 2752, 0, 0, 39, '2751'),
	(377, 1, 0, -50246, 2753, 0, 0, 39, '2752'),
	(377, 1, 0, -50246, 2754, 0, 0, 39, '2753'),
	(377, 1, 0, -50246, 2755, 0, 0, 39, '2754'),
	(377, 1, 0, -50246, 2756, 0, 0, 39, '2755'),
	(377, 1, 0, -50246, 2757, 0, 0, 39, '2756'),
	(377, 1, 0, -50246, 2758, 0, 0, 39, '2757'),
	(377, 1, 0, -50246, 2759, 0, 0, 39, '2758'),
	(377, 1, 0, -50246, 2760, 0, 0, 39, '2759'),
	(377, 1, 0, -50246, 2761, 0, 0, 39, '2760'),
	(377, 1, 0, -50246, 2762, 0, 0, 39, '2761'),
	(377, 1, 0, -50246, 2763, 0, 0, 39, '2762'),
	(377, 1, 0, -50246, 2764, 0, 0, 39, '2763'),
	(377, 1, 0, -50246, 2765, 0, 0, 39, '2764'),
	(377, 1, 0, -50246, 2766, 0, 0, 39, '2765'),
	(377, 1, 0, -50246, 2767, 0, 0, 39, '2766'),
	(377, 1, 0, -50246, 2768, 0, 0, 39, '2767'),
	(377, 1, 0, -50246, 2769, 0, 0, 39, '2768'),
	(377, 1, 0, -50246, 2770, 0, 0, 39, '2769'),
	(377, 1, 0, -50246, 2771, 0, 0, 39, '2770'),
	(377, 1, 0, -50246, 2772, 0, 0, 39, '2771'),
	(377, 1, 0, -50246, 2773, 0, 0, 39, '2772'),
	(377, 1, 0, -50246, 2774, 0, 0, 39, '2773'),
	(377, 1, 0, -50246, 2775, 0, 0, 39, '2774'),
	(377, 1, 0, -50246, 2776, 0, 0, 39, '2775'),
	(377, 1, 0, -50246, 2777, 0, 0, 39, '2776'),
	(377, 1, 0, -50246, 2778, 0, 0, 39, '2777'),
	(377, 1, 0, -50246, 2779, 0, 0, 39, '2778'),
	(377, 1, 0, -50246, 2780, 0, 0, 39, '2779'),
	(377, 1, 0, -50246, 2781, 0, 0, 39, '2780'),
	(377, 1, 0, -50246, 2782, 0, 0, 39, '2781'),
	(377, 1, 0, -50246, 2783, 0, 0, 39, '2782'),
	(377, 1, 0, -50246, 2784, 0, 0, 39, '2783'),
	(377, 1, 0, -50246, 2785, 0, 0, 39, '2784'),
	(377, 1, 0, -50246, 2786, 0, 0, 39, '2785'),
	(377, 1, 0, -50246, 2787, 0, 0, 39, '2786'),
	(377, 1, 0, -50246, 2788, 0, 0, 39, '2787'),
	(377, 1, 0, -50246, 2789, 0, 0, 39, '2788'),
	(377, 1, 0, -50246, 2790, 0, 0, 39, '2789'),
	(377, 1, 0, -50246, 2791, 0, 0, 39, '2790'),
	(377, 1, 0, -50246, 2792, 0, 0, 39, '2791'),
	(377, 1, 0, -50246, 2793, 0, 0, 39, '2792'),
	(377, 1, 0, -50246, 2794, 0, 0, 39, '2793'),
	(377, 1, 0, -50246, 2795, 0, 0, 39, '2794'),
	(377, 1, 0, -50246, 2796, 0, 0, 39, '2795'),
	(377, 1, 0, -50246, 2797, 0, 0, 39, '2796'),
	(377, 1, 0, -50246, 2798, 0, 0, 39, '2797'),
	(377, 1, 0, -50246, 2799, 0, 0, 39, '2798'),
	(377, 1, 0, -50246, 2800, 0, 0, 39, '2799'),
	(377, 1, 0, -50246, 2801, 0, 0, 39, '2800'),
	(377, 1, 0, -50246, 2802, 0, 0, 39, '2801'),
	(377, 1, 0, -50246, 2803, 0, 0, 39, '2802'),
	(377, 1, 0, -50246, 2804, 0, 0, 39, '2803'),
	(377, 1, 0, -50246, 2805, 0, 0, 39, '2804'),
	(377, 1, 0, -50246, 2806, 0, 0, 39, '2805'),
	(377, 1, 0, -50246, 2807, 0, 0, 39, '2806'),
	(377, 1, 0, -50246, 2808, 0, 0, 39, '2807'),
	(377, 1, 0, -50246, 2809, 0, 0, 39, '2808'),
	(377, 1, 0, -50246, 2810, 0, 0, 39, '2809'),
	(377, 1, 0, -50246, 2811, 0, 0, 39, '2810'),
	(377, 1, 0, -50246, 2812, 0, 0, 39, '2811'),
	(377, 1, 0, -50246, 2813, 0, 0, 39, '2812'),
	(377, 1, 0, -50246, 2814, 0, 0, 39, '2813'),
	(377, 1, 0, -50246, 2815, 0, 0, 39, '2814'),
	(377, 1, 0, -50246, 2816, 0, 0, 39, '2815'),
	(377, 1, 0, -50246, 2817, 0, 0, 39, '2816'),
	(377, 1, 0, -50246, 2818, 0, 0, 39, '2817'),
	(377, 1, 0, -50246, 2819, 0, 0, 39, '2818'),
	(377, 1, 0, -50246, 2820, 0, 0, 39, '2819'),
	(377, 1, 0, -50246, 2821, 0, 0, 39, '2820'),
	(377, 1, 0, -50246, 2822, 0, 0, 39, '2821'),
	(377, 1, 0, -50246, 2823, 0, 0, 39, '2822'),
	(377, 1, 0, -50246, 2824, 0, 0, 39, '2823'),
	(377, 1, 0, -50246, 2825, 0, 0, 39, '2824'),
	(377, 1, 0, -50246, 2826, 0, 0, 39, '2825'),
	(377, 1, 0, -50246, 2827, 0, 0, 39, '2826'),
	(377, 1, 0, -50246, 2828, 0, 0, 39, '2827'),
	(377, 1, 0, -50246, 2829, 0, 0, 39, '2828'),
	(377, 1, 0, -50246, 2830, 0, 0, 39, '2829'),
	(377, 1, 0, -50246, 2831, 0, 0, 39, '2830'),
	(377, 1, 0, -50246, 2832, 0, 0, 39, '2831'),
	(377, 1, 0, -50246, 2833, 0, 0, 39, '2832'),
	(377, 1, 0, -50246, 2834, 0, 0, 39, '2833'),
	(377, 1, 0, -50246, 2835, 0, 0, 39, '2834'),
	(377, 1, 0, -50246, 2836, 0, 0, 39, '2835'),
	(377, 1, 0, -50246, 2837, 0, 0, 39, '2836'),
	(377, 1, 0, -50246, 2838, 0, 0, 39, '2837'),
	(377, 1, 0, -50246, 2839, 0, 0, 39, '2838'),
	(377, 1, 0, -50246, 2840, 0, 0, 39, '2839'),
	(377, 1, 0, -50246, 2841, 0, 0, 39, '2840'),
	(377, 1, 0, -50246, 2842, 0, 0, 39, '2841'),
	(377, 1, 0, -50246, 2843, 0, 0, 39, '2842'),
	(377, 1, 0, -50246, 2844, 0, 0, 39, '2843'),
	(377, 1, 0, -50246, 2845, 0, 0, 39, '2844'),
	(377, 1, 0, -50246, 2846, 0, 0, 39, '2845'),
	(377, 1, 0, -50246, 2847, 0, 0, 39, '2846'),
	(377, 1, 0, -50246, 2848, 0, 0, 39, '2847'),
	(377, 1, 0, -50246, 2849, 0, 0, 39, '2848'),
	(377, 1, 0, -50246, 2850, 0, 0, 39, '2849'),
	(377, 1, 0, -50246, 2851, 0, 0, 39, '2850'),
	(377, 1, 0, -50246, 2852, 0, 0, 39, '2851'),
	(377, 1, 0, -50246, 2853, 0, 0, 39, '2852'),
	(377, 1, 0, -50246, 2854, 0, 0, 39, '2853'),
	(377, 1, 0, -50246, 2855, 0, 0, 39, '2854'),
	(377, 1, 0, -50246, 2856, 0, 0, 39, '2855'),
	(377, 1, 0, -50246, 2857, 0, 0, 39, '2856'),
	(377, 1, 0, -50246, 2858, 0, 0, 39, '2857'),
	(377, 1, 0, -50246, 2859, 0, 0, 39, '2858'),
	(377, 1, 0, -50246, 2860, 0, 0, 39, '2859'),
	(377, 1, 0, -50246, 2861, 0, 0, 39, '2860'),
	(377, 1, 0, -50246, 2862, 0, 0, 39, '2861'),
	(377, 1, 0, -50246, 2863, 0, 0, 39, '2862'),
	(377, 1, 0, -50246, 2864, 0, 0, 39, '2863'),
	(377, 1, 0, -50246, 2865, 0, 0, 39, '2864'),
	(377, 1, 0, -50246, 2866, 0, 0, 39, '2865'),
	(377, 1, 0, -50246, 2867, 0, 0, 39, '2866'),
	(377, 1, 0, -50246, 2868, 0, 0, 39, '2867'),
	(377, 1, 0, -50246, 2869, 0, 0, 39, '2868'),
	(377, 1, 0, -50246, 2870, 0, 0, 39, '2869'),
	(377, 1, 0, -50246, 2871, 0, 0, 39, '2870'),
	(377, 1, 0, -50246, 2872, 0, 0, 39, '2871'),
	(377, 1, 0, -50246, 2873, 0, 0, 39, '2872'),
	(377, 1, 0, -50246, 2874, 0, 0, 39, '2873'),
	(377, 1, 0, -50246, 2875, 0, 0, 39, '2874'),
	(377, 1, 0, -50246, 2876, 0, 0, 39, '2875'),
	(377, 1, 0, -50246, 2877, 0, 0, 39, '2876'),
	(377, 1, 0, -50246, 2878, 0, 0, 39, '2877'),
	(377, 1, 0, -50246, 2879, 0, 0, 39, '2878'),
	(377, 1, 0, -50246, 2880, 0, 0, 39, '2879'),
	(377, 1, 0, -50246, 2881, 0, 0, 39, '2880'),
	(377, 1, 0, -50246, 2882, 0, 0, 39, '2881'),
	(377, 1, 0, -50246, 2883, 0, 0, 39, '2882'),
	(377, 1, 0, -50246, 2884, 0, 0, 39, '2883'),
	(377, 1, 0, -50246, 2885, 0, 0, 39, '2884'),
	(377, 1, 0, -50246, 2886, 0, 0, 39, '2885'),
	(377, 1, 0, -50246, 2887, 0, 0, 39, '2886'),
	(377, 1, 0, -50246, 2888, 0, 0, 39, '2887'),
	(377, 1, 0, -50246, 2889, 0, 0, 39, '2888'),
	(377, 1, 0, -50246, 2890, 0, 0, 39, '2889'),
	(377, 1, 0, -50246, 2891, 0, 0, 39, '2890'),
	(377, 1, 0, -50246, 2892, 0, 0, 39, '2891'),
	(377, 1, 0, -50246, 2893, 0, 0, 39, '2892'),
	(377, 1, 0, -50246, 2894, 0, 0, 39, '2893'),
	(377, 1, 0, -50246, 2895, 0, 0, 39, '2894'),
	(377, 1, 0, -50246, 2896, 0, 0, 39, '2895'),
	(377, 1, 0, -50246, 2897, 0, 0, 39, '2896'),
	(377, 1, 0, -50246, 2898, 0, 0, 39, '2897'),
	(377, 1, 0, -50246, 2899, 0, 0, 39, '2898'),
	(377, 1, 0, -50246, 2900, 0, 0, 39, '2899'),
	(377, 1, 0, -50246, 2901, 0, 0, 39, '2900'),
	(377, 1, 0, -50246, 2902, 0, 0, 39, '2901'),
	(377, 1, 0, -50246, 2903, 0, 0, 39, '2902'),
	(377, 1, 0, -50246, 2904, 0, 0, 39, '2903'),
	(377, 1, 0, -50246, 2905, 0, 0, 39, '2904'),
	(377, 1, 0, -50246, 2906, 0, 0, 39, '2905'),
	(377, 1, 0, -50246, 2907, 0, 0, 39, '2906'),
	(377, 1, 0, -50246, 2908, 0, 0, 39, '2907'),
	(377, 1, 0, -50246, 2909, 0, 0, 39, '2908'),
	(377, 1, 0, -50246, 2910, 0, 0, 39, '2909'),
	(377, 1, 0, -50246, 2911, 0, 0, 39, '2910'),
	(377, 1, 0, -50246, 2912, 0, 0, 39, '2911'),
	(377, 1, 0, -50246, 2913, 0, 0, 39, '2912'),
	(377, 1, 0, -50246, 2914, 0, 0, 39, '2913'),
	(377, 1, 0, -50246, 2915, 0, 0, 39, '2914'),
	(377, 1, 0, -50246, 2916, 0, 0, 39, '2915'),
	(377, 1, 0, -50246, 2917, 0, 0, 39, '2916'),
	(377, 1, 0, -50246, 2918, 0, 0, 39, '2917'),
	(377, 1, 0, -50246, 2919, 0, 0, 39, '2918'),
	(377, 1, 0, -50246, 2920, 0, 0, 39, '2919'),
	(377, 1, 0, -50246, 2921, 0, 0, 39, '2920'),
	(377, 1, 0, -50246, 2922, 0, 0, 39, '2921'),
	(377, 1, 0, -50246, 2923, 0, 0, 39, '2922'),
	(377, 1, 0, -50246, 2924, 0, 0, 39, '2923'),
	(377, 1, 0, -50246, 2925, 0, 0, 39, '2924'),
	(377, 1, 0, -50246, 2926, 0, 0, 39, '2925'),
	(377, 1, 0, -50246, 2927, 0, 0, 39, '2926'),
	(377, 1, 0, -50246, 2928, 0, 0, 39, '2927'),
	(377, 1, 0, -50246, 2929, 0, 0, 39, '2928'),
	(377, 1, 0, -50246, 2930, 0, 0, 39, '2929'),
	(377, 1, 0, -50246, 2931, 0, 0, 39, '2930'),
	(377, 1, 0, -50246, 2932, 0, 0, 39, '2931'),
	(377, 1, 0, -50246, 2933, 0, 0, 39, '2932'),
	(377, 1, 0, -50246, 2934, 0, 0, 39, '2933'),
	(377, 1, 0, -50246, 2935, 0, 0, 39, '2934'),
	(377, 1, 0, -50246, 2936, 0, 0, 39, '2935'),
	(377, 1, 0, -50246, 2937, 0, 0, 39, '2936'),
	(377, 1, 0, -50246, 2938, 0, 0, 39, '2937'),
	(377, 1, 0, -50246, 2939, 0, 0, 39, '2938'),
	(377, 1, 0, -50246, 2940, 0, 0, 39, '2939'),
	(377, 1, 0, -50246, 2941, 0, 0, 39, '2940'),
	(377, 1, 0, -50246, 2942, 0, 0, 39, '2941'),
	(377, 1, 0, -50246, 2943, 0, 0, 39, '2942'),
	(377, 1, 0, -50246, 2944, 0, 0, 39, '2943'),
	(377, 1, 0, -50246, 2945, 0, 0, 39, '2944'),
	(377, 1, 0, -50246, 2946, 0, 0, 39, '2945'),
	(377, 1, 0, -50246, 2947, 0, 0, 39, '2946'),
	(377, 1, 0, -50246, 2948, 0, 0, 39, '2947'),
	(377, 1, 0, -50246, 2949, 0, 0, 39, '2948'),
	(377, 1, 0, -50246, 2950, 0, 0, 39, '2949'),
	(377, 1, 0, -50246, 2951, 0, 0, 39, '2950'),
	(377, 1, 0, -50246, 2952, 0, 0, 39, '2951'),
	(377, 1, 0, -50246, 2953, 0, 0, 39, '2952'),
	(377, 1, 0, -50246, 2954, 0, 0, 39, '2953'),
	(377, 1, 0, -50246, 2955, 0, 0, 39, '2954'),
	(377, 1, 0, -50246, 2956, 0, 0, 39, '2955'),
	(377, 1, 0, -50246, 2957, 0, 0, 39, '2956'),
	(377, 1, 0, -50246, 2958, 0, 0, 39, '2957'),
	(377, 1, 0, -50246, 2959, 0, 0, 39, '2958'),
	(377, 1, 0, -50246, 2960, 0, 0, 39, '2959'),
	(377, 1, 0, -50246, 2961, 0, 0, 39, '2960'),
	(377, 1, 0, -50246, 2962, 0, 0, 39, '2961'),
	(377, 1, 0, -50246, 2963, 0, 0, 39, '2962'),
	(377, 1, 0, -50246, 2964, 0, 0, 39, '2963'),
	(377, 1, 0, -50246, 2965, 0, 0, 39, '2964'),
	(377, 1, 0, -50246, 2966, 0, 0, 39, '2965'),
	(377, 1, 0, -50246, 2967, 0, 0, 39, '2966'),
	(377, 1, 0, -50246, 2968, 0, 0, 39, '2967'),
	(377, 1, 0, -50246, 2969, 0, 0, 39, '2968'),
	(377, 1, 0, -50246, 2970, 0, 0, 39, '2969'),
	(377, 1, 0, -50246, 2971, 0, 0, 39, '2970'),
	(377, 1, 0, -50246, 2972, 0, 0, 39, '2971'),
	(377, 1, 0, -50246, 2973, 0, 0, 39, '2972'),
	(377, 1, 0, -50246, 2974, 0, 0, 39, '2973'),
	(377, 1, 0, -50246, 2975, 0, 0, 39, '2974'),
	(377, 1, 0, -50246, 2976, 0, 0, 39, '2975'),
	(377, 1, 0, -50246, 2977, 0, 0, 39, '2976'),
	(377, 1, 0, -50246, 2978, 0, 0, 39, '2977'),
	(377, 1, 0, -50246, 2979, 0, 0, 39, '2978'),
	(377, 1, 0, -50246, 2980, 0, 0, 39, '2979'),
	(377, 1, 0, -50246, 2981, 0, 0, 39, '2980'),
	(377, 1, 0, -50246, 2982, 0, 0, 39, '2981'),
	(377, 1, 0, -50246, 2983, 0, 0, 39, '2982'),
	(377, 1, 0, -50246, 2984, 0, 0, 39, '2983'),
	(377, 1, 0, -50246, 2985, 0, 0, 39, '2984'),
	(377, 1, 0, -50246, 2986, 0, 0, 39, '2985'),
	(377, 1, 0, -50246, 2987, 0, 0, 39, '2986'),
	(377, 1, 0, -50246, 2988, 0, 0, 39, '2987'),
	(377, 1, 0, -50246, 2989, 0, 0, 39, '2988'),
	(377, 1, 0, -50246, 2990, 0, 0, 39, '2989'),
	(377, 1, 0, -50246, 2991, 0, 0, 39, '2990'),
	(377, 1, 0, -50246, 2992, 0, 0, 39, '2991'),
	(377, 1, 0, -50246, 2993, 0, 0, 39, '2992'),
	(377, 1, 0, -50246, 2994, 0, 0, 39, '2993'),
	(377, 1, 0, -50246, 2995, 0, 0, 39, '2994'),
	(377, 1, 0, -50246, 2996, 0, 0, 39, '2995'),
	(377, 1, 0, -50246, 2997, 0, 0, 39, '2996'),
	(377, 1, 0, -50246, 2998, 0, 0, 39, '2997'),
	(377, 1, 0, -50246, 2999, 0, 0, 39, '2998'),
	(377, 1, 0, -50246, 3000, 0, 0, 39, '2999'),
	(377, 1, 0, -50246, 3001, 0, 0, 39, '3000'),
	(377, 1, 0, -50246, 3002, 0, 0, 39, '3001'),
	(377, 1, 0, -50246, 3003, 0, 0, 39, '3002'),
	(377, 1, 0, -50246, 3004, 0, 0, 39, '3003'),
	(377, 1, 0, -50246, 3005, 0, 0, 39, '3004'),
	(377, 1, 0, -50246, 3006, 0, 0, 39, '3005'),
	(377, 1, 0, -50246, 3007, 0, 0, 39, '3006'),
	(377, 1, 0, -50246, 3008, 0, 0, 39, '3007'),
	(377, 1, 0, -50246, 3009, 0, 0, 39, '3008'),
	(377, 1, 0, -50246, 3010, 0, 0, 39, '3009'),
	(377, 1, 0, -50246, 3011, 0, 0, 39, '3010'),
	(377, 1, 0, -50246, 3012, 0, 0, 39, '3011'),
	(377, 1, 0, -50246, 3013, 0, 0, 39, '3012'),
	(377, 1, 0, -50246, 3014, 0, 0, 39, '3013'),
	(377, 1, 0, -50246, 3015, 0, 0, 39, '3014'),
	(377, 1, 0, -50246, 3016, 0, 0, 39, '3015'),
	(377, 1, 0, -50246, 3017, 0, 0, 39, '3016'),
	(377, 1, 0, -50246, 3018, 0, 0, 39, '3017'),
	(377, 1, 0, -50246, 3019, 0, 0, 39, '3018'),
	(377, 1, 0, -50246, 3020, 0, 0, 39, '3019'),
	(377, 1, 0, -50246, 3021, 0, 0, 39, '3020'),
	(377, 1, 0, -50246, 3022, 0, 0, 39, '3021'),
	(377, 1, 0, -50246, 3023, 0, 0, 39, '3022'),
	(377, 1, 0, -50246, 3024, 0, 0, 39, '3023'),
	(377, 1, 0, -50246, 3025, 0, 0, 39, '3024'),
	(377, 1, 0, -50246, 3026, 0, 0, 39, '3025'),
	(377, 1, 0, -50246, 3027, 0, 0, 39, '3026'),
	(377, 1, 0, -50246, 3028, 0, 0, 39, '3027'),
	(377, 1, 0, -50246, 3029, 0, 0, 39, '3028'),
	(377, 1, 0, -50246, 3030, 0, 0, 39, '3029'),
	(377, 1, 0, -50246, 3031, 0, 0, 39, '3030'),
	(377, 1, 0, -50246, 3032, 0, 0, 39, '3031'),
	(377, 1, 0, -50246, 3033, 0, 0, 39, '3032'),
	(377, 1, 0, -50246, 3034, 0, 0, 39, '3033'),
	(377, 1, 0, -50246, 3035, 0, 0, 39, '3034'),
	(377, 1, 0, -50246, 3036, 0, 0, 39, '3035'),
	(377, 1, 0, -50246, 3037, 0, 0, 39, '3036'),
	(377, 1, 0, -50246, 3038, 0, 0, 39, '3037'),
	(377, 1, 0, -50246, 3039, 0, 0, 39, '3038'),
	(377, 1, 0, -50246, 3040, 0, 0, 39, '3039'),
	(377, 1, 0, -50246, 3041, 0, 0, 39, '3040'),
	(377, 1, 0, -50246, 3042, 0, 0, 39, '3041'),
	(377, 1, 0, -50246, 3043, 0, 0, 39, '3042'),
	(377, 1, 0, -50246, 3044, 0, 0, 39, '3043'),
	(377, 1, 0, -50246, 3045, 0, 0, 39, '3044'),
	(377, 1, 0, -50246, 3046, 0, 0, 39, '3045'),
	(377, 1, 0, -50246, 3047, 0, 0, 39, '3046'),
	(377, 1, 0, -50246, 3048, 0, 0, 39, '3047'),
	(377, 1, 0, -50246, 3049, 0, 0, 39, '3048'),
	(377, 1, 0, -50246, 3050, 0, 0, 39, '3049'),
	(377, 1, 0, -50246, 3051, 0, 0, 39, '3050'),
	(377, 1, 0, -50246, 3052, 0, 0, 39, '3051'),
	(377, 1, 0, -50246, 3053, 0, 0, 39, '3052'),
	(377, 1, 0, -50246, 3054, 0, 0, 39, '3053'),
	(377, 1, 0, -50246, 3055, 0, 0, 39, '3054'),
	(377, 1, 0, -50246, 3056, 0, 0, 39, '3055'),
	(377, 1, 0, -50246, 3057, 0, 0, 39, '3056'),
	(377, 1, 0, -50246, 3058, 0, 0, 39, '3057'),
	(377, 1, 0, -50246, 3059, 0, 0, 39, '3058'),
	(377, 1, 0, -50246, 3060, 0, 0, 39, '3059'),
	(377, 1, 0, -50246, 3061, 0, 0, 39, '3060'),
	(377, 1, 0, -50246, 3062, 0, 0, 39, '3061'),
	(377, 1, 0, -50246, 3063, 0, 0, 39, '3062'),
	(377, 1, 0, -50246, 3064, 0, 0, 39, '3063'),
	(377, 1, 0, -50246, 3065, 0, 0, 39, '3064'),
	(377, 1, 0, -50246, 3066, 0, 0, 39, '3065'),
	(377, 1, 0, -50246, 3067, 0, 0, 39, '3066'),
	(377, 1, 0, -50246, 3068, 0, 0, 39, '3067'),
	(377, 1, 0, -50246, 3069, 0, 0, 39, '3068'),
	(377, 1, 0, -50246, 3070, 0, 0, 39, '3069'),
	(377, 1, 0, -50246, 3071, 0, 0, 39, '3070'),
	(377, 1, 0, -50246, 3072, 0, 0, 39, '3071'),
	(377, 1, 0, -50246, 3073, 0, 0, 39, '3072'),
	(377, 1, 0, -50246, 3074, 0, 0, 39, '3073'),
	(377, 1, 0, -50246, 3075, 0, 0, 39, '3074'),
	(377, 1, 0, -50246, 3076, 0, 0, 39, '3075'),
	(377, 1, 0, -50246, 3077, 0, 0, 39, '3076'),
	(377, 1, 0, -50246, 3078, 0, 0, 39, '3077'),
	(377, 1, 0, -50246, 3079, 0, 0, 39, '3078'),
	(377, 1, 0, -50246, 3080, 0, 0, 39, '3079'),
	(377, 1, 0, -50246, 3081, 0, 0, 39, '3080'),
	(377, 1, 0, -50246, 3082, 0, 0, 39, '3081'),
	(377, 1, 0, -50246, 3083, 0, 0, 39, '3082'),
	(377, 1, 0, -50246, 3084, 0, 0, 39, '3083'),
	(377, 1, 0, -50246, 3085, 0, 0, 39, '3084'),
	(377, 1, 0, -50246, 3086, 0, 0, 39, '3085'),
	(377, 1, 0, -50246, 3087, 0, 0, 39, '3086'),
	(377, 1, 0, -50246, 3088, 0, 0, 39, '3087'),
	(377, 1, 0, -50246, 3089, 0, 0, 39, '3088'),
	(377, 1, 0, -50246, 3090, 0, 0, 39, '3089'),
	(377, 1, 0, -50246, 3091, 0, 0, 39, '3090'),
	(377, 1, 0, -50246, 3092, 0, 0, 39, '3091'),
	(377, 1, 0, -50246, 3093, 0, 0, 39, '3092'),
	(377, 1, 0, -50246, 3094, 0, 0, 39, '3093'),
	(377, 1, 0, -50246, 3095, 0, 0, 39, '3094'),
	(377, 1, 0, -50246, 3096, 0, 0, 39, '3095'),
	(377, 1, 0, -50246, 3097, 0, 0, 39, '3096'),
	(377, 1, 0, -50246, 3098, 0, 0, 39, '3097'),
	(377, 1, 0, -50246, 3099, 0, 0, 39, '3098'),
	(377, 1, 0, -50246, 3100, 0, 0, 39, '3099'),
	(377, 1, 0, -50246, 3101, 0, 0, 39, '3100'),
	(377, 1, 0, -50246, 3102, 0, 0, 39, '3101'),
	(377, 1, 0, -50246, 3103, 0, 0, 39, '3102'),
	(377, 1, 0, -50246, 3104, 0, 0, 39, '3103'),
	(377, 1, 0, -50246, 3105, 0, 0, 39, '3104'),
	(377, 1, 0, -50246, 3106, 0, 0, 39, '3105'),
	(377, 1, 0, -50246, 3107, 0, 0, 39, '3106'),
	(377, 1, 0, -50246, 3108, 0, 0, 39, '3107'),
	(377, 1, 0, -50246, 3109, 0, 0, 39, '3108'),
	(377, 1, 0, -50246, 3110, 0, 0, 39, '3109'),
	(377, 1, 0, -50246, 3111, 0, 0, 39, '3110'),
	(377, 1, 0, -50246, 3112, 0, 0, 39, '3111'),
	(377, 1, 0, -50246, 3113, 0, 0, 39, '3112'),
	(377, 1, 0, -50246, 3114, 0, 0, 39, '3113'),
	(377, 1, 0, -50246, 3115, 0, 0, 39, '3114'),
	(377, 1, 0, -50246, 3116, 0, 0, 39, '3115'),
	(377, 1, 0, -50246, 3117, 0, 0, 39, '3116'),
	(377, 1, 0, -50246, 3118, 0, 0, 39, '3117'),
	(377, 1, 0, -50246, 3119, 0, 0, 39, '3118'),
	(377, 1, 0, -50246, 3120, 0, 0, 39, '3119'),
	(377, 1, 0, -50246, 3121, 0, 0, 39, '3120'),
	(377, 1, 0, -50246, 3122, 0, 0, 39, '3121'),
	(377, 1, 0, -50246, 3123, 0, 0, 39, '3122'),
	(377, 1, 0, -50246, 3124, 0, 0, 39, '3123'),
	(377, 1, 0, -50246, 3125, 0, 0, 39, '3124'),
	(377, 1, 0, -50246, 3126, 0, 0, 39, '3125'),
	(377, 1, 0, -50246, 3127, 0, 0, 39, '3126'),
	(377, 1, 0, -50246, 3128, 0, 0, 39, '3127'),
	(377, 1, 0, -50246, 3129, 0, 0, 39, '3128'),
	(377, 1, 0, -50246, 3130, 0, 0, 39, '3129'),
	(377, 1, 0, -50246, 3131, 0, 0, 39, '3130'),
	(377, 1, 0, -50246, 3132, 0, 0, 39, '3131'),
	(377, 1, 0, -50246, 3133, 0, 0, 39, '3132'),
	(377, 1, 0, -50246, 3134, 0, 0, 39, '3133'),
	(377, 1, 0, -50246, 3135, 0, 0, 39, '3134'),
	(377, 1, 0, -50246, 3136, 0, 0, 39, '3135'),
	(377, 1, 0, -50246, 3137, 0, 0, 39, '3136'),
	(377, 1, 0, -50246, 3138, 0, 0, 39, '3137'),
	(377, 1, 0, -50246, 3139, 0, 0, 39, '3138'),
	(377, 1, 0, -50246, 3140, 0, 0, 39, '3139'),
	(377, 1, 0, -50246, 3141, 0, 0, 39, '3140'),
	(377, 1, 0, -50246, 3142, 0, 0, 39, '3141'),
	(377, 1, 0, -50246, 3143, 0, 0, 39, '3142'),
	(377, 1, 0, -50246, 3144, 0, 0, 39, '3143'),
	(377, 1, 0, -50246, 3145, 0, 0, 39, '3144'),
	(377, 1, 0, -50246, 3146, 0, 0, 39, '3145'),
	(377, 1, 0, -50246, 3147, 0, 0, 39, '3146'),
	(377, 1, 0, -50246, 3148, 0, 0, 39, '3147'),
	(377, 1, 0, -50246, 3149, 0, 0, 39, '3148'),
	(377, 1, 0, -50246, 3150, 0, 0, 39, '3149'),
	(377, 1, 0, -50246, 3151, 0, 0, 39, '3150'),
	(377, 1, 0, -50246, 3152, 0, 0, 39, '3151'),
	(377, 1, 0, -50246, 3153, 0, 0, 39, '3152'),
	(377, 1, 0, -50246, 3154, 0, 0, 39, '3153'),
	(377, 1, 0, -50246, 3155, 0, 0, 39, '3154'),
	(377, 1, 0, -50246, 3156, 0, 0, 39, '3155'),
	(377, 1, 0, -50246, 3157, 0, 0, 39, '3156'),
	(377, 1, 0, -50246, 3158, 0, 0, 39, '3157'),
	(377, 1, 0, -50246, 3159, 0, 0, 39, '3158'),
	(377, 1, 0, -50246, 3160, 0, 0, 39, '3159'),
	(377, 1, 0, -50246, 3161, 0, 0, 39, '3160'),
	(377, 1, 0, -50246, 3162, 0, 0, 39, '3161'),
	(377, 1, 0, -50246, 3163, 0, 0, 39, '3162'),
	(377, 1, 0, -50246, 3164, 0, 0, 39, '3163'),
	(377, 1, 0, -50246, 3165, 0, 0, 39, '3164'),
	(377, 1, 0, -50246, 3166, 0, 0, 39, '3165'),
	(377, 1, 0, -50246, 3167, 0, 0, 39, '3166'),
	(377, 1, 0, -50246, 3168, 0, 0, 39, '3167'),
	(377, 1, 0, -50246, 3169, 0, 0, 39, '3168'),
	(377, 1, 0, -50246, 3170, 0, 0, 39, '3169'),
	(377, 1, 0, -50246, 3171, 0, 0, 39, '3170'),
	(377, 1, 0, -50246, 3172, 0, 0, 39, '3171'),
	(377, 1, 0, -50246, 3173, 0, 0, 39, '3172'),
	(377, 1, 0, -50246, 3174, 0, 0, 39, '3173'),
	(377, 1, 0, -50246, 3175, 0, 0, 39, '3174'),
	(377, 1, 0, -50246, 3176, 0, 0, 39, '3175'),
	(377, 1, 0, -50246, 3177, 0, 0, 39, '3176'),
	(377, 1, 0, -50246, 3178, 0, 0, 39, '3177'),
	(377, 1, 0, -50246, 3179, 0, 0, 39, '3178'),
	(377, 1, 0, -50246, 3180, 0, 0, 39, '3179'),
	(377, 1, 0, -50246, 3181, 0, 0, 39, '3180'),
	(377, 1, 0, -50246, 3182, 0, 0, 39, '3181'),
	(377, 1, 0, -50246, 3183, 0, 0, 39, '3182'),
	(377, 1, 0, -50246, 3184, 0, 0, 39, '3183'),
	(377, 1, 0, -50246, 3185, 0, 0, 39, '3184'),
	(377, 1, 0, -50246, 3186, 0, 0, 39, '3185'),
	(377, 1, 0, -50246, 3187, 0, 0, 39, '3186'),
	(377, 1, 0, -50246, 3188, 0, 0, 39, '3187'),
	(377, 1, 0, -50246, 3189, 0, 0, 39, '3188'),
	(377, 1, 0, -50246, 3190, 0, 0, 39, '3189'),
	(377, 1, 0, -50246, 3191, 0, 0, 39, '3190'),
	(377, 1, 0, -50246, 3192, 0, 0, 39, '3191'),
	(377, 1, 0, -50246, 3193, 0, 0, 39, '3192'),
	(377, 1, 0, -50246, 3194, 0, 0, 39, '3193'),
	(377, 1, 0, -50246, 3195, 0, 0, 39, '3194'),
	(377, 1, 0, -50246, 3196, 0, 0, 39, '3195'),
	(377, 1, 0, -50246, 3197, 0, 0, 39, '3196'),
	(377, 1, 0, -50246, 3198, 0, 0, 39, '3197'),
	(377, 1, 0, -50246, 3199, 0, 0, 39, '3198'),
	(377, 1, 0, -50246, 3200, 0, 0, 39, '3199'),
	(377, 1, 0, -50246, 3201, 0, 0, 39, '3200'),
	(377, 1, 0, -50246, 3202, 0, 0, 39, '3201'),
	(377, 1, 0, -50246, 3203, 0, 0, 39, '3202'),
	(377, 1, 0, -50246, 3204, 0, 0, 39, '3203'),
	(377, 1, 0, -50246, 3205, 0, 0, 39, '3204'),
	(377, 1, 0, -50246, 3206, 0, 0, 39, '3205'),
	(377, 1, 0, -50246, 3207, 0, 0, 39, '3206'),
	(377, 1, 0, -50246, 3208, 0, 0, 39, '3207'),
	(377, 1, 0, -50246, 3209, 0, 0, 39, '3208'),
	(377, 1, 0, -50246, 3210, 0, 0, 39, '3209'),
	(377, 1, 0, -50246, 3211, 0, 0, 39, '3210'),
	(377, 1, 0, -50246, 3212, 0, 0, 39, '3211'),
	(377, 1, 0, -50246, 3213, 0, 0, 39, '3212'),
	(377, 1, 0, -50246, 3214, 0, 0, 39, '3213'),
	(377, 1, 0, -50246, 3215, 0, 0, 39, '3214'),
	(377, 1, 0, -50246, 3216, 0, 0, 39, '3215'),
	(377, 1, 0, -50246, 3217, 0, 0, 39, '3216'),
	(377, 1, 0, -50246, 3218, 0, 0, 39, '3217'),
	(377, 1, 0, -50246, 3219, 0, 0, 39, '3218'),
	(377, 1, 0, -50246, 3220, 0, 0, 39, '3219'),
	(377, 1, 0, -50246, 3221, 0, 0, 39, '3220'),
	(377, 1, 0, -50246, 3222, 0, 0, 39, '3221'),
	(377, 1, 0, -50246, 3223, 0, 0, 39, '3222'),
	(377, 1, 0, -50246, 3224, 0, 0, 39, '3223'),
	(377, 1, 0, -50246, 3225, 0, 0, 39, '3224'),
	(377, 1, 0, -50246, 3226, 0, 0, 39, '3225'),
	(377, 1, 0, -50246, 3227, 0, 0, 39, '3226'),
	(377, 1, 0, -50246, 3228, 0, 0, 39, '3227'),
	(377, 1, 0, -50246, 3229, 0, 0, 39, '3228'),
	(377, 1, 0, -50246, 3230, 0, 0, 39, '3229'),
	(377, 1, 0, -50246, 3231, 0, 0, 39, '3230'),
	(377, 1, 0, -50246, 3232, 0, 0, 39, '3231'),
	(377, 1, 0, -50246, 3233, 0, 0, 39, '3232'),
	(377, 1, 0, -50246, 3234, 0, 0, 39, '3233'),
	(377, 1, 0, -50246, 3235, 0, 0, 39, '3234'),
	(377, 1, 0, -50246, 3236, 0, 0, 39, '3235'),
	(377, 1, 0, -50246, 3237, 0, 0, 39, '3236'),
	(377, 1, 0, -50246, 3238, 0, 0, 39, '3237'),
	(377, 1, 0, -50246, 3239, 0, 0, 39, '3238'),
	(377, 1, 0, -50246, 3240, 0, 0, 39, '3239'),
	(377, 1, 0, -50246, 3241, 0, 0, 39, '3240'),
	(377, 1, 0, -50246, 3242, 0, 0, 39, '3241'),
	(377, 1, 0, -50246, 3243, 0, 0, 39, '3242'),
	(377, 1, 0, -50246, 3244, 0, 0, 39, '3243'),
	(377, 1, 0, -50246, 3245, 0, 0, 39, '3244'),
	(377, 1, 0, -50246, 3246, 0, 0, 39, '3245'),
	(377, 1, 0, -50246, 3247, 0, 0, 39, '3246'),
	(377, 1, 0, -50246, 3248, 0, 0, 39, '3247'),
	(377, 1, 0, -50246, 3249, 0, 0, 39, '3248'),
	(377, 1, 0, -50246, 3250, 0, 0, 39, '3249'),
	(377, 1, 0, -50246, 3251, 0, 0, 39, '3250'),
	(377, 1, 0, -50246, 3252, 0, 0, 39, '3251'),
	(377, 1, 0, -50246, 3253, 0, 0, 39, '3252'),
	(377, 1, 0, -50246, 3254, 0, 0, 39, '3253'),
	(377, 1, 0, -50246, 3255, 0, 0, 39, '3254'),
	(377, 1, 0, -50246, 3256, 0, 0, 39, '3255'),
	(377, 1, 0, -50246, 3257, 0, 0, 39, '3256'),
	(377, 1, 0, -50246, 3258, 0, 0, 39, '3257'),
	(377, 1, 0, -50246, 3259, 0, 0, 39, '3258'),
	(377, 1, 0, -50246, 3260, 0, 0, 39, '3259'),
	(377, 1, 0, -50246, 3261, 0, 0, 39, '3260'),
	(377, 1, 0, -50246, 3262, 0, 0, 39, '3261'),
	(377, 1, 0, -50246, 3263, 0, 0, 39, '3262'),
	(377, 1, 0, -50246, 3264, 0, 0, 39, '3263'),
	(377, 1, 0, -50246, 3265, 0, 0, 39, '3264'),
	(377, 1, 0, -50246, 3266, 0, 0, 39, '3265'),
	(377, 1, 0, -50246, 3267, 0, 0, 39, '3266'),
	(377, 1, 0, -50246, 3268, 0, 0, 39, '3267'),
	(377, 1, 0, -50246, 3269, 0, 0, 39, '3268'),
	(377, 1, 0, -50246, 3270, 0, 0, 39, '3269'),
	(377, 1, 0, -50246, 3271, 0, 0, 39, '3270'),
	(377, 1, 0, -50246, 3272, 0, 0, 39, '3271'),
	(377, 1, 0, -50246, 3273, 0, 0, 39, '3272'),
	(377, 1, 0, -50246, 3274, 0, 0, 39, '3273'),
	(377, 1, 0, -50246, 3275, 0, 0, 39, '3274'),
	(377, 1, 0, -50246, 3276, 0, 0, 39, '3275'),
	(377, 1, 0, -50246, 3277, 0, 0, 39, '3276'),
	(377, 1, 0, -50246, 3278, 0, 0, 39, '3277'),
	(377, 1, 0, -50246, 3279, 0, 0, 39, '3278'),
	(377, 1, 0, -50246, 3280, 0, 0, 39, '3279'),
	(377, 1, 0, -50246, 3281, 0, 0, 39, '3280'),
	(377, 1, 0, -50246, 3282, 0, 0, 39, '3281'),
	(377, 1, 0, -50246, 3283, 0, 0, 39, '3282'),
	(377, 1, 0, -50246, 3284, 0, 0, 39, '3283'),
	(377, 1, 0, -50246, 3285, 0, 0, 39, '3284'),
	(377, 1, 0, -50246, 3286, 0, 0, 39, '3285'),
	(377, 1, 0, -50246, 3287, 0, 0, 39, '3286'),
	(377, 1, 0, -50246, 3288, 0, 0, 39, '3287'),
	(377, 1, 0, -50246, 3289, 0, 0, 39, '3288'),
	(377, 1, 0, -50246, 3290, 0, 0, 39, '3289'),
	(377, 1, 0, -50246, 3291, 0, 0, 39, '3290'),
	(377, 1, 0, -50246, 3292, 0, 0, 39, '3291'),
	(377, 1, 0, -50246, 3293, 0, 0, 39, '3292'),
	(377, 1, 0, -50246, 3294, 0, 0, 39, '3293'),
	(377, 1, 0, -50246, 3295, 0, 0, 39, '3294'),
	(377, 1, 0, -50246, 3296, 0, 0, 39, '3295'),
	(377, 1, 0, -50246, 3297, 0, 0, 39, '3296'),
	(377, 1, 0, -50246, 3298, 0, 0, 39, '3297'),
	(377, 1, 0, -50246, 3299, 0, 0, 39, '3298'),
	(377, 1, 0, -50246, 3300, 0, 0, 39, '3299'),
	(377, 1, 0, -50246, 3301, 0, 0, 39, '3300'),
	(377, 1, 0, -50246, 3302, 0, 0, 39, '3301'),
	(377, 1, 0, -50246, 3303, 0, 0, 39, '3302'),
	(377, 1, 0, -50246, 3304, 0, 0, 39, '3303'),
	(377, 1, 0, -50246, 3305, 0, 0, 39, '3304'),
	(377, 1, 0, -50246, 3306, 0, 0, 39, '3305'),
	(377, 1, 0, -50246, 3307, 0, 0, 39, '3306'),
	(377, 1, 0, -50246, 3308, 0, 0, 39, '3307'),
	(377, 1, 0, -50246, 3309, 0, 0, 39, '3308'),
	(377, 1, 0, -50246, 3310, 0, 0, 39, '3309'),
	(377, 1, 0, -50246, 3311, 0, 0, 39, '3310'),
	(377, 1, 0, -50246, 3312, 0, 0, 39, '3311'),
	(377, 1, 0, -50246, 3313, 0, 0, 39, '3312'),
	(377, 1, 0, -50246, 3314, 0, 0, 39, '3313'),
	(377, 1, 0, -50246, 3315, 0, 0, 39, '3314'),
	(377, 1, 0, -50246, 3316, 0, 0, 39, '3315'),
	(377, 1, 0, -50246, 3317, 0, 0, 39, '3316'),
	(377, 1, 0, -50246, 3318, 0, 0, 39, '3317'),
	(377, 1, 0, -50246, 3319, 0, 0, 39, '3318'),
	(377, 1, 0, -50246, 3320, 0, 0, 39, '3319'),
	(377, 1, 0, -50246, 3321, 0, 0, 39, '3320'),
	(377, 1, 0, -50246, 3322, 0, 0, 39, '3321'),
	(377, 1, 0, -50246, 3323, 0, 0, 39, '3322'),
	(377, 1, 0, -50246, 3324, 0, 0, 39, '3323'),
	(377, 1, 0, -50246, 3325, 0, 0, 39, '3324'),
	(377, 1, 0, -50246, 3326, 0, 0, 39, '3325'),
	(377, 1, 0, -50246, 3327, 0, 0, 39, '3326'),
	(377, 1, 0, -50246, 3328, 0, 0, 39, '3327'),
	(377, 1, 0, -50246, 3329, 0, 0, 39, '3328'),
	(377, 1, 0, -50246, 3330, 0, 0, 39, '3329'),
	(377, 1, 0, -50246, 3331, 0, 0, 39, '3330'),
	(377, 1, 0, -50246, 3332, 0, 0, 39, '3331'),
	(377, 1, 0, -50246, 3333, 0, 0, 39, '3332'),
	(377, 1, 0, -50246, 3334, 0, 0, 39, '3333'),
	(377, 1, 0, -50246, 3335, 0, 0, 39, '3334'),
	(377, 1, 0, -50246, 3336, 0, 0, 39, '3335'),
	(377, 1, 0, -50246, 3337, 0, 0, 39, '3336'),
	(377, 1, 0, -50246, 3338, 0, 0, 39, '3337'),
	(377, 1, 0, -50246, 3339, 0, 0, 39, '3338'),
	(377, 1, 0, -50246, 3340, 0, 0, 39, '3339'),
	(377, 1, 0, -50246, 3341, 0, 0, 39, '3340'),
	(377, 1, 0, -50246, 3342, 0, 0, 39, '3341'),
	(377, 1, 0, -50246, 3343, 0, 0, 39, '3342'),
	(377, 1, 0, -50246, 3344, 0, 0, 39, '3343'),
	(377, 1, 0, -50246, 3345, 0, 0, 39, '3344'),
	(377, 1, 0, -50246, 3346, 0, 0, 39, '3345'),
	(377, 1, 0, -50246, 3347, 0, 0, 39, '3346'),
	(377, 1, 0, -50246, 3348, 0, 0, 39, '3347'),
	(377, 1, 0, -50246, 3349, 0, 0, 39, '3348'),
	(377, 1, 0, -50246, 3350, 0, 0, 39, '3349'),
	(377, 1, 0, -50246, 3351, 0, 0, 39, '3350'),
	(377, 1, 0, -50246, 3352, 0, 0, 39, '3351'),
	(377, 1, 0, -50246, 3353, 0, 0, 39, '3352'),
	(377, 1, 0, -50246, 3354, 0, 0, 39, '3353'),
	(377, 1, 0, -50246, 3355, 0, 0, 39, '3354'),
	(377, 1, 0, -50246, 3356, 0, 0, 39, '3355'),
	(377, 1, 0, -50246, 3357, 0, 0, 39, '3356'),
	(377, 1, 0, -50246, 3358, 0, 0, 39, '3357'),
	(377, 1, 0, -50246, 3359, 0, 0, 39, '3358'),
	(377, 1, 0, -50246, 3360, 0, 0, 39, '3359'),
	(377, 1, 0, -50246, 3361, 0, 0, 39, '3360'),
	(377, 1, 0, -50246, 3362, 0, 0, 39, '3361'),
	(377, 1, 0, -50246, 3363, 0, 0, 39, '3362'),
	(377, 1, 0, -50246, 3364, 0, 0, 39, '3363'),
	(377, 1, 0, -50246, 3365, 0, 0, 39, '3364'),
	(377, 1, 0, -50246, 3366, 0, 0, 39, '3365'),
	(377, 1, 0, -50246, 3367, 0, 0, 39, '3366'),
	(377, 1, 0, -50246, 3368, 0, 0, 39, '3367'),
	(377, 1, 0, -50246, 3369, 0, 0, 39, '3368'),
	(377, 1, 0, -50246, 3370, 0, 0, 39, '3369'),
	(377, 1, 0, -50246, 3371, 0, 0, 39, '3370'),
	(377, 1, 0, -50246, 3372, 0, 0, 39, '3371'),
	(377, 1, 0, -50246, 3373, 0, 0, 39, '3372'),
	(377, 1, 0, -50246, 3374, 0, 0, 39, '3373'),
	(377, 1, 0, -50246, 3375, 0, 0, 39, '3374'),
	(377, 1, 0, -50246, 3376, 0, 0, 39, '3375'),
	(377, 1, 0, -50246, 3377, 0, 0, 39, '3376'),
	(377, 1, 0, -50246, 3378, 0, 0, 39, '3377'),
	(377, 1, 0, -50246, 3379, 0, 0, 39, '3378'),
	(377, 1, 0, -50246, 3380, 0, 0, 39, '3379'),
	(377, 1, 0, -50246, 3381, 0, 0, 39, '3380'),
	(377, 1, 0, -50246, 3382, 0, 0, 39, '3381'),
	(377, 1, 0, -50246, 3383, 0, 0, 39, '3382'),
	(377, 1, 0, -50246, 3384, 0, 0, 39, '3383'),
	(377, 1, 0, -50246, 3385, 0, 0, 39, '3384'),
	(377, 1, 0, -50246, 3386, 0, 0, 39, '3385'),
	(377, 1, 0, -50246, 3387, 0, 0, 39, '3386'),
	(377, 1, 0, -50246, 3388, 0, 0, 39, '3387'),
	(377, 1, 0, -50246, 3389, 0, 0, 39, '3388'),
	(377, 1, 0, -50246, 3390, 0, 0, 39, '3389'),
	(377, 1, 0, -50246, 3391, 0, 0, 39, '3390'),
	(377, 1, 0, -50246, 3392, 0, 0, 39, '3391'),
	(377, 1, 0, -50246, 3393, 0, 0, 39, '3392'),
	(377, 1, 0, -50246, 3394, 0, 0, 39, '3393'),
	(377, 1, 0, -50246, 3395, 0, 0, 39, '3394'),
	(377, 1, 0, -50246, 3396, 0, 0, 39, '3395'),
	(377, 1, 0, -50246, 3397, 0, 0, 39, '3396'),
	(377, 1, 0, -50246, 3398, 0, 0, 39, '3397'),
	(377, 1, 0, -50246, 3399, 0, 0, 39, '3398'),
	(377, 1, 0, -50246, 3400, 0, 0, 39, '3399'),
	(377, 1, 0, -50246, 3401, 0, 0, 39, '3400'),
	(377, 1, 0, -50246, 3402, 0, 0, 39, '3401'),
	(377, 1, 0, -50246, 3403, 0, 0, 39, '3402'),
	(377, 1, 0, -50246, 3404, 0, 0, 39, '3403'),
	(377, 1, 0, -50246, 3405, 0, 0, 39, '3404'),
	(377, 1, 0, -50246, 3406, 0, 0, 39, '3405'),
	(377, 1, 0, -50246, 3407, 0, 0, 39, '3406'),
	(377, 1, 0, -50246, 3408, 0, 0, 39, '3407'),
	(377, 1, 0, -50246, 3409, 0, 0, 39, '3408'),
	(377, 1, 0, -50246, 3410, 0, 0, 39, '3409'),
	(377, 1, 0, -50246, 3411, 0, 0, 39, '3410'),
	(377, 1, 0, -50246, 3412, 0, 0, 39, '3411'),
	(377, 1, 0, -50246, 3413, 0, 0, 39, '3412'),
	(377, 1, 0, -50246, 3414, 0, 0, 39, '3413'),
	(377, 1, 0, -50246, 3415, 0, 0, 39, '3414'),
	(377, 1, 0, -50246, 3416, 0, 0, 39, '3415'),
	(377, 1, 0, -50246, 3417, 0, 0, 39, '3416'),
	(377, 1, 0, -50246, 3418, 0, 0, 39, '3417'),
	(377, 1, 0, -50246, 3419, 0, 0, 39, '3418'),
	(377, 1, 0, -50246, 3420, 0, 0, 39, '3419'),
	(377, 1, 0, -50246, 3421, 0, 0, 39, '3420'),
	(377, 1, 0, -50246, 3422, 0, 0, 39, '3421'),
	(377, 1, 0, -50246, 3423, 0, 0, 39, '3422'),
	(377, 1, 0, -50246, 3424, 0, 0, 39, '3423'),
	(377, 1, 0, -50246, 3425, 0, 0, 39, '3424'),
	(377, 1, 0, -50246, 3426, 0, 0, 39, '3425'),
	(377, 1, 0, -50246, 3427, 0, 0, 39, '3426'),
	(377, 1, 0, -50246, 3428, 0, 0, 39, '3427'),
	(377, 1, 0, -50246, 3429, 0, 0, 39, '3428'),
	(377, 1, 0, -50246, 3430, 0, 0, 39, '3429'),
	(377, 1, 0, -50246, 3431, 0, 0, 39, '3430'),
	(377, 1, 0, -50246, 3432, 0, 0, 39, '3431'),
	(377, 1, 0, -50246, 3433, 0, 0, 39, '3432'),
	(377, 1, 0, -50246, 3434, 0, 0, 39, '3433'),
	(377, 1, 0, -50246, 3435, 0, 0, 39, '3434'),
	(377, 1, 0, -50246, 3436, 0, 0, 39, '3435'),
	(377, 1, 0, -50246, 3437, 0, 0, 39, '3436'),
	(377, 1, 0, -50246, 3438, 0, 0, 39, '3437'),
	(377, 1, 0, -50246, 3439, 0, 0, 39, '3438'),
	(377, 1, 0, -50246, 3440, 0, 0, 39, '3439'),
	(377, 1, 0, -50246, 3441, 0, 0, 39, '3440'),
	(377, 1, 0, -50246, 3442, 0, 0, 39, '3441'),
	(377, 1, 0, -50246, 3443, 0, 0, 39, '3442'),
	(377, 1, 0, -50246, 3444, 0, 0, 39, '3443'),
	(377, 1, 0, -50246, 3445, 0, 0, 39, '3444'),
	(377, 1, 0, -50246, 3446, 0, 0, 39, '3445'),
	(377, 1, 0, -50246, 3447, 0, 0, 39, '3446'),
	(377, 1, 0, -50246, 3448, 0, 0, 39, '3447'),
	(377, 1, 0, -50246, 3449, 0, 0, 39, '3448'),
	(377, 1, 0, -50246, 3450, 0, 0, 39, '3449'),
	(377, 1, 0, -50246, 3451, 0, 0, 39, '3450'),
	(377, 1, 0, -50246, 3452, 0, 0, 39, '3451'),
	(377, 1, 0, -50246, 3453, 0, 0, 39, '3452'),
	(377, 1, 0, -50246, 3454, 0, 0, 39, '3453'),
	(377, 1, 0, -50246, 3455, 0, 0, 39, '3454'),
	(377, 1, 0, -50246, 3456, 0, 0, 39, '3455'),
	(377, 1, 0, -50246, 3457, 0, 0, 39, '3456'),
	(377, 1, 0, -50246, 3458, 0, 0, 39, '3457'),
	(377, 1, 0, -50246, 3459, 0, 0, 39, '3458'),
	(377, 1, 0, -50246, 3460, 0, 0, 39, '3459'),
	(377, 1, 0, -50246, 3461, 0, 0, 39, '3460'),
	(377, 1, 0, -50246, 3462, 0, 0, 39, '3461'),
	(377, 1, 0, -50246, 3463, 0, 0, 39, '3462'),
	(377, 1, 0, -50246, 3464, 0, 0, 39, '3463'),
	(377, 1, 0, -50246, 3465, 0, 0, 39, '3464'),
	(377, 1, 0, -50246, 3466, 0, 0, 39, '3465'),
	(377, 1, 0, -50246, 3467, 0, 0, 39, '3466'),
	(377, 1, 0, -50246, 3468, 0, 0, 39, '3467'),
	(377, 1, 0, -50246, 3469, 0, 0, 39, '3468'),
	(377, 1, 0, -50246, 3470, 0, 0, 39, '3469'),
	(377, 1, 0, -50246, 3471, 0, 0, 39, '3470'),
	(377, 1, 0, -50246, 3472, 0, 0, 39, '3471'),
	(377, 1, 0, -50246, 3473, 0, 0, 39, '3472'),
	(377, 1, 0, -50246, 3474, 0, 0, 39, '3473'),
	(377, 1, 0, -50246, 3475, 0, 0, 39, '3474'),
	(377, 1, 0, -50246, 3476, 0, 0, 39, '3475'),
	(377, 1, 0, -50246, 3477, 0, 0, 39, '3476'),
	(377, 1, 0, -50246, 3478, 0, 0, 39, '3477'),
	(377, 1, 0, -50246, 3479, 0, 0, 39, '3478'),
	(377, 1, 0, -50246, 3480, 0, 0, 39, '3479'),
	(377, 1, 0, -50246, 3481, 0, 0, 39, '3480'),
	(377, 1, 0, -50246, 3482, 0, 0, 39, '3481'),
	(377, 1, 0, -50246, 3483, 0, 0, 39, '3482'),
	(377, 1, 0, -50246, 3484, 0, 0, 39, '3483'),
	(377, 1, 0, -50246, 3485, 0, 0, 39, '3484'),
	(377, 1, 0, -50246, 3486, 0, 0, 39, '3485'),
	(377, 1, 0, -50246, 3487, 0, 0, 39, '3486'),
	(377, 1, 0, -50246, 3488, 0, 0, 39, '3487'),
	(377, 1, 0, -50246, 3489, 0, 0, 39, '3488'),
	(377, 1, 0, -50246, 3490, 0, 0, 39, '3489'),
	(377, 1, 0, -50246, 3491, 0, 0, 39, '3490'),
	(377, 1, 0, -50246, 3492, 0, 0, 39, '3491'),
	(377, 1, 0, -50246, 3493, 0, 0, 39, '3492'),
	(377, 1, 0, -50246, 3494, 0, 0, 39, '3493'),
	(377, 1, 0, -50246, 3495, 0, 0, 39, '3494'),
	(377, 1, 0, -50246, 3496, 0, 0, 39, '3495'),
	(377, 1, 0, -50246, 3497, 0, 0, 39, '3496'),
	(377, 1, 0, -50246, 3498, 0, 0, 39, '3497'),
	(377, 1, 0, -50246, 3499, 0, 0, 39, '3498'),
	(377, 1, 0, -50246, 3500, 0, 0, 39, '3499'),
	(377, 1, 0, -50246, 3501, 0, 0, 39, '3500'),
	(377, 1, 0, -50246, 3502, 0, 0, 39, '3501'),
	(377, 1, 0, -50246, 3503, 0, 0, 39, '3502'),
	(377, 1, 0, -50246, 3504, 0, 0, 39, '3503'),
	(377, 1, 0, -50246, 3505, 0, 0, 39, '3504'),
	(377, 1, 0, -50246, 3506, 0, 0, 39, '3505'),
	(377, 1, 0, -50246, 3507, 0, 0, 39, '3506'),
	(377, 1, 0, -50246, 3508, 0, 0, 39, '3507'),
	(377, 1, 0, -50246, 3509, 0, 0, 39, '3508'),
	(377, 1, 0, -50246, 3510, 0, 0, 39, '3509'),
	(377, 1, 0, -50246, 3511, 0, 0, 39, '3510'),
	(377, 1, 0, -50246, 3512, 0, 0, 39, '3511'),
	(377, 1, 0, -50246, 3513, 0, 0, 39, '3512'),
	(377, 1, 0, -50246, 3514, 0, 0, 39, '3513'),
	(377, 1, 0, -50246, 3515, 0, 0, 39, '3514'),
	(377, 1, 0, -50246, 3516, 0, 0, 39, '3515'),
	(377, 1, 0, -50246, 3517, 0, 0, 39, '3516'),
	(377, 1, 0, -50246, 3518, 0, 0, 39, '3517'),
	(377, 1, 0, -50246, 3519, 0, 0, 39, '3518'),
	(377, 1, 0, -50246, 3520, 0, 0, 39, '3519'),
	(377, 1, 0, -50246, 3521, 0, 0, 39, '3520'),
	(377, 1, 0, -50246, 3522, 0, 0, 39, '3521'),
	(377, 1, 0, -50246, 3523, 0, 0, 39, '3522'),
	(377, 1, 0, -50246, 3524, 0, 0, 39, '3523'),
	(377, 1, 0, -50246, 3525, 0, 0, 39, '3524'),
	(377, 1, 0, -50246, 3526, 0, 0, 39, '3525'),
	(377, 1, 0, -50246, 3527, 0, 0, 39, '3526'),
	(377, 1, 0, -50246, 3528, 0, 0, 39, '3527'),
	(377, 1, 0, -50246, 3529, 0, 0, 39, '3528'),
	(377, 1, 0, -50246, 3530, 0, 0, 39, '3529'),
	(377, 1, 0, -50246, 3531, 0, 0, 39, '3530'),
	(377, 1, 0, -50246, 3532, 0, 0, 39, '3531'),
	(377, 1, 0, -50246, 3533, 0, 0, 39, '3532'),
	(377, 1, 0, -50246, 3534, 0, 0, 39, '3533'),
	(377, 1, 0, -50246, 3535, 0, 0, 39, '3534'),
	(377, 1, 0, -50246, 3536, 0, 0, 39, '3535'),
	(377, 1, 0, -50246, 3537, 0, 0, 39, '3536'),
	(377, 1, 0, -50246, 3538, 0, 0, 39, '3537'),
	(377, 1, 0, -50246, 3539, 0, 0, 39, '3538'),
	(377, 1, 0, -50246, 3540, 0, 0, 39, '3539'),
	(377, 1, 0, -50246, 3541, 0, 0, 39, '3540'),
	(377, 1, 0, -50246, 3542, 0, 0, 39, '3541'),
	(377, 1, 0, -50246, 3543, 0, 0, 39, '3542'),
	(377, 1, 0, -50246, 3544, 0, 0, 39, '3543'),
	(377, 1, 0, -50246, 3545, 0, 0, 39, '3544'),
	(377, 1, 0, -50246, 3546, 0, 0, 39, '3545'),
	(377, 1, 0, -50246, 3547, 0, 0, 39, '3546'),
	(377, 1, 0, -50246, 3548, 0, 0, 39, '3547'),
	(377, 1, 0, -50246, 3549, 0, 0, 39, '3548'),
	(377, 1, 0, -50246, 3550, 0, 0, 39, '3549'),
	(377, 1, 0, -50246, 3551, 0, 0, 39, '3550'),
	(377, 1, 0, -50246, 3552, 0, 0, 39, '3551'),
	(377, 1, 0, -50246, 3553, 0, 0, 39, '3552'),
	(377, 1, 0, -50246, 3554, 0, 0, 39, '3553'),
	(377, 1, 0, -50246, 3555, 0, 0, 39, '3554'),
	(377, 1, 0, -50246, 3556, 0, 0, 39, '3555'),
	(377, 1, 0, -50246, 3557, 0, 0, 39, '3556'),
	(377, 1, 0, -50246, 3558, 0, 0, 39, '3557'),
	(377, 1, 0, -50246, 3559, 0, 0, 39, '3558'),
	(377, 1, 0, -50246, 3560, 0, 0, 39, '3559'),
	(377, 1, 0, -50246, 3561, 0, 0, 39, '3560'),
	(377, 1, 0, -50246, 3562, 0, 0, 39, '3561'),
	(377, 1, 0, -50246, 3563, 0, 0, 39, '3562'),
	(377, 1, 0, -50246, 3564, 0, 0, 39, '3563'),
	(377, 1, 0, -50246, 3565, 0, 0, 39, '3564'),
	(377, 1, 0, -50246, 3566, 0, 0, 39, '3565'),
	(377, 1, 0, -50246, 3567, 0, 0, 39, '3566'),
	(377, 1, 0, -50246, 3568, 0, 0, 39, '3567'),
	(377, 1, 0, -50246, 3569, 0, 0, 39, '3568'),
	(377, 1, 0, -50246, 3570, 0, 0, 39, '3569'),
	(377, 1, 0, -50246, 3571, 0, 0, 39, '3570'),
	(377, 1, 0, -50246, 3572, 0, 0, 39, '3571'),
	(377, 1, 0, -50246, 3573, 0, 0, 39, '3572'),
	(377, 1, 0, -50246, 3574, 0, 0, 39, '3573'),
	(377, 1, 0, -50246, 3575, 0, 0, 39, '3574'),
	(377, 1, 0, -50246, 3576, 0, 0, 39, '3575'),
	(377, 1, 0, -50246, 3577, 0, 0, 39, '3576'),
	(377, 1, 0, -50246, 3578, 0, 0, 39, '3577'),
	(377, 1, 0, -50246, 3579, 0, 0, 39, '3578'),
	(377, 1, 0, -50246, 3580, 0, 0, 39, '3579'),
	(377, 1, 0, -50246, 3581, 0, 0, 39, '3580'),
	(377, 1, 0, -50246, 3582, 0, 0, 39, '3581'),
	(377, 1, 0, -50246, 3583, 0, 0, 39, '3582'),
	(377, 1, 0, -50246, 3584, 0, 0, 39, '3583'),
	(377, 1, 0, -50246, 3585, 0, 0, 39, '3584'),
	(377, 1, 0, -50246, 3586, 0, 0, 39, '3585'),
	(377, 1, 0, -50246, 3587, 0, 0, 39, '3586'),
	(377, 1, 0, -50246, 3588, 0, 0, 39, '3587'),
	(377, 1, 0, -50246, 3589, 0, 0, 39, '3588'),
	(377, 1, 0, -50246, 3590, 0, 0, 39, '3589'),
	(377, 1, 0, -50246, 3591, 0, 0, 39, '3590'),
	(377, 1, 0, -50246, 3592, 0, 0, 39, '3591'),
	(377, 1, 0, -50246, 3593, 0, 0, 39, '3592'),
	(377, 1, 0, -50246, 3594, 0, 0, 39, '3593'),
	(377, 1, 0, -50246, 3595, 0, 0, 39, '3594'),
	(377, 1, 0, -50246, 3596, 0, 0, 39, '3595'),
	(377, 1, 0, -50246, 3597, 0, 0, 39, '3596'),
	(377, 1, 0, -50246, 3598, 0, 0, 39, '3597'),
	(377, 1, 0, -50246, 3599, 0, 0, 39, '3598'),
	(377, 1, 0, -50246, 3600, 0, 0, 39, '3599'),
	(377, 1, 0, -50246, 3601, 0, 0, 39, '3600'),
	(377, 1, 0, -50246, 3602, 0, 0, 39, '3601'),
	(377, 1, 0, -50246, 3603, 0, 0, 39, '3602'),
	(377, 1, 0, -50246, 3604, 0, 0, 39, '3603'),
	(377, 1, 0, -50246, 3605, 0, 0, 39, '3604'),
	(377, 1, 0, -50246, 3606, 0, 0, 39, '3605'),
	(377, 1, 0, -50246, 3607, 0, 0, 39, '3606'),
	(377, 1, 0, -50246, 3608, 0, 0, 39, '3607'),
	(377, 1, 0, -50246, 3609, 0, 0, 39, '3608'),
	(377, 1, 0, -50246, 3610, 0, 0, 39, '3609'),
	(377, 1, 0, -50246, 3611, 0, 0, 39, '3610'),
	(377, 1, 0, -50246, 3612, 0, 0, 39, '3611'),
	(377, 1, 0, -50246, 3613, 0, 0, 39, '3612'),
	(377, 1, 0, -50246, 3614, 0, 0, 39, '3613'),
	(377, 1, 0, -50246, 3615, 0, 0, 39, '3614'),
	(377, 1, 0, -50246, 3616, 0, 0, 39, '3615'),
	(377, 1, 0, -50246, 3617, 0, 0, 39, '3616'),
	(377, 1, 0, -50246, 3618, 0, 0, 39, '3617'),
	(377, 1, 0, -50246, 3619, 0, 0, 39, '3618'),
	(377, 1, 0, -50246, 3620, 0, 0, 39, '3619'),
	(377, 1, 0, -50246, 3621, 0, 0, 39, '3620'),
	(377, 1, 0, -50246, 3622, 0, 0, 39, '3621'),
	(377, 1, 0, -50246, 3623, 0, 0, 39, '3622'),
	(377, 1, 0, -50246, 3624, 0, 0, 39, '3623'),
	(377, 1, 0, -50246, 3625, 0, 0, 39, '3624'),
	(377, 1, 0, -50246, 3626, 0, 0, 39, '3625'),
	(377, 1, 0, -50246, 3627, 0, 0, 39, '3626'),
	(377, 1, 0, -50246, 3628, 0, 0, 39, '3627'),
	(377, 1, 0, -50246, 3629, 0, 0, 39, '3628'),
	(377, 1, 0, -50246, 3630, 0, 0, 39, '3629'),
	(377, 1, 0, -50246, 3631, 0, 0, 39, '3630'),
	(377, 1, 0, -50246, 3632, 0, 0, 39, '3631'),
	(377, 1, 0, -50246, 3633, 0, 0, 39, '3632'),
	(377, 1, 0, -50246, 3634, 0, 0, 39, '3633'),
	(377, 1, 0, -50246, 3635, 0, 0, 39, '3634'),
	(377, 1, 0, -50246, 3636, 0, 0, 39, '3635'),
	(377, 1, 0, -50246, 3637, 0, 0, 39, '3636'),
	(377, 1, 0, -50246, 3638, 0, 0, 39, '3637'),
	(377, 1, 0, -50246, 3639, 0, 0, 39, '3638'),
	(377, 1, 0, -50246, 3640, 0, 0, 39, '3639'),
	(377, 1, 0, -50246, 3641, 0, 0, 39, '3640'),
	(377, 1, 0, -50246, 3642, 0, 0, 39, '3641'),
	(377, 1, 0, -50246, 3643, 0, 0, 39, '3642'),
	(377, 1, 0, -50246, 3644, 0, 0, 39, '3643'),
	(377, 1, 0, -50246, 3645, 0, 0, 39, '3644'),
	(377, 1, 0, -50246, 3646, 0, 0, 39, '3645'),
	(377, 1, 0, -50246, 3647, 0, 0, 39, '3646'),
	(377, 1, 0, -50246, 3648, 0, 0, 39, '3647'),
	(377, 1, 0, -50246, 3649, 0, 0, 39, '3648'),
	(377, 1, 0, -50246, 3650, 0, 0, 39, '3649'),
	(377, 1, 0, -50246, 3651, 0, 0, 39, '3650'),
	(377, 1, 0, -50246, 3652, 0, 0, 39, '3651'),
	(377, 1, 0, -50246, 3653, 0, 0, 39, '3652'),
	(377, 1, 0, -50246, 3654, 0, 0, 39, '3653'),
	(377, 1, 0, -50246, 3655, 0, 0, 39, '3654'),
	(377, 1, 0, -50246, 3656, 0, 0, 39, '3655'),
	(377, 1, 0, -50246, 3657, 0, 0, 39, '3656'),
	(377, 1, 0, -50246, 3658, 0, 0, 39, '3657'),
	(377, 1, 0, -50246, 3659, 0, 0, 39, '3658'),
	(377, 1, 0, -50246, 3660, 0, 0, 39, '3659'),
	(377, 1, 0, -50246, 3661, 0, 0, 39, '3660'),
	(377, 1, 0, -50246, 3662, 0, 0, 39, '3661'),
	(377, 1, 0, -50246, 3663, 0, 0, 39, '3662'),
	(377, 1, 0, -50246, 3664, 0, 0, 39, '3663'),
	(377, 1, 0, -50246, 3665, 0, 0, 39, '3664'),
	(377, 1, 0, -50246, 3666, 0, 0, 39, '3665'),
	(377, 1, 0, -50246, 3667, 0, 0, 39, '3666'),
	(377, 1, 0, -50246, 3668, 0, 0, 39, '3667'),
	(377, 1, 0, -50246, 3669, 0, 0, 39, '3668'),
	(377, 1, 0, -50246, 3670, 0, 0, 39, '3669'),
	(377, 1, 0, -50246, 3671, 0, 0, 39, '3670'),
	(377, 1, 0, -50246, 3672, 0, 0, 39, '3671'),
	(377, 1, 0, -50246, 3673, 0, 0, 39, '3672'),
	(377, 1, 0, -50246, 3674, 0, 0, 39, '3673'),
	(377, 1, 0, -50246, 3675, 0, 0, 39, '3674'),
	(377, 1, 0, -50246, 3676, 0, 0, 39, '3675'),
	(377, 1, 0, -50246, 3677, 0, 0, 39, '3676'),
	(377, 1, 0, -50246, 3678, 0, 0, 39, '3677'),
	(377, 1, 0, -50246, 3679, 0, 0, 39, '3678'),
	(377, 1, 0, -50246, 3680, 0, 0, 39, '3679'),
	(377, 1, 0, -50246, 3681, 0, 0, 39, '3680'),
	(377, 1, 0, -50246, 3682, 0, 0, 39, '3681'),
	(377, 1, 0, -50246, 3683, 0, 0, 39, '3682'),
	(377, 1, 0, -50246, 3684, 0, 0, 39, '3683'),
	(377, 1, 0, -50246, 3685, 0, 0, 39, '3684'),
	(377, 1, 0, -50246, 3686, 0, 0, 39, '3685'),
	(377, 1, 0, -50246, 3687, 0, 0, 39, '3686'),
	(377, 1, 0, -50246, 3688, 0, 0, 39, '3687'),
	(377, 1, 0, -50246, 3689, 0, 0, 39, '3688'),
	(377, 1, 0, -50246, 3690, 0, 0, 39, '3689'),
	(377, 1, 0, -50246, 3691, 0, 0, 39, '3690'),
	(377, 1, 0, -50246, 3692, 0, 0, 39, '3691'),
	(377, 1, 0, -50246, 3693, 0, 0, 39, '3692'),
	(377, 1, 0, -50246, 3694, 0, 0, 39, '3693'),
	(377, 1, 0, -50246, 3695, 0, 0, 39, '3694'),
	(377, 1, 0, -50246, 3696, 0, 0, 39, '3695'),
	(377, 1, 0, -50246, 3697, 0, 0, 39, '3696'),
	(377, 1, 0, -50246, 3698, 0, 0, 39, '3697'),
	(377, 1, 0, -50246, 3699, 0, 0, 39, '3698'),
	(377, 1, 0, -50246, 3700, 0, 0, 39, '3699'),
	(377, 1, 0, -50246, 3701, 0, 0, 39, '3700'),
	(377, 1, 0, -50246, 3702, 0, 0, 39, '3701'),
	(377, 1, 0, -50246, 3703, 0, 0, 39, '3702'),
	(377, 1, 0, -50246, 3704, 0, 0, 39, '3703'),
	(377, 1, 0, -50246, 3705, 0, 0, 39, '3704'),
	(377, 1, 0, -50246, 3706, 0, 0, 39, '3705'),
	(377, 1, 0, -50246, 3707, 0, 0, 39, '3706'),
	(377, 1, 0, -50246, 3708, 0, 0, 39, '3707'),
	(377, 1, 0, -50246, 3709, 0, 0, 39, '3708'),
	(377, 1, 0, -50246, 3710, 0, 0, 39, '3709'),
	(377, 1, 0, -50246, 3711, 0, 0, 39, '3710'),
	(377, 1, 0, -50246, 3712, 0, 0, 39, '3711'),
	(377, 1, 0, -50246, 3713, 0, 0, 39, '3712'),
	(377, 1, 0, -50246, 3714, 0, 0, 39, '3713'),
	(377, 1, 0, -50246, 3715, 0, 0, 39, '3714'),
	(377, 1, 0, -50246, 3716, 0, 0, 39, '3715'),
	(377, 1, 0, -50246, 3717, 0, 0, 39, '3716'),
	(377, 1, 0, -50246, 3718, 0, 0, 39, '3717'),
	(377, 1, 0, -50246, 3719, 0, 0, 39, '3718'),
	(377, 1, 0, -50246, 3720, 0, 0, 39, '3719'),
	(377, 1, 0, -50246, 3721, 0, 0, 39, '3720'),
	(377, 1, 0, -50246, 3722, 0, 0, 39, '3721'),
	(377, 1, 0, -50246, 3723, 0, 0, 39, '3722'),
	(377, 1, 0, -50246, 3724, 0, 0, 39, '3723'),
	(377, 1, 0, -50246, 3725, 0, 0, 39, '3724'),
	(377, 1, 0, -50246, 3726, 0, 0, 39, '3725'),
	(377, 1, 0, -50246, 3727, 0, 0, 39, '3726'),
	(377, 1, 0, -50246, 3728, 0, 0, 39, '3727'),
	(377, 1, 0, -50246, 3729, 0, 0, 39, '3728'),
	(377, 1, 0, -50246, 3730, 0, 0, 39, '3729'),
	(377, 1, 0, -50246, 3731, 0, 0, 39, '3730'),
	(377, 1, 0, -50246, 3732, 0, 0, 39, '3731'),
	(377, 1, 0, -50246, 3733, 0, 0, 39, '3732'),
	(377, 1, 0, -50246, 3734, 0, 0, 39, '3733'),
	(377, 1, 0, -50246, 3735, 0, 0, 39, '3734'),
	(377, 1, 0, -50246, 3736, 0, 0, 39, '3735'),
	(377, 1, 0, -50246, 3737, 0, 0, 39, '3736'),
	(377, 1, 0, -50246, 3738, 0, 0, 39, '3737'),
	(377, 1, 0, -50246, 3739, 0, 0, 39, '3738'),
	(377, 1, 0, -50246, 3740, 0, 0, 39, '3739'),
	(377, 1, 0, -50246, 3741, 0, 0, 39, '3740'),
	(377, 1, 0, -50246, 3742, 0, 0, 39, '3741'),
	(377, 1, 0, -50246, 3743, 0, 0, 39, '3742'),
	(377, 1, 0, -50246, 3744, 0, 0, 39, '3743'),
	(377, 1, 0, -50246, 3745, 0, 0, 39, '3744'),
	(377, 1, 0, -50246, 3746, 0, 0, 39, '3745'),
	(377, 1, 0, -50246, 3747, 0, 0, 39, '3746'),
	(377, 1, 0, -50246, 3748, 0, 0, 39, '3747'),
	(377, 1, 0, -50246, 3749, 0, 0, 39, '3748'),
	(377, 1, 0, -50246, 3750, 0, 0, 39, '3749'),
	(377, 1, 0, -50246, 3751, 0, 0, 39, '3750'),
	(377, 1, 0, -50246, 3752, 0, 0, 39, '3751'),
	(377, 1, 0, -50246, 3753, 0, 0, 39, '3752'),
	(377, 1, 0, -50246, 3754, 0, 0, 39, '3753'),
	(377, 1, 0, -50246, 3755, 0, 0, 39, '3754'),
	(377, 1, 0, -50246, 3756, 0, 0, 39, '3755'),
	(377, 1, 0, -50246, 3757, 0, 0, 39, '3756'),
	(377, 1, 0, -50246, 3758, 0, 0, 39, '3757'),
	(377, 1, 0, -50246, 3759, 0, 0, 39, '3758'),
	(377, 1, 0, -50246, 3760, 0, 0, 39, '3759'),
	(377, 1, 0, -50246, 3761, 0, 0, 39, '3760'),
	(377, 1, 0, -50246, 3762, 0, 0, 39, '3761'),
	(377, 1, 0, -50246, 3763, 0, 0, 39, '3762'),
	(377, 1, 0, -50246, 3764, 0, 0, 39, '3763'),
	(377, 1, 0, -50246, 3765, 0, 0, 39, '3764'),
	(377, 1, 0, -50246, 3766, 0, 0, 39, '3765'),
	(377, 1, 0, -50246, 3767, 0, 0, 39, '3766'),
	(377, 1, 0, -50246, 3768, 0, 0, 39, '3767'),
	(377, 1, 0, -50246, 3769, 0, 0, 39, '3768'),
	(377, 1, 0, -50246, 3770, 0, 0, 39, '3769'),
	(377, 1, 0, -50246, 3771, 0, 0, 39, '3770'),
	(377, 1, 0, -50246, 3772, 0, 0, 39, '3771'),
	(377, 1, 0, -50246, 3773, 0, 0, 39, '3772'),
	(377, 1, 0, -50246, 3774, 0, 0, 39, '3773'),
	(377, 1, 0, -50246, 3775, 0, 0, 39, '3774'),
	(377, 1, 0, -50246, 3776, 0, 0, 39, '3775'),
	(377, 1, 0, -50246, 3777, 0, 0, 39, '3776'),
	(377, 1, 0, -50246, 3778, 0, 0, 39, '3777'),
	(377, 1, 0, -50246, 3779, 0, 0, 39, '3778'),
	(377, 1, 0, -50246, 3780, 0, 0, 39, '3779'),
	(377, 1, 0, -50246, 3781, 0, 0, 39, '3780'),
	(377, 1, 0, -50246, 3782, 0, 0, 39, '3781'),
	(377, 1, 0, -50246, 3783, 0, 0, 39, '3782'),
	(377, 1, 0, -50246, 3784, 0, 0, 39, '3783'),
	(377, 1, 0, -50246, 3785, 0, 0, 39, '3784'),
	(377, 1, 0, -50246, 3786, 0, 0, 39, '3785'),
	(377, 1, 0, -50246, 3787, 0, 0, 39, '3786'),
	(377, 1, 0, -50246, 3788, 0, 0, 39, '3787'),
	(377, 1, 0, -50246, 3789, 0, 0, 39, '3788'),
	(377, 1, 0, -50246, 3790, 0, 0, 39, '3789'),
	(377, 1, 0, -50246, 3791, 0, 0, 39, '3790'),
	(377, 1, 0, -50246, 3792, 0, 0, 39, '3791'),
	(377, 1, 0, -50246, 3793, 0, 0, 39, '3792'),
	(377, 1, 0, -50246, 3794, 0, 0, 39, '3793'),
	(377, 1, 0, -50246, 3795, 0, 0, 39, '3794'),
	(377, 1, 0, -50246, 3796, 0, 0, 39, '3795'),
	(377, 1, 0, -50246, 3797, 0, 0, 39, '3796'),
	(377, 1, 0, -50246, 3798, 0, 0, 39, '3797'),
	(377, 1, 0, -50246, 3799, 0, 0, 39, '3798'),
	(377, 1, 0, -50246, 3800, 0, 0, 39, '3799'),
	(377, 1, 0, -50246, 3801, 0, 0, 39, '3800'),
	(377, 1, 0, -50246, 3802, 0, 0, 39, '3801'),
	(377, 1, 0, -50246, 3803, 0, 0, 39, '3802'),
	(377, 1, 0, -50246, 3804, 0, 0, 39, '3803'),
	(377, 1, 0, -50246, 3805, 0, 0, 39, '3804'),
	(377, 1, 0, -50246, 3806, 0, 0, 39, '3805'),
	(377, 1, 0, -50246, 3807, 0, 0, 39, '3806'),
	(377, 1, 0, -50246, 3808, 0, 0, 39, '3807'),
	(377, 1, 0, -50246, 3809, 0, 0, 39, '3808'),
	(377, 1, 0, -50246, 3810, 0, 0, 39, '3809'),
	(377, 1, 0, -50246, 3811, 0, 0, 39, '3810'),
	(377, 1, 0, -50246, 3812, 0, 0, 39, '3811'),
	(377, 1, 0, -50246, 3813, 0, 0, 39, '3812'),
	(377, 1, 0, -50246, 3814, 0, 0, 39, '3813'),
	(377, 1, 0, -50246, 3815, 0, 0, 39, '3814'),
	(377, 1, 0, -50246, 3816, 0, 0, 39, '3815'),
	(377, 1, 0, -50246, 3817, 0, 0, 39, '3816'),
	(377, 1, 0, -50246, 3818, 0, 0, 39, '3817'),
	(377, 1, 0, -50246, 3819, 0, 0, 39, '3818'),
	(377, 1, 0, -50246, 3820, 0, 0, 39, '3819'),
	(377, 1, 0, -50246, 3821, 0, 0, 39, '3820'),
	(377, 1, 0, -50246, 3822, 0, 0, 39, '3821'),
	(377, 1, 0, -50246, 3823, 0, 0, 39, '3822'),
	(377, 1, 0, -50246, 3824, 0, 0, 39, '3823'),
	(377, 1, 0, -50246, 3825, 0, 0, 39, '3824'),
	(377, 1, 0, -50246, 3826, 0, 0, 39, '3825'),
	(377, 1, 0, -50246, 3827, 0, 0, 39, '3826'),
	(377, 1, 0, -50246, 3828, 0, 0, 39, '3827'),
	(377, 1, 0, -50246, 3829, 0, 0, 39, '3828'),
	(377, 1, 0, -50246, 3830, 0, 0, 39, '3829'),
	(377, 1, 0, -50246, 3831, 0, 0, 39, '3830'),
	(377, 1, 0, -50246, 3832, 0, 0, 39, '3831'),
	(377, 1, 0, -50246, 3833, 0, 0, 39, '3832'),
	(377, 1, 0, -50246, 3834, 0, 0, 39, '3833'),
	(377, 1, 0, -50246, 3835, 0, 0, 39, '3834'),
	(377, 1, 0, -50246, 3836, 0, 0, 39, '3835'),
	(377, 1, 0, -50246, 3837, 0, 0, 39, '3836'),
	(377, 1, 0, -50246, 3838, 0, 0, 39, '3837'),
	(377, 1, 0, -50246, 3839, 0, 0, 39, '3838'),
	(377, 1, 0, -50246, 3840, 0, 0, 39, '3839'),
	(377, 1, 0, -50246, 3841, 0, 0, 39, '3840'),
	(377, 1, 0, -50246, 3842, 0, 0, 39, '3841'),
	(377, 1, 0, -50246, 3843, 0, 0, 39, '3842'),
	(377, 1, 0, -50246, 3844, 0, 0, 39, '3843'),
	(377, 1, 0, -50246, 3845, 0, 0, 39, '3844'),
	(377, 1, 0, -50246, 3846, 0, 0, 39, '3845'),
	(377, 1, 0, -50246, 3847, 0, 0, 39, '3846'),
	(377, 1, 0, -50246, 3848, 0, 0, 39, '3847'),
	(377, 1, 0, -50246, 3849, 0, 0, 39, '3848'),
	(377, 1, 0, -50246, 3850, 0, 0, 39, '3849'),
	(377, 1, 0, -50246, 3851, 0, 0, 39, '3850'),
	(377, 1, 0, -50246, 3852, 0, 0, 39, '3851'),
	(377, 1, 0, -50246, 3853, 0, 0, 39, '3852'),
	(377, 1, 0, -50246, 3854, 0, 0, 39, '3853'),
	(377, 1, 0, -50246, 3855, 0, 0, 39, '3854'),
	(377, 1, 0, -50246, 3856, 0, 0, 39, '3855'),
	(377, 1, 0, -50246, 3857, 0, 0, 39, '3856'),
	(377, 1, 0, -50246, 3858, 0, 0, 39, '3857'),
	(377, 1, 0, -50246, 3859, 0, 0, 39, '3858'),
	(377, 1, 0, -50246, 3860, 0, 0, 39, '3859'),
	(377, 1, 0, -50246, 3861, 0, 0, 39, '3860'),
	(377, 1, 0, -50246, 3862, 0, 0, 39, '3861'),
	(377, 1, 0, -50246, 3863, 0, 0, 39, '3862'),
	(377, 1, 0, -50246, 3864, 0, 0, 39, '3863'),
	(377, 1, 0, -50246, 3865, 0, 0, 39, '3864'),
	(377, 1, 0, -50246, 3866, 0, 0, 39, '3865'),
	(377, 1, 0, -50246, 3867, 0, 0, 39, '3866'),
	(377, 1, 0, -50246, 3868, 0, 0, 39, '3867'),
	(377, 1, 0, -50246, 3869, 0, 0, 39, '3868'),
	(377, 1, 0, -50246, 3870, 0, 0, 39, '3869'),
	(377, 1, 0, -50246, 3871, 0, 0, 39, '3870'),
	(377, 1, 0, -50246, 3872, 0, 0, 39, '3871'),
	(377, 1, 0, -50246, 3873, 0, 0, 39, '3872'),
	(377, 1, 0, -50246, 3874, 0, 0, 39, '3873'),
	(377, 1, 0, -50246, 3875, 0, 0, 39, '3874'),
	(377, 1, 0, -50246, 3876, 0, 0, 39, '3875'),
	(377, 1, 0, -50246, 3877, 0, 0, 39, '3876'),
	(377, 1, 0, -50246, 3878, 0, 0, 39, '3877'),
	(377, 1, 0, -50246, 3879, 0, 0, 39, '3878'),
	(377, 1, 0, -50246, 3880, 0, 0, 39, '3879'),
	(377, 1, 0, -50246, 3881, 0, 0, 39, '3880'),
	(377, 1, 0, -50246, 3882, 0, 0, 39, '3881'),
	(377, 1, 0, -50246, 3883, 0, 0, 39, '3882'),
	(377, 1, 0, -50246, 3884, 0, 0, 39, '3883'),
	(377, 1, 0, -50246, 3885, 0, 0, 39, '3884'),
	(377, 1, 0, -50246, 3886, 0, 0, 39, '3885'),
	(377, 1, 0, -50246, 3887, 0, 0, 39, '3886'),
	(377, 1, 0, -50246, 3888, 0, 0, 39, '3887'),
	(377, 1, 0, -50246, 3889, 0, 0, 39, '3888'),
	(377, 1, 0, -50246, 3890, 0, 0, 39, '3889'),
	(377, 1, 0, -50246, 3891, 0, 0, 39, '3890'),
	(377, 1, 0, -50246, 3892, 0, 0, 39, '3891'),
	(377, 1, 0, -50246, 3893, 0, 0, 39, '3892'),
	(377, 1, 0, -50246, 3894, 0, 0, 39, '3893'),
	(377, 1, 0, -50246, 3895, 0, 0, 39, '3894'),
	(377, 1, 0, -50246, 3896, 0, 0, 39, '3895'),
	(377, 1, 0, -50246, 3897, 0, 0, 39, '3896'),
	(377, 1, 0, -50246, 3898, 0, 0, 39, '3897'),
	(377, 1, 0, -50246, 3899, 0, 0, 39, '3898'),
	(377, 1, 0, -50246, 3900, 0, 0, 39, '3899'),
	(377, 1, 0, -50246, 3901, 0, 0, 39, '3900'),
	(377, 1, 0, -50246, 3902, 0, 0, 39, '3901'),
	(377, 1, 0, -50246, 3903, 0, 0, 39, '3902'),
	(377, 1, 0, -50246, 3904, 0, 0, 39, '3903'),
	(377, 1, 0, -50246, 3905, 0, 0, 39, '3904'),
	(377, 1, 0, -50246, 3906, 0, 0, 39, '3905'),
	(377, 1, 0, -50246, 3907, 0, 0, 39, '3906'),
	(377, 1, 0, -50246, 3908, 0, 0, 39, '3907'),
	(377, 1, 0, -50246, 3909, 0, 0, 39, '3908'),
	(377, 1, 0, -50246, 3910, 0, 0, 39, '3909'),
	(377, 1, 0, -50246, 3911, 0, 0, 39, '3910'),
	(377, 1, 0, -50246, 3912, 0, 0, 39, '3911'),
	(377, 1, 0, -50246, 3913, 0, 0, 39, '3912'),
	(377, 1, 0, -50246, 3914, 0, 0, 39, '3913'),
	(377, 1, 0, -50246, 3915, 0, 0, 39, '3914'),
	(377, 1, 0, -50246, 3916, 0, 0, 39, '3915'),
	(377, 1, 0, -50246, 3917, 0, 0, 39, '3916'),
	(377, 1, 0, -50246, 3918, 0, 0, 39, '3917'),
	(377, 1, 0, -50246, 3919, 0, 0, 39, '3918'),
	(377, 1, 0, -50246, 3920, 0, 0, 39, '3919'),
	(377, 1, 0, -50246, 3921, 0, 0, 39, '3920'),
	(377, 1, 0, -50246, 3922, 0, 0, 39, '3921'),
	(377, 1, 0, -50246, 3923, 0, 0, 39, '3922'),
	(377, 1, 0, -50246, 3924, 0, 0, 39, '3923'),
	(377, 1, 0, -50246, 3925, 0, 0, 39, '3924'),
	(377, 1, 0, -50246, 3926, 0, 0, 39, '3925'),
	(377, 1, 0, -50246, 3927, 0, 0, 39, '3926'),
	(377, 1, 0, -50246, 3928, 0, 0, 39, '3927'),
	(377, 1, 0, -50246, 3929, 0, 0, 39, '3928'),
	(377, 1, 0, -50246, 3930, 0, 0, 39, '3929'),
	(377, 1, 0, -50246, 3931, 0, 0, 39, '3930'),
	(377, 1, 0, -50246, 3932, 0, 0, 39, '3931'),
	(377, 1, 0, -50246, 3933, 0, 0, 39, '3932'),
	(377, 1, 0, -50246, 3934, 0, 0, 39, '3933'),
	(377, 1, 0, -50246, 3935, 0, 0, 39, '3934'),
	(377, 1, 0, -50246, 3936, 0, 0, 39, '3935'),
	(377, 1, 0, -50246, 3937, 0, 0, 39, '3936'),
	(377, 1, 0, -50246, 3938, 0, 0, 39, '3937'),
	(377, 1, 0, -50246, 3939, 0, 0, 39, '3938'),
	(377, 1, 0, -50246, 3940, 0, 0, 39, '3939'),
	(377, 1, 0, -50246, 3941, 0, 0, 39, '3940'),
	(377, 1, 0, -50246, 3942, 0, 0, 39, '3941'),
	(377, 1, 0, -50246, 3943, 0, 0, 39, '3942'),
	(377, 1, 0, -50246, 3944, 0, 0, 39, '3943'),
	(377, 1, 0, -50246, 3945, 0, 0, 39, '3944'),
	(377, 1, 0, -50246, 3946, 0, 0, 39, '3945'),
	(377, 1, 0, -50246, 3947, 0, 0, 39, '3946'),
	(377, 1, 0, -50246, 3948, 0, 0, 39, '3947'),
	(377, 1, 0, -50246, 3949, 0, 0, 39, '3948'),
	(377, 1, 0, -50246, 3950, 0, 0, 39, '3949'),
	(377, 1, 0, -50246, 3951, 0, 0, 39, '3950'),
	(377, 1, 0, -50246, 3952, 0, 0, 39, '3951'),
	(377, 1, 0, -50246, 3953, 0, 0, 39, '3952'),
	(377, 1, 0, -50246, 3954, 0, 0, 39, '3953'),
	(377, 1, 0, -50246, 3955, 0, 0, 39, '3954'),
	(377, 1, 0, -50246, 3956, 0, 0, 39, '3955'),
	(377, 1, 0, -50246, 3957, 0, 0, 39, '3956'),
	(377, 1, 0, -50246, 3958, 0, 0, 39, '3957'),
	(377, 1, 0, -50246, 3959, 0, 0, 39, '3958'),
	(377, 1, 0, -50246, 3960, 0, 0, 39, '3959'),
	(377, 1, 0, -50246, 3961, 0, 0, 39, '3960'),
	(377, 1, 0, -50246, 3962, 0, 0, 39, '3961'),
	(377, 1, 0, -50246, 3963, 0, 0, 39, '3962'),
	(377, 1, 0, -50246, 3964, 0, 0, 39, '3963'),
	(377, 1, 0, -50246, 3965, 0, 0, 39, '3964'),
	(377, 1, 0, -50246, 3966, 0, 0, 39, '3965'),
	(377, 1, 0, -50246, 3967, 0, 0, 39, '3966'),
	(377, 1, 0, -50246, 3968, 0, 0, 39, '3967'),
	(377, 1, 0, -50246, 3969, 0, 0, 39, '3968'),
	(377, 1, 0, -50246, 3970, 0, 0, 39, '3969'),
	(377, 1, 0, -50246, 3971, 0, 0, 39, '3970'),
	(377, 1, 0, -50246, 3972, 0, 0, 39, '3971'),
	(377, 1, 0, -50246, 3973, 0, 0, 39, '3972'),
	(377, 1, 0, -50246, 3974, 0, 0, 39, '3973'),
	(377, 1, 0, -50246, 3975, 0, 0, 39, '3974'),
	(377, 1, 0, -50246, 3976, 0, 0, 39, '3975'),
	(377, 1, 0, -50246, 3977, 0, 0, 39, '3976'),
	(377, 1, 0, -50246, 3978, 0, 0, 39, '3977'),
	(377, 1, 0, -50246, 3979, 0, 0, 39, '3978'),
	(377, 1, 0, -50246, 3980, 0, 0, 39, '3979'),
	(377, 1, 0, -50246, 3981, 0, 0, 39, '3980'),
	(377, 1, 0, -50246, 3982, 0, 0, 39, '3981'),
	(377, 1, 0, -50246, 3983, 0, 0, 39, '3982'),
	(377, 1, 0, -50246, 3984, 0, 0, 39, '3983'),
	(377, 1, 0, -50246, 3985, 0, 0, 39, '3984'),
	(377, 1, 0, -50246, 3986, 0, 0, 39, '3985'),
	(377, 1, 0, -50246, 3987, 0, 0, 39, '3986'),
	(377, 1, 0, -50246, 3988, 0, 0, 39, '3987'),
	(377, 1, 0, -50246, 3989, 0, 0, 39, '3988'),
	(377, 1, 0, -50246, 3990, 0, 0, 39, '3989'),
	(377, 1, 0, -50246, 3991, 0, 0, 39, '3990'),
	(377, 1, 0, -50246, 3992, 0, 0, 39, '3991'),
	(377, 1, 0, -50246, 3993, 0, 0, 39, '3992'),
	(377, 1, 0, -50246, 3994, 0, 0, 39, '3993'),
	(377, 1, 0, -50246, 3995, 0, 0, 39, '3994'),
	(377, 1, 0, -50246, 3996, 0, 0, 39, '3995'),
	(377, 1, 0, -50246, 3997, 0, 0, 39, '3996'),
	(377, 1, 0, -50246, 3998, 0, 0, 39, '3997'),
	(377, 1, 0, -50246, 3999, 0, 0, 39, '3998'),
	(377, 1, 0, -50246, 4000, 0, 0, 39, '3999'),
	(377, 1, 0, -50244, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50244, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50244, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50244, 4, 0, 0, 39, '3'),
	(377, 1, 0, -50244, 5, 0, 0, 39, '4'),
	(377, 1, 0, -50244, 6, 0, 0, 39, '5'),
	(377, 1, 0, -50244, 7, 0, 0, 39, '6'),
	(377, 1, 0, -50244, 8, 0, 0, 39, '7'),
	(377, 1, 0, -50244, 9, 0, 0, 39, '8'),
	(377, 1, 0, -50244, 10, 0, 0, 39, '9'),
	(377, 1, 0, -50244, 11, 0, 0, 39, '10'),
	(377, 1, 0, -50244, 12, 0, 0, 39, '11'),
	(377, 1, 0, -50244, 13, 0, 0, 39, '12'),
	(377, 1, 0, -50244, 14, 0, 0, 39, '13'),
	(377, 1, 0, -50244, 15, 0, 0, 39, '14'),
	(377, 1, 0, -50244, 16, 0, 0, 39, '15'),
	(377, 1, 0, -50244, 17, 0, 0, 39, '16'),
	(377, 1, 0, -50244, 18, 0, 0, 39, '17'),
	(377, 1, 0, -50244, 19, 0, 0, 39, '18'),
	(377, 1, 0, -50244, 20, 0, 0, 39, '19'),
	(377, 1, 0, -50244, 21, 0, 0, 39, '20'),
	(377, 1, 0, -50244, 22, 0, 0, 39, '21'),
	(377, 1, 0, -50244, 23, 0, 0, 39, '22'),
	(377, 1, 0, -50244, 24, 0, 0, 39, '23'),
	(377, 1, 0, -50244, 25, 0, 0, 39, '24'),
	(377, 1, 0, -50244, 26, 0, 0, 39, '25'),
	(377, 1, 0, -50244, 27, 0, 0, 39, '26'),
	(377, 1, 0, -50244, 28, 0, 0, 39, '27'),
	(377, 1, 0, -50244, 29, 0, 0, 39, '28'),
	(377, 1, 0, -50244, 30, 0, 0, 39, '29'),
	(377, 1, 0, -50244, 31, 0, 0, 39, '30'),
	(377, 1, 0, -50244, 32, 0, 0, 39, '31'),
	(377, 1, 0, -50244, 33, 0, 0, 39, '32'),
	(377, 1, 0, -50244, 34, 0, 0, 39, '33'),
	(377, 1, 0, -50244, 35, 0, 0, 39, '34'),
	(377, 1, 0, -50244, 36, 0, 0, 39, '35'),
	(377, 1, 0, -50244, 37, 0, 0, 39, '36'),
	(377, 1, 0, -50244, 38, 0, 0, 39, '37'),
	(377, 1, 0, -50244, 39, 0, 0, 39, '38'),
	(377, 1, 0, -50244, 40, 0, 0, 39, '39'),
	(377, 1, 0, -50244, 41, 0, 0, 39, '40'),
	(377, 1, 0, -50244, 42, 0, 0, 39, '41'),
	(377, 1, 0, -50244, 43, 0, 0, 39, '42'),
	(377, 1, 0, -50244, 44, 0, 0, 39, '43'),
	(377, 1, 0, -50244, 45, 0, 0, 39, '44'),
	(377, 1, 0, -50244, 46, 0, 0, 39, '45'),
	(377, 1, 0, -50244, 47, 0, 0, 39, '46'),
	(377, 1, 0, -50244, 48, 0, 0, 39, '47'),
	(377, 1, 0, -50244, 49, 0, 0, 39, '48'),
	(377, 1, 0, -50244, 50, 0, 0, 39, '49'),
	(377, 1, 0, -50244, 51, 0, 0, 39, '50'),
	(377, 1, 0, -50244, 52, 0, 0, 39, '51'),
	(377, 1, 0, -50244, 53, 0, 0, 39, '52'),
	(377, 1, 0, -50244, 54, 0, 0, 39, '53'),
	(377, 1, 0, -50244, 55, 0, 0, 39, '54'),
	(377, 1, 0, -50244, 56, 0, 0, 39, '55'),
	(377, 1, 0, -50244, 57, 0, 0, 39, '56'),
	(377, 1, 0, -50244, 58, 0, 0, 39, '57'),
	(377, 1, 0, -50244, 59, 0, 0, 39, '58'),
	(377, 1, 0, -50244, 60, 0, 0, 39, '59'),
	(377, 1, 0, -50244, 61, 0, 0, 39, '60'),
	(377, 1, 0, -50244, 62, 0, 0, 39, '61'),
	(377, 1, 0, -50244, 63, 0, 0, 39, '62'),
	(377, 1, 0, -50244, 64, 0, 0, 39, '63'),
	(377, 1, 0, -50244, 65, 0, 0, 39, '64'),
	(377, 1, 0, -50244, 66, 0, 0, 39, '65'),
	(377, 1, 0, -50244, 67, 0, 0, 39, '66'),
	(377, 1, 0, -50244, 68, 0, 0, 39, '67'),
	(377, 1, 0, -50244, 69, 0, 0, 39, '68'),
	(377, 1, 0, -50244, 70, 0, 0, 39, '69'),
	(377, 1, 0, -50244, 71, 0, 0, 39, '70'),
	(377, 1, 0, -50244, 72, 0, 0, 39, '71'),
	(377, 1, 0, -50244, 73, 0, 0, 39, '72'),
	(377, 1, 0, -50244, 74, 0, 0, 39, '73'),
	(377, 1, 0, -50244, 75, 0, 0, 39, '74'),
	(377, 1, 0, -50244, 76, 0, 0, 39, '75'),
	(377, 1, 0, -50244, 77, 0, 0, 39, '76'),
	(377, 1, 0, -50244, 78, 0, 0, 39, '77'),
	(377, 1, 0, -50244, 79, 0, 0, 39, '78'),
	(377, 1, 0, -50244, 80, 0, 0, 39, '79'),
	(377, 1, 0, -50244, 81, 0, 0, 39, '80'),
	(377, 1, 0, -50244, 82, 0, 0, 39, '81'),
	(377, 1, 0, -50244, 83, 0, 0, 39, '82'),
	(377, 1, 0, -50244, 84, 0, 0, 39, '83'),
	(377, 1, 0, -50244, 85, 0, 0, 39, '84'),
	(377, 1, 0, -50244, 86, 0, 0, 39, '85'),
	(377, 1, 0, -50244, 87, 0, 0, 39, '86'),
	(377, 1, 0, -50244, 88, 0, 0, 39, '87'),
	(377, 1, 0, -50244, 89, 0, 0, 39, '88'),
	(377, 1, 0, -50244, 90, 0, 0, 39, '89'),
	(377, 1, 0, -50244, 91, 0, 0, 39, '90'),
	(377, 1, 0, -50244, 92, 0, 0, 39, '91'),
	(377, 1, 0, -50244, 93, 0, 0, 39, '92'),
	(377, 1, 0, -50244, 94, 0, 0, 39, '93'),
	(377, 1, 0, -50244, 95, 0, 0, 39, '94'),
	(377, 1, 0, -50244, 96, 0, 0, 39, '95'),
	(377, 1, 0, -50244, 97, 0, 0, 39, '96'),
	(377, 1, 0, -50244, 98, 0, 0, 39, '97'),
	(377, 1, 0, -50244, 99, 0, 0, 39, '98'),
	(377, 1, 0, -50244, 100, 0, 0, 39, '99'),
	(377, 1, 0, -50244, 101, 0, 0, 39, '100'),
	(377, 1, 0, -50244, 102, 0, 0, 39, '101'),
	(377, 1, 0, -50244, 103, 0, 0, 39, '102'),
	(377, 1, 0, -50244, 104, 0, 0, 39, '103'),
	(377, 1, 0, -50244, 105, 0, 0, 39, '104'),
	(377, 1, 0, -50244, 106, 0, 0, 39, '105'),
	(377, 1, 0, -50244, 107, 0, 0, 39, '106'),
	(377, 1, 0, -50244, 108, 0, 0, 39, '107'),
	(377, 1, 0, -50244, 109, 0, 0, 39, '108'),
	(377, 1, 0, -50244, 110, 0, 0, 39, '109'),
	(377, 1, 0, -50244, 111, 0, 0, 39, '110'),
	(377, 1, 0, -50244, 112, 0, 0, 39, '111'),
	(377, 1, 0, -50244, 113, 0, 0, 39, '112'),
	(377, 1, 0, -50244, 114, 0, 0, 39, '113'),
	(377, 1, 0, -50244, 115, 0, 0, 39, '114'),
	(377, 1, 0, -50244, 116, 0, 0, 39, '115'),
	(377, 1, 0, -50244, 117, 0, 0, 39, '116'),
	(377, 1, 0, -50244, 118, 0, 0, 39, '117'),
	(377, 1, 0, -50244, 119, 0, 0, 39, '118'),
	(377, 1, 0, -50244, 120, 0, 0, 39, '119'),
	(377, 1, 0, -50244, 121, 0, 0, 39, '120'),
	(377, 1, 0, -50244, 122, 0, 0, 39, '121'),
	(377, 1, 0, -50244, 123, 0, 0, 39, '122'),
	(377, 1, 0, -50244, 124, 0, 0, 39, '123'),
	(377, 1, 0, -50244, 125, 0, 0, 39, '124'),
	(377, 1, 0, -50244, 126, 0, 0, 39, '125'),
	(377, 1, 0, -50244, 127, 0, 0, 39, '126'),
	(377, 1, 0, -50244, 128, 0, 0, 39, '127'),
	(377, 1, 0, -50244, 129, 0, 0, 39, '128'),
	(377, 1, 0, -50244, 130, 0, 0, 39, '129'),
	(377, 1, 0, -50244, 131, 0, 0, 39, '130'),
	(377, 1, 0, -50244, 132, 0, 0, 39, '131'),
	(377, 1, 0, -50244, 133, 0, 0, 39, '132'),
	(377, 1, 0, -50244, 134, 0, 0, 39, '133'),
	(377, 1, 0, -50244, 135, 0, 0, 39, '134'),
	(377, 1, 0, -50244, 136, 0, 0, 39, '135'),
	(377, 1, 0, -50244, 137, 0, 0, 39, '136'),
	(377, 1, 0, -50244, 138, 0, 0, 39, '137'),
	(377, 1, 0, -50244, 139, 0, 0, 39, '138'),
	(377, 1, 0, -50244, 140, 0, 0, 39, '139'),
	(377, 1, 0, -50244, 141, 0, 0, 39, '140'),
	(377, 1, 0, -50244, 142, 0, 0, 39, '141');
INSERT INTO `src_type_mod_withe#opty` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`, `ind1`, `ind2`, `ind3`, `opty_id`, `opty_value`) VALUES
	(377, 1, 0, -50244, 143, 0, 0, 39, '142'),
	(377, 1, 0, -50244, 144, 0, 0, 39, '143'),
	(377, 1, 0, -50244, 145, 0, 0, 39, '144'),
	(377, 1, 0, -50244, 146, 0, 0, 39, '145'),
	(377, 1, 0, -50244, 147, 0, 0, 39, '146'),
	(377, 1, 0, -50244, 148, 0, 0, 39, '147'),
	(377, 1, 0, -50244, 149, 0, 0, 39, '148'),
	(377, 1, 0, -50244, 150, 0, 0, 39, '149'),
	(377, 1, 0, -50244, 151, 0, 0, 39, '150'),
	(377, 1, 0, -50244, 152, 0, 0, 39, '151'),
	(377, 1, 0, -50244, 153, 0, 0, 39, '152'),
	(377, 1, 0, -50244, 154, 0, 0, 39, '153'),
	(377, 1, 0, -50244, 155, 0, 0, 39, '154'),
	(377, 1, 0, -50244, 156, 0, 0, 39, '155'),
	(377, 1, 0, -50244, 157, 0, 0, 39, '156'),
	(377, 1, 0, -50244, 158, 0, 0, 39, '157'),
	(377, 1, 0, -50244, 159, 0, 0, 39, '158'),
	(377, 1, 0, -50244, 160, 0, 0, 39, '159'),
	(377, 1, 0, -50244, 161, 0, 0, 39, '160'),
	(377, 1, 0, -50244, 162, 0, 0, 39, '161'),
	(377, 1, 0, -50244, 163, 0, 0, 39, '162'),
	(377, 1, 0, -50244, 164, 0, 0, 39, '163'),
	(377, 1, 0, -50244, 165, 0, 0, 39, '164'),
	(377, 1, 0, -50244, 166, 0, 0, 39, '165'),
	(377, 1, 0, -50244, 167, 0, 0, 39, '166'),
	(377, 1, 0, -50244, 168, 0, 0, 39, '167'),
	(377, 1, 0, -50244, 169, 0, 0, 39, '168'),
	(377, 1, 0, -50244, 170, 0, 0, 39, '169'),
	(377, 1, 0, -50244, 171, 0, 0, 39, '170'),
	(377, 1, 0, -50244, 172, 0, 0, 39, '171'),
	(377, 1, 0, -50244, 173, 0, 0, 39, '172'),
	(377, 1, 0, -50244, 174, 0, 0, 39, '173'),
	(377, 1, 0, -50244, 175, 0, 0, 39, '174'),
	(377, 1, 0, -50244, 176, 0, 0, 39, '175'),
	(377, 1, 0, -50244, 177, 0, 0, 39, '176'),
	(377, 1, 0, -50244, 178, 0, 0, 39, '177'),
	(377, 1, 0, -50244, 179, 0, 0, 39, '178'),
	(377, 1, 0, -50244, 180, 0, 0, 39, '179'),
	(377, 1, 0, -50244, 181, 0, 0, 39, '180'),
	(377, 1, 0, -50244, 182, 0, 0, 39, '181'),
	(377, 1, 0, -50244, 183, 0, 0, 39, '182'),
	(377, 1, 0, -50244, 184, 0, 0, 39, '183'),
	(377, 1, 0, -50244, 185, 0, 0, 39, '184'),
	(377, 1, 0, -50244, 186, 0, 0, 39, '185'),
	(377, 1, 0, -50244, 187, 0, 0, 39, '186'),
	(377, 1, 0, -50244, 188, 0, 0, 39, '187'),
	(377, 1, 0, -50244, 189, 0, 0, 39, '188'),
	(377, 1, 0, -50244, 190, 0, 0, 39, '189'),
	(377, 1, 0, -50244, 191, 0, 0, 39, '190'),
	(377, 1, 0, -50244, 192, 0, 0, 39, '191'),
	(377, 1, 0, -50244, 193, 0, 0, 39, '192'),
	(377, 1, 0, -50244, 194, 0, 0, 39, '193'),
	(377, 1, 0, -50244, 195, 0, 0, 39, '194'),
	(377, 1, 0, -50244, 196, 0, 0, 39, '195'),
	(377, 1, 0, -50244, 197, 0, 0, 39, '196'),
	(377, 1, 0, -50244, 198, 0, 0, 39, '197'),
	(377, 1, 0, -50244, 199, 0, 0, 39, '198'),
	(377, 1, 0, -50244, 200, 0, 0, 39, '199'),
	(377, 1, 0, -50244, 201, 0, 0, 39, '200'),
	(377, 1, 0, -50244, 202, 0, 0, 39, '201'),
	(377, 1, 0, -50244, 203, 0, 0, 39, '202'),
	(377, 1, 0, -50244, 204, 0, 0, 39, '203'),
	(377, 1, 0, -50244, 205, 0, 0, 39, '204'),
	(377, 1, 0, -50244, 206, 0, 0, 39, '205'),
	(377, 1, 0, -50244, 207, 0, 0, 39, '206'),
	(377, 1, 0, -50244, 208, 0, 0, 39, '207'),
	(377, 1, 0, -50244, 209, 0, 0, 39, '208'),
	(377, 1, 0, -50244, 210, 0, 0, 39, '209'),
	(377, 1, 0, -50244, 211, 0, 0, 39, '210'),
	(377, 1, 0, -50244, 212, 0, 0, 39, '211'),
	(377, 1, 0, -50244, 213, 0, 0, 39, '212'),
	(377, 1, 0, -50244, 214, 0, 0, 39, '213'),
	(377, 1, 0, -50244, 215, 0, 0, 39, '214'),
	(377, 1, 0, -50244, 216, 0, 0, 39, '215'),
	(377, 1, 0, -50244, 217, 0, 0, 39, '216'),
	(377, 1, 0, -50244, 218, 0, 0, 39, '217'),
	(377, 1, 0, -50244, 219, 0, 0, 39, '218'),
	(377, 1, 0, -50244, 220, 0, 0, 39, '219'),
	(377, 1, 0, -50244, 221, 0, 0, 39, '220'),
	(377, 1, 0, -50244, 222, 0, 0, 39, '221'),
	(377, 1, 0, -50244, 223, 0, 0, 39, '222'),
	(377, 1, 0, -50244, 224, 0, 0, 39, '223'),
	(377, 1, 0, -50244, 225, 0, 0, 39, '224'),
	(377, 1, 0, -50244, 226, 0, 0, 39, '225'),
	(377, 1, 0, -50244, 227, 0, 0, 39, '226'),
	(377, 1, 0, -50244, 228, 0, 0, 39, '227'),
	(377, 1, 0, -50244, 229, 0, 0, 39, '228'),
	(377, 1, 0, -50244, 230, 0, 0, 39, '229'),
	(377, 1, 0, -50244, 231, 0, 0, 39, '230'),
	(377, 1, 0, -50244, 232, 0, 0, 39, '231'),
	(377, 1, 0, -50244, 233, 0, 0, 39, '232'),
	(377, 1, 0, -50244, 234, 0, 0, 39, '233'),
	(377, 1, 0, -50244, 235, 0, 0, 39, '234'),
	(377, 1, 0, -50244, 236, 0, 0, 39, '235'),
	(377, 1, 0, -50244, 237, 0, 0, 39, '236'),
	(377, 1, 0, -50244, 238, 0, 0, 39, '237'),
	(377, 1, 0, -50244, 239, 0, 0, 39, '238'),
	(377, 1, 0, -50244, 240, 0, 0, 39, '239'),
	(377, 1, 0, -50244, 241, 0, 0, 39, '240'),
	(377, 1, 0, -50244, 242, 0, 0, 39, '241'),
	(377, 1, 0, -50244, 243, 0, 0, 39, '242'),
	(377, 1, 0, -50244, 244, 0, 0, 39, '243'),
	(377, 1, 0, -50244, 245, 0, 0, 39, '244'),
	(377, 1, 0, -50244, 246, 0, 0, 39, '245'),
	(377, 1, 0, -50244, 247, 0, 0, 39, '246'),
	(377, 1, 0, -50244, 248, 0, 0, 39, '247'),
	(377, 1, 0, -50244, 249, 0, 0, 39, '248'),
	(377, 1, 0, -50244, 250, 0, 0, 39, '249'),
	(377, 1, 0, -50244, 251, 0, 0, 39, '250'),
	(377, 1, 0, -50244, 252, 0, 0, 39, '251'),
	(377, 1, 0, -50244, 253, 0, 0, 39, '252'),
	(377, 1, 0, -50244, 254, 0, 0, 39, '253'),
	(377, 1, 0, -50244, 255, 0, 0, 39, '254'),
	(377, 1, 0, -50244, 256, 0, 0, 39, '255'),
	(377, 1, 0, -50244, 257, 0, 0, 39, '256'),
	(377, 1, 0, -50244, 258, 0, 0, 39, '257'),
	(377, 1, 0, -50244, 259, 0, 0, 39, '258'),
	(377, 1, 0, -50244, 260, 0, 0, 39, '259'),
	(377, 1, 0, -50244, 261, 0, 0, 39, '260'),
	(377, 1, 0, -50244, 262, 0, 0, 39, '261'),
	(377, 1, 0, -50244, 263, 0, 0, 39, '262'),
	(377, 1, 0, -50244, 264, 0, 0, 39, '263'),
	(377, 1, 0, -50244, 265, 0, 0, 39, '264'),
	(377, 1, 0, -50244, 266, 0, 0, 39, '265'),
	(377, 1, 0, -50244, 267, 0, 0, 39, '266'),
	(377, 1, 0, -50244, 268, 0, 0, 39, '267'),
	(377, 1, 0, -50244, 269, 0, 0, 39, '268'),
	(377, 1, 0, -50244, 270, 0, 0, 39, '269'),
	(377, 1, 0, -50244, 271, 0, 0, 39, '270'),
	(377, 1, 0, -50244, 272, 0, 0, 39, '271'),
	(377, 1, 0, -50244, 273, 0, 0, 39, '272'),
	(377, 1, 0, -50244, 274, 0, 0, 39, '273'),
	(377, 1, 0, -50244, 275, 0, 0, 39, '274'),
	(377, 1, 0, -50244, 276, 0, 0, 39, '275'),
	(377, 1, 0, -50244, 277, 0, 0, 39, '276'),
	(377, 1, 0, -50244, 278, 0, 0, 39, '277'),
	(377, 1, 0, -50244, 279, 0, 0, 39, '278'),
	(377, 1, 0, -50244, 280, 0, 0, 39, '279'),
	(377, 1, 0, -50244, 281, 0, 0, 39, '280'),
	(377, 1, 0, -50244, 282, 0, 0, 39, '281'),
	(377, 1, 0, -50244, 283, 0, 0, 39, '282'),
	(377, 1, 0, -50244, 284, 0, 0, 39, '283'),
	(377, 1, 0, -50244, 285, 0, 0, 39, '284'),
	(377, 1, 0, -50244, 286, 0, 0, 39, '285'),
	(377, 1, 0, -50244, 287, 0, 0, 39, '286'),
	(377, 1, 0, -50244, 288, 0, 0, 39, '287'),
	(377, 1, 0, -50244, 289, 0, 0, 39, '288'),
	(377, 1, 0, -50244, 290, 0, 0, 39, '289'),
	(377, 1, 0, -50244, 291, 0, 0, 39, '290'),
	(377, 1, 0, -50244, 292, 0, 0, 39, '291'),
	(377, 1, 0, -50244, 293, 0, 0, 39, '292'),
	(377, 1, 0, -50244, 294, 0, 0, 39, '293'),
	(377, 1, 0, -50244, 295, 0, 0, 39, '294'),
	(377, 1, 0, -50244, 296, 0, 0, 39, '295'),
	(377, 1, 0, -50244, 297, 0, 0, 39, '296'),
	(377, 1, 0, -50244, 298, 0, 0, 39, '297'),
	(377, 1, 0, -50244, 299, 0, 0, 39, '298'),
	(377, 1, 0, -50244, 300, 0, 0, 39, '299'),
	(377, 1, 0, -50244, 301, 0, 0, 39, '300'),
	(377, 1, 0, -50244, 302, 0, 0, 39, '301'),
	(377, 1, 0, -50244, 303, 0, 0, 39, '302'),
	(377, 1, 0, -50244, 304, 0, 0, 39, '303'),
	(377, 1, 0, -50244, 305, 0, 0, 39, '304'),
	(377, 1, 0, -50244, 306, 0, 0, 39, '305'),
	(377, 1, 0, -50244, 307, 0, 0, 39, '306'),
	(377, 1, 0, -50244, 308, 0, 0, 39, '307'),
	(377, 1, 0, -50244, 309, 0, 0, 39, '308'),
	(377, 1, 0, -50244, 310, 0, 0, 39, '309'),
	(377, 1, 0, -50244, 311, 0, 0, 39, '310'),
	(377, 1, 0, -50244, 312, 0, 0, 39, '311'),
	(377, 1, 0, -50244, 313, 0, 0, 39, '312'),
	(377, 1, 0, -50244, 314, 0, 0, 39, '313'),
	(377, 1, 0, -50244, 315, 0, 0, 39, '314'),
	(377, 1, 0, -50244, 316, 0, 0, 39, '315'),
	(377, 1, 0, -50244, 317, 0, 0, 39, '316'),
	(377, 1, 0, -50244, 318, 0, 0, 39, '317'),
	(377, 1, 0, -50244, 319, 0, 0, 39, '318'),
	(377, 1, 0, -50244, 320, 0, 0, 39, '319'),
	(377, 1, 0, -50244, 321, 0, 0, 39, '320'),
	(377, 1, 0, -50244, 322, 0, 0, 39, '321'),
	(377, 1, 0, -50244, 323, 0, 0, 39, '322'),
	(377, 1, 0, -50244, 324, 0, 0, 39, '323'),
	(377, 1, 0, -50244, 325, 0, 0, 39, '324'),
	(377, 1, 0, -50244, 326, 0, 0, 39, '325'),
	(377, 1, 0, -50244, 327, 0, 0, 39, '326'),
	(377, 1, 0, -50244, 328, 0, 0, 39, '327'),
	(377, 1, 0, -50244, 329, 0, 0, 39, '328'),
	(377, 1, 0, -50244, 330, 0, 0, 39, '329'),
	(377, 1, 0, -50244, 331, 0, 0, 39, '330'),
	(377, 1, 0, -50244, 332, 0, 0, 39, '331'),
	(377, 1, 0, -50244, 333, 0, 0, 39, '332'),
	(377, 1, 0, -50244, 334, 0, 0, 39, '333'),
	(377, 1, 0, -50244, 335, 0, 0, 39, '334'),
	(377, 1, 0, -50244, 336, 0, 0, 39, '335'),
	(377, 1, 0, -50244, 337, 0, 0, 39, '336'),
	(377, 1, 0, -50244, 338, 0, 0, 39, '337'),
	(377, 1, 0, -50244, 339, 0, 0, 39, '338'),
	(377, 1, 0, -50244, 340, 0, 0, 39, '339'),
	(377, 1, 0, -50244, 341, 0, 0, 39, '340'),
	(377, 1, 0, -50244, 342, 0, 0, 39, '341'),
	(377, 1, 0, -50244, 343, 0, 0, 39, '342'),
	(377, 1, 0, -50244, 344, 0, 0, 39, '343'),
	(377, 1, 0, -50244, 345, 0, 0, 39, '344'),
	(377, 1, 0, -50244, 346, 0, 0, 39, '345'),
	(377, 1, 0, -50244, 347, 0, 0, 39, '346'),
	(377, 1, 0, -50244, 348, 0, 0, 39, '347'),
	(377, 1, 0, -50244, 349, 0, 0, 39, '348'),
	(377, 1, 0, -50244, 350, 0, 0, 39, '349'),
	(377, 1, 0, -50244, 351, 0, 0, 39, '350'),
	(377, 1, 0, -50244, 352, 0, 0, 39, '351'),
	(377, 1, 0, -50244, 353, 0, 0, 39, '352'),
	(377, 1, 0, -50244, 354, 0, 0, 39, '353'),
	(377, 1, 0, -50244, 355, 0, 0, 39, '354'),
	(377, 1, 0, -50244, 356, 0, 0, 39, '355'),
	(377, 1, 0, -50244, 357, 0, 0, 39, '356'),
	(377, 1, 0, -50244, 358, 0, 0, 39, '357'),
	(377, 1, 0, -50244, 359, 0, 0, 39, '358'),
	(377, 1, 0, -50244, 360, 0, 0, 39, '359'),
	(377, 1, 0, -50244, 361, 0, 0, 39, '360'),
	(377, 1, 0, -50244, 362, 0, 0, 39, '361'),
	(377, 1, 0, -50244, 363, 0, 0, 39, '362'),
	(377, 1, 0, -50244, 364, 0, 0, 39, '363'),
	(377, 1, 0, -50244, 365, 0, 0, 39, '364'),
	(377, 1, 0, -50244, 366, 0, 0, 39, '365'),
	(377, 1, 0, -50244, 367, 0, 0, 39, '366'),
	(377, 1, 0, -50244, 368, 0, 0, 39, '367'),
	(377, 1, 0, -50244, 369, 0, 0, 39, '368'),
	(377, 1, 0, -50244, 370, 0, 0, 39, '369'),
	(377, 1, 0, -50244, 371, 0, 0, 39, '370'),
	(377, 1, 0, -50244, 372, 0, 0, 39, '371'),
	(377, 1, 0, -50244, 373, 0, 0, 39, '372'),
	(377, 1, 0, -50244, 374, 0, 0, 39, '373'),
	(377, 1, 0, -50244, 375, 0, 0, 39, '374'),
	(377, 1, 0, -50244, 376, 0, 0, 39, '375'),
	(377, 1, 0, -50244, 377, 0, 0, 39, '376'),
	(377, 1, 0, -50244, 378, 0, 0, 39, '377'),
	(377, 1, 0, -50244, 379, 0, 0, 39, '378'),
	(377, 1, 0, -50244, 380, 0, 0, 39, '379'),
	(377, 1, 0, -50244, 381, 0, 0, 39, '380'),
	(377, 1, 0, -50244, 382, 0, 0, 39, '381'),
	(377, 1, 0, -50244, 383, 0, 0, 39, '382'),
	(377, 1, 0, -50244, 384, 0, 0, 39, '383'),
	(377, 1, 0, -50244, 385, 0, 0, 39, '384'),
	(377, 1, 0, -50244, 386, 0, 0, 39, '385'),
	(377, 1, 0, -50244, 387, 0, 0, 39, '386'),
	(377, 1, 0, -50244, 388, 0, 0, 39, '387'),
	(377, 1, 0, -50244, 389, 0, 0, 39, '388'),
	(377, 1, 0, -50244, 390, 0, 0, 39, '389'),
	(377, 1, 0, -50244, 391, 0, 0, 39, '390'),
	(377, 1, 0, -50244, 392, 0, 0, 39, '391'),
	(377, 1, 0, -50244, 393, 0, 0, 39, '392'),
	(377, 1, 0, -50244, 394, 0, 0, 39, '393'),
	(377, 1, 0, -50244, 395, 0, 0, 39, '394'),
	(377, 1, 0, -50244, 396, 0, 0, 39, '395'),
	(377, 1, 0, -50244, 397, 0, 0, 39, '396'),
	(377, 1, 0, -50244, 398, 0, 0, 39, '397'),
	(377, 1, 0, -50244, 399, 0, 0, 39, '398'),
	(377, 1, 0, -50244, 400, 0, 0, 39, '399'),
	(377, 1, 0, -50244, 401, 0, 0, 39, '400'),
	(377, 1, 0, -50244, 402, 0, 0, 39, '401'),
	(377, 1, 0, -50244, 403, 0, 0, 39, '402'),
	(377, 1, 0, -50244, 404, 0, 0, 39, '403'),
	(377, 1, 0, -50244, 405, 0, 0, 39, '404'),
	(377, 1, 0, -50244, 406, 0, 0, 39, '405'),
	(377, 1, 0, -50244, 407, 0, 0, 39, '406'),
	(377, 1, 0, -50244, 408, 0, 0, 39, '407'),
	(377, 1, 0, -50244, 409, 0, 0, 39, '408'),
	(377, 1, 0, -50244, 410, 0, 0, 39, '409'),
	(377, 1, 0, -50244, 411, 0, 0, 39, '410'),
	(377, 1, 0, -50244, 412, 0, 0, 39, '411'),
	(377, 1, 0, -50244, 413, 0, 0, 39, '412'),
	(377, 1, 0, -50244, 414, 0, 0, 39, '413'),
	(377, 1, 0, -50244, 415, 0, 0, 39, '414'),
	(377, 1, 0, -50244, 416, 0, 0, 39, '415'),
	(377, 1, 0, -50244, 417, 0, 0, 39, '416'),
	(377, 1, 0, -50244, 418, 0, 0, 39, '417'),
	(377, 1, 0, -50244, 419, 0, 0, 39, '418'),
	(377, 1, 0, -50244, 420, 0, 0, 39, '419'),
	(377, 1, 0, -50244, 421, 0, 0, 39, '420'),
	(377, 1, 0, -50244, 422, 0, 0, 39, '421'),
	(377, 1, 0, -50244, 423, 0, 0, 39, '422'),
	(377, 1, 0, -50244, 424, 0, 0, 39, '423'),
	(377, 1, 0, -50244, 425, 0, 0, 39, '424'),
	(377, 1, 0, -50244, 426, 0, 0, 39, '425'),
	(377, 1, 0, -50244, 427, 0, 0, 39, '426'),
	(377, 1, 0, -50244, 428, 0, 0, 39, '427'),
	(377, 1, 0, -50244, 429, 0, 0, 39, '428'),
	(377, 1, 0, -50244, 430, 0, 0, 39, '429'),
	(377, 1, 0, -50244, 431, 0, 0, 39, '430'),
	(377, 1, 0, -50244, 432, 0, 0, 39, '431'),
	(377, 1, 0, -50244, 433, 0, 0, 39, '432'),
	(377, 1, 0, -50244, 434, 0, 0, 39, '433'),
	(377, 1, 0, -50244, 435, 0, 0, 39, '434'),
	(377, 1, 0, -50244, 436, 0, 0, 39, '435'),
	(377, 1, 0, -50244, 437, 0, 0, 39, '436'),
	(377, 1, 0, -50244, 438, 0, 0, 39, '437'),
	(377, 1, 0, -50244, 439, 0, 0, 39, '438'),
	(377, 1, 0, -50244, 440, 0, 0, 39, '439'),
	(377, 1, 0, -50244, 441, 0, 0, 39, '440'),
	(377, 1, 0, -50244, 442, 0, 0, 39, '441'),
	(377, 1, 0, -50244, 443, 0, 0, 39, '442'),
	(377, 1, 0, -50244, 444, 0, 0, 39, '443'),
	(377, 1, 0, -50244, 445, 0, 0, 39, '444'),
	(377, 1, 0, -50244, 446, 0, 0, 39, '445'),
	(377, 1, 0, -50244, 447, 0, 0, 39, '446'),
	(377, 1, 0, -50244, 448, 0, 0, 39, '447'),
	(377, 1, 0, -50244, 449, 0, 0, 39, '448'),
	(377, 1, 0, -50244, 450, 0, 0, 39, '449'),
	(377, 1, 0, -50244, 451, 0, 0, 39, '450'),
	(377, 1, 0, -50244, 452, 0, 0, 39, '451'),
	(377, 1, 0, -50244, 453, 0, 0, 39, '452'),
	(377, 1, 0, -50244, 454, 0, 0, 39, '453'),
	(377, 1, 0, -50244, 455, 0, 0, 39, '454'),
	(377, 1, 0, -50244, 456, 0, 0, 39, '455'),
	(377, 1, 0, -50244, 457, 0, 0, 39, '456'),
	(377, 1, 0, -50244, 458, 0, 0, 39, '457'),
	(377, 1, 0, -50244, 459, 0, 0, 39, '458'),
	(377, 1, 0, -50244, 460, 0, 0, 39, '459'),
	(377, 1, 0, -50244, 461, 0, 0, 39, '460'),
	(377, 1, 0, -50244, 462, 0, 0, 39, '461'),
	(377, 1, 0, -50244, 463, 0, 0, 39, '462'),
	(377, 1, 0, -50244, 464, 0, 0, 39, '463'),
	(377, 1, 0, -50244, 465, 0, 0, 39, '464'),
	(377, 1, 0, -50244, 466, 0, 0, 39, '465'),
	(377, 1, 0, -50244, 467, 0, 0, 39, '466'),
	(377, 1, 0, -50244, 468, 0, 0, 39, '467'),
	(377, 1, 0, -50244, 469, 0, 0, 39, '468'),
	(377, 1, 0, -50244, 470, 0, 0, 39, '469'),
	(377, 1, 0, -50244, 471, 0, 0, 39, '470'),
	(377, 1, 0, -50244, 472, 0, 0, 39, '471'),
	(377, 1, 0, -50244, 473, 0, 0, 39, '472'),
	(377, 1, 0, -50244, 474, 0, 0, 39, '473'),
	(377, 1, 0, -50244, 475, 0, 0, 39, '474'),
	(377, 1, 0, -50244, 476, 0, 0, 39, '475'),
	(377, 1, 0, -50244, 477, 0, 0, 39, '476'),
	(377, 1, 0, -50244, 478, 0, 0, 39, '477'),
	(377, 1, 0, -50244, 479, 0, 0, 39, '478'),
	(377, 1, 0, -50244, 480, 0, 0, 39, '479'),
	(377, 1, 0, -50244, 481, 0, 0, 39, '480'),
	(377, 1, 0, -50244, 482, 0, 0, 39, '481'),
	(377, 1, 0, -50244, 483, 0, 0, 39, '482'),
	(377, 1, 0, -50244, 484, 0, 0, 39, '483'),
	(377, 1, 0, -50244, 485, 0, 0, 39, '484'),
	(377, 1, 0, -50244, 486, 0, 0, 39, '485'),
	(377, 1, 0, -50244, 487, 0, 0, 39, '486'),
	(377, 1, 0, -50244, 488, 0, 0, 39, '487'),
	(377, 1, 0, -50244, 489, 0, 0, 39, '488'),
	(377, 1, 0, -50244, 490, 0, 0, 39, '489'),
	(377, 1, 0, -50244, 491, 0, 0, 39, '490'),
	(377, 1, 0, -50244, 492, 0, 0, 39, '491'),
	(377, 1, 0, -50244, 493, 0, 0, 39, '492'),
	(377, 1, 0, -50244, 494, 0, 0, 39, '493'),
	(377, 1, 0, -50244, 495, 0, 0, 39, '494'),
	(377, 1, 0, -50244, 496, 0, 0, 39, '495'),
	(377, 1, 0, -50244, 497, 0, 0, 39, '496'),
	(377, 1, 0, -50244, 498, 0, 0, 39, '497'),
	(377, 1, 0, -50244, 499, 0, 0, 39, '498'),
	(377, 1, 0, -50244, 500, 0, 0, 39, '499'),
	(377, 1, 0, -50244, 501, 0, 0, 39, '500'),
	(377, 1, 0, -50244, 502, 0, 0, 39, '501'),
	(377, 1, 0, -50244, 503, 0, 0, 39, '502'),
	(377, 1, 0, -50244, 504, 0, 0, 39, '503'),
	(377, 1, 0, -50244, 505, 0, 0, 39, '504'),
	(377, 1, 0, -50244, 506, 0, 0, 39, '505'),
	(377, 1, 0, -50244, 507, 0, 0, 39, '506'),
	(377, 1, 0, -50244, 508, 0, 0, 39, '507'),
	(377, 1, 0, -50244, 509, 0, 0, 39, '508'),
	(377, 1, 0, -50244, 510, 0, 0, 39, '509'),
	(377, 1, 0, -50244, 511, 0, 0, 39, '510'),
	(377, 1, 0, -50244, 512, 0, 0, 39, '511'),
	(377, 1, 0, -50244, 513, 0, 0, 39, '512'),
	(377, 1, 0, -50244, 514, 0, 0, 39, '513'),
	(377, 1, 0, -50244, 515, 0, 0, 39, '514'),
	(377, 1, 0, -50244, 516, 0, 0, 39, '515'),
	(377, 1, 0, -50244, 517, 0, 0, 39, '516'),
	(377, 1, 0, -50244, 518, 0, 0, 39, '517'),
	(377, 1, 0, -50244, 519, 0, 0, 39, '518'),
	(377, 1, 0, -50244, 520, 0, 0, 39, '519'),
	(377, 1, 0, -50244, 521, 0, 0, 39, '520'),
	(377, 1, 0, -50244, 522, 0, 0, 39, '521'),
	(377, 1, 0, -50244, 523, 0, 0, 39, '522'),
	(377, 1, 0, -50244, 524, 0, 0, 39, '523'),
	(377, 1, 0, -50244, 525, 0, 0, 39, '524'),
	(377, 1, 0, -50244, 526, 0, 0, 39, '525'),
	(377, 1, 0, -50244, 527, 0, 0, 39, '526'),
	(377, 1, 0, -50244, 528, 0, 0, 39, '527'),
	(377, 1, 0, -50244, 529, 0, 0, 39, '528'),
	(377, 1, 0, -50244, 530, 0, 0, 39, '529'),
	(377, 1, 0, -50244, 531, 0, 0, 39, '530'),
	(377, 1, 0, -50244, 532, 0, 0, 39, '531'),
	(377, 1, 0, -50244, 533, 0, 0, 39, '532'),
	(377, 1, 0, -50244, 534, 0, 0, 39, '533'),
	(377, 1, 0, -50244, 535, 0, 0, 39, '534'),
	(377, 1, 0, -50244, 536, 0, 0, 39, '535'),
	(377, 1, 0, -50244, 537, 0, 0, 39, '536'),
	(377, 1, 0, -50244, 538, 0, 0, 39, '537'),
	(377, 1, 0, -50244, 539, 0, 0, 39, '538'),
	(377, 1, 0, -50244, 540, 0, 0, 39, '539'),
	(377, 1, 0, -50244, 541, 0, 0, 39, '540'),
	(377, 1, 0, -50244, 542, 0, 0, 39, '541'),
	(377, 1, 0, -50244, 543, 0, 0, 39, '542'),
	(377, 1, 0, -50244, 544, 0, 0, 39, '543'),
	(377, 1, 0, -50244, 545, 0, 0, 39, '544'),
	(377, 1, 0, -50244, 546, 0, 0, 39, '545'),
	(377, 1, 0, -50244, 547, 0, 0, 39, '546'),
	(377, 1, 0, -50244, 548, 0, 0, 39, '547'),
	(377, 1, 0, -50244, 549, 0, 0, 39, '548'),
	(377, 1, 0, -50244, 550, 0, 0, 39, '549'),
	(377, 1, 0, -50244, 551, 0, 0, 39, '550'),
	(377, 1, 0, -50244, 552, 0, 0, 39, '551'),
	(377, 1, 0, -50244, 553, 0, 0, 39, '552'),
	(377, 1, 0, -50244, 554, 0, 0, 39, '553'),
	(377, 1, 0, -50244, 555, 0, 0, 39, '554'),
	(377, 1, 0, -50244, 556, 0, 0, 39, '555'),
	(377, 1, 0, -50244, 557, 0, 0, 39, '556'),
	(377, 1, 0, -50244, 558, 0, 0, 39, '557'),
	(377, 1, 0, -50244, 559, 0, 0, 39, '558'),
	(377, 1, 0, -50244, 560, 0, 0, 39, '559'),
	(377, 1, 0, -50244, 561, 0, 0, 39, '560'),
	(377, 1, 0, -50244, 562, 0, 0, 39, '561'),
	(377, 1, 0, -50244, 563, 0, 0, 39, '562'),
	(377, 1, 0, -50244, 564, 0, 0, 39, '563'),
	(377, 1, 0, -50244, 565, 0, 0, 39, '564'),
	(377, 1, 0, -50244, 566, 0, 0, 39, '565'),
	(377, 1, 0, -50244, 567, 0, 0, 39, '566'),
	(377, 1, 0, -50244, 568, 0, 0, 39, '567'),
	(377, 1, 0, -50244, 569, 0, 0, 39, '568'),
	(377, 1, 0, -50244, 570, 0, 0, 39, '569'),
	(377, 1, 0, -50244, 571, 0, 0, 39, '570'),
	(377, 1, 0, -50244, 572, 0, 0, 39, '571'),
	(377, 1, 0, -50244, 573, 0, 0, 39, '572'),
	(377, 1, 0, -50244, 574, 0, 0, 39, '573'),
	(377, 1, 0, -50244, 575, 0, 0, 39, '574'),
	(377, 1, 0, -50244, 576, 0, 0, 39, '575'),
	(377, 1, 0, -50244, 577, 0, 0, 39, '576'),
	(377, 1, 0, -50244, 578, 0, 0, 39, '577'),
	(377, 1, 0, -50244, 579, 0, 0, 39, '578'),
	(377, 1, 0, -50244, 580, 0, 0, 39, '579'),
	(377, 1, 0, -50244, 581, 0, 0, 39, '580'),
	(377, 1, 0, -50244, 582, 0, 0, 39, '581'),
	(377, 1, 0, -50244, 583, 0, 0, 39, '582'),
	(377, 1, 0, -50244, 584, 0, 0, 39, '583'),
	(377, 1, 0, -50244, 585, 0, 0, 39, '584'),
	(377, 1, 0, -50244, 586, 0, 0, 39, '585'),
	(377, 1, 0, -50244, 587, 0, 0, 39, '586'),
	(377, 1, 0, -50244, 588, 0, 0, 39, '587'),
	(377, 1, 0, -50244, 589, 0, 0, 39, '588'),
	(377, 1, 0, -50244, 590, 0, 0, 39, '589'),
	(377, 1, 0, -50244, 591, 0, 0, 39, '590'),
	(377, 1, 0, -50244, 592, 0, 0, 39, '591'),
	(377, 1, 0, -50244, 593, 0, 0, 39, '592'),
	(377, 1, 0, -50244, 594, 0, 0, 39, '593'),
	(377, 1, 0, -50244, 595, 0, 0, 39, '594'),
	(377, 1, 0, -50244, 596, 0, 0, 39, '595'),
	(377, 1, 0, -50244, 597, 0, 0, 39, '596'),
	(377, 1, 0, -50244, 598, 0, 0, 39, '597'),
	(377, 1, 0, -50244, 599, 0, 0, 39, '598'),
	(377, 1, 0, -50244, 600, 0, 0, 39, '599'),
	(377, 1, 0, -50244, 601, 0, 0, 39, '600'),
	(377, 1, 0, -50244, 602, 0, 0, 39, '601'),
	(377, 1, 0, -50244, 603, 0, 0, 39, '602'),
	(377, 1, 0, -50244, 604, 0, 0, 39, '603'),
	(377, 1, 0, -50244, 605, 0, 0, 39, '604'),
	(377, 1, 0, -50244, 606, 0, 0, 39, '605'),
	(377, 1, 0, -50244, 607, 0, 0, 39, '606'),
	(377, 1, 0, -50244, 608, 0, 0, 39, '607'),
	(377, 1, 0, -50244, 609, 0, 0, 39, '608'),
	(377, 1, 0, -50244, 610, 0, 0, 39, '609'),
	(377, 1, 0, -50244, 611, 0, 0, 39, '610'),
	(377, 1, 0, -50244, 612, 0, 0, 39, '611'),
	(377, 1, 0, -50244, 613, 0, 0, 39, '612'),
	(377, 1, 0, -50244, 614, 0, 0, 39, '613'),
	(377, 1, 0, -50244, 615, 0, 0, 39, '614'),
	(377, 1, 0, -50244, 616, 0, 0, 39, '615'),
	(377, 1, 0, -50244, 617, 0, 0, 39, '616'),
	(377, 1, 0, -50244, 618, 0, 0, 39, '617'),
	(377, 1, 0, -50244, 619, 0, 0, 39, '618'),
	(377, 1, 0, -50244, 620, 0, 0, 39, '619'),
	(377, 1, 0, -50244, 621, 0, 0, 39, '620'),
	(377, 1, 0, -50244, 622, 0, 0, 39, '621'),
	(377, 1, 0, -50244, 623, 0, 0, 39, '622'),
	(377, 1, 0, -50244, 624, 0, 0, 39, '623'),
	(377, 1, 0, -50244, 625, 0, 0, 39, '624'),
	(377, 1, 0, -50244, 626, 0, 0, 39, '625'),
	(377, 1, 0, -50244, 627, 0, 0, 39, '626'),
	(377, 1, 0, -50244, 628, 0, 0, 39, '627'),
	(377, 1, 0, -50244, 629, 0, 0, 39, '628'),
	(377, 1, 0, -50244, 630, 0, 0, 39, '629'),
	(377, 1, 0, -50244, 631, 0, 0, 39, '630'),
	(377, 1, 0, -50244, 632, 0, 0, 39, '631'),
	(377, 1, 0, -50244, 633, 0, 0, 39, '632'),
	(377, 1, 0, -50244, 634, 0, 0, 39, '633'),
	(377, 1, 0, -50244, 635, 0, 0, 39, '634'),
	(377, 1, 0, -50244, 636, 0, 0, 39, '635'),
	(377, 1, 0, -50244, 637, 0, 0, 39, '636'),
	(377, 1, 0, -50244, 638, 0, 0, 39, '637'),
	(377, 1, 0, -50244, 639, 0, 0, 39, '638'),
	(377, 1, 0, -50244, 640, 0, 0, 39, '639'),
	(377, 1, 0, -50244, 641, 0, 0, 39, '640'),
	(377, 1, 0, -50244, 642, 0, 0, 39, '641'),
	(377, 1, 0, -50244, 643, 0, 0, 39, '642'),
	(377, 1, 0, -50244, 644, 0, 0, 39, '643'),
	(377, 1, 0, -50244, 645, 0, 0, 39, '644'),
	(377, 1, 0, -50244, 646, 0, 0, 39, '645'),
	(377, 1, 0, -50244, 647, 0, 0, 39, '646'),
	(377, 1, 0, -50244, 648, 0, 0, 39, '647'),
	(377, 1, 0, -50244, 649, 0, 0, 39, '648'),
	(377, 1, 0, -50244, 650, 0, 0, 39, '649'),
	(377, 1, 0, -50244, 651, 0, 0, 39, '650'),
	(377, 1, 0, -50244, 652, 0, 0, 39, '651'),
	(377, 1, 0, -50244, 653, 0, 0, 39, '652'),
	(377, 1, 0, -50244, 654, 0, 0, 39, '653'),
	(377, 1, 0, -50244, 655, 0, 0, 39, '654'),
	(377, 1, 0, -50244, 656, 0, 0, 39, '655'),
	(377, 1, 0, -50244, 657, 0, 0, 39, '656'),
	(377, 1, 0, -50244, 658, 0, 0, 39, '657'),
	(377, 1, 0, -50244, 659, 0, 0, 39, '658'),
	(377, 1, 0, -50244, 660, 0, 0, 39, '659'),
	(377, 1, 0, -50244, 661, 0, 0, 39, '660'),
	(377, 1, 0, -50244, 662, 0, 0, 39, '661'),
	(377, 1, 0, -50244, 663, 0, 0, 39, '662'),
	(377, 1, 0, -50244, 664, 0, 0, 39, '663'),
	(377, 1, 0, -50244, 665, 0, 0, 39, '664'),
	(377, 1, 0, -50244, 666, 0, 0, 39, '665'),
	(377, 1, 0, -50244, 667, 0, 0, 39, '666'),
	(377, 1, 0, -50244, 668, 0, 0, 39, '667'),
	(377, 1, 0, -50244, 669, 0, 0, 39, '668'),
	(377, 1, 0, -50244, 670, 0, 0, 39, '669'),
	(377, 1, 0, -50244, 671, 0, 0, 39, '670'),
	(377, 1, 0, -50244, 672, 0, 0, 39, '671'),
	(377, 1, 0, -50244, 673, 0, 0, 39, '672'),
	(377, 1, 0, -50244, 674, 0, 0, 39, '673'),
	(377, 1, 0, -50244, 675, 0, 0, 39, '674'),
	(377, 1, 0, -50244, 676, 0, 0, 39, '675'),
	(377, 1, 0, -50244, 677, 0, 0, 39, '676'),
	(377, 1, 0, -50244, 678, 0, 0, 39, '677'),
	(377, 1, 0, -50244, 679, 0, 0, 39, '678'),
	(377, 1, 0, -50244, 680, 0, 0, 39, '679'),
	(377, 1, 0, -50244, 681, 0, 0, 39, '680'),
	(377, 1, 0, -50244, 682, 0, 0, 39, '681'),
	(377, 1, 0, -50244, 683, 0, 0, 39, '682'),
	(377, 1, 0, -50244, 684, 0, 0, 39, '683'),
	(377, 1, 0, -50244, 685, 0, 0, 39, '684'),
	(377, 1, 0, -50244, 686, 0, 0, 39, '685'),
	(377, 1, 0, -50244, 687, 0, 0, 39, '686'),
	(377, 1, 0, -50244, 688, 0, 0, 39, '687'),
	(377, 1, 0, -50244, 689, 0, 0, 39, '688'),
	(377, 1, 0, -50244, 690, 0, 0, 39, '689'),
	(377, 1, 0, -50244, 691, 0, 0, 39, '690'),
	(377, 1, 0, -50244, 692, 0, 0, 39, '691'),
	(377, 1, 0, -50244, 693, 0, 0, 39, '692'),
	(377, 1, 0, -50244, 694, 0, 0, 39, '693'),
	(377, 1, 0, -50244, 695, 0, 0, 39, '694'),
	(377, 1, 0, -50244, 696, 0, 0, 39, '695'),
	(377, 1, 0, -50244, 697, 0, 0, 39, '696'),
	(377, 1, 0, -50244, 698, 0, 0, 39, '697'),
	(377, 1, 0, -50244, 699, 0, 0, 39, '698'),
	(377, 1, 0, -50244, 700, 0, 0, 39, '699'),
	(377, 1, 0, -50244, 701, 0, 0, 39, '700'),
	(377, 1, 0, -50244, 702, 0, 0, 39, '701'),
	(377, 1, 0, -50244, 703, 0, 0, 39, '702'),
	(377, 1, 0, -50244, 704, 0, 0, 39, '703'),
	(377, 1, 0, -50244, 705, 0, 0, 39, '704'),
	(377, 1, 0, -50244, 706, 0, 0, 39, '705'),
	(377, 1, 0, -50244, 707, 0, 0, 39, '706'),
	(377, 1, 0, -50244, 708, 0, 0, 39, '707'),
	(377, 1, 0, -50244, 709, 0, 0, 39, '708'),
	(377, 1, 0, -50244, 710, 0, 0, 39, '709'),
	(377, 1, 0, -50244, 711, 0, 0, 39, '710'),
	(377, 1, 0, -50244, 712, 0, 0, 39, '711'),
	(377, 1, 0, -50244, 713, 0, 0, 39, '712'),
	(377, 1, 0, -50244, 714, 0, 0, 39, '713'),
	(377, 1, 0, -50244, 715, 0, 0, 39, '714'),
	(377, 1, 0, -50244, 716, 0, 0, 39, '715'),
	(377, 1, 0, -50244, 717, 0, 0, 39, '716'),
	(377, 1, 0, -50244, 718, 0, 0, 39, '717'),
	(377, 1, 0, -50244, 719, 0, 0, 39, '718'),
	(377, 1, 0, -50244, 720, 0, 0, 39, '719'),
	(377, 1, 0, -50244, 721, 0, 0, 39, '720'),
	(377, 1, 0, -50244, 722, 0, 0, 39, '721'),
	(377, 1, 0, -50244, 723, 0, 0, 39, '722'),
	(377, 1, 0, -50244, 724, 0, 0, 39, '723'),
	(377, 1, 0, -50244, 725, 0, 0, 39, '724'),
	(377, 1, 0, -50244, 726, 0, 0, 39, '725'),
	(377, 1, 0, -50244, 727, 0, 0, 39, '726'),
	(377, 1, 0, -50244, 728, 0, 0, 39, '727'),
	(377, 1, 0, -50244, 729, 0, 0, 39, '728'),
	(377, 1, 0, -50244, 730, 0, 0, 39, '729'),
	(377, 1, 0, -50244, 731, 0, 0, 39, '730'),
	(377, 1, 0, -50244, 732, 0, 0, 39, '731'),
	(377, 1, 0, -50244, 733, 0, 0, 39, '732'),
	(377, 1, 0, -50244, 734, 0, 0, 39, '733'),
	(377, 1, 0, -50244, 735, 0, 0, 39, '734'),
	(377, 1, 0, -50244, 736, 0, 0, 39, '735'),
	(377, 1, 0, -50244, 737, 0, 0, 39, '736'),
	(377, 1, 0, -50244, 738, 0, 0, 39, '737'),
	(377, 1, 0, -50244, 739, 0, 0, 39, '738'),
	(377, 1, 0, -50244, 740, 0, 0, 39, '739'),
	(377, 1, 0, -50244, 741, 0, 0, 39, '740'),
	(377, 1, 0, -50244, 742, 0, 0, 39, '741'),
	(377, 1, 0, -50244, 743, 0, 0, 39, '742'),
	(377, 1, 0, -50244, 744, 0, 0, 39, '743'),
	(377, 1, 0, -50244, 745, 0, 0, 39, '744'),
	(377, 1, 0, -50244, 746, 0, 0, 39, '745'),
	(377, 1, 0, -50244, 747, 0, 0, 39, '746'),
	(377, 1, 0, -50244, 748, 0, 0, 39, '747'),
	(377, 1, 0, -50244, 749, 0, 0, 39, '748'),
	(377, 1, 0, -50244, 750, 0, 0, 39, '749'),
	(377, 1, 0, -50244, 751, 0, 0, 39, '750'),
	(377, 1, 0, -50244, 752, 0, 0, 39, '751'),
	(377, 1, 0, -50244, 753, 0, 0, 39, '752'),
	(377, 1, 0, -50244, 754, 0, 0, 39, '753'),
	(377, 1, 0, -50244, 755, 0, 0, 39, '754'),
	(377, 1, 0, -50244, 756, 0, 0, 39, '755'),
	(377, 1, 0, -50244, 757, 0, 0, 39, '756'),
	(377, 1, 0, -50244, 758, 0, 0, 39, '757'),
	(377, 1, 0, -50244, 759, 0, 0, 39, '758'),
	(377, 1, 0, -50244, 760, 0, 0, 39, '759'),
	(377, 1, 0, -50244, 761, 0, 0, 39, '760'),
	(377, 1, 0, -50244, 762, 0, 0, 39, '761'),
	(377, 1, 0, -50244, 763, 0, 0, 39, '762'),
	(377, 1, 0, -50244, 764, 0, 0, 39, '763'),
	(377, 1, 0, -50244, 765, 0, 0, 39, '764'),
	(377, 1, 0, -50244, 766, 0, 0, 39, '765'),
	(377, 1, 0, -50244, 767, 0, 0, 39, '766'),
	(377, 1, 0, -50244, 768, 0, 0, 39, '767'),
	(377, 1, 0, -50244, 769, 0, 0, 39, '768'),
	(377, 1, 0, -50244, 770, 0, 0, 39, '769'),
	(377, 1, 0, -50244, 771, 0, 0, 39, '770'),
	(377, 1, 0, -50244, 772, 0, 0, 39, '771'),
	(377, 1, 0, -50244, 773, 0, 0, 39, '772'),
	(377, 1, 0, -50244, 774, 0, 0, 39, '773'),
	(377, 1, 0, -50244, 775, 0, 0, 39, '774'),
	(377, 1, 0, -50244, 776, 0, 0, 39, '775'),
	(377, 1, 0, -50244, 777, 0, 0, 39, '776'),
	(377, 1, 0, -50244, 778, 0, 0, 39, '777'),
	(377, 1, 0, -50244, 779, 0, 0, 39, '778'),
	(377, 1, 0, -50244, 780, 0, 0, 39, '779'),
	(377, 1, 0, -50244, 781, 0, 0, 39, '780'),
	(377, 1, 0, -50244, 782, 0, 0, 39, '781'),
	(377, 1, 0, -50244, 783, 0, 0, 39, '782'),
	(377, 1, 0, -50244, 784, 0, 0, 39, '783'),
	(377, 1, 0, -50244, 785, 0, 0, 39, '784'),
	(377, 1, 0, -50244, 786, 0, 0, 39, '785'),
	(377, 1, 0, -50244, 787, 0, 0, 39, '786'),
	(377, 1, 0, -50244, 788, 0, 0, 39, '787'),
	(377, 1, 0, -50244, 789, 0, 0, 39, '788'),
	(377, 1, 0, -50244, 790, 0, 0, 39, '789'),
	(377, 1, 0, -50244, 791, 0, 0, 39, '790'),
	(377, 1, 0, -50244, 792, 0, 0, 39, '791'),
	(377, 1, 0, -50244, 793, 0, 0, 39, '792'),
	(377, 1, 0, -50244, 794, 0, 0, 39, '793'),
	(377, 1, 0, -50244, 795, 0, 0, 39, '794'),
	(377, 1, 0, -50244, 796, 0, 0, 39, '795'),
	(377, 1, 0, -50244, 797, 0, 0, 39, '796'),
	(377, 1, 0, -50244, 798, 0, 0, 39, '797'),
	(377, 1, 0, -50244, 799, 0, 0, 39, '798'),
	(377, 1, 0, -50244, 800, 0, 0, 39, '799'),
	(377, 1, 0, -50244, 801, 0, 0, 39, '800'),
	(377, 1, 0, -50244, 802, 0, 0, 39, '801'),
	(377, 1, 0, -50244, 803, 0, 0, 39, '802'),
	(377, 1, 0, -50244, 804, 0, 0, 39, '803'),
	(377, 1, 0, -50244, 805, 0, 0, 39, '804'),
	(377, 1, 0, -50244, 806, 0, 0, 39, '805'),
	(377, 1, 0, -50244, 807, 0, 0, 39, '806'),
	(377, 1, 0, -50244, 808, 0, 0, 39, '807'),
	(377, 1, 0, -50244, 809, 0, 0, 39, '808'),
	(377, 1, 0, -50244, 810, 0, 0, 39, '809'),
	(377, 1, 0, -50244, 811, 0, 0, 39, '810'),
	(377, 1, 0, -50244, 812, 0, 0, 39, '811'),
	(377, 1, 0, -50244, 813, 0, 0, 39, '812'),
	(377, 1, 0, -50244, 814, 0, 0, 39, '813'),
	(377, 1, 0, -50244, 815, 0, 0, 39, '814'),
	(377, 1, 0, -50244, 816, 0, 0, 39, '815'),
	(377, 1, 0, -50244, 817, 0, 0, 39, '816'),
	(377, 1, 0, -50244, 818, 0, 0, 39, '817'),
	(377, 1, 0, -50244, 819, 0, 0, 39, '818'),
	(377, 1, 0, -50244, 820, 0, 0, 39, '819'),
	(377, 1, 0, -50244, 821, 0, 0, 39, '820'),
	(377, 1, 0, -50244, 822, 0, 0, 39, '821'),
	(377, 1, 0, -50244, 823, 0, 0, 39, '822'),
	(377, 1, 0, -50244, 824, 0, 0, 39, '823'),
	(377, 1, 0, -50244, 825, 0, 0, 39, '824'),
	(377, 1, 0, -50244, 826, 0, 0, 39, '825'),
	(377, 1, 0, -50244, 827, 0, 0, 39, '826'),
	(377, 1, 0, -50244, 828, 0, 0, 39, '827'),
	(377, 1, 0, -50244, 829, 0, 0, 39, '828'),
	(377, 1, 0, -50244, 830, 0, 0, 39, '829'),
	(377, 1, 0, -50244, 831, 0, 0, 39, '830'),
	(377, 1, 0, -50244, 832, 0, 0, 39, '831'),
	(377, 1, 0, -50244, 833, 0, 0, 39, '832'),
	(377, 1, 0, -50244, 834, 0, 0, 39, '833'),
	(377, 1, 0, -50244, 835, 0, 0, 39, '834'),
	(377, 1, 0, -50244, 836, 0, 0, 39, '835'),
	(377, 1, 0, -50244, 837, 0, 0, 39, '836'),
	(377, 1, 0, -50244, 838, 0, 0, 39, '837'),
	(377, 1, 0, -50244, 839, 0, 0, 39, '838'),
	(377, 1, 0, -50244, 840, 0, 0, 39, '839'),
	(377, 1, 0, -50244, 841, 0, 0, 39, '840'),
	(377, 1, 0, -50244, 842, 0, 0, 39, '841'),
	(377, 1, 0, -50244, 843, 0, 0, 39, '842'),
	(377, 1, 0, -50244, 844, 0, 0, 39, '843'),
	(377, 1, 0, -50244, 845, 0, 0, 39, '844'),
	(377, 1, 0, -50244, 846, 0, 0, 39, '845'),
	(377, 1, 0, -50244, 847, 0, 0, 39, '846'),
	(377, 1, 0, -50244, 848, 0, 0, 39, '847'),
	(377, 1, 0, -50244, 849, 0, 0, 39, '848'),
	(377, 1, 0, -50244, 850, 0, 0, 39, '849'),
	(377, 1, 0, -50244, 851, 0, 0, 39, '850'),
	(377, 1, 0, -50244, 852, 0, 0, 39, '851'),
	(377, 1, 0, -50244, 853, 0, 0, 39, '852'),
	(377, 1, 0, -50244, 854, 0, 0, 39, '853'),
	(377, 1, 0, -50244, 855, 0, 0, 39, '854'),
	(377, 1, 0, -50244, 856, 0, 0, 39, '855'),
	(377, 1, 0, -50244, 857, 0, 0, 39, '856'),
	(377, 1, 0, -50244, 858, 0, 0, 39, '857'),
	(377, 1, 0, -50244, 859, 0, 0, 39, '858'),
	(377, 1, 0, -50244, 860, 0, 0, 39, '859'),
	(377, 1, 0, -50244, 861, 0, 0, 39, '860'),
	(377, 1, 0, -50244, 862, 0, 0, 39, '861'),
	(377, 1, 0, -50244, 863, 0, 0, 39, '862'),
	(377, 1, 0, -50244, 864, 0, 0, 39, '863'),
	(377, 1, 0, -50244, 865, 0, 0, 39, '864'),
	(377, 1, 0, -50244, 866, 0, 0, 39, '865'),
	(377, 1, 0, -50244, 867, 0, 0, 39, '866'),
	(377, 1, 0, -50244, 868, 0, 0, 39, '867'),
	(377, 1, 0, -50244, 869, 0, 0, 39, '868'),
	(377, 1, 0, -50244, 870, 0, 0, 39, '869'),
	(377, 1, 0, -50244, 871, 0, 0, 39, '870'),
	(377, 1, 0, -50244, 872, 0, 0, 39, '871'),
	(377, 1, 0, -50244, 873, 0, 0, 39, '872'),
	(377, 1, 0, -50244, 874, 0, 0, 39, '873'),
	(377, 1, 0, -50244, 875, 0, 0, 39, '874'),
	(377, 1, 0, -50244, 876, 0, 0, 39, '875'),
	(377, 1, 0, -50244, 877, 0, 0, 39, '876'),
	(377, 1, 0, -50244, 878, 0, 0, 39, '877'),
	(377, 1, 0, -50244, 879, 0, 0, 39, '878'),
	(377, 1, 0, -50244, 880, 0, 0, 39, '879'),
	(377, 1, 0, -50244, 881, 0, 0, 39, '880'),
	(377, 1, 0, -50244, 882, 0, 0, 39, '881'),
	(377, 1, 0, -50244, 883, 0, 0, 39, '882'),
	(377, 1, 0, -50244, 884, 0, 0, 39, '883'),
	(377, 1, 0, -50244, 885, 0, 0, 39, '884'),
	(377, 1, 0, -50244, 886, 0, 0, 39, '885'),
	(377, 1, 0, -50244, 887, 0, 0, 39, '886'),
	(377, 1, 0, -50244, 888, 0, 0, 39, '887'),
	(377, 1, 0, -50244, 889, 0, 0, 39, '888'),
	(377, 1, 0, -50244, 890, 0, 0, 39, '889'),
	(377, 1, 0, -50244, 891, 0, 0, 39, '890'),
	(377, 1, 0, -50244, 892, 0, 0, 39, '891'),
	(377, 1, 0, -50244, 893, 0, 0, 39, '892'),
	(377, 1, 0, -50244, 894, 0, 0, 39, '893'),
	(377, 1, 0, -50244, 895, 0, 0, 39, '894'),
	(377, 1, 0, -50244, 896, 0, 0, 39, '895'),
	(377, 1, 0, -50244, 897, 0, 0, 39, '896'),
	(377, 1, 0, -50244, 898, 0, 0, 39, '897'),
	(377, 1, 0, -50244, 899, 0, 0, 39, '898'),
	(377, 1, 0, -50244, 900, 0, 0, 39, '899'),
	(377, 1, 0, -50244, 901, 0, 0, 39, '900'),
	(377, 1, 0, -50244, 902, 0, 0, 39, '901'),
	(377, 1, 0, -50244, 903, 0, 0, 39, '902'),
	(377, 1, 0, -50244, 904, 0, 0, 39, '903'),
	(377, 1, 0, -50244, 905, 0, 0, 39, '904'),
	(377, 1, 0, -50244, 906, 0, 0, 39, '905'),
	(377, 1, 0, -50244, 907, 0, 0, 39, '906'),
	(377, 1, 0, -50244, 908, 0, 0, 39, '907'),
	(377, 1, 0, -50244, 909, 0, 0, 39, '908'),
	(377, 1, 0, -50244, 910, 0, 0, 39, '909'),
	(377, 1, 0, -50244, 911, 0, 0, 39, '910'),
	(377, 1, 0, -50244, 912, 0, 0, 39, '911'),
	(377, 1, 0, -50244, 913, 0, 0, 39, '912'),
	(377, 1, 0, -50244, 914, 0, 0, 39, '913'),
	(377, 1, 0, -50244, 915, 0, 0, 39, '914'),
	(377, 1, 0, -50244, 916, 0, 0, 39, '915'),
	(377, 1, 0, -50244, 917, 0, 0, 39, '916'),
	(377, 1, 0, -50244, 918, 0, 0, 39, '917'),
	(377, 1, 0, -50244, 919, 0, 0, 39, '918'),
	(377, 1, 0, -50244, 920, 0, 0, 39, '919'),
	(377, 1, 0, -50244, 921, 0, 0, 39, '920'),
	(377, 1, 0, -50244, 922, 0, 0, 39, '921'),
	(377, 1, 0, -50244, 923, 0, 0, 39, '922'),
	(377, 1, 0, -50244, 924, 0, 0, 39, '923'),
	(377, 1, 0, -50244, 925, 0, 0, 39, '924'),
	(377, 1, 0, -50244, 926, 0, 0, 39, '925'),
	(377, 1, 0, -50244, 927, 0, 0, 39, '926'),
	(377, 1, 0, -50244, 928, 0, 0, 39, '927'),
	(377, 1, 0, -50244, 929, 0, 0, 39, '928'),
	(377, 1, 0, -50244, 930, 0, 0, 39, '929'),
	(377, 1, 0, -50244, 931, 0, 0, 39, '930'),
	(377, 1, 0, -50244, 932, 0, 0, 39, '931'),
	(377, 1, 0, -50244, 933, 0, 0, 39, '932'),
	(377, 1, 0, -50244, 934, 0, 0, 39, '933'),
	(377, 1, 0, -50244, 935, 0, 0, 39, '934'),
	(377, 1, 0, -50244, 936, 0, 0, 39, '935'),
	(377, 1, 0, -50244, 937, 0, 0, 39, '936'),
	(377, 1, 0, -50244, 938, 0, 0, 39, '937'),
	(377, 1, 0, -50244, 939, 0, 0, 39, '938'),
	(377, 1, 0, -50244, 940, 0, 0, 39, '939'),
	(377, 1, 0, -50244, 941, 0, 0, 39, '940'),
	(377, 1, 0, -50244, 942, 0, 0, 39, '941'),
	(377, 1, 0, -50244, 943, 0, 0, 39, '942'),
	(377, 1, 0, -50244, 944, 0, 0, 39, '943'),
	(377, 1, 0, -50244, 945, 0, 0, 39, '944'),
	(377, 1, 0, -50244, 946, 0, 0, 39, '945'),
	(377, 1, 0, -50244, 947, 0, 0, 39, '946'),
	(377, 1, 0, -50244, 948, 0, 0, 39, '947'),
	(377, 1, 0, -50244, 949, 0, 0, 39, '948'),
	(377, 1, 0, -50244, 950, 0, 0, 39, '949'),
	(377, 1, 0, -50244, 951, 0, 0, 39, '950'),
	(377, 1, 0, -50244, 952, 0, 0, 39, '951'),
	(377, 1, 0, -50244, 953, 0, 0, 39, '952'),
	(377, 1, 0, -50244, 954, 0, 0, 39, '953'),
	(377, 1, 0, -50244, 955, 0, 0, 39, '954'),
	(377, 1, 0, -50244, 956, 0, 0, 39, '955'),
	(377, 1, 0, -50244, 957, 0, 0, 39, '956'),
	(377, 1, 0, -50244, 958, 0, 0, 39, '957'),
	(377, 1, 0, -50244, 959, 0, 0, 39, '958'),
	(377, 1, 0, -50244, 960, 0, 0, 39, '959'),
	(377, 1, 0, -50244, 961, 0, 0, 39, '960'),
	(377, 1, 0, -50244, 962, 0, 0, 39, '961'),
	(377, 1, 0, -50244, 963, 0, 0, 39, '962'),
	(377, 1, 0, -50244, 964, 0, 0, 39, '963'),
	(377, 1, 0, -50244, 965, 0, 0, 39, '964'),
	(377, 1, 0, -50244, 966, 0, 0, 39, '965'),
	(377, 1, 0, -50244, 967, 0, 0, 39, '966'),
	(377, 1, 0, -50244, 968, 0, 0, 39, '967'),
	(377, 1, 0, -50244, 969, 0, 0, 39, '968'),
	(377, 1, 0, -50244, 970, 0, 0, 39, '969'),
	(377, 1, 0, -50244, 971, 0, 0, 39, '970'),
	(377, 1, 0, -50244, 972, 0, 0, 39, '971'),
	(377, 1, 0, -50244, 973, 0, 0, 39, '972'),
	(377, 1, 0, -50244, 974, 0, 0, 39, '973'),
	(377, 1, 0, -50244, 975, 0, 0, 39, '974'),
	(377, 1, 0, -50244, 976, 0, 0, 39, '975'),
	(377, 1, 0, -50244, 977, 0, 0, 39, '976'),
	(377, 1, 0, -50244, 978, 0, 0, 39, '977'),
	(377, 1, 0, -50244, 979, 0, 0, 39, '978'),
	(377, 1, 0, -50244, 980, 0, 0, 39, '979'),
	(377, 1, 0, -50244, 981, 0, 0, 39, '980'),
	(377, 1, 0, -50244, 982, 0, 0, 39, '981'),
	(377, 1, 0, -50244, 983, 0, 0, 39, '982'),
	(377, 1, 0, -50244, 984, 0, 0, 39, '983'),
	(377, 1, 0, -50244, 985, 0, 0, 39, '984'),
	(377, 1, 0, -50244, 986, 0, 0, 39, '985'),
	(377, 1, 0, -50244, 987, 0, 0, 39, '986'),
	(377, 1, 0, -50244, 988, 0, 0, 39, '987'),
	(377, 1, 0, -50244, 989, 0, 0, 39, '988'),
	(377, 1, 0, -50244, 990, 0, 0, 39, '989'),
	(377, 1, 0, -50244, 991, 0, 0, 39, '990'),
	(377, 1, 0, -50244, 992, 0, 0, 39, '991'),
	(377, 1, 0, -50244, 993, 0, 0, 39, '992'),
	(377, 1, 0, -50244, 994, 0, 0, 39, '993'),
	(377, 1, 0, -50244, 995, 0, 0, 39, '994'),
	(377, 1, 0, -50244, 996, 0, 0, 39, '995'),
	(377, 1, 0, -50244, 997, 0, 0, 39, '996'),
	(377, 1, 0, -50244, 998, 0, 0, 39, '997'),
	(377, 1, 0, -50244, 999, 0, 0, 39, '998'),
	(377, 1, 0, -50244, 1000, 0, 0, 39, '999'),
	(377, 1, 0, -50244, 1001, 0, 0, 39, '1000'),
	(377, 1, 0, -50244, 1002, 0, 0, 39, '1001'),
	(377, 1, 0, -50244, 1003, 0, 0, 39, '1002'),
	(377, 1, 0, -50244, 1004, 0, 0, 39, '1003'),
	(377, 1, 0, -50244, 1005, 0, 0, 39, '1004'),
	(377, 1, 0, -50244, 1006, 0, 0, 39, '1005'),
	(377, 1, 0, -50244, 1007, 0, 0, 39, '1006'),
	(377, 1, 0, -50244, 1008, 0, 0, 39, '1007'),
	(377, 1, 0, -50244, 1009, 0, 0, 39, '1008'),
	(377, 1, 0, -50244, 1010, 0, 0, 39, '1009'),
	(377, 1, 0, -50244, 1011, 0, 0, 39, '1010'),
	(377, 1, 0, -50244, 1012, 0, 0, 39, '1011'),
	(377, 1, 0, -50244, 1013, 0, 0, 39, '1012'),
	(377, 1, 0, -50244, 1014, 0, 0, 39, '1013'),
	(377, 1, 0, -50244, 1015, 0, 0, 39, '1014'),
	(377, 1, 0, -50244, 1016, 0, 0, 39, '1015'),
	(377, 1, 0, -50244, 1017, 0, 0, 39, '1016'),
	(377, 1, 0, -50244, 1018, 0, 0, 39, '1017'),
	(377, 1, 0, -50244, 1019, 0, 0, 39, '1018'),
	(377, 1, 0, -50244, 1020, 0, 0, 39, '1019'),
	(377, 1, 0, -50244, 1021, 0, 0, 39, '1020'),
	(377, 1, 0, -50244, 1022, 0, 0, 39, '1021'),
	(377, 1, 0, -50244, 1023, 0, 0, 39, '1022'),
	(377, 1, 0, -50244, 1024, 0, 0, 39, '1023'),
	(377, 1, 0, -50244, 1025, 0, 0, 39, '1024'),
	(377, 1, 0, -50244, 1026, 0, 0, 39, '1025'),
	(377, 1, 0, -50244, 1027, 0, 0, 39, '1026'),
	(377, 1, 0, -50244, 1028, 0, 0, 39, '1027'),
	(377, 1, 0, -50244, 1029, 0, 0, 39, '1028'),
	(377, 1, 0, -50244, 1030, 0, 0, 39, '1029'),
	(377, 1, 0, -50244, 1031, 0, 0, 39, '1030'),
	(377, 1, 0, -50244, 1032, 0, 0, 39, '1031'),
	(377, 1, 0, -50244, 1033, 0, 0, 39, '1032'),
	(377, 1, 0, -50244, 1034, 0, 0, 39, '1033'),
	(377, 1, 0, -50244, 1035, 0, 0, 39, '1034'),
	(377, 1, 0, -50244, 1036, 0, 0, 39, '1035'),
	(377, 1, 0, -50244, 1037, 0, 0, 39, '1036'),
	(377, 1, 0, -50244, 1038, 0, 0, 39, '1037'),
	(377, 1, 0, -50244, 1039, 0, 0, 39, '1038'),
	(377, 1, 0, -50244, 1040, 0, 0, 39, '1039'),
	(377, 1, 0, -50244, 1041, 0, 0, 39, '1040'),
	(377, 1, 0, -50244, 1042, 0, 0, 39, '1041'),
	(377, 1, 0, -50244, 1043, 0, 0, 39, '1042'),
	(377, 1, 0, -50244, 1044, 0, 0, 39, '1043'),
	(377, 1, 0, -50244, 1045, 0, 0, 39, '1044'),
	(377, 1, 0, -50244, 1046, 0, 0, 39, '1045'),
	(377, 1, 0, -50244, 1047, 0, 0, 39, '1046'),
	(377, 1, 0, -50244, 1048, 0, 0, 39, '1047'),
	(377, 1, 0, -50244, 1049, 0, 0, 39, '1048'),
	(377, 1, 0, -50244, 1050, 0, 0, 39, '1049'),
	(377, 1, 0, -50244, 1051, 0, 0, 39, '1050'),
	(377, 1, 0, -50244, 1052, 0, 0, 39, '1051'),
	(377, 1, 0, -50244, 1053, 0, 0, 39, '1052'),
	(377, 1, 0, -50244, 1054, 0, 0, 39, '1053'),
	(377, 1, 0, -50244, 1055, 0, 0, 39, '1054'),
	(377, 1, 0, -50244, 1056, 0, 0, 39, '1055'),
	(377, 1, 0, -50244, 1057, 0, 0, 39, '1056'),
	(377, 1, 0, -50244, 1058, 0, 0, 39, '1057'),
	(377, 1, 0, -50244, 1059, 0, 0, 39, '1058'),
	(377, 1, 0, -50244, 1060, 0, 0, 39, '1059'),
	(377, 1, 0, -50244, 1061, 0, 0, 39, '1060'),
	(377, 1, 0, -50244, 1062, 0, 0, 39, '1061'),
	(377, 1, 0, -50244, 1063, 0, 0, 39, '1062'),
	(377, 1, 0, -50244, 1064, 0, 0, 39, '1063'),
	(377, 1, 0, -50244, 1065, 0, 0, 39, '1064'),
	(377, 1, 0, -50244, 1066, 0, 0, 39, '1065'),
	(377, 1, 0, -50244, 1067, 0, 0, 39, '1066'),
	(377, 1, 0, -50244, 1068, 0, 0, 39, '1067'),
	(377, 1, 0, -50244, 1069, 0, 0, 39, '1068'),
	(377, 1, 0, -50244, 1070, 0, 0, 39, '1069'),
	(377, 1, 0, -50244, 1071, 0, 0, 39, '1070'),
	(377, 1, 0, -50244, 1072, 0, 0, 39, '1071'),
	(377, 1, 0, -50244, 1073, 0, 0, 39, '1072'),
	(377, 1, 0, -50244, 1074, 0, 0, 39, '1073'),
	(377, 1, 0, -50244, 1075, 0, 0, 39, '1074'),
	(377, 1, 0, -50244, 1076, 0, 0, 39, '1075'),
	(377, 1, 0, -50244, 1077, 0, 0, 39, '1076'),
	(377, 1, 0, -50244, 1078, 0, 0, 39, '1077'),
	(377, 1, 0, -50244, 1079, 0, 0, 39, '1078'),
	(377, 1, 0, -50244, 1080, 0, 0, 39, '1079'),
	(377, 1, 0, -50244, 1081, 0, 0, 39, '1080'),
	(377, 1, 0, -50244, 1082, 0, 0, 39, '1081'),
	(377, 1, 0, -50244, 1083, 0, 0, 39, '1082'),
	(377, 1, 0, -50244, 1084, 0, 0, 39, '1083'),
	(377, 1, 0, -50244, 1085, 0, 0, 39, '1084'),
	(377, 1, 0, -50244, 1086, 0, 0, 39, '1085'),
	(377, 1, 0, -50244, 1087, 0, 0, 39, '1086'),
	(377, 1, 0, -50244, 1088, 0, 0, 39, '1087'),
	(377, 1, 0, -50244, 1089, 0, 0, 39, '1088'),
	(377, 1, 0, -50244, 1090, 0, 0, 39, '1089'),
	(377, 1, 0, -50244, 1091, 0, 0, 39, '1090'),
	(377, 1, 0, -50244, 1092, 0, 0, 39, '1091'),
	(377, 1, 0, -50244, 1093, 0, 0, 39, '1092'),
	(377, 1, 0, -50244, 1094, 0, 0, 39, '1093'),
	(377, 1, 0, -50244, 1095, 0, 0, 39, '1094'),
	(377, 1, 0, -50244, 1096, 0, 0, 39, '1095'),
	(377, 1, 0, -50244, 1097, 0, 0, 39, '1096'),
	(377, 1, 0, -50244, 1098, 0, 0, 39, '1097'),
	(377, 1, 0, -50244, 1099, 0, 0, 39, '1098'),
	(377, 1, 0, -50244, 1100, 0, 0, 39, '1099'),
	(377, 1, 0, -50244, 1101, 0, 0, 39, '1100'),
	(377, 1, 0, -50244, 1102, 0, 0, 39, '1101'),
	(377, 1, 0, -50244, 1103, 0, 0, 39, '1102'),
	(377, 1, 0, -50244, 1104, 0, 0, 39, '1103'),
	(377, 1, 0, -50244, 1105, 0, 0, 39, '1104'),
	(377, 1, 0, -50244, 1106, 0, 0, 39, '1105'),
	(377, 1, 0, -50244, 1107, 0, 0, 39, '1106'),
	(377, 1, 0, -50244, 1108, 0, 0, 39, '1107'),
	(377, 1, 0, -50244, 1109, 0, 0, 39, '1108'),
	(377, 1, 0, -50244, 1110, 0, 0, 39, '1109'),
	(377, 1, 0, -50244, 1111, 0, 0, 39, '1110'),
	(377, 1, 0, -50244, 1112, 0, 0, 39, '1111'),
	(377, 1, 0, -50244, 1113, 0, 0, 39, '1112'),
	(377, 1, 0, -50244, 1114, 0, 0, 39, '1113'),
	(377, 1, 0, -50244, 1115, 0, 0, 39, '1114'),
	(377, 1, 0, -50244, 1116, 0, 0, 39, '1115'),
	(377, 1, 0, -50244, 1117, 0, 0, 39, '1116'),
	(377, 1, 0, -50244, 1118, 0, 0, 39, '1117'),
	(377, 1, 0, -50244, 1119, 0, 0, 39, '1118'),
	(377, 1, 0, -50244, 1120, 0, 0, 39, '1119'),
	(377, 1, 0, -50244, 1121, 0, 0, 39, '1120'),
	(377, 1, 0, -50244, 1122, 0, 0, 39, '1121'),
	(377, 1, 0, -50244, 1123, 0, 0, 39, '1122'),
	(377, 1, 0, -50244, 1124, 0, 0, 39, '1123'),
	(377, 1, 0, -50244, 1125, 0, 0, 39, '1124'),
	(377, 1, 0, -50244, 1126, 0, 0, 39, '1125'),
	(377, 1, 0, -50244, 1127, 0, 0, 39, '1126'),
	(377, 1, 0, -50244, 1128, 0, 0, 39, '1127'),
	(377, 1, 0, -50244, 1129, 0, 0, 39, '1128'),
	(377, 1, 0, -50244, 1130, 0, 0, 39, '1129'),
	(377, 1, 0, -50244, 1131, 0, 0, 39, '1130'),
	(377, 1, 0, -50244, 1132, 0, 0, 39, '1131'),
	(377, 1, 0, -50244, 1133, 0, 0, 39, '1132'),
	(377, 1, 0, -50244, 1134, 0, 0, 39, '1133'),
	(377, 1, 0, -50244, 1135, 0, 0, 39, '1134'),
	(377, 1, 0, -50244, 1136, 0, 0, 39, '1135'),
	(377, 1, 0, -50244, 1137, 0, 0, 39, '1136'),
	(377, 1, 0, -50244, 1138, 0, 0, 39, '1137'),
	(377, 1, 0, -50244, 1139, 0, 0, 39, '1138'),
	(377, 1, 0, -50244, 1140, 0, 0, 39, '1139'),
	(377, 1, 0, -50244, 1141, 0, 0, 39, '1140'),
	(377, 1, 0, -50244, 1142, 0, 0, 39, '1141'),
	(377, 1, 0, -50244, 1143, 0, 0, 39, '1142'),
	(377, 1, 0, -50244, 1144, 0, 0, 39, '1143'),
	(377, 1, 0, -50244, 1145, 0, 0, 39, '1144'),
	(377, 1, 0, -50244, 1146, 0, 0, 39, '1145'),
	(377, 1, 0, -50244, 1147, 0, 0, 39, '1146'),
	(377, 1, 0, -50244, 1148, 0, 0, 39, '1147'),
	(377, 1, 0, -50244, 1149, 0, 0, 39, '1148'),
	(377, 1, 0, -50244, 1150, 0, 0, 39, '1149'),
	(377, 1, 0, -50244, 1151, 0, 0, 39, '1150'),
	(377, 1, 0, -50244, 1152, 0, 0, 39, '1151'),
	(377, 1, 0, -50244, 1153, 0, 0, 39, '1152'),
	(377, 1, 0, -50244, 1154, 0, 0, 39, '1153'),
	(377, 1, 0, -50244, 1155, 0, 0, 39, '1154'),
	(377, 1, 0, -50244, 1156, 0, 0, 39, '1155'),
	(377, 1, 0, -50244, 1157, 0, 0, 39, '1156'),
	(377, 1, 0, -50244, 1158, 0, 0, 39, '1157'),
	(377, 1, 0, -50244, 1159, 0, 0, 39, '1158'),
	(377, 1, 0, -50244, 1160, 0, 0, 39, '1159'),
	(377, 1, 0, -50244, 1161, 0, 0, 39, '1160'),
	(377, 1, 0, -50244, 1162, 0, 0, 39, '1161'),
	(377, 1, 0, -50244, 1163, 0, 0, 39, '1162'),
	(377, 1, 0, -50244, 1164, 0, 0, 39, '1163'),
	(377, 1, 0, -50244, 1165, 0, 0, 39, '1164'),
	(377, 1, 0, -50244, 1166, 0, 0, 39, '1165'),
	(377, 1, 0, -50244, 1167, 0, 0, 39, '1166'),
	(377, 1, 0, -50244, 1168, 0, 0, 39, '1167'),
	(377, 1, 0, -50244, 1169, 0, 0, 39, '1168'),
	(377, 1, 0, -50244, 1170, 0, 0, 39, '1169'),
	(377, 1, 0, -50244, 1171, 0, 0, 39, '1170'),
	(377, 1, 0, -50244, 1172, 0, 0, 39, '1171'),
	(377, 1, 0, -50244, 1173, 0, 0, 39, '1172'),
	(377, 1, 0, -50244, 1174, 0, 0, 39, '1173'),
	(377, 1, 0, -50244, 1175, 0, 0, 39, '1174'),
	(377, 1, 0, -50244, 1176, 0, 0, 39, '1175'),
	(377, 1, 0, -50244, 1177, 0, 0, 39, '1176'),
	(377, 1, 0, -50244, 1178, 0, 0, 39, '1177'),
	(377, 1, 0, -50244, 1179, 0, 0, 39, '1178'),
	(377, 1, 0, -50244, 1180, 0, 0, 39, '1179'),
	(377, 1, 0, -50244, 1181, 0, 0, 39, '1180'),
	(377, 1, 0, -50244, 1182, 0, 0, 39, '1181'),
	(377, 1, 0, -50244, 1183, 0, 0, 39, '1182'),
	(377, 1, 0, -50244, 1184, 0, 0, 39, '1183'),
	(377, 1, 0, -50244, 1185, 0, 0, 39, '1184'),
	(377, 1, 0, -50244, 1186, 0, 0, 39, '1185'),
	(377, 1, 0, -50244, 1187, 0, 0, 39, '1186'),
	(377, 1, 0, -50244, 1188, 0, 0, 39, '1187'),
	(377, 1, 0, -50244, 1189, 0, 0, 39, '1188'),
	(377, 1, 0, -50244, 1190, 0, 0, 39, '1189'),
	(377, 1, 0, -50244, 1191, 0, 0, 39, '1190'),
	(377, 1, 0, -50244, 1192, 0, 0, 39, '1191'),
	(377, 1, 0, -50244, 1193, 0, 0, 39, '1192'),
	(377, 1, 0, -50244, 1194, 0, 0, 39, '1193'),
	(377, 1, 0, -50244, 1195, 0, 0, 39, '1194'),
	(377, 1, 0, -50244, 1196, 0, 0, 39, '1195'),
	(377, 1, 0, -50244, 1197, 0, 0, 39, '1196'),
	(377, 1, 0, -50244, 1198, 0, 0, 39, '1197'),
	(377, 1, 0, -50244, 1199, 0, 0, 39, '1198'),
	(377, 1, 0, -50244, 1200, 0, 0, 39, '1199'),
	(377, 1, 0, -50244, 1201, 0, 0, 39, '1200'),
	(377, 1, 0, -50244, 1202, 0, 0, 39, '1201'),
	(377, 1, 0, -50244, 1203, 0, 0, 39, '1202'),
	(377, 1, 0, -50244, 1204, 0, 0, 39, '1203'),
	(377, 1, 0, -50244, 1205, 0, 0, 39, '1204'),
	(377, 1, 0, -50244, 1206, 0, 0, 39, '1205'),
	(377, 1, 0, -50244, 1207, 0, 0, 39, '1206'),
	(377, 1, 0, -50244, 1208, 0, 0, 39, '1207'),
	(377, 1, 0, -50244, 1209, 0, 0, 39, '1208'),
	(377, 1, 0, -50244, 1210, 0, 0, 39, '1209'),
	(377, 1, 0, -50244, 1211, 0, 0, 39, '1210'),
	(377, 1, 0, -50244, 1212, 0, 0, 39, '1211'),
	(377, 1, 0, -50244, 1213, 0, 0, 39, '1212'),
	(377, 1, 0, -50244, 1214, 0, 0, 39, '1213'),
	(377, 1, 0, -50244, 1215, 0, 0, 39, '1214'),
	(377, 1, 0, -50244, 1216, 0, 0, 39, '1215'),
	(377, 1, 0, -50244, 1217, 0, 0, 39, '1216'),
	(377, 1, 0, -50244, 1218, 0, 0, 39, '1217'),
	(377, 1, 0, -50244, 1219, 0, 0, 39, '1218'),
	(377, 1, 0, -50244, 1220, 0, 0, 39, '1219'),
	(377, 1, 0, -50244, 1221, 0, 0, 39, '1220'),
	(377, 1, 0, -50244, 1222, 0, 0, 39, '1221'),
	(377, 1, 0, -50244, 1223, 0, 0, 39, '1222'),
	(377, 1, 0, -50244, 1224, 0, 0, 39, '1223'),
	(377, 1, 0, -50244, 1225, 0, 0, 39, '1224'),
	(377, 1, 0, -50244, 1226, 0, 0, 39, '1225'),
	(377, 1, 0, -50244, 1227, 0, 0, 39, '1226'),
	(377, 1, 0, -50244, 1228, 0, 0, 39, '1227'),
	(377, 1, 0, -50244, 1229, 0, 0, 39, '1228'),
	(377, 1, 0, -50244, 1230, 0, 0, 39, '1229'),
	(377, 1, 0, -50244, 1231, 0, 0, 39, '1230'),
	(377, 1, 0, -50244, 1232, 0, 0, 39, '1231'),
	(377, 1, 0, -50244, 1233, 0, 0, 39, '1232'),
	(377, 1, 0, -50244, 1234, 0, 0, 39, '1233'),
	(377, 1, 0, -50244, 1235, 0, 0, 39, '1234'),
	(377, 1, 0, -50244, 1236, 0, 0, 39, '1235'),
	(377, 1, 0, -50244, 1237, 0, 0, 39, '1236'),
	(377, 1, 0, -50244, 1238, 0, 0, 39, '1237'),
	(377, 1, 0, -50244, 1239, 0, 0, 39, '1238'),
	(377, 1, 0, -50244, 1240, 0, 0, 39, '1239'),
	(377, 1, 0, -50244, 1241, 0, 0, 39, '1240'),
	(377, 1, 0, -50244, 1242, 0, 0, 39, '1241'),
	(377, 1, 0, -50244, 1243, 0, 0, 39, '1242'),
	(377, 1, 0, -50244, 1244, 0, 0, 39, '1243'),
	(377, 1, 0, -50244, 1245, 0, 0, 39, '1244'),
	(377, 1, 0, -50244, 1246, 0, 0, 39, '1245'),
	(377, 1, 0, -50244, 1247, 0, 0, 39, '1246'),
	(377, 1, 0, -50244, 1248, 0, 0, 39, '1247'),
	(377, 1, 0, -50244, 1249, 0, 0, 39, '1248'),
	(377, 1, 0, -50244, 1250, 0, 0, 39, '1249'),
	(377, 1, 0, -50244, 1251, 0, 0, 39, '1250'),
	(377, 1, 0, -50244, 1252, 0, 0, 39, '1251'),
	(377, 1, 0, -50244, 1253, 0, 0, 39, '1252'),
	(377, 1, 0, -50244, 1254, 0, 0, 39, '1253'),
	(377, 1, 0, -50244, 1255, 0, 0, 39, '1254'),
	(377, 1, 0, -50244, 1256, 0, 0, 39, '1255'),
	(377, 1, 0, -50244, 1257, 0, 0, 39, '1256'),
	(377, 1, 0, -50244, 1258, 0, 0, 39, '1257'),
	(377, 1, 0, -50244, 1259, 0, 0, 39, '1258'),
	(377, 1, 0, -50244, 1260, 0, 0, 39, '1259'),
	(377, 1, 0, -50244, 1261, 0, 0, 39, '1260'),
	(377, 1, 0, -50244, 1262, 0, 0, 39, '1261'),
	(377, 1, 0, -50244, 1263, 0, 0, 39, '1262'),
	(377, 1, 0, -50244, 1264, 0, 0, 39, '1263'),
	(377, 1, 0, -50244, 1265, 0, 0, 39, '1264'),
	(377, 1, 0, -50244, 1266, 0, 0, 39, '1265'),
	(377, 1, 0, -50244, 1267, 0, 0, 39, '1266'),
	(377, 1, 0, -50244, 1268, 0, 0, 39, '1267'),
	(377, 1, 0, -50244, 1269, 0, 0, 39, '1268'),
	(377, 1, 0, -50244, 1270, 0, 0, 39, '1269'),
	(377, 1, 0, -50244, 1271, 0, 0, 39, '1270'),
	(377, 1, 0, -50244, 1272, 0, 0, 39, '1271'),
	(377, 1, 0, -50244, 1273, 0, 0, 39, '1272'),
	(377, 1, 0, -50244, 1274, 0, 0, 39, '1273'),
	(377, 1, 0, -50244, 1275, 0, 0, 39, '1274'),
	(377, 1, 0, -50244, 1276, 0, 0, 39, '1275'),
	(377, 1, 0, -50244, 1277, 0, 0, 39, '1276'),
	(377, 1, 0, -50244, 1278, 0, 0, 39, '1277'),
	(377, 1, 0, -50244, 1279, 0, 0, 39, '1278'),
	(377, 1, 0, -50244, 1280, 0, 0, 39, '1279'),
	(377, 1, 0, -50244, 1281, 0, 0, 39, '1280'),
	(377, 1, 0, -50244, 1282, 0, 0, 39, '1281'),
	(377, 1, 0, -50244, 1283, 0, 0, 39, '1282'),
	(377, 1, 0, -50244, 1284, 0, 0, 39, '1283'),
	(377, 1, 0, -50244, 1285, 0, 0, 39, '1284'),
	(377, 1, 0, -50244, 1286, 0, 0, 39, '1285'),
	(377, 1, 0, -50244, 1287, 0, 0, 39, '1286'),
	(377, 1, 0, -50244, 1288, 0, 0, 39, '1287'),
	(377, 1, 0, -50244, 1289, 0, 0, 39, '1288'),
	(377, 1, 0, -50244, 1290, 0, 0, 39, '1289'),
	(377, 1, 0, -50244, 1291, 0, 0, 39, '1290'),
	(377, 1, 0, -50244, 1292, 0, 0, 39, '1291'),
	(377, 1, 0, -50244, 1293, 0, 0, 39, '1292'),
	(377, 1, 0, -50244, 1294, 0, 0, 39, '1293'),
	(377, 1, 0, -50244, 1295, 0, 0, 39, '1294'),
	(377, 1, 0, -50244, 1296, 0, 0, 39, '1295'),
	(377, 1, 0, -50244, 1297, 0, 0, 39, '1296'),
	(377, 1, 0, -50244, 1298, 0, 0, 39, '1297'),
	(377, 1, 0, -50244, 1299, 0, 0, 39, '1298'),
	(377, 1, 0, -50244, 1300, 0, 0, 39, '1299'),
	(377, 1, 0, -50244, 1301, 0, 0, 39, '1300'),
	(377, 1, 0, -50244, 1302, 0, 0, 39, '1301'),
	(377, 1, 0, -50244, 1303, 0, 0, 39, '1302'),
	(377, 1, 0, -50244, 1304, 0, 0, 39, '1303'),
	(377, 1, 0, -50244, 1305, 0, 0, 39, '1304'),
	(377, 1, 0, -50244, 1306, 0, 0, 39, '1305'),
	(377, 1, 0, -50244, 1307, 0, 0, 39, '1306'),
	(377, 1, 0, -50244, 1308, 0, 0, 39, '1307'),
	(377, 1, 0, -50244, 1309, 0, 0, 39, '1308'),
	(377, 1, 0, -50244, 1310, 0, 0, 39, '1309'),
	(377, 1, 0, -50244, 1311, 0, 0, 39, '1310'),
	(377, 1, 0, -50244, 1312, 0, 0, 39, '1311'),
	(377, 1, 0, -50244, 1313, 0, 0, 39, '1312'),
	(377, 1, 0, -50244, 1314, 0, 0, 39, '1313'),
	(377, 1, 0, -50244, 1315, 0, 0, 39, '1314'),
	(377, 1, 0, -50244, 1316, 0, 0, 39, '1315'),
	(377, 1, 0, -50244, 1317, 0, 0, 39, '1316'),
	(377, 1, 0, -50244, 1318, 0, 0, 39, '1317'),
	(377, 1, 0, -50244, 1319, 0, 0, 39, '1318'),
	(377, 1, 0, -50244, 1320, 0, 0, 39, '1319'),
	(377, 1, 0, -50244, 1321, 0, 0, 39, '1320'),
	(377, 1, 0, -50244, 1322, 0, 0, 39, '1321'),
	(377, 1, 0, -50244, 1323, 0, 0, 39, '1322'),
	(377, 1, 0, -50244, 1324, 0, 0, 39, '1323'),
	(377, 1, 0, -50244, 1325, 0, 0, 39, '1324'),
	(377, 1, 0, -50244, 1326, 0, 0, 39, '1325'),
	(377, 1, 0, -50244, 1327, 0, 0, 39, '1326'),
	(377, 1, 0, -50244, 1328, 0, 0, 39, '1327'),
	(377, 1, 0, -50244, 1329, 0, 0, 39, '1328'),
	(377, 1, 0, -50244, 1330, 0, 0, 39, '1329'),
	(377, 1, 0, -50244, 1331, 0, 0, 39, '1330'),
	(377, 1, 0, -50244, 1332, 0, 0, 39, '1331'),
	(377, 1, 0, -50244, 1333, 0, 0, 39, '1332'),
	(377, 1, 0, -50244, 1334, 0, 0, 39, '1333'),
	(377, 1, 0, -50244, 1335, 0, 0, 39, '1334'),
	(377, 1, 0, -50244, 1336, 0, 0, 39, '1335'),
	(377, 1, 0, -50244, 1337, 0, 0, 39, '1336'),
	(377, 1, 0, -50244, 1338, 0, 0, 39, '1337'),
	(377, 1, 0, -50244, 1339, 0, 0, 39, '1338'),
	(377, 1, 0, -50244, 1340, 0, 0, 39, '1339'),
	(377, 1, 0, -50244, 1341, 0, 0, 39, '1340'),
	(377, 1, 0, -50244, 1342, 0, 0, 39, '1341'),
	(377, 1, 0, -50244, 1343, 0, 0, 39, '1342'),
	(377, 1, 0, -50244, 1344, 0, 0, 39, '1343'),
	(377, 1, 0, -50244, 1345, 0, 0, 39, '1344'),
	(377, 1, 0, -50244, 1346, 0, 0, 39, '1345'),
	(377, 1, 0, -50244, 1347, 0, 0, 39, '1346'),
	(377, 1, 0, -50244, 1348, 0, 0, 39, '1347'),
	(377, 1, 0, -50244, 1349, 0, 0, 39, '1348'),
	(377, 1, 0, -50244, 1350, 0, 0, 39, '1349'),
	(377, 1, 0, -50244, 1351, 0, 0, 39, '1350'),
	(377, 1, 0, -50244, 1352, 0, 0, 39, '1351'),
	(377, 1, 0, -50244, 1353, 0, 0, 39, '1352'),
	(377, 1, 0, -50244, 1354, 0, 0, 39, '1353'),
	(377, 1, 0, -50244, 1355, 0, 0, 39, '1354'),
	(377, 1, 0, -50244, 1356, 0, 0, 39, '1355'),
	(377, 1, 0, -50244, 1357, 0, 0, 39, '1356'),
	(377, 1, 0, -50244, 1358, 0, 0, 39, '1357'),
	(377, 1, 0, -50244, 1359, 0, 0, 39, '1358'),
	(377, 1, 0, -50244, 1360, 0, 0, 39, '1359'),
	(377, 1, 0, -50244, 1361, 0, 0, 39, '1360'),
	(377, 1, 0, -50244, 1362, 0, 0, 39, '1361'),
	(377, 1, 0, -50244, 1363, 0, 0, 39, '1362'),
	(377, 1, 0, -50244, 1364, 0, 0, 39, '1363'),
	(377, 1, 0, -50244, 1365, 0, 0, 39, '1364'),
	(377, 1, 0, -50244, 1366, 0, 0, 39, '1365'),
	(377, 1, 0, -50244, 1367, 0, 0, 39, '1366'),
	(377, 1, 0, -50244, 1368, 0, 0, 39, '1367'),
	(377, 1, 0, -50244, 1369, 0, 0, 39, '1368'),
	(377, 1, 0, -50244, 1370, 0, 0, 39, '1369'),
	(377, 1, 0, -50244, 1371, 0, 0, 39, '1370'),
	(377, 1, 0, -50244, 1372, 0, 0, 39, '1371'),
	(377, 1, 0, -50244, 1373, 0, 0, 39, '1372'),
	(377, 1, 0, -50244, 1374, 0, 0, 39, '1373'),
	(377, 1, 0, -50244, 1375, 0, 0, 39, '1374'),
	(377, 1, 0, -50244, 1376, 0, 0, 39, '1375'),
	(377, 1, 0, -50244, 1377, 0, 0, 39, '1376'),
	(377, 1, 0, -50244, 1378, 0, 0, 39, '1377'),
	(377, 1, 0, -50244, 1379, 0, 0, 39, '1378'),
	(377, 1, 0, -50244, 1380, 0, 0, 39, '1379'),
	(377, 1, 0, -50244, 1381, 0, 0, 39, '1380'),
	(377, 1, 0, -50244, 1382, 0, 0, 39, '1381'),
	(377, 1, 0, -50244, 1383, 0, 0, 39, '1382'),
	(377, 1, 0, -50244, 1384, 0, 0, 39, '1383'),
	(377, 1, 0, -50244, 1385, 0, 0, 39, '1384'),
	(377, 1, 0, -50244, 1386, 0, 0, 39, '1385'),
	(377, 1, 0, -50244, 1387, 0, 0, 39, '1386'),
	(377, 1, 0, -50244, 1388, 0, 0, 39, '1387'),
	(377, 1, 0, -50244, 1389, 0, 0, 39, '1388'),
	(377, 1, 0, -50244, 1390, 0, 0, 39, '1389'),
	(377, 1, 0, -50244, 1391, 0, 0, 39, '1390'),
	(377, 1, 0, -50244, 1392, 0, 0, 39, '1391'),
	(377, 1, 0, -50244, 1393, 0, 0, 39, '1392'),
	(377, 1, 0, -50244, 1394, 0, 0, 39, '1393'),
	(377, 1, 0, -50244, 1395, 0, 0, 39, '1394'),
	(377, 1, 0, -50244, 1396, 0, 0, 39, '1395'),
	(377, 1, 0, -50244, 1397, 0, 0, 39, '1396'),
	(377, 1, 0, -50244, 1398, 0, 0, 39, '1397'),
	(377, 1, 0, -50244, 1399, 0, 0, 39, '1398'),
	(377, 1, 0, -50244, 1400, 0, 0, 39, '1399'),
	(377, 1, 0, -50244, 1401, 0, 0, 39, '1400'),
	(377, 1, 0, -50244, 1402, 0, 0, 39, '1401'),
	(377, 1, 0, -50244, 1403, 0, 0, 39, '1402'),
	(377, 1, 0, -50244, 1404, 0, 0, 39, '1403'),
	(377, 1, 0, -50244, 1405, 0, 0, 39, '1404'),
	(377, 1, 0, -50244, 1406, 0, 0, 39, '1405'),
	(377, 1, 0, -50244, 1407, 0, 0, 39, '1406'),
	(377, 1, 0, -50244, 1408, 0, 0, 39, '1407'),
	(377, 1, 0, -50244, 1409, 0, 0, 39, '1408'),
	(377, 1, 0, -50244, 1410, 0, 0, 39, '1409'),
	(377, 1, 0, -50244, 1411, 0, 0, 39, '1410'),
	(377, 1, 0, -50244, 1412, 0, 0, 39, '1411'),
	(377, 1, 0, -50244, 1413, 0, 0, 39, '1412'),
	(377, 1, 0, -50244, 1414, 0, 0, 39, '1413'),
	(377, 1, 0, -50244, 1415, 0, 0, 39, '1414'),
	(377, 1, 0, -50244, 1416, 0, 0, 39, '1415'),
	(377, 1, 0, -50244, 1417, 0, 0, 39, '1416'),
	(377, 1, 0, -50244, 1418, 0, 0, 39, '1417'),
	(377, 1, 0, -50244, 1419, 0, 0, 39, '1418'),
	(377, 1, 0, -50244, 1420, 0, 0, 39, '1419'),
	(377, 1, 0, -50244, 1421, 0, 0, 39, '1420'),
	(377, 1, 0, -50244, 1422, 0, 0, 39, '1421'),
	(377, 1, 0, -50244, 1423, 0, 0, 39, '1422'),
	(377, 1, 0, -50244, 1424, 0, 0, 39, '1423'),
	(377, 1, 0, -50244, 1425, 0, 0, 39, '1424'),
	(377, 1, 0, -50244, 1426, 0, 0, 39, '1425'),
	(377, 1, 0, -50244, 1427, 0, 0, 39, '1426'),
	(377, 1, 0, -50244, 1428, 0, 0, 39, '1427'),
	(377, 1, 0, -50244, 1429, 0, 0, 39, '1428'),
	(377, 1, 0, -50244, 1430, 0, 0, 39, '1429'),
	(377, 1, 0, -50244, 1431, 0, 0, 39, '1430'),
	(377, 1, 0, -50244, 1432, 0, 0, 39, '1431'),
	(377, 1, 0, -50244, 1433, 0, 0, 39, '1432'),
	(377, 1, 0, -50244, 1434, 0, 0, 39, '1433'),
	(377, 1, 0, -50244, 1435, 0, 0, 39, '1434'),
	(377, 1, 0, -50244, 1436, 0, 0, 39, '1435'),
	(377, 1, 0, -50244, 1437, 0, 0, 39, '1436'),
	(377, 1, 0, -50244, 1438, 0, 0, 39, '1437'),
	(377, 1, 0, -50244, 1439, 0, 0, 39, '1438'),
	(377, 1, 0, -50244, 1440, 0, 0, 39, '1439'),
	(377, 1, 0, -50244, 1441, 0, 0, 39, '1440'),
	(377, 1, 0, -50244, 1442, 0, 0, 39, '1441'),
	(377, 1, 0, -50244, 1443, 0, 0, 39, '1442'),
	(377, 1, 0, -50244, 1444, 0, 0, 39, '1443'),
	(377, 1, 0, -50244, 1445, 0, 0, 39, '1444'),
	(377, 1, 0, -50244, 1446, 0, 0, 39, '1445'),
	(377, 1, 0, -50244, 1447, 0, 0, 39, '1446'),
	(377, 1, 0, -50244, 1448, 0, 0, 39, '1447'),
	(377, 1, 0, -50244, 1449, 0, 0, 39, '1448'),
	(377, 1, 0, -50244, 1450, 0, 0, 39, '1449'),
	(377, 1, 0, -50244, 1451, 0, 0, 39, '1450'),
	(377, 1, 0, -50244, 1452, 0, 0, 39, '1451'),
	(377, 1, 0, -50244, 1453, 0, 0, 39, '1452'),
	(377, 1, 0, -50244, 1454, 0, 0, 39, '1453'),
	(377, 1, 0, -50244, 1455, 0, 0, 39, '1454'),
	(377, 1, 0, -50244, 1456, 0, 0, 39, '1455'),
	(377, 1, 0, -50244, 1457, 0, 0, 39, '1456'),
	(377, 1, 0, -50244, 1458, 0, 0, 39, '1457'),
	(377, 1, 0, -50244, 1459, 0, 0, 39, '1458'),
	(377, 1, 0, -50244, 1460, 0, 0, 39, '1459'),
	(377, 1, 0, -50244, 1461, 0, 0, 39, '1460'),
	(377, 1, 0, -50244, 1462, 0, 0, 39, '1461'),
	(377, 1, 0, -50244, 1463, 0, 0, 39, '1462'),
	(377, 1, 0, -50244, 1464, 0, 0, 39, '1463'),
	(377, 1, 0, -50244, 1465, 0, 0, 39, '1464'),
	(377, 1, 0, -50244, 1466, 0, 0, 39, '1465'),
	(377, 1, 0, -50244, 1467, 0, 0, 39, '1466'),
	(377, 1, 0, -50244, 1468, 0, 0, 39, '1467'),
	(377, 1, 0, -50244, 1469, 0, 0, 39, '1468'),
	(377, 1, 0, -50244, 1470, 0, 0, 39, '1469'),
	(377, 1, 0, -50244, 1471, 0, 0, 39, '1470'),
	(377, 1, 0, -50244, 1472, 0, 0, 39, '1471'),
	(377, 1, 0, -50244, 1473, 0, 0, 39, '1472'),
	(377, 1, 0, -50244, 1474, 0, 0, 39, '1473'),
	(377, 1, 0, -50244, 1475, 0, 0, 39, '1474'),
	(377, 1, 0, -50244, 1476, 0, 0, 39, '1475'),
	(377, 1, 0, -50244, 1477, 0, 0, 39, '1476'),
	(377, 1, 0, -50244, 1478, 0, 0, 39, '1477'),
	(377, 1, 0, -50244, 1479, 0, 0, 39, '1478'),
	(377, 1, 0, -50244, 1480, 0, 0, 39, '1479'),
	(377, 1, 0, -50244, 1481, 0, 0, 39, '1480'),
	(377, 1, 0, -50244, 1482, 0, 0, 39, '1481'),
	(377, 1, 0, -50244, 1483, 0, 0, 39, '1482'),
	(377, 1, 0, -50244, 1484, 0, 0, 39, '1483'),
	(377, 1, 0, -50244, 1485, 0, 0, 39, '1484'),
	(377, 1, 0, -50244, 1486, 0, 0, 39, '1485'),
	(377, 1, 0, -50244, 1487, 0, 0, 39, '1486'),
	(377, 1, 0, -50244, 1488, 0, 0, 39, '1487'),
	(377, 1, 0, -50244, 1489, 0, 0, 39, '1488'),
	(377, 1, 0, -50244, 1490, 0, 0, 39, '1489'),
	(377, 1, 0, -50244, 1491, 0, 0, 39, '1490'),
	(377, 1, 0, -50244, 1492, 0, 0, 39, '1491'),
	(377, 1, 0, -50244, 1493, 0, 0, 39, '1492'),
	(377, 1, 0, -50244, 1494, 0, 0, 39, '1493'),
	(377, 1, 0, -50244, 1495, 0, 0, 39, '1494'),
	(377, 1, 0, -50244, 1496, 0, 0, 39, '1495'),
	(377, 1, 0, -50244, 1497, 0, 0, 39, '1496'),
	(377, 1, 0, -50244, 1498, 0, 0, 39, '1497'),
	(377, 1, 0, -50244, 1499, 0, 0, 39, '1498'),
	(377, 1, 0, -50244, 1500, 0, 0, 39, '1499'),
	(377, 1, 0, -50244, 1501, 0, 0, 39, '1500'),
	(377, 1, 0, -50244, 1502, 0, 0, 39, '1501'),
	(377, 1, 0, -50244, 1503, 0, 0, 39, '1502'),
	(377, 1, 0, -50244, 1504, 0, 0, 39, '1503'),
	(377, 1, 0, -50244, 1505, 0, 0, 39, '1504'),
	(377, 1, 0, -50244, 1506, 0, 0, 39, '1505'),
	(377, 1, 0, -50244, 1507, 0, 0, 39, '1506'),
	(377, 1, 0, -50244, 1508, 0, 0, 39, '1507'),
	(377, 1, 0, -50244, 1509, 0, 0, 39, '1508'),
	(377, 1, 0, -50244, 1510, 0, 0, 39, '1509'),
	(377, 1, 0, -50244, 1511, 0, 0, 39, '1510'),
	(377, 1, 0, -50244, 1512, 0, 0, 39, '1511'),
	(377, 1, 0, -50244, 1513, 0, 0, 39, '1512'),
	(377, 1, 0, -50244, 1514, 0, 0, 39, '1513'),
	(377, 1, 0, -50244, 1515, 0, 0, 39, '1514'),
	(377, 1, 0, -50244, 1516, 0, 0, 39, '1515'),
	(377, 1, 0, -50244, 1517, 0, 0, 39, '1516'),
	(377, 1, 0, -50244, 1518, 0, 0, 39, '1517'),
	(377, 1, 0, -50244, 1519, 0, 0, 39, '1518'),
	(377, 1, 0, -50244, 1520, 0, 0, 39, '1519'),
	(377, 1, 0, -50244, 1521, 0, 0, 39, '1520'),
	(377, 1, 0, -50244, 1522, 0, 0, 39, '1521'),
	(377, 1, 0, -50244, 1523, 0, 0, 39, '1522'),
	(377, 1, 0, -50244, 1524, 0, 0, 39, '1523'),
	(377, 1, 0, -50244, 1525, 0, 0, 39, '1524'),
	(377, 1, 0, -50244, 1526, 0, 0, 39, '1525'),
	(377, 1, 0, -50244, 1527, 0, 0, 39, '1526'),
	(377, 1, 0, -50244, 1528, 0, 0, 39, '1527'),
	(377, 1, 0, -50244, 1529, 0, 0, 39, '1528'),
	(377, 1, 0, -50244, 1530, 0, 0, 39, '1529'),
	(377, 1, 0, -50244, 1531, 0, 0, 39, '1530'),
	(377, 1, 0, -50244, 1532, 0, 0, 39, '1531'),
	(377, 1, 0, -50244, 1533, 0, 0, 39, '1532'),
	(377, 1, 0, -50244, 1534, 0, 0, 39, '1533'),
	(377, 1, 0, -50244, 1535, 0, 0, 39, '1534'),
	(377, 1, 0, -50244, 1536, 0, 0, 39, '1535'),
	(377, 1, 0, -50244, 1537, 0, 0, 39, '1536'),
	(377, 1, 0, -50244, 1538, 0, 0, 39, '1537'),
	(377, 1, 0, -50244, 1539, 0, 0, 39, '1538'),
	(377, 1, 0, -50244, 1540, 0, 0, 39, '1539'),
	(377, 1, 0, -50244, 1541, 0, 0, 39, '1540'),
	(377, 1, 0, -50244, 1542, 0, 0, 39, '1541'),
	(377, 1, 0, -50244, 1543, 0, 0, 39, '1542'),
	(377, 1, 0, -50244, 1544, 0, 0, 39, '1543'),
	(377, 1, 0, -50244, 1545, 0, 0, 39, '1544'),
	(377, 1, 0, -50244, 1546, 0, 0, 39, '1545'),
	(377, 1, 0, -50244, 1547, 0, 0, 39, '1546'),
	(377, 1, 0, -50244, 1548, 0, 0, 39, '1547'),
	(377, 1, 0, -50244, 1549, 0, 0, 39, '1548'),
	(377, 1, 0, -50244, 1550, 0, 0, 39, '1549'),
	(377, 1, 0, -50244, 1551, 0, 0, 39, '1550'),
	(377, 1, 0, -50244, 1552, 0, 0, 39, '1551'),
	(377, 1, 0, -50244, 1553, 0, 0, 39, '1552'),
	(377, 1, 0, -50244, 1554, 0, 0, 39, '1553'),
	(377, 1, 0, -50244, 1555, 0, 0, 39, '1554'),
	(377, 1, 0, -50244, 1556, 0, 0, 39, '1555'),
	(377, 1, 0, -50244, 1557, 0, 0, 39, '1556'),
	(377, 1, 0, -50244, 1558, 0, 0, 39, '1557'),
	(377, 1, 0, -50244, 1559, 0, 0, 39, '1558'),
	(377, 1, 0, -50244, 1560, 0, 0, 39, '1559'),
	(377, 1, 0, -50244, 1561, 0, 0, 39, '1560'),
	(377, 1, 0, -50244, 1562, 0, 0, 39, '1561'),
	(377, 1, 0, -50244, 1563, 0, 0, 39, '1562'),
	(377, 1, 0, -50244, 1564, 0, 0, 39, '1563'),
	(377, 1, 0, -50244, 1565, 0, 0, 39, '1564'),
	(377, 1, 0, -50244, 1566, 0, 0, 39, '1565'),
	(377, 1, 0, -50244, 1567, 0, 0, 39, '1566'),
	(377, 1, 0, -50244, 1568, 0, 0, 39, '1567'),
	(377, 1, 0, -50244, 1569, 0, 0, 39, '1568'),
	(377, 1, 0, -50244, 1570, 0, 0, 39, '1569'),
	(377, 1, 0, -50244, 1571, 0, 0, 39, '1570'),
	(377, 1, 0, -50244, 1572, 0, 0, 39, '1571'),
	(377, 1, 0, -50244, 1573, 0, 0, 39, '1572'),
	(377, 1, 0, -50244, 1574, 0, 0, 39, '1573'),
	(377, 1, 0, -50244, 1575, 0, 0, 39, '1574'),
	(377, 1, 0, -50244, 1576, 0, 0, 39, '1575'),
	(377, 1, 0, -50244, 1577, 0, 0, 39, '1576'),
	(377, 1, 0, -50244, 1578, 0, 0, 39, '1577'),
	(377, 1, 0, -50244, 1579, 0, 0, 39, '1578'),
	(377, 1, 0, -50244, 1580, 0, 0, 39, '1579'),
	(377, 1, 0, -50244, 1581, 0, 0, 39, '1580'),
	(377, 1, 0, -50244, 1582, 0, 0, 39, '1581'),
	(377, 1, 0, -50244, 1583, 0, 0, 39, '1582'),
	(377, 1, 0, -50244, 1584, 0, 0, 39, '1583'),
	(377, 1, 0, -50244, 1585, 0, 0, 39, '1584'),
	(377, 1, 0, -50244, 1586, 0, 0, 39, '1585'),
	(377, 1, 0, -50244, 1587, 0, 0, 39, '1586'),
	(377, 1, 0, -50244, 1588, 0, 0, 39, '1587'),
	(377, 1, 0, -50244, 1589, 0, 0, 39, '1588'),
	(377, 1, 0, -50244, 1590, 0, 0, 39, '1589'),
	(377, 1, 0, -50244, 1591, 0, 0, 39, '1590'),
	(377, 1, 0, -50244, 1592, 0, 0, 39, '1591'),
	(377, 1, 0, -50244, 1593, 0, 0, 39, '1592'),
	(377, 1, 0, -50244, 1594, 0, 0, 39, '1593'),
	(377, 1, 0, -50244, 1595, 0, 0, 39, '1594'),
	(377, 1, 0, -50244, 1596, 0, 0, 39, '1595'),
	(377, 1, 0, -50244, 1597, 0, 0, 39, '1596'),
	(377, 1, 0, -50244, 1598, 0, 0, 39, '1597'),
	(377, 1, 0, -50244, 1599, 0, 0, 39, '1598'),
	(377, 1, 0, -50244, 1600, 0, 0, 39, '1599'),
	(377, 1, 0, -50244, 1601, 0, 0, 39, '1600'),
	(377, 1, 0, -50244, 1602, 0, 0, 39, '1601'),
	(377, 1, 0, -50244, 1603, 0, 0, 39, '1602'),
	(377, 1, 0, -50244, 1604, 0, 0, 39, '1603'),
	(377, 1, 0, -50244, 1605, 0, 0, 39, '1604'),
	(377, 1, 0, -50244, 1606, 0, 0, 39, '1605'),
	(377, 1, 0, -50244, 1607, 0, 0, 39, '1606'),
	(377, 1, 0, -50244, 1608, 0, 0, 39, '1607'),
	(377, 1, 0, -50244, 1609, 0, 0, 39, '1608'),
	(377, 1, 0, -50244, 1610, 0, 0, 39, '1609'),
	(377, 1, 0, -50244, 1611, 0, 0, 39, '1610'),
	(377, 1, 0, -50244, 1612, 0, 0, 39, '1611'),
	(377, 1, 0, -50244, 1613, 0, 0, 39, '1612'),
	(377, 1, 0, -50244, 1614, 0, 0, 39, '1613'),
	(377, 1, 0, -50244, 1615, 0, 0, 39, '1614'),
	(377, 1, 0, -50244, 1616, 0, 0, 39, '1615'),
	(377, 1, 0, -50244, 1617, 0, 0, 39, '1616'),
	(377, 1, 0, -50244, 1618, 0, 0, 39, '1617'),
	(377, 1, 0, -50244, 1619, 0, 0, 39, '1618'),
	(377, 1, 0, -50244, 1620, 0, 0, 39, '1619'),
	(377, 1, 0, -50244, 1621, 0, 0, 39, '1620'),
	(377, 1, 0, -50244, 1622, 0, 0, 39, '1621'),
	(377, 1, 0, -50244, 1623, 0, 0, 39, '1622'),
	(377, 1, 0, -50244, 1624, 0, 0, 39, '1623'),
	(377, 1, 0, -50244, 1625, 0, 0, 39, '1624'),
	(377, 1, 0, -50244, 1626, 0, 0, 39, '1625'),
	(377, 1, 0, -50244, 1627, 0, 0, 39, '1626'),
	(377, 1, 0, -50244, 1628, 0, 0, 39, '1627'),
	(377, 1, 0, -50244, 1629, 0, 0, 39, '1628'),
	(377, 1, 0, -50244, 1630, 0, 0, 39, '1629'),
	(377, 1, 0, -50244, 1631, 0, 0, 39, '1630'),
	(377, 1, 0, -50244, 1632, 0, 0, 39, '1631'),
	(377, 1, 0, -50244, 1633, 0, 0, 39, '1632'),
	(377, 1, 0, -50244, 1634, 0, 0, 39, '1633'),
	(377, 1, 0, -50244, 1635, 0, 0, 39, '1634'),
	(377, 1, 0, -50244, 1636, 0, 0, 39, '1635'),
	(377, 1, 0, -50244, 1637, 0, 0, 39, '1636'),
	(377, 1, 0, -50244, 1638, 0, 0, 39, '1637'),
	(377, 1, 0, -50244, 1639, 0, 0, 39, '1638'),
	(377, 1, 0, -50244, 1640, 0, 0, 39, '1639'),
	(377, 1, 0, -50244, 1641, 0, 0, 39, '1640'),
	(377, 1, 0, -50244, 1642, 0, 0, 39, '1641'),
	(377, 1, 0, -50244, 1643, 0, 0, 39, '1642'),
	(377, 1, 0, -50244, 1644, 0, 0, 39, '1643'),
	(377, 1, 0, -50244, 1645, 0, 0, 39, '1644'),
	(377, 1, 0, -50244, 1646, 0, 0, 39, '1645'),
	(377, 1, 0, -50244, 1647, 0, 0, 39, '1646'),
	(377, 1, 0, -50244, 1648, 0, 0, 39, '1647'),
	(377, 1, 0, -50244, 1649, 0, 0, 39, '1648'),
	(377, 1, 0, -50244, 1650, 0, 0, 39, '1649'),
	(377, 1, 0, -50244, 1651, 0, 0, 39, '1650'),
	(377, 1, 0, -50244, 1652, 0, 0, 39, '1651'),
	(377, 1, 0, -50244, 1653, 0, 0, 39, '1652'),
	(377, 1, 0, -50244, 1654, 0, 0, 39, '1653'),
	(377, 1, 0, -50244, 1655, 0, 0, 39, '1654'),
	(377, 1, 0, -50244, 1656, 0, 0, 39, '1655'),
	(377, 1, 0, -50244, 1657, 0, 0, 39, '1656'),
	(377, 1, 0, -50244, 1658, 0, 0, 39, '1657'),
	(377, 1, 0, -50244, 1659, 0, 0, 39, '1658'),
	(377, 1, 0, -50244, 1660, 0, 0, 39, '1659'),
	(377, 1, 0, -50244, 1661, 0, 0, 39, '1660'),
	(377, 1, 0, -50244, 1662, 0, 0, 39, '1661'),
	(377, 1, 0, -50244, 1663, 0, 0, 39, '1662'),
	(377, 1, 0, -50244, 1664, 0, 0, 39, '1663'),
	(377, 1, 0, -50244, 1665, 0, 0, 39, '1664'),
	(377, 1, 0, -50244, 1666, 0, 0, 39, '1665'),
	(377, 1, 0, -50244, 1667, 0, 0, 39, '1666'),
	(377, 1, 0, -50244, 1668, 0, 0, 39, '1667'),
	(377, 1, 0, -50244, 1669, 0, 0, 39, '1668'),
	(377, 1, 0, -50244, 1670, 0, 0, 39, '1669'),
	(377, 1, 0, -50244, 1671, 0, 0, 39, '1670'),
	(377, 1, 0, -50244, 1672, 0, 0, 39, '1671'),
	(377, 1, 0, -50244, 1673, 0, 0, 39, '1672'),
	(377, 1, 0, -50244, 1674, 0, 0, 39, '1673'),
	(377, 1, 0, -50244, 1675, 0, 0, 39, '1674'),
	(377, 1, 0, -50244, 1676, 0, 0, 39, '1675'),
	(377, 1, 0, -50244, 1677, 0, 0, 39, '1676'),
	(377, 1, 0, -50244, 1678, 0, 0, 39, '1677'),
	(377, 1, 0, -50244, 1679, 0, 0, 39, '1678'),
	(377, 1, 0, -50244, 1680, 0, 0, 39, '1679'),
	(377, 1, 0, -50244, 1681, 0, 0, 39, '1680'),
	(377, 1, 0, -50244, 1682, 0, 0, 39, '1681'),
	(377, 1, 0, -50244, 1683, 0, 0, 39, '1682'),
	(377, 1, 0, -50244, 1684, 0, 0, 39, '1683'),
	(377, 1, 0, -50244, 1685, 0, 0, 39, '1684'),
	(377, 1, 0, -50244, 1686, 0, 0, 39, '1685'),
	(377, 1, 0, -50244, 1687, 0, 0, 39, '1686'),
	(377, 1, 0, -50244, 1688, 0, 0, 39, '1687'),
	(377, 1, 0, -50244, 1689, 0, 0, 39, '1688'),
	(377, 1, 0, -50244, 1690, 0, 0, 39, '1689'),
	(377, 1, 0, -50244, 1691, 0, 0, 39, '1690'),
	(377, 1, 0, -50244, 1692, 0, 0, 39, '1691'),
	(377, 1, 0, -50244, 1693, 0, 0, 39, '1692'),
	(377, 1, 0, -50244, 1694, 0, 0, 39, '1693'),
	(377, 1, 0, -50244, 1695, 0, 0, 39, '1694'),
	(377, 1, 0, -50244, 1696, 0, 0, 39, '1695'),
	(377, 1, 0, -50244, 1697, 0, 0, 39, '1696'),
	(377, 1, 0, -50244, 1698, 0, 0, 39, '1697'),
	(377, 1, 0, -50244, 1699, 0, 0, 39, '1698'),
	(377, 1, 0, -50244, 1700, 0, 0, 39, '1699'),
	(377, 1, 0, -50244, 1701, 0, 0, 39, '1700'),
	(377, 1, 0, -50244, 1702, 0, 0, 39, '1701'),
	(377, 1, 0, -50244, 1703, 0, 0, 39, '1702'),
	(377, 1, 0, -50244, 1704, 0, 0, 39, '1703'),
	(377, 1, 0, -50244, 1705, 0, 0, 39, '1704'),
	(377, 1, 0, -50244, 1706, 0, 0, 39, '1705'),
	(377, 1, 0, -50244, 1707, 0, 0, 39, '1706'),
	(377, 1, 0, -50244, 1708, 0, 0, 39, '1707'),
	(377, 1, 0, -50244, 1709, 0, 0, 39, '1708'),
	(377, 1, 0, -50244, 1710, 0, 0, 39, '1709'),
	(377, 1, 0, -50244, 1711, 0, 0, 39, '1710'),
	(377, 1, 0, -50244, 1712, 0, 0, 39, '1711'),
	(377, 1, 0, -50244, 1713, 0, 0, 39, '1712'),
	(377, 1, 0, -50244, 1714, 0, 0, 39, '1713'),
	(377, 1, 0, -50244, 1715, 0, 0, 39, '1714'),
	(377, 1, 0, -50244, 1716, 0, 0, 39, '1715'),
	(377, 1, 0, -50244, 1717, 0, 0, 39, '1716'),
	(377, 1, 0, -50244, 1718, 0, 0, 39, '1717'),
	(377, 1, 0, -50244, 1719, 0, 0, 39, '1718'),
	(377, 1, 0, -50244, 1720, 0, 0, 39, '1719'),
	(377, 1, 0, -50244, 1721, 0, 0, 39, '1720'),
	(377, 1, 0, -50244, 1722, 0, 0, 39, '1721'),
	(377, 1, 0, -50244, 1723, 0, 0, 39, '1722'),
	(377, 1, 0, -50244, 1724, 0, 0, 39, '1723'),
	(377, 1, 0, -50244, 1725, 0, 0, 39, '1724'),
	(377, 1, 0, -50244, 1726, 0, 0, 39, '1725'),
	(377, 1, 0, -50244, 1727, 0, 0, 39, '1726'),
	(377, 1, 0, -50244, 1728, 0, 0, 39, '1727'),
	(377, 1, 0, -50244, 1729, 0, 0, 39, '1728'),
	(377, 1, 0, -50244, 1730, 0, 0, 39, '1729'),
	(377, 1, 0, -50244, 1731, 0, 0, 39, '1730'),
	(377, 1, 0, -50244, 1732, 0, 0, 39, '1731'),
	(377, 1, 0, -50244, 1733, 0, 0, 39, '1732'),
	(377, 1, 0, -50244, 1734, 0, 0, 39, '1733'),
	(377, 1, 0, -50244, 1735, 0, 0, 39, '1734'),
	(377, 1, 0, -50244, 1736, 0, 0, 39, '1735'),
	(377, 1, 0, -50244, 1737, 0, 0, 39, '1736'),
	(377, 1, 0, -50244, 1738, 0, 0, 39, '1737'),
	(377, 1, 0, -50244, 1739, 0, 0, 39, '1738'),
	(377, 1, 0, -50244, 1740, 0, 0, 39, '1739'),
	(377, 1, 0, -50244, 1741, 0, 0, 39, '1740'),
	(377, 1, 0, -50244, 1742, 0, 0, 39, '1741'),
	(377, 1, 0, -50244, 1743, 0, 0, 39, '1742'),
	(377, 1, 0, -50244, 1744, 0, 0, 39, '1743'),
	(377, 1, 0, -50244, 1745, 0, 0, 39, '1744'),
	(377, 1, 0, -50244, 1746, 0, 0, 39, '1745'),
	(377, 1, 0, -50244, 1747, 0, 0, 39, '1746'),
	(377, 1, 0, -50244, 1748, 0, 0, 39, '1747'),
	(377, 1, 0, -50244, 1749, 0, 0, 39, '1748'),
	(377, 1, 0, -50244, 1750, 0, 0, 39, '1749'),
	(377, 1, 0, -50244, 1751, 0, 0, 39, '1750'),
	(377, 1, 0, -50244, 1752, 0, 0, 39, '1751'),
	(377, 1, 0, -50244, 1753, 0, 0, 39, '1752'),
	(377, 1, 0, -50244, 1754, 0, 0, 39, '1753'),
	(377, 1, 0, -50244, 1755, 0, 0, 39, '1754'),
	(377, 1, 0, -50244, 1756, 0, 0, 39, '1755'),
	(377, 1, 0, -50244, 1757, 0, 0, 39, '1756'),
	(377, 1, 0, -50244, 1758, 0, 0, 39, '1757'),
	(377, 1, 0, -50244, 1759, 0, 0, 39, '1758'),
	(377, 1, 0, -50244, 1760, 0, 0, 39, '1759'),
	(377, 1, 0, -50244, 1761, 0, 0, 39, '1760'),
	(377, 1, 0, -50244, 1762, 0, 0, 39, '1761'),
	(377, 1, 0, -50244, 1763, 0, 0, 39, '1762'),
	(377, 1, 0, -50244, 1764, 0, 0, 39, '1763'),
	(377, 1, 0, -50244, 1765, 0, 0, 39, '1764'),
	(377, 1, 0, -50244, 1766, 0, 0, 39, '1765'),
	(377, 1, 0, -50244, 1767, 0, 0, 39, '1766'),
	(377, 1, 0, -50244, 1768, 0, 0, 39, '1767'),
	(377, 1, 0, -50244, 1769, 0, 0, 39, '1768'),
	(377, 1, 0, -50244, 1770, 0, 0, 39, '1769'),
	(377, 1, 0, -50244, 1771, 0, 0, 39, '1770'),
	(377, 1, 0, -50244, 1772, 0, 0, 39, '1771'),
	(377, 1, 0, -50244, 1773, 0, 0, 39, '1772'),
	(377, 1, 0, -50244, 1774, 0, 0, 39, '1773'),
	(377, 1, 0, -50244, 1775, 0, 0, 39, '1774'),
	(377, 1, 0, -50244, 1776, 0, 0, 39, '1775'),
	(377, 1, 0, -50244, 1777, 0, 0, 39, '1776'),
	(377, 1, 0, -50244, 1778, 0, 0, 39, '1777'),
	(377, 1, 0, -50244, 1779, 0, 0, 39, '1778'),
	(377, 1, 0, -50244, 1780, 0, 0, 39, '1779'),
	(377, 1, 0, -50244, 1781, 0, 0, 39, '1780'),
	(377, 1, 0, -50244, 1782, 0, 0, 39, '1781'),
	(377, 1, 0, -50244, 1783, 0, 0, 39, '1782'),
	(377, 1, 0, -50244, 1784, 0, 0, 39, '1783'),
	(377, 1, 0, -50244, 1785, 0, 0, 39, '1784'),
	(377, 1, 0, -50244, 1786, 0, 0, 39, '1785'),
	(377, 1, 0, -50244, 1787, 0, 0, 39, '1786'),
	(377, 1, 0, -50244, 1788, 0, 0, 39, '1787'),
	(377, 1, 0, -50244, 1789, 0, 0, 39, '1788'),
	(377, 1, 0, -50244, 1790, 0, 0, 39, '1789'),
	(377, 1, 0, -50244, 1791, 0, 0, 39, '1790'),
	(377, 1, 0, -50244, 1792, 0, 0, 39, '1791'),
	(377, 1, 0, -50244, 1793, 0, 0, 39, '1792'),
	(377, 1, 0, -50244, 1794, 0, 0, 39, '1793'),
	(377, 1, 0, -50244, 1795, 0, 0, 39, '1794'),
	(377, 1, 0, -50244, 1796, 0, 0, 39, '1795'),
	(377, 1, 0, -50244, 1797, 0, 0, 39, '1796'),
	(377, 1, 0, -50244, 1798, 0, 0, 39, '1797'),
	(377, 1, 0, -50244, 1799, 0, 0, 39, '1798'),
	(377, 1, 0, -50244, 1800, 0, 0, 39, '1799'),
	(377, 1, 0, -50244, 1801, 0, 0, 39, '1800'),
	(377, 1, 0, -50244, 1802, 0, 0, 39, '1801'),
	(377, 1, 0, -50244, 1803, 0, 0, 39, '1802'),
	(377, 1, 0, -50244, 1804, 0, 0, 39, '1803'),
	(377, 1, 0, -50244, 1805, 0, 0, 39, '1804'),
	(377, 1, 0, -50244, 1806, 0, 0, 39, '1805'),
	(377, 1, 0, -50244, 1807, 0, 0, 39, '1806'),
	(377, 1, 0, -50244, 1808, 0, 0, 39, '1807'),
	(377, 1, 0, -50244, 1809, 0, 0, 39, '1808'),
	(377, 1, 0, -50244, 1810, 0, 0, 39, '1809'),
	(377, 1, 0, -50244, 1811, 0, 0, 39, '1810'),
	(377, 1, 0, -50244, 1812, 0, 0, 39, '1811'),
	(377, 1, 0, -50244, 1813, 0, 0, 39, '1812'),
	(377, 1, 0, -50244, 1814, 0, 0, 39, '1813'),
	(377, 1, 0, -50244, 1815, 0, 0, 39, '1814'),
	(377, 1, 0, -50244, 1816, 0, 0, 39, '1815'),
	(377, 1, 0, -50244, 1817, 0, 0, 39, '1816'),
	(377, 1, 0, -50244, 1818, 0, 0, 39, '1817'),
	(377, 1, 0, -50244, 1819, 0, 0, 39, '1818'),
	(377, 1, 0, -50244, 1820, 0, 0, 39, '1819'),
	(377, 1, 0, -50244, 1821, 0, 0, 39, '1820'),
	(377, 1, 0, -50244, 1822, 0, 0, 39, '1821'),
	(377, 1, 0, -50244, 1823, 0, 0, 39, '1822'),
	(377, 1, 0, -50244, 1824, 0, 0, 39, '1823'),
	(377, 1, 0, -50244, 1825, 0, 0, 39, '1824'),
	(377, 1, 0, -50244, 1826, 0, 0, 39, '1825'),
	(377, 1, 0, -50244, 1827, 0, 0, 39, '1826'),
	(377, 1, 0, -50244, 1828, 0, 0, 39, '1827'),
	(377, 1, 0, -50244, 1829, 0, 0, 39, '1828'),
	(377, 1, 0, -50244, 1830, 0, 0, 39, '1829'),
	(377, 1, 0, -50244, 1831, 0, 0, 39, '1830'),
	(377, 1, 0, -50244, 1832, 0, 0, 39, '1831'),
	(377, 1, 0, -50244, 1833, 0, 0, 39, '1832'),
	(377, 1, 0, -50244, 1834, 0, 0, 39, '1833'),
	(377, 1, 0, -50244, 1835, 0, 0, 39, '1834'),
	(377, 1, 0, -50244, 1836, 0, 0, 39, '1835'),
	(377, 1, 0, -50244, 1837, 0, 0, 39, '1836'),
	(377, 1, 0, -50244, 1838, 0, 0, 39, '1837'),
	(377, 1, 0, -50244, 1839, 0, 0, 39, '1838'),
	(377, 1, 0, -50244, 1840, 0, 0, 39, '1839'),
	(377, 1, 0, -50244, 1841, 0, 0, 39, '1840'),
	(377, 1, 0, -50244, 1842, 0, 0, 39, '1841'),
	(377, 1, 0, -50244, 1843, 0, 0, 39, '1842'),
	(377, 1, 0, -50244, 1844, 0, 0, 39, '1843'),
	(377, 1, 0, -50244, 1845, 0, 0, 39, '1844'),
	(377, 1, 0, -50244, 1846, 0, 0, 39, '1845'),
	(377, 1, 0, -50244, 1847, 0, 0, 39, '1846'),
	(377, 1, 0, -50244, 1848, 0, 0, 39, '1847'),
	(377, 1, 0, -50244, 1849, 0, 0, 39, '1848'),
	(377, 1, 0, -50244, 1850, 0, 0, 39, '1849'),
	(377, 1, 0, -50244, 1851, 0, 0, 39, '1850'),
	(377, 1, 0, -50244, 1852, 0, 0, 39, '1851'),
	(377, 1, 0, -50244, 1853, 0, 0, 39, '1852'),
	(377, 1, 0, -50244, 1854, 0, 0, 39, '1853'),
	(377, 1, 0, -50244, 1855, 0, 0, 39, '1854'),
	(377, 1, 0, -50244, 1856, 0, 0, 39, '1855'),
	(377, 1, 0, -50244, 1857, 0, 0, 39, '1856'),
	(377, 1, 0, -50244, 1858, 0, 0, 39, '1857'),
	(377, 1, 0, -50244, 1859, 0, 0, 39, '1858'),
	(377, 1, 0, -50244, 1860, 0, 0, 39, '1859'),
	(377, 1, 0, -50244, 1861, 0, 0, 39, '1860'),
	(377, 1, 0, -50244, 1862, 0, 0, 39, '1861'),
	(377, 1, 0, -50244, 1863, 0, 0, 39, '1862'),
	(377, 1, 0, -50244, 1864, 0, 0, 39, '1863'),
	(377, 1, 0, -50244, 1865, 0, 0, 39, '1864'),
	(377, 1, 0, -50244, 1866, 0, 0, 39, '1865'),
	(377, 1, 0, -50244, 1867, 0, 0, 39, '1866'),
	(377, 1, 0, -50244, 1868, 0, 0, 39, '1867'),
	(377, 1, 0, -50244, 1869, 0, 0, 39, '1868'),
	(377, 1, 0, -50244, 1870, 0, 0, 39, '1869'),
	(377, 1, 0, -50244, 1871, 0, 0, 39, '1870'),
	(377, 1, 0, -50244, 1872, 0, 0, 39, '1871'),
	(377, 1, 0, -50244, 1873, 0, 0, 39, '1872'),
	(377, 1, 0, -50244, 1874, 0, 0, 39, '1873'),
	(377, 1, 0, -50244, 1875, 0, 0, 39, '1874'),
	(377, 1, 0, -50244, 1876, 0, 0, 39, '1875'),
	(377, 1, 0, -50244, 1877, 0, 0, 39, '1876'),
	(377, 1, 0, -50244, 1878, 0, 0, 39, '1877'),
	(377, 1, 0, -50244, 1879, 0, 0, 39, '1878'),
	(377, 1, 0, -50244, 1880, 0, 0, 39, '1879'),
	(377, 1, 0, -50244, 1881, 0, 0, 39, '1880'),
	(377, 1, 0, -50244, 1882, 0, 0, 39, '1881'),
	(377, 1, 0, -50244, 1883, 0, 0, 39, '1882'),
	(377, 1, 0, -50244, 1884, 0, 0, 39, '1883'),
	(377, 1, 0, -50244, 1885, 0, 0, 39, '1884'),
	(377, 1, 0, -50244, 1886, 0, 0, 39, '1885'),
	(377, 1, 0, -50244, 1887, 0, 0, 39, '1886'),
	(377, 1, 0, -50244, 1888, 0, 0, 39, '1887'),
	(377, 1, 0, -50244, 1889, 0, 0, 39, '1888'),
	(377, 1, 0, -50244, 1890, 0, 0, 39, '1889'),
	(377, 1, 0, -50244, 1891, 0, 0, 39, '1890'),
	(377, 1, 0, -50244, 1892, 0, 0, 39, '1891'),
	(377, 1, 0, -50244, 1893, 0, 0, 39, '1892'),
	(377, 1, 0, -50244, 1894, 0, 0, 39, '1893'),
	(377, 1, 0, -50244, 1895, 0, 0, 39, '1894'),
	(377, 1, 0, -50244, 1896, 0, 0, 39, '1895'),
	(377, 1, 0, -50244, 1897, 0, 0, 39, '1896'),
	(377, 1, 0, -50244, 1898, 0, 0, 39, '1897'),
	(377, 1, 0, -50244, 1899, 0, 0, 39, '1898'),
	(377, 1, 0, -50244, 1900, 0, 0, 39, '1899'),
	(377, 1, 0, -50244, 1901, 0, 0, 39, '1900'),
	(377, 1, 0, -50244, 1902, 0, 0, 39, '1901'),
	(377, 1, 0, -50244, 1903, 0, 0, 39, '1902'),
	(377, 1, 0, -50244, 1904, 0, 0, 39, '1903'),
	(377, 1, 0, -50244, 1905, 0, 0, 39, '1904'),
	(377, 1, 0, -50244, 1906, 0, 0, 39, '1905'),
	(377, 1, 0, -50244, 1907, 0, 0, 39, '1906'),
	(377, 1, 0, -50244, 1908, 0, 0, 39, '1907'),
	(377, 1, 0, -50244, 1909, 0, 0, 39, '1908'),
	(377, 1, 0, -50244, 1910, 0, 0, 39, '1909'),
	(377, 1, 0, -50244, 1911, 0, 0, 39, '1910'),
	(377, 1, 0, -50244, 1912, 0, 0, 39, '1911'),
	(377, 1, 0, -50244, 1913, 0, 0, 39, '1912'),
	(377, 1, 0, -50244, 1914, 0, 0, 39, '1913'),
	(377, 1, 0, -50244, 1915, 0, 0, 39, '1914'),
	(377, 1, 0, -50244, 1916, 0, 0, 39, '1915'),
	(377, 1, 0, -50244, 1917, 0, 0, 39, '1916'),
	(377, 1, 0, -50244, 1918, 0, 0, 39, '1917'),
	(377, 1, 0, -50244, 1919, 0, 0, 39, '1918'),
	(377, 1, 0, -50244, 1920, 0, 0, 39, '1919'),
	(377, 1, 0, -50244, 1921, 0, 0, 39, '1920'),
	(377, 1, 0, -50244, 1922, 0, 0, 39, '1921'),
	(377, 1, 0, -50244, 1923, 0, 0, 39, '1922'),
	(377, 1, 0, -50244, 1924, 0, 0, 39, '1923'),
	(377, 1, 0, -50244, 1925, 0, 0, 39, '1924'),
	(377, 1, 0, -50244, 1926, 0, 0, 39, '1925'),
	(377, 1, 0, -50244, 1927, 0, 0, 39, '1926'),
	(377, 1, 0, -50244, 1928, 0, 0, 39, '1927'),
	(377, 1, 0, -50244, 1929, 0, 0, 39, '1928'),
	(377, 1, 0, -50244, 1930, 0, 0, 39, '1929'),
	(377, 1, 0, -50244, 1931, 0, 0, 39, '1930'),
	(377, 1, 0, -50244, 1932, 0, 0, 39, '1931'),
	(377, 1, 0, -50244, 1933, 0, 0, 39, '1932'),
	(377, 1, 0, -50244, 1934, 0, 0, 39, '1933'),
	(377, 1, 0, -50244, 1935, 0, 0, 39, '1934'),
	(377, 1, 0, -50244, 1936, 0, 0, 39, '1935'),
	(377, 1, 0, -50244, 1937, 0, 0, 39, '1936'),
	(377, 1, 0, -50244, 1938, 0, 0, 39, '1937'),
	(377, 1, 0, -50244, 1939, 0, 0, 39, '1938'),
	(377, 1, 0, -50244, 1940, 0, 0, 39, '1939'),
	(377, 1, 0, -50244, 1941, 0, 0, 39, '1940'),
	(377, 1, 0, -50244, 1942, 0, 0, 39, '1941'),
	(377, 1, 0, -50244, 1943, 0, 0, 39, '1942'),
	(377, 1, 0, -50244, 1944, 0, 0, 39, '1943'),
	(377, 1, 0, -50244, 1945, 0, 0, 39, '1944'),
	(377, 1, 0, -50244, 1946, 0, 0, 39, '1945'),
	(377, 1, 0, -50244, 1947, 0, 0, 39, '1946'),
	(377, 1, 0, -50244, 1948, 0, 0, 39, '1947'),
	(377, 1, 0, -50244, 1949, 0, 0, 39, '1948'),
	(377, 1, 0, -50244, 1950, 0, 0, 39, '1949'),
	(377, 1, 0, -50244, 1951, 0, 0, 39, '1950'),
	(377, 1, 0, -50244, 1952, 0, 0, 39, '1951'),
	(377, 1, 0, -50244, 1953, 0, 0, 39, '1952'),
	(377, 1, 0, -50244, 1954, 0, 0, 39, '1953'),
	(377, 1, 0, -50244, 1955, 0, 0, 39, '1954'),
	(377, 1, 0, -50244, 1956, 0, 0, 39, '1955'),
	(377, 1, 0, -50244, 1957, 0, 0, 39, '1956'),
	(377, 1, 0, -50244, 1958, 0, 0, 39, '1957'),
	(377, 1, 0, -50244, 1959, 0, 0, 39, '1958'),
	(377, 1, 0, -50244, 1960, 0, 0, 39, '1959'),
	(377, 1, 0, -50244, 1961, 0, 0, 39, '1960'),
	(377, 1, 0, -50244, 1962, 0, 0, 39, '1961'),
	(377, 1, 0, -50244, 1963, 0, 0, 39, '1962'),
	(377, 1, 0, -50244, 1964, 0, 0, 39, '1963'),
	(377, 1, 0, -50244, 1965, 0, 0, 39, '1964'),
	(377, 1, 0, -50244, 1966, 0, 0, 39, '1965'),
	(377, 1, 0, -50244, 1967, 0, 0, 39, '1966'),
	(377, 1, 0, -50244, 1968, 0, 0, 39, '1967'),
	(377, 1, 0, -50244, 1969, 0, 0, 39, '1968'),
	(377, 1, 0, -50244, 1970, 0, 0, 39, '1969'),
	(377, 1, 0, -50244, 1971, 0, 0, 39, '1970'),
	(377, 1, 0, -50244, 1972, 0, 0, 39, '1971'),
	(377, 1, 0, -50244, 1973, 0, 0, 39, '1972'),
	(377, 1, 0, -50244, 1974, 0, 0, 39, '1973'),
	(377, 1, 0, -50244, 1975, 0, 0, 39, '1974'),
	(377, 1, 0, -50244, 1976, 0, 0, 39, '1975'),
	(377, 1, 0, -50244, 1977, 0, 0, 39, '1976'),
	(377, 1, 0, -50244, 1978, 0, 0, 39, '1977'),
	(377, 1, 0, -50244, 1979, 0, 0, 39, '1978'),
	(377, 1, 0, -50244, 1980, 0, 0, 39, '1979'),
	(377, 1, 0, -50244, 1981, 0, 0, 39, '1980'),
	(377, 1, 0, -50244, 1982, 0, 0, 39, '1981'),
	(377, 1, 0, -50244, 1983, 0, 0, 39, '1982'),
	(377, 1, 0, -50244, 1984, 0, 0, 39, '1983'),
	(377, 1, 0, -50244, 1985, 0, 0, 39, '1984'),
	(377, 1, 0, -50244, 1986, 0, 0, 39, '1985'),
	(377, 1, 0, -50244, 1987, 0, 0, 39, '1986'),
	(377, 1, 0, -50244, 1988, 0, 0, 39, '1987'),
	(377, 1, 0, -50244, 1989, 0, 0, 39, '1988'),
	(377, 1, 0, -50244, 1990, 0, 0, 39, '1989'),
	(377, 1, 0, -50244, 1991, 0, 0, 39, '1990'),
	(377, 1, 0, -50244, 1992, 0, 0, 39, '1991'),
	(377, 1, 0, -50244, 1993, 0, 0, 39, '1992'),
	(377, 1, 0, -50244, 1994, 0, 0, 39, '1993'),
	(377, 1, 0, -50244, 1995, 0, 0, 39, '1994'),
	(377, 1, 0, -50244, 1996, 0, 0, 39, '1995'),
	(377, 1, 0, -50244, 1997, 0, 0, 39, '1996'),
	(377, 1, 0, -50244, 1998, 0, 0, 39, '1997'),
	(377, 1, 0, -50244, 1999, 0, 0, 39, '1998'),
	(377, 1, 0, -50244, 2000, 0, 0, 39, '1999'),
	(377, 1, 0, -50244, 2001, 0, 0, 39, '2000'),
	(377, 1, 0, -50244, 2002, 0, 0, 39, '2001'),
	(377, 1, 0, -50244, 2003, 0, 0, 39, '2002'),
	(377, 1, 0, -50244, 2004, 0, 0, 39, '2003'),
	(377, 1, 0, -50244, 2005, 0, 0, 39, '2004'),
	(377, 1, 0, -50244, 2006, 0, 0, 39, '2005'),
	(377, 1, 0, -50244, 2007, 0, 0, 39, '2006'),
	(377, 1, 0, -50244, 2008, 0, 0, 39, '2007'),
	(377, 1, 0, -50244, 2009, 0, 0, 39, '2008'),
	(377, 1, 0, -50244, 2010, 0, 0, 39, '2009'),
	(377, 1, 0, -50244, 2011, 0, 0, 39, '2010'),
	(377, 1, 0, -50244, 2012, 0, 0, 39, '2011'),
	(377, 1, 0, -50244, 2013, 0, 0, 39, '2012'),
	(377, 1, 0, -50244, 2014, 0, 0, 39, '2013'),
	(377, 1, 0, -50244, 2015, 0, 0, 39, '2014'),
	(377, 1, 0, -50244, 2016, 0, 0, 39, '2015'),
	(377, 1, 0, -50244, 2017, 0, 0, 39, '2016'),
	(377, 1, 0, -50244, 2018, 0, 0, 39, '2017'),
	(377, 1, 0, -50244, 2019, 0, 0, 39, '2018'),
	(377, 1, 0, -50244, 2020, 0, 0, 39, '2019'),
	(377, 1, 0, -50244, 2021, 0, 0, 39, '2020'),
	(377, 1, 0, -50244, 2022, 0, 0, 39, '2021'),
	(377, 1, 0, -50244, 2023, 0, 0, 39, '2022'),
	(377, 1, 0, -50244, 2024, 0, 0, 39, '2023'),
	(377, 1, 0, -50244, 2025, 0, 0, 39, '2024'),
	(377, 1, 0, -50244, 2026, 0, 0, 39, '2025'),
	(377, 1, 0, -50244, 2027, 0, 0, 39, '2026'),
	(377, 1, 0, -50244, 2028, 0, 0, 39, '2027'),
	(377, 1, 0, -50244, 2029, 0, 0, 39, '2028'),
	(377, 1, 0, -50244, 2030, 0, 0, 39, '2029'),
	(377, 1, 0, -50244, 2031, 0, 0, 39, '2030'),
	(377, 1, 0, -50244, 2032, 0, 0, 39, '2031'),
	(377, 1, 0, -50244, 2033, 0, 0, 39, '2032'),
	(377, 1, 0, -50244, 2034, 0, 0, 39, '2033'),
	(377, 1, 0, -50244, 2035, 0, 0, 39, '2034'),
	(377, 1, 0, -50244, 2036, 0, 0, 39, '2035'),
	(377, 1, 0, -50244, 2037, 0, 0, 39, '2036'),
	(377, 1, 0, -50244, 2038, 0, 0, 39, '2037'),
	(377, 1, 0, -50244, 2039, 0, 0, 39, '2038'),
	(377, 1, 0, -50244, 2040, 0, 0, 39, '2039'),
	(377, 1, 0, -50244, 2041, 0, 0, 39, '2040'),
	(377, 1, 0, -50244, 2042, 0, 0, 39, '2041'),
	(377, 1, 0, -50244, 2043, 0, 0, 39, '2042'),
	(377, 1, 0, -50244, 2044, 0, 0, 39, '2043'),
	(377, 1, 0, -50244, 2045, 0, 0, 39, '2044'),
	(377, 1, 0, -50244, 2046, 0, 0, 39, '2045'),
	(377, 1, 0, -50244, 2047, 0, 0, 39, '2046'),
	(377, 1, 0, -50244, 2048, 0, 0, 39, '2047'),
	(377, 1, 0, -50244, 2049, 0, 0, 39, '2048'),
	(377, 1, 0, -50244, 2050, 0, 0, 39, '2049'),
	(377, 1, 0, -50244, 2051, 0, 0, 39, '2050'),
	(377, 1, 0, -50244, 2052, 0, 0, 39, '2051'),
	(377, 1, 0, -50244, 2053, 0, 0, 39, '2052'),
	(377, 1, 0, -50244, 2054, 0, 0, 39, '2053'),
	(377, 1, 0, -50244, 2055, 0, 0, 39, '2054'),
	(377, 1, 0, -50244, 2056, 0, 0, 39, '2055'),
	(377, 1, 0, -50244, 2057, 0, 0, 39, '2056'),
	(377, 1, 0, -50244, 2058, 0, 0, 39, '2057'),
	(377, 1, 0, -50244, 2059, 0, 0, 39, '2058'),
	(377, 1, 0, -50244, 2060, 0, 0, 39, '2059'),
	(377, 1, 0, -50244, 2061, 0, 0, 39, '2060'),
	(377, 1, 0, -50244, 2062, 0, 0, 39, '2061'),
	(377, 1, 0, -50244, 2063, 0, 0, 39, '2062'),
	(377, 1, 0, -50244, 2064, 0, 0, 39, '2063'),
	(377, 1, 0, -50244, 2065, 0, 0, 39, '2064'),
	(377, 1, 0, -50244, 2066, 0, 0, 39, '2065'),
	(377, 1, 0, -50244, 2067, 0, 0, 39, '2066'),
	(377, 1, 0, -50244, 2068, 0, 0, 39, '2067'),
	(377, 1, 0, -50244, 2069, 0, 0, 39, '2068'),
	(377, 1, 0, -50244, 2070, 0, 0, 39, '2069'),
	(377, 1, 0, -50244, 2071, 0, 0, 39, '2070'),
	(377, 1, 0, -50244, 2072, 0, 0, 39, '2071'),
	(377, 1, 0, -50244, 2073, 0, 0, 39, '2072'),
	(377, 1, 0, -50244, 2074, 0, 0, 39, '2073'),
	(377, 1, 0, -50244, 2075, 0, 0, 39, '2074'),
	(377, 1, 0, -50244, 2076, 0, 0, 39, '2075'),
	(377, 1, 0, -50244, 2077, 0, 0, 39, '2076'),
	(377, 1, 0, -50244, 2078, 0, 0, 39, '2077'),
	(377, 1, 0, -50244, 2079, 0, 0, 39, '2078'),
	(377, 1, 0, -50244, 2080, 0, 0, 39, '2079'),
	(377, 1, 0, -50244, 2081, 0, 0, 39, '2080'),
	(377, 1, 0, -50244, 2082, 0, 0, 39, '2081'),
	(377, 1, 0, -50244, 2083, 0, 0, 39, '2082'),
	(377, 1, 0, -50244, 2084, 0, 0, 39, '2083'),
	(377, 1, 0, -50244, 2085, 0, 0, 39, '2084'),
	(377, 1, 0, -50244, 2086, 0, 0, 39, '2085'),
	(377, 1, 0, -50244, 2087, 0, 0, 39, '2086'),
	(377, 1, 0, -50244, 2088, 0, 0, 39, '2087'),
	(377, 1, 0, -50244, 2089, 0, 0, 39, '2088'),
	(377, 1, 0, -50244, 2090, 0, 0, 39, '2089'),
	(377, 1, 0, -50244, 2091, 0, 0, 39, '2090'),
	(377, 1, 0, -50244, 2092, 0, 0, 39, '2091'),
	(377, 1, 0, -50244, 2093, 0, 0, 39, '2092'),
	(377, 1, 0, -50244, 2094, 0, 0, 39, '2093'),
	(377, 1, 0, -50244, 2095, 0, 0, 39, '2094'),
	(377, 1, 0, -50244, 2096, 0, 0, 39, '2095'),
	(377, 1, 0, -50244, 2097, 0, 0, 39, '2096'),
	(377, 1, 0, -50244, 2098, 0, 0, 39, '2097'),
	(377, 1, 0, -50244, 2099, 0, 0, 39, '2098'),
	(377, 1, 0, -50244, 2100, 0, 0, 39, '2099'),
	(377, 1, 0, -50244, 2101, 0, 0, 39, '2100'),
	(377, 1, 0, -50244, 2102, 0, 0, 39, '2101'),
	(377, 1, 0, -50244, 2103, 0, 0, 39, '2102'),
	(377, 1, 0, -50244, 2104, 0, 0, 39, '2103'),
	(377, 1, 0, -50244, 2105, 0, 0, 39, '2104'),
	(377, 1, 0, -50244, 2106, 0, 0, 39, '2105'),
	(377, 1, 0, -50244, 2107, 0, 0, 39, '2106'),
	(377, 1, 0, -50244, 2108, 0, 0, 39, '2107'),
	(377, 1, 0, -50244, 2109, 0, 0, 39, '2108'),
	(377, 1, 0, -50244, 2110, 0, 0, 39, '2109'),
	(377, 1, 0, -50244, 2111, 0, 0, 39, '2110'),
	(377, 1, 0, -50244, 2112, 0, 0, 39, '2111'),
	(377, 1, 0, -50244, 2113, 0, 0, 39, '2112'),
	(377, 1, 0, -50244, 2114, 0, 0, 39, '2113'),
	(377, 1, 0, -50244, 2115, 0, 0, 39, '2114'),
	(377, 1, 0, -50244, 2116, 0, 0, 39, '2115'),
	(377, 1, 0, -50244, 2117, 0, 0, 39, '2116'),
	(377, 1, 0, -50244, 2118, 0, 0, 39, '2117'),
	(377, 1, 0, -50244, 2119, 0, 0, 39, '2118'),
	(377, 1, 0, -50244, 2120, 0, 0, 39, '2119'),
	(377, 1, 0, -50244, 2121, 0, 0, 39, '2120'),
	(377, 1, 0, -50244, 2122, 0, 0, 39, '2121'),
	(377, 1, 0, -50244, 2123, 0, 0, 39, '2122'),
	(377, 1, 0, -50244, 2124, 0, 0, 39, '2123'),
	(377, 1, 0, -50244, 2125, 0, 0, 39, '2124'),
	(377, 1, 0, -50244, 2126, 0, 0, 39, '2125'),
	(377, 1, 0, -50244, 2127, 0, 0, 39, '2126'),
	(377, 1, 0, -50244, 2128, 0, 0, 39, '2127'),
	(377, 1, 0, -50244, 2129, 0, 0, 39, '2128'),
	(377, 1, 0, -50244, 2130, 0, 0, 39, '2129'),
	(377, 1, 0, -50244, 2131, 0, 0, 39, '2130'),
	(377, 1, 0, -50244, 2132, 0, 0, 39, '2131'),
	(377, 1, 0, -50244, 2133, 0, 0, 39, '2132'),
	(377, 1, 0, -50244, 2134, 0, 0, 39, '2133'),
	(377, 1, 0, -50244, 2135, 0, 0, 39, '2134'),
	(377, 1, 0, -50244, 2136, 0, 0, 39, '2135'),
	(377, 1, 0, -50244, 2137, 0, 0, 39, '2136'),
	(377, 1, 0, -50244, 2138, 0, 0, 39, '2137'),
	(377, 1, 0, -50244, 2139, 0, 0, 39, '2138'),
	(377, 1, 0, -50244, 2140, 0, 0, 39, '2139'),
	(377, 1, 0, -50244, 2141, 0, 0, 39, '2140'),
	(377, 1, 0, -50244, 2142, 0, 0, 39, '2141'),
	(377, 1, 0, -50244, 2143, 0, 0, 39, '2142'),
	(377, 1, 0, -50244, 2144, 0, 0, 39, '2143'),
	(377, 1, 0, -50244, 2145, 0, 0, 39, '2144'),
	(377, 1, 0, -50244, 2146, 0, 0, 39, '2145'),
	(377, 1, 0, -50244, 2147, 0, 0, 39, '2146'),
	(377, 1, 0, -50244, 2148, 0, 0, 39, '2147'),
	(377, 1, 0, -50244, 2149, 0, 0, 39, '2148'),
	(377, 1, 0, -50244, 2150, 0, 0, 39, '2149'),
	(377, 1, 0, -50244, 2151, 0, 0, 39, '2150'),
	(377, 1, 0, -50244, 2152, 0, 0, 39, '2151'),
	(377, 1, 0, -50244, 2153, 0, 0, 39, '2152'),
	(377, 1, 0, -50244, 2154, 0, 0, 39, '2153'),
	(377, 1, 0, -50244, 2155, 0, 0, 39, '2154'),
	(377, 1, 0, -50244, 2156, 0, 0, 39, '2155'),
	(377, 1, 0, -50244, 2157, 0, 0, 39, '2156'),
	(377, 1, 0, -50244, 2158, 0, 0, 39, '2157'),
	(377, 1, 0, -50244, 2159, 0, 0, 39, '2158'),
	(377, 1, 0, -50244, 2160, 0, 0, 39, '2159'),
	(377, 1, 0, -50244, 2161, 0, 0, 39, '2160'),
	(377, 1, 0, -50244, 2162, 0, 0, 39, '2161'),
	(377, 1, 0, -50244, 2163, 0, 0, 39, '2162'),
	(377, 1, 0, -50244, 2164, 0, 0, 39, '2163'),
	(377, 1, 0, -50244, 2165, 0, 0, 39, '2164'),
	(377, 1, 0, -50244, 2166, 0, 0, 39, '2165'),
	(377, 1, 0, -50244, 2167, 0, 0, 39, '2166'),
	(377, 1, 0, -50244, 2168, 0, 0, 39, '2167'),
	(377, 1, 0, -50244, 2169, 0, 0, 39, '2168'),
	(377, 1, 0, -50244, 2170, 0, 0, 39, '2169'),
	(377, 1, 0, -50244, 2171, 0, 0, 39, '2170'),
	(377, 1, 0, -50244, 2172, 0, 0, 39, '2171'),
	(377, 1, 0, -50244, 2173, 0, 0, 39, '2172'),
	(377, 1, 0, -50244, 2174, 0, 0, 39, '2173'),
	(377, 1, 0, -50244, 2175, 0, 0, 39, '2174'),
	(377, 1, 0, -50244, 2176, 0, 0, 39, '2175'),
	(377, 1, 0, -50244, 2177, 0, 0, 39, '2176'),
	(377, 1, 0, -50244, 2178, 0, 0, 39, '2177'),
	(377, 1, 0, -50244, 2179, 0, 0, 39, '2178'),
	(377, 1, 0, -50244, 2180, 0, 0, 39, '2179'),
	(377, 1, 0, -50244, 2181, 0, 0, 39, '2180'),
	(377, 1, 0, -50244, 2182, 0, 0, 39, '2181'),
	(377, 1, 0, -50244, 2183, 0, 0, 39, '2182'),
	(377, 1, 0, -50244, 2184, 0, 0, 39, '2183'),
	(377, 1, 0, -50244, 2185, 0, 0, 39, '2184'),
	(377, 1, 0, -50244, 2186, 0, 0, 39, '2185'),
	(377, 1, 0, -50244, 2187, 0, 0, 39, '2186'),
	(377, 1, 0, -50244, 2188, 0, 0, 39, '2187'),
	(377, 1, 0, -50244, 2189, 0, 0, 39, '2188'),
	(377, 1, 0, -50244, 2190, 0, 0, 39, '2189'),
	(377, 1, 0, -50244, 2191, 0, 0, 39, '2190'),
	(377, 1, 0, -50244, 2192, 0, 0, 39, '2191'),
	(377, 1, 0, -50244, 2193, 0, 0, 39, '2192'),
	(377, 1, 0, -50244, 2194, 0, 0, 39, '2193'),
	(377, 1, 0, -50244, 2195, 0, 0, 39, '2194'),
	(377, 1, 0, -50244, 2196, 0, 0, 39, '2195'),
	(377, 1, 0, -50244, 2197, 0, 0, 39, '2196'),
	(377, 1, 0, -50244, 2198, 0, 0, 39, '2197'),
	(377, 1, 0, -50244, 2199, 0, 0, 39, '2198'),
	(377, 1, 0, -50244, 2200, 0, 0, 39, '2199'),
	(377, 1, 0, -50244, 2201, 0, 0, 39, '2200'),
	(377, 1, 0, -50244, 2202, 0, 0, 39, '2201'),
	(377, 1, 0, -50244, 2203, 0, 0, 39, '2202'),
	(377, 1, 0, -50244, 2204, 0, 0, 39, '2203'),
	(377, 1, 0, -50244, 2205, 0, 0, 39, '2204'),
	(377, 1, 0, -50244, 2206, 0, 0, 39, '2205'),
	(377, 1, 0, -50244, 2207, 0, 0, 39, '2206'),
	(377, 1, 0, -50244, 2208, 0, 0, 39, '2207'),
	(377, 1, 0, -50244, 2209, 0, 0, 39, '2208'),
	(377, 1, 0, -50244, 2210, 0, 0, 39, '2209'),
	(377, 1, 0, -50244, 2211, 0, 0, 39, '2210'),
	(377, 1, 0, -50244, 2212, 0, 0, 39, '2211'),
	(377, 1, 0, -50244, 2213, 0, 0, 39, '2212'),
	(377, 1, 0, -50244, 2214, 0, 0, 39, '2213'),
	(377, 1, 0, -50244, 2215, 0, 0, 39, '2214'),
	(377, 1, 0, -50244, 2216, 0, 0, 39, '2215'),
	(377, 1, 0, -50244, 2217, 0, 0, 39, '2216'),
	(377, 1, 0, -50244, 2218, 0, 0, 39, '2217'),
	(377, 1, 0, -50244, 2219, 0, 0, 39, '2218'),
	(377, 1, 0, -50244, 2220, 0, 0, 39, '2219'),
	(377, 1, 0, -50244, 2221, 0, 0, 39, '2220'),
	(377, 1, 0, -50244, 2222, 0, 0, 39, '2221'),
	(377, 1, 0, -50244, 2223, 0, 0, 39, '2222'),
	(377, 1, 0, -50244, 2224, 0, 0, 39, '2223'),
	(377, 1, 0, -50244, 2225, 0, 0, 39, '2224'),
	(377, 1, 0, -50244, 2226, 0, 0, 39, '2225'),
	(377, 1, 0, -50244, 2227, 0, 0, 39, '2226'),
	(377, 1, 0, -50244, 2228, 0, 0, 39, '2227'),
	(377, 1, 0, -50244, 2229, 0, 0, 39, '2228'),
	(377, 1, 0, -50244, 2230, 0, 0, 39, '2229'),
	(377, 1, 0, -50244, 2231, 0, 0, 39, '2230'),
	(377, 1, 0, -50244, 2232, 0, 0, 39, '2231'),
	(377, 1, 0, -50244, 2233, 0, 0, 39, '2232'),
	(377, 1, 0, -50244, 2234, 0, 0, 39, '2233'),
	(377, 1, 0, -50244, 2235, 0, 0, 39, '2234'),
	(377, 1, 0, -50244, 2236, 0, 0, 39, '2235'),
	(377, 1, 0, -50244, 2237, 0, 0, 39, '2236'),
	(377, 1, 0, -50244, 2238, 0, 0, 39, '2237'),
	(377, 1, 0, -50244, 2239, 0, 0, 39, '2238'),
	(377, 1, 0, -50244, 2240, 0, 0, 39, '2239'),
	(377, 1, 0, -50244, 2241, 0, 0, 39, '2240'),
	(377, 1, 0, -50244, 2242, 0, 0, 39, '2241'),
	(377, 1, 0, -50244, 2243, 0, 0, 39, '2242'),
	(377, 1, 0, -50244, 2244, 0, 0, 39, '2243'),
	(377, 1, 0, -50244, 2245, 0, 0, 39, '2244'),
	(377, 1, 0, -50244, 2246, 0, 0, 39, '2245'),
	(377, 1, 0, -50244, 2247, 0, 0, 39, '2246'),
	(377, 1, 0, -50244, 2248, 0, 0, 39, '2247'),
	(377, 1, 0, -50244, 2249, 0, 0, 39, '2248'),
	(377, 1, 0, -50244, 2250, 0, 0, 39, '2249'),
	(377, 1, 0, -50244, 2251, 0, 0, 39, '2250'),
	(377, 1, 0, -50244, 2252, 0, 0, 39, '2251'),
	(377, 1, 0, -50244, 2253, 0, 0, 39, '2252'),
	(377, 1, 0, -50244, 2254, 0, 0, 39, '2253'),
	(377, 1, 0, -50244, 2255, 0, 0, 39, '2254'),
	(377, 1, 0, -50244, 2256, 0, 0, 39, '2255'),
	(377, 1, 0, -50244, 2257, 0, 0, 39, '2256'),
	(377, 1, 0, -50244, 2258, 0, 0, 39, '2257'),
	(377, 1, 0, -50244, 2259, 0, 0, 39, '2258'),
	(377, 1, 0, -50244, 2260, 0, 0, 39, '2259'),
	(377, 1, 0, -50244, 2261, 0, 0, 39, '2260'),
	(377, 1, 0, -50244, 2262, 0, 0, 39, '2261'),
	(377, 1, 0, -50244, 2263, 0, 0, 39, '2262'),
	(377, 1, 0, -50244, 2264, 0, 0, 39, '2263'),
	(377, 1, 0, -50244, 2265, 0, 0, 39, '2264'),
	(377, 1, 0, -50244, 2266, 0, 0, 39, '2265'),
	(377, 1, 0, -50244, 2267, 0, 0, 39, '2266'),
	(377, 1, 0, -50244, 2268, 0, 0, 39, '2267'),
	(377, 1, 0, -50244, 2269, 0, 0, 39, '2268'),
	(377, 1, 0, -50244, 2270, 0, 0, 39, '2269'),
	(377, 1, 0, -50244, 2271, 0, 0, 39, '2270'),
	(377, 1, 0, -50244, 2272, 0, 0, 39, '2271'),
	(377, 1, 0, -50244, 2273, 0, 0, 39, '2272'),
	(377, 1, 0, -50244, 2274, 0, 0, 39, '2273'),
	(377, 1, 0, -50244, 2275, 0, 0, 39, '2274'),
	(377, 1, 0, -50244, 2276, 0, 0, 39, '2275'),
	(377, 1, 0, -50244, 2277, 0, 0, 39, '2276'),
	(377, 1, 0, -50244, 2278, 0, 0, 39, '2277'),
	(377, 1, 0, -50244, 2279, 0, 0, 39, '2278'),
	(377, 1, 0, -50244, 2280, 0, 0, 39, '2279'),
	(377, 1, 0, -50244, 2281, 0, 0, 39, '2280'),
	(377, 1, 0, -50244, 2282, 0, 0, 39, '2281'),
	(377, 1, 0, -50244, 2283, 0, 0, 39, '2282'),
	(377, 1, 0, -50244, 2284, 0, 0, 39, '2283'),
	(377, 1, 0, -50244, 2285, 0, 0, 39, '2284'),
	(377, 1, 0, -50244, 2286, 0, 0, 39, '2285'),
	(377, 1, 0, -50244, 2287, 0, 0, 39, '2286'),
	(377, 1, 0, -50244, 2288, 0, 0, 39, '2287'),
	(377, 1, 0, -50244, 2289, 0, 0, 39, '2288'),
	(377, 1, 0, -50244, 2290, 0, 0, 39, '2289'),
	(377, 1, 0, -50244, 2291, 0, 0, 39, '2290'),
	(377, 1, 0, -50244, 2292, 0, 0, 39, '2291'),
	(377, 1, 0, -50244, 2293, 0, 0, 39, '2292'),
	(377, 1, 0, -50244, 2294, 0, 0, 39, '2293'),
	(377, 1, 0, -50244, 2295, 0, 0, 39, '2294'),
	(377, 1, 0, -50244, 2296, 0, 0, 39, '2295'),
	(377, 1, 0, -50244, 2297, 0, 0, 39, '2296'),
	(377, 1, 0, -50244, 2298, 0, 0, 39, '2297'),
	(377, 1, 0, -50244, 2299, 0, 0, 39, '2298'),
	(377, 1, 0, -50244, 2300, 0, 0, 39, '2299'),
	(377, 1, 0, -50244, 2301, 0, 0, 39, '2300'),
	(377, 1, 0, -50244, 2302, 0, 0, 39, '2301'),
	(377, 1, 0, -50244, 2303, 0, 0, 39, '2302'),
	(377, 1, 0, -50244, 2304, 0, 0, 39, '2303'),
	(377, 1, 0, -50244, 2305, 0, 0, 39, '2304'),
	(377, 1, 0, -50244, 2306, 0, 0, 39, '2305'),
	(377, 1, 0, -50244, 2307, 0, 0, 39, '2306'),
	(377, 1, 0, -50244, 2308, 0, 0, 39, '2307'),
	(377, 1, 0, -50244, 2309, 0, 0, 39, '2308'),
	(377, 1, 0, -50244, 2310, 0, 0, 39, '2309'),
	(377, 1, 0, -50244, 2311, 0, 0, 39, '2310'),
	(377, 1, 0, -50244, 2312, 0, 0, 39, '2311'),
	(377, 1, 0, -50244, 2313, 0, 0, 39, '2312'),
	(377, 1, 0, -50244, 2314, 0, 0, 39, '2313'),
	(377, 1, 0, -50244, 2315, 0, 0, 39, '2314'),
	(377, 1, 0, -50244, 2316, 0, 0, 39, '2315'),
	(377, 1, 0, -50244, 2317, 0, 0, 39, '2316'),
	(377, 1, 0, -50244, 2318, 0, 0, 39, '2317'),
	(377, 1, 0, -50244, 2319, 0, 0, 39, '2318'),
	(377, 1, 0, -50244, 2320, 0, 0, 39, '2319'),
	(377, 1, 0, -50244, 2321, 0, 0, 39, '2320'),
	(377, 1, 0, -50244, 2322, 0, 0, 39, '2321'),
	(377, 1, 0, -50244, 2323, 0, 0, 39, '2322'),
	(377, 1, 0, -50244, 2324, 0, 0, 39, '2323'),
	(377, 1, 0, -50244, 2325, 0, 0, 39, '2324'),
	(377, 1, 0, -50244, 2326, 0, 0, 39, '2325'),
	(377, 1, 0, -50244, 2327, 0, 0, 39, '2326'),
	(377, 1, 0, -50244, 2328, 0, 0, 39, '2327'),
	(377, 1, 0, -50244, 2329, 0, 0, 39, '2328'),
	(377, 1, 0, -50244, 2330, 0, 0, 39, '2329'),
	(377, 1, 0, -50244, 2331, 0, 0, 39, '2330'),
	(377, 1, 0, -50244, 2332, 0, 0, 39, '2331'),
	(377, 1, 0, -50244, 2333, 0, 0, 39, '2332'),
	(377, 1, 0, -50244, 2334, 0, 0, 39, '2333'),
	(377, 1, 0, -50244, 2335, 0, 0, 39, '2334'),
	(377, 1, 0, -50244, 2336, 0, 0, 39, '2335'),
	(377, 1, 0, -50244, 2337, 0, 0, 39, '2336'),
	(377, 1, 0, -50244, 2338, 0, 0, 39, '2337'),
	(377, 1, 0, -50244, 2339, 0, 0, 39, '2338'),
	(377, 1, 0, -50244, 2340, 0, 0, 39, '2339'),
	(377, 1, 0, -50244, 2341, 0, 0, 39, '2340'),
	(377, 1, 0, -50244, 2342, 0, 0, 39, '2341'),
	(377, 1, 0, -50244, 2343, 0, 0, 39, '2342'),
	(377, 1, 0, -50244, 2344, 0, 0, 39, '2343'),
	(377, 1, 0, -50244, 2345, 0, 0, 39, '2344'),
	(377, 1, 0, -50244, 2346, 0, 0, 39, '2345'),
	(377, 1, 0, -50244, 2347, 0, 0, 39, '2346'),
	(377, 1, 0, -50244, 2348, 0, 0, 39, '2347'),
	(377, 1, 0, -50244, 2349, 0, 0, 39, '2348'),
	(377, 1, 0, -50244, 2350, 0, 0, 39, '2349'),
	(377, 1, 0, -50244, 2351, 0, 0, 39, '2350'),
	(377, 1, 0, -50244, 2352, 0, 0, 39, '2351'),
	(377, 1, 0, -50244, 2353, 0, 0, 39, '2352'),
	(377, 1, 0, -50244, 2354, 0, 0, 39, '2353'),
	(377, 1, 0, -50244, 2355, 0, 0, 39, '2354'),
	(377, 1, 0, -50244, 2356, 0, 0, 39, '2355'),
	(377, 1, 0, -50244, 2357, 0, 0, 39, '2356'),
	(377, 1, 0, -50244, 2358, 0, 0, 39, '2357'),
	(377, 1, 0, -50244, 2359, 0, 0, 39, '2358'),
	(377, 1, 0, -50244, 2360, 0, 0, 39, '2359'),
	(377, 1, 0, -50244, 2361, 0, 0, 39, '2360'),
	(377, 1, 0, -50244, 2362, 0, 0, 39, '2361'),
	(377, 1, 0, -50244, 2363, 0, 0, 39, '2362'),
	(377, 1, 0, -50244, 2364, 0, 0, 39, '2363'),
	(377, 1, 0, -50244, 2365, 0, 0, 39, '2364'),
	(377, 1, 0, -50244, 2366, 0, 0, 39, '2365'),
	(377, 1, 0, -50244, 2367, 0, 0, 39, '2366'),
	(377, 1, 0, -50244, 2368, 0, 0, 39, '2367'),
	(377, 1, 0, -50244, 2369, 0, 0, 39, '2368'),
	(377, 1, 0, -50244, 2370, 0, 0, 39, '2369'),
	(377, 1, 0, -50244, 2371, 0, 0, 39, '2370'),
	(377, 1, 0, -50244, 2372, 0, 0, 39, '2371'),
	(377, 1, 0, -50244, 2373, 0, 0, 39, '2372'),
	(377, 1, 0, -50244, 2374, 0, 0, 39, '2373'),
	(377, 1, 0, -50244, 2375, 0, 0, 39, '2374'),
	(377, 1, 0, -50244, 2376, 0, 0, 39, '2375'),
	(377, 1, 0, -50244, 2377, 0, 0, 39, '2376'),
	(377, 1, 0, -50244, 2378, 0, 0, 39, '2377'),
	(377, 1, 0, -50244, 2379, 0, 0, 39, '2378'),
	(377, 1, 0, -50244, 2380, 0, 0, 39, '2379'),
	(377, 1, 0, -50244, 2381, 0, 0, 39, '2380'),
	(377, 1, 0, -50244, 2382, 0, 0, 39, '2381'),
	(377, 1, 0, -50244, 2383, 0, 0, 39, '2382'),
	(377, 1, 0, -50244, 2384, 0, 0, 39, '2383'),
	(377, 1, 0, -50244, 2385, 0, 0, 39, '2384'),
	(377, 1, 0, -50244, 2386, 0, 0, 39, '2385'),
	(377, 1, 0, -50244, 2387, 0, 0, 39, '2386'),
	(377, 1, 0, -50244, 2388, 0, 0, 39, '2387'),
	(377, 1, 0, -50244, 2389, 0, 0, 39, '2388'),
	(377, 1, 0, -50244, 2390, 0, 0, 39, '2389'),
	(377, 1, 0, -50244, 2391, 0, 0, 39, '2390'),
	(377, 1, 0, -50244, 2392, 0, 0, 39, '2391'),
	(377, 1, 0, -50244, 2393, 0, 0, 39, '2392'),
	(377, 1, 0, -50244, 2394, 0, 0, 39, '2393'),
	(377, 1, 0, -50244, 2395, 0, 0, 39, '2394'),
	(377, 1, 0, -50244, 2396, 0, 0, 39, '2395'),
	(377, 1, 0, -50244, 2397, 0, 0, 39, '2396'),
	(377, 1, 0, -50244, 2398, 0, 0, 39, '2397'),
	(377, 1, 0, -50244, 2399, 0, 0, 39, '2398'),
	(377, 1, 0, -50244, 2400, 0, 0, 39, '2399'),
	(377, 1, 0, -50244, 2401, 0, 0, 39, '2400'),
	(377, 1, 0, -50244, 2402, 0, 0, 39, '2401'),
	(377, 1, 0, -50244, 2403, 0, 0, 39, '2402'),
	(377, 1, 0, -50244, 2404, 0, 0, 39, '2403'),
	(377, 1, 0, -50244, 2405, 0, 0, 39, '2404'),
	(377, 1, 0, -50244, 2406, 0, 0, 39, '2405'),
	(377, 1, 0, -50244, 2407, 0, 0, 39, '2406'),
	(377, 1, 0, -50244, 2408, 0, 0, 39, '2407'),
	(377, 1, 0, -50244, 2409, 0, 0, 39, '2408'),
	(377, 1, 0, -50244, 2410, 0, 0, 39, '2409'),
	(377, 1, 0, -50244, 2411, 0, 0, 39, '2410'),
	(377, 1, 0, -50244, 2412, 0, 0, 39, '2411'),
	(377, 1, 0, -50244, 2413, 0, 0, 39, '2412'),
	(377, 1, 0, -50244, 2414, 0, 0, 39, '2413'),
	(377, 1, 0, -50244, 2415, 0, 0, 39, '2414'),
	(377, 1, 0, -50244, 2416, 0, 0, 39, '2415'),
	(377, 1, 0, -50244, 2417, 0, 0, 39, '2416'),
	(377, 1, 0, -50244, 2418, 0, 0, 39, '2417'),
	(377, 1, 0, -50244, 2419, 0, 0, 39, '2418'),
	(377, 1, 0, -50244, 2420, 0, 0, 39, '2419'),
	(377, 1, 0, -50244, 2421, 0, 0, 39, '2420'),
	(377, 1, 0, -50244, 2422, 0, 0, 39, '2421'),
	(377, 1, 0, -50244, 2423, 0, 0, 39, '2422'),
	(377, 1, 0, -50244, 2424, 0, 0, 39, '2423'),
	(377, 1, 0, -50244, 2425, 0, 0, 39, '2424'),
	(377, 1, 0, -50244, 2426, 0, 0, 39, '2425'),
	(377, 1, 0, -50244, 2427, 0, 0, 39, '2426'),
	(377, 1, 0, -50244, 2428, 0, 0, 39, '2427'),
	(377, 1, 0, -50244, 2429, 0, 0, 39, '2428'),
	(377, 1, 0, -50244, 2430, 0, 0, 39, '2429'),
	(377, 1, 0, -50244, 2431, 0, 0, 39, '2430'),
	(377, 1, 0, -50244, 2432, 0, 0, 39, '2431'),
	(377, 1, 0, -50244, 2433, 0, 0, 39, '2432'),
	(377, 1, 0, -50244, 2434, 0, 0, 39, '2433'),
	(377, 1, 0, -50244, 2435, 0, 0, 39, '2434'),
	(377, 1, 0, -50244, 2436, 0, 0, 39, '2435'),
	(377, 1, 0, -50244, 2437, 0, 0, 39, '2436'),
	(377, 1, 0, -50244, 2438, 0, 0, 39, '2437'),
	(377, 1, 0, -50244, 2439, 0, 0, 39, '2438'),
	(377, 1, 0, -50244, 2440, 0, 0, 39, '2439'),
	(377, 1, 0, -50244, 2441, 0, 0, 39, '2440'),
	(377, 1, 0, -50244, 2442, 0, 0, 39, '2441'),
	(377, 1, 0, -50244, 2443, 0, 0, 39, '2442'),
	(377, 1, 0, -50244, 2444, 0, 0, 39, '2443'),
	(377, 1, 0, -50244, 2445, 0, 0, 39, '2444'),
	(377, 1, 0, -50244, 2446, 0, 0, 39, '2445'),
	(377, 1, 0, -50244, 2447, 0, 0, 39, '2446'),
	(377, 1, 0, -50244, 2448, 0, 0, 39, '2447'),
	(377, 1, 0, -50244, 2449, 0, 0, 39, '2448'),
	(377, 1, 0, -50244, 2450, 0, 0, 39, '2449'),
	(377, 1, 0, -50244, 2451, 0, 0, 39, '2450'),
	(377, 1, 0, -50244, 2452, 0, 0, 39, '2451'),
	(377, 1, 0, -50244, 2453, 0, 0, 39, '2452'),
	(377, 1, 0, -50244, 2454, 0, 0, 39, '2453'),
	(377, 1, 0, -50244, 2455, 0, 0, 39, '2454'),
	(377, 1, 0, -50244, 2456, 0, 0, 39, '2455'),
	(377, 1, 0, -50244, 2457, 0, 0, 39, '2456'),
	(377, 1, 0, -50244, 2458, 0, 0, 39, '2457'),
	(377, 1, 0, -50244, 2459, 0, 0, 39, '2458'),
	(377, 1, 0, -50244, 2460, 0, 0, 39, '2459'),
	(377, 1, 0, -50244, 2461, 0, 0, 39, '2460'),
	(377, 1, 0, -50244, 2462, 0, 0, 39, '2461'),
	(377, 1, 0, -50244, 2463, 0, 0, 39, '2462'),
	(377, 1, 0, -50244, 2464, 0, 0, 39, '2463'),
	(377, 1, 0, -50244, 2465, 0, 0, 39, '2464'),
	(377, 1, 0, -50244, 2466, 0, 0, 39, '2465'),
	(377, 1, 0, -50244, 2467, 0, 0, 39, '2466'),
	(377, 1, 0, -50244, 2468, 0, 0, 39, '2467'),
	(377, 1, 0, -50244, 2469, 0, 0, 39, '2468'),
	(377, 1, 0, -50244, 2470, 0, 0, 39, '2469'),
	(377, 1, 0, -50244, 2471, 0, 0, 39, '2470'),
	(377, 1, 0, -50244, 2472, 0, 0, 39, '2471'),
	(377, 1, 0, -50244, 2473, 0, 0, 39, '2472'),
	(377, 1, 0, -50244, 2474, 0, 0, 39, '2473'),
	(377, 1, 0, -50244, 2475, 0, 0, 39, '2474'),
	(377, 1, 0, -50244, 2476, 0, 0, 39, '2475'),
	(377, 1, 0, -50244, 2477, 0, 0, 39, '2476'),
	(377, 1, 0, -50244, 2478, 0, 0, 39, '2477'),
	(377, 1, 0, -50244, 2479, 0, 0, 39, '2478'),
	(377, 1, 0, -50244, 2480, 0, 0, 39, '2479'),
	(377, 1, 0, -50244, 2481, 0, 0, 39, '2480'),
	(377, 1, 0, -50244, 2482, 0, 0, 39, '2481'),
	(377, 1, 0, -50244, 2483, 0, 0, 39, '2482'),
	(377, 1, 0, -50244, 2484, 0, 0, 39, '2483'),
	(377, 1, 0, -50244, 2485, 0, 0, 39, '2484'),
	(377, 1, 0, -50244, 2486, 0, 0, 39, '2485'),
	(377, 1, 0, -50244, 2487, 0, 0, 39, '2486'),
	(377, 1, 0, -50244, 2488, 0, 0, 39, '2487'),
	(377, 1, 0, -50244, 2489, 0, 0, 39, '2488'),
	(377, 1, 0, -50244, 2490, 0, 0, 39, '2489'),
	(377, 1, 0, -50244, 2491, 0, 0, 39, '2490'),
	(377, 1, 0, -50244, 2492, 0, 0, 39, '2491'),
	(377, 1, 0, -50244, 2493, 0, 0, 39, '2492'),
	(377, 1, 0, -50244, 2494, 0, 0, 39, '2493'),
	(377, 1, 0, -50244, 2495, 0, 0, 39, '2494'),
	(377, 1, 0, -50244, 2496, 0, 0, 39, '2495'),
	(377, 1, 0, -50244, 2497, 0, 0, 39, '2496'),
	(377, 1, 0, -50244, 2498, 0, 0, 39, '2497'),
	(377, 1, 0, -50244, 2499, 0, 0, 39, '2498'),
	(377, 1, 0, -50244, 2500, 0, 0, 39, '2499'),
	(377, 1, 0, -50244, 2501, 0, 0, 39, '2500'),
	(377, 1, 0, -50244, 2502, 0, 0, 39, '2501'),
	(377, 1, 0, -50244, 2503, 0, 0, 39, '2502'),
	(377, 1, 0, -50244, 2504, 0, 0, 39, '2503'),
	(377, 1, 0, -50244, 2505, 0, 0, 39, '2504'),
	(377, 1, 0, -50244, 2506, 0, 0, 39, '2505'),
	(377, 1, 0, -50244, 2507, 0, 0, 39, '2506'),
	(377, 1, 0, -50244, 2508, 0, 0, 39, '2507'),
	(377, 1, 0, -50244, 2509, 0, 0, 39, '2508'),
	(377, 1, 0, -50244, 2510, 0, 0, 39, '2509'),
	(377, 1, 0, -50244, 2511, 0, 0, 39, '2510'),
	(377, 1, 0, -50244, 2512, 0, 0, 39, '2511'),
	(377, 1, 0, -50244, 2513, 0, 0, 39, '2512'),
	(377, 1, 0, -50244, 2514, 0, 0, 39, '2513'),
	(377, 1, 0, -50244, 2515, 0, 0, 39, '2514'),
	(377, 1, 0, -50244, 2516, 0, 0, 39, '2515'),
	(377, 1, 0, -50244, 2517, 0, 0, 39, '2516'),
	(377, 1, 0, -50244, 2518, 0, 0, 39, '2517'),
	(377, 1, 0, -50244, 2519, 0, 0, 39, '2518'),
	(377, 1, 0, -50244, 2520, 0, 0, 39, '2519'),
	(377, 1, 0, -50244, 2521, 0, 0, 39, '2520'),
	(377, 1, 0, -50244, 2522, 0, 0, 39, '2521'),
	(377, 1, 0, -50244, 2523, 0, 0, 39, '2522'),
	(377, 1, 0, -50244, 2524, 0, 0, 39, '2523'),
	(377, 1, 0, -50244, 2525, 0, 0, 39, '2524'),
	(377, 1, 0, -50244, 2526, 0, 0, 39, '2525'),
	(377, 1, 0, -50244, 2527, 0, 0, 39, '2526'),
	(377, 1, 0, -50244, 2528, 0, 0, 39, '2527'),
	(377, 1, 0, -50244, 2529, 0, 0, 39, '2528'),
	(377, 1, 0, -50244, 2530, 0, 0, 39, '2529'),
	(377, 1, 0, -50244, 2531, 0, 0, 39, '2530'),
	(377, 1, 0, -50244, 2532, 0, 0, 39, '2531'),
	(377, 1, 0, -50244, 2533, 0, 0, 39, '2532'),
	(377, 1, 0, -50244, 2534, 0, 0, 39, '2533'),
	(377, 1, 0, -50244, 2535, 0, 0, 39, '2534'),
	(377, 1, 0, -50244, 2536, 0, 0, 39, '2535'),
	(377, 1, 0, -50244, 2537, 0, 0, 39, '2536'),
	(377, 1, 0, -50244, 2538, 0, 0, 39, '2537'),
	(377, 1, 0, -50244, 2539, 0, 0, 39, '2538'),
	(377, 1, 0, -50244, 2540, 0, 0, 39, '2539'),
	(377, 1, 0, -50244, 2541, 0, 0, 39, '2540'),
	(377, 1, 0, -50244, 2542, 0, 0, 39, '2541'),
	(377, 1, 0, -50244, 2543, 0, 0, 39, '2542'),
	(377, 1, 0, -50244, 2544, 0, 0, 39, '2543'),
	(377, 1, 0, -50244, 2545, 0, 0, 39, '2544'),
	(377, 1, 0, -50244, 2546, 0, 0, 39, '2545'),
	(377, 1, 0, -50244, 2547, 0, 0, 39, '2546'),
	(377, 1, 0, -50244, 2548, 0, 0, 39, '2547'),
	(377, 1, 0, -50244, 2549, 0, 0, 39, '2548'),
	(377, 1, 0, -50244, 2550, 0, 0, 39, '2549'),
	(377, 1, 0, -50244, 2551, 0, 0, 39, '2550'),
	(377, 1, 0, -50244, 2552, 0, 0, 39, '2551'),
	(377, 1, 0, -50244, 2553, 0, 0, 39, '2552'),
	(377, 1, 0, -50244, 2554, 0, 0, 39, '2553'),
	(377, 1, 0, -50244, 2555, 0, 0, 39, '2554'),
	(377, 1, 0, -50244, 2556, 0, 0, 39, '2555'),
	(377, 1, 0, -50244, 2557, 0, 0, 39, '2556'),
	(377, 1, 0, -50244, 2558, 0, 0, 39, '2557'),
	(377, 1, 0, -50244, 2559, 0, 0, 39, '2558'),
	(377, 1, 0, -50244, 2560, 0, 0, 39, '2559'),
	(377, 1, 0, -50244, 2561, 0, 0, 39, '2560'),
	(377, 1, 0, -50244, 2562, 0, 0, 39, '2561'),
	(377, 1, 0, -50244, 2563, 0, 0, 39, '2562'),
	(377, 1, 0, -50244, 2564, 0, 0, 39, '2563'),
	(377, 1, 0, -50244, 2565, 0, 0, 39, '2564'),
	(377, 1, 0, -50244, 2566, 0, 0, 39, '2565'),
	(377, 1, 0, -50244, 2567, 0, 0, 39, '2566'),
	(377, 1, 0, -50244, 2568, 0, 0, 39, '2567'),
	(377, 1, 0, -50244, 2569, 0, 0, 39, '2568'),
	(377, 1, 0, -50244, 2570, 0, 0, 39, '2569'),
	(377, 1, 0, -50244, 2571, 0, 0, 39, '2570'),
	(377, 1, 0, -50244, 2572, 0, 0, 39, '2571'),
	(377, 1, 0, -50244, 2573, 0, 0, 39, '2572'),
	(377, 1, 0, -50244, 2574, 0, 0, 39, '2573'),
	(377, 1, 0, -50244, 2575, 0, 0, 39, '2574'),
	(377, 1, 0, -50244, 2576, 0, 0, 39, '2575'),
	(377, 1, 0, -50244, 2577, 0, 0, 39, '2576'),
	(377, 1, 0, -50244, 2578, 0, 0, 39, '2577'),
	(377, 1, 0, -50244, 2579, 0, 0, 39, '2578'),
	(377, 1, 0, -50244, 2580, 0, 0, 39, '2579'),
	(377, 1, 0, -50244, 2581, 0, 0, 39, '2580'),
	(377, 1, 0, -50244, 2582, 0, 0, 39, '2581'),
	(377, 1, 0, -50244, 2583, 0, 0, 39, '2582'),
	(377, 1, 0, -50244, 2584, 0, 0, 39, '2583'),
	(377, 1, 0, -50244, 2585, 0, 0, 39, '2584'),
	(377, 1, 0, -50244, 2586, 0, 0, 39, '2585'),
	(377, 1, 0, -50244, 2587, 0, 0, 39, '2586'),
	(377, 1, 0, -50244, 2588, 0, 0, 39, '2587'),
	(377, 1, 0, -50244, 2589, 0, 0, 39, '2588'),
	(377, 1, 0, -50244, 2590, 0, 0, 39, '2589'),
	(377, 1, 0, -50244, 2591, 0, 0, 39, '2590'),
	(377, 1, 0, -50244, 2592, 0, 0, 39, '2591'),
	(377, 1, 0, -50244, 2593, 0, 0, 39, '2592'),
	(377, 1, 0, -50244, 2594, 0, 0, 39, '2593'),
	(377, 1, 0, -50244, 2595, 0, 0, 39, '2594'),
	(377, 1, 0, -50244, 2596, 0, 0, 39, '2595'),
	(377, 1, 0, -50244, 2597, 0, 0, 39, '2596'),
	(377, 1, 0, -50244, 2598, 0, 0, 39, '2597'),
	(377, 1, 0, -50244, 2599, 0, 0, 39, '2598'),
	(377, 1, 0, -50244, 2600, 0, 0, 39, '2599'),
	(377, 1, 0, -50244, 2601, 0, 0, 39, '2600'),
	(377, 1, 0, -50244, 2602, 0, 0, 39, '2601'),
	(377, 1, 0, -50244, 2603, 0, 0, 39, '2602'),
	(377, 1, 0, -50244, 2604, 0, 0, 39, '2603'),
	(377, 1, 0, -50244, 2605, 0, 0, 39, '2604'),
	(377, 1, 0, -50244, 2606, 0, 0, 39, '2605'),
	(377, 1, 0, -50244, 2607, 0, 0, 39, '2606'),
	(377, 1, 0, -50244, 2608, 0, 0, 39, '2607'),
	(377, 1, 0, -50244, 2609, 0, 0, 39, '2608'),
	(377, 1, 0, -50244, 2610, 0, 0, 39, '2609'),
	(377, 1, 0, -50244, 2611, 0, 0, 39, '2610'),
	(377, 1, 0, -50244, 2612, 0, 0, 39, '2611'),
	(377, 1, 0, -50244, 2613, 0, 0, 39, '2612'),
	(377, 1, 0, -50244, 2614, 0, 0, 39, '2613'),
	(377, 1, 0, -50244, 2615, 0, 0, 39, '2614'),
	(377, 1, 0, -50244, 2616, 0, 0, 39, '2615'),
	(377, 1, 0, -50244, 2617, 0, 0, 39, '2616'),
	(377, 1, 0, -50244, 2618, 0, 0, 39, '2617'),
	(377, 1, 0, -50244, 2619, 0, 0, 39, '2618'),
	(377, 1, 0, -50244, 2620, 0, 0, 39, '2619'),
	(377, 1, 0, -50244, 2621, 0, 0, 39, '2620'),
	(377, 1, 0, -50244, 2622, 0, 0, 39, '2621'),
	(377, 1, 0, -50244, 2623, 0, 0, 39, '2622'),
	(377, 1, 0, -50244, 2624, 0, 0, 39, '2623'),
	(377, 1, 0, -50244, 2625, 0, 0, 39, '2624'),
	(377, 1, 0, -50244, 2626, 0, 0, 39, '2625'),
	(377, 1, 0, -50244, 2627, 0, 0, 39, '2626'),
	(377, 1, 0, -50244, 2628, 0, 0, 39, '2627'),
	(377, 1, 0, -50244, 2629, 0, 0, 39, '2628'),
	(377, 1, 0, -50244, 2630, 0, 0, 39, '2629'),
	(377, 1, 0, -50244, 2631, 0, 0, 39, '2630'),
	(377, 1, 0, -50244, 2632, 0, 0, 39, '2631'),
	(377, 1, 0, -50244, 2633, 0, 0, 39, '2632'),
	(377, 1, 0, -50244, 2634, 0, 0, 39, '2633'),
	(377, 1, 0, -50244, 2635, 0, 0, 39, '2634'),
	(377, 1, 0, -50244, 2636, 0, 0, 39, '2635'),
	(377, 1, 0, -50244, 2637, 0, 0, 39, '2636'),
	(377, 1, 0, -50244, 2638, 0, 0, 39, '2637'),
	(377, 1, 0, -50244, 2639, 0, 0, 39, '2638'),
	(377, 1, 0, -50244, 2640, 0, 0, 39, '2639'),
	(377, 1, 0, -50244, 2641, 0, 0, 39, '2640'),
	(377, 1, 0, -50244, 2642, 0, 0, 39, '2641'),
	(377, 1, 0, -50244, 2643, 0, 0, 39, '2642'),
	(377, 1, 0, -50244, 2644, 0, 0, 39, '2643'),
	(377, 1, 0, -50244, 2645, 0, 0, 39, '2644'),
	(377, 1, 0, -50244, 2646, 0, 0, 39, '2645'),
	(377, 1, 0, -50244, 2647, 0, 0, 39, '2646'),
	(377, 1, 0, -50244, 2648, 0, 0, 39, '2647'),
	(377, 1, 0, -50244, 2649, 0, 0, 39, '2648'),
	(377, 1, 0, -50244, 2650, 0, 0, 39, '2649'),
	(377, 1, 0, -50244, 2651, 0, 0, 39, '2650'),
	(377, 1, 0, -50244, 2652, 0, 0, 39, '2651'),
	(377, 1, 0, -50244, 2653, 0, 0, 39, '2652'),
	(377, 1, 0, -50244, 2654, 0, 0, 39, '2653'),
	(377, 1, 0, -50244, 2655, 0, 0, 39, '2654'),
	(377, 1, 0, -50244, 2656, 0, 0, 39, '2655'),
	(377, 1, 0, -50244, 2657, 0, 0, 39, '2656'),
	(377, 1, 0, -50244, 2658, 0, 0, 39, '2657'),
	(377, 1, 0, -50244, 2659, 0, 0, 39, '2658'),
	(377, 1, 0, -50244, 2660, 0, 0, 39, '2659'),
	(377, 1, 0, -50244, 2661, 0, 0, 39, '2660'),
	(377, 1, 0, -50244, 2662, 0, 0, 39, '2661'),
	(377, 1, 0, -50244, 2663, 0, 0, 39, '2662'),
	(377, 1, 0, -50244, 2664, 0, 0, 39, '2663'),
	(377, 1, 0, -50244, 2665, 0, 0, 39, '2664'),
	(377, 1, 0, -50244, 2666, 0, 0, 39, '2665'),
	(377, 1, 0, -50244, 2667, 0, 0, 39, '2666'),
	(377, 1, 0, -50244, 2668, 0, 0, 39, '2667'),
	(377, 1, 0, -50244, 2669, 0, 0, 39, '2668'),
	(377, 1, 0, -50244, 2670, 0, 0, 39, '2669'),
	(377, 1, 0, -50244, 2671, 0, 0, 39, '2670'),
	(377, 1, 0, -50244, 2672, 0, 0, 39, '2671'),
	(377, 1, 0, -50244, 2673, 0, 0, 39, '2672'),
	(377, 1, 0, -50244, 2674, 0, 0, 39, '2673'),
	(377, 1, 0, -50244, 2675, 0, 0, 39, '2674'),
	(377, 1, 0, -50244, 2676, 0, 0, 39, '2675'),
	(377, 1, 0, -50244, 2677, 0, 0, 39, '2676'),
	(377, 1, 0, -50244, 2678, 0, 0, 39, '2677'),
	(377, 1, 0, -50244, 2679, 0, 0, 39, '2678'),
	(377, 1, 0, -50244, 2680, 0, 0, 39, '2679'),
	(377, 1, 0, -50244, 2681, 0, 0, 39, '2680'),
	(377, 1, 0, -50244, 2682, 0, 0, 39, '2681'),
	(377, 1, 0, -50244, 2683, 0, 0, 39, '2682'),
	(377, 1, 0, -50244, 2684, 0, 0, 39, '2683'),
	(377, 1, 0, -50244, 2685, 0, 0, 39, '2684'),
	(377, 1, 0, -50244, 2686, 0, 0, 39, '2685'),
	(377, 1, 0, -50244, 2687, 0, 0, 39, '2686'),
	(377, 1, 0, -50244, 2688, 0, 0, 39, '2687'),
	(377, 1, 0, -50244, 2689, 0, 0, 39, '2688'),
	(377, 1, 0, -50244, 2690, 0, 0, 39, '2689'),
	(377, 1, 0, -50244, 2691, 0, 0, 39, '2690'),
	(377, 1, 0, -50244, 2692, 0, 0, 39, '2691'),
	(377, 1, 0, -50244, 2693, 0, 0, 39, '2692'),
	(377, 1, 0, -50244, 2694, 0, 0, 39, '2693'),
	(377, 1, 0, -50244, 2695, 0, 0, 39, '2694'),
	(377, 1, 0, -50244, 2696, 0, 0, 39, '2695'),
	(377, 1, 0, -50244, 2697, 0, 0, 39, '2696'),
	(377, 1, 0, -50244, 2698, 0, 0, 39, '2697'),
	(377, 1, 0, -50244, 2699, 0, 0, 39, '2698'),
	(377, 1, 0, -50244, 2700, 0, 0, 39, '2699'),
	(377, 1, 0, -50244, 2701, 0, 0, 39, '2700'),
	(377, 1, 0, -50244, 2702, 0, 0, 39, '2701'),
	(377, 1, 0, -50244, 2703, 0, 0, 39, '2702'),
	(377, 1, 0, -50244, 2704, 0, 0, 39, '2703'),
	(377, 1, 0, -50244, 2705, 0, 0, 39, '2704'),
	(377, 1, 0, -50244, 2706, 0, 0, 39, '2705'),
	(377, 1, 0, -50244, 2707, 0, 0, 39, '2706'),
	(377, 1, 0, -50244, 2708, 0, 0, 39, '2707'),
	(377, 1, 0, -50244, 2709, 0, 0, 39, '2708'),
	(377, 1, 0, -50244, 2710, 0, 0, 39, '2709'),
	(377, 1, 0, -50244, 2711, 0, 0, 39, '2710'),
	(377, 1, 0, -50244, 2712, 0, 0, 39, '2711'),
	(377, 1, 0, -50244, 2713, 0, 0, 39, '2712'),
	(377, 1, 0, -50244, 2714, 0, 0, 39, '2713'),
	(377, 1, 0, -50244, 2715, 0, 0, 39, '2714'),
	(377, 1, 0, -50244, 2716, 0, 0, 39, '2715'),
	(377, 1, 0, -50244, 2717, 0, 0, 39, '2716'),
	(377, 1, 0, -50244, 2718, 0, 0, 39, '2717'),
	(377, 1, 0, -50244, 2719, 0, 0, 39, '2718'),
	(377, 1, 0, -50244, 2720, 0, 0, 39, '2719'),
	(377, 1, 0, -50244, 2721, 0, 0, 39, '2720'),
	(377, 1, 0, -50244, 2722, 0, 0, 39, '2721'),
	(377, 1, 0, -50244, 2723, 0, 0, 39, '2722'),
	(377, 1, 0, -50244, 2724, 0, 0, 39, '2723'),
	(377, 1, 0, -50244, 2725, 0, 0, 39, '2724'),
	(377, 1, 0, -50244, 2726, 0, 0, 39, '2725'),
	(377, 1, 0, -50244, 2727, 0, 0, 39, '2726'),
	(377, 1, 0, -50244, 2728, 0, 0, 39, '2727'),
	(377, 1, 0, -50244, 2729, 0, 0, 39, '2728'),
	(377, 1, 0, -50244, 2730, 0, 0, 39, '2729'),
	(377, 1, 0, -50244, 2731, 0, 0, 39, '2730'),
	(377, 1, 0, -50244, 2732, 0, 0, 39, '2731'),
	(377, 1, 0, -50244, 2733, 0, 0, 39, '2732'),
	(377, 1, 0, -50244, 2734, 0, 0, 39, '2733'),
	(377, 1, 0, -50244, 2735, 0, 0, 39, '2734'),
	(377, 1, 0, -50244, 2736, 0, 0, 39, '2735'),
	(377, 1, 0, -50244, 2737, 0, 0, 39, '2736'),
	(377, 1, 0, -50244, 2738, 0, 0, 39, '2737'),
	(377, 1, 0, -50244, 2739, 0, 0, 39, '2738'),
	(377, 1, 0, -50244, 2740, 0, 0, 39, '2739'),
	(377, 1, 0, -50244, 2741, 0, 0, 39, '2740'),
	(377, 1, 0, -50244, 2742, 0, 0, 39, '2741'),
	(377, 1, 0, -50244, 2743, 0, 0, 39, '2742'),
	(377, 1, 0, -50244, 2744, 0, 0, 39, '2743'),
	(377, 1, 0, -50244, 2745, 0, 0, 39, '2744'),
	(377, 1, 0, -50244, 2746, 0, 0, 39, '2745'),
	(377, 1, 0, -50244, 2747, 0, 0, 39, '2746'),
	(377, 1, 0, -50244, 2748, 0, 0, 39, '2747'),
	(377, 1, 0, -50244, 2749, 0, 0, 39, '2748'),
	(377, 1, 0, -50244, 2750, 0, 0, 39, '2749'),
	(377, 1, 0, -50244, 2751, 0, 0, 39, '2750'),
	(377, 1, 0, -50244, 2752, 0, 0, 39, '2751'),
	(377, 1, 0, -50244, 2753, 0, 0, 39, '2752'),
	(377, 1, 0, -50244, 2754, 0, 0, 39, '2753'),
	(377, 1, 0, -50244, 2755, 0, 0, 39, '2754'),
	(377, 1, 0, -50244, 2756, 0, 0, 39, '2755'),
	(377, 1, 0, -50244, 2757, 0, 0, 39, '2756'),
	(377, 1, 0, -50244, 2758, 0, 0, 39, '2757'),
	(377, 1, 0, -50244, 2759, 0, 0, 39, '2758'),
	(377, 1, 0, -50244, 2760, 0, 0, 39, '2759'),
	(377, 1, 0, -50244, 2761, 0, 0, 39, '2760'),
	(377, 1, 0, -50244, 2762, 0, 0, 39, '2761'),
	(377, 1, 0, -50244, 2763, 0, 0, 39, '2762'),
	(377, 1, 0, -50244, 2764, 0, 0, 39, '2763'),
	(377, 1, 0, -50244, 2765, 0, 0, 39, '2764'),
	(377, 1, 0, -50244, 2766, 0, 0, 39, '2765'),
	(377, 1, 0, -50244, 2767, 0, 0, 39, '2766'),
	(377, 1, 0, -50244, 2768, 0, 0, 39, '2767'),
	(377, 1, 0, -50244, 2769, 0, 0, 39, '2768'),
	(377, 1, 0, -50244, 2770, 0, 0, 39, '2769'),
	(377, 1, 0, -50244, 2771, 0, 0, 39, '2770'),
	(377, 1, 0, -50244, 2772, 0, 0, 39, '2771'),
	(377, 1, 0, -50244, 2773, 0, 0, 39, '2772'),
	(377, 1, 0, -50244, 2774, 0, 0, 39, '2773'),
	(377, 1, 0, -50244, 2775, 0, 0, 39, '2774'),
	(377, 1, 0, -50244, 2776, 0, 0, 39, '2775'),
	(377, 1, 0, -50244, 2777, 0, 0, 39, '2776'),
	(377, 1, 0, -50244, 2778, 0, 0, 39, '2777'),
	(377, 1, 0, -50244, 2779, 0, 0, 39, '2778'),
	(377, 1, 0, -50244, 2780, 0, 0, 39, '2779'),
	(377, 1, 0, -50244, 2781, 0, 0, 39, '2780'),
	(377, 1, 0, -50244, 2782, 0, 0, 39, '2781'),
	(377, 1, 0, -50244, 2783, 0, 0, 39, '2782'),
	(377, 1, 0, -50244, 2784, 0, 0, 39, '2783'),
	(377, 1, 0, -50244, 2785, 0, 0, 39, '2784'),
	(377, 1, 0, -50244, 2786, 0, 0, 39, '2785'),
	(377, 1, 0, -50244, 2787, 0, 0, 39, '2786'),
	(377, 1, 0, -50244, 2788, 0, 0, 39, '2787'),
	(377, 1, 0, -50244, 2789, 0, 0, 39, '2788'),
	(377, 1, 0, -50244, 2790, 0, 0, 39, '2789'),
	(377, 1, 0, -50244, 2791, 0, 0, 39, '2790'),
	(377, 1, 0, -50244, 2792, 0, 0, 39, '2791'),
	(377, 1, 0, -50244, 2793, 0, 0, 39, '2792'),
	(377, 1, 0, -50244, 2794, 0, 0, 39, '2793'),
	(377, 1, 0, -50244, 2795, 0, 0, 39, '2794'),
	(377, 1, 0, -50244, 2796, 0, 0, 39, '2795'),
	(377, 1, 0, -50244, 2797, 0, 0, 39, '2796'),
	(377, 1, 0, -50244, 2798, 0, 0, 39, '2797'),
	(377, 1, 0, -50244, 2799, 0, 0, 39, '2798'),
	(377, 1, 0, -50244, 2800, 0, 0, 39, '2799'),
	(377, 1, 0, -50244, 2801, 0, 0, 39, '2800'),
	(377, 1, 0, -50244, 2802, 0, 0, 39, '2801'),
	(377, 1, 0, -50244, 2803, 0, 0, 39, '2802'),
	(377, 1, 0, -50244, 2804, 0, 0, 39, '2803'),
	(377, 1, 0, -50244, 2805, 0, 0, 39, '2804'),
	(377, 1, 0, -50244, 2806, 0, 0, 39, '2805'),
	(377, 1, 0, -50244, 2807, 0, 0, 39, '2806'),
	(377, 1, 0, -50244, 2808, 0, 0, 39, '2807'),
	(377, 1, 0, -50244, 2809, 0, 0, 39, '2808'),
	(377, 1, 0, -50244, 2810, 0, 0, 39, '2809'),
	(377, 1, 0, -50244, 2811, 0, 0, 39, '2810'),
	(377, 1, 0, -50244, 2812, 0, 0, 39, '2811'),
	(377, 1, 0, -50244, 2813, 0, 0, 39, '2812'),
	(377, 1, 0, -50244, 2814, 0, 0, 39, '2813'),
	(377, 1, 0, -50244, 2815, 0, 0, 39, '2814'),
	(377, 1, 0, -50244, 2816, 0, 0, 39, '2815'),
	(377, 1, 0, -50244, 2817, 0, 0, 39, '2816'),
	(377, 1, 0, -50244, 2818, 0, 0, 39, '2817'),
	(377, 1, 0, -50244, 2819, 0, 0, 39, '2818'),
	(377, 1, 0, -50244, 2820, 0, 0, 39, '2819'),
	(377, 1, 0, -50244, 2821, 0, 0, 39, '2820'),
	(377, 1, 0, -50244, 2822, 0, 0, 39, '2821'),
	(377, 1, 0, -50244, 2823, 0, 0, 39, '2822'),
	(377, 1, 0, -50244, 2824, 0, 0, 39, '2823'),
	(377, 1, 0, -50244, 2825, 0, 0, 39, '2824'),
	(377, 1, 0, -50244, 2826, 0, 0, 39, '2825'),
	(377, 1, 0, -50244, 2827, 0, 0, 39, '2826'),
	(377, 1, 0, -50244, 2828, 0, 0, 39, '2827'),
	(377, 1, 0, -50244, 2829, 0, 0, 39, '2828'),
	(377, 1, 0, -50244, 2830, 0, 0, 39, '2829'),
	(377, 1, 0, -50244, 2831, 0, 0, 39, '2830'),
	(377, 1, 0, -50244, 2832, 0, 0, 39, '2831'),
	(377, 1, 0, -50244, 2833, 0, 0, 39, '2832'),
	(377, 1, 0, -50244, 2834, 0, 0, 39, '2833'),
	(377, 1, 0, -50244, 2835, 0, 0, 39, '2834'),
	(377, 1, 0, -50244, 2836, 0, 0, 39, '2835'),
	(377, 1, 0, -50244, 2837, 0, 0, 39, '2836'),
	(377, 1, 0, -50244, 2838, 0, 0, 39, '2837'),
	(377, 1, 0, -50244, 2839, 0, 0, 39, '2838'),
	(377, 1, 0, -50244, 2840, 0, 0, 39, '2839'),
	(377, 1, 0, -50244, 2841, 0, 0, 39, '2840'),
	(377, 1, 0, -50244, 2842, 0, 0, 39, '2841'),
	(377, 1, 0, -50244, 2843, 0, 0, 39, '2842'),
	(377, 1, 0, -50244, 2844, 0, 0, 39, '2843'),
	(377, 1, 0, -50244, 2845, 0, 0, 39, '2844'),
	(377, 1, 0, -50244, 2846, 0, 0, 39, '2845'),
	(377, 1, 0, -50244, 2847, 0, 0, 39, '2846'),
	(377, 1, 0, -50244, 2848, 0, 0, 39, '2847'),
	(377, 1, 0, -50244, 2849, 0, 0, 39, '2848'),
	(377, 1, 0, -50244, 2850, 0, 0, 39, '2849'),
	(377, 1, 0, -50244, 2851, 0, 0, 39, '2850'),
	(377, 1, 0, -50244, 2852, 0, 0, 39, '2851'),
	(377, 1, 0, -50244, 2853, 0, 0, 39, '2852'),
	(377, 1, 0, -50244, 2854, 0, 0, 39, '2853'),
	(377, 1, 0, -50244, 2855, 0, 0, 39, '2854'),
	(377, 1, 0, -50244, 2856, 0, 0, 39, '2855'),
	(377, 1, 0, -50244, 2857, 0, 0, 39, '2856'),
	(377, 1, 0, -50244, 2858, 0, 0, 39, '2857'),
	(377, 1, 0, -50244, 2859, 0, 0, 39, '2858'),
	(377, 1, 0, -50244, 2860, 0, 0, 39, '2859'),
	(377, 1, 0, -50244, 2861, 0, 0, 39, '2860'),
	(377, 1, 0, -50244, 2862, 0, 0, 39, '2861'),
	(377, 1, 0, -50244, 2863, 0, 0, 39, '2862'),
	(377, 1, 0, -50244, 2864, 0, 0, 39, '2863'),
	(377, 1, 0, -50244, 2865, 0, 0, 39, '2864'),
	(377, 1, 0, -50244, 2866, 0, 0, 39, '2865'),
	(377, 1, 0, -50244, 2867, 0, 0, 39, '2866'),
	(377, 1, 0, -50244, 2868, 0, 0, 39, '2867'),
	(377, 1, 0, -50244, 2869, 0, 0, 39, '2868'),
	(377, 1, 0, -50244, 2870, 0, 0, 39, '2869'),
	(377, 1, 0, -50244, 2871, 0, 0, 39, '2870'),
	(377, 1, 0, -50244, 2872, 0, 0, 39, '2871'),
	(377, 1, 0, -50244, 2873, 0, 0, 39, '2872'),
	(377, 1, 0, -50244, 2874, 0, 0, 39, '2873'),
	(377, 1, 0, -50244, 2875, 0, 0, 39, '2874'),
	(377, 1, 0, -50244, 2876, 0, 0, 39, '2875'),
	(377, 1, 0, -50244, 2877, 0, 0, 39, '2876'),
	(377, 1, 0, -50244, 2878, 0, 0, 39, '2877'),
	(377, 1, 0, -50244, 2879, 0, 0, 39, '2878'),
	(377, 1, 0, -50244, 2880, 0, 0, 39, '2879'),
	(377, 1, 0, -50244, 2881, 0, 0, 39, '2880'),
	(377, 1, 0, -50244, 2882, 0, 0, 39, '2881'),
	(377, 1, 0, -50244, 2883, 0, 0, 39, '2882'),
	(377, 1, 0, -50244, 2884, 0, 0, 39, '2883'),
	(377, 1, 0, -50244, 2885, 0, 0, 39, '2884'),
	(377, 1, 0, -50244, 2886, 0, 0, 39, '2885'),
	(377, 1, 0, -50244, 2887, 0, 0, 39, '2886'),
	(377, 1, 0, -50244, 2888, 0, 0, 39, '2887'),
	(377, 1, 0, -50244, 2889, 0, 0, 39, '2888'),
	(377, 1, 0, -50244, 2890, 0, 0, 39, '2889'),
	(377, 1, 0, -50244, 2891, 0, 0, 39, '2890'),
	(377, 1, 0, -50244, 2892, 0, 0, 39, '2891'),
	(377, 1, 0, -50244, 2893, 0, 0, 39, '2892'),
	(377, 1, 0, -50244, 2894, 0, 0, 39, '2893'),
	(377, 1, 0, -50244, 2895, 0, 0, 39, '2894'),
	(377, 1, 0, -50244, 2896, 0, 0, 39, '2895'),
	(377, 1, 0, -50244, 2897, 0, 0, 39, '2896'),
	(377, 1, 0, -50244, 2898, 0, 0, 39, '2897'),
	(377, 1, 0, -50244, 2899, 0, 0, 39, '2898'),
	(377, 1, 0, -50244, 2900, 0, 0, 39, '2899'),
	(377, 1, 0, -50244, 2901, 0, 0, 39, '2900'),
	(377, 1, 0, -50244, 2902, 0, 0, 39, '2901'),
	(377, 1, 0, -50244, 2903, 0, 0, 39, '2902'),
	(377, 1, 0, -50244, 2904, 0, 0, 39, '2903'),
	(377, 1, 0, -50244, 2905, 0, 0, 39, '2904'),
	(377, 1, 0, -50244, 2906, 0, 0, 39, '2905'),
	(377, 1, 0, -50244, 2907, 0, 0, 39, '2906'),
	(377, 1, 0, -50244, 2908, 0, 0, 39, '2907'),
	(377, 1, 0, -50244, 2909, 0, 0, 39, '2908'),
	(377, 1, 0, -50244, 2910, 0, 0, 39, '2909'),
	(377, 1, 0, -50244, 2911, 0, 0, 39, '2910'),
	(377, 1, 0, -50244, 2912, 0, 0, 39, '2911'),
	(377, 1, 0, -50244, 2913, 0, 0, 39, '2912'),
	(377, 1, 0, -50244, 2914, 0, 0, 39, '2913'),
	(377, 1, 0, -50244, 2915, 0, 0, 39, '2914'),
	(377, 1, 0, -50244, 2916, 0, 0, 39, '2915'),
	(377, 1, 0, -50244, 2917, 0, 0, 39, '2916'),
	(377, 1, 0, -50244, 2918, 0, 0, 39, '2917'),
	(377, 1, 0, -50244, 2919, 0, 0, 39, '2918'),
	(377, 1, 0, -50244, 2920, 0, 0, 39, '2919'),
	(377, 1, 0, -50244, 2921, 0, 0, 39, '2920'),
	(377, 1, 0, -50244, 2922, 0, 0, 39, '2921'),
	(377, 1, 0, -50244, 2923, 0, 0, 39, '2922'),
	(377, 1, 0, -50244, 2924, 0, 0, 39, '2923'),
	(377, 1, 0, -50244, 2925, 0, 0, 39, '2924'),
	(377, 1, 0, -50244, 2926, 0, 0, 39, '2925'),
	(377, 1, 0, -50244, 2927, 0, 0, 39, '2926'),
	(377, 1, 0, -50244, 2928, 0, 0, 39, '2927'),
	(377, 1, 0, -50244, 2929, 0, 0, 39, '2928'),
	(377, 1, 0, -50244, 2930, 0, 0, 39, '2929'),
	(377, 1, 0, -50244, 2931, 0, 0, 39, '2930'),
	(377, 1, 0, -50244, 2932, 0, 0, 39, '2931'),
	(377, 1, 0, -50244, 2933, 0, 0, 39, '2932'),
	(377, 1, 0, -50244, 2934, 0, 0, 39, '2933'),
	(377, 1, 0, -50244, 2935, 0, 0, 39, '2934'),
	(377, 1, 0, -50244, 2936, 0, 0, 39, '2935'),
	(377, 1, 0, -50244, 2937, 0, 0, 39, '2936'),
	(377, 1, 0, -50244, 2938, 0, 0, 39, '2937'),
	(377, 1, 0, -50244, 2939, 0, 0, 39, '2938'),
	(377, 1, 0, -50244, 2940, 0, 0, 39, '2939'),
	(377, 1, 0, -50244, 2941, 0, 0, 39, '2940'),
	(377, 1, 0, -50244, 2942, 0, 0, 39, '2941'),
	(377, 1, 0, -50244, 2943, 0, 0, 39, '2942'),
	(377, 1, 0, -50244, 2944, 0, 0, 39, '2943'),
	(377, 1, 0, -50244, 2945, 0, 0, 39, '2944'),
	(377, 1, 0, -50244, 2946, 0, 0, 39, '2945'),
	(377, 1, 0, -50244, 2947, 0, 0, 39, '2946'),
	(377, 1, 0, -50244, 2948, 0, 0, 39, '2947'),
	(377, 1, 0, -50244, 2949, 0, 0, 39, '2948'),
	(377, 1, 0, -50244, 2950, 0, 0, 39, '2949'),
	(377, 1, 0, -50244, 2951, 0, 0, 39, '2950'),
	(377, 1, 0, -50244, 2952, 0, 0, 39, '2951'),
	(377, 1, 0, -50244, 2953, 0, 0, 39, '2952'),
	(377, 1, 0, -50244, 2954, 0, 0, 39, '2953'),
	(377, 1, 0, -50244, 2955, 0, 0, 39, '2954'),
	(377, 1, 0, -50244, 2956, 0, 0, 39, '2955'),
	(377, 1, 0, -50244, 2957, 0, 0, 39, '2956'),
	(377, 1, 0, -50244, 2958, 0, 0, 39, '2957'),
	(377, 1, 0, -50244, 2959, 0, 0, 39, '2958'),
	(377, 1, 0, -50244, 2960, 0, 0, 39, '2959'),
	(377, 1, 0, -50244, 2961, 0, 0, 39, '2960'),
	(377, 1, 0, -50244, 2962, 0, 0, 39, '2961'),
	(377, 1, 0, -50244, 2963, 0, 0, 39, '2962'),
	(377, 1, 0, -50244, 2964, 0, 0, 39, '2963'),
	(377, 1, 0, -50244, 2965, 0, 0, 39, '2964'),
	(377, 1, 0, -50244, 2966, 0, 0, 39, '2965'),
	(377, 1, 0, -50244, 2967, 0, 0, 39, '2966'),
	(377, 1, 0, -50244, 2968, 0, 0, 39, '2967'),
	(377, 1, 0, -50244, 2969, 0, 0, 39, '2968'),
	(377, 1, 0, -50244, 2970, 0, 0, 39, '2969'),
	(377, 1, 0, -50244, 2971, 0, 0, 39, '2970'),
	(377, 1, 0, -50244, 2972, 0, 0, 39, '2971'),
	(377, 1, 0, -50244, 2973, 0, 0, 39, '2972'),
	(377, 1, 0, -50244, 2974, 0, 0, 39, '2973'),
	(377, 1, 0, -50244, 2975, 0, 0, 39, '2974'),
	(377, 1, 0, -50244, 2976, 0, 0, 39, '2975'),
	(377, 1, 0, -50244, 2977, 0, 0, 39, '2976'),
	(377, 1, 0, -50244, 2978, 0, 0, 39, '2977'),
	(377, 1, 0, -50244, 2979, 0, 0, 39, '2978'),
	(377, 1, 0, -50244, 2980, 0, 0, 39, '2979'),
	(377, 1, 0, -50244, 2981, 0, 0, 39, '2980'),
	(377, 1, 0, -50244, 2982, 0, 0, 39, '2981'),
	(377, 1, 0, -50244, 2983, 0, 0, 39, '2982'),
	(377, 1, 0, -50244, 2984, 0, 0, 39, '2983'),
	(377, 1, 0, -50244, 2985, 0, 0, 39, '2984'),
	(377, 1, 0, -50244, 2986, 0, 0, 39, '2985'),
	(377, 1, 0, -50244, 2987, 0, 0, 39, '2986'),
	(377, 1, 0, -50244, 2988, 0, 0, 39, '2987'),
	(377, 1, 0, -50244, 2989, 0, 0, 39, '2988'),
	(377, 1, 0, -50244, 2990, 0, 0, 39, '2989'),
	(377, 1, 0, -50244, 2991, 0, 0, 39, '2990'),
	(377, 1, 0, -50244, 2992, 0, 0, 39, '2991'),
	(377, 1, 0, -50244, 2993, 0, 0, 39, '2992'),
	(377, 1, 0, -50244, 2994, 0, 0, 39, '2993'),
	(377, 1, 0, -50244, 2995, 0, 0, 39, '2994'),
	(377, 1, 0, -50244, 2996, 0, 0, 39, '2995'),
	(377, 1, 0, -50244, 2997, 0, 0, 39, '2996'),
	(377, 1, 0, -50244, 2998, 0, 0, 39, '2997'),
	(377, 1, 0, -50244, 2999, 0, 0, 39, '2998'),
	(377, 1, 0, -50244, 3000, 0, 0, 39, '2999'),
	(377, 1, 0, -50244, 3001, 0, 0, 39, '3000'),
	(377, 1, 0, -50244, 3002, 0, 0, 39, '3001'),
	(377, 1, 0, -50244, 3003, 0, 0, 39, '3002'),
	(377, 1, 0, -50244, 3004, 0, 0, 39, '3003'),
	(377, 1, 0, -50244, 3005, 0, 0, 39, '3004'),
	(377, 1, 0, -50244, 3006, 0, 0, 39, '3005'),
	(377, 1, 0, -50244, 3007, 0, 0, 39, '3006'),
	(377, 1, 0, -50244, 3008, 0, 0, 39, '3007'),
	(377, 1, 0, -50244, 3009, 0, 0, 39, '3008'),
	(377, 1, 0, -50244, 3010, 0, 0, 39, '3009'),
	(377, 1, 0, -50244, 3011, 0, 0, 39, '3010'),
	(377, 1, 0, -50244, 3012, 0, 0, 39, '3011'),
	(377, 1, 0, -50244, 3013, 0, 0, 39, '3012'),
	(377, 1, 0, -50244, 3014, 0, 0, 39, '3013'),
	(377, 1, 0, -50244, 3015, 0, 0, 39, '3014'),
	(377, 1, 0, -50244, 3016, 0, 0, 39, '3015'),
	(377, 1, 0, -50244, 3017, 0, 0, 39, '3016'),
	(377, 1, 0, -50244, 3018, 0, 0, 39, '3017'),
	(377, 1, 0, -50244, 3019, 0, 0, 39, '3018'),
	(377, 1, 0, -50244, 3020, 0, 0, 39, '3019'),
	(377, 1, 0, -50244, 3021, 0, 0, 39, '3020'),
	(377, 1, 0, -50244, 3022, 0, 0, 39, '3021'),
	(377, 1, 0, -50244, 3023, 0, 0, 39, '3022'),
	(377, 1, 0, -50244, 3024, 0, 0, 39, '3023'),
	(377, 1, 0, -50244, 3025, 0, 0, 39, '3024'),
	(377, 1, 0, -50244, 3026, 0, 0, 39, '3025'),
	(377, 1, 0, -50244, 3027, 0, 0, 39, '3026'),
	(377, 1, 0, -50244, 3028, 0, 0, 39, '3027'),
	(377, 1, 0, -50244, 3029, 0, 0, 39, '3028'),
	(377, 1, 0, -50244, 3030, 0, 0, 39, '3029'),
	(377, 1, 0, -50244, 3031, 0, 0, 39, '3030'),
	(377, 1, 0, -50244, 3032, 0, 0, 39, '3031'),
	(377, 1, 0, -50244, 3033, 0, 0, 39, '3032'),
	(377, 1, 0, -50244, 3034, 0, 0, 39, '3033'),
	(377, 1, 0, -50244, 3035, 0, 0, 39, '3034'),
	(377, 1, 0, -50244, 3036, 0, 0, 39, '3035'),
	(377, 1, 0, -50244, 3037, 0, 0, 39, '3036'),
	(377, 1, 0, -50244, 3038, 0, 0, 39, '3037'),
	(377, 1, 0, -50244, 3039, 0, 0, 39, '3038'),
	(377, 1, 0, -50244, 3040, 0, 0, 39, '3039'),
	(377, 1, 0, -50244, 3041, 0, 0, 39, '3040'),
	(377, 1, 0, -50244, 3042, 0, 0, 39, '3041'),
	(377, 1, 0, -50244, 3043, 0, 0, 39, '3042'),
	(377, 1, 0, -50244, 3044, 0, 0, 39, '3043'),
	(377, 1, 0, -50244, 3045, 0, 0, 39, '3044'),
	(377, 1, 0, -50244, 3046, 0, 0, 39, '3045'),
	(377, 1, 0, -50244, 3047, 0, 0, 39, '3046'),
	(377, 1, 0, -50244, 3048, 0, 0, 39, '3047'),
	(377, 1, 0, -50244, 3049, 0, 0, 39, '3048'),
	(377, 1, 0, -50244, 3050, 0, 0, 39, '3049'),
	(377, 1, 0, -50244, 3051, 0, 0, 39, '3050'),
	(377, 1, 0, -50244, 3052, 0, 0, 39, '3051'),
	(377, 1, 0, -50244, 3053, 0, 0, 39, '3052'),
	(377, 1, 0, -50244, 3054, 0, 0, 39, '3053'),
	(377, 1, 0, -50244, 3055, 0, 0, 39, '3054'),
	(377, 1, 0, -50244, 3056, 0, 0, 39, '3055'),
	(377, 1, 0, -50244, 3057, 0, 0, 39, '3056'),
	(377, 1, 0, -50244, 3058, 0, 0, 39, '3057'),
	(377, 1, 0, -50244, 3059, 0, 0, 39, '3058'),
	(377, 1, 0, -50244, 3060, 0, 0, 39, '3059'),
	(377, 1, 0, -50244, 3061, 0, 0, 39, '3060'),
	(377, 1, 0, -50244, 3062, 0, 0, 39, '3061'),
	(377, 1, 0, -50244, 3063, 0, 0, 39, '3062'),
	(377, 1, 0, -50244, 3064, 0, 0, 39, '3063'),
	(377, 1, 0, -50244, 3065, 0, 0, 39, '3064'),
	(377, 1, 0, -50244, 3066, 0, 0, 39, '3065'),
	(377, 1, 0, -50244, 3067, 0, 0, 39, '3066'),
	(377, 1, 0, -50244, 3068, 0, 0, 39, '3067'),
	(377, 1, 0, -50244, 3069, 0, 0, 39, '3068'),
	(377, 1, 0, -50244, 3070, 0, 0, 39, '3069'),
	(377, 1, 0, -50244, 3071, 0, 0, 39, '3070'),
	(377, 1, 0, -50244, 3072, 0, 0, 39, '3071'),
	(377, 1, 0, -50244, 3073, 0, 0, 39, '3072'),
	(377, 1, 0, -50244, 3074, 0, 0, 39, '3073'),
	(377, 1, 0, -50244, 3075, 0, 0, 39, '3074'),
	(377, 1, 0, -50244, 3076, 0, 0, 39, '3075'),
	(377, 1, 0, -50244, 3077, 0, 0, 39, '3076'),
	(377, 1, 0, -50244, 3078, 0, 0, 39, '3077'),
	(377, 1, 0, -50244, 3079, 0, 0, 39, '3078'),
	(377, 1, 0, -50244, 3080, 0, 0, 39, '3079'),
	(377, 1, 0, -50244, 3081, 0, 0, 39, '3080'),
	(377, 1, 0, -50244, 3082, 0, 0, 39, '3081'),
	(377, 1, 0, -50244, 3083, 0, 0, 39, '3082'),
	(377, 1, 0, -50244, 3084, 0, 0, 39, '3083'),
	(377, 1, 0, -50244, 3085, 0, 0, 39, '3084'),
	(377, 1, 0, -50244, 3086, 0, 0, 39, '3085'),
	(377, 1, 0, -50244, 3087, 0, 0, 39, '3086'),
	(377, 1, 0, -50244, 3088, 0, 0, 39, '3087'),
	(377, 1, 0, -50244, 3089, 0, 0, 39, '3088'),
	(377, 1, 0, -50244, 3090, 0, 0, 39, '3089'),
	(377, 1, 0, -50244, 3091, 0, 0, 39, '3090'),
	(377, 1, 0, -50244, 3092, 0, 0, 39, '3091'),
	(377, 1, 0, -50244, 3093, 0, 0, 39, '3092'),
	(377, 1, 0, -50244, 3094, 0, 0, 39, '3093'),
	(377, 1, 0, -50244, 3095, 0, 0, 39, '3094'),
	(377, 1, 0, -50244, 3096, 0, 0, 39, '3095'),
	(377, 1, 0, -50244, 3097, 0, 0, 39, '3096'),
	(377, 1, 0, -50244, 3098, 0, 0, 39, '3097'),
	(377, 1, 0, -50244, 3099, 0, 0, 39, '3098'),
	(377, 1, 0, -50244, 3100, 0, 0, 39, '3099'),
	(377, 1, 0, -50244, 3101, 0, 0, 39, '3100'),
	(377, 1, 0, -50244, 3102, 0, 0, 39, '3101'),
	(377, 1, 0, -50244, 3103, 0, 0, 39, '3102'),
	(377, 1, 0, -50244, 3104, 0, 0, 39, '3103'),
	(377, 1, 0, -50244, 3105, 0, 0, 39, '3104'),
	(377, 1, 0, -50244, 3106, 0, 0, 39, '3105'),
	(377, 1, 0, -50244, 3107, 0, 0, 39, '3106'),
	(377, 1, 0, -50244, 3108, 0, 0, 39, '3107'),
	(377, 1, 0, -50244, 3109, 0, 0, 39, '3108'),
	(377, 1, 0, -50244, 3110, 0, 0, 39, '3109'),
	(377, 1, 0, -50244, 3111, 0, 0, 39, '3110'),
	(377, 1, 0, -50244, 3112, 0, 0, 39, '3111'),
	(377, 1, 0, -50244, 3113, 0, 0, 39, '3112'),
	(377, 1, 0, -50244, 3114, 0, 0, 39, '3113'),
	(377, 1, 0, -50244, 3115, 0, 0, 39, '3114'),
	(377, 1, 0, -50244, 3116, 0, 0, 39, '3115'),
	(377, 1, 0, -50244, 3117, 0, 0, 39, '3116'),
	(377, 1, 0, -50244, 3118, 0, 0, 39, '3117'),
	(377, 1, 0, -50244, 3119, 0, 0, 39, '3118'),
	(377, 1, 0, -50244, 3120, 0, 0, 39, '3119'),
	(377, 1, 0, -50244, 3121, 0, 0, 39, '3120'),
	(377, 1, 0, -50244, 3122, 0, 0, 39, '3121'),
	(377, 1, 0, -50244, 3123, 0, 0, 39, '3122'),
	(377, 1, 0, -50244, 3124, 0, 0, 39, '3123'),
	(377, 1, 0, -50244, 3125, 0, 0, 39, '3124'),
	(377, 1, 0, -50244, 3126, 0, 0, 39, '3125'),
	(377, 1, 0, -50244, 3127, 0, 0, 39, '3126'),
	(377, 1, 0, -50244, 3128, 0, 0, 39, '3127'),
	(377, 1, 0, -50244, 3129, 0, 0, 39, '3128'),
	(377, 1, 0, -50244, 3130, 0, 0, 39, '3129'),
	(377, 1, 0, -50244, 3131, 0, 0, 39, '3130'),
	(377, 1, 0, -50244, 3132, 0, 0, 39, '3131'),
	(377, 1, 0, -50244, 3133, 0, 0, 39, '3132'),
	(377, 1, 0, -50244, 3134, 0, 0, 39, '3133'),
	(377, 1, 0, -50244, 3135, 0, 0, 39, '3134'),
	(377, 1, 0, -50244, 3136, 0, 0, 39, '3135'),
	(377, 1, 0, -50244, 3137, 0, 0, 39, '3136'),
	(377, 1, 0, -50244, 3138, 0, 0, 39, '3137'),
	(377, 1, 0, -50244, 3139, 0, 0, 39, '3138'),
	(377, 1, 0, -50244, 3140, 0, 0, 39, '3139'),
	(377, 1, 0, -50244, 3141, 0, 0, 39, '3140'),
	(377, 1, 0, -50244, 3142, 0, 0, 39, '3141'),
	(377, 1, 0, -50244, 3143, 0, 0, 39, '3142'),
	(377, 1, 0, -50244, 3144, 0, 0, 39, '3143'),
	(377, 1, 0, -50244, 3145, 0, 0, 39, '3144'),
	(377, 1, 0, -50244, 3146, 0, 0, 39, '3145'),
	(377, 1, 0, -50244, 3147, 0, 0, 39, '3146'),
	(377, 1, 0, -50244, 3148, 0, 0, 39, '3147'),
	(377, 1, 0, -50244, 3149, 0, 0, 39, '3148'),
	(377, 1, 0, -50244, 3150, 0, 0, 39, '3149'),
	(377, 1, 0, -50244, 3151, 0, 0, 39, '3150'),
	(377, 1, 0, -50244, 3152, 0, 0, 39, '3151'),
	(377, 1, 0, -50244, 3153, 0, 0, 39, '3152'),
	(377, 1, 0, -50244, 3154, 0, 0, 39, '3153'),
	(377, 1, 0, -50244, 3155, 0, 0, 39, '3154'),
	(377, 1, 0, -50244, 3156, 0, 0, 39, '3155'),
	(377, 1, 0, -50244, 3157, 0, 0, 39, '3156'),
	(377, 1, 0, -50244, 3158, 0, 0, 39, '3157'),
	(377, 1, 0, -50244, 3159, 0, 0, 39, '3158'),
	(377, 1, 0, -50244, 3160, 0, 0, 39, '3159'),
	(377, 1, 0, -50244, 3161, 0, 0, 39, '3160'),
	(377, 1, 0, -50244, 3162, 0, 0, 39, '3161'),
	(377, 1, 0, -50244, 3163, 0, 0, 39, '3162'),
	(377, 1, 0, -50244, 3164, 0, 0, 39, '3163'),
	(377, 1, 0, -50244, 3165, 0, 0, 39, '3164'),
	(377, 1, 0, -50244, 3166, 0, 0, 39, '3165'),
	(377, 1, 0, -50244, 3167, 0, 0, 39, '3166'),
	(377, 1, 0, -50244, 3168, 0, 0, 39, '3167'),
	(377, 1, 0, -50244, 3169, 0, 0, 39, '3168'),
	(377, 1, 0, -50244, 3170, 0, 0, 39, '3169'),
	(377, 1, 0, -50244, 3171, 0, 0, 39, '3170'),
	(377, 1, 0, -50244, 3172, 0, 0, 39, '3171'),
	(377, 1, 0, -50244, 3173, 0, 0, 39, '3172'),
	(377, 1, 0, -50244, 3174, 0, 0, 39, '3173'),
	(377, 1, 0, -50244, 3175, 0, 0, 39, '3174'),
	(377, 1, 0, -50244, 3176, 0, 0, 39, '3175'),
	(377, 1, 0, -50244, 3177, 0, 0, 39, '3176'),
	(377, 1, 0, -50244, 3178, 0, 0, 39, '3177'),
	(377, 1, 0, -50244, 3179, 0, 0, 39, '3178'),
	(377, 1, 0, -50244, 3180, 0, 0, 39, '3179'),
	(377, 1, 0, -50244, 3181, 0, 0, 39, '3180'),
	(377, 1, 0, -50244, 3182, 0, 0, 39, '3181'),
	(377, 1, 0, -50244, 3183, 0, 0, 39, '3182'),
	(377, 1, 0, -50244, 3184, 0, 0, 39, '3183'),
	(377, 1, 0, -50244, 3185, 0, 0, 39, '3184'),
	(377, 1, 0, -50244, 3186, 0, 0, 39, '3185'),
	(377, 1, 0, -50244, 3187, 0, 0, 39, '3186'),
	(377, 1, 0, -50244, 3188, 0, 0, 39, '3187'),
	(377, 1, 0, -50244, 3189, 0, 0, 39, '3188'),
	(377, 1, 0, -50244, 3190, 0, 0, 39, '3189'),
	(377, 1, 0, -50244, 3191, 0, 0, 39, '3190'),
	(377, 1, 0, -50244, 3192, 0, 0, 39, '3191'),
	(377, 1, 0, -50244, 3193, 0, 0, 39, '3192'),
	(377, 1, 0, -50244, 3194, 0, 0, 39, '3193'),
	(377, 1, 0, -50244, 3195, 0, 0, 39, '3194'),
	(377, 1, 0, -50244, 3196, 0, 0, 39, '3195'),
	(377, 1, 0, -50244, 3197, 0, 0, 39, '3196'),
	(377, 1, 0, -50244, 3198, 0, 0, 39, '3197'),
	(377, 1, 0, -50244, 3199, 0, 0, 39, '3198'),
	(377, 1, 0, -50244, 3200, 0, 0, 39, '3199'),
	(377, 1, 0, -50244, 3201, 0, 0, 39, '3200'),
	(377, 1, 0, -50244, 3202, 0, 0, 39, '3201'),
	(377, 1, 0, -50244, 3203, 0, 0, 39, '3202'),
	(377, 1, 0, -50244, 3204, 0, 0, 39, '3203'),
	(377, 1, 0, -50244, 3205, 0, 0, 39, '3204'),
	(377, 1, 0, -50244, 3206, 0, 0, 39, '3205'),
	(377, 1, 0, -50244, 3207, 0, 0, 39, '3206'),
	(377, 1, 0, -50244, 3208, 0, 0, 39, '3207'),
	(377, 1, 0, -50244, 3209, 0, 0, 39, '3208'),
	(377, 1, 0, -50244, 3210, 0, 0, 39, '3209'),
	(377, 1, 0, -50244, 3211, 0, 0, 39, '3210'),
	(377, 1, 0, -50244, 3212, 0, 0, 39, '3211'),
	(377, 1, 0, -50244, 3213, 0, 0, 39, '3212'),
	(377, 1, 0, -50244, 3214, 0, 0, 39, '3213'),
	(377, 1, 0, -50244, 3215, 0, 0, 39, '3214'),
	(377, 1, 0, -50244, 3216, 0, 0, 39, '3215'),
	(377, 1, 0, -50244, 3217, 0, 0, 39, '3216'),
	(377, 1, 0, -50244, 3218, 0, 0, 39, '3217'),
	(377, 1, 0, -50244, 3219, 0, 0, 39, '3218'),
	(377, 1, 0, -50244, 3220, 0, 0, 39, '3219'),
	(377, 1, 0, -50244, 3221, 0, 0, 39, '3220'),
	(377, 1, 0, -50244, 3222, 0, 0, 39, '3221'),
	(377, 1, 0, -50244, 3223, 0, 0, 39, '3222'),
	(377, 1, 0, -50244, 3224, 0, 0, 39, '3223'),
	(377, 1, 0, -50244, 3225, 0, 0, 39, '3224'),
	(377, 1, 0, -50244, 3226, 0, 0, 39, '3225'),
	(377, 1, 0, -50244, 3227, 0, 0, 39, '3226'),
	(377, 1, 0, -50244, 3228, 0, 0, 39, '3227'),
	(377, 1, 0, -50244, 3229, 0, 0, 39, '3228'),
	(377, 1, 0, -50244, 3230, 0, 0, 39, '3229'),
	(377, 1, 0, -50244, 3231, 0, 0, 39, '3230'),
	(377, 1, 0, -50244, 3232, 0, 0, 39, '3231'),
	(377, 1, 0, -50244, 3233, 0, 0, 39, '3232'),
	(377, 1, 0, -50244, 3234, 0, 0, 39, '3233'),
	(377, 1, 0, -50244, 3235, 0, 0, 39, '3234'),
	(377, 1, 0, -50244, 3236, 0, 0, 39, '3235'),
	(377, 1, 0, -50244, 3237, 0, 0, 39, '3236'),
	(377, 1, 0, -50244, 3238, 0, 0, 39, '3237'),
	(377, 1, 0, -50244, 3239, 0, 0, 39, '3238'),
	(377, 1, 0, -50244, 3240, 0, 0, 39, '3239'),
	(377, 1, 0, -50244, 3241, 0, 0, 39, '3240'),
	(377, 1, 0, -50244, 3242, 0, 0, 39, '3241'),
	(377, 1, 0, -50244, 3243, 0, 0, 39, '3242'),
	(377, 1, 0, -50244, 3244, 0, 0, 39, '3243'),
	(377, 1, 0, -50244, 3245, 0, 0, 39, '3244'),
	(377, 1, 0, -50244, 3246, 0, 0, 39, '3245'),
	(377, 1, 0, -50244, 3247, 0, 0, 39, '3246'),
	(377, 1, 0, -50244, 3248, 0, 0, 39, '3247'),
	(377, 1, 0, -50244, 3249, 0, 0, 39, '3248'),
	(377, 1, 0, -50244, 3250, 0, 0, 39, '3249'),
	(377, 1, 0, -50244, 3251, 0, 0, 39, '3250'),
	(377, 1, 0, -50244, 3252, 0, 0, 39, '3251'),
	(377, 1, 0, -50244, 3253, 0, 0, 39, '3252'),
	(377, 1, 0, -50244, 3254, 0, 0, 39, '3253'),
	(377, 1, 0, -50244, 3255, 0, 0, 39, '3254'),
	(377, 1, 0, -50244, 3256, 0, 0, 39, '3255'),
	(377, 1, 0, -50244, 3257, 0, 0, 39, '3256'),
	(377, 1, 0, -50244, 3258, 0, 0, 39, '3257'),
	(377, 1, 0, -50244, 3259, 0, 0, 39, '3258'),
	(377, 1, 0, -50244, 3260, 0, 0, 39, '3259'),
	(377, 1, 0, -50244, 3261, 0, 0, 39, '3260'),
	(377, 1, 0, -50244, 3262, 0, 0, 39, '3261'),
	(377, 1, 0, -50244, 3263, 0, 0, 39, '3262'),
	(377, 1, 0, -50244, 3264, 0, 0, 39, '3263'),
	(377, 1, 0, -50244, 3265, 0, 0, 39, '3264'),
	(377, 1, 0, -50244, 3266, 0, 0, 39, '3265'),
	(377, 1, 0, -50244, 3267, 0, 0, 39, '3266'),
	(377, 1, 0, -50244, 3268, 0, 0, 39, '3267'),
	(377, 1, 0, -50244, 3269, 0, 0, 39, '3268'),
	(377, 1, 0, -50244, 3270, 0, 0, 39, '3269'),
	(377, 1, 0, -50244, 3271, 0, 0, 39, '3270'),
	(377, 1, 0, -50244, 3272, 0, 0, 39, '3271'),
	(377, 1, 0, -50244, 3273, 0, 0, 39, '3272'),
	(377, 1, 0, -50244, 3274, 0, 0, 39, '3273'),
	(377, 1, 0, -50244, 3275, 0, 0, 39, '3274'),
	(377, 1, 0, -50244, 3276, 0, 0, 39, '3275'),
	(377, 1, 0, -50244, 3277, 0, 0, 39, '3276'),
	(377, 1, 0, -50244, 3278, 0, 0, 39, '3277'),
	(377, 1, 0, -50244, 3279, 0, 0, 39, '3278'),
	(377, 1, 0, -50244, 3280, 0, 0, 39, '3279'),
	(377, 1, 0, -50244, 3281, 0, 0, 39, '3280'),
	(377, 1, 0, -50244, 3282, 0, 0, 39, '3281'),
	(377, 1, 0, -50244, 3283, 0, 0, 39, '3282'),
	(377, 1, 0, -50244, 3284, 0, 0, 39, '3283'),
	(377, 1, 0, -50244, 3285, 0, 0, 39, '3284'),
	(377, 1, 0, -50244, 3286, 0, 0, 39, '3285'),
	(377, 1, 0, -50244, 3287, 0, 0, 39, '3286'),
	(377, 1, 0, -50244, 3288, 0, 0, 39, '3287'),
	(377, 1, 0, -50244, 3289, 0, 0, 39, '3288'),
	(377, 1, 0, -50244, 3290, 0, 0, 39, '3289'),
	(377, 1, 0, -50244, 3291, 0, 0, 39, '3290'),
	(377, 1, 0, -50244, 3292, 0, 0, 39, '3291'),
	(377, 1, 0, -50244, 3293, 0, 0, 39, '3292'),
	(377, 1, 0, -50244, 3294, 0, 0, 39, '3293'),
	(377, 1, 0, -50244, 3295, 0, 0, 39, '3294'),
	(377, 1, 0, -50244, 3296, 0, 0, 39, '3295'),
	(377, 1, 0, -50244, 3297, 0, 0, 39, '3296'),
	(377, 1, 0, -50244, 3298, 0, 0, 39, '3297'),
	(377, 1, 0, -50244, 3299, 0, 0, 39, '3298'),
	(377, 1, 0, -50244, 3300, 0, 0, 39, '3299'),
	(377, 1, 0, -50244, 3301, 0, 0, 39, '3300'),
	(377, 1, 0, -50244, 3302, 0, 0, 39, '3301'),
	(377, 1, 0, -50244, 3303, 0, 0, 39, '3302'),
	(377, 1, 0, -50244, 3304, 0, 0, 39, '3303'),
	(377, 1, 0, -50244, 3305, 0, 0, 39, '3304'),
	(377, 1, 0, -50244, 3306, 0, 0, 39, '3305'),
	(377, 1, 0, -50244, 3307, 0, 0, 39, '3306'),
	(377, 1, 0, -50244, 3308, 0, 0, 39, '3307'),
	(377, 1, 0, -50244, 3309, 0, 0, 39, '3308'),
	(377, 1, 0, -50244, 3310, 0, 0, 39, '3309'),
	(377, 1, 0, -50244, 3311, 0, 0, 39, '3310'),
	(377, 1, 0, -50244, 3312, 0, 0, 39, '3311'),
	(377, 1, 0, -50244, 3313, 0, 0, 39, '3312'),
	(377, 1, 0, -50244, 3314, 0, 0, 39, '3313'),
	(377, 1, 0, -50244, 3315, 0, 0, 39, '3314'),
	(377, 1, 0, -50244, 3316, 0, 0, 39, '3315'),
	(377, 1, 0, -50244, 3317, 0, 0, 39, '3316'),
	(377, 1, 0, -50244, 3318, 0, 0, 39, '3317'),
	(377, 1, 0, -50244, 3319, 0, 0, 39, '3318'),
	(377, 1, 0, -50244, 3320, 0, 0, 39, '3319'),
	(377, 1, 0, -50244, 3321, 0, 0, 39, '3320'),
	(377, 1, 0, -50244, 3322, 0, 0, 39, '3321'),
	(377, 1, 0, -50244, 3323, 0, 0, 39, '3322'),
	(377, 1, 0, -50244, 3324, 0, 0, 39, '3323'),
	(377, 1, 0, -50244, 3325, 0, 0, 39, '3324'),
	(377, 1, 0, -50244, 3326, 0, 0, 39, '3325'),
	(377, 1, 0, -50244, 3327, 0, 0, 39, '3326'),
	(377, 1, 0, -50244, 3328, 0, 0, 39, '3327'),
	(377, 1, 0, -50244, 3329, 0, 0, 39, '3328'),
	(377, 1, 0, -50244, 3330, 0, 0, 39, '3329'),
	(377, 1, 0, -50244, 3331, 0, 0, 39, '3330'),
	(377, 1, 0, -50244, 3332, 0, 0, 39, '3331'),
	(377, 1, 0, -50244, 3333, 0, 0, 39, '3332'),
	(377, 1, 0, -50244, 3334, 0, 0, 39, '3333'),
	(377, 1, 0, -50244, 3335, 0, 0, 39, '3334'),
	(377, 1, 0, -50244, 3336, 0, 0, 39, '3335'),
	(377, 1, 0, -50244, 3337, 0, 0, 39, '3336'),
	(377, 1, 0, -50244, 3338, 0, 0, 39, '3337'),
	(377, 1, 0, -50244, 3339, 0, 0, 39, '3338'),
	(377, 1, 0, -50244, 3340, 0, 0, 39, '3339'),
	(377, 1, 0, -50244, 3341, 0, 0, 39, '3340'),
	(377, 1, 0, -50244, 3342, 0, 0, 39, '3341'),
	(377, 1, 0, -50244, 3343, 0, 0, 39, '3342'),
	(377, 1, 0, -50244, 3344, 0, 0, 39, '3343'),
	(377, 1, 0, -50244, 3345, 0, 0, 39, '3344'),
	(377, 1, 0, -50244, 3346, 0, 0, 39, '3345'),
	(377, 1, 0, -50244, 3347, 0, 0, 39, '3346'),
	(377, 1, 0, -50244, 3348, 0, 0, 39, '3347'),
	(377, 1, 0, -50244, 3349, 0, 0, 39, '3348'),
	(377, 1, 0, -50244, 3350, 0, 0, 39, '3349'),
	(377, 1, 0, -50244, 3351, 0, 0, 39, '3350'),
	(377, 1, 0, -50244, 3352, 0, 0, 39, '3351'),
	(377, 1, 0, -50244, 3353, 0, 0, 39, '3352'),
	(377, 1, 0, -50244, 3354, 0, 0, 39, '3353'),
	(377, 1, 0, -50244, 3355, 0, 0, 39, '3354'),
	(377, 1, 0, -50244, 3356, 0, 0, 39, '3355'),
	(377, 1, 0, -50244, 3357, 0, 0, 39, '3356'),
	(377, 1, 0, -50244, 3358, 0, 0, 39, '3357'),
	(377, 1, 0, -50244, 3359, 0, 0, 39, '3358'),
	(377, 1, 0, -50244, 3360, 0, 0, 39, '3359'),
	(377, 1, 0, -50244, 3361, 0, 0, 39, '3360'),
	(377, 1, 0, -50244, 3362, 0, 0, 39, '3361'),
	(377, 1, 0, -50244, 3363, 0, 0, 39, '3362'),
	(377, 1, 0, -50244, 3364, 0, 0, 39, '3363'),
	(377, 1, 0, -50244, 3365, 0, 0, 39, '3364'),
	(377, 1, 0, -50244, 3366, 0, 0, 39, '3365'),
	(377, 1, 0, -50244, 3367, 0, 0, 39, '3366'),
	(377, 1, 0, -50244, 3368, 0, 0, 39, '3367'),
	(377, 1, 0, -50244, 3369, 0, 0, 39, '3368'),
	(377, 1, 0, -50244, 3370, 0, 0, 39, '3369'),
	(377, 1, 0, -50244, 3371, 0, 0, 39, '3370'),
	(377, 1, 0, -50244, 3372, 0, 0, 39, '3371'),
	(377, 1, 0, -50244, 3373, 0, 0, 39, '3372'),
	(377, 1, 0, -50244, 3374, 0, 0, 39, '3373'),
	(377, 1, 0, -50244, 3375, 0, 0, 39, '3374'),
	(377, 1, 0, -50244, 3376, 0, 0, 39, '3375'),
	(377, 1, 0, -50244, 3377, 0, 0, 39, '3376'),
	(377, 1, 0, -50244, 3378, 0, 0, 39, '3377'),
	(377, 1, 0, -50244, 3379, 0, 0, 39, '3378'),
	(377, 1, 0, -50244, 3380, 0, 0, 39, '3379'),
	(377, 1, 0, -50244, 3381, 0, 0, 39, '3380'),
	(377, 1, 0, -50244, 3382, 0, 0, 39, '3381'),
	(377, 1, 0, -50244, 3383, 0, 0, 39, '3382'),
	(377, 1, 0, -50244, 3384, 0, 0, 39, '3383'),
	(377, 1, 0, -50244, 3385, 0, 0, 39, '3384'),
	(377, 1, 0, -50244, 3386, 0, 0, 39, '3385'),
	(377, 1, 0, -50244, 3387, 0, 0, 39, '3386'),
	(377, 1, 0, -50244, 3388, 0, 0, 39, '3387'),
	(377, 1, 0, -50244, 3389, 0, 0, 39, '3388'),
	(377, 1, 0, -50244, 3390, 0, 0, 39, '3389'),
	(377, 1, 0, -50244, 3391, 0, 0, 39, '3390'),
	(377, 1, 0, -50244, 3392, 0, 0, 39, '3391'),
	(377, 1, 0, -50244, 3393, 0, 0, 39, '3392'),
	(377, 1, 0, -50244, 3394, 0, 0, 39, '3393'),
	(377, 1, 0, -50244, 3395, 0, 0, 39, '3394'),
	(377, 1, 0, -50244, 3396, 0, 0, 39, '3395'),
	(377, 1, 0, -50244, 3397, 0, 0, 39, '3396'),
	(377, 1, 0, -50244, 3398, 0, 0, 39, '3397'),
	(377, 1, 0, -50244, 3399, 0, 0, 39, '3398'),
	(377, 1, 0, -50244, 3400, 0, 0, 39, '3399'),
	(377, 1, 0, -50244, 3401, 0, 0, 39, '3400'),
	(377, 1, 0, -50244, 3402, 0, 0, 39, '3401'),
	(377, 1, 0, -50244, 3403, 0, 0, 39, '3402'),
	(377, 1, 0, -50244, 3404, 0, 0, 39, '3403'),
	(377, 1, 0, -50244, 3405, 0, 0, 39, '3404'),
	(377, 1, 0, -50244, 3406, 0, 0, 39, '3405'),
	(377, 1, 0, -50244, 3407, 0, 0, 39, '3406'),
	(377, 1, 0, -50244, 3408, 0, 0, 39, '3407'),
	(377, 1, 0, -50244, 3409, 0, 0, 39, '3408'),
	(377, 1, 0, -50244, 3410, 0, 0, 39, '3409'),
	(377, 1, 0, -50244, 3411, 0, 0, 39, '3410'),
	(377, 1, 0, -50244, 3412, 0, 0, 39, '3411'),
	(377, 1, 0, -50244, 3413, 0, 0, 39, '3412'),
	(377, 1, 0, -50244, 3414, 0, 0, 39, '3413'),
	(377, 1, 0, -50244, 3415, 0, 0, 39, '3414'),
	(377, 1, 0, -50244, 3416, 0, 0, 39, '3415'),
	(377, 1, 0, -50244, 3417, 0, 0, 39, '3416'),
	(377, 1, 0, -50244, 3418, 0, 0, 39, '3417'),
	(377, 1, 0, -50244, 3419, 0, 0, 39, '3418'),
	(377, 1, 0, -50244, 3420, 0, 0, 39, '3419'),
	(377, 1, 0, -50244, 3421, 0, 0, 39, '3420'),
	(377, 1, 0, -50244, 3422, 0, 0, 39, '3421'),
	(377, 1, 0, -50244, 3423, 0, 0, 39, '3422'),
	(377, 1, 0, -50244, 3424, 0, 0, 39, '3423'),
	(377, 1, 0, -50244, 3425, 0, 0, 39, '3424'),
	(377, 1, 0, -50244, 3426, 0, 0, 39, '3425'),
	(377, 1, 0, -50244, 3427, 0, 0, 39, '3426'),
	(377, 1, 0, -50244, 3428, 0, 0, 39, '3427'),
	(377, 1, 0, -50244, 3429, 0, 0, 39, '3428'),
	(377, 1, 0, -50244, 3430, 0, 0, 39, '3429'),
	(377, 1, 0, -50244, 3431, 0, 0, 39, '3430'),
	(377, 1, 0, -50244, 3432, 0, 0, 39, '3431'),
	(377, 1, 0, -50244, 3433, 0, 0, 39, '3432'),
	(377, 1, 0, -50244, 3434, 0, 0, 39, '3433'),
	(377, 1, 0, -50244, 3435, 0, 0, 39, '3434'),
	(377, 1, 0, -50244, 3436, 0, 0, 39, '3435'),
	(377, 1, 0, -50244, 3437, 0, 0, 39, '3436'),
	(377, 1, 0, -50244, 3438, 0, 0, 39, '3437'),
	(377, 1, 0, -50244, 3439, 0, 0, 39, '3438'),
	(377, 1, 0, -50244, 3440, 0, 0, 39, '3439'),
	(377, 1, 0, -50244, 3441, 0, 0, 39, '3440'),
	(377, 1, 0, -50244, 3442, 0, 0, 39, '3441'),
	(377, 1, 0, -50244, 3443, 0, 0, 39, '3442'),
	(377, 1, 0, -50244, 3444, 0, 0, 39, '3443'),
	(377, 1, 0, -50244, 3445, 0, 0, 39, '3444'),
	(377, 1, 0, -50244, 3446, 0, 0, 39, '3445'),
	(377, 1, 0, -50244, 3447, 0, 0, 39, '3446'),
	(377, 1, 0, -50244, 3448, 0, 0, 39, '3447'),
	(377, 1, 0, -50244, 3449, 0, 0, 39, '3448'),
	(377, 1, 0, -50244, 3450, 0, 0, 39, '3449'),
	(377, 1, 0, -50244, 3451, 0, 0, 39, '3450'),
	(377, 1, 0, -50244, 3452, 0, 0, 39, '3451'),
	(377, 1, 0, -50244, 3453, 0, 0, 39, '3452'),
	(377, 1, 0, -50244, 3454, 0, 0, 39, '3453'),
	(377, 1, 0, -50244, 3455, 0, 0, 39, '3454'),
	(377, 1, 0, -50244, 3456, 0, 0, 39, '3455'),
	(377, 1, 0, -50244, 3457, 0, 0, 39, '3456'),
	(377, 1, 0, -50244, 3458, 0, 0, 39, '3457'),
	(377, 1, 0, -50244, 3459, 0, 0, 39, '3458'),
	(377, 1, 0, -50244, 3460, 0, 0, 39, '3459'),
	(377, 1, 0, -50244, 3461, 0, 0, 39, '3460'),
	(377, 1, 0, -50244, 3462, 0, 0, 39, '3461'),
	(377, 1, 0, -50244, 3463, 0, 0, 39, '3462'),
	(377, 1, 0, -50244, 3464, 0, 0, 39, '3463'),
	(377, 1, 0, -50244, 3465, 0, 0, 39, '3464'),
	(377, 1, 0, -50244, 3466, 0, 0, 39, '3465'),
	(377, 1, 0, -50244, 3467, 0, 0, 39, '3466'),
	(377, 1, 0, -50244, 3468, 0, 0, 39, '3467'),
	(377, 1, 0, -50244, 3469, 0, 0, 39, '3468'),
	(377, 1, 0, -50244, 3470, 0, 0, 39, '3469'),
	(377, 1, 0, -50244, 3471, 0, 0, 39, '3470'),
	(377, 1, 0, -50244, 3472, 0, 0, 39, '3471'),
	(377, 1, 0, -50244, 3473, 0, 0, 39, '3472'),
	(377, 1, 0, -50244, 3474, 0, 0, 39, '3473'),
	(377, 1, 0, -50244, 3475, 0, 0, 39, '3474'),
	(377, 1, 0, -50244, 3476, 0, 0, 39, '3475'),
	(377, 1, 0, -50244, 3477, 0, 0, 39, '3476'),
	(377, 1, 0, -50244, 3478, 0, 0, 39, '3477'),
	(377, 1, 0, -50244, 3479, 0, 0, 39, '3478'),
	(377, 1, 0, -50244, 3480, 0, 0, 39, '3479'),
	(377, 1, 0, -50244, 3481, 0, 0, 39, '3480'),
	(377, 1, 0, -50244, 3482, 0, 0, 39, '3481'),
	(377, 1, 0, -50244, 3483, 0, 0, 39, '3482'),
	(377, 1, 0, -50244, 3484, 0, 0, 39, '3483'),
	(377, 1, 0, -50244, 3485, 0, 0, 39, '3484'),
	(377, 1, 0, -50244, 3486, 0, 0, 39, '3485'),
	(377, 1, 0, -50244, 3487, 0, 0, 39, '3486'),
	(377, 1, 0, -50244, 3488, 0, 0, 39, '3487'),
	(377, 1, 0, -50244, 3489, 0, 0, 39, '3488'),
	(377, 1, 0, -50244, 3490, 0, 0, 39, '3489'),
	(377, 1, 0, -50244, 3491, 0, 0, 39, '3490'),
	(377, 1, 0, -50244, 3492, 0, 0, 39, '3491'),
	(377, 1, 0, -50244, 3493, 0, 0, 39, '3492'),
	(377, 1, 0, -50244, 3494, 0, 0, 39, '3493'),
	(377, 1, 0, -50244, 3495, 0, 0, 39, '3494'),
	(377, 1, 0, -50244, 3496, 0, 0, 39, '3495'),
	(377, 1, 0, -50244, 3497, 0, 0, 39, '3496'),
	(377, 1, 0, -50244, 3498, 0, 0, 39, '3497'),
	(377, 1, 0, -50244, 3499, 0, 0, 39, '3498'),
	(377, 1, 0, -50244, 3500, 0, 0, 39, '3499'),
	(377, 1, 0, -50244, 3501, 0, 0, 39, '3500'),
	(377, 1, 0, -50244, 3502, 0, 0, 39, '3501'),
	(377, 1, 0, -50244, 3503, 0, 0, 39, '3502'),
	(377, 1, 0, -50244, 3504, 0, 0, 39, '3503'),
	(377, 1, 0, -50244, 3505, 0, 0, 39, '3504'),
	(377, 1, 0, -50244, 3506, 0, 0, 39, '3505'),
	(377, 1, 0, -50244, 3507, 0, 0, 39, '3506'),
	(377, 1, 0, -50244, 3508, 0, 0, 39, '3507'),
	(377, 1, 0, -50244, 3509, 0, 0, 39, '3508'),
	(377, 1, 0, -50244, 3510, 0, 0, 39, '3509'),
	(377, 1, 0, -50244, 3511, 0, 0, 39, '3510'),
	(377, 1, 0, -50244, 3512, 0, 0, 39, '3511'),
	(377, 1, 0, -50244, 3513, 0, 0, 39, '3512'),
	(377, 1, 0, -50244, 3514, 0, 0, 39, '3513'),
	(377, 1, 0, -50244, 3515, 0, 0, 39, '3514'),
	(377, 1, 0, -50244, 3516, 0, 0, 39, '3515'),
	(377, 1, 0, -50244, 3517, 0, 0, 39, '3516'),
	(377, 1, 0, -50244, 3518, 0, 0, 39, '3517'),
	(377, 1, 0, -50244, 3519, 0, 0, 39, '3518'),
	(377, 1, 0, -50244, 3520, 0, 0, 39, '3519'),
	(377, 1, 0, -50244, 3521, 0, 0, 39, '3520'),
	(377, 1, 0, -50244, 3522, 0, 0, 39, '3521'),
	(377, 1, 0, -50244, 3523, 0, 0, 39, '3522'),
	(377, 1, 0, -50244, 3524, 0, 0, 39, '3523'),
	(377, 1, 0, -50244, 3525, 0, 0, 39, '3524'),
	(377, 1, 0, -50244, 3526, 0, 0, 39, '3525'),
	(377, 1, 0, -50244, 3527, 0, 0, 39, '3526'),
	(377, 1, 0, -50244, 3528, 0, 0, 39, '3527'),
	(377, 1, 0, -50244, 3529, 0, 0, 39, '3528'),
	(377, 1, 0, -50244, 3530, 0, 0, 39, '3529'),
	(377, 1, 0, -50244, 3531, 0, 0, 39, '3530'),
	(377, 1, 0, -50244, 3532, 0, 0, 39, '3531'),
	(377, 1, 0, -50244, 3533, 0, 0, 39, '3532'),
	(377, 1, 0, -50244, 3534, 0, 0, 39, '3533'),
	(377, 1, 0, -50244, 3535, 0, 0, 39, '3534'),
	(377, 1, 0, -50244, 3536, 0, 0, 39, '3535'),
	(377, 1, 0, -50244, 3537, 0, 0, 39, '3536'),
	(377, 1, 0, -50244, 3538, 0, 0, 39, '3537'),
	(377, 1, 0, -50244, 3539, 0, 0, 39, '3538'),
	(377, 1, 0, -50244, 3540, 0, 0, 39, '3539'),
	(377, 1, 0, -50244, 3541, 0, 0, 39, '3540'),
	(377, 1, 0, -50244, 3542, 0, 0, 39, '3541'),
	(377, 1, 0, -50244, 3543, 0, 0, 39, '3542'),
	(377, 1, 0, -50244, 3544, 0, 0, 39, '3543'),
	(377, 1, 0, -50244, 3545, 0, 0, 39, '3544'),
	(377, 1, 0, -50244, 3546, 0, 0, 39, '3545'),
	(377, 1, 0, -50244, 3547, 0, 0, 39, '3546'),
	(377, 1, 0, -50244, 3548, 0, 0, 39, '3547'),
	(377, 1, 0, -50244, 3549, 0, 0, 39, '3548'),
	(377, 1, 0, -50244, 3550, 0, 0, 39, '3549'),
	(377, 1, 0, -50244, 3551, 0, 0, 39, '3550'),
	(377, 1, 0, -50244, 3552, 0, 0, 39, '3551'),
	(377, 1, 0, -50244, 3553, 0, 0, 39, '3552'),
	(377, 1, 0, -50244, 3554, 0, 0, 39, '3553'),
	(377, 1, 0, -50244, 3555, 0, 0, 39, '3554'),
	(377, 1, 0, -50244, 3556, 0, 0, 39, '3555'),
	(377, 1, 0, -50244, 3557, 0, 0, 39, '3556'),
	(377, 1, 0, -50244, 3558, 0, 0, 39, '3557'),
	(377, 1, 0, -50244, 3559, 0, 0, 39, '3558'),
	(377, 1, 0, -50244, 3560, 0, 0, 39, '3559'),
	(377, 1, 0, -50244, 3561, 0, 0, 39, '3560'),
	(377, 1, 0, -50244, 3562, 0, 0, 39, '3561'),
	(377, 1, 0, -50244, 3563, 0, 0, 39, '3562'),
	(377, 1, 0, -50244, 3564, 0, 0, 39, '3563'),
	(377, 1, 0, -50244, 3565, 0, 0, 39, '3564'),
	(377, 1, 0, -50244, 3566, 0, 0, 39, '3565'),
	(377, 1, 0, -50244, 3567, 0, 0, 39, '3566'),
	(377, 1, 0, -50244, 3568, 0, 0, 39, '3567'),
	(377, 1, 0, -50244, 3569, 0, 0, 39, '3568'),
	(377, 1, 0, -50244, 3570, 0, 0, 39, '3569'),
	(377, 1, 0, -50244, 3571, 0, 0, 39, '3570'),
	(377, 1, 0, -50244, 3572, 0, 0, 39, '3571'),
	(377, 1, 0, -50244, 3573, 0, 0, 39, '3572'),
	(377, 1, 0, -50244, 3574, 0, 0, 39, '3573'),
	(377, 1, 0, -50244, 3575, 0, 0, 39, '3574'),
	(377, 1, 0, -50244, 3576, 0, 0, 39, '3575'),
	(377, 1, 0, -50244, 3577, 0, 0, 39, '3576'),
	(377, 1, 0, -50244, 3578, 0, 0, 39, '3577'),
	(377, 1, 0, -50244, 3579, 0, 0, 39, '3578'),
	(377, 1, 0, -50244, 3580, 0, 0, 39, '3579'),
	(377, 1, 0, -50244, 3581, 0, 0, 39, '3580'),
	(377, 1, 0, -50244, 3582, 0, 0, 39, '3581'),
	(377, 1, 0, -50244, 3583, 0, 0, 39, '3582'),
	(377, 1, 0, -50244, 3584, 0, 0, 39, '3583'),
	(377, 1, 0, -50244, 3585, 0, 0, 39, '3584'),
	(377, 1, 0, -50244, 3586, 0, 0, 39, '3585'),
	(377, 1, 0, -50244, 3587, 0, 0, 39, '3586'),
	(377, 1, 0, -50244, 3588, 0, 0, 39, '3587'),
	(377, 1, 0, -50244, 3589, 0, 0, 39, '3588'),
	(377, 1, 0, -50244, 3590, 0, 0, 39, '3589'),
	(377, 1, 0, -50244, 3591, 0, 0, 39, '3590'),
	(377, 1, 0, -50244, 3592, 0, 0, 39, '3591'),
	(377, 1, 0, -50244, 3593, 0, 0, 39, '3592'),
	(377, 1, 0, -50244, 3594, 0, 0, 39, '3593'),
	(377, 1, 0, -50244, 3595, 0, 0, 39, '3594'),
	(377, 1, 0, -50244, 3596, 0, 0, 39, '3595'),
	(377, 1, 0, -50244, 3597, 0, 0, 39, '3596'),
	(377, 1, 0, -50244, 3598, 0, 0, 39, '3597'),
	(377, 1, 0, -50244, 3599, 0, 0, 39, '3598'),
	(377, 1, 0, -50244, 3600, 0, 0, 39, '3599'),
	(377, 1, 0, -50244, 3601, 0, 0, 39, '3600'),
	(377, 1, 0, -50244, 3602, 0, 0, 39, '3601'),
	(377, 1, 0, -50244, 3603, 0, 0, 39, '3602'),
	(377, 1, 0, -50244, 3604, 0, 0, 39, '3603'),
	(377, 1, 0, -50244, 3605, 0, 0, 39, '3604'),
	(377, 1, 0, -50244, 3606, 0, 0, 39, '3605'),
	(377, 1, 0, -50244, 3607, 0, 0, 39, '3606'),
	(377, 1, 0, -50244, 3608, 0, 0, 39, '3607'),
	(377, 1, 0, -50244, 3609, 0, 0, 39, '3608'),
	(377, 1, 0, -50244, 3610, 0, 0, 39, '3609'),
	(377, 1, 0, -50244, 3611, 0, 0, 39, '3610'),
	(377, 1, 0, -50244, 3612, 0, 0, 39, '3611'),
	(377, 1, 0, -50244, 3613, 0, 0, 39, '3612'),
	(377, 1, 0, -50244, 3614, 0, 0, 39, '3613'),
	(377, 1, 0, -50244, 3615, 0, 0, 39, '3614'),
	(377, 1, 0, -50244, 3616, 0, 0, 39, '3615'),
	(377, 1, 0, -50244, 3617, 0, 0, 39, '3616'),
	(377, 1, 0, -50244, 3618, 0, 0, 39, '3617'),
	(377, 1, 0, -50244, 3619, 0, 0, 39, '3618'),
	(377, 1, 0, -50244, 3620, 0, 0, 39, '3619'),
	(377, 1, 0, -50244, 3621, 0, 0, 39, '3620'),
	(377, 1, 0, -50244, 3622, 0, 0, 39, '3621'),
	(377, 1, 0, -50244, 3623, 0, 0, 39, '3622'),
	(377, 1, 0, -50244, 3624, 0, 0, 39, '3623'),
	(377, 1, 0, -50244, 3625, 0, 0, 39, '3624'),
	(377, 1, 0, -50244, 3626, 0, 0, 39, '3625'),
	(377, 1, 0, -50244, 3627, 0, 0, 39, '3626'),
	(377, 1, 0, -50244, 3628, 0, 0, 39, '3627'),
	(377, 1, 0, -50244, 3629, 0, 0, 39, '3628'),
	(377, 1, 0, -50244, 3630, 0, 0, 39, '3629'),
	(377, 1, 0, -50244, 3631, 0, 0, 39, '3630'),
	(377, 1, 0, -50244, 3632, 0, 0, 39, '3631'),
	(377, 1, 0, -50244, 3633, 0, 0, 39, '3632'),
	(377, 1, 0, -50244, 3634, 0, 0, 39, '3633'),
	(377, 1, 0, -50244, 3635, 0, 0, 39, '3634'),
	(377, 1, 0, -50244, 3636, 0, 0, 39, '3635'),
	(377, 1, 0, -50244, 3637, 0, 0, 39, '3636'),
	(377, 1, 0, -50244, 3638, 0, 0, 39, '3637'),
	(377, 1, 0, -50244, 3639, 0, 0, 39, '3638'),
	(377, 1, 0, -50244, 3640, 0, 0, 39, '3639'),
	(377, 1, 0, -50244, 3641, 0, 0, 39, '3640'),
	(377, 1, 0, -50244, 3642, 0, 0, 39, '3641'),
	(377, 1, 0, -50244, 3643, 0, 0, 39, '3642'),
	(377, 1, 0, -50244, 3644, 0, 0, 39, '3643'),
	(377, 1, 0, -50244, 3645, 0, 0, 39, '3644'),
	(377, 1, 0, -50244, 3646, 0, 0, 39, '3645'),
	(377, 1, 0, -50244, 3647, 0, 0, 39, '3646'),
	(377, 1, 0, -50244, 3648, 0, 0, 39, '3647'),
	(377, 1, 0, -50244, 3649, 0, 0, 39, '3648'),
	(377, 1, 0, -50244, 3650, 0, 0, 39, '3649'),
	(377, 1, 0, -50244, 3651, 0, 0, 39, '3650'),
	(377, 1, 0, -50244, 3652, 0, 0, 39, '3651'),
	(377, 1, 0, -50244, 3653, 0, 0, 39, '3652'),
	(377, 1, 0, -50244, 3654, 0, 0, 39, '3653'),
	(377, 1, 0, -50244, 3655, 0, 0, 39, '3654'),
	(377, 1, 0, -50244, 3656, 0, 0, 39, '3655'),
	(377, 1, 0, -50244, 3657, 0, 0, 39, '3656'),
	(377, 1, 0, -50244, 3658, 0, 0, 39, '3657'),
	(377, 1, 0, -50244, 3659, 0, 0, 39, '3658'),
	(377, 1, 0, -50244, 3660, 0, 0, 39, '3659'),
	(377, 1, 0, -50244, 3661, 0, 0, 39, '3660'),
	(377, 1, 0, -50244, 3662, 0, 0, 39, '3661'),
	(377, 1, 0, -50244, 3663, 0, 0, 39, '3662'),
	(377, 1, 0, -50244, 3664, 0, 0, 39, '3663'),
	(377, 1, 0, -50244, 3665, 0, 0, 39, '3664'),
	(377, 1, 0, -50244, 3666, 0, 0, 39, '3665'),
	(377, 1, 0, -50244, 3667, 0, 0, 39, '3666'),
	(377, 1, 0, -50244, 3668, 0, 0, 39, '3667'),
	(377, 1, 0, -50244, 3669, 0, 0, 39, '3668'),
	(377, 1, 0, -50244, 3670, 0, 0, 39, '3669'),
	(377, 1, 0, -50244, 3671, 0, 0, 39, '3670'),
	(377, 1, 0, -50244, 3672, 0, 0, 39, '3671'),
	(377, 1, 0, -50244, 3673, 0, 0, 39, '3672'),
	(377, 1, 0, -50244, 3674, 0, 0, 39, '3673'),
	(377, 1, 0, -50244, 3675, 0, 0, 39, '3674'),
	(377, 1, 0, -50244, 3676, 0, 0, 39, '3675'),
	(377, 1, 0, -50244, 3677, 0, 0, 39, '3676'),
	(377, 1, 0, -50244, 3678, 0, 0, 39, '3677'),
	(377, 1, 0, -50244, 3679, 0, 0, 39, '3678'),
	(377, 1, 0, -50244, 3680, 0, 0, 39, '3679'),
	(377, 1, 0, -50244, 3681, 0, 0, 39, '3680'),
	(377, 1, 0, -50244, 3682, 0, 0, 39, '3681'),
	(377, 1, 0, -50244, 3683, 0, 0, 39, '3682'),
	(377, 1, 0, -50244, 3684, 0, 0, 39, '3683'),
	(377, 1, 0, -50244, 3685, 0, 0, 39, '3684'),
	(377, 1, 0, -50244, 3686, 0, 0, 39, '3685'),
	(377, 1, 0, -50244, 3687, 0, 0, 39, '3686'),
	(377, 1, 0, -50244, 3688, 0, 0, 39, '3687'),
	(377, 1, 0, -50244, 3689, 0, 0, 39, '3688'),
	(377, 1, 0, -50244, 3690, 0, 0, 39, '3689'),
	(377, 1, 0, -50244, 3691, 0, 0, 39, '3690'),
	(377, 1, 0, -50244, 3692, 0, 0, 39, '3691'),
	(377, 1, 0, -50244, 3693, 0, 0, 39, '3692'),
	(377, 1, 0, -50244, 3694, 0, 0, 39, '3693'),
	(377, 1, 0, -50244, 3695, 0, 0, 39, '3694'),
	(377, 1, 0, -50244, 3696, 0, 0, 39, '3695'),
	(377, 1, 0, -50244, 3697, 0, 0, 39, '3696'),
	(377, 1, 0, -50244, 3698, 0, 0, 39, '3697'),
	(377, 1, 0, -50244, 3699, 0, 0, 39, '3698'),
	(377, 1, 0, -50244, 3700, 0, 0, 39, '3699'),
	(377, 1, 0, -50244, 3701, 0, 0, 39, '3700'),
	(377, 1, 0, -50244, 3702, 0, 0, 39, '3701'),
	(377, 1, 0, -50244, 3703, 0, 0, 39, '3702'),
	(377, 1, 0, -50244, 3704, 0, 0, 39, '3703'),
	(377, 1, 0, -50244, 3705, 0, 0, 39, '3704'),
	(377, 1, 0, -50244, 3706, 0, 0, 39, '3705'),
	(377, 1, 0, -50244, 3707, 0, 0, 39, '3706'),
	(377, 1, 0, -50244, 3708, 0, 0, 39, '3707'),
	(377, 1, 0, -50244, 3709, 0, 0, 39, '3708'),
	(377, 1, 0, -50244, 3710, 0, 0, 39, '3709'),
	(377, 1, 0, -50244, 3711, 0, 0, 39, '3710'),
	(377, 1, 0, -50244, 3712, 0, 0, 39, '3711'),
	(377, 1, 0, -50244, 3713, 0, 0, 39, '3712'),
	(377, 1, 0, -50244, 3714, 0, 0, 39, '3713'),
	(377, 1, 0, -50244, 3715, 0, 0, 39, '3714'),
	(377, 1, 0, -50244, 3716, 0, 0, 39, '3715'),
	(377, 1, 0, -50244, 3717, 0, 0, 39, '3716'),
	(377, 1, 0, -50244, 3718, 0, 0, 39, '3717'),
	(377, 1, 0, -50244, 3719, 0, 0, 39, '3718'),
	(377, 1, 0, -50244, 3720, 0, 0, 39, '3719'),
	(377, 1, 0, -50244, 3721, 0, 0, 39, '3720'),
	(377, 1, 0, -50244, 3722, 0, 0, 39, '3721'),
	(377, 1, 0, -50244, 3723, 0, 0, 39, '3722'),
	(377, 1, 0, -50244, 3724, 0, 0, 39, '3723'),
	(377, 1, 0, -50244, 3725, 0, 0, 39, '3724'),
	(377, 1, 0, -50244, 3726, 0, 0, 39, '3725'),
	(377, 1, 0, -50244, 3727, 0, 0, 39, '3726'),
	(377, 1, 0, -50244, 3728, 0, 0, 39, '3727'),
	(377, 1, 0, -50244, 3729, 0, 0, 39, '3728'),
	(377, 1, 0, -50244, 3730, 0, 0, 39, '3729'),
	(377, 1, 0, -50244, 3731, 0, 0, 39, '3730'),
	(377, 1, 0, -50244, 3732, 0, 0, 39, '3731'),
	(377, 1, 0, -50244, 3733, 0, 0, 39, '3732'),
	(377, 1, 0, -50244, 3734, 0, 0, 39, '3733'),
	(377, 1, 0, -50244, 3735, 0, 0, 39, '3734'),
	(377, 1, 0, -50244, 3736, 0, 0, 39, '3735'),
	(377, 1, 0, -50244, 3737, 0, 0, 39, '3736'),
	(377, 1, 0, -50244, 3738, 0, 0, 39, '3737'),
	(377, 1, 0, -50244, 3739, 0, 0, 39, '3738'),
	(377, 1, 0, -50244, 3740, 0, 0, 39, '3739'),
	(377, 1, 0, -50244, 3741, 0, 0, 39, '3740'),
	(377, 1, 0, -50244, 3742, 0, 0, 39, '3741'),
	(377, 1, 0, -50244, 3743, 0, 0, 39, '3742'),
	(377, 1, 0, -50244, 3744, 0, 0, 39, '3743'),
	(377, 1, 0, -50244, 3745, 0, 0, 39, '3744'),
	(377, 1, 0, -50244, 3746, 0, 0, 39, '3745'),
	(377, 1, 0, -50244, 3747, 0, 0, 39, '3746'),
	(377, 1, 0, -50244, 3748, 0, 0, 39, '3747'),
	(377, 1, 0, -50244, 3749, 0, 0, 39, '3748'),
	(377, 1, 0, -50244, 3750, 0, 0, 39, '3749'),
	(377, 1, 0, -50244, 3751, 0, 0, 39, '3750'),
	(377, 1, 0, -50244, 3752, 0, 0, 39, '3751'),
	(377, 1, 0, -50244, 3753, 0, 0, 39, '3752'),
	(377, 1, 0, -50244, 3754, 0, 0, 39, '3753'),
	(377, 1, 0, -50244, 3755, 0, 0, 39, '3754'),
	(377, 1, 0, -50244, 3756, 0, 0, 39, '3755'),
	(377, 1, 0, -50244, 3757, 0, 0, 39, '3756'),
	(377, 1, 0, -50244, 3758, 0, 0, 39, '3757'),
	(377, 1, 0, -50244, 3759, 0, 0, 39, '3758'),
	(377, 1, 0, -50244, 3760, 0, 0, 39, '3759'),
	(377, 1, 0, -50244, 3761, 0, 0, 39, '3760'),
	(377, 1, 0, -50244, 3762, 0, 0, 39, '3761'),
	(377, 1, 0, -50244, 3763, 0, 0, 39, '3762'),
	(377, 1, 0, -50244, 3764, 0, 0, 39, '3763'),
	(377, 1, 0, -50244, 3765, 0, 0, 39, '3764'),
	(377, 1, 0, -50244, 3766, 0, 0, 39, '3765'),
	(377, 1, 0, -50244, 3767, 0, 0, 39, '3766'),
	(377, 1, 0, -50244, 3768, 0, 0, 39, '3767'),
	(377, 1, 0, -50244, 3769, 0, 0, 39, '3768'),
	(377, 1, 0, -50244, 3770, 0, 0, 39, '3769'),
	(377, 1, 0, -50244, 3771, 0, 0, 39, '3770'),
	(377, 1, 0, -50244, 3772, 0, 0, 39, '3771'),
	(377, 1, 0, -50244, 3773, 0, 0, 39, '3772'),
	(377, 1, 0, -50244, 3774, 0, 0, 39, '3773'),
	(377, 1, 0, -50244, 3775, 0, 0, 39, '3774'),
	(377, 1, 0, -50244, 3776, 0, 0, 39, '3775'),
	(377, 1, 0, -50244, 3777, 0, 0, 39, '3776'),
	(377, 1, 0, -50244, 3778, 0, 0, 39, '3777'),
	(377, 1, 0, -50244, 3779, 0, 0, 39, '3778'),
	(377, 1, 0, -50244, 3780, 0, 0, 39, '3779'),
	(377, 1, 0, -50244, 3781, 0, 0, 39, '3780'),
	(377, 1, 0, -50244, 3782, 0, 0, 39, '3781'),
	(377, 1, 0, -50244, 3783, 0, 0, 39, '3782'),
	(377, 1, 0, -50244, 3784, 0, 0, 39, '3783'),
	(377, 1, 0, -50244, 3785, 0, 0, 39, '3784'),
	(377, 1, 0, -50244, 3786, 0, 0, 39, '3785'),
	(377, 1, 0, -50244, 3787, 0, 0, 39, '3786'),
	(377, 1, 0, -50244, 3788, 0, 0, 39, '3787'),
	(377, 1, 0, -50244, 3789, 0, 0, 39, '3788'),
	(377, 1, 0, -50244, 3790, 0, 0, 39, '3789'),
	(377, 1, 0, -50244, 3791, 0, 0, 39, '3790'),
	(377, 1, 0, -50244, 3792, 0, 0, 39, '3791'),
	(377, 1, 0, -50244, 3793, 0, 0, 39, '3792'),
	(377, 1, 0, -50244, 3794, 0, 0, 39, '3793'),
	(377, 1, 0, -50244, 3795, 0, 0, 39, '3794'),
	(377, 1, 0, -50244, 3796, 0, 0, 39, '3795'),
	(377, 1, 0, -50244, 3797, 0, 0, 39, '3796'),
	(377, 1, 0, -50244, 3798, 0, 0, 39, '3797'),
	(377, 1, 0, -50244, 3799, 0, 0, 39, '3798'),
	(377, 1, 0, -50244, 3800, 0, 0, 39, '3799'),
	(377, 1, 0, -50244, 3801, 0, 0, 39, '3800'),
	(377, 1, 0, -50244, 3802, 0, 0, 39, '3801'),
	(377, 1, 0, -50244, 3803, 0, 0, 39, '3802'),
	(377, 1, 0, -50244, 3804, 0, 0, 39, '3803'),
	(377, 1, 0, -50244, 3805, 0, 0, 39, '3804'),
	(377, 1, 0, -50244, 3806, 0, 0, 39, '3805'),
	(377, 1, 0, -50244, 3807, 0, 0, 39, '3806'),
	(377, 1, 0, -50244, 3808, 0, 0, 39, '3807'),
	(377, 1, 0, -50244, 3809, 0, 0, 39, '3808'),
	(377, 1, 0, -50244, 3810, 0, 0, 39, '3809'),
	(377, 1, 0, -50244, 3811, 0, 0, 39, '3810'),
	(377, 1, 0, -50244, 3812, 0, 0, 39, '3811'),
	(377, 1, 0, -50244, 3813, 0, 0, 39, '3812'),
	(377, 1, 0, -50244, 3814, 0, 0, 39, '3813'),
	(377, 1, 0, -50244, 3815, 0, 0, 39, '3814'),
	(377, 1, 0, -50244, 3816, 0, 0, 39, '3815'),
	(377, 1, 0, -50244, 3817, 0, 0, 39, '3816'),
	(377, 1, 0, -50244, 3818, 0, 0, 39, '3817'),
	(377, 1, 0, -50244, 3819, 0, 0, 39, '3818'),
	(377, 1, 0, -50244, 3820, 0, 0, 39, '3819'),
	(377, 1, 0, -50244, 3821, 0, 0, 39, '3820'),
	(377, 1, 0, -50244, 3822, 0, 0, 39, '3821'),
	(377, 1, 0, -50244, 3823, 0, 0, 39, '3822'),
	(377, 1, 0, -50244, 3824, 0, 0, 39, '3823'),
	(377, 1, 0, -50244, 3825, 0, 0, 39, '3824'),
	(377, 1, 0, -50244, 3826, 0, 0, 39, '3825'),
	(377, 1, 0, -50244, 3827, 0, 0, 39, '3826'),
	(377, 1, 0, -50244, 3828, 0, 0, 39, '3827'),
	(377, 1, 0, -50244, 3829, 0, 0, 39, '3828'),
	(377, 1, 0, -50244, 3830, 0, 0, 39, '3829'),
	(377, 1, 0, -50244, 3831, 0, 0, 39, '3830'),
	(377, 1, 0, -50244, 3832, 0, 0, 39, '3831'),
	(377, 1, 0, -50244, 3833, 0, 0, 39, '3832'),
	(377, 1, 0, -50244, 3834, 0, 0, 39, '3833'),
	(377, 1, 0, -50244, 3835, 0, 0, 39, '3834'),
	(377, 1, 0, -50244, 3836, 0, 0, 39, '3835'),
	(377, 1, 0, -50244, 3837, 0, 0, 39, '3836'),
	(377, 1, 0, -50244, 3838, 0, 0, 39, '3837'),
	(377, 1, 0, -50244, 3839, 0, 0, 39, '3838'),
	(377, 1, 0, -50244, 3840, 0, 0, 39, '3839'),
	(377, 1, 0, -50244, 3841, 0, 0, 39, '3840'),
	(377, 1, 0, -50244, 3842, 0, 0, 39, '3841'),
	(377, 1, 0, -50244, 3843, 0, 0, 39, '3842'),
	(377, 1, 0, -50244, 3844, 0, 0, 39, '3843'),
	(377, 1, 0, -50244, 3845, 0, 0, 39, '3844'),
	(377, 1, 0, -50244, 3846, 0, 0, 39, '3845'),
	(377, 1, 0, -50244, 3847, 0, 0, 39, '3846'),
	(377, 1, 0, -50244, 3848, 0, 0, 39, '3847'),
	(377, 1, 0, -50244, 3849, 0, 0, 39, '3848'),
	(377, 1, 0, -50244, 3850, 0, 0, 39, '3849'),
	(377, 1, 0, -50244, 3851, 0, 0, 39, '3850'),
	(377, 1, 0, -50244, 3852, 0, 0, 39, '3851'),
	(377, 1, 0, -50244, 3853, 0, 0, 39, '3852'),
	(377, 1, 0, -50244, 3854, 0, 0, 39, '3853'),
	(377, 1, 0, -50244, 3855, 0, 0, 39, '3854'),
	(377, 1, 0, -50244, 3856, 0, 0, 39, '3855'),
	(377, 1, 0, -50244, 3857, 0, 0, 39, '3856'),
	(377, 1, 0, -50244, 3858, 0, 0, 39, '3857'),
	(377, 1, 0, -50244, 3859, 0, 0, 39, '3858'),
	(377, 1, 0, -50244, 3860, 0, 0, 39, '3859'),
	(377, 1, 0, -50244, 3861, 0, 0, 39, '3860'),
	(377, 1, 0, -50244, 3862, 0, 0, 39, '3861'),
	(377, 1, 0, -50244, 3863, 0, 0, 39, '3862'),
	(377, 1, 0, -50244, 3864, 0, 0, 39, '3863'),
	(377, 1, 0, -50244, 3865, 0, 0, 39, '3864'),
	(377, 1, 0, -50244, 3866, 0, 0, 39, '3865'),
	(377, 1, 0, -50244, 3867, 0, 0, 39, '3866'),
	(377, 1, 0, -50244, 3868, 0, 0, 39, '3867'),
	(377, 1, 0, -50244, 3869, 0, 0, 39, '3868'),
	(377, 1, 0, -50244, 3870, 0, 0, 39, '3869'),
	(377, 1, 0, -50244, 3871, 0, 0, 39, '3870'),
	(377, 1, 0, -50244, 3872, 0, 0, 39, '3871'),
	(377, 1, 0, -50244, 3873, 0, 0, 39, '3872'),
	(377, 1, 0, -50244, 3874, 0, 0, 39, '3873'),
	(377, 1, 0, -50244, 3875, 0, 0, 39, '3874'),
	(377, 1, 0, -50244, 3876, 0, 0, 39, '3875'),
	(377, 1, 0, -50244, 3877, 0, 0, 39, '3876'),
	(377, 1, 0, -50244, 3878, 0, 0, 39, '3877'),
	(377, 1, 0, -50244, 3879, 0, 0, 39, '3878'),
	(377, 1, 0, -50244, 3880, 0, 0, 39, '3879'),
	(377, 1, 0, -50244, 3881, 0, 0, 39, '3880'),
	(377, 1, 0, -50244, 3882, 0, 0, 39, '3881'),
	(377, 1, 0, -50244, 3883, 0, 0, 39, '3882'),
	(377, 1, 0, -50244, 3884, 0, 0, 39, '3883'),
	(377, 1, 0, -50244, 3885, 0, 0, 39, '3884'),
	(377, 1, 0, -50244, 3886, 0, 0, 39, '3885'),
	(377, 1, 0, -50244, 3887, 0, 0, 39, '3886'),
	(377, 1, 0, -50244, 3888, 0, 0, 39, '3887'),
	(377, 1, 0, -50244, 3889, 0, 0, 39, '3888'),
	(377, 1, 0, -50244, 3890, 0, 0, 39, '3889'),
	(377, 1, 0, -50244, 3891, 0, 0, 39, '3890'),
	(377, 1, 0, -50244, 3892, 0, 0, 39, '3891'),
	(377, 1, 0, -50244, 3893, 0, 0, 39, '3892'),
	(377, 1, 0, -50244, 3894, 0, 0, 39, '3893'),
	(377, 1, 0, -50244, 3895, 0, 0, 39, '3894'),
	(377, 1, 0, -50244, 3896, 0, 0, 39, '3895'),
	(377, 1, 0, -50244, 3897, 0, 0, 39, '3896'),
	(377, 1, 0, -50244, 3898, 0, 0, 39, '3897'),
	(377, 1, 0, -50244, 3899, 0, 0, 39, '3898'),
	(377, 1, 0, -50244, 3900, 0, 0, 39, '3899'),
	(377, 1, 0, -50244, 3901, 0, 0, 39, '3900'),
	(377, 1, 0, -50244, 3902, 0, 0, 39, '3901'),
	(377, 1, 0, -50244, 3903, 0, 0, 39, '3902'),
	(377, 1, 0, -50244, 3904, 0, 0, 39, '3903'),
	(377, 1, 0, -50244, 3905, 0, 0, 39, '3904'),
	(377, 1, 0, -50244, 3906, 0, 0, 39, '3905'),
	(377, 1, 0, -50244, 3907, 0, 0, 39, '3906'),
	(377, 1, 0, -50244, 3908, 0, 0, 39, '3907'),
	(377, 1, 0, -50244, 3909, 0, 0, 39, '3908'),
	(377, 1, 0, -50244, 3910, 0, 0, 39, '3909'),
	(377, 1, 0, -50244, 3911, 0, 0, 39, '3910'),
	(377, 1, 0, -50244, 3912, 0, 0, 39, '3911'),
	(377, 1, 0, -50244, 3913, 0, 0, 39, '3912'),
	(377, 1, 0, -50244, 3914, 0, 0, 39, '3913'),
	(377, 1, 0, -50244, 3915, 0, 0, 39, '3914'),
	(377, 1, 0, -50244, 3916, 0, 0, 39, '3915'),
	(377, 1, 0, -50244, 3917, 0, 0, 39, '3916'),
	(377, 1, 0, -50244, 3918, 0, 0, 39, '3917'),
	(377, 1, 0, -50244, 3919, 0, 0, 39, '3918'),
	(377, 1, 0, -50244, 3920, 0, 0, 39, '3919'),
	(377, 1, 0, -50244, 3921, 0, 0, 39, '3920'),
	(377, 1, 0, -50244, 3922, 0, 0, 39, '3921'),
	(377, 1, 0, -50244, 3923, 0, 0, 39, '3922'),
	(377, 1, 0, -50244, 3924, 0, 0, 39, '3923'),
	(377, 1, 0, -50244, 3925, 0, 0, 39, '3924'),
	(377, 1, 0, -50244, 3926, 0, 0, 39, '3925'),
	(377, 1, 0, -50244, 3927, 0, 0, 39, '3926'),
	(377, 1, 0, -50244, 3928, 0, 0, 39, '3927'),
	(377, 1, 0, -50244, 3929, 0, 0, 39, '3928'),
	(377, 1, 0, -50244, 3930, 0, 0, 39, '3929'),
	(377, 1, 0, -50244, 3931, 0, 0, 39, '3930'),
	(377, 1, 0, -50244, 3932, 0, 0, 39, '3931'),
	(377, 1, 0, -50244, 3933, 0, 0, 39, '3932'),
	(377, 1, 0, -50244, 3934, 0, 0, 39, '3933'),
	(377, 1, 0, -50244, 3935, 0, 0, 39, '3934'),
	(377, 1, 0, -50244, 3936, 0, 0, 39, '3935'),
	(377, 1, 0, -50244, 3937, 0, 0, 39, '3936'),
	(377, 1, 0, -50244, 3938, 0, 0, 39, '3937'),
	(377, 1, 0, -50244, 3939, 0, 0, 39, '3938'),
	(377, 1, 0, -50244, 3940, 0, 0, 39, '3939'),
	(377, 1, 0, -50244, 3941, 0, 0, 39, '3940'),
	(377, 1, 0, -50244, 3942, 0, 0, 39, '3941'),
	(377, 1, 0, -50244, 3943, 0, 0, 39, '3942'),
	(377, 1, 0, -50244, 3944, 0, 0, 39, '3943'),
	(377, 1, 0, -50244, 3945, 0, 0, 39, '3944'),
	(377, 1, 0, -50244, 3946, 0, 0, 39, '3945'),
	(377, 1, 0, -50244, 3947, 0, 0, 39, '3946'),
	(377, 1, 0, -50244, 3948, 0, 0, 39, '3947'),
	(377, 1, 0, -50244, 3949, 0, 0, 39, '3948'),
	(377, 1, 0, -50244, 3950, 0, 0, 39, '3949'),
	(377, 1, 0, -50244, 3951, 0, 0, 39, '3950'),
	(377, 1, 0, -50244, 3952, 0, 0, 39, '3951'),
	(377, 1, 0, -50244, 3953, 0, 0, 39, '3952'),
	(377, 1, 0, -50244, 3954, 0, 0, 39, '3953'),
	(377, 1, 0, -50244, 3955, 0, 0, 39, '3954'),
	(377, 1, 0, -50244, 3956, 0, 0, 39, '3955'),
	(377, 1, 0, -50244, 3957, 0, 0, 39, '3956'),
	(377, 1, 0, -50244, 3958, 0, 0, 39, '3957'),
	(377, 1, 0, -50244, 3959, 0, 0, 39, '3958'),
	(377, 1, 0, -50244, 3960, 0, 0, 39, '3959'),
	(377, 1, 0, -50244, 3961, 0, 0, 39, '3960'),
	(377, 1, 0, -50244, 3962, 0, 0, 39, '3961'),
	(377, 1, 0, -50244, 3963, 0, 0, 39, '3962'),
	(377, 1, 0, -50244, 3964, 0, 0, 39, '3963'),
	(377, 1, 0, -50244, 3965, 0, 0, 39, '3964'),
	(377, 1, 0, -50244, 3966, 0, 0, 39, '3965'),
	(377, 1, 0, -50244, 3967, 0, 0, 39, '3966'),
	(377, 1, 0, -50244, 3968, 0, 0, 39, '3967'),
	(377, 1, 0, -50244, 3969, 0, 0, 39, '3968'),
	(377, 1, 0, -50244, 3970, 0, 0, 39, '3969'),
	(377, 1, 0, -50244, 3971, 0, 0, 39, '3970'),
	(377, 1, 0, -50244, 3972, 0, 0, 39, '3971'),
	(377, 1, 0, -50244, 3973, 0, 0, 39, '3972'),
	(377, 1, 0, -50244, 3974, 0, 0, 39, '3973'),
	(377, 1, 0, -50244, 3975, 0, 0, 39, '3974'),
	(377, 1, 0, -50244, 3976, 0, 0, 39, '3975'),
	(377, 1, 0, -50244, 3977, 0, 0, 39, '3976'),
	(377, 1, 0, -50244, 3978, 0, 0, 39, '3977'),
	(377, 1, 0, -50244, 3979, 0, 0, 39, '3978'),
	(377, 1, 0, -50244, 3980, 0, 0, 39, '3979'),
	(377, 1, 0, -50244, 3981, 0, 0, 39, '3980'),
	(377, 1, 0, -50244, 3982, 0, 0, 39, '3981'),
	(377, 1, 0, -50244, 3983, 0, 0, 39, '3982'),
	(377, 1, 0, -50244, 3984, 0, 0, 39, '3983'),
	(377, 1, 0, -50244, 3985, 0, 0, 39, '3984'),
	(377, 1, 0, -50244, 3986, 0, 0, 39, '3985'),
	(377, 1, 0, -50244, 3987, 0, 0, 39, '3986'),
	(377, 1, 0, -50244, 3988, 0, 0, 39, '3987'),
	(377, 1, 0, -50244, 3989, 0, 0, 39, '3988'),
	(377, 1, 0, -50244, 3990, 0, 0, 39, '3989'),
	(377, 1, 0, -50244, 3991, 0, 0, 39, '3990'),
	(377, 1, 0, -50244, 3992, 0, 0, 39, '3991'),
	(377, 1, 0, -50244, 3993, 0, 0, 39, '3992'),
	(377, 1, 0, -50244, 3994, 0, 0, 39, '3993'),
	(377, 1, 0, -50244, 3995, 0, 0, 39, '3994'),
	(377, 1, 0, -50244, 3996, 0, 0, 39, '3995'),
	(377, 1, 0, -50244, 3997, 0, 0, 39, '3996'),
	(377, 1, 0, -50244, 3998, 0, 0, 39, '3997'),
	(377, 1, 0, -50244, 3999, 0, 0, 39, '3998'),
	(377, 1, 0, -50244, 4000, 0, 0, 39, '3999'),
	(377, 1, 0, -50242, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50242, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50242, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50242, 4, 0, 0, 39, '3'),
	(377, 1, 0, -50242, 5, 0, 0, 39, '4'),
	(377, 1, 0, -50242, 6, 0, 0, 39, '5'),
	(377, 1, 0, -50242, 7, 0, 0, 39, '6'),
	(377, 1, 0, -50242, 8, 0, 0, 39, '7'),
	(377, 1, 0, -50242, 9, 0, 0, 39, '8'),
	(377, 1, 0, -50242, 10, 0, 0, 39, '9'),
	(377, 1, 0, -50242, 11, 0, 0, 39, '10'),
	(377, 1, 0, -50242, 12, 0, 0, 39, '11'),
	(377, 1, 0, -50242, 13, 0, 0, 39, '12'),
	(377, 1, 0, -50242, 14, 0, 0, 39, '13'),
	(377, 1, 0, -50242, 15, 0, 0, 39, '14'),
	(377, 1, 0, -50242, 16, 0, 0, 39, '15'),
	(377, 1, 0, -50242, 17, 0, 0, 39, '16'),
	(377, 1, 0, -50242, 18, 0, 0, 39, '17'),
	(377, 1, 0, -50242, 19, 0, 0, 39, '18'),
	(377, 1, 0, -50242, 20, 0, 0, 39, '19'),
	(377, 1, 0, -50242, 21, 0, 0, 39, '20'),
	(377, 1, 0, -50242, 22, 0, 0, 39, '21'),
	(377, 1, 0, -50242, 23, 0, 0, 39, '22'),
	(377, 1, 0, -50242, 24, 0, 0, 39, '23'),
	(377, 1, 0, -50242, 25, 0, 0, 39, '24'),
	(377, 1, 0, -50242, 26, 0, 0, 39, '25'),
	(377, 1, 0, -50242, 27, 0, 0, 39, '26'),
	(377, 1, 0, -50242, 28, 0, 0, 39, '27'),
	(377, 1, 0, -50242, 29, 0, 0, 39, '28'),
	(377, 1, 0, -50242, 30, 0, 0, 39, '29'),
	(377, 1, 0, -50242, 31, 0, 0, 39, '30'),
	(377, 1, 0, -50242, 32, 0, 0, 39, '31'),
	(377, 1, 0, -50242, 33, 0, 0, 39, '32'),
	(377, 1, 0, -50242, 34, 0, 0, 39, '33'),
	(377, 1, 0, -50242, 35, 0, 0, 39, '34'),
	(377, 1, 0, -50242, 36, 0, 0, 39, '35'),
	(377, 1, 0, -50242, 37, 0, 0, 39, '36'),
	(377, 1, 0, -50242, 38, 0, 0, 39, '37'),
	(377, 1, 0, -50242, 39, 0, 0, 39, '38'),
	(377, 1, 0, -50242, 40, 0, 0, 39, '39'),
	(377, 1, 0, -50242, 41, 0, 0, 39, '40'),
	(377, 1, 0, -50242, 42, 0, 0, 39, '41'),
	(377, 1, 0, -50242, 43, 0, 0, 39, '42'),
	(377, 1, 0, -50242, 44, 0, 0, 39, '43'),
	(377, 1, 0, -50242, 45, 0, 0, 39, '44'),
	(377, 1, 0, -50242, 46, 0, 0, 39, '45'),
	(377, 1, 0, -50242, 47, 0, 0, 39, '46'),
	(377, 1, 0, -50242, 48, 0, 0, 39, '47'),
	(377, 1, 0, -50242, 49, 0, 0, 39, '48'),
	(377, 1, 0, -50242, 50, 0, 0, 39, '49'),
	(377, 1, 0, -50242, 51, 0, 0, 39, '50'),
	(377, 1, 0, -50242, 52, 0, 0, 39, '51'),
	(377, 1, 0, -50242, 53, 0, 0, 39, '52'),
	(377, 1, 0, -50242, 54, 0, 0, 39, '53'),
	(377, 1, 0, -50242, 55, 0, 0, 39, '54'),
	(377, 1, 0, -50242, 56, 0, 0, 39, '55'),
	(377, 1, 0, -50242, 57, 0, 0, 39, '56'),
	(377, 1, 0, -50242, 58, 0, 0, 39, '57'),
	(377, 1, 0, -50242, 59, 0, 0, 39, '58'),
	(377, 1, 0, -50242, 60, 0, 0, 39, '59'),
	(377, 1, 0, -50242, 61, 0, 0, 39, '60'),
	(377, 1, 0, -50242, 62, 0, 0, 39, '61'),
	(377, 1, 0, -50242, 63, 0, 0, 39, '62'),
	(377, 1, 0, -50242, 64, 0, 0, 39, '63'),
	(377, 1, 0, -50242, 65, 0, 0, 39, '64'),
	(377, 1, 0, -50242, 66, 0, 0, 39, '65'),
	(377, 1, 0, -50242, 67, 0, 0, 39, '66'),
	(377, 1, 0, -50242, 68, 0, 0, 39, '67'),
	(377, 1, 0, -50242, 69, 0, 0, 39, '68'),
	(377, 1, 0, -50242, 70, 0, 0, 39, '69'),
	(377, 1, 0, -50242, 71, 0, 0, 39, '70'),
	(377, 1, 0, -50242, 72, 0, 0, 39, '71'),
	(377, 1, 0, -50242, 73, 0, 0, 39, '72'),
	(377, 1, 0, -50242, 74, 0, 0, 39, '73'),
	(377, 1, 0, -50242, 75, 0, 0, 39, '74'),
	(377, 1, 0, -50242, 76, 0, 0, 39, '75'),
	(377, 1, 0, -50242, 77, 0, 0, 39, '76'),
	(377, 1, 0, -50242, 78, 0, 0, 39, '77'),
	(377, 1, 0, -50242, 79, 0, 0, 39, '78'),
	(377, 1, 0, -50242, 80, 0, 0, 39, '79'),
	(377, 1, 0, -50242, 81, 0, 0, 39, '80'),
	(377, 1, 0, -50242, 82, 0, 0, 39, '81'),
	(377, 1, 0, -50242, 83, 0, 0, 39, '82'),
	(377, 1, 0, -50242, 84, 0, 0, 39, '83'),
	(377, 1, 0, -50242, 85, 0, 0, 39, '84'),
	(377, 1, 0, -50242, 86, 0, 0, 39, '85'),
	(377, 1, 0, -50242, 87, 0, 0, 39, '86'),
	(377, 1, 0, -50242, 88, 0, 0, 39, '87'),
	(377, 1, 0, -50242, 89, 0, 0, 39, '88'),
	(377, 1, 0, -50242, 90, 0, 0, 39, '89'),
	(377, 1, 0, -50242, 91, 0, 0, 39, '90'),
	(377, 1, 0, -50242, 92, 0, 0, 39, '91'),
	(377, 1, 0, -50242, 93, 0, 0, 39, '92'),
	(377, 1, 0, -50242, 94, 0, 0, 39, '93'),
	(377, 1, 0, -50242, 95, 0, 0, 39, '94'),
	(377, 1, 0, -50242, 96, 0, 0, 39, '95'),
	(377, 1, 0, -50242, 97, 0, 0, 39, '96'),
	(377, 1, 0, -50242, 98, 0, 0, 39, '97'),
	(377, 1, 0, -50242, 99, 0, 0, 39, '98'),
	(377, 1, 0, -50242, 100, 0, 0, 39, '99'),
	(377, 1, 0, -50242, 101, 0, 0, 39, '100'),
	(377, 1, 0, -50242, 102, 0, 0, 39, '101'),
	(377, 1, 0, -50242, 103, 0, 0, 39, '102'),
	(377, 1, 0, -50242, 104, 0, 0, 39, '103'),
	(377, 1, 0, -50242, 105, 0, 0, 39, '104'),
	(377, 1, 0, -50242, 106, 0, 0, 39, '105'),
	(377, 1, 0, -50242, 107, 0, 0, 39, '106'),
	(377, 1, 0, -50242, 108, 0, 0, 39, '107'),
	(377, 1, 0, -50242, 109, 0, 0, 39, '108'),
	(377, 1, 0, -50242, 110, 0, 0, 39, '109'),
	(377, 1, 0, -50242, 111, 0, 0, 39, '110'),
	(377, 1, 0, -50242, 112, 0, 0, 39, '111'),
	(377, 1, 0, -50242, 113, 0, 0, 39, '112'),
	(377, 1, 0, -50242, 114, 0, 0, 39, '113'),
	(377, 1, 0, -50242, 115, 0, 0, 39, '114'),
	(377, 1, 0, -50242, 116, 0, 0, 39, '115'),
	(377, 1, 0, -50242, 117, 0, 0, 39, '116'),
	(377, 1, 0, -50242, 118, 0, 0, 39, '117'),
	(377, 1, 0, -50242, 119, 0, 0, 39, '118'),
	(377, 1, 0, -50242, 120, 0, 0, 39, '119'),
	(377, 1, 0, -50242, 121, 0, 0, 39, '120'),
	(377, 1, 0, -50242, 122, 0, 0, 39, '121'),
	(377, 1, 0, -50242, 123, 0, 0, 39, '122'),
	(377, 1, 0, -50242, 124, 0, 0, 39, '123'),
	(377, 1, 0, -50242, 125, 0, 0, 39, '124'),
	(377, 1, 0, -50242, 126, 0, 0, 39, '125'),
	(377, 1, 0, -50242, 127, 0, 0, 39, '126'),
	(377, 1, 0, -50242, 128, 0, 0, 39, '127'),
	(377, 1, 0, -50242, 129, 0, 0, 39, '128'),
	(377, 1, 0, -50242, 130, 0, 0, 39, '129'),
	(377, 1, 0, -50242, 131, 0, 0, 39, '130'),
	(377, 1, 0, -50242, 132, 0, 0, 39, '131'),
	(377, 1, 0, -50242, 133, 0, 0, 39, '132'),
	(377, 1, 0, -50242, 134, 0, 0, 39, '133'),
	(377, 1, 0, -50242, 135, 0, 0, 39, '134'),
	(377, 1, 0, -50242, 136, 0, 0, 39, '135'),
	(377, 1, 0, -50242, 137, 0, 0, 39, '136'),
	(377, 1, 0, -50242, 138, 0, 0, 39, '137'),
	(377, 1, 0, -50242, 139, 0, 0, 39, '138'),
	(377, 1, 0, -50242, 140, 0, 0, 39, '139'),
	(377, 1, 0, -50242, 141, 0, 0, 39, '140'),
	(377, 1, 0, -50242, 142, 0, 0, 39, '141'),
	(377, 1, 0, -50242, 143, 0, 0, 39, '142'),
	(377, 1, 0, -50242, 144, 0, 0, 39, '143'),
	(377, 1, 0, -50242, 145, 0, 0, 39, '144'),
	(377, 1, 0, -50242, 146, 0, 0, 39, '145'),
	(377, 1, 0, -50242, 147, 0, 0, 39, '146'),
	(377, 1, 0, -50242, 148, 0, 0, 39, '147'),
	(377, 1, 0, -50242, 149, 0, 0, 39, '148'),
	(377, 1, 0, -50242, 150, 0, 0, 39, '149'),
	(377, 1, 0, -50242, 151, 0, 0, 39, '150'),
	(377, 1, 0, -50242, 152, 0, 0, 39, '151'),
	(377, 1, 0, -50242, 153, 0, 0, 39, '152'),
	(377, 1, 0, -50242, 154, 0, 0, 39, '153'),
	(377, 1, 0, -50242, 155, 0, 0, 39, '154'),
	(377, 1, 0, -50242, 156, 0, 0, 39, '155'),
	(377, 1, 0, -50242, 157, 0, 0, 39, '156'),
	(377, 1, 0, -50242, 158, 0, 0, 39, '157'),
	(377, 1, 0, -50242, 159, 0, 0, 39, '158'),
	(377, 1, 0, -50242, 160, 0, 0, 39, '159'),
	(377, 1, 0, -50242, 161, 0, 0, 39, '160'),
	(377, 1, 0, -50242, 162, 0, 0, 39, '161'),
	(377, 1, 0, -50242, 163, 0, 0, 39, '162'),
	(377, 1, 0, -50242, 164, 0, 0, 39, '163'),
	(377, 1, 0, -50242, 165, 0, 0, 39, '164'),
	(377, 1, 0, -50242, 166, 0, 0, 39, '165'),
	(377, 1, 0, -50242, 167, 0, 0, 39, '166'),
	(377, 1, 0, -50242, 168, 0, 0, 39, '167'),
	(377, 1, 0, -50242, 169, 0, 0, 39, '168'),
	(377, 1, 0, -50242, 170, 0, 0, 39, '169'),
	(377, 1, 0, -50242, 171, 0, 0, 39, '170'),
	(377, 1, 0, -50242, 172, 0, 0, 39, '171'),
	(377, 1, 0, -50242, 173, 0, 0, 39, '172'),
	(377, 1, 0, -50242, 174, 0, 0, 39, '173'),
	(377, 1, 0, -50242, 175, 0, 0, 39, '174'),
	(377, 1, 0, -50242, 176, 0, 0, 39, '175'),
	(377, 1, 0, -50242, 177, 0, 0, 39, '176'),
	(377, 1, 0, -50242, 178, 0, 0, 39, '177'),
	(377, 1, 0, -50242, 179, 0, 0, 39, '178'),
	(377, 1, 0, -50242, 180, 0, 0, 39, '179'),
	(377, 1, 0, -50242, 181, 0, 0, 39, '180'),
	(377, 1, 0, -50242, 182, 0, 0, 39, '181'),
	(377, 1, 0, -50242, 183, 0, 0, 39, '182'),
	(377, 1, 0, -50242, 184, 0, 0, 39, '183'),
	(377, 1, 0, -50242, 185, 0, 0, 39, '184'),
	(377, 1, 0, -50242, 186, 0, 0, 39, '185'),
	(377, 1, 0, -50242, 187, 0, 0, 39, '186'),
	(377, 1, 0, -50242, 188, 0, 0, 39, '187'),
	(377, 1, 0, -50242, 189, 0, 0, 39, '188'),
	(377, 1, 0, -50242, 190, 0, 0, 39, '189'),
	(377, 1, 0, -50242, 191, 0, 0, 39, '190'),
	(377, 1, 0, -50242, 192, 0, 0, 39, '191'),
	(377, 1, 0, -50242, 193, 0, 0, 39, '192'),
	(377, 1, 0, -50242, 194, 0, 0, 39, '193'),
	(377, 1, 0, -50242, 195, 0, 0, 39, '194'),
	(377, 1, 0, -50242, 196, 0, 0, 39, '195'),
	(377, 1, 0, -50242, 197, 0, 0, 39, '196'),
	(377, 1, 0, -50242, 198, 0, 0, 39, '197'),
	(377, 1, 0, -50242, 199, 0, 0, 39, '198'),
	(377, 1, 0, -50242, 200, 0, 0, 39, '199'),
	(377, 1, 0, -50242, 201, 0, 0, 39, '200'),
	(377, 1, 0, -50242, 202, 0, 0, 39, '201'),
	(377, 1, 0, -50242, 203, 0, 0, 39, '202'),
	(377, 1, 0, -50242, 204, 0, 0, 39, '203'),
	(377, 1, 0, -50242, 205, 0, 0, 39, '204'),
	(377, 1, 0, -50242, 206, 0, 0, 39, '205'),
	(377, 1, 0, -50242, 207, 0, 0, 39, '206'),
	(377, 1, 0, -50242, 208, 0, 0, 39, '207'),
	(377, 1, 0, -50242, 209, 0, 0, 39, '208'),
	(377, 1, 0, -50242, 210, 0, 0, 39, '209'),
	(377, 1, 0, -50242, 211, 0, 0, 39, '210'),
	(377, 1, 0, -50242, 212, 0, 0, 39, '211'),
	(377, 1, 0, -50242, 213, 0, 0, 39, '212'),
	(377, 1, 0, -50242, 214, 0, 0, 39, '213'),
	(377, 1, 0, -50242, 215, 0, 0, 39, '214'),
	(377, 1, 0, -50242, 216, 0, 0, 39, '215'),
	(377, 1, 0, -50242, 217, 0, 0, 39, '216'),
	(377, 1, 0, -50242, 218, 0, 0, 39, '217'),
	(377, 1, 0, -50242, 219, 0, 0, 39, '218'),
	(377, 1, 0, -50242, 220, 0, 0, 39, '219'),
	(377, 1, 0, -50242, 221, 0, 0, 39, '220'),
	(377, 1, 0, -50242, 222, 0, 0, 39, '221'),
	(377, 1, 0, -50242, 223, 0, 0, 39, '222'),
	(377, 1, 0, -50242, 224, 0, 0, 39, '223'),
	(377, 1, 0, -50242, 225, 0, 0, 39, '224'),
	(377, 1, 0, -50242, 226, 0, 0, 39, '225'),
	(377, 1, 0, -50242, 227, 0, 0, 39, '226'),
	(377, 1, 0, -50242, 228, 0, 0, 39, '227'),
	(377, 1, 0, -50242, 229, 0, 0, 39, '228'),
	(377, 1, 0, -50242, 230, 0, 0, 39, '229'),
	(377, 1, 0, -50242, 231, 0, 0, 39, '230'),
	(377, 1, 0, -50242, 232, 0, 0, 39, '231'),
	(377, 1, 0, -50242, 233, 0, 0, 39, '232'),
	(377, 1, 0, -50242, 234, 0, 0, 39, '233'),
	(377, 1, 0, -50242, 235, 0, 0, 39, '234'),
	(377, 1, 0, -50242, 236, 0, 0, 39, '235'),
	(377, 1, 0, -50242, 237, 0, 0, 39, '236'),
	(377, 1, 0, -50242, 238, 0, 0, 39, '237'),
	(377, 1, 0, -50242, 239, 0, 0, 39, '238'),
	(377, 1, 0, -50242, 240, 0, 0, 39, '239'),
	(377, 1, 0, -50242, 241, 0, 0, 39, '240'),
	(377, 1, 0, -50242, 242, 0, 0, 39, '241'),
	(377, 1, 0, -50242, 243, 0, 0, 39, '242'),
	(377, 1, 0, -50242, 244, 0, 0, 39, '243'),
	(377, 1, 0, -50242, 245, 0, 0, 39, '244'),
	(377, 1, 0, -50242, 246, 0, 0, 39, '245'),
	(377, 1, 0, -50242, 247, 0, 0, 39, '246'),
	(377, 1, 0, -50242, 248, 0, 0, 39, '247'),
	(377, 1, 0, -50242, 249, 0, 0, 39, '248'),
	(377, 1, 0, -50242, 250, 0, 0, 39, '249'),
	(377, 1, 0, -50242, 251, 0, 0, 39, '250'),
	(377, 1, 0, -50242, 252, 0, 0, 39, '251'),
	(377, 1, 0, -50242, 253, 0, 0, 39, '252'),
	(377, 1, 0, -50242, 254, 0, 0, 39, '253'),
	(377, 1, 0, -50242, 255, 0, 0, 39, '254'),
	(377, 1, 0, -50242, 256, 0, 0, 39, '255'),
	(377, 1, 0, -50242, 257, 0, 0, 39, '256'),
	(377, 1, 0, -50242, 258, 0, 0, 39, '257'),
	(377, 1, 0, -50242, 259, 0, 0, 39, '258'),
	(377, 1, 0, -50242, 260, 0, 0, 39, '259'),
	(377, 1, 0, -50242, 261, 0, 0, 39, '260'),
	(377, 1, 0, -50242, 262, 0, 0, 39, '261'),
	(377, 1, 0, -50242, 263, 0, 0, 39, '262'),
	(377, 1, 0, -50242, 264, 0, 0, 39, '263'),
	(377, 1, 0, -50242, 265, 0, 0, 39, '264'),
	(377, 1, 0, -50242, 266, 0, 0, 39, '265'),
	(377, 1, 0, -50242, 267, 0, 0, 39, '266'),
	(377, 1, 0, -50242, 268, 0, 0, 39, '267'),
	(377, 1, 0, -50242, 269, 0, 0, 39, '268'),
	(377, 1, 0, -50242, 270, 0, 0, 39, '269'),
	(377, 1, 0, -50242, 271, 0, 0, 39, '270'),
	(377, 1, 0, -50242, 272, 0, 0, 39, '271'),
	(377, 1, 0, -50242, 273, 0, 0, 39, '272'),
	(377, 1, 0, -50242, 274, 0, 0, 39, '273'),
	(377, 1, 0, -50242, 275, 0, 0, 39, '274'),
	(377, 1, 0, -50242, 276, 0, 0, 39, '275'),
	(377, 1, 0, -50242, 277, 0, 0, 39, '276'),
	(377, 1, 0, -50242, 278, 0, 0, 39, '277'),
	(377, 1, 0, -50242, 279, 0, 0, 39, '278'),
	(377, 1, 0, -50242, 280, 0, 0, 39, '279'),
	(377, 1, 0, -50242, 281, 0, 0, 39, '280'),
	(377, 1, 0, -50242, 282, 0, 0, 39, '281'),
	(377, 1, 0, -50242, 283, 0, 0, 39, '282'),
	(377, 1, 0, -50242, 284, 0, 0, 39, '283'),
	(377, 1, 0, -50242, 285, 0, 0, 39, '284'),
	(377, 1, 0, -50242, 286, 0, 0, 39, '285'),
	(377, 1, 0, -50242, 287, 0, 0, 39, '286'),
	(377, 1, 0, -50242, 288, 0, 0, 39, '287'),
	(377, 1, 0, -50242, 289, 0, 0, 39, '288'),
	(377, 1, 0, -50242, 290, 0, 0, 39, '289'),
	(377, 1, 0, -50242, 291, 0, 0, 39, '290'),
	(377, 1, 0, -50242, 292, 0, 0, 39, '291'),
	(377, 1, 0, -50242, 293, 0, 0, 39, '292'),
	(377, 1, 0, -50242, 294, 0, 0, 39, '293'),
	(377, 1, 0, -50242, 295, 0, 0, 39, '294'),
	(377, 1, 0, -50242, 296, 0, 0, 39, '295'),
	(377, 1, 0, -50242, 297, 0, 0, 39, '296'),
	(377, 1, 0, -50242, 298, 0, 0, 39, '297'),
	(377, 1, 0, -50242, 299, 0, 0, 39, '298'),
	(377, 1, 0, -50242, 300, 0, 0, 39, '299'),
	(377, 1, 0, -50242, 301, 0, 0, 39, '300'),
	(377, 1, 0, -50242, 302, 0, 0, 39, '301'),
	(377, 1, 0, -50242, 303, 0, 0, 39, '302'),
	(377, 1, 0, -50242, 304, 0, 0, 39, '303'),
	(377, 1, 0, -50242, 305, 0, 0, 39, '304'),
	(377, 1, 0, -50242, 306, 0, 0, 39, '305'),
	(377, 1, 0, -50242, 307, 0, 0, 39, '306'),
	(377, 1, 0, -50242, 308, 0, 0, 39, '307'),
	(377, 1, 0, -50242, 309, 0, 0, 39, '308'),
	(377, 1, 0, -50242, 310, 0, 0, 39, '309'),
	(377, 1, 0, -50242, 311, 0, 0, 39, '310'),
	(377, 1, 0, -50242, 312, 0, 0, 39, '311'),
	(377, 1, 0, -50242, 313, 0, 0, 39, '312'),
	(377, 1, 0, -50242, 314, 0, 0, 39, '313'),
	(377, 1, 0, -50242, 315, 0, 0, 39, '314'),
	(377, 1, 0, -50242, 316, 0, 0, 39, '315'),
	(377, 1, 0, -50242, 317, 0, 0, 39, '316'),
	(377, 1, 0, -50242, 318, 0, 0, 39, '317'),
	(377, 1, 0, -50242, 319, 0, 0, 39, '318'),
	(377, 1, 0, -50242, 320, 0, 0, 39, '319'),
	(377, 1, 0, -50242, 321, 0, 0, 39, '320'),
	(377, 1, 0, -50242, 322, 0, 0, 39, '321'),
	(377, 1, 0, -50242, 323, 0, 0, 39, '322'),
	(377, 1, 0, -50242, 324, 0, 0, 39, '323'),
	(377, 1, 0, -50242, 325, 0, 0, 39, '324'),
	(377, 1, 0, -50242, 326, 0, 0, 39, '325'),
	(377, 1, 0, -50242, 327, 0, 0, 39, '326'),
	(377, 1, 0, -50242, 328, 0, 0, 39, '327'),
	(377, 1, 0, -50242, 329, 0, 0, 39, '328'),
	(377, 1, 0, -50242, 330, 0, 0, 39, '329'),
	(377, 1, 0, -50242, 331, 0, 0, 39, '330'),
	(377, 1, 0, -50242, 332, 0, 0, 39, '331'),
	(377, 1, 0, -50242, 333, 0, 0, 39, '332'),
	(377, 1, 0, -50242, 334, 0, 0, 39, '333'),
	(377, 1, 0, -50242, 335, 0, 0, 39, '334'),
	(377, 1, 0, -50242, 336, 0, 0, 39, '335'),
	(377, 1, 0, -50242, 337, 0, 0, 39, '336'),
	(377, 1, 0, -50242, 338, 0, 0, 39, '337'),
	(377, 1, 0, -50242, 339, 0, 0, 39, '338'),
	(377, 1, 0, -50242, 340, 0, 0, 39, '339'),
	(377, 1, 0, -50242, 341, 0, 0, 39, '340'),
	(377, 1, 0, -50242, 342, 0, 0, 39, '341'),
	(377, 1, 0, -50242, 343, 0, 0, 39, '342'),
	(377, 1, 0, -50242, 344, 0, 0, 39, '343'),
	(377, 1, 0, -50242, 345, 0, 0, 39, '344'),
	(377, 1, 0, -50242, 346, 0, 0, 39, '345'),
	(377, 1, 0, -50242, 347, 0, 0, 39, '346'),
	(377, 1, 0, -50242, 348, 0, 0, 39, '347'),
	(377, 1, 0, -50242, 349, 0, 0, 39, '348'),
	(377, 1, 0, -50242, 350, 0, 0, 39, '349'),
	(377, 1, 0, -50242, 351, 0, 0, 39, '350'),
	(377, 1, 0, -50242, 352, 0, 0, 39, '351'),
	(377, 1, 0, -50242, 353, 0, 0, 39, '352'),
	(377, 1, 0, -50242, 354, 0, 0, 39, '353'),
	(377, 1, 0, -50242, 355, 0, 0, 39, '354'),
	(377, 1, 0, -50242, 356, 0, 0, 39, '355'),
	(377, 1, 0, -50242, 357, 0, 0, 39, '356'),
	(377, 1, 0, -50242, 358, 0, 0, 39, '357'),
	(377, 1, 0, -50242, 359, 0, 0, 39, '358'),
	(377, 1, 0, -50242, 360, 0, 0, 39, '359'),
	(377, 1, 0, -50242, 361, 0, 0, 39, '360'),
	(377, 1, 0, -50242, 362, 0, 0, 39, '361'),
	(377, 1, 0, -50242, 363, 0, 0, 39, '362'),
	(377, 1, 0, -50242, 364, 0, 0, 39, '363'),
	(377, 1, 0, -50242, 365, 0, 0, 39, '364'),
	(377, 1, 0, -50242, 366, 0, 0, 39, '365'),
	(377, 1, 0, -50242, 367, 0, 0, 39, '366'),
	(377, 1, 0, -50242, 368, 0, 0, 39, '367'),
	(377, 1, 0, -50242, 369, 0, 0, 39, '368'),
	(377, 1, 0, -50242, 370, 0, 0, 39, '369'),
	(377, 1, 0, -50242, 371, 0, 0, 39, '370'),
	(377, 1, 0, -50242, 372, 0, 0, 39, '371'),
	(377, 1, 0, -50242, 373, 0, 0, 39, '372'),
	(377, 1, 0, -50242, 374, 0, 0, 39, '373'),
	(377, 1, 0, -50242, 375, 0, 0, 39, '374'),
	(377, 1, 0, -50242, 376, 0, 0, 39, '375'),
	(377, 1, 0, -50242, 377, 0, 0, 39, '376'),
	(377, 1, 0, -50242, 378, 0, 0, 39, '377'),
	(377, 1, 0, -50242, 379, 0, 0, 39, '378'),
	(377, 1, 0, -50242, 380, 0, 0, 39, '379'),
	(377, 1, 0, -50242, 381, 0, 0, 39, '380'),
	(377, 1, 0, -50242, 382, 0, 0, 39, '381'),
	(377, 1, 0, -50242, 383, 0, 0, 39, '382'),
	(377, 1, 0, -50242, 384, 0, 0, 39, '383'),
	(377, 1, 0, -50242, 385, 0, 0, 39, '384'),
	(377, 1, 0, -50242, 386, 0, 0, 39, '385'),
	(377, 1, 0, -50242, 387, 0, 0, 39, '386'),
	(377, 1, 0, -50242, 388, 0, 0, 39, '387'),
	(377, 1, 0, -50242, 389, 0, 0, 39, '388'),
	(377, 1, 0, -50242, 390, 0, 0, 39, '389'),
	(377, 1, 0, -50242, 391, 0, 0, 39, '390'),
	(377, 1, 0, -50242, 392, 0, 0, 39, '391'),
	(377, 1, 0, -50242, 393, 0, 0, 39, '392'),
	(377, 1, 0, -50242, 394, 0, 0, 39, '393'),
	(377, 1, 0, -50242, 395, 0, 0, 39, '394'),
	(377, 1, 0, -50242, 396, 0, 0, 39, '395'),
	(377, 1, 0, -50242, 397, 0, 0, 39, '396'),
	(377, 1, 0, -50242, 398, 0, 0, 39, '397'),
	(377, 1, 0, -50242, 399, 0, 0, 39, '398'),
	(377, 1, 0, -50242, 400, 0, 0, 39, '399'),
	(377, 1, 0, -50242, 401, 0, 0, 39, '400'),
	(377, 1, 0, -50242, 402, 0, 0, 39, '401'),
	(377, 1, 0, -50242, 403, 0, 0, 39, '402'),
	(377, 1, 0, -50242, 404, 0, 0, 39, '403'),
	(377, 1, 0, -50242, 405, 0, 0, 39, '404'),
	(377, 1, 0, -50242, 406, 0, 0, 39, '405'),
	(377, 1, 0, -50242, 407, 0, 0, 39, '406'),
	(377, 1, 0, -50242, 408, 0, 0, 39, '407'),
	(377, 1, 0, -50242, 409, 0, 0, 39, '408'),
	(377, 1, 0, -50242, 410, 0, 0, 39, '409'),
	(377, 1, 0, -50242, 411, 0, 0, 39, '410'),
	(377, 1, 0, -50242, 412, 0, 0, 39, '411'),
	(377, 1, 0, -50242, 413, 0, 0, 39, '412'),
	(377, 1, 0, -50242, 414, 0, 0, 39, '413'),
	(377, 1, 0, -50242, 415, 0, 0, 39, '414'),
	(377, 1, 0, -50242, 416, 0, 0, 39, '415'),
	(377, 1, 0, -50242, 417, 0, 0, 39, '416'),
	(377, 1, 0, -50242, 418, 0, 0, 39, '417'),
	(377, 1, 0, -50242, 419, 0, 0, 39, '418'),
	(377, 1, 0, -50242, 420, 0, 0, 39, '419'),
	(377, 1, 0, -50242, 421, 0, 0, 39, '420'),
	(377, 1, 0, -50242, 422, 0, 0, 39, '421'),
	(377, 1, 0, -50242, 423, 0, 0, 39, '422'),
	(377, 1, 0, -50242, 424, 0, 0, 39, '423'),
	(377, 1, 0, -50242, 425, 0, 0, 39, '424'),
	(377, 1, 0, -50242, 426, 0, 0, 39, '425'),
	(377, 1, 0, -50242, 427, 0, 0, 39, '426'),
	(377, 1, 0, -50242, 428, 0, 0, 39, '427'),
	(377, 1, 0, -50242, 429, 0, 0, 39, '428'),
	(377, 1, 0, -50242, 430, 0, 0, 39, '429'),
	(377, 1, 0, -50242, 431, 0, 0, 39, '430'),
	(377, 1, 0, -50242, 432, 0, 0, 39, '431'),
	(377, 1, 0, -50242, 433, 0, 0, 39, '432'),
	(377, 1, 0, -50242, 434, 0, 0, 39, '433'),
	(377, 1, 0, -50242, 435, 0, 0, 39, '434'),
	(377, 1, 0, -50242, 436, 0, 0, 39, '435'),
	(377, 1, 0, -50242, 437, 0, 0, 39, '436'),
	(377, 1, 0, -50242, 438, 0, 0, 39, '437'),
	(377, 1, 0, -50242, 439, 0, 0, 39, '438'),
	(377, 1, 0, -50242, 440, 0, 0, 39, '439'),
	(377, 1, 0, -50242, 441, 0, 0, 39, '440'),
	(377, 1, 0, -50242, 442, 0, 0, 39, '441'),
	(377, 1, 0, -50242, 443, 0, 0, 39, '442'),
	(377, 1, 0, -50242, 444, 0, 0, 39, '443'),
	(377, 1, 0, -50242, 445, 0, 0, 39, '444'),
	(377, 1, 0, -50242, 446, 0, 0, 39, '445'),
	(377, 1, 0, -50242, 447, 0, 0, 39, '446'),
	(377, 1, 0, -50242, 448, 0, 0, 39, '447'),
	(377, 1, 0, -50242, 449, 0, 0, 39, '448'),
	(377, 1, 0, -50242, 450, 0, 0, 39, '449'),
	(377, 1, 0, -50242, 451, 0, 0, 39, '450'),
	(377, 1, 0, -50242, 452, 0, 0, 39, '451'),
	(377, 1, 0, -50242, 453, 0, 0, 39, '452'),
	(377, 1, 0, -50242, 454, 0, 0, 39, '453'),
	(377, 1, 0, -50242, 455, 0, 0, 39, '454'),
	(377, 1, 0, -50242, 456, 0, 0, 39, '455'),
	(377, 1, 0, -50242, 457, 0, 0, 39, '456'),
	(377, 1, 0, -50242, 458, 0, 0, 39, '457'),
	(377, 1, 0, -50242, 459, 0, 0, 39, '458'),
	(377, 1, 0, -50242, 460, 0, 0, 39, '459'),
	(377, 1, 0, -50242, 461, 0, 0, 39, '460'),
	(377, 1, 0, -50242, 462, 0, 0, 39, '461'),
	(377, 1, 0, -50242, 463, 0, 0, 39, '462'),
	(377, 1, 0, -50242, 464, 0, 0, 39, '463'),
	(377, 1, 0, -50242, 465, 0, 0, 39, '464'),
	(377, 1, 0, -50242, 466, 0, 0, 39, '465'),
	(377, 1, 0, -50242, 467, 0, 0, 39, '466'),
	(377, 1, 0, -50242, 468, 0, 0, 39, '467'),
	(377, 1, 0, -50242, 469, 0, 0, 39, '468'),
	(377, 1, 0, -50242, 470, 0, 0, 39, '469'),
	(377, 1, 0, -50242, 471, 0, 0, 39, '470'),
	(377, 1, 0, -50242, 472, 0, 0, 39, '471'),
	(377, 1, 0, -50242, 473, 0, 0, 39, '472'),
	(377, 1, 0, -50242, 474, 0, 0, 39, '473'),
	(377, 1, 0, -50242, 475, 0, 0, 39, '474'),
	(377, 1, 0, -50242, 476, 0, 0, 39, '475'),
	(377, 1, 0, -50242, 477, 0, 0, 39, '476'),
	(377, 1, 0, -50242, 478, 0, 0, 39, '477'),
	(377, 1, 0, -50242, 479, 0, 0, 39, '478'),
	(377, 1, 0, -50242, 480, 0, 0, 39, '479'),
	(377, 1, 0, -50242, 481, 0, 0, 39, '480'),
	(377, 1, 0, -50242, 482, 0, 0, 39, '481'),
	(377, 1, 0, -50242, 483, 0, 0, 39, '482'),
	(377, 1, 0, -50242, 484, 0, 0, 39, '483'),
	(377, 1, 0, -50242, 485, 0, 0, 39, '484'),
	(377, 1, 0, -50242, 486, 0, 0, 39, '485'),
	(377, 1, 0, -50242, 487, 0, 0, 39, '486'),
	(377, 1, 0, -50242, 488, 0, 0, 39, '487'),
	(377, 1, 0, -50242, 489, 0, 0, 39, '488'),
	(377, 1, 0, -50242, 490, 0, 0, 39, '489'),
	(377, 1, 0, -50242, 491, 0, 0, 39, '490'),
	(377, 1, 0, -50242, 492, 0, 0, 39, '491'),
	(377, 1, 0, -50242, 493, 0, 0, 39, '492'),
	(377, 1, 0, -50242, 494, 0, 0, 39, '493'),
	(377, 1, 0, -50242, 495, 0, 0, 39, '494'),
	(377, 1, 0, -50242, 496, 0, 0, 39, '495'),
	(377, 1, 0, -50242, 497, 0, 0, 39, '496'),
	(377, 1, 0, -50242, 498, 0, 0, 39, '497'),
	(377, 1, 0, -50242, 499, 0, 0, 39, '498'),
	(377, 1, 0, -50242, 500, 0, 0, 39, '499'),
	(377, 1, 0, -50242, 501, 0, 0, 39, '500'),
	(377, 1, 0, -50242, 502, 0, 0, 39, '501'),
	(377, 1, 0, -50242, 503, 0, 0, 39, '502'),
	(377, 1, 0, -50242, 504, 0, 0, 39, '503'),
	(377, 1, 0, -50242, 505, 0, 0, 39, '504'),
	(377, 1, 0, -50242, 506, 0, 0, 39, '505'),
	(377, 1, 0, -50242, 507, 0, 0, 39, '506'),
	(377, 1, 0, -50242, 508, 0, 0, 39, '507'),
	(377, 1, 0, -50242, 509, 0, 0, 39, '508'),
	(377, 1, 0, -50242, 510, 0, 0, 39, '509'),
	(377, 1, 0, -50242, 511, 0, 0, 39, '510'),
	(377, 1, 0, -50242, 512, 0, 0, 39, '511'),
	(377, 1, 0, -50242, 513, 0, 0, 39, '512'),
	(377, 1, 0, -50242, 514, 0, 0, 39, '513'),
	(377, 1, 0, -50242, 515, 0, 0, 39, '514'),
	(377, 1, 0, -50242, 516, 0, 0, 39, '515'),
	(377, 1, 0, -50242, 517, 0, 0, 39, '516'),
	(377, 1, 0, -50242, 518, 0, 0, 39, '517'),
	(377, 1, 0, -50242, 519, 0, 0, 39, '518'),
	(377, 1, 0, -50242, 520, 0, 0, 39, '519'),
	(377, 1, 0, -50242, 521, 0, 0, 39, '520'),
	(377, 1, 0, -50242, 522, 0, 0, 39, '521'),
	(377, 1, 0, -50242, 523, 0, 0, 39, '522'),
	(377, 1, 0, -50242, 524, 0, 0, 39, '523'),
	(377, 1, 0, -50242, 525, 0, 0, 39, '524'),
	(377, 1, 0, -50242, 526, 0, 0, 39, '525'),
	(377, 1, 0, -50242, 527, 0, 0, 39, '526'),
	(377, 1, 0, -50242, 528, 0, 0, 39, '527'),
	(377, 1, 0, -50242, 529, 0, 0, 39, '528'),
	(377, 1, 0, -50242, 530, 0, 0, 39, '529'),
	(377, 1, 0, -50242, 531, 0, 0, 39, '530'),
	(377, 1, 0, -50242, 532, 0, 0, 39, '531'),
	(377, 1, 0, -50242, 533, 0, 0, 39, '532'),
	(377, 1, 0, -50242, 534, 0, 0, 39, '533'),
	(377, 1, 0, -50242, 535, 0, 0, 39, '534'),
	(377, 1, 0, -50242, 536, 0, 0, 39, '535'),
	(377, 1, 0, -50242, 537, 0, 0, 39, '536'),
	(377, 1, 0, -50242, 538, 0, 0, 39, '537'),
	(377, 1, 0, -50242, 539, 0, 0, 39, '538'),
	(377, 1, 0, -50242, 540, 0, 0, 39, '539'),
	(377, 1, 0, -50242, 541, 0, 0, 39, '540'),
	(377, 1, 0, -50242, 542, 0, 0, 39, '541'),
	(377, 1, 0, -50242, 543, 0, 0, 39, '542'),
	(377, 1, 0, -50242, 544, 0, 0, 39, '543'),
	(377, 1, 0, -50242, 545, 0, 0, 39, '544'),
	(377, 1, 0, -50242, 546, 0, 0, 39, '545'),
	(377, 1, 0, -50242, 547, 0, 0, 39, '546'),
	(377, 1, 0, -50242, 548, 0, 0, 39, '547'),
	(377, 1, 0, -50242, 549, 0, 0, 39, '548'),
	(377, 1, 0, -50242, 550, 0, 0, 39, '549'),
	(377, 1, 0, -50242, 551, 0, 0, 39, '550'),
	(377, 1, 0, -50242, 552, 0, 0, 39, '551'),
	(377, 1, 0, -50242, 553, 0, 0, 39, '552'),
	(377, 1, 0, -50242, 554, 0, 0, 39, '553'),
	(377, 1, 0, -50242, 555, 0, 0, 39, '554'),
	(377, 1, 0, -50242, 556, 0, 0, 39, '555'),
	(377, 1, 0, -50242, 557, 0, 0, 39, '556'),
	(377, 1, 0, -50242, 558, 0, 0, 39, '557'),
	(377, 1, 0, -50242, 559, 0, 0, 39, '558'),
	(377, 1, 0, -50242, 560, 0, 0, 39, '559'),
	(377, 1, 0, -50242, 561, 0, 0, 39, '560'),
	(377, 1, 0, -50242, 562, 0, 0, 39, '561'),
	(377, 1, 0, -50242, 563, 0, 0, 39, '562'),
	(377, 1, 0, -50242, 564, 0, 0, 39, '563'),
	(377, 1, 0, -50242, 565, 0, 0, 39, '564'),
	(377, 1, 0, -50242, 566, 0, 0, 39, '565'),
	(377, 1, 0, -50242, 567, 0, 0, 39, '566'),
	(377, 1, 0, -50242, 568, 0, 0, 39, '567'),
	(377, 1, 0, -50242, 569, 0, 0, 39, '568'),
	(377, 1, 0, -50242, 570, 0, 0, 39, '569'),
	(377, 1, 0, -50242, 571, 0, 0, 39, '570'),
	(377, 1, 0, -50242, 572, 0, 0, 39, '571'),
	(377, 1, 0, -50242, 573, 0, 0, 39, '572'),
	(377, 1, 0, -50242, 574, 0, 0, 39, '573'),
	(377, 1, 0, -50242, 575, 0, 0, 39, '574'),
	(377, 1, 0, -50242, 576, 0, 0, 39, '575'),
	(377, 1, 0, -50242, 577, 0, 0, 39, '576'),
	(377, 1, 0, -50242, 578, 0, 0, 39, '577'),
	(377, 1, 0, -50242, 579, 0, 0, 39, '578'),
	(377, 1, 0, -50242, 580, 0, 0, 39, '579'),
	(377, 1, 0, -50242, 581, 0, 0, 39, '580'),
	(377, 1, 0, -50242, 582, 0, 0, 39, '581'),
	(377, 1, 0, -50242, 583, 0, 0, 39, '582'),
	(377, 1, 0, -50242, 584, 0, 0, 39, '583'),
	(377, 1, 0, -50242, 585, 0, 0, 39, '584'),
	(377, 1, 0, -50242, 586, 0, 0, 39, '585'),
	(377, 1, 0, -50242, 587, 0, 0, 39, '586'),
	(377, 1, 0, -50242, 588, 0, 0, 39, '587'),
	(377, 1, 0, -50242, 589, 0, 0, 39, '588'),
	(377, 1, 0, -50242, 590, 0, 0, 39, '589'),
	(377, 1, 0, -50242, 591, 0, 0, 39, '590'),
	(377, 1, 0, -50242, 592, 0, 0, 39, '591'),
	(377, 1, 0, -50242, 593, 0, 0, 39, '592'),
	(377, 1, 0, -50242, 594, 0, 0, 39, '593'),
	(377, 1, 0, -50242, 595, 0, 0, 39, '594'),
	(377, 1, 0, -50242, 596, 0, 0, 39, '595'),
	(377, 1, 0, -50242, 597, 0, 0, 39, '596'),
	(377, 1, 0, -50242, 598, 0, 0, 39, '597'),
	(377, 1, 0, -50242, 599, 0, 0, 39, '598'),
	(377, 1, 0, -50242, 600, 0, 0, 39, '599'),
	(377, 1, 0, -50242, 601, 0, 0, 39, '600'),
	(377, 1, 0, -50242, 602, 0, 0, 39, '601'),
	(377, 1, 0, -50242, 603, 0, 0, 39, '602'),
	(377, 1, 0, -50242, 604, 0, 0, 39, '603'),
	(377, 1, 0, -50242, 605, 0, 0, 39, '604'),
	(377, 1, 0, -50242, 606, 0, 0, 39, '605'),
	(377, 1, 0, -50242, 607, 0, 0, 39, '606'),
	(377, 1, 0, -50242, 608, 0, 0, 39, '607'),
	(377, 1, 0, -50242, 609, 0, 0, 39, '608'),
	(377, 1, 0, -50242, 610, 0, 0, 39, '609'),
	(377, 1, 0, -50242, 611, 0, 0, 39, '610'),
	(377, 1, 0, -50242, 612, 0, 0, 39, '611'),
	(377, 1, 0, -50242, 613, 0, 0, 39, '612'),
	(377, 1, 0, -50242, 614, 0, 0, 39, '613'),
	(377, 1, 0, -50242, 615, 0, 0, 39, '614'),
	(377, 1, 0, -50242, 616, 0, 0, 39, '615'),
	(377, 1, 0, -50242, 617, 0, 0, 39, '616'),
	(377, 1, 0, -50242, 618, 0, 0, 39, '617'),
	(377, 1, 0, -50242, 619, 0, 0, 39, '618'),
	(377, 1, 0, -50242, 620, 0, 0, 39, '619'),
	(377, 1, 0, -50242, 621, 0, 0, 39, '620'),
	(377, 1, 0, -50242, 622, 0, 0, 39, '621'),
	(377, 1, 0, -50242, 623, 0, 0, 39, '622'),
	(377, 1, 0, -50242, 624, 0, 0, 39, '623'),
	(377, 1, 0, -50242, 625, 0, 0, 39, '624'),
	(377, 1, 0, -50242, 626, 0, 0, 39, '625'),
	(377, 1, 0, -50242, 627, 0, 0, 39, '626'),
	(377, 1, 0, -50242, 628, 0, 0, 39, '627'),
	(377, 1, 0, -50242, 629, 0, 0, 39, '628'),
	(377, 1, 0, -50242, 630, 0, 0, 39, '629'),
	(377, 1, 0, -50242, 631, 0, 0, 39, '630'),
	(377, 1, 0, -50242, 632, 0, 0, 39, '631'),
	(377, 1, 0, -50242, 633, 0, 0, 39, '632'),
	(377, 1, 0, -50242, 634, 0, 0, 39, '633'),
	(377, 1, 0, -50242, 635, 0, 0, 39, '634'),
	(377, 1, 0, -50242, 636, 0, 0, 39, '635'),
	(377, 1, 0, -50242, 637, 0, 0, 39, '636'),
	(377, 1, 0, -50242, 638, 0, 0, 39, '637'),
	(377, 1, 0, -50242, 639, 0, 0, 39, '638'),
	(377, 1, 0, -50242, 640, 0, 0, 39, '639'),
	(377, 1, 0, -50242, 641, 0, 0, 39, '640'),
	(377, 1, 0, -50242, 642, 0, 0, 39, '641'),
	(377, 1, 0, -50242, 643, 0, 0, 39, '642'),
	(377, 1, 0, -50242, 644, 0, 0, 39, '643'),
	(377, 1, 0, -50242, 645, 0, 0, 39, '644'),
	(377, 1, 0, -50242, 646, 0, 0, 39, '645'),
	(377, 1, 0, -50242, 647, 0, 0, 39, '646'),
	(377, 1, 0, -50242, 648, 0, 0, 39, '647'),
	(377, 1, 0, -50242, 649, 0, 0, 39, '648'),
	(377, 1, 0, -50242, 650, 0, 0, 39, '649'),
	(377, 1, 0, -50242, 651, 0, 0, 39, '650'),
	(377, 1, 0, -50242, 652, 0, 0, 39, '651'),
	(377, 1, 0, -50242, 653, 0, 0, 39, '652'),
	(377, 1, 0, -50242, 654, 0, 0, 39, '653'),
	(377, 1, 0, -50242, 655, 0, 0, 39, '654'),
	(377, 1, 0, -50242, 656, 0, 0, 39, '655'),
	(377, 1, 0, -50242, 657, 0, 0, 39, '656'),
	(377, 1, 0, -50242, 658, 0, 0, 39, '657'),
	(377, 1, 0, -50242, 659, 0, 0, 39, '658'),
	(377, 1, 0, -50242, 660, 0, 0, 39, '659'),
	(377, 1, 0, -50242, 661, 0, 0, 39, '660'),
	(377, 1, 0, -50242, 662, 0, 0, 39, '661'),
	(377, 1, 0, -50242, 663, 0, 0, 39, '662'),
	(377, 1, 0, -50242, 664, 0, 0, 39, '663'),
	(377, 1, 0, -50242, 665, 0, 0, 39, '664'),
	(377, 1, 0, -50242, 666, 0, 0, 39, '665'),
	(377, 1, 0, -50242, 667, 0, 0, 39, '666'),
	(377, 1, 0, -50242, 668, 0, 0, 39, '667'),
	(377, 1, 0, -50242, 669, 0, 0, 39, '668'),
	(377, 1, 0, -50242, 670, 0, 0, 39, '669'),
	(377, 1, 0, -50242, 671, 0, 0, 39, '670'),
	(377, 1, 0, -50242, 672, 0, 0, 39, '671'),
	(377, 1, 0, -50242, 673, 0, 0, 39, '672'),
	(377, 1, 0, -50242, 674, 0, 0, 39, '673'),
	(377, 1, 0, -50242, 675, 0, 0, 39, '674'),
	(377, 1, 0, -50242, 676, 0, 0, 39, '675'),
	(377, 1, 0, -50242, 677, 0, 0, 39, '676'),
	(377, 1, 0, -50242, 678, 0, 0, 39, '677'),
	(377, 1, 0, -50242, 679, 0, 0, 39, '678'),
	(377, 1, 0, -50242, 680, 0, 0, 39, '679'),
	(377, 1, 0, -50242, 681, 0, 0, 39, '680'),
	(377, 1, 0, -50242, 682, 0, 0, 39, '681'),
	(377, 1, 0, -50242, 683, 0, 0, 39, '682'),
	(377, 1, 0, -50242, 684, 0, 0, 39, '683'),
	(377, 1, 0, -50242, 685, 0, 0, 39, '684'),
	(377, 1, 0, -50242, 686, 0, 0, 39, '685'),
	(377, 1, 0, -50242, 687, 0, 0, 39, '686'),
	(377, 1, 0, -50242, 688, 0, 0, 39, '687'),
	(377, 1, 0, -50242, 689, 0, 0, 39, '688'),
	(377, 1, 0, -50242, 690, 0, 0, 39, '689'),
	(377, 1, 0, -50242, 691, 0, 0, 39, '690'),
	(377, 1, 0, -50242, 692, 0, 0, 39, '691'),
	(377, 1, 0, -50242, 693, 0, 0, 39, '692'),
	(377, 1, 0, -50242, 694, 0, 0, 39, '693'),
	(377, 1, 0, -50242, 695, 0, 0, 39, '694'),
	(377, 1, 0, -50242, 696, 0, 0, 39, '695'),
	(377, 1, 0, -50242, 697, 0, 0, 39, '696'),
	(377, 1, 0, -50242, 698, 0, 0, 39, '697'),
	(377, 1, 0, -50242, 699, 0, 0, 39, '698'),
	(377, 1, 0, -50242, 700, 0, 0, 39, '699'),
	(377, 1, 0, -50242, 701, 0, 0, 39, '700'),
	(377, 1, 0, -50242, 702, 0, 0, 39, '701'),
	(377, 1, 0, -50242, 703, 0, 0, 39, '702'),
	(377, 1, 0, -50242, 704, 0, 0, 39, '703'),
	(377, 1, 0, -50242, 705, 0, 0, 39, '704'),
	(377, 1, 0, -50242, 706, 0, 0, 39, '705'),
	(377, 1, 0, -50242, 707, 0, 0, 39, '706'),
	(377, 1, 0, -50242, 708, 0, 0, 39, '707'),
	(377, 1, 0, -50242, 709, 0, 0, 39, '708'),
	(377, 1, 0, -50242, 710, 0, 0, 39, '709'),
	(377, 1, 0, -50242, 711, 0, 0, 39, '710'),
	(377, 1, 0, -50242, 712, 0, 0, 39, '711'),
	(377, 1, 0, -50242, 713, 0, 0, 39, '712'),
	(377, 1, 0, -50242, 714, 0, 0, 39, '713'),
	(377, 1, 0, -50242, 715, 0, 0, 39, '714'),
	(377, 1, 0, -50242, 716, 0, 0, 39, '715'),
	(377, 1, 0, -50242, 717, 0, 0, 39, '716'),
	(377, 1, 0, -50242, 718, 0, 0, 39, '717'),
	(377, 1, 0, -50242, 719, 0, 0, 39, '718'),
	(377, 1, 0, -50242, 720, 0, 0, 39, '719'),
	(377, 1, 0, -50242, 721, 0, 0, 39, '720'),
	(377, 1, 0, -50242, 722, 0, 0, 39, '721'),
	(377, 1, 0, -50242, 723, 0, 0, 39, '722'),
	(377, 1, 0, -50242, 724, 0, 0, 39, '723'),
	(377, 1, 0, -50242, 725, 0, 0, 39, '724'),
	(377, 1, 0, -50242, 726, 0, 0, 39, '725'),
	(377, 1, 0, -50242, 727, 0, 0, 39, '726'),
	(377, 1, 0, -50242, 728, 0, 0, 39, '727'),
	(377, 1, 0, -50242, 729, 0, 0, 39, '728'),
	(377, 1, 0, -50242, 730, 0, 0, 39, '729'),
	(377, 1, 0, -50242, 731, 0, 0, 39, '730'),
	(377, 1, 0, -50242, 732, 0, 0, 39, '731'),
	(377, 1, 0, -50242, 733, 0, 0, 39, '732'),
	(377, 1, 0, -50242, 734, 0, 0, 39, '733'),
	(377, 1, 0, -50242, 735, 0, 0, 39, '734'),
	(377, 1, 0, -50242, 736, 0, 0, 39, '735'),
	(377, 1, 0, -50242, 737, 0, 0, 39, '736'),
	(377, 1, 0, -50242, 738, 0, 0, 39, '737'),
	(377, 1, 0, -50242, 739, 0, 0, 39, '738'),
	(377, 1, 0, -50242, 740, 0, 0, 39, '739'),
	(377, 1, 0, -50242, 741, 0, 0, 39, '740'),
	(377, 1, 0, -50242, 742, 0, 0, 39, '741'),
	(377, 1, 0, -50242, 743, 0, 0, 39, '742'),
	(377, 1, 0, -50242, 744, 0, 0, 39, '743'),
	(377, 1, 0, -50242, 745, 0, 0, 39, '744'),
	(377, 1, 0, -50242, 746, 0, 0, 39, '745'),
	(377, 1, 0, -50242, 747, 0, 0, 39, '746'),
	(377, 1, 0, -50242, 748, 0, 0, 39, '747'),
	(377, 1, 0, -50242, 749, 0, 0, 39, '748'),
	(377, 1, 0, -50242, 750, 0, 0, 39, '749'),
	(377, 1, 0, -50242, 751, 0, 0, 39, '750'),
	(377, 1, 0, -50242, 752, 0, 0, 39, '751'),
	(377, 1, 0, -50242, 753, 0, 0, 39, '752'),
	(377, 1, 0, -50242, 754, 0, 0, 39, '753'),
	(377, 1, 0, -50242, 755, 0, 0, 39, '754'),
	(377, 1, 0, -50242, 756, 0, 0, 39, '755'),
	(377, 1, 0, -50242, 757, 0, 0, 39, '756'),
	(377, 1, 0, -50242, 758, 0, 0, 39, '757'),
	(377, 1, 0, -50242, 759, 0, 0, 39, '758'),
	(377, 1, 0, -50242, 760, 0, 0, 39, '759'),
	(377, 1, 0, -50242, 761, 0, 0, 39, '760'),
	(377, 1, 0, -50242, 762, 0, 0, 39, '761'),
	(377, 1, 0, -50242, 763, 0, 0, 39, '762'),
	(377, 1, 0, -50242, 764, 0, 0, 39, '763'),
	(377, 1, 0, -50242, 765, 0, 0, 39, '764'),
	(377, 1, 0, -50242, 766, 0, 0, 39, '765'),
	(377, 1, 0, -50242, 767, 0, 0, 39, '766'),
	(377, 1, 0, -50242, 768, 0, 0, 39, '767'),
	(377, 1, 0, -50242, 769, 0, 0, 39, '768'),
	(377, 1, 0, -50242, 770, 0, 0, 39, '769'),
	(377, 1, 0, -50242, 771, 0, 0, 39, '770'),
	(377, 1, 0, -50242, 772, 0, 0, 39, '771'),
	(377, 1, 0, -50242, 773, 0, 0, 39, '772'),
	(377, 1, 0, -50242, 774, 0, 0, 39, '773'),
	(377, 1, 0, -50242, 775, 0, 0, 39, '774'),
	(377, 1, 0, -50242, 776, 0, 0, 39, '775'),
	(377, 1, 0, -50242, 777, 0, 0, 39, '776'),
	(377, 1, 0, -50242, 778, 0, 0, 39, '777'),
	(377, 1, 0, -50242, 779, 0, 0, 39, '778'),
	(377, 1, 0, -50242, 780, 0, 0, 39, '779'),
	(377, 1, 0, -50242, 781, 0, 0, 39, '780'),
	(377, 1, 0, -50242, 782, 0, 0, 39, '781'),
	(377, 1, 0, -50242, 783, 0, 0, 39, '782'),
	(377, 1, 0, -50242, 784, 0, 0, 39, '783'),
	(377, 1, 0, -50242, 785, 0, 0, 39, '784'),
	(377, 1, 0, -50242, 786, 0, 0, 39, '785'),
	(377, 1, 0, -50242, 787, 0, 0, 39, '786'),
	(377, 1, 0, -50242, 788, 0, 0, 39, '787'),
	(377, 1, 0, -50242, 789, 0, 0, 39, '788'),
	(377, 1, 0, -50242, 790, 0, 0, 39, '789'),
	(377, 1, 0, -50242, 791, 0, 0, 39, '790'),
	(377, 1, 0, -50242, 792, 0, 0, 39, '791'),
	(377, 1, 0, -50242, 793, 0, 0, 39, '792'),
	(377, 1, 0, -50242, 794, 0, 0, 39, '793'),
	(377, 1, 0, -50242, 795, 0, 0, 39, '794'),
	(377, 1, 0, -50242, 796, 0, 0, 39, '795'),
	(377, 1, 0, -50242, 797, 0, 0, 39, '796'),
	(377, 1, 0, -50242, 798, 0, 0, 39, '797'),
	(377, 1, 0, -50242, 799, 0, 0, 39, '798'),
	(377, 1, 0, -50242, 800, 0, 0, 39, '799'),
	(377, 1, 0, -50242, 801, 0, 0, 39, '800'),
	(377, 1, 0, -50242, 802, 0, 0, 39, '801'),
	(377, 1, 0, -50242, 803, 0, 0, 39, '802'),
	(377, 1, 0, -50242, 804, 0, 0, 39, '803'),
	(377, 1, 0, -50242, 805, 0, 0, 39, '804'),
	(377, 1, 0, -50242, 806, 0, 0, 39, '805'),
	(377, 1, 0, -50242, 807, 0, 0, 39, '806'),
	(377, 1, 0, -50242, 808, 0, 0, 39, '807'),
	(377, 1, 0, -50242, 809, 0, 0, 39, '808'),
	(377, 1, 0, -50242, 810, 0, 0, 39, '809'),
	(377, 1, 0, -50242, 811, 0, 0, 39, '810'),
	(377, 1, 0, -50242, 812, 0, 0, 39, '811'),
	(377, 1, 0, -50242, 813, 0, 0, 39, '812'),
	(377, 1, 0, -50242, 814, 0, 0, 39, '813'),
	(377, 1, 0, -50242, 815, 0, 0, 39, '814'),
	(377, 1, 0, -50242, 816, 0, 0, 39, '815'),
	(377, 1, 0, -50242, 817, 0, 0, 39, '816'),
	(377, 1, 0, -50242, 818, 0, 0, 39, '817'),
	(377, 1, 0, -50242, 819, 0, 0, 39, '818'),
	(377, 1, 0, -50242, 820, 0, 0, 39, '819'),
	(377, 1, 0, -50242, 821, 0, 0, 39, '820'),
	(377, 1, 0, -50242, 822, 0, 0, 39, '821'),
	(377, 1, 0, -50242, 823, 0, 0, 39, '822'),
	(377, 1, 0, -50242, 824, 0, 0, 39, '823'),
	(377, 1, 0, -50242, 825, 0, 0, 39, '824'),
	(377, 1, 0, -50242, 826, 0, 0, 39, '825'),
	(377, 1, 0, -50242, 827, 0, 0, 39, '826'),
	(377, 1, 0, -50242, 828, 0, 0, 39, '827'),
	(377, 1, 0, -50242, 829, 0, 0, 39, '828'),
	(377, 1, 0, -50242, 830, 0, 0, 39, '829'),
	(377, 1, 0, -50242, 831, 0, 0, 39, '830'),
	(377, 1, 0, -50242, 832, 0, 0, 39, '831'),
	(377, 1, 0, -50242, 833, 0, 0, 39, '832'),
	(377, 1, 0, -50242, 834, 0, 0, 39, '833'),
	(377, 1, 0, -50242, 835, 0, 0, 39, '834'),
	(377, 1, 0, -50242, 836, 0, 0, 39, '835'),
	(377, 1, 0, -50242, 837, 0, 0, 39, '836'),
	(377, 1, 0, -50242, 838, 0, 0, 39, '837'),
	(377, 1, 0, -50242, 839, 0, 0, 39, '838'),
	(377, 1, 0, -50242, 840, 0, 0, 39, '839'),
	(377, 1, 0, -50242, 841, 0, 0, 39, '840'),
	(377, 1, 0, -50242, 842, 0, 0, 39, '841'),
	(377, 1, 0, -50242, 843, 0, 0, 39, '842'),
	(377, 1, 0, -50242, 844, 0, 0, 39, '843'),
	(377, 1, 0, -50242, 845, 0, 0, 39, '844'),
	(377, 1, 0, -50242, 846, 0, 0, 39, '845'),
	(377, 1, 0, -50242, 847, 0, 0, 39, '846'),
	(377, 1, 0, -50242, 848, 0, 0, 39, '847'),
	(377, 1, 0, -50242, 849, 0, 0, 39, '848'),
	(377, 1, 0, -50242, 850, 0, 0, 39, '849'),
	(377, 1, 0, -50242, 851, 0, 0, 39, '850'),
	(377, 1, 0, -50242, 852, 0, 0, 39, '851'),
	(377, 1, 0, -50242, 853, 0, 0, 39, '852'),
	(377, 1, 0, -50242, 854, 0, 0, 39, '853'),
	(377, 1, 0, -50242, 855, 0, 0, 39, '854'),
	(377, 1, 0, -50242, 856, 0, 0, 39, '855'),
	(377, 1, 0, -50242, 857, 0, 0, 39, '856'),
	(377, 1, 0, -50242, 858, 0, 0, 39, '857'),
	(377, 1, 0, -50242, 859, 0, 0, 39, '858'),
	(377, 1, 0, -50242, 860, 0, 0, 39, '859'),
	(377, 1, 0, -50242, 861, 0, 0, 39, '860'),
	(377, 1, 0, -50242, 862, 0, 0, 39, '861'),
	(377, 1, 0, -50242, 863, 0, 0, 39, '862'),
	(377, 1, 0, -50242, 864, 0, 0, 39, '863'),
	(377, 1, 0, -50242, 865, 0, 0, 39, '864'),
	(377, 1, 0, -50242, 866, 0, 0, 39, '865'),
	(377, 1, 0, -50242, 867, 0, 0, 39, '866'),
	(377, 1, 0, -50242, 868, 0, 0, 39, '867'),
	(377, 1, 0, -50242, 869, 0, 0, 39, '868'),
	(377, 1, 0, -50242, 870, 0, 0, 39, '869'),
	(377, 1, 0, -50242, 871, 0, 0, 39, '870'),
	(377, 1, 0, -50242, 872, 0, 0, 39, '871'),
	(377, 1, 0, -50242, 873, 0, 0, 39, '872'),
	(377, 1, 0, -50242, 874, 0, 0, 39, '873'),
	(377, 1, 0, -50242, 875, 0, 0, 39, '874'),
	(377, 1, 0, -50242, 876, 0, 0, 39, '875'),
	(377, 1, 0, -50242, 877, 0, 0, 39, '876'),
	(377, 1, 0, -50242, 878, 0, 0, 39, '877'),
	(377, 1, 0, -50242, 879, 0, 0, 39, '878'),
	(377, 1, 0, -50242, 880, 0, 0, 39, '879'),
	(377, 1, 0, -50242, 881, 0, 0, 39, '880'),
	(377, 1, 0, -50242, 882, 0, 0, 39, '881'),
	(377, 1, 0, -50242, 883, 0, 0, 39, '882'),
	(377, 1, 0, -50242, 884, 0, 0, 39, '883'),
	(377, 1, 0, -50242, 885, 0, 0, 39, '884'),
	(377, 1, 0, -50242, 886, 0, 0, 39, '885'),
	(377, 1, 0, -50242, 887, 0, 0, 39, '886'),
	(377, 1, 0, -50242, 888, 0, 0, 39, '887'),
	(377, 1, 0, -50242, 889, 0, 0, 39, '888'),
	(377, 1, 0, -50242, 890, 0, 0, 39, '889'),
	(377, 1, 0, -50242, 891, 0, 0, 39, '890'),
	(377, 1, 0, -50242, 892, 0, 0, 39, '891'),
	(377, 1, 0, -50242, 893, 0, 0, 39, '892'),
	(377, 1, 0, -50242, 894, 0, 0, 39, '893'),
	(377, 1, 0, -50242, 895, 0, 0, 39, '894'),
	(377, 1, 0, -50242, 896, 0, 0, 39, '895'),
	(377, 1, 0, -50242, 897, 0, 0, 39, '896'),
	(377, 1, 0, -50242, 898, 0, 0, 39, '897'),
	(377, 1, 0, -50242, 899, 0, 0, 39, '898'),
	(377, 1, 0, -50242, 900, 0, 0, 39, '899'),
	(377, 1, 0, -50242, 901, 0, 0, 39, '900'),
	(377, 1, 0, -50242, 902, 0, 0, 39, '901'),
	(377, 1, 0, -50242, 903, 0, 0, 39, '902'),
	(377, 1, 0, -50242, 904, 0, 0, 39, '903'),
	(377, 1, 0, -50242, 905, 0, 0, 39, '904'),
	(377, 1, 0, -50242, 906, 0, 0, 39, '905'),
	(377, 1, 0, -50242, 907, 0, 0, 39, '906'),
	(377, 1, 0, -50242, 908, 0, 0, 39, '907'),
	(377, 1, 0, -50242, 909, 0, 0, 39, '908'),
	(377, 1, 0, -50242, 910, 0, 0, 39, '909'),
	(377, 1, 0, -50242, 911, 0, 0, 39, '910'),
	(377, 1, 0, -50242, 912, 0, 0, 39, '911'),
	(377, 1, 0, -50242, 913, 0, 0, 39, '912'),
	(377, 1, 0, -50242, 914, 0, 0, 39, '913'),
	(377, 1, 0, -50242, 915, 0, 0, 39, '914'),
	(377, 1, 0, -50242, 916, 0, 0, 39, '915'),
	(377, 1, 0, -50242, 917, 0, 0, 39, '916'),
	(377, 1, 0, -50242, 918, 0, 0, 39, '917'),
	(377, 1, 0, -50242, 919, 0, 0, 39, '918'),
	(377, 1, 0, -50242, 920, 0, 0, 39, '919'),
	(377, 1, 0, -50242, 921, 0, 0, 39, '920'),
	(377, 1, 0, -50242, 922, 0, 0, 39, '921'),
	(377, 1, 0, -50242, 923, 0, 0, 39, '922'),
	(377, 1, 0, -50242, 924, 0, 0, 39, '923'),
	(377, 1, 0, -50242, 925, 0, 0, 39, '924'),
	(377, 1, 0, -50242, 926, 0, 0, 39, '925'),
	(377, 1, 0, -50242, 927, 0, 0, 39, '926'),
	(377, 1, 0, -50242, 928, 0, 0, 39, '927'),
	(377, 1, 0, -50242, 929, 0, 0, 39, '928'),
	(377, 1, 0, -50242, 930, 0, 0, 39, '929'),
	(377, 1, 0, -50242, 931, 0, 0, 39, '930'),
	(377, 1, 0, -50242, 932, 0, 0, 39, '931'),
	(377, 1, 0, -50242, 933, 0, 0, 39, '932'),
	(377, 1, 0, -50242, 934, 0, 0, 39, '933'),
	(377, 1, 0, -50242, 935, 0, 0, 39, '934'),
	(377, 1, 0, -50242, 936, 0, 0, 39, '935'),
	(377, 1, 0, -50242, 937, 0, 0, 39, '936'),
	(377, 1, 0, -50242, 938, 0, 0, 39, '937'),
	(377, 1, 0, -50242, 939, 0, 0, 39, '938'),
	(377, 1, 0, -50242, 940, 0, 0, 39, '939'),
	(377, 1, 0, -50242, 941, 0, 0, 39, '940'),
	(377, 1, 0, -50242, 942, 0, 0, 39, '941'),
	(377, 1, 0, -50242, 943, 0, 0, 39, '942'),
	(377, 1, 0, -50242, 944, 0, 0, 39, '943'),
	(377, 1, 0, -50242, 945, 0, 0, 39, '944'),
	(377, 1, 0, -50242, 946, 0, 0, 39, '945'),
	(377, 1, 0, -50242, 947, 0, 0, 39, '946'),
	(377, 1, 0, -50242, 948, 0, 0, 39, '947'),
	(377, 1, 0, -50242, 949, 0, 0, 39, '948'),
	(377, 1, 0, -50242, 950, 0, 0, 39, '949'),
	(377, 1, 0, -50242, 951, 0, 0, 39, '950'),
	(377, 1, 0, -50242, 952, 0, 0, 39, '951'),
	(377, 1, 0, -50242, 953, 0, 0, 39, '952'),
	(377, 1, 0, -50242, 954, 0, 0, 39, '953'),
	(377, 1, 0, -50242, 955, 0, 0, 39, '954'),
	(377, 1, 0, -50242, 956, 0, 0, 39, '955'),
	(377, 1, 0, -50242, 957, 0, 0, 39, '956'),
	(377, 1, 0, -50242, 958, 0, 0, 39, '957'),
	(377, 1, 0, -50242, 959, 0, 0, 39, '958'),
	(377, 1, 0, -50242, 960, 0, 0, 39, '959'),
	(377, 1, 0, -50242, 961, 0, 0, 39, '960'),
	(377, 1, 0, -50242, 962, 0, 0, 39, '961'),
	(377, 1, 0, -50242, 963, 0, 0, 39, '962'),
	(377, 1, 0, -50242, 964, 0, 0, 39, '963'),
	(377, 1, 0, -50242, 965, 0, 0, 39, '964'),
	(377, 1, 0, -50242, 966, 0, 0, 39, '965'),
	(377, 1, 0, -50242, 967, 0, 0, 39, '966'),
	(377, 1, 0, -50242, 968, 0, 0, 39, '967'),
	(377, 1, 0, -50242, 969, 0, 0, 39, '968'),
	(377, 1, 0, -50242, 970, 0, 0, 39, '969'),
	(377, 1, 0, -50242, 971, 0, 0, 39, '970'),
	(377, 1, 0, -50242, 972, 0, 0, 39, '971'),
	(377, 1, 0, -50242, 973, 0, 0, 39, '972'),
	(377, 1, 0, -50242, 974, 0, 0, 39, '973'),
	(377, 1, 0, -50242, 975, 0, 0, 39, '974'),
	(377, 1, 0, -50242, 976, 0, 0, 39, '975'),
	(377, 1, 0, -50242, 977, 0, 0, 39, '976'),
	(377, 1, 0, -50242, 978, 0, 0, 39, '977'),
	(377, 1, 0, -50242, 979, 0, 0, 39, '978'),
	(377, 1, 0, -50242, 980, 0, 0, 39, '979'),
	(377, 1, 0, -50242, 981, 0, 0, 39, '980'),
	(377, 1, 0, -50242, 982, 0, 0, 39, '981'),
	(377, 1, 0, -50242, 983, 0, 0, 39, '982'),
	(377, 1, 0, -50242, 984, 0, 0, 39, '983'),
	(377, 1, 0, -50242, 985, 0, 0, 39, '984'),
	(377, 1, 0, -50242, 986, 0, 0, 39, '985'),
	(377, 1, 0, -50242, 987, 0, 0, 39, '986'),
	(377, 1, 0, -50242, 988, 0, 0, 39, '987'),
	(377, 1, 0, -50242, 989, 0, 0, 39, '988'),
	(377, 1, 0, -50242, 990, 0, 0, 39, '989'),
	(377, 1, 0, -50242, 991, 0, 0, 39, '990'),
	(377, 1, 0, -50242, 992, 0, 0, 39, '991'),
	(377, 1, 0, -50242, 993, 0, 0, 39, '992'),
	(377, 1, 0, -50242, 994, 0, 0, 39, '993'),
	(377, 1, 0, -50242, 995, 0, 0, 39, '994'),
	(377, 1, 0, -50242, 996, 0, 0, 39, '995'),
	(377, 1, 0, -50242, 997, 0, 0, 39, '996'),
	(377, 1, 0, -50242, 998, 0, 0, 39, '997'),
	(377, 1, 0, -50242, 999, 0, 0, 39, '998'),
	(377, 1, 0, -50242, 1000, 0, 0, 39, '999'),
	(377, 1, 0, -50242, 1001, 0, 0, 39, '1000'),
	(377, 1, 0, -50242, 1002, 0, 0, 39, '1001'),
	(377, 1, 0, -50242, 1003, 0, 0, 39, '1002'),
	(377, 1, 0, -50242, 1004, 0, 0, 39, '1003'),
	(377, 1, 0, -50242, 1005, 0, 0, 39, '1004'),
	(377, 1, 0, -50242, 1006, 0, 0, 39, '1005'),
	(377, 1, 0, -50242, 1007, 0, 0, 39, '1006'),
	(377, 1, 0, -50242, 1008, 0, 0, 39, '1007'),
	(377, 1, 0, -50242, 1009, 0, 0, 39, '1008'),
	(377, 1, 0, -50242, 1010, 0, 0, 39, '1009'),
	(377, 1, 0, -50242, 1011, 0, 0, 39, '1010'),
	(377, 1, 0, -50242, 1012, 0, 0, 39, '1011'),
	(377, 1, 0, -50242, 1013, 0, 0, 39, '1012'),
	(377, 1, 0, -50242, 1014, 0, 0, 39, '1013'),
	(377, 1, 0, -50242, 1015, 0, 0, 39, '1014'),
	(377, 1, 0, -50242, 1016, 0, 0, 39, '1015'),
	(377, 1, 0, -50242, 1017, 0, 0, 39, '1016'),
	(377, 1, 0, -50242, 1018, 0, 0, 39, '1017'),
	(377, 1, 0, -50242, 1019, 0, 0, 39, '1018'),
	(377, 1, 0, -50242, 1020, 0, 0, 39, '1019'),
	(377, 1, 0, -50242, 1021, 0, 0, 39, '1020'),
	(377, 1, 0, -50242, 1022, 0, 0, 39, '1021'),
	(377, 1, 0, -50242, 1023, 0, 0, 39, '1022'),
	(377, 1, 0, -50242, 1024, 0, 0, 39, '1023'),
	(377, 1, 0, -50242, 1025, 0, 0, 39, '1024'),
	(377, 1, 0, -50242, 1026, 0, 0, 39, '1025'),
	(377, 1, 0, -50242, 1027, 0, 0, 39, '1026'),
	(377, 1, 0, -50242, 1028, 0, 0, 39, '1027'),
	(377, 1, 0, -50242, 1029, 0, 0, 39, '1028'),
	(377, 1, 0, -50242, 1030, 0, 0, 39, '1029'),
	(377, 1, 0, -50242, 1031, 0, 0, 39, '1030'),
	(377, 1, 0, -50242, 1032, 0, 0, 39, '1031'),
	(377, 1, 0, -50242, 1033, 0, 0, 39, '1032'),
	(377, 1, 0, -50242, 1034, 0, 0, 39, '1033'),
	(377, 1, 0, -50242, 1035, 0, 0, 39, '1034'),
	(377, 1, 0, -50242, 1036, 0, 0, 39, '1035'),
	(377, 1, 0, -50242, 1037, 0, 0, 39, '1036'),
	(377, 1, 0, -50242, 1038, 0, 0, 39, '1037'),
	(377, 1, 0, -50242, 1039, 0, 0, 39, '1038'),
	(377, 1, 0, -50242, 1040, 0, 0, 39, '1039'),
	(377, 1, 0, -50242, 1041, 0, 0, 39, '1040'),
	(377, 1, 0, -50242, 1042, 0, 0, 39, '1041'),
	(377, 1, 0, -50242, 1043, 0, 0, 39, '1042'),
	(377, 1, 0, -50242, 1044, 0, 0, 39, '1043'),
	(377, 1, 0, -50242, 1045, 0, 0, 39, '1044'),
	(377, 1, 0, -50242, 1046, 0, 0, 39, '1045'),
	(377, 1, 0, -50242, 1047, 0, 0, 39, '1046'),
	(377, 1, 0, -50242, 1048, 0, 0, 39, '1047'),
	(377, 1, 0, -50242, 1049, 0, 0, 39, '1048'),
	(377, 1, 0, -50242, 1050, 0, 0, 39, '1049'),
	(377, 1, 0, -50242, 1051, 0, 0, 39, '1050'),
	(377, 1, 0, -50242, 1052, 0, 0, 39, '1051'),
	(377, 1, 0, -50242, 1053, 0, 0, 39, '1052'),
	(377, 1, 0, -50242, 1054, 0, 0, 39, '1053'),
	(377, 1, 0, -50242, 1055, 0, 0, 39, '1054'),
	(377, 1, 0, -50242, 1056, 0, 0, 39, '1055'),
	(377, 1, 0, -50242, 1057, 0, 0, 39, '1056'),
	(377, 1, 0, -50242, 1058, 0, 0, 39, '1057'),
	(377, 1, 0, -50242, 1059, 0, 0, 39, '1058'),
	(377, 1, 0, -50242, 1060, 0, 0, 39, '1059'),
	(377, 1, 0, -50242, 1061, 0, 0, 39, '1060'),
	(377, 1, 0, -50242, 1062, 0, 0, 39, '1061'),
	(377, 1, 0, -50242, 1063, 0, 0, 39, '1062'),
	(377, 1, 0, -50242, 1064, 0, 0, 39, '1063'),
	(377, 1, 0, -50242, 1065, 0, 0, 39, '1064'),
	(377, 1, 0, -50242, 1066, 0, 0, 39, '1065'),
	(377, 1, 0, -50242, 1067, 0, 0, 39, '1066'),
	(377, 1, 0, -50242, 1068, 0, 0, 39, '1067'),
	(377, 1, 0, -50242, 1069, 0, 0, 39, '1068'),
	(377, 1, 0, -50242, 1070, 0, 0, 39, '1069'),
	(377, 1, 0, -50242, 1071, 0, 0, 39, '1070'),
	(377, 1, 0, -50242, 1072, 0, 0, 39, '1071'),
	(377, 1, 0, -50242, 1073, 0, 0, 39, '1072'),
	(377, 1, 0, -50242, 1074, 0, 0, 39, '1073'),
	(377, 1, 0, -50242, 1075, 0, 0, 39, '1074'),
	(377, 1, 0, -50242, 1076, 0, 0, 39, '1075'),
	(377, 1, 0, -50242, 1077, 0, 0, 39, '1076'),
	(377, 1, 0, -50242, 1078, 0, 0, 39, '1077'),
	(377, 1, 0, -50242, 1079, 0, 0, 39, '1078'),
	(377, 1, 0, -50242, 1080, 0, 0, 39, '1079'),
	(377, 1, 0, -50242, 1081, 0, 0, 39, '1080'),
	(377, 1, 0, -50242, 1082, 0, 0, 39, '1081'),
	(377, 1, 0, -50242, 1083, 0, 0, 39, '1082'),
	(377, 1, 0, -50242, 1084, 0, 0, 39, '1083'),
	(377, 1, 0, -50242, 1085, 0, 0, 39, '1084'),
	(377, 1, 0, -50242, 1086, 0, 0, 39, '1085'),
	(377, 1, 0, -50242, 1087, 0, 0, 39, '1086'),
	(377, 1, 0, -50242, 1088, 0, 0, 39, '1087'),
	(377, 1, 0, -50242, 1089, 0, 0, 39, '1088'),
	(377, 1, 0, -50242, 1090, 0, 0, 39, '1089'),
	(377, 1, 0, -50242, 1091, 0, 0, 39, '1090'),
	(377, 1, 0, -50242, 1092, 0, 0, 39, '1091'),
	(377, 1, 0, -50242, 1093, 0, 0, 39, '1092'),
	(377, 1, 0, -50242, 1094, 0, 0, 39, '1093'),
	(377, 1, 0, -50242, 1095, 0, 0, 39, '1094'),
	(377, 1, 0, -50242, 1096, 0, 0, 39, '1095'),
	(377, 1, 0, -50242, 1097, 0, 0, 39, '1096'),
	(377, 1, 0, -50242, 1098, 0, 0, 39, '1097'),
	(377, 1, 0, -50242, 1099, 0, 0, 39, '1098'),
	(377, 1, 0, -50242, 1100, 0, 0, 39, '1099'),
	(377, 1, 0, -50242, 1101, 0, 0, 39, '1100'),
	(377, 1, 0, -50242, 1102, 0, 0, 39, '1101'),
	(377, 1, 0, -50242, 1103, 0, 0, 39, '1102'),
	(377, 1, 0, -50242, 1104, 0, 0, 39, '1103'),
	(377, 1, 0, -50242, 1105, 0, 0, 39, '1104'),
	(377, 1, 0, -50242, 1106, 0, 0, 39, '1105'),
	(377, 1, 0, -50242, 1107, 0, 0, 39, '1106'),
	(377, 1, 0, -50242, 1108, 0, 0, 39, '1107'),
	(377, 1, 0, -50242, 1109, 0, 0, 39, '1108'),
	(377, 1, 0, -50242, 1110, 0, 0, 39, '1109'),
	(377, 1, 0, -50242, 1111, 0, 0, 39, '1110'),
	(377, 1, 0, -50242, 1112, 0, 0, 39, '1111'),
	(377, 1, 0, -50242, 1113, 0, 0, 39, '1112'),
	(377, 1, 0, -50242, 1114, 0, 0, 39, '1113'),
	(377, 1, 0, -50242, 1115, 0, 0, 39, '1114'),
	(377, 1, 0, -50242, 1116, 0, 0, 39, '1115'),
	(377, 1, 0, -50242, 1117, 0, 0, 39, '1116'),
	(377, 1, 0, -50242, 1118, 0, 0, 39, '1117'),
	(377, 1, 0, -50242, 1119, 0, 0, 39, '1118'),
	(377, 1, 0, -50242, 1120, 0, 0, 39, '1119'),
	(377, 1, 0, -50242, 1121, 0, 0, 39, '1120'),
	(377, 1, 0, -50242, 1122, 0, 0, 39, '1121'),
	(377, 1, 0, -50242, 1123, 0, 0, 39, '1122'),
	(377, 1, 0, -50242, 1124, 0, 0, 39, '1123'),
	(377, 1, 0, -50242, 1125, 0, 0, 39, '1124'),
	(377, 1, 0, -50242, 1126, 0, 0, 39, '1125'),
	(377, 1, 0, -50242, 1127, 0, 0, 39, '1126'),
	(377, 1, 0, -50242, 1128, 0, 0, 39, '1127'),
	(377, 1, 0, -50242, 1129, 0, 0, 39, '1128'),
	(377, 1, 0, -50242, 1130, 0, 0, 39, '1129'),
	(377, 1, 0, -50242, 1131, 0, 0, 39, '1130'),
	(377, 1, 0, -50242, 1132, 0, 0, 39, '1131'),
	(377, 1, 0, -50242, 1133, 0, 0, 39, '1132'),
	(377, 1, 0, -50242, 1134, 0, 0, 39, '1133'),
	(377, 1, 0, -50242, 1135, 0, 0, 39, '1134'),
	(377, 1, 0, -50242, 1136, 0, 0, 39, '1135'),
	(377, 1, 0, -50242, 1137, 0, 0, 39, '1136'),
	(377, 1, 0, -50242, 1138, 0, 0, 39, '1137'),
	(377, 1, 0, -50242, 1139, 0, 0, 39, '1138'),
	(377, 1, 0, -50242, 1140, 0, 0, 39, '1139'),
	(377, 1, 0, -50242, 1141, 0, 0, 39, '1140'),
	(377, 1, 0, -50242, 1142, 0, 0, 39, '1141'),
	(377, 1, 0, -50242, 1143, 0, 0, 39, '1142'),
	(377, 1, 0, -50242, 1144, 0, 0, 39, '1143'),
	(377, 1, 0, -50242, 1145, 0, 0, 39, '1144'),
	(377, 1, 0, -50242, 1146, 0, 0, 39, '1145'),
	(377, 1, 0, -50242, 1147, 0, 0, 39, '1146'),
	(377, 1, 0, -50242, 1148, 0, 0, 39, '1147'),
	(377, 1, 0, -50242, 1149, 0, 0, 39, '1148'),
	(377, 1, 0, -50242, 1150, 0, 0, 39, '1149'),
	(377, 1, 0, -50242, 1151, 0, 0, 39, '1150'),
	(377, 1, 0, -50242, 1152, 0, 0, 39, '1151'),
	(377, 1, 0, -50242, 1153, 0, 0, 39, '1152'),
	(377, 1, 0, -50242, 1154, 0, 0, 39, '1153'),
	(377, 1, 0, -50242, 1155, 0, 0, 39, '1154'),
	(377, 1, 0, -50242, 1156, 0, 0, 39, '1155'),
	(377, 1, 0, -50242, 1157, 0, 0, 39, '1156'),
	(377, 1, 0, -50242, 1158, 0, 0, 39, '1157'),
	(377, 1, 0, -50242, 1159, 0, 0, 39, '1158'),
	(377, 1, 0, -50242, 1160, 0, 0, 39, '1159'),
	(377, 1, 0, -50242, 1161, 0, 0, 39, '1160'),
	(377, 1, 0, -50242, 1162, 0, 0, 39, '1161'),
	(377, 1, 0, -50242, 1163, 0, 0, 39, '1162'),
	(377, 1, 0, -50242, 1164, 0, 0, 39, '1163'),
	(377, 1, 0, -50242, 1165, 0, 0, 39, '1164'),
	(377, 1, 0, -50242, 1166, 0, 0, 39, '1165'),
	(377, 1, 0, -50242, 1167, 0, 0, 39, '1166'),
	(377, 1, 0, -50242, 1168, 0, 0, 39, '1167'),
	(377, 1, 0, -50242, 1169, 0, 0, 39, '1168'),
	(377, 1, 0, -50242, 1170, 0, 0, 39, '1169'),
	(377, 1, 0, -50242, 1171, 0, 0, 39, '1170'),
	(377, 1, 0, -50242, 1172, 0, 0, 39, '1171'),
	(377, 1, 0, -50242, 1173, 0, 0, 39, '1172'),
	(377, 1, 0, -50242, 1174, 0, 0, 39, '1173'),
	(377, 1, 0, -50242, 1175, 0, 0, 39, '1174'),
	(377, 1, 0, -50242, 1176, 0, 0, 39, '1175'),
	(377, 1, 0, -50242, 1177, 0, 0, 39, '1176'),
	(377, 1, 0, -50242, 1178, 0, 0, 39, '1177'),
	(377, 1, 0, -50242, 1179, 0, 0, 39, '1178'),
	(377, 1, 0, -50242, 1180, 0, 0, 39, '1179'),
	(377, 1, 0, -50242, 1181, 0, 0, 39, '1180'),
	(377, 1, 0, -50242, 1182, 0, 0, 39, '1181'),
	(377, 1, 0, -50242, 1183, 0, 0, 39, '1182'),
	(377, 1, 0, -50242, 1184, 0, 0, 39, '1183'),
	(377, 1, 0, -50242, 1185, 0, 0, 39, '1184'),
	(377, 1, 0, -50242, 1186, 0, 0, 39, '1185'),
	(377, 1, 0, -50242, 1187, 0, 0, 39, '1186'),
	(377, 1, 0, -50242, 1188, 0, 0, 39, '1187'),
	(377, 1, 0, -50242, 1189, 0, 0, 39, '1188'),
	(377, 1, 0, -50242, 1190, 0, 0, 39, '1189'),
	(377, 1, 0, -50242, 1191, 0, 0, 39, '1190'),
	(377, 1, 0, -50242, 1192, 0, 0, 39, '1191'),
	(377, 1, 0, -50242, 1193, 0, 0, 39, '1192'),
	(377, 1, 0, -50242, 1194, 0, 0, 39, '1193'),
	(377, 1, 0, -50242, 1195, 0, 0, 39, '1194'),
	(377, 1, 0, -50242, 1196, 0, 0, 39, '1195'),
	(377, 1, 0, -50242, 1197, 0, 0, 39, '1196'),
	(377, 1, 0, -50242, 1198, 0, 0, 39, '1197'),
	(377, 1, 0, -50242, 1199, 0, 0, 39, '1198'),
	(377, 1, 0, -50242, 1200, 0, 0, 39, '1199'),
	(377, 1, 0, -50242, 1201, 0, 0, 39, '1200'),
	(377, 1, 0, -50242, 1202, 0, 0, 39, '1201'),
	(377, 1, 0, -50242, 1203, 0, 0, 39, '1202'),
	(377, 1, 0, -50242, 1204, 0, 0, 39, '1203'),
	(377, 1, 0, -50242, 1205, 0, 0, 39, '1204'),
	(377, 1, 0, -50242, 1206, 0, 0, 39, '1205'),
	(377, 1, 0, -50242, 1207, 0, 0, 39, '1206'),
	(377, 1, 0, -50242, 1208, 0, 0, 39, '1207'),
	(377, 1, 0, -50242, 1209, 0, 0, 39, '1208'),
	(377, 1, 0, -50242, 1210, 0, 0, 39, '1209'),
	(377, 1, 0, -50242, 1211, 0, 0, 39, '1210'),
	(377, 1, 0, -50242, 1212, 0, 0, 39, '1211'),
	(377, 1, 0, -50242, 1213, 0, 0, 39, '1212'),
	(377, 1, 0, -50242, 1214, 0, 0, 39, '1213'),
	(377, 1, 0, -50242, 1215, 0, 0, 39, '1214'),
	(377, 1, 0, -50242, 1216, 0, 0, 39, '1215'),
	(377, 1, 0, -50242, 1217, 0, 0, 39, '1216'),
	(377, 1, 0, -50242, 1218, 0, 0, 39, '1217'),
	(377, 1, 0, -50242, 1219, 0, 0, 39, '1218'),
	(377, 1, 0, -50242, 1220, 0, 0, 39, '1219'),
	(377, 1, 0, -50242, 1221, 0, 0, 39, '1220'),
	(377, 1, 0, -50242, 1222, 0, 0, 39, '1221'),
	(377, 1, 0, -50242, 1223, 0, 0, 39, '1222'),
	(377, 1, 0, -50242, 1224, 0, 0, 39, '1223'),
	(377, 1, 0, -50242, 1225, 0, 0, 39, '1224'),
	(377, 1, 0, -50242, 1226, 0, 0, 39, '1225'),
	(377, 1, 0, -50242, 1227, 0, 0, 39, '1226'),
	(377, 1, 0, -50242, 1228, 0, 0, 39, '1227'),
	(377, 1, 0, -50242, 1229, 0, 0, 39, '1228'),
	(377, 1, 0, -50242, 1230, 0, 0, 39, '1229'),
	(377, 1, 0, -50242, 1231, 0, 0, 39, '1230'),
	(377, 1, 0, -50242, 1232, 0, 0, 39, '1231'),
	(377, 1, 0, -50242, 1233, 0, 0, 39, '1232'),
	(377, 1, 0, -50242, 1234, 0, 0, 39, '1233'),
	(377, 1, 0, -50242, 1235, 0, 0, 39, '1234'),
	(377, 1, 0, -50242, 1236, 0, 0, 39, '1235'),
	(377, 1, 0, -50242, 1237, 0, 0, 39, '1236'),
	(377, 1, 0, -50242, 1238, 0, 0, 39, '1237'),
	(377, 1, 0, -50242, 1239, 0, 0, 39, '1238'),
	(377, 1, 0, -50242, 1240, 0, 0, 39, '1239'),
	(377, 1, 0, -50242, 1241, 0, 0, 39, '1240'),
	(377, 1, 0, -50242, 1242, 0, 0, 39, '1241'),
	(377, 1, 0, -50242, 1243, 0, 0, 39, '1242'),
	(377, 1, 0, -50242, 1244, 0, 0, 39, '1243'),
	(377, 1, 0, -50242, 1245, 0, 0, 39, '1244'),
	(377, 1, 0, -50242, 1246, 0, 0, 39, '1245'),
	(377, 1, 0, -50242, 1247, 0, 0, 39, '1246'),
	(377, 1, 0, -50242, 1248, 0, 0, 39, '1247'),
	(377, 1, 0, -50242, 1249, 0, 0, 39, '1248'),
	(377, 1, 0, -50242, 1250, 0, 0, 39, '1249'),
	(377, 1, 0, -50242, 1251, 0, 0, 39, '1250'),
	(377, 1, 0, -50242, 1252, 0, 0, 39, '1251'),
	(377, 1, 0, -50242, 1253, 0, 0, 39, '1252'),
	(377, 1, 0, -50242, 1254, 0, 0, 39, '1253'),
	(377, 1, 0, -50242, 1255, 0, 0, 39, '1254'),
	(377, 1, 0, -50242, 1256, 0, 0, 39, '1255'),
	(377, 1, 0, -50242, 1257, 0, 0, 39, '1256'),
	(377, 1, 0, -50242, 1258, 0, 0, 39, '1257'),
	(377, 1, 0, -50242, 1259, 0, 0, 39, '1258'),
	(377, 1, 0, -50242, 1260, 0, 0, 39, '1259'),
	(377, 1, 0, -50242, 1261, 0, 0, 39, '1260'),
	(377, 1, 0, -50242, 1262, 0, 0, 39, '1261'),
	(377, 1, 0, -50242, 1263, 0, 0, 39, '1262'),
	(377, 1, 0, -50242, 1264, 0, 0, 39, '1263'),
	(377, 1, 0, -50242, 1265, 0, 0, 39, '1264'),
	(377, 1, 0, -50242, 1266, 0, 0, 39, '1265'),
	(377, 1, 0, -50242, 1267, 0, 0, 39, '1266'),
	(377, 1, 0, -50242, 1268, 0, 0, 39, '1267'),
	(377, 1, 0, -50242, 1269, 0, 0, 39, '1268'),
	(377, 1, 0, -50242, 1270, 0, 0, 39, '1269'),
	(377, 1, 0, -50242, 1271, 0, 0, 39, '1270'),
	(377, 1, 0, -50242, 1272, 0, 0, 39, '1271'),
	(377, 1, 0, -50242, 1273, 0, 0, 39, '1272'),
	(377, 1, 0, -50242, 1274, 0, 0, 39, '1273'),
	(377, 1, 0, -50242, 1275, 0, 0, 39, '1274'),
	(377, 1, 0, -50242, 1276, 0, 0, 39, '1275'),
	(377, 1, 0, -50242, 1277, 0, 0, 39, '1276'),
	(377, 1, 0, -50242, 1278, 0, 0, 39, '1277'),
	(377, 1, 0, -50242, 1279, 0, 0, 39, '1278'),
	(377, 1, 0, -50242, 1280, 0, 0, 39, '1279'),
	(377, 1, 0, -50242, 1281, 0, 0, 39, '1280'),
	(377, 1, 0, -50242, 1282, 0, 0, 39, '1281'),
	(377, 1, 0, -50242, 1283, 0, 0, 39, '1282'),
	(377, 1, 0, -50242, 1284, 0, 0, 39, '1283'),
	(377, 1, 0, -50242, 1285, 0, 0, 39, '1284'),
	(377, 1, 0, -50242, 1286, 0, 0, 39, '1285'),
	(377, 1, 0, -50242, 1287, 0, 0, 39, '1286'),
	(377, 1, 0, -50242, 1288, 0, 0, 39, '1287'),
	(377, 1, 0, -50242, 1289, 0, 0, 39, '1288'),
	(377, 1, 0, -50242, 1290, 0, 0, 39, '1289'),
	(377, 1, 0, -50242, 1291, 0, 0, 39, '1290'),
	(377, 1, 0, -50242, 1292, 0, 0, 39, '1291'),
	(377, 1, 0, -50242, 1293, 0, 0, 39, '1292'),
	(377, 1, 0, -50242, 1294, 0, 0, 39, '1293'),
	(377, 1, 0, -50242, 1295, 0, 0, 39, '1294'),
	(377, 1, 0, -50242, 1296, 0, 0, 39, '1295'),
	(377, 1, 0, -50242, 1297, 0, 0, 39, '1296'),
	(377, 1, 0, -50242, 1298, 0, 0, 39, '1297'),
	(377, 1, 0, -50242, 1299, 0, 0, 39, '1298'),
	(377, 1, 0, -50242, 1300, 0, 0, 39, '1299'),
	(377, 1, 0, -50242, 1301, 0, 0, 39, '1300'),
	(377, 1, 0, -50242, 1302, 0, 0, 39, '1301'),
	(377, 1, 0, -50242, 1303, 0, 0, 39, '1302'),
	(377, 1, 0, -50242, 1304, 0, 0, 39, '1303'),
	(377, 1, 0, -50242, 1305, 0, 0, 39, '1304'),
	(377, 1, 0, -50242, 1306, 0, 0, 39, '1305'),
	(377, 1, 0, -50242, 1307, 0, 0, 39, '1306'),
	(377, 1, 0, -50242, 1308, 0, 0, 39, '1307'),
	(377, 1, 0, -50242, 1309, 0, 0, 39, '1308'),
	(377, 1, 0, -50242, 1310, 0, 0, 39, '1309'),
	(377, 1, 0, -50242, 1311, 0, 0, 39, '1310'),
	(377, 1, 0, -50242, 1312, 0, 0, 39, '1311'),
	(377, 1, 0, -50242, 1313, 0, 0, 39, '1312'),
	(377, 1, 0, -50242, 1314, 0, 0, 39, '1313'),
	(377, 1, 0, -50242, 1315, 0, 0, 39, '1314'),
	(377, 1, 0, -50242, 1316, 0, 0, 39, '1315'),
	(377, 1, 0, -50242, 1317, 0, 0, 39, '1316'),
	(377, 1, 0, -50242, 1318, 0, 0, 39, '1317'),
	(377, 1, 0, -50242, 1319, 0, 0, 39, '1318'),
	(377, 1, 0, -50242, 1320, 0, 0, 39, '1319'),
	(377, 1, 0, -50242, 1321, 0, 0, 39, '1320'),
	(377, 1, 0, -50242, 1322, 0, 0, 39, '1321'),
	(377, 1, 0, -50242, 1323, 0, 0, 39, '1322'),
	(377, 1, 0, -50242, 1324, 0, 0, 39, '1323'),
	(377, 1, 0, -50242, 1325, 0, 0, 39, '1324'),
	(377, 1, 0, -50242, 1326, 0, 0, 39, '1325'),
	(377, 1, 0, -50242, 1327, 0, 0, 39, '1326'),
	(377, 1, 0, -50242, 1328, 0, 0, 39, '1327'),
	(377, 1, 0, -50242, 1329, 0, 0, 39, '1328'),
	(377, 1, 0, -50242, 1330, 0, 0, 39, '1329'),
	(377, 1, 0, -50242, 1331, 0, 0, 39, '1330'),
	(377, 1, 0, -50242, 1332, 0, 0, 39, '1331'),
	(377, 1, 0, -50242, 1333, 0, 0, 39, '1332'),
	(377, 1, 0, -50242, 1334, 0, 0, 39, '1333'),
	(377, 1, 0, -50242, 1335, 0, 0, 39, '1334'),
	(377, 1, 0, -50242, 1336, 0, 0, 39, '1335'),
	(377, 1, 0, -50242, 1337, 0, 0, 39, '1336'),
	(377, 1, 0, -50242, 1338, 0, 0, 39, '1337'),
	(377, 1, 0, -50242, 1339, 0, 0, 39, '1338'),
	(377, 1, 0, -50242, 1340, 0, 0, 39, '1339'),
	(377, 1, 0, -50242, 1341, 0, 0, 39, '1340'),
	(377, 1, 0, -50242, 1342, 0, 0, 39, '1341'),
	(377, 1, 0, -50242, 1343, 0, 0, 39, '1342'),
	(377, 1, 0, -50242, 1344, 0, 0, 39, '1343'),
	(377, 1, 0, -50242, 1345, 0, 0, 39, '1344'),
	(377, 1, 0, -50242, 1346, 0, 0, 39, '1345'),
	(377, 1, 0, -50242, 1347, 0, 0, 39, '1346'),
	(377, 1, 0, -50242, 1348, 0, 0, 39, '1347'),
	(377, 1, 0, -50242, 1349, 0, 0, 39, '1348'),
	(377, 1, 0, -50242, 1350, 0, 0, 39, '1349'),
	(377, 1, 0, -50242, 1351, 0, 0, 39, '1350'),
	(377, 1, 0, -50242, 1352, 0, 0, 39, '1351'),
	(377, 1, 0, -50242, 1353, 0, 0, 39, '1352'),
	(377, 1, 0, -50242, 1354, 0, 0, 39, '1353'),
	(377, 1, 0, -50242, 1355, 0, 0, 39, '1354'),
	(377, 1, 0, -50242, 1356, 0, 0, 39, '1355'),
	(377, 1, 0, -50242, 1357, 0, 0, 39, '1356'),
	(377, 1, 0, -50242, 1358, 0, 0, 39, '1357'),
	(377, 1, 0, -50242, 1359, 0, 0, 39, '1358'),
	(377, 1, 0, -50242, 1360, 0, 0, 39, '1359'),
	(377, 1, 0, -50242, 1361, 0, 0, 39, '1360'),
	(377, 1, 0, -50242, 1362, 0, 0, 39, '1361'),
	(377, 1, 0, -50242, 1363, 0, 0, 39, '1362'),
	(377, 1, 0, -50242, 1364, 0, 0, 39, '1363'),
	(377, 1, 0, -50242, 1365, 0, 0, 39, '1364'),
	(377, 1, 0, -50242, 1366, 0, 0, 39, '1365'),
	(377, 1, 0, -50242, 1367, 0, 0, 39, '1366'),
	(377, 1, 0, -50242, 1368, 0, 0, 39, '1367'),
	(377, 1, 0, -50242, 1369, 0, 0, 39, '1368'),
	(377, 1, 0, -50242, 1370, 0, 0, 39, '1369'),
	(377, 1, 0, -50242, 1371, 0, 0, 39, '1370'),
	(377, 1, 0, -50242, 1372, 0, 0, 39, '1371'),
	(377, 1, 0, -50242, 1373, 0, 0, 39, '1372'),
	(377, 1, 0, -50242, 1374, 0, 0, 39, '1373'),
	(377, 1, 0, -50242, 1375, 0, 0, 39, '1374'),
	(377, 1, 0, -50242, 1376, 0, 0, 39, '1375'),
	(377, 1, 0, -50242, 1377, 0, 0, 39, '1376'),
	(377, 1, 0, -50242, 1378, 0, 0, 39, '1377'),
	(377, 1, 0, -50242, 1379, 0, 0, 39, '1378'),
	(377, 1, 0, -50242, 1380, 0, 0, 39, '1379'),
	(377, 1, 0, -50242, 1381, 0, 0, 39, '1380'),
	(377, 1, 0, -50242, 1382, 0, 0, 39, '1381'),
	(377, 1, 0, -50242, 1383, 0, 0, 39, '1382'),
	(377, 1, 0, -50242, 1384, 0, 0, 39, '1383'),
	(377, 1, 0, -50242, 1385, 0, 0, 39, '1384'),
	(377, 1, 0, -50242, 1386, 0, 0, 39, '1385'),
	(377, 1, 0, -50242, 1387, 0, 0, 39, '1386'),
	(377, 1, 0, -50242, 1388, 0, 0, 39, '1387'),
	(377, 1, 0, -50242, 1389, 0, 0, 39, '1388'),
	(377, 1, 0, -50242, 1390, 0, 0, 39, '1389'),
	(377, 1, 0, -50242, 1391, 0, 0, 39, '1390'),
	(377, 1, 0, -50242, 1392, 0, 0, 39, '1391'),
	(377, 1, 0, -50242, 1393, 0, 0, 39, '1392'),
	(377, 1, 0, -50242, 1394, 0, 0, 39, '1393'),
	(377, 1, 0, -50242, 1395, 0, 0, 39, '1394'),
	(377, 1, 0, -50242, 1396, 0, 0, 39, '1395'),
	(377, 1, 0, -50242, 1397, 0, 0, 39, '1396'),
	(377, 1, 0, -50242, 1398, 0, 0, 39, '1397'),
	(377, 1, 0, -50242, 1399, 0, 0, 39, '1398'),
	(377, 1, 0, -50242, 1400, 0, 0, 39, '1399'),
	(377, 1, 0, -50242, 1401, 0, 0, 39, '1400'),
	(377, 1, 0, -50242, 1402, 0, 0, 39, '1401'),
	(377, 1, 0, -50242, 1403, 0, 0, 39, '1402'),
	(377, 1, 0, -50242, 1404, 0, 0, 39, '1403'),
	(377, 1, 0, -50242, 1405, 0, 0, 39, '1404'),
	(377, 1, 0, -50242, 1406, 0, 0, 39, '1405'),
	(377, 1, 0, -50242, 1407, 0, 0, 39, '1406'),
	(377, 1, 0, -50242, 1408, 0, 0, 39, '1407'),
	(377, 1, 0, -50242, 1409, 0, 0, 39, '1408'),
	(377, 1, 0, -50242, 1410, 0, 0, 39, '1409'),
	(377, 1, 0, -50242, 1411, 0, 0, 39, '1410'),
	(377, 1, 0, -50242, 1412, 0, 0, 39, '1411'),
	(377, 1, 0, -50242, 1413, 0, 0, 39, '1412'),
	(377, 1, 0, -50242, 1414, 0, 0, 39, '1413'),
	(377, 1, 0, -50242, 1415, 0, 0, 39, '1414'),
	(377, 1, 0, -50242, 1416, 0, 0, 39, '1415'),
	(377, 1, 0, -50242, 1417, 0, 0, 39, '1416'),
	(377, 1, 0, -50242, 1418, 0, 0, 39, '1417'),
	(377, 1, 0, -50242, 1419, 0, 0, 39, '1418'),
	(377, 1, 0, -50242, 1420, 0, 0, 39, '1419'),
	(377, 1, 0, -50242, 1421, 0, 0, 39, '1420'),
	(377, 1, 0, -50242, 1422, 0, 0, 39, '1421'),
	(377, 1, 0, -50242, 1423, 0, 0, 39, '1422'),
	(377, 1, 0, -50242, 1424, 0, 0, 39, '1423'),
	(377, 1, 0, -50242, 1425, 0, 0, 39, '1424'),
	(377, 1, 0, -50242, 1426, 0, 0, 39, '1425'),
	(377, 1, 0, -50242, 1427, 0, 0, 39, '1426'),
	(377, 1, 0, -50242, 1428, 0, 0, 39, '1427'),
	(377, 1, 0, -50242, 1429, 0, 0, 39, '1428'),
	(377, 1, 0, -50242, 1430, 0, 0, 39, '1429'),
	(377, 1, 0, -50242, 1431, 0, 0, 39, '1430'),
	(377, 1, 0, -50242, 1432, 0, 0, 39, '1431'),
	(377, 1, 0, -50242, 1433, 0, 0, 39, '1432'),
	(377, 1, 0, -50242, 1434, 0, 0, 39, '1433'),
	(377, 1, 0, -50242, 1435, 0, 0, 39, '1434'),
	(377, 1, 0, -50242, 1436, 0, 0, 39, '1435'),
	(377, 1, 0, -50242, 1437, 0, 0, 39, '1436'),
	(377, 1, 0, -50242, 1438, 0, 0, 39, '1437'),
	(377, 1, 0, -50242, 1439, 0, 0, 39, '1438'),
	(377, 1, 0, -50242, 1440, 0, 0, 39, '1439'),
	(377, 1, 0, -50242, 1441, 0, 0, 39, '1440'),
	(377, 1, 0, -50242, 1442, 0, 0, 39, '1441'),
	(377, 1, 0, -50242, 1443, 0, 0, 39, '1442'),
	(377, 1, 0, -50242, 1444, 0, 0, 39, '1443'),
	(377, 1, 0, -50242, 1445, 0, 0, 39, '1444'),
	(377, 1, 0, -50242, 1446, 0, 0, 39, '1445'),
	(377, 1, 0, -50242, 1447, 0, 0, 39, '1446'),
	(377, 1, 0, -50242, 1448, 0, 0, 39, '1447'),
	(377, 1, 0, -50242, 1449, 0, 0, 39, '1448'),
	(377, 1, 0, -50242, 1450, 0, 0, 39, '1449'),
	(377, 1, 0, -50242, 1451, 0, 0, 39, '1450'),
	(377, 1, 0, -50242, 1452, 0, 0, 39, '1451'),
	(377, 1, 0, -50242, 1453, 0, 0, 39, '1452'),
	(377, 1, 0, -50242, 1454, 0, 0, 39, '1453'),
	(377, 1, 0, -50242, 1455, 0, 0, 39, '1454'),
	(377, 1, 0, -50242, 1456, 0, 0, 39, '1455'),
	(377, 1, 0, -50242, 1457, 0, 0, 39, '1456'),
	(377, 1, 0, -50242, 1458, 0, 0, 39, '1457'),
	(377, 1, 0, -50242, 1459, 0, 0, 39, '1458'),
	(377, 1, 0, -50242, 1460, 0, 0, 39, '1459'),
	(377, 1, 0, -50242, 1461, 0, 0, 39, '1460'),
	(377, 1, 0, -50242, 1462, 0, 0, 39, '1461'),
	(377, 1, 0, -50242, 1463, 0, 0, 39, '1462'),
	(377, 1, 0, -50242, 1464, 0, 0, 39, '1463'),
	(377, 1, 0, -50242, 1465, 0, 0, 39, '1464'),
	(377, 1, 0, -50242, 1466, 0, 0, 39, '1465'),
	(377, 1, 0, -50242, 1467, 0, 0, 39, '1466'),
	(377, 1, 0, -50242, 1468, 0, 0, 39, '1467'),
	(377, 1, 0, -50242, 1469, 0, 0, 39, '1468'),
	(377, 1, 0, -50242, 1470, 0, 0, 39, '1469'),
	(377, 1, 0, -50242, 1471, 0, 0, 39, '1470'),
	(377, 1, 0, -50242, 1472, 0, 0, 39, '1471'),
	(377, 1, 0, -50242, 1473, 0, 0, 39, '1472'),
	(377, 1, 0, -50242, 1474, 0, 0, 39, '1473'),
	(377, 1, 0, -50242, 1475, 0, 0, 39, '1474'),
	(377, 1, 0, -50242, 1476, 0, 0, 39, '1475'),
	(377, 1, 0, -50242, 1477, 0, 0, 39, '1476'),
	(377, 1, 0, -50242, 1478, 0, 0, 39, '1477'),
	(377, 1, 0, -50242, 1479, 0, 0, 39, '1478'),
	(377, 1, 0, -50242, 1480, 0, 0, 39, '1479'),
	(377, 1, 0, -50242, 1481, 0, 0, 39, '1480'),
	(377, 1, 0, -50242, 1482, 0, 0, 39, '1481'),
	(377, 1, 0, -50242, 1483, 0, 0, 39, '1482'),
	(377, 1, 0, -50242, 1484, 0, 0, 39, '1483'),
	(377, 1, 0, -50242, 1485, 0, 0, 39, '1484'),
	(377, 1, 0, -50242, 1486, 0, 0, 39, '1485'),
	(377, 1, 0, -50242, 1487, 0, 0, 39, '1486'),
	(377, 1, 0, -50242, 1488, 0, 0, 39, '1487'),
	(377, 1, 0, -50242, 1489, 0, 0, 39, '1488'),
	(377, 1, 0, -50242, 1490, 0, 0, 39, '1489'),
	(377, 1, 0, -50242, 1491, 0, 0, 39, '1490'),
	(377, 1, 0, -50242, 1492, 0, 0, 39, '1491'),
	(377, 1, 0, -50242, 1493, 0, 0, 39, '1492'),
	(377, 1, 0, -50242, 1494, 0, 0, 39, '1493'),
	(377, 1, 0, -50242, 1495, 0, 0, 39, '1494'),
	(377, 1, 0, -50242, 1496, 0, 0, 39, '1495'),
	(377, 1, 0, -50242, 1497, 0, 0, 39, '1496'),
	(377, 1, 0, -50242, 1498, 0, 0, 39, '1497'),
	(377, 1, 0, -50242, 1499, 0, 0, 39, '1498'),
	(377, 1, 0, -50242, 1500, 0, 0, 39, '1499'),
	(377, 1, 0, -50242, 1501, 0, 0, 39, '1500'),
	(377, 1, 0, -50242, 1502, 0, 0, 39, '1501'),
	(377, 1, 0, -50242, 1503, 0, 0, 39, '1502'),
	(377, 1, 0, -50242, 1504, 0, 0, 39, '1503'),
	(377, 1, 0, -50242, 1505, 0, 0, 39, '1504'),
	(377, 1, 0, -50242, 1506, 0, 0, 39, '1505'),
	(377, 1, 0, -50242, 1507, 0, 0, 39, '1506'),
	(377, 1, 0, -50242, 1508, 0, 0, 39, '1507'),
	(377, 1, 0, -50242, 1509, 0, 0, 39, '1508'),
	(377, 1, 0, -50242, 1510, 0, 0, 39, '1509'),
	(377, 1, 0, -50242, 1511, 0, 0, 39, '1510'),
	(377, 1, 0, -50242, 1512, 0, 0, 39, '1511'),
	(377, 1, 0, -50242, 1513, 0, 0, 39, '1512'),
	(377, 1, 0, -50242, 1514, 0, 0, 39, '1513'),
	(377, 1, 0, -50242, 1515, 0, 0, 39, '1514'),
	(377, 1, 0, -50242, 1516, 0, 0, 39, '1515'),
	(377, 1, 0, -50242, 1517, 0, 0, 39, '1516'),
	(377, 1, 0, -50242, 1518, 0, 0, 39, '1517'),
	(377, 1, 0, -50242, 1519, 0, 0, 39, '1518'),
	(377, 1, 0, -50242, 1520, 0, 0, 39, '1519'),
	(377, 1, 0, -50242, 1521, 0, 0, 39, '1520'),
	(377, 1, 0, -50242, 1522, 0, 0, 39, '1521'),
	(377, 1, 0, -50242, 1523, 0, 0, 39, '1522'),
	(377, 1, 0, -50242, 1524, 0, 0, 39, '1523'),
	(377, 1, 0, -50242, 1525, 0, 0, 39, '1524'),
	(377, 1, 0, -50242, 1526, 0, 0, 39, '1525'),
	(377, 1, 0, -50242, 1527, 0, 0, 39, '1526'),
	(377, 1, 0, -50242, 1528, 0, 0, 39, '1527'),
	(377, 1, 0, -50242, 1529, 0, 0, 39, '1528'),
	(377, 1, 0, -50242, 1530, 0, 0, 39, '1529'),
	(377, 1, 0, -50242, 1531, 0, 0, 39, '1530'),
	(377, 1, 0, -50242, 1532, 0, 0, 39, '1531'),
	(377, 1, 0, -50242, 1533, 0, 0, 39, '1532'),
	(377, 1, 0, -50242, 1534, 0, 0, 39, '1533'),
	(377, 1, 0, -50242, 1535, 0, 0, 39, '1534'),
	(377, 1, 0, -50242, 1536, 0, 0, 39, '1535'),
	(377, 1, 0, -50242, 1537, 0, 0, 39, '1536'),
	(377, 1, 0, -50242, 1538, 0, 0, 39, '1537'),
	(377, 1, 0, -50242, 1539, 0, 0, 39, '1538'),
	(377, 1, 0, -50242, 1540, 0, 0, 39, '1539'),
	(377, 1, 0, -50242, 1541, 0, 0, 39, '1540'),
	(377, 1, 0, -50242, 1542, 0, 0, 39, '1541'),
	(377, 1, 0, -50242, 1543, 0, 0, 39, '1542'),
	(377, 1, 0, -50242, 1544, 0, 0, 39, '1543'),
	(377, 1, 0, -50242, 1545, 0, 0, 39, '1544'),
	(377, 1, 0, -50242, 1546, 0, 0, 39, '1545'),
	(377, 1, 0, -50242, 1547, 0, 0, 39, '1546'),
	(377, 1, 0, -50242, 1548, 0, 0, 39, '1547'),
	(377, 1, 0, -50242, 1549, 0, 0, 39, '1548'),
	(377, 1, 0, -50242, 1550, 0, 0, 39, '1549'),
	(377, 1, 0, -50242, 1551, 0, 0, 39, '1550'),
	(377, 1, 0, -50242, 1552, 0, 0, 39, '1551'),
	(377, 1, 0, -50242, 1553, 0, 0, 39, '1552'),
	(377, 1, 0, -50242, 1554, 0, 0, 39, '1553'),
	(377, 1, 0, -50242, 1555, 0, 0, 39, '1554'),
	(377, 1, 0, -50242, 1556, 0, 0, 39, '1555'),
	(377, 1, 0, -50242, 1557, 0, 0, 39, '1556'),
	(377, 1, 0, -50242, 1558, 0, 0, 39, '1557'),
	(377, 1, 0, -50242, 1559, 0, 0, 39, '1558'),
	(377, 1, 0, -50242, 1560, 0, 0, 39, '1559'),
	(377, 1, 0, -50242, 1561, 0, 0, 39, '1560'),
	(377, 1, 0, -50242, 1562, 0, 0, 39, '1561'),
	(377, 1, 0, -50242, 1563, 0, 0, 39, '1562'),
	(377, 1, 0, -50242, 1564, 0, 0, 39, '1563'),
	(377, 1, 0, -50242, 1565, 0, 0, 39, '1564'),
	(377, 1, 0, -50242, 1566, 0, 0, 39, '1565'),
	(377, 1, 0, -50242, 1567, 0, 0, 39, '1566'),
	(377, 1, 0, -50242, 1568, 0, 0, 39, '1567'),
	(377, 1, 0, -50242, 1569, 0, 0, 39, '1568'),
	(377, 1, 0, -50242, 1570, 0, 0, 39, '1569'),
	(377, 1, 0, -50242, 1571, 0, 0, 39, '1570'),
	(377, 1, 0, -50242, 1572, 0, 0, 39, '1571'),
	(377, 1, 0, -50242, 1573, 0, 0, 39, '1572'),
	(377, 1, 0, -50242, 1574, 0, 0, 39, '1573'),
	(377, 1, 0, -50242, 1575, 0, 0, 39, '1574'),
	(377, 1, 0, -50242, 1576, 0, 0, 39, '1575'),
	(377, 1, 0, -50242, 1577, 0, 0, 39, '1576'),
	(377, 1, 0, -50242, 1578, 0, 0, 39, '1577'),
	(377, 1, 0, -50242, 1579, 0, 0, 39, '1578'),
	(377, 1, 0, -50242, 1580, 0, 0, 39, '1579'),
	(377, 1, 0, -50242, 1581, 0, 0, 39, '1580'),
	(377, 1, 0, -50242, 1582, 0, 0, 39, '1581'),
	(377, 1, 0, -50242, 1583, 0, 0, 39, '1582'),
	(377, 1, 0, -50242, 1584, 0, 0, 39, '1583'),
	(377, 1, 0, -50242, 1585, 0, 0, 39, '1584'),
	(377, 1, 0, -50242, 1586, 0, 0, 39, '1585'),
	(377, 1, 0, -50242, 1587, 0, 0, 39, '1586'),
	(377, 1, 0, -50242, 1588, 0, 0, 39, '1587'),
	(377, 1, 0, -50242, 1589, 0, 0, 39, '1588'),
	(377, 1, 0, -50242, 1590, 0, 0, 39, '1589'),
	(377, 1, 0, -50242, 1591, 0, 0, 39, '1590'),
	(377, 1, 0, -50242, 1592, 0, 0, 39, '1591'),
	(377, 1, 0, -50242, 1593, 0, 0, 39, '1592'),
	(377, 1, 0, -50242, 1594, 0, 0, 39, '1593'),
	(377, 1, 0, -50242, 1595, 0, 0, 39, '1594'),
	(377, 1, 0, -50242, 1596, 0, 0, 39, '1595'),
	(377, 1, 0, -50242, 1597, 0, 0, 39, '1596'),
	(377, 1, 0, -50242, 1598, 0, 0, 39, '1597'),
	(377, 1, 0, -50242, 1599, 0, 0, 39, '1598'),
	(377, 1, 0, -50242, 1600, 0, 0, 39, '1599'),
	(377, 1, 0, -50242, 1601, 0, 0, 39, '1600'),
	(377, 1, 0, -50242, 1602, 0, 0, 39, '1601'),
	(377, 1, 0, -50242, 1603, 0, 0, 39, '1602'),
	(377, 1, 0, -50242, 1604, 0, 0, 39, '1603'),
	(377, 1, 0, -50242, 1605, 0, 0, 39, '1604'),
	(377, 1, 0, -50242, 1606, 0, 0, 39, '1605'),
	(377, 1, 0, -50242, 1607, 0, 0, 39, '1606'),
	(377, 1, 0, -50242, 1608, 0, 0, 39, '1607'),
	(377, 1, 0, -50242, 1609, 0, 0, 39, '1608'),
	(377, 1, 0, -50242, 1610, 0, 0, 39, '1609'),
	(377, 1, 0, -50242, 1611, 0, 0, 39, '1610'),
	(377, 1, 0, -50242, 1612, 0, 0, 39, '1611'),
	(377, 1, 0, -50242, 1613, 0, 0, 39, '1612'),
	(377, 1, 0, -50242, 1614, 0, 0, 39, '1613'),
	(377, 1, 0, -50242, 1615, 0, 0, 39, '1614'),
	(377, 1, 0, -50242, 1616, 0, 0, 39, '1615'),
	(377, 1, 0, -50242, 1617, 0, 0, 39, '1616'),
	(377, 1, 0, -50242, 1618, 0, 0, 39, '1617'),
	(377, 1, 0, -50242, 1619, 0, 0, 39, '1618'),
	(377, 1, 0, -50242, 1620, 0, 0, 39, '1619'),
	(377, 1, 0, -50242, 1621, 0, 0, 39, '1620'),
	(377, 1, 0, -50242, 1622, 0, 0, 39, '1621'),
	(377, 1, 0, -50242, 1623, 0, 0, 39, '1622'),
	(377, 1, 0, -50242, 1624, 0, 0, 39, '1623'),
	(377, 1, 0, -50242, 1625, 0, 0, 39, '1624'),
	(377, 1, 0, -50242, 1626, 0, 0, 39, '1625'),
	(377, 1, 0, -50242, 1627, 0, 0, 39, '1626'),
	(377, 1, 0, -50242, 1628, 0, 0, 39, '1627'),
	(377, 1, 0, -50242, 1629, 0, 0, 39, '1628'),
	(377, 1, 0, -50242, 1630, 0, 0, 39, '1629'),
	(377, 1, 0, -50242, 1631, 0, 0, 39, '1630'),
	(377, 1, 0, -50242, 1632, 0, 0, 39, '1631'),
	(377, 1, 0, -50242, 1633, 0, 0, 39, '1632'),
	(377, 1, 0, -50242, 1634, 0, 0, 39, '1633'),
	(377, 1, 0, -50242, 1635, 0, 0, 39, '1634'),
	(377, 1, 0, -50242, 1636, 0, 0, 39, '1635'),
	(377, 1, 0, -50242, 1637, 0, 0, 39, '1636'),
	(377, 1, 0, -50242, 1638, 0, 0, 39, '1637'),
	(377, 1, 0, -50242, 1639, 0, 0, 39, '1638'),
	(377, 1, 0, -50242, 1640, 0, 0, 39, '1639'),
	(377, 1, 0, -50242, 1641, 0, 0, 39, '1640'),
	(377, 1, 0, -50242, 1642, 0, 0, 39, '1641'),
	(377, 1, 0, -50242, 1643, 0, 0, 39, '1642'),
	(377, 1, 0, -50242, 1644, 0, 0, 39, '1643'),
	(377, 1, 0, -50242, 1645, 0, 0, 39, '1644'),
	(377, 1, 0, -50242, 1646, 0, 0, 39, '1645'),
	(377, 1, 0, -50242, 1647, 0, 0, 39, '1646'),
	(377, 1, 0, -50242, 1648, 0, 0, 39, '1647'),
	(377, 1, 0, -50242, 1649, 0, 0, 39, '1648'),
	(377, 1, 0, -50242, 1650, 0, 0, 39, '1649'),
	(377, 1, 0, -50242, 1651, 0, 0, 39, '1650'),
	(377, 1, 0, -50242, 1652, 0, 0, 39, '1651'),
	(377, 1, 0, -50242, 1653, 0, 0, 39, '1652'),
	(377, 1, 0, -50242, 1654, 0, 0, 39, '1653'),
	(377, 1, 0, -50242, 1655, 0, 0, 39, '1654'),
	(377, 1, 0, -50242, 1656, 0, 0, 39, '1655'),
	(377, 1, 0, -50242, 1657, 0, 0, 39, '1656'),
	(377, 1, 0, -50242, 1658, 0, 0, 39, '1657'),
	(377, 1, 0, -50242, 1659, 0, 0, 39, '1658'),
	(377, 1, 0, -50242, 1660, 0, 0, 39, '1659'),
	(377, 1, 0, -50242, 1661, 0, 0, 39, '1660'),
	(377, 1, 0, -50242, 1662, 0, 0, 39, '1661'),
	(377, 1, 0, -50242, 1663, 0, 0, 39, '1662'),
	(377, 1, 0, -50242, 1664, 0, 0, 39, '1663'),
	(377, 1, 0, -50242, 1665, 0, 0, 39, '1664'),
	(377, 1, 0, -50242, 1666, 0, 0, 39, '1665'),
	(377, 1, 0, -50242, 1667, 0, 0, 39, '1666'),
	(377, 1, 0, -50242, 1668, 0, 0, 39, '1667'),
	(377, 1, 0, -50242, 1669, 0, 0, 39, '1668'),
	(377, 1, 0, -50242, 1670, 0, 0, 39, '1669'),
	(377, 1, 0, -50242, 1671, 0, 0, 39, '1670'),
	(377, 1, 0, -50242, 1672, 0, 0, 39, '1671'),
	(377, 1, 0, -50242, 1673, 0, 0, 39, '1672'),
	(377, 1, 0, -50242, 1674, 0, 0, 39, '1673'),
	(377, 1, 0, -50242, 1675, 0, 0, 39, '1674'),
	(377, 1, 0, -50242, 1676, 0, 0, 39, '1675'),
	(377, 1, 0, -50242, 1677, 0, 0, 39, '1676'),
	(377, 1, 0, -50242, 1678, 0, 0, 39, '1677'),
	(377, 1, 0, -50242, 1679, 0, 0, 39, '1678'),
	(377, 1, 0, -50242, 1680, 0, 0, 39, '1679'),
	(377, 1, 0, -50242, 1681, 0, 0, 39, '1680'),
	(377, 1, 0, -50242, 1682, 0, 0, 39, '1681'),
	(377, 1, 0, -50242, 1683, 0, 0, 39, '1682'),
	(377, 1, 0, -50242, 1684, 0, 0, 39, '1683'),
	(377, 1, 0, -50242, 1685, 0, 0, 39, '1684'),
	(377, 1, 0, -50242, 1686, 0, 0, 39, '1685'),
	(377, 1, 0, -50242, 1687, 0, 0, 39, '1686'),
	(377, 1, 0, -50242, 1688, 0, 0, 39, '1687'),
	(377, 1, 0, -50242, 1689, 0, 0, 39, '1688'),
	(377, 1, 0, -50242, 1690, 0, 0, 39, '1689'),
	(377, 1, 0, -50242, 1691, 0, 0, 39, '1690'),
	(377, 1, 0, -50242, 1692, 0, 0, 39, '1691'),
	(377, 1, 0, -50242, 1693, 0, 0, 39, '1692'),
	(377, 1, 0, -50242, 1694, 0, 0, 39, '1693'),
	(377, 1, 0, -50242, 1695, 0, 0, 39, '1694'),
	(377, 1, 0, -50242, 1696, 0, 0, 39, '1695'),
	(377, 1, 0, -50242, 1697, 0, 0, 39, '1696'),
	(377, 1, 0, -50242, 1698, 0, 0, 39, '1697'),
	(377, 1, 0, -50242, 1699, 0, 0, 39, '1698'),
	(377, 1, 0, -50242, 1700, 0, 0, 39, '1699'),
	(377, 1, 0, -50242, 1701, 0, 0, 39, '1700'),
	(377, 1, 0, -50242, 1702, 0, 0, 39, '1701'),
	(377, 1, 0, -50242, 1703, 0, 0, 39, '1702'),
	(377, 1, 0, -50242, 1704, 0, 0, 39, '1703'),
	(377, 1, 0, -50242, 1705, 0, 0, 39, '1704'),
	(377, 1, 0, -50242, 1706, 0, 0, 39, '1705'),
	(377, 1, 0, -50242, 1707, 0, 0, 39, '1706'),
	(377, 1, 0, -50242, 1708, 0, 0, 39, '1707'),
	(377, 1, 0, -50242, 1709, 0, 0, 39, '1708'),
	(377, 1, 0, -50242, 1710, 0, 0, 39, '1709'),
	(377, 1, 0, -50242, 1711, 0, 0, 39, '1710'),
	(377, 1, 0, -50242, 1712, 0, 0, 39, '1711'),
	(377, 1, 0, -50242, 1713, 0, 0, 39, '1712'),
	(377, 1, 0, -50242, 1714, 0, 0, 39, '1713'),
	(377, 1, 0, -50242, 1715, 0, 0, 39, '1714'),
	(377, 1, 0, -50242, 1716, 0, 0, 39, '1715'),
	(377, 1, 0, -50242, 1717, 0, 0, 39, '1716'),
	(377, 1, 0, -50242, 1718, 0, 0, 39, '1717'),
	(377, 1, 0, -50242, 1719, 0, 0, 39, '1718'),
	(377, 1, 0, -50242, 1720, 0, 0, 39, '1719'),
	(377, 1, 0, -50242, 1721, 0, 0, 39, '1720'),
	(377, 1, 0, -50242, 1722, 0, 0, 39, '1721'),
	(377, 1, 0, -50242, 1723, 0, 0, 39, '1722'),
	(377, 1, 0, -50242, 1724, 0, 0, 39, '1723'),
	(377, 1, 0, -50242, 1725, 0, 0, 39, '1724'),
	(377, 1, 0, -50242, 1726, 0, 0, 39, '1725'),
	(377, 1, 0, -50242, 1727, 0, 0, 39, '1726'),
	(377, 1, 0, -50242, 1728, 0, 0, 39, '1727'),
	(377, 1, 0, -50242, 1729, 0, 0, 39, '1728'),
	(377, 1, 0, -50242, 1730, 0, 0, 39, '1729'),
	(377, 1, 0, -50242, 1731, 0, 0, 39, '1730'),
	(377, 1, 0, -50242, 1732, 0, 0, 39, '1731'),
	(377, 1, 0, -50242, 1733, 0, 0, 39, '1732'),
	(377, 1, 0, -50242, 1734, 0, 0, 39, '1733'),
	(377, 1, 0, -50242, 1735, 0, 0, 39, '1734'),
	(377, 1, 0, -50242, 1736, 0, 0, 39, '1735'),
	(377, 1, 0, -50242, 1737, 0, 0, 39, '1736'),
	(377, 1, 0, -50242, 1738, 0, 0, 39, '1737'),
	(377, 1, 0, -50242, 1739, 0, 0, 39, '1738'),
	(377, 1, 0, -50242, 1740, 0, 0, 39, '1739'),
	(377, 1, 0, -50242, 1741, 0, 0, 39, '1740'),
	(377, 1, 0, -50242, 1742, 0, 0, 39, '1741'),
	(377, 1, 0, -50242, 1743, 0, 0, 39, '1742'),
	(377, 1, 0, -50242, 1744, 0, 0, 39, '1743'),
	(377, 1, 0, -50242, 1745, 0, 0, 39, '1744'),
	(377, 1, 0, -50242, 1746, 0, 0, 39, '1745'),
	(377, 1, 0, -50242, 1747, 0, 0, 39, '1746'),
	(377, 1, 0, -50242, 1748, 0, 0, 39, '1747'),
	(377, 1, 0, -50242, 1749, 0, 0, 39, '1748'),
	(377, 1, 0, -50242, 1750, 0, 0, 39, '1749'),
	(377, 1, 0, -50242, 1751, 0, 0, 39, '1750'),
	(377, 1, 0, -50242, 1752, 0, 0, 39, '1751'),
	(377, 1, 0, -50242, 1753, 0, 0, 39, '1752'),
	(377, 1, 0, -50242, 1754, 0, 0, 39, '1753'),
	(377, 1, 0, -50242, 1755, 0, 0, 39, '1754'),
	(377, 1, 0, -50242, 1756, 0, 0, 39, '1755'),
	(377, 1, 0, -50242, 1757, 0, 0, 39, '1756'),
	(377, 1, 0, -50242, 1758, 0, 0, 39, '1757'),
	(377, 1, 0, -50242, 1759, 0, 0, 39, '1758'),
	(377, 1, 0, -50242, 1760, 0, 0, 39, '1759'),
	(377, 1, 0, -50242, 1761, 0, 0, 39, '1760'),
	(377, 1, 0, -50242, 1762, 0, 0, 39, '1761'),
	(377, 1, 0, -50242, 1763, 0, 0, 39, '1762'),
	(377, 1, 0, -50242, 1764, 0, 0, 39, '1763'),
	(377, 1, 0, -50242, 1765, 0, 0, 39, '1764'),
	(377, 1, 0, -50242, 1766, 0, 0, 39, '1765'),
	(377, 1, 0, -50242, 1767, 0, 0, 39, '1766'),
	(377, 1, 0, -50242, 1768, 0, 0, 39, '1767'),
	(377, 1, 0, -50242, 1769, 0, 0, 39, '1768'),
	(377, 1, 0, -50242, 1770, 0, 0, 39, '1769'),
	(377, 1, 0, -50242, 1771, 0, 0, 39, '1770'),
	(377, 1, 0, -50242, 1772, 0, 0, 39, '1771'),
	(377, 1, 0, -50242, 1773, 0, 0, 39, '1772'),
	(377, 1, 0, -50242, 1774, 0, 0, 39, '1773'),
	(377, 1, 0, -50242, 1775, 0, 0, 39, '1774'),
	(377, 1, 0, -50242, 1776, 0, 0, 39, '1775'),
	(377, 1, 0, -50242, 1777, 0, 0, 39, '1776'),
	(377, 1, 0, -50242, 1778, 0, 0, 39, '1777'),
	(377, 1, 0, -50242, 1779, 0, 0, 39, '1778'),
	(377, 1, 0, -50242, 1780, 0, 0, 39, '1779'),
	(377, 1, 0, -50242, 1781, 0, 0, 39, '1780'),
	(377, 1, 0, -50242, 1782, 0, 0, 39, '1781'),
	(377, 1, 0, -50242, 1783, 0, 0, 39, '1782'),
	(377, 1, 0, -50242, 1784, 0, 0, 39, '1783'),
	(377, 1, 0, -50242, 1785, 0, 0, 39, '1784'),
	(377, 1, 0, -50242, 1786, 0, 0, 39, '1785'),
	(377, 1, 0, -50242, 1787, 0, 0, 39, '1786'),
	(377, 1, 0, -50242, 1788, 0, 0, 39, '1787'),
	(377, 1, 0, -50242, 1789, 0, 0, 39, '1788'),
	(377, 1, 0, -50242, 1790, 0, 0, 39, '1789'),
	(377, 1, 0, -50242, 1791, 0, 0, 39, '1790'),
	(377, 1, 0, -50242, 1792, 0, 0, 39, '1791'),
	(377, 1, 0, -50242, 1793, 0, 0, 39, '1792'),
	(377, 1, 0, -50242, 1794, 0, 0, 39, '1793'),
	(377, 1, 0, -50242, 1795, 0, 0, 39, '1794'),
	(377, 1, 0, -50242, 1796, 0, 0, 39, '1795'),
	(377, 1, 0, -50242, 1797, 0, 0, 39, '1796'),
	(377, 1, 0, -50242, 1798, 0, 0, 39, '1797'),
	(377, 1, 0, -50242, 1799, 0, 0, 39, '1798'),
	(377, 1, 0, -50242, 1800, 0, 0, 39, '1799'),
	(377, 1, 0, -50242, 1801, 0, 0, 39, '1800'),
	(377, 1, 0, -50242, 1802, 0, 0, 39, '1801'),
	(377, 1, 0, -50242, 1803, 0, 0, 39, '1802'),
	(377, 1, 0, -50242, 1804, 0, 0, 39, '1803'),
	(377, 1, 0, -50242, 1805, 0, 0, 39, '1804'),
	(377, 1, 0, -50242, 1806, 0, 0, 39, '1805'),
	(377, 1, 0, -50242, 1807, 0, 0, 39, '1806'),
	(377, 1, 0, -50242, 1808, 0, 0, 39, '1807'),
	(377, 1, 0, -50242, 1809, 0, 0, 39, '1808'),
	(377, 1, 0, -50242, 1810, 0, 0, 39, '1809'),
	(377, 1, 0, -50242, 1811, 0, 0, 39, '1810'),
	(377, 1, 0, -50242, 1812, 0, 0, 39, '1811'),
	(377, 1, 0, -50242, 1813, 0, 0, 39, '1812'),
	(377, 1, 0, -50242, 1814, 0, 0, 39, '1813'),
	(377, 1, 0, -50242, 1815, 0, 0, 39, '1814'),
	(377, 1, 0, -50242, 1816, 0, 0, 39, '1815'),
	(377, 1, 0, -50242, 1817, 0, 0, 39, '1816'),
	(377, 1, 0, -50242, 1818, 0, 0, 39, '1817'),
	(377, 1, 0, -50242, 1819, 0, 0, 39, '1818'),
	(377, 1, 0, -50242, 1820, 0, 0, 39, '1819'),
	(377, 1, 0, -50242, 1821, 0, 0, 39, '1820'),
	(377, 1, 0, -50242, 1822, 0, 0, 39, '1821'),
	(377, 1, 0, -50242, 1823, 0, 0, 39, '1822'),
	(377, 1, 0, -50242, 1824, 0, 0, 39, '1823'),
	(377, 1, 0, -50242, 1825, 0, 0, 39, '1824'),
	(377, 1, 0, -50242, 1826, 0, 0, 39, '1825'),
	(377, 1, 0, -50242, 1827, 0, 0, 39, '1826'),
	(377, 1, 0, -50242, 1828, 0, 0, 39, '1827'),
	(377, 1, 0, -50242, 1829, 0, 0, 39, '1828'),
	(377, 1, 0, -50242, 1830, 0, 0, 39, '1829'),
	(377, 1, 0, -50242, 1831, 0, 0, 39, '1830'),
	(377, 1, 0, -50242, 1832, 0, 0, 39, '1831'),
	(377, 1, 0, -50242, 1833, 0, 0, 39, '1832'),
	(377, 1, 0, -50242, 1834, 0, 0, 39, '1833'),
	(377, 1, 0, -50242, 1835, 0, 0, 39, '1834'),
	(377, 1, 0, -50242, 1836, 0, 0, 39, '1835'),
	(377, 1, 0, -50242, 1837, 0, 0, 39, '1836'),
	(377, 1, 0, -50242, 1838, 0, 0, 39, '1837'),
	(377, 1, 0, -50242, 1839, 0, 0, 39, '1838'),
	(377, 1, 0, -50242, 1840, 0, 0, 39, '1839'),
	(377, 1, 0, -50242, 1841, 0, 0, 39, '1840'),
	(377, 1, 0, -50242, 1842, 0, 0, 39, '1841'),
	(377, 1, 0, -50242, 1843, 0, 0, 39, '1842'),
	(377, 1, 0, -50242, 1844, 0, 0, 39, '1843'),
	(377, 1, 0, -50242, 1845, 0, 0, 39, '1844'),
	(377, 1, 0, -50242, 1846, 0, 0, 39, '1845'),
	(377, 1, 0, -50242, 1847, 0, 0, 39, '1846'),
	(377, 1, 0, -50242, 1848, 0, 0, 39, '1847'),
	(377, 1, 0, -50242, 1849, 0, 0, 39, '1848'),
	(377, 1, 0, -50242, 1850, 0, 0, 39, '1849'),
	(377, 1, 0, -50242, 1851, 0, 0, 39, '1850'),
	(377, 1, 0, -50242, 1852, 0, 0, 39, '1851'),
	(377, 1, 0, -50242, 1853, 0, 0, 39, '1852'),
	(377, 1, 0, -50242, 1854, 0, 0, 39, '1853'),
	(377, 1, 0, -50242, 1855, 0, 0, 39, '1854'),
	(377, 1, 0, -50242, 1856, 0, 0, 39, '1855'),
	(377, 1, 0, -50242, 1857, 0, 0, 39, '1856'),
	(377, 1, 0, -50242, 1858, 0, 0, 39, '1857'),
	(377, 1, 0, -50242, 1859, 0, 0, 39, '1858'),
	(377, 1, 0, -50242, 1860, 0, 0, 39, '1859'),
	(377, 1, 0, -50242, 1861, 0, 0, 39, '1860'),
	(377, 1, 0, -50242, 1862, 0, 0, 39, '1861'),
	(377, 1, 0, -50242, 1863, 0, 0, 39, '1862'),
	(377, 1, 0, -50242, 1864, 0, 0, 39, '1863'),
	(377, 1, 0, -50242, 1865, 0, 0, 39, '1864'),
	(377, 1, 0, -50242, 1866, 0, 0, 39, '1865'),
	(377, 1, 0, -50242, 1867, 0, 0, 39, '1866'),
	(377, 1, 0, -50242, 1868, 0, 0, 39, '1867'),
	(377, 1, 0, -50242, 1869, 0, 0, 39, '1868'),
	(377, 1, 0, -50242, 1870, 0, 0, 39, '1869'),
	(377, 1, 0, -50242, 1871, 0, 0, 39, '1870'),
	(377, 1, 0, -50242, 1872, 0, 0, 39, '1871'),
	(377, 1, 0, -50242, 1873, 0, 0, 39, '1872'),
	(377, 1, 0, -50242, 1874, 0, 0, 39, '1873'),
	(377, 1, 0, -50242, 1875, 0, 0, 39, '1874'),
	(377, 1, 0, -50242, 1876, 0, 0, 39, '1875'),
	(377, 1, 0, -50242, 1877, 0, 0, 39, '1876'),
	(377, 1, 0, -50242, 1878, 0, 0, 39, '1877'),
	(377, 1, 0, -50242, 1879, 0, 0, 39, '1878'),
	(377, 1, 0, -50242, 1880, 0, 0, 39, '1879'),
	(377, 1, 0, -50242, 1881, 0, 0, 39, '1880'),
	(377, 1, 0, -50242, 1882, 0, 0, 39, '1881'),
	(377, 1, 0, -50242, 1883, 0, 0, 39, '1882'),
	(377, 1, 0, -50242, 1884, 0, 0, 39, '1883'),
	(377, 1, 0, -50242, 1885, 0, 0, 39, '1884'),
	(377, 1, 0, -50242, 1886, 0, 0, 39, '1885'),
	(377, 1, 0, -50242, 1887, 0, 0, 39, '1886'),
	(377, 1, 0, -50242, 1888, 0, 0, 39, '1887'),
	(377, 1, 0, -50242, 1889, 0, 0, 39, '1888'),
	(377, 1, 0, -50242, 1890, 0, 0, 39, '1889'),
	(377, 1, 0, -50242, 1891, 0, 0, 39, '1890'),
	(377, 1, 0, -50242, 1892, 0, 0, 39, '1891'),
	(377, 1, 0, -50242, 1893, 0, 0, 39, '1892'),
	(377, 1, 0, -50242, 1894, 0, 0, 39, '1893'),
	(377, 1, 0, -50242, 1895, 0, 0, 39, '1894'),
	(377, 1, 0, -50242, 1896, 0, 0, 39, '1895'),
	(377, 1, 0, -50242, 1897, 0, 0, 39, '1896'),
	(377, 1, 0, -50242, 1898, 0, 0, 39, '1897'),
	(377, 1, 0, -50242, 1899, 0, 0, 39, '1898'),
	(377, 1, 0, -50242, 1900, 0, 0, 39, '1899'),
	(377, 1, 0, -50242, 1901, 0, 0, 39, '1900'),
	(377, 1, 0, -50242, 1902, 0, 0, 39, '1901'),
	(377, 1, 0, -50242, 1903, 0, 0, 39, '1902'),
	(377, 1, 0, -50242, 1904, 0, 0, 39, '1903'),
	(377, 1, 0, -50242, 1905, 0, 0, 39, '1904'),
	(377, 1, 0, -50242, 1906, 0, 0, 39, '1905'),
	(377, 1, 0, -50242, 1907, 0, 0, 39, '1906'),
	(377, 1, 0, -50242, 1908, 0, 0, 39, '1907'),
	(377, 1, 0, -50242, 1909, 0, 0, 39, '1908'),
	(377, 1, 0, -50242, 1910, 0, 0, 39, '1909'),
	(377, 1, 0, -50242, 1911, 0, 0, 39, '1910'),
	(377, 1, 0, -50242, 1912, 0, 0, 39, '1911'),
	(377, 1, 0, -50242, 1913, 0, 0, 39, '1912'),
	(377, 1, 0, -50242, 1914, 0, 0, 39, '1913'),
	(377, 1, 0, -50242, 1915, 0, 0, 39, '1914'),
	(377, 1, 0, -50242, 1916, 0, 0, 39, '1915'),
	(377, 1, 0, -50242, 1917, 0, 0, 39, '1916'),
	(377, 1, 0, -50242, 1918, 0, 0, 39, '1917'),
	(377, 1, 0, -50242, 1919, 0, 0, 39, '1918'),
	(377, 1, 0, -50242, 1920, 0, 0, 39, '1919'),
	(377, 1, 0, -50242, 1921, 0, 0, 39, '1920'),
	(377, 1, 0, -50242, 1922, 0, 0, 39, '1921'),
	(377, 1, 0, -50242, 1923, 0, 0, 39, '1922'),
	(377, 1, 0, -50242, 1924, 0, 0, 39, '1923'),
	(377, 1, 0, -50242, 1925, 0, 0, 39, '1924'),
	(377, 1, 0, -50242, 1926, 0, 0, 39, '1925'),
	(377, 1, 0, -50242, 1927, 0, 0, 39, '1926'),
	(377, 1, 0, -50242, 1928, 0, 0, 39, '1927'),
	(377, 1, 0, -50242, 1929, 0, 0, 39, '1928'),
	(377, 1, 0, -50242, 1930, 0, 0, 39, '1929'),
	(377, 1, 0, -50242, 1931, 0, 0, 39, '1930'),
	(377, 1, 0, -50242, 1932, 0, 0, 39, '1931'),
	(377, 1, 0, -50242, 1933, 0, 0, 39, '1932'),
	(377, 1, 0, -50242, 1934, 0, 0, 39, '1933'),
	(377, 1, 0, -50242, 1935, 0, 0, 39, '1934'),
	(377, 1, 0, -50242, 1936, 0, 0, 39, '1935'),
	(377, 1, 0, -50242, 1937, 0, 0, 39, '1936'),
	(377, 1, 0, -50242, 1938, 0, 0, 39, '1937'),
	(377, 1, 0, -50242, 1939, 0, 0, 39, '1938'),
	(377, 1, 0, -50242, 1940, 0, 0, 39, '1939'),
	(377, 1, 0, -50242, 1941, 0, 0, 39, '1940'),
	(377, 1, 0, -50242, 1942, 0, 0, 39, '1941'),
	(377, 1, 0, -50242, 1943, 0, 0, 39, '1942'),
	(377, 1, 0, -50242, 1944, 0, 0, 39, '1943'),
	(377, 1, 0, -50242, 1945, 0, 0, 39, '1944'),
	(377, 1, 0, -50242, 1946, 0, 0, 39, '1945'),
	(377, 1, 0, -50242, 1947, 0, 0, 39, '1946'),
	(377, 1, 0, -50242, 1948, 0, 0, 39, '1947'),
	(377, 1, 0, -50242, 1949, 0, 0, 39, '1948'),
	(377, 1, 0, -50242, 1950, 0, 0, 39, '1949'),
	(377, 1, 0, -50242, 1951, 0, 0, 39, '1950'),
	(377, 1, 0, -50242, 1952, 0, 0, 39, '1951'),
	(377, 1, 0, -50242, 1953, 0, 0, 39, '1952'),
	(377, 1, 0, -50242, 1954, 0, 0, 39, '1953'),
	(377, 1, 0, -50242, 1955, 0, 0, 39, '1954'),
	(377, 1, 0, -50242, 1956, 0, 0, 39, '1955'),
	(377, 1, 0, -50242, 1957, 0, 0, 39, '1956'),
	(377, 1, 0, -50242, 1958, 0, 0, 39, '1957'),
	(377, 1, 0, -50242, 1959, 0, 0, 39, '1958'),
	(377, 1, 0, -50242, 1960, 0, 0, 39, '1959'),
	(377, 1, 0, -50242, 1961, 0, 0, 39, '1960'),
	(377, 1, 0, -50242, 1962, 0, 0, 39, '1961'),
	(377, 1, 0, -50242, 1963, 0, 0, 39, '1962'),
	(377, 1, 0, -50242, 1964, 0, 0, 39, '1963'),
	(377, 1, 0, -50242, 1965, 0, 0, 39, '1964'),
	(377, 1, 0, -50242, 1966, 0, 0, 39, '1965'),
	(377, 1, 0, -50242, 1967, 0, 0, 39, '1966'),
	(377, 1, 0, -50242, 1968, 0, 0, 39, '1967'),
	(377, 1, 0, -50242, 1969, 0, 0, 39, '1968'),
	(377, 1, 0, -50242, 1970, 0, 0, 39, '1969'),
	(377, 1, 0, -50242, 1971, 0, 0, 39, '1970'),
	(377, 1, 0, -50242, 1972, 0, 0, 39, '1971'),
	(377, 1, 0, -50242, 1973, 0, 0, 39, '1972'),
	(377, 1, 0, -50242, 1974, 0, 0, 39, '1973'),
	(377, 1, 0, -50242, 1975, 0, 0, 39, '1974'),
	(377, 1, 0, -50242, 1976, 0, 0, 39, '1975'),
	(377, 1, 0, -50242, 1977, 0, 0, 39, '1976'),
	(377, 1, 0, -50242, 1978, 0, 0, 39, '1977'),
	(377, 1, 0, -50242, 1979, 0, 0, 39, '1978'),
	(377, 1, 0, -50242, 1980, 0, 0, 39, '1979'),
	(377, 1, 0, -50242, 1981, 0, 0, 39, '1980'),
	(377, 1, 0, -50242, 1982, 0, 0, 39, '1981'),
	(377, 1, 0, -50242, 1983, 0, 0, 39, '1982'),
	(377, 1, 0, -50242, 1984, 0, 0, 39, '1983'),
	(377, 1, 0, -50242, 1985, 0, 0, 39, '1984'),
	(377, 1, 0, -50242, 1986, 0, 0, 39, '1985'),
	(377, 1, 0, -50242, 1987, 0, 0, 39, '1986'),
	(377, 1, 0, -50242, 1988, 0, 0, 39, '1987'),
	(377, 1, 0, -50242, 1989, 0, 0, 39, '1988'),
	(377, 1, 0, -50242, 1990, 0, 0, 39, '1989'),
	(377, 1, 0, -50242, 1991, 0, 0, 39, '1990'),
	(377, 1, 0, -50242, 1992, 0, 0, 39, '1991'),
	(377, 1, 0, -50242, 1993, 0, 0, 39, '1992'),
	(377, 1, 0, -50242, 1994, 0, 0, 39, '1993'),
	(377, 1, 0, -50242, 1995, 0, 0, 39, '1994'),
	(377, 1, 0, -50242, 1996, 0, 0, 39, '1995'),
	(377, 1, 0, -50242, 1997, 0, 0, 39, '1996'),
	(377, 1, 0, -50242, 1998, 0, 0, 39, '1997'),
	(377, 1, 0, -50242, 1999, 0, 0, 39, '1998'),
	(377, 1, 0, -50242, 2000, 0, 0, 39, '1999'),
	(377, 1, 0, -50242, 2001, 0, 0, 39, '2000'),
	(377, 1, 0, -50242, 2002, 0, 0, 39, '2001'),
	(377, 1, 0, -50242, 2003, 0, 0, 39, '2002'),
	(377, 1, 0, -50242, 2004, 0, 0, 39, '2003'),
	(377, 1, 0, -50242, 2005, 0, 0, 39, '2004'),
	(377, 1, 0, -50242, 2006, 0, 0, 39, '2005'),
	(377, 1, 0, -50242, 2007, 0, 0, 39, '2006'),
	(377, 1, 0, -50242, 2008, 0, 0, 39, '2007'),
	(377, 1, 0, -50242, 2009, 0, 0, 39, '2008'),
	(377, 1, 0, -50242, 2010, 0, 0, 39, '2009'),
	(377, 1, 0, -50242, 2011, 0, 0, 39, '2010'),
	(377, 1, 0, -50242, 2012, 0, 0, 39, '2011'),
	(377, 1, 0, -50242, 2013, 0, 0, 39, '2012'),
	(377, 1, 0, -50242, 2014, 0, 0, 39, '2013'),
	(377, 1, 0, -50242, 2015, 0, 0, 39, '2014'),
	(377, 1, 0, -50242, 2016, 0, 0, 39, '2015'),
	(377, 1, 0, -50242, 2017, 0, 0, 39, '2016'),
	(377, 1, 0, -50242, 2018, 0, 0, 39, '2017'),
	(377, 1, 0, -50242, 2019, 0, 0, 39, '2018'),
	(377, 1, 0, -50242, 2020, 0, 0, 39, '2019'),
	(377, 1, 0, -50242, 2021, 0, 0, 39, '2020'),
	(377, 1, 0, -50242, 2022, 0, 0, 39, '2021'),
	(377, 1, 0, -50242, 2023, 0, 0, 39, '2022'),
	(377, 1, 0, -50242, 2024, 0, 0, 39, '2023'),
	(377, 1, 0, -50242, 2025, 0, 0, 39, '2024'),
	(377, 1, 0, -50242, 2026, 0, 0, 39, '2025'),
	(377, 1, 0, -50242, 2027, 0, 0, 39, '2026'),
	(377, 1, 0, -50242, 2028, 0, 0, 39, '2027'),
	(377, 1, 0, -50242, 2029, 0, 0, 39, '2028'),
	(377, 1, 0, -50242, 2030, 0, 0, 39, '2029'),
	(377, 1, 0, -50242, 2031, 0, 0, 39, '2030'),
	(377, 1, 0, -50242, 2032, 0, 0, 39, '2031'),
	(377, 1, 0, -50242, 2033, 0, 0, 39, '2032'),
	(377, 1, 0, -50242, 2034, 0, 0, 39, '2033'),
	(377, 1, 0, -50242, 2035, 0, 0, 39, '2034'),
	(377, 1, 0, -50242, 2036, 0, 0, 39, '2035'),
	(377, 1, 0, -50242, 2037, 0, 0, 39, '2036'),
	(377, 1, 0, -50242, 2038, 0, 0, 39, '2037'),
	(377, 1, 0, -50242, 2039, 0, 0, 39, '2038'),
	(377, 1, 0, -50242, 2040, 0, 0, 39, '2039'),
	(377, 1, 0, -50242, 2041, 0, 0, 39, '2040'),
	(377, 1, 0, -50242, 2042, 0, 0, 39, '2041'),
	(377, 1, 0, -50242, 2043, 0, 0, 39, '2042'),
	(377, 1, 0, -50242, 2044, 0, 0, 39, '2043'),
	(377, 1, 0, -50242, 2045, 0, 0, 39, '2044'),
	(377, 1, 0, -50242, 2046, 0, 0, 39, '2045'),
	(377, 1, 0, -50242, 2047, 0, 0, 39, '2046'),
	(377, 1, 0, -50242, 2048, 0, 0, 39, '2047'),
	(377, 1, 0, -50242, 2049, 0, 0, 39, '2048'),
	(377, 1, 0, -50242, 2050, 0, 0, 39, '2049'),
	(377, 1, 0, -50242, 2051, 0, 0, 39, '2050'),
	(377, 1, 0, -50242, 2052, 0, 0, 39, '2051'),
	(377, 1, 0, -50242, 2053, 0, 0, 39, '2052'),
	(377, 1, 0, -50242, 2054, 0, 0, 39, '2053'),
	(377, 1, 0, -50242, 2055, 0, 0, 39, '2054'),
	(377, 1, 0, -50242, 2056, 0, 0, 39, '2055'),
	(377, 1, 0, -50242, 2057, 0, 0, 39, '2056'),
	(377, 1, 0, -50242, 2058, 0, 0, 39, '2057'),
	(377, 1, 0, -50242, 2059, 0, 0, 39, '2058'),
	(377, 1, 0, -50242, 2060, 0, 0, 39, '2059'),
	(377, 1, 0, -50242, 2061, 0, 0, 39, '2060'),
	(377, 1, 0, -50242, 2062, 0, 0, 39, '2061'),
	(377, 1, 0, -50242, 2063, 0, 0, 39, '2062'),
	(377, 1, 0, -50242, 2064, 0, 0, 39, '2063'),
	(377, 1, 0, -50242, 2065, 0, 0, 39, '2064'),
	(377, 1, 0, -50242, 2066, 0, 0, 39, '2065'),
	(377, 1, 0, -50242, 2067, 0, 0, 39, '2066'),
	(377, 1, 0, -50242, 2068, 0, 0, 39, '2067'),
	(377, 1, 0, -50242, 2069, 0, 0, 39, '2068'),
	(377, 1, 0, -50242, 2070, 0, 0, 39, '2069'),
	(377, 1, 0, -50242, 2071, 0, 0, 39, '2070'),
	(377, 1, 0, -50242, 2072, 0, 0, 39, '2071'),
	(377, 1, 0, -50242, 2073, 0, 0, 39, '2072'),
	(377, 1, 0, -50242, 2074, 0, 0, 39, '2073'),
	(377, 1, 0, -50242, 2075, 0, 0, 39, '2074'),
	(377, 1, 0, -50242, 2076, 0, 0, 39, '2075'),
	(377, 1, 0, -50242, 2077, 0, 0, 39, '2076'),
	(377, 1, 0, -50242, 2078, 0, 0, 39, '2077'),
	(377, 1, 0, -50242, 2079, 0, 0, 39, '2078'),
	(377, 1, 0, -50242, 2080, 0, 0, 39, '2079'),
	(377, 1, 0, -50242, 2081, 0, 0, 39, '2080'),
	(377, 1, 0, -50242, 2082, 0, 0, 39, '2081'),
	(377, 1, 0, -50242, 2083, 0, 0, 39, '2082'),
	(377, 1, 0, -50242, 2084, 0, 0, 39, '2083'),
	(377, 1, 0, -50242, 2085, 0, 0, 39, '2084'),
	(377, 1, 0, -50242, 2086, 0, 0, 39, '2085'),
	(377, 1, 0, -50242, 2087, 0, 0, 39, '2086'),
	(377, 1, 0, -50242, 2088, 0, 0, 39, '2087'),
	(377, 1, 0, -50242, 2089, 0, 0, 39, '2088'),
	(377, 1, 0, -50242, 2090, 0, 0, 39, '2089'),
	(377, 1, 0, -50242, 2091, 0, 0, 39, '2090'),
	(377, 1, 0, -50242, 2092, 0, 0, 39, '2091'),
	(377, 1, 0, -50242, 2093, 0, 0, 39, '2092'),
	(377, 1, 0, -50242, 2094, 0, 0, 39, '2093'),
	(377, 1, 0, -50242, 2095, 0, 0, 39, '2094'),
	(377, 1, 0, -50242, 2096, 0, 0, 39, '2095'),
	(377, 1, 0, -50242, 2097, 0, 0, 39, '2096'),
	(377, 1, 0, -50242, 2098, 0, 0, 39, '2097'),
	(377, 1, 0, -50242, 2099, 0, 0, 39, '2098'),
	(377, 1, 0, -50242, 2100, 0, 0, 39, '2099'),
	(377, 1, 0, -50242, 2101, 0, 0, 39, '2100'),
	(377, 1, 0, -50242, 2102, 0, 0, 39, '2101'),
	(377, 1, 0, -50242, 2103, 0, 0, 39, '2102'),
	(377, 1, 0, -50242, 2104, 0, 0, 39, '2103'),
	(377, 1, 0, -50242, 2105, 0, 0, 39, '2104'),
	(377, 1, 0, -50242, 2106, 0, 0, 39, '2105'),
	(377, 1, 0, -50242, 2107, 0, 0, 39, '2106'),
	(377, 1, 0, -50242, 2108, 0, 0, 39, '2107'),
	(377, 1, 0, -50242, 2109, 0, 0, 39, '2108'),
	(377, 1, 0, -50242, 2110, 0, 0, 39, '2109'),
	(377, 1, 0, -50242, 2111, 0, 0, 39, '2110'),
	(377, 1, 0, -50242, 2112, 0, 0, 39, '2111'),
	(377, 1, 0, -50242, 2113, 0, 0, 39, '2112'),
	(377, 1, 0, -50242, 2114, 0, 0, 39, '2113'),
	(377, 1, 0, -50242, 2115, 0, 0, 39, '2114'),
	(377, 1, 0, -50242, 2116, 0, 0, 39, '2115'),
	(377, 1, 0, -50242, 2117, 0, 0, 39, '2116'),
	(377, 1, 0, -50242, 2118, 0, 0, 39, '2117'),
	(377, 1, 0, -50242, 2119, 0, 0, 39, '2118'),
	(377, 1, 0, -50242, 2120, 0, 0, 39, '2119'),
	(377, 1, 0, -50242, 2121, 0, 0, 39, '2120'),
	(377, 1, 0, -50242, 2122, 0, 0, 39, '2121'),
	(377, 1, 0, -50242, 2123, 0, 0, 39, '2122'),
	(377, 1, 0, -50242, 2124, 0, 0, 39, '2123'),
	(377, 1, 0, -50242, 2125, 0, 0, 39, '2124'),
	(377, 1, 0, -50242, 2126, 0, 0, 39, '2125'),
	(377, 1, 0, -50242, 2127, 0, 0, 39, '2126'),
	(377, 1, 0, -50242, 2128, 0, 0, 39, '2127'),
	(377, 1, 0, -50242, 2129, 0, 0, 39, '2128'),
	(377, 1, 0, -50242, 2130, 0, 0, 39, '2129'),
	(377, 1, 0, -50242, 2131, 0, 0, 39, '2130'),
	(377, 1, 0, -50242, 2132, 0, 0, 39, '2131'),
	(377, 1, 0, -50242, 2133, 0, 0, 39, '2132'),
	(377, 1, 0, -50242, 2134, 0, 0, 39, '2133'),
	(377, 1, 0, -50242, 2135, 0, 0, 39, '2134'),
	(377, 1, 0, -50242, 2136, 0, 0, 39, '2135'),
	(377, 1, 0, -50242, 2137, 0, 0, 39, '2136'),
	(377, 1, 0, -50242, 2138, 0, 0, 39, '2137'),
	(377, 1, 0, -50242, 2139, 0, 0, 39, '2138'),
	(377, 1, 0, -50242, 2140, 0, 0, 39, '2139'),
	(377, 1, 0, -50242, 2141, 0, 0, 39, '2140'),
	(377, 1, 0, -50242, 2142, 0, 0, 39, '2141'),
	(377, 1, 0, -50242, 2143, 0, 0, 39, '2142'),
	(377, 1, 0, -50242, 2144, 0, 0, 39, '2143'),
	(377, 1, 0, -50242, 2145, 0, 0, 39, '2144'),
	(377, 1, 0, -50242, 2146, 0, 0, 39, '2145'),
	(377, 1, 0, -50242, 2147, 0, 0, 39, '2146'),
	(377, 1, 0, -50242, 2148, 0, 0, 39, '2147'),
	(377, 1, 0, -50242, 2149, 0, 0, 39, '2148'),
	(377, 1, 0, -50242, 2150, 0, 0, 39, '2149'),
	(377, 1, 0, -50242, 2151, 0, 0, 39, '2150'),
	(377, 1, 0, -50242, 2152, 0, 0, 39, '2151'),
	(377, 1, 0, -50242, 2153, 0, 0, 39, '2152'),
	(377, 1, 0, -50242, 2154, 0, 0, 39, '2153'),
	(377, 1, 0, -50242, 2155, 0, 0, 39, '2154'),
	(377, 1, 0, -50242, 2156, 0, 0, 39, '2155'),
	(377, 1, 0, -50242, 2157, 0, 0, 39, '2156'),
	(377, 1, 0, -50242, 2158, 0, 0, 39, '2157'),
	(377, 1, 0, -50242, 2159, 0, 0, 39, '2158'),
	(377, 1, 0, -50242, 2160, 0, 0, 39, '2159'),
	(377, 1, 0, -50242, 2161, 0, 0, 39, '2160'),
	(377, 1, 0, -50242, 2162, 0, 0, 39, '2161'),
	(377, 1, 0, -50242, 2163, 0, 0, 39, '2162'),
	(377, 1, 0, -50242, 2164, 0, 0, 39, '2163'),
	(377, 1, 0, -50242, 2165, 0, 0, 39, '2164'),
	(377, 1, 0, -50242, 2166, 0, 0, 39, '2165'),
	(377, 1, 0, -50242, 2167, 0, 0, 39, '2166'),
	(377, 1, 0, -50242, 2168, 0, 0, 39, '2167'),
	(377, 1, 0, -50242, 2169, 0, 0, 39, '2168'),
	(377, 1, 0, -50242, 2170, 0, 0, 39, '2169'),
	(377, 1, 0, -50242, 2171, 0, 0, 39, '2170'),
	(377, 1, 0, -50242, 2172, 0, 0, 39, '2171'),
	(377, 1, 0, -50242, 2173, 0, 0, 39, '2172'),
	(377, 1, 0, -50242, 2174, 0, 0, 39, '2173'),
	(377, 1, 0, -50242, 2175, 0, 0, 39, '2174'),
	(377, 1, 0, -50242, 2176, 0, 0, 39, '2175'),
	(377, 1, 0, -50242, 2177, 0, 0, 39, '2176'),
	(377, 1, 0, -50242, 2178, 0, 0, 39, '2177'),
	(377, 1, 0, -50242, 2179, 0, 0, 39, '2178'),
	(377, 1, 0, -50242, 2180, 0, 0, 39, '2179'),
	(377, 1, 0, -50242, 2181, 0, 0, 39, '2180'),
	(377, 1, 0, -50242, 2182, 0, 0, 39, '2181'),
	(377, 1, 0, -50242, 2183, 0, 0, 39, '2182'),
	(377, 1, 0, -50242, 2184, 0, 0, 39, '2183'),
	(377, 1, 0, -50242, 2185, 0, 0, 39, '2184'),
	(377, 1, 0, -50242, 2186, 0, 0, 39, '2185'),
	(377, 1, 0, -50242, 2187, 0, 0, 39, '2186'),
	(377, 1, 0, -50242, 2188, 0, 0, 39, '2187'),
	(377, 1, 0, -50242, 2189, 0, 0, 39, '2188'),
	(377, 1, 0, -50242, 2190, 0, 0, 39, '2189'),
	(377, 1, 0, -50242, 2191, 0, 0, 39, '2190'),
	(377, 1, 0, -50242, 2192, 0, 0, 39, '2191'),
	(377, 1, 0, -50242, 2193, 0, 0, 39, '2192'),
	(377, 1, 0, -50242, 2194, 0, 0, 39, '2193'),
	(377, 1, 0, -50242, 2195, 0, 0, 39, '2194'),
	(377, 1, 0, -50242, 2196, 0, 0, 39, '2195'),
	(377, 1, 0, -50242, 2197, 0, 0, 39, '2196'),
	(377, 1, 0, -50242, 2198, 0, 0, 39, '2197'),
	(377, 1, 0, -50242, 2199, 0, 0, 39, '2198'),
	(377, 1, 0, -50242, 2200, 0, 0, 39, '2199'),
	(377, 1, 0, -50242, 2201, 0, 0, 39, '2200'),
	(377, 1, 0, -50242, 2202, 0, 0, 39, '2201'),
	(377, 1, 0, -50242, 2203, 0, 0, 39, '2202'),
	(377, 1, 0, -50242, 2204, 0, 0, 39, '2203'),
	(377, 1, 0, -50242, 2205, 0, 0, 39, '2204'),
	(377, 1, 0, -50242, 2206, 0, 0, 39, '2205'),
	(377, 1, 0, -50242, 2207, 0, 0, 39, '2206'),
	(377, 1, 0, -50242, 2208, 0, 0, 39, '2207'),
	(377, 1, 0, -50242, 2209, 0, 0, 39, '2208'),
	(377, 1, 0, -50242, 2210, 0, 0, 39, '2209'),
	(377, 1, 0, -50242, 2211, 0, 0, 39, '2210'),
	(377, 1, 0, -50242, 2212, 0, 0, 39, '2211'),
	(377, 1, 0, -50242, 2213, 0, 0, 39, '2212'),
	(377, 1, 0, -50242, 2214, 0, 0, 39, '2213'),
	(377, 1, 0, -50242, 2215, 0, 0, 39, '2214'),
	(377, 1, 0, -50242, 2216, 0, 0, 39, '2215'),
	(377, 1, 0, -50242, 2217, 0, 0, 39, '2216'),
	(377, 1, 0, -50242, 2218, 0, 0, 39, '2217'),
	(377, 1, 0, -50242, 2219, 0, 0, 39, '2218'),
	(377, 1, 0, -50242, 2220, 0, 0, 39, '2219'),
	(377, 1, 0, -50242, 2221, 0, 0, 39, '2220'),
	(377, 1, 0, -50242, 2222, 0, 0, 39, '2221'),
	(377, 1, 0, -50242, 2223, 0, 0, 39, '2222'),
	(377, 1, 0, -50242, 2224, 0, 0, 39, '2223'),
	(377, 1, 0, -50242, 2225, 0, 0, 39, '2224'),
	(377, 1, 0, -50242, 2226, 0, 0, 39, '2225'),
	(377, 1, 0, -50242, 2227, 0, 0, 39, '2226'),
	(377, 1, 0, -50242, 2228, 0, 0, 39, '2227'),
	(377, 1, 0, -50242, 2229, 0, 0, 39, '2228'),
	(377, 1, 0, -50242, 2230, 0, 0, 39, '2229'),
	(377, 1, 0, -50242, 2231, 0, 0, 39, '2230'),
	(377, 1, 0, -50242, 2232, 0, 0, 39, '2231'),
	(377, 1, 0, -50242, 2233, 0, 0, 39, '2232'),
	(377, 1, 0, -50242, 2234, 0, 0, 39, '2233'),
	(377, 1, 0, -50242, 2235, 0, 0, 39, '2234'),
	(377, 1, 0, -50242, 2236, 0, 0, 39, '2235'),
	(377, 1, 0, -50242, 2237, 0, 0, 39, '2236'),
	(377, 1, 0, -50242, 2238, 0, 0, 39, '2237'),
	(377, 1, 0, -50242, 2239, 0, 0, 39, '2238'),
	(377, 1, 0, -50242, 2240, 0, 0, 39, '2239'),
	(377, 1, 0, -50242, 2241, 0, 0, 39, '2240'),
	(377, 1, 0, -50242, 2242, 0, 0, 39, '2241'),
	(377, 1, 0, -50242, 2243, 0, 0, 39, '2242'),
	(377, 1, 0, -50242, 2244, 0, 0, 39, '2243'),
	(377, 1, 0, -50242, 2245, 0, 0, 39, '2244'),
	(377, 1, 0, -50242, 2246, 0, 0, 39, '2245'),
	(377, 1, 0, -50242, 2247, 0, 0, 39, '2246'),
	(377, 1, 0, -50242, 2248, 0, 0, 39, '2247'),
	(377, 1, 0, -50242, 2249, 0, 0, 39, '2248'),
	(377, 1, 0, -50242, 2250, 0, 0, 39, '2249'),
	(377, 1, 0, -50242, 2251, 0, 0, 39, '2250'),
	(377, 1, 0, -50242, 2252, 0, 0, 39, '2251'),
	(377, 1, 0, -50242, 2253, 0, 0, 39, '2252'),
	(377, 1, 0, -50242, 2254, 0, 0, 39, '2253'),
	(377, 1, 0, -50242, 2255, 0, 0, 39, '2254'),
	(377, 1, 0, -50242, 2256, 0, 0, 39, '2255'),
	(377, 1, 0, -50242, 2257, 0, 0, 39, '2256'),
	(377, 1, 0, -50242, 2258, 0, 0, 39, '2257'),
	(377, 1, 0, -50242, 2259, 0, 0, 39, '2258'),
	(377, 1, 0, -50242, 2260, 0, 0, 39, '2259'),
	(377, 1, 0, -50242, 2261, 0, 0, 39, '2260'),
	(377, 1, 0, -50242, 2262, 0, 0, 39, '2261'),
	(377, 1, 0, -50242, 2263, 0, 0, 39, '2262'),
	(377, 1, 0, -50242, 2264, 0, 0, 39, '2263'),
	(377, 1, 0, -50242, 2265, 0, 0, 39, '2264'),
	(377, 1, 0, -50242, 2266, 0, 0, 39, '2265'),
	(377, 1, 0, -50242, 2267, 0, 0, 39, '2266'),
	(377, 1, 0, -50242, 2268, 0, 0, 39, '2267'),
	(377, 1, 0, -50242, 2269, 0, 0, 39, '2268'),
	(377, 1, 0, -50242, 2270, 0, 0, 39, '2269'),
	(377, 1, 0, -50242, 2271, 0, 0, 39, '2270'),
	(377, 1, 0, -50242, 2272, 0, 0, 39, '2271'),
	(377, 1, 0, -50242, 2273, 0, 0, 39, '2272'),
	(377, 1, 0, -50242, 2274, 0, 0, 39, '2273'),
	(377, 1, 0, -50242, 2275, 0, 0, 39, '2274'),
	(377, 1, 0, -50242, 2276, 0, 0, 39, '2275'),
	(377, 1, 0, -50242, 2277, 0, 0, 39, '2276'),
	(377, 1, 0, -50242, 2278, 0, 0, 39, '2277'),
	(377, 1, 0, -50242, 2279, 0, 0, 39, '2278'),
	(377, 1, 0, -50242, 2280, 0, 0, 39, '2279'),
	(377, 1, 0, -50242, 2281, 0, 0, 39, '2280'),
	(377, 1, 0, -50242, 2282, 0, 0, 39, '2281'),
	(377, 1, 0, -50242, 2283, 0, 0, 39, '2282'),
	(377, 1, 0, -50242, 2284, 0, 0, 39, '2283'),
	(377, 1, 0, -50242, 2285, 0, 0, 39, '2284'),
	(377, 1, 0, -50242, 2286, 0, 0, 39, '2285'),
	(377, 1, 0, -50242, 2287, 0, 0, 39, '2286'),
	(377, 1, 0, -50242, 2288, 0, 0, 39, '2287'),
	(377, 1, 0, -50242, 2289, 0, 0, 39, '2288'),
	(377, 1, 0, -50242, 2290, 0, 0, 39, '2289'),
	(377, 1, 0, -50242, 2291, 0, 0, 39, '2290'),
	(377, 1, 0, -50242, 2292, 0, 0, 39, '2291'),
	(377, 1, 0, -50242, 2293, 0, 0, 39, '2292'),
	(377, 1, 0, -50242, 2294, 0, 0, 39, '2293'),
	(377, 1, 0, -50242, 2295, 0, 0, 39, '2294'),
	(377, 1, 0, -50242, 2296, 0, 0, 39, '2295'),
	(377, 1, 0, -50242, 2297, 0, 0, 39, '2296'),
	(377, 1, 0, -50242, 2298, 0, 0, 39, '2297'),
	(377, 1, 0, -50242, 2299, 0, 0, 39, '2298'),
	(377, 1, 0, -50242, 2300, 0, 0, 39, '2299'),
	(377, 1, 0, -50242, 2301, 0, 0, 39, '2300'),
	(377, 1, 0, -50242, 2302, 0, 0, 39, '2301'),
	(377, 1, 0, -50242, 2303, 0, 0, 39, '2302'),
	(377, 1, 0, -50242, 2304, 0, 0, 39, '2303'),
	(377, 1, 0, -50242, 2305, 0, 0, 39, '2304'),
	(377, 1, 0, -50242, 2306, 0, 0, 39, '2305'),
	(377, 1, 0, -50242, 2307, 0, 0, 39, '2306'),
	(377, 1, 0, -50242, 2308, 0, 0, 39, '2307'),
	(377, 1, 0, -50242, 2309, 0, 0, 39, '2308'),
	(377, 1, 0, -50242, 2310, 0, 0, 39, '2309'),
	(377, 1, 0, -50242, 2311, 0, 0, 39, '2310'),
	(377, 1, 0, -50242, 2312, 0, 0, 39, '2311'),
	(377, 1, 0, -50242, 2313, 0, 0, 39, '2312'),
	(377, 1, 0, -50242, 2314, 0, 0, 39, '2313'),
	(377, 1, 0, -50242, 2315, 0, 0, 39, '2314'),
	(377, 1, 0, -50242, 2316, 0, 0, 39, '2315'),
	(377, 1, 0, -50242, 2317, 0, 0, 39, '2316'),
	(377, 1, 0, -50242, 2318, 0, 0, 39, '2317'),
	(377, 1, 0, -50242, 2319, 0, 0, 39, '2318'),
	(377, 1, 0, -50242, 2320, 0, 0, 39, '2319'),
	(377, 1, 0, -50242, 2321, 0, 0, 39, '2320'),
	(377, 1, 0, -50242, 2322, 0, 0, 39, '2321'),
	(377, 1, 0, -50242, 2323, 0, 0, 39, '2322'),
	(377, 1, 0, -50242, 2324, 0, 0, 39, '2323'),
	(377, 1, 0, -50242, 2325, 0, 0, 39, '2324'),
	(377, 1, 0, -50242, 2326, 0, 0, 39, '2325'),
	(377, 1, 0, -50242, 2327, 0, 0, 39, '2326'),
	(377, 1, 0, -50242, 2328, 0, 0, 39, '2327'),
	(377, 1, 0, -50242, 2329, 0, 0, 39, '2328'),
	(377, 1, 0, -50242, 2330, 0, 0, 39, '2329'),
	(377, 1, 0, -50242, 2331, 0, 0, 39, '2330'),
	(377, 1, 0, -50242, 2332, 0, 0, 39, '2331'),
	(377, 1, 0, -50242, 2333, 0, 0, 39, '2332'),
	(377, 1, 0, -50242, 2334, 0, 0, 39, '2333'),
	(377, 1, 0, -50242, 2335, 0, 0, 39, '2334'),
	(377, 1, 0, -50242, 2336, 0, 0, 39, '2335'),
	(377, 1, 0, -50242, 2337, 0, 0, 39, '2336'),
	(377, 1, 0, -50242, 2338, 0, 0, 39, '2337'),
	(377, 1, 0, -50242, 2339, 0, 0, 39, '2338'),
	(377, 1, 0, -50242, 2340, 0, 0, 39, '2339'),
	(377, 1, 0, -50242, 2341, 0, 0, 39, '2340'),
	(377, 1, 0, -50242, 2342, 0, 0, 39, '2341'),
	(377, 1, 0, -50242, 2343, 0, 0, 39, '2342'),
	(377, 1, 0, -50242, 2344, 0, 0, 39, '2343'),
	(377, 1, 0, -50242, 2345, 0, 0, 39, '2344'),
	(377, 1, 0, -50242, 2346, 0, 0, 39, '2345'),
	(377, 1, 0, -50242, 2347, 0, 0, 39, '2346'),
	(377, 1, 0, -50242, 2348, 0, 0, 39, '2347'),
	(377, 1, 0, -50242, 2349, 0, 0, 39, '2348'),
	(377, 1, 0, -50242, 2350, 0, 0, 39, '2349'),
	(377, 1, 0, -50242, 2351, 0, 0, 39, '2350'),
	(377, 1, 0, -50242, 2352, 0, 0, 39, '2351'),
	(377, 1, 0, -50242, 2353, 0, 0, 39, '2352'),
	(377, 1, 0, -50242, 2354, 0, 0, 39, '2353'),
	(377, 1, 0, -50242, 2355, 0, 0, 39, '2354'),
	(377, 1, 0, -50242, 2356, 0, 0, 39, '2355'),
	(377, 1, 0, -50242, 2357, 0, 0, 39, '2356'),
	(377, 1, 0, -50242, 2358, 0, 0, 39, '2357'),
	(377, 1, 0, -50242, 2359, 0, 0, 39, '2358'),
	(377, 1, 0, -50242, 2360, 0, 0, 39, '2359'),
	(377, 1, 0, -50242, 2361, 0, 0, 39, '2360'),
	(377, 1, 0, -50242, 2362, 0, 0, 39, '2361'),
	(377, 1, 0, -50242, 2363, 0, 0, 39, '2362'),
	(377, 1, 0, -50242, 2364, 0, 0, 39, '2363'),
	(377, 1, 0, -50242, 2365, 0, 0, 39, '2364'),
	(377, 1, 0, -50242, 2366, 0, 0, 39, '2365'),
	(377, 1, 0, -50242, 2367, 0, 0, 39, '2366'),
	(377, 1, 0, -50242, 2368, 0, 0, 39, '2367'),
	(377, 1, 0, -50242, 2369, 0, 0, 39, '2368'),
	(377, 1, 0, -50242, 2370, 0, 0, 39, '2369'),
	(377, 1, 0, -50242, 2371, 0, 0, 39, '2370'),
	(377, 1, 0, -50242, 2372, 0, 0, 39, '2371'),
	(377, 1, 0, -50242, 2373, 0, 0, 39, '2372'),
	(377, 1, 0, -50242, 2374, 0, 0, 39, '2373'),
	(377, 1, 0, -50242, 2375, 0, 0, 39, '2374'),
	(377, 1, 0, -50242, 2376, 0, 0, 39, '2375'),
	(377, 1, 0, -50242, 2377, 0, 0, 39, '2376'),
	(377, 1, 0, -50242, 2378, 0, 0, 39, '2377'),
	(377, 1, 0, -50242, 2379, 0, 0, 39, '2378'),
	(377, 1, 0, -50242, 2380, 0, 0, 39, '2379'),
	(377, 1, 0, -50242, 2381, 0, 0, 39, '2380'),
	(377, 1, 0, -50242, 2382, 0, 0, 39, '2381'),
	(377, 1, 0, -50242, 2383, 0, 0, 39, '2382'),
	(377, 1, 0, -50242, 2384, 0, 0, 39, '2383'),
	(377, 1, 0, -50242, 2385, 0, 0, 39, '2384'),
	(377, 1, 0, -50242, 2386, 0, 0, 39, '2385'),
	(377, 1, 0, -50242, 2387, 0, 0, 39, '2386'),
	(377, 1, 0, -50242, 2388, 0, 0, 39, '2387'),
	(377, 1, 0, -50242, 2389, 0, 0, 39, '2388'),
	(377, 1, 0, -50242, 2390, 0, 0, 39, '2389'),
	(377, 1, 0, -50242, 2391, 0, 0, 39, '2390'),
	(377, 1, 0, -50242, 2392, 0, 0, 39, '2391'),
	(377, 1, 0, -50242, 2393, 0, 0, 39, '2392'),
	(377, 1, 0, -50242, 2394, 0, 0, 39, '2393'),
	(377, 1, 0, -50242, 2395, 0, 0, 39, '2394'),
	(377, 1, 0, -50242, 2396, 0, 0, 39, '2395'),
	(377, 1, 0, -50242, 2397, 0, 0, 39, '2396'),
	(377, 1, 0, -50242, 2398, 0, 0, 39, '2397'),
	(377, 1, 0, -50242, 2399, 0, 0, 39, '2398'),
	(377, 1, 0, -50242, 2400, 0, 0, 39, '2399'),
	(377, 1, 0, -50242, 2401, 0, 0, 39, '2400'),
	(377, 1, 0, -50242, 2402, 0, 0, 39, '2401'),
	(377, 1, 0, -50242, 2403, 0, 0, 39, '2402'),
	(377, 1, 0, -50242, 2404, 0, 0, 39, '2403'),
	(377, 1, 0, -50242, 2405, 0, 0, 39, '2404'),
	(377, 1, 0, -50242, 2406, 0, 0, 39, '2405'),
	(377, 1, 0, -50242, 2407, 0, 0, 39, '2406'),
	(377, 1, 0, -50242, 2408, 0, 0, 39, '2407'),
	(377, 1, 0, -50242, 2409, 0, 0, 39, '2408'),
	(377, 1, 0, -50242, 2410, 0, 0, 39, '2409'),
	(377, 1, 0, -50242, 2411, 0, 0, 39, '2410'),
	(377, 1, 0, -50242, 2412, 0, 0, 39, '2411'),
	(377, 1, 0, -50242, 2413, 0, 0, 39, '2412'),
	(377, 1, 0, -50242, 2414, 0, 0, 39, '2413'),
	(377, 1, 0, -50242, 2415, 0, 0, 39, '2414'),
	(377, 1, 0, -50242, 2416, 0, 0, 39, '2415'),
	(377, 1, 0, -50242, 2417, 0, 0, 39, '2416'),
	(377, 1, 0, -50242, 2418, 0, 0, 39, '2417'),
	(377, 1, 0, -50242, 2419, 0, 0, 39, '2418'),
	(377, 1, 0, -50242, 2420, 0, 0, 39, '2419'),
	(377, 1, 0, -50242, 2421, 0, 0, 39, '2420'),
	(377, 1, 0, -50242, 2422, 0, 0, 39, '2421'),
	(377, 1, 0, -50242, 2423, 0, 0, 39, '2422'),
	(377, 1, 0, -50242, 2424, 0, 0, 39, '2423'),
	(377, 1, 0, -50242, 2425, 0, 0, 39, '2424'),
	(377, 1, 0, -50242, 2426, 0, 0, 39, '2425'),
	(377, 1, 0, -50242, 2427, 0, 0, 39, '2426'),
	(377, 1, 0, -50242, 2428, 0, 0, 39, '2427'),
	(377, 1, 0, -50242, 2429, 0, 0, 39, '2428'),
	(377, 1, 0, -50242, 2430, 0, 0, 39, '2429'),
	(377, 1, 0, -50242, 2431, 0, 0, 39, '2430'),
	(377, 1, 0, -50242, 2432, 0, 0, 39, '2431'),
	(377, 1, 0, -50242, 2433, 0, 0, 39, '2432'),
	(377, 1, 0, -50242, 2434, 0, 0, 39, '2433'),
	(377, 1, 0, -50242, 2435, 0, 0, 39, '2434'),
	(377, 1, 0, -50242, 2436, 0, 0, 39, '2435'),
	(377, 1, 0, -50242, 2437, 0, 0, 39, '2436'),
	(377, 1, 0, -50242, 2438, 0, 0, 39, '2437'),
	(377, 1, 0, -50242, 2439, 0, 0, 39, '2438'),
	(377, 1, 0, -50242, 2440, 0, 0, 39, '2439'),
	(377, 1, 0, -50242, 2441, 0, 0, 39, '2440'),
	(377, 1, 0, -50242, 2442, 0, 0, 39, '2441'),
	(377, 1, 0, -50242, 2443, 0, 0, 39, '2442'),
	(377, 1, 0, -50242, 2444, 0, 0, 39, '2443'),
	(377, 1, 0, -50242, 2445, 0, 0, 39, '2444'),
	(377, 1, 0, -50242, 2446, 0, 0, 39, '2445'),
	(377, 1, 0, -50242, 2447, 0, 0, 39, '2446'),
	(377, 1, 0, -50242, 2448, 0, 0, 39, '2447'),
	(377, 1, 0, -50242, 2449, 0, 0, 39, '2448'),
	(377, 1, 0, -50242, 2450, 0, 0, 39, '2449'),
	(377, 1, 0, -50242, 2451, 0, 0, 39, '2450'),
	(377, 1, 0, -50242, 2452, 0, 0, 39, '2451'),
	(377, 1, 0, -50242, 2453, 0, 0, 39, '2452'),
	(377, 1, 0, -50242, 2454, 0, 0, 39, '2453'),
	(377, 1, 0, -50242, 2455, 0, 0, 39, '2454'),
	(377, 1, 0, -50242, 2456, 0, 0, 39, '2455'),
	(377, 1, 0, -50242, 2457, 0, 0, 39, '2456'),
	(377, 1, 0, -50242, 2458, 0, 0, 39, '2457'),
	(377, 1, 0, -50242, 2459, 0, 0, 39, '2458'),
	(377, 1, 0, -50242, 2460, 0, 0, 39, '2459'),
	(377, 1, 0, -50242, 2461, 0, 0, 39, '2460'),
	(377, 1, 0, -50242, 2462, 0, 0, 39, '2461'),
	(377, 1, 0, -50242, 2463, 0, 0, 39, '2462'),
	(377, 1, 0, -50242, 2464, 0, 0, 39, '2463'),
	(377, 1, 0, -50242, 2465, 0, 0, 39, '2464'),
	(377, 1, 0, -50242, 2466, 0, 0, 39, '2465'),
	(377, 1, 0, -50242, 2467, 0, 0, 39, '2466'),
	(377, 1, 0, -50242, 2468, 0, 0, 39, '2467'),
	(377, 1, 0, -50242, 2469, 0, 0, 39, '2468'),
	(377, 1, 0, -50242, 2470, 0, 0, 39, '2469'),
	(377, 1, 0, -50242, 2471, 0, 0, 39, '2470'),
	(377, 1, 0, -50242, 2472, 0, 0, 39, '2471'),
	(377, 1, 0, -50242, 2473, 0, 0, 39, '2472'),
	(377, 1, 0, -50242, 2474, 0, 0, 39, '2473'),
	(377, 1, 0, -50242, 2475, 0, 0, 39, '2474'),
	(377, 1, 0, -50242, 2476, 0, 0, 39, '2475'),
	(377, 1, 0, -50242, 2477, 0, 0, 39, '2476'),
	(377, 1, 0, -50242, 2478, 0, 0, 39, '2477'),
	(377, 1, 0, -50242, 2479, 0, 0, 39, '2478'),
	(377, 1, 0, -50242, 2480, 0, 0, 39, '2479'),
	(377, 1, 0, -50242, 2481, 0, 0, 39, '2480'),
	(377, 1, 0, -50242, 2482, 0, 0, 39, '2481'),
	(377, 1, 0, -50242, 2483, 0, 0, 39, '2482'),
	(377, 1, 0, -50242, 2484, 0, 0, 39, '2483'),
	(377, 1, 0, -50242, 2485, 0, 0, 39, '2484'),
	(377, 1, 0, -50242, 2486, 0, 0, 39, '2485'),
	(377, 1, 0, -50242, 2487, 0, 0, 39, '2486'),
	(377, 1, 0, -50242, 2488, 0, 0, 39, '2487'),
	(377, 1, 0, -50242, 2489, 0, 0, 39, '2488'),
	(377, 1, 0, -50242, 2490, 0, 0, 39, '2489'),
	(377, 1, 0, -50242, 2491, 0, 0, 39, '2490'),
	(377, 1, 0, -50242, 2492, 0, 0, 39, '2491'),
	(377, 1, 0, -50242, 2493, 0, 0, 39, '2492'),
	(377, 1, 0, -50242, 2494, 0, 0, 39, '2493'),
	(377, 1, 0, -50242, 2495, 0, 0, 39, '2494'),
	(377, 1, 0, -50242, 2496, 0, 0, 39, '2495'),
	(377, 1, 0, -50242, 2497, 0, 0, 39, '2496'),
	(377, 1, 0, -50242, 2498, 0, 0, 39, '2497'),
	(377, 1, 0, -50242, 2499, 0, 0, 39, '2498'),
	(377, 1, 0, -50242, 2500, 0, 0, 39, '2499'),
	(377, 1, 0, -50242, 2501, 0, 0, 39, '2500'),
	(377, 1, 0, -50242, 2502, 0, 0, 39, '2501'),
	(377, 1, 0, -50242, 2503, 0, 0, 39, '2502'),
	(377, 1, 0, -50242, 2504, 0, 0, 39, '2503'),
	(377, 1, 0, -50242, 2505, 0, 0, 39, '2504'),
	(377, 1, 0, -50242, 2506, 0, 0, 39, '2505'),
	(377, 1, 0, -50242, 2507, 0, 0, 39, '2506'),
	(377, 1, 0, -50242, 2508, 0, 0, 39, '2507'),
	(377, 1, 0, -50242, 2509, 0, 0, 39, '2508'),
	(377, 1, 0, -50242, 2510, 0, 0, 39, '2509'),
	(377, 1, 0, -50242, 2511, 0, 0, 39, '2510'),
	(377, 1, 0, -50242, 2512, 0, 0, 39, '2511'),
	(377, 1, 0, -50242, 2513, 0, 0, 39, '2512'),
	(377, 1, 0, -50242, 2514, 0, 0, 39, '2513'),
	(377, 1, 0, -50242, 2515, 0, 0, 39, '2514'),
	(377, 1, 0, -50242, 2516, 0, 0, 39, '2515'),
	(377, 1, 0, -50242, 2517, 0, 0, 39, '2516'),
	(377, 1, 0, -50242, 2518, 0, 0, 39, '2517'),
	(377, 1, 0, -50242, 2519, 0, 0, 39, '2518'),
	(377, 1, 0, -50242, 2520, 0, 0, 39, '2519'),
	(377, 1, 0, -50242, 2521, 0, 0, 39, '2520'),
	(377, 1, 0, -50242, 2522, 0, 0, 39, '2521'),
	(377, 1, 0, -50242, 2523, 0, 0, 39, '2522'),
	(377, 1, 0, -50242, 2524, 0, 0, 39, '2523'),
	(377, 1, 0, -50242, 2525, 0, 0, 39, '2524'),
	(377, 1, 0, -50242, 2526, 0, 0, 39, '2525'),
	(377, 1, 0, -50242, 2527, 0, 0, 39, '2526'),
	(377, 1, 0, -50242, 2528, 0, 0, 39, '2527'),
	(377, 1, 0, -50242, 2529, 0, 0, 39, '2528'),
	(377, 1, 0, -50242, 2530, 0, 0, 39, '2529'),
	(377, 1, 0, -50242, 2531, 0, 0, 39, '2530'),
	(377, 1, 0, -50242, 2532, 0, 0, 39, '2531'),
	(377, 1, 0, -50242, 2533, 0, 0, 39, '2532'),
	(377, 1, 0, -50242, 2534, 0, 0, 39, '2533'),
	(377, 1, 0, -50242, 2535, 0, 0, 39, '2534'),
	(377, 1, 0, -50242, 2536, 0, 0, 39, '2535'),
	(377, 1, 0, -50242, 2537, 0, 0, 39, '2536'),
	(377, 1, 0, -50242, 2538, 0, 0, 39, '2537'),
	(377, 1, 0, -50242, 2539, 0, 0, 39, '2538'),
	(377, 1, 0, -50242, 2540, 0, 0, 39, '2539'),
	(377, 1, 0, -50242, 2541, 0, 0, 39, '2540'),
	(377, 1, 0, -50242, 2542, 0, 0, 39, '2541'),
	(377, 1, 0, -50242, 2543, 0, 0, 39, '2542'),
	(377, 1, 0, -50242, 2544, 0, 0, 39, '2543'),
	(377, 1, 0, -50242, 2545, 0, 0, 39, '2544'),
	(377, 1, 0, -50242, 2546, 0, 0, 39, '2545'),
	(377, 1, 0, -50242, 2547, 0, 0, 39, '2546'),
	(377, 1, 0, -50242, 2548, 0, 0, 39, '2547'),
	(377, 1, 0, -50242, 2549, 0, 0, 39, '2548'),
	(377, 1, 0, -50242, 2550, 0, 0, 39, '2549'),
	(377, 1, 0, -50242, 2551, 0, 0, 39, '2550'),
	(377, 1, 0, -50242, 2552, 0, 0, 39, '2551'),
	(377, 1, 0, -50242, 2553, 0, 0, 39, '2552'),
	(377, 1, 0, -50242, 2554, 0, 0, 39, '2553'),
	(377, 1, 0, -50242, 2555, 0, 0, 39, '2554'),
	(377, 1, 0, -50242, 2556, 0, 0, 39, '2555'),
	(377, 1, 0, -50242, 2557, 0, 0, 39, '2556'),
	(377, 1, 0, -50242, 2558, 0, 0, 39, '2557'),
	(377, 1, 0, -50242, 2559, 0, 0, 39, '2558'),
	(377, 1, 0, -50242, 2560, 0, 0, 39, '2559'),
	(377, 1, 0, -50242, 2561, 0, 0, 39, '2560'),
	(377, 1, 0, -50242, 2562, 0, 0, 39, '2561'),
	(377, 1, 0, -50242, 2563, 0, 0, 39, '2562'),
	(377, 1, 0, -50242, 2564, 0, 0, 39, '2563'),
	(377, 1, 0, -50242, 2565, 0, 0, 39, '2564'),
	(377, 1, 0, -50242, 2566, 0, 0, 39, '2565'),
	(377, 1, 0, -50242, 2567, 0, 0, 39, '2566'),
	(377, 1, 0, -50242, 2568, 0, 0, 39, '2567'),
	(377, 1, 0, -50242, 2569, 0, 0, 39, '2568'),
	(377, 1, 0, -50242, 2570, 0, 0, 39, '2569'),
	(377, 1, 0, -50242, 2571, 0, 0, 39, '2570'),
	(377, 1, 0, -50242, 2572, 0, 0, 39, '2571'),
	(377, 1, 0, -50242, 2573, 0, 0, 39, '2572'),
	(377, 1, 0, -50242, 2574, 0, 0, 39, '2573'),
	(377, 1, 0, -50242, 2575, 0, 0, 39, '2574'),
	(377, 1, 0, -50242, 2576, 0, 0, 39, '2575'),
	(377, 1, 0, -50242, 2577, 0, 0, 39, '2576'),
	(377, 1, 0, -50242, 2578, 0, 0, 39, '2577'),
	(377, 1, 0, -50242, 2579, 0, 0, 39, '2578'),
	(377, 1, 0, -50242, 2580, 0, 0, 39, '2579'),
	(377, 1, 0, -50242, 2581, 0, 0, 39, '2580'),
	(377, 1, 0, -50242, 2582, 0, 0, 39, '2581'),
	(377, 1, 0, -50242, 2583, 0, 0, 39, '2582'),
	(377, 1, 0, -50242, 2584, 0, 0, 39, '2583'),
	(377, 1, 0, -50242, 2585, 0, 0, 39, '2584'),
	(377, 1, 0, -50242, 2586, 0, 0, 39, '2585'),
	(377, 1, 0, -50242, 2587, 0, 0, 39, '2586'),
	(377, 1, 0, -50242, 2588, 0, 0, 39, '2587'),
	(377, 1, 0, -50242, 2589, 0, 0, 39, '2588'),
	(377, 1, 0, -50242, 2590, 0, 0, 39, '2589'),
	(377, 1, 0, -50242, 2591, 0, 0, 39, '2590'),
	(377, 1, 0, -50242, 2592, 0, 0, 39, '2591'),
	(377, 1, 0, -50242, 2593, 0, 0, 39, '2592'),
	(377, 1, 0, -50242, 2594, 0, 0, 39, '2593'),
	(377, 1, 0, -50242, 2595, 0, 0, 39, '2594'),
	(377, 1, 0, -50242, 2596, 0, 0, 39, '2595'),
	(377, 1, 0, -50242, 2597, 0, 0, 39, '2596'),
	(377, 1, 0, -50242, 2598, 0, 0, 39, '2597'),
	(377, 1, 0, -50242, 2599, 0, 0, 39, '2598'),
	(377, 1, 0, -50242, 2600, 0, 0, 39, '2599'),
	(377, 1, 0, -50242, 2601, 0, 0, 39, '2600'),
	(377, 1, 0, -50242, 2602, 0, 0, 39, '2601'),
	(377, 1, 0, -50242, 2603, 0, 0, 39, '2602'),
	(377, 1, 0, -50242, 2604, 0, 0, 39, '2603'),
	(377, 1, 0, -50242, 2605, 0, 0, 39, '2604'),
	(377, 1, 0, -50242, 2606, 0, 0, 39, '2605'),
	(377, 1, 0, -50242, 2607, 0, 0, 39, '2606'),
	(377, 1, 0, -50242, 2608, 0, 0, 39, '2607'),
	(377, 1, 0, -50242, 2609, 0, 0, 39, '2608'),
	(377, 1, 0, -50242, 2610, 0, 0, 39, '2609'),
	(377, 1, 0, -50242, 2611, 0, 0, 39, '2610'),
	(377, 1, 0, -50242, 2612, 0, 0, 39, '2611'),
	(377, 1, 0, -50242, 2613, 0, 0, 39, '2612'),
	(377, 1, 0, -50242, 2614, 0, 0, 39, '2613'),
	(377, 1, 0, -50242, 2615, 0, 0, 39, '2614'),
	(377, 1, 0, -50242, 2616, 0, 0, 39, '2615'),
	(377, 1, 0, -50242, 2617, 0, 0, 39, '2616'),
	(377, 1, 0, -50242, 2618, 0, 0, 39, '2617'),
	(377, 1, 0, -50242, 2619, 0, 0, 39, '2618'),
	(377, 1, 0, -50242, 2620, 0, 0, 39, '2619'),
	(377, 1, 0, -50242, 2621, 0, 0, 39, '2620'),
	(377, 1, 0, -50242, 2622, 0, 0, 39, '2621'),
	(377, 1, 0, -50242, 2623, 0, 0, 39, '2622'),
	(377, 1, 0, -50242, 2624, 0, 0, 39, '2623'),
	(377, 1, 0, -50242, 2625, 0, 0, 39, '2624'),
	(377, 1, 0, -50242, 2626, 0, 0, 39, '2625'),
	(377, 1, 0, -50242, 2627, 0, 0, 39, '2626'),
	(377, 1, 0, -50242, 2628, 0, 0, 39, '2627'),
	(377, 1, 0, -50242, 2629, 0, 0, 39, '2628'),
	(377, 1, 0, -50242, 2630, 0, 0, 39, '2629'),
	(377, 1, 0, -50242, 2631, 0, 0, 39, '2630'),
	(377, 1, 0, -50242, 2632, 0, 0, 39, '2631'),
	(377, 1, 0, -50242, 2633, 0, 0, 39, '2632'),
	(377, 1, 0, -50242, 2634, 0, 0, 39, '2633'),
	(377, 1, 0, -50242, 2635, 0, 0, 39, '2634'),
	(377, 1, 0, -50242, 2636, 0, 0, 39, '2635'),
	(377, 1, 0, -50242, 2637, 0, 0, 39, '2636'),
	(377, 1, 0, -50242, 2638, 0, 0, 39, '2637'),
	(377, 1, 0, -50242, 2639, 0, 0, 39, '2638'),
	(377, 1, 0, -50242, 2640, 0, 0, 39, '2639'),
	(377, 1, 0, -50242, 2641, 0, 0, 39, '2640'),
	(377, 1, 0, -50242, 2642, 0, 0, 39, '2641'),
	(377, 1, 0, -50242, 2643, 0, 0, 39, '2642'),
	(377, 1, 0, -50242, 2644, 0, 0, 39, '2643'),
	(377, 1, 0, -50242, 2645, 0, 0, 39, '2644'),
	(377, 1, 0, -50242, 2646, 0, 0, 39, '2645'),
	(377, 1, 0, -50242, 2647, 0, 0, 39, '2646'),
	(377, 1, 0, -50242, 2648, 0, 0, 39, '2647'),
	(377, 1, 0, -50242, 2649, 0, 0, 39, '2648'),
	(377, 1, 0, -50242, 2650, 0, 0, 39, '2649'),
	(377, 1, 0, -50242, 2651, 0, 0, 39, '2650'),
	(377, 1, 0, -50242, 2652, 0, 0, 39, '2651'),
	(377, 1, 0, -50242, 2653, 0, 0, 39, '2652'),
	(377, 1, 0, -50242, 2654, 0, 0, 39, '2653'),
	(377, 1, 0, -50242, 2655, 0, 0, 39, '2654'),
	(377, 1, 0, -50242, 2656, 0, 0, 39, '2655'),
	(377, 1, 0, -50242, 2657, 0, 0, 39, '2656'),
	(377, 1, 0, -50242, 2658, 0, 0, 39, '2657'),
	(377, 1, 0, -50242, 2659, 0, 0, 39, '2658'),
	(377, 1, 0, -50242, 2660, 0, 0, 39, '2659'),
	(377, 1, 0, -50242, 2661, 0, 0, 39, '2660'),
	(377, 1, 0, -50242, 2662, 0, 0, 39, '2661'),
	(377, 1, 0, -50242, 2663, 0, 0, 39, '2662'),
	(377, 1, 0, -50242, 2664, 0, 0, 39, '2663'),
	(377, 1, 0, -50242, 2665, 0, 0, 39, '2664'),
	(377, 1, 0, -50242, 2666, 0, 0, 39, '2665'),
	(377, 1, 0, -50242, 2667, 0, 0, 39, '2666'),
	(377, 1, 0, -50242, 2668, 0, 0, 39, '2667'),
	(377, 1, 0, -50242, 2669, 0, 0, 39, '2668'),
	(377, 1, 0, -50242, 2670, 0, 0, 39, '2669'),
	(377, 1, 0, -50242, 2671, 0, 0, 39, '2670'),
	(377, 1, 0, -50242, 2672, 0, 0, 39, '2671'),
	(377, 1, 0, -50242, 2673, 0, 0, 39, '2672'),
	(377, 1, 0, -50242, 2674, 0, 0, 39, '2673'),
	(377, 1, 0, -50242, 2675, 0, 0, 39, '2674'),
	(377, 1, 0, -50242, 2676, 0, 0, 39, '2675'),
	(377, 1, 0, -50242, 2677, 0, 0, 39, '2676'),
	(377, 1, 0, -50242, 2678, 0, 0, 39, '2677'),
	(377, 1, 0, -50242, 2679, 0, 0, 39, '2678'),
	(377, 1, 0, -50242, 2680, 0, 0, 39, '2679'),
	(377, 1, 0, -50242, 2681, 0, 0, 39, '2680'),
	(377, 1, 0, -50242, 2682, 0, 0, 39, '2681'),
	(377, 1, 0, -50242, 2683, 0, 0, 39, '2682'),
	(377, 1, 0, -50242, 2684, 0, 0, 39, '2683'),
	(377, 1, 0, -50242, 2685, 0, 0, 39, '2684'),
	(377, 1, 0, -50242, 2686, 0, 0, 39, '2685'),
	(377, 1, 0, -50242, 2687, 0, 0, 39, '2686'),
	(377, 1, 0, -50242, 2688, 0, 0, 39, '2687'),
	(377, 1, 0, -50242, 2689, 0, 0, 39, '2688'),
	(377, 1, 0, -50242, 2690, 0, 0, 39, '2689'),
	(377, 1, 0, -50242, 2691, 0, 0, 39, '2690'),
	(377, 1, 0, -50242, 2692, 0, 0, 39, '2691'),
	(377, 1, 0, -50242, 2693, 0, 0, 39, '2692'),
	(377, 1, 0, -50242, 2694, 0, 0, 39, '2693'),
	(377, 1, 0, -50242, 2695, 0, 0, 39, '2694'),
	(377, 1, 0, -50242, 2696, 0, 0, 39, '2695'),
	(377, 1, 0, -50242, 2697, 0, 0, 39, '2696'),
	(377, 1, 0, -50242, 2698, 0, 0, 39, '2697'),
	(377, 1, 0, -50242, 2699, 0, 0, 39, '2698'),
	(377, 1, 0, -50242, 2700, 0, 0, 39, '2699'),
	(377, 1, 0, -50242, 2701, 0, 0, 39, '2700'),
	(377, 1, 0, -50242, 2702, 0, 0, 39, '2701'),
	(377, 1, 0, -50242, 2703, 0, 0, 39, '2702'),
	(377, 1, 0, -50242, 2704, 0, 0, 39, '2703'),
	(377, 1, 0, -50242, 2705, 0, 0, 39, '2704'),
	(377, 1, 0, -50242, 2706, 0, 0, 39, '2705'),
	(377, 1, 0, -50242, 2707, 0, 0, 39, '2706'),
	(377, 1, 0, -50242, 2708, 0, 0, 39, '2707'),
	(377, 1, 0, -50242, 2709, 0, 0, 39, '2708'),
	(377, 1, 0, -50242, 2710, 0, 0, 39, '2709'),
	(377, 1, 0, -50242, 2711, 0, 0, 39, '2710'),
	(377, 1, 0, -50242, 2712, 0, 0, 39, '2711'),
	(377, 1, 0, -50242, 2713, 0, 0, 39, '2712'),
	(377, 1, 0, -50242, 2714, 0, 0, 39, '2713'),
	(377, 1, 0, -50242, 2715, 0, 0, 39, '2714'),
	(377, 1, 0, -50242, 2716, 0, 0, 39, '2715'),
	(377, 1, 0, -50242, 2717, 0, 0, 39, '2716'),
	(377, 1, 0, -50242, 2718, 0, 0, 39, '2717'),
	(377, 1, 0, -50242, 2719, 0, 0, 39, '2718'),
	(377, 1, 0, -50242, 2720, 0, 0, 39, '2719'),
	(377, 1, 0, -50242, 2721, 0, 0, 39, '2720'),
	(377, 1, 0, -50242, 2722, 0, 0, 39, '2721'),
	(377, 1, 0, -50242, 2723, 0, 0, 39, '2722'),
	(377, 1, 0, -50242, 2724, 0, 0, 39, '2723'),
	(377, 1, 0, -50242, 2725, 0, 0, 39, '2724'),
	(377, 1, 0, -50242, 2726, 0, 0, 39, '2725'),
	(377, 1, 0, -50242, 2727, 0, 0, 39, '2726'),
	(377, 1, 0, -50242, 2728, 0, 0, 39, '2727'),
	(377, 1, 0, -50242, 2729, 0, 0, 39, '2728'),
	(377, 1, 0, -50242, 2730, 0, 0, 39, '2729'),
	(377, 1, 0, -50242, 2731, 0, 0, 39, '2730'),
	(377, 1, 0, -50242, 2732, 0, 0, 39, '2731'),
	(377, 1, 0, -50242, 2733, 0, 0, 39, '2732'),
	(377, 1, 0, -50242, 2734, 0, 0, 39, '2733'),
	(377, 1, 0, -50242, 2735, 0, 0, 39, '2734'),
	(377, 1, 0, -50242, 2736, 0, 0, 39, '2735'),
	(377, 1, 0, -50242, 2737, 0, 0, 39, '2736'),
	(377, 1, 0, -50242, 2738, 0, 0, 39, '2737'),
	(377, 1, 0, -50242, 2739, 0, 0, 39, '2738'),
	(377, 1, 0, -50242, 2740, 0, 0, 39, '2739'),
	(377, 1, 0, -50242, 2741, 0, 0, 39, '2740'),
	(377, 1, 0, -50242, 2742, 0, 0, 39, '2741'),
	(377, 1, 0, -50242, 2743, 0, 0, 39, '2742'),
	(377, 1, 0, -50242, 2744, 0, 0, 39, '2743'),
	(377, 1, 0, -50242, 2745, 0, 0, 39, '2744'),
	(377, 1, 0, -50242, 2746, 0, 0, 39, '2745'),
	(377, 1, 0, -50242, 2747, 0, 0, 39, '2746'),
	(377, 1, 0, -50242, 2748, 0, 0, 39, '2747'),
	(377, 1, 0, -50242, 2749, 0, 0, 39, '2748'),
	(377, 1, 0, -50242, 2750, 0, 0, 39, '2749'),
	(377, 1, 0, -50242, 2751, 0, 0, 39, '2750'),
	(377, 1, 0, -50242, 2752, 0, 0, 39, '2751'),
	(377, 1, 0, -50242, 2753, 0, 0, 39, '2752'),
	(377, 1, 0, -50242, 2754, 0, 0, 39, '2753'),
	(377, 1, 0, -50242, 2755, 0, 0, 39, '2754'),
	(377, 1, 0, -50242, 2756, 0, 0, 39, '2755'),
	(377, 1, 0, -50242, 2757, 0, 0, 39, '2756'),
	(377, 1, 0, -50242, 2758, 0, 0, 39, '2757'),
	(377, 1, 0, -50242, 2759, 0, 0, 39, '2758'),
	(377, 1, 0, -50242, 2760, 0, 0, 39, '2759'),
	(377, 1, 0, -50242, 2761, 0, 0, 39, '2760'),
	(377, 1, 0, -50242, 2762, 0, 0, 39, '2761'),
	(377, 1, 0, -50242, 2763, 0, 0, 39, '2762'),
	(377, 1, 0, -50242, 2764, 0, 0, 39, '2763'),
	(377, 1, 0, -50242, 2765, 0, 0, 39, '2764'),
	(377, 1, 0, -50242, 2766, 0, 0, 39, '2765'),
	(377, 1, 0, -50242, 2767, 0, 0, 39, '2766'),
	(377, 1, 0, -50242, 2768, 0, 0, 39, '2767'),
	(377, 1, 0, -50242, 2769, 0, 0, 39, '2768'),
	(377, 1, 0, -50242, 2770, 0, 0, 39, '2769'),
	(377, 1, 0, -50242, 2771, 0, 0, 39, '2770'),
	(377, 1, 0, -50242, 2772, 0, 0, 39, '2771'),
	(377, 1, 0, -50242, 2773, 0, 0, 39, '2772'),
	(377, 1, 0, -50242, 2774, 0, 0, 39, '2773'),
	(377, 1, 0, -50242, 2775, 0, 0, 39, '2774'),
	(377, 1, 0, -50242, 2776, 0, 0, 39, '2775'),
	(377, 1, 0, -50242, 2777, 0, 0, 39, '2776'),
	(377, 1, 0, -50242, 2778, 0, 0, 39, '2777'),
	(377, 1, 0, -50242, 2779, 0, 0, 39, '2778'),
	(377, 1, 0, -50242, 2780, 0, 0, 39, '2779'),
	(377, 1, 0, -50242, 2781, 0, 0, 39, '2780'),
	(377, 1, 0, -50242, 2782, 0, 0, 39, '2781'),
	(377, 1, 0, -50242, 2783, 0, 0, 39, '2782'),
	(377, 1, 0, -50242, 2784, 0, 0, 39, '2783'),
	(377, 1, 0, -50242, 2785, 0, 0, 39, '2784'),
	(377, 1, 0, -50242, 2786, 0, 0, 39, '2785'),
	(377, 1, 0, -50242, 2787, 0, 0, 39, '2786'),
	(377, 1, 0, -50242, 2788, 0, 0, 39, '2787'),
	(377, 1, 0, -50242, 2789, 0, 0, 39, '2788'),
	(377, 1, 0, -50242, 2790, 0, 0, 39, '2789'),
	(377, 1, 0, -50242, 2791, 0, 0, 39, '2790'),
	(377, 1, 0, -50242, 2792, 0, 0, 39, '2791'),
	(377, 1, 0, -50242, 2793, 0, 0, 39, '2792'),
	(377, 1, 0, -50242, 2794, 0, 0, 39, '2793'),
	(377, 1, 0, -50242, 2795, 0, 0, 39, '2794'),
	(377, 1, 0, -50242, 2796, 0, 0, 39, '2795'),
	(377, 1, 0, -50242, 2797, 0, 0, 39, '2796'),
	(377, 1, 0, -50242, 2798, 0, 0, 39, '2797'),
	(377, 1, 0, -50242, 2799, 0, 0, 39, '2798'),
	(377, 1, 0, -50242, 2800, 0, 0, 39, '2799'),
	(377, 1, 0, -50242, 2801, 0, 0, 39, '2800'),
	(377, 1, 0, -50242, 2802, 0, 0, 39, '2801'),
	(377, 1, 0, -50242, 2803, 0, 0, 39, '2802'),
	(377, 1, 0, -50242, 2804, 0, 0, 39, '2803'),
	(377, 1, 0, -50242, 2805, 0, 0, 39, '2804'),
	(377, 1, 0, -50242, 2806, 0, 0, 39, '2805'),
	(377, 1, 0, -50242, 2807, 0, 0, 39, '2806'),
	(377, 1, 0, -50242, 2808, 0, 0, 39, '2807'),
	(377, 1, 0, -50242, 2809, 0, 0, 39, '2808'),
	(377, 1, 0, -50242, 2810, 0, 0, 39, '2809'),
	(377, 1, 0, -50242, 2811, 0, 0, 39, '2810'),
	(377, 1, 0, -50242, 2812, 0, 0, 39, '2811'),
	(377, 1, 0, -50242, 2813, 0, 0, 39, '2812'),
	(377, 1, 0, -50242, 2814, 0, 0, 39, '2813'),
	(377, 1, 0, -50242, 2815, 0, 0, 39, '2814'),
	(377, 1, 0, -50242, 2816, 0, 0, 39, '2815'),
	(377, 1, 0, -50242, 2817, 0, 0, 39, '2816'),
	(377, 1, 0, -50242, 2818, 0, 0, 39, '2817'),
	(377, 1, 0, -50242, 2819, 0, 0, 39, '2818'),
	(377, 1, 0, -50242, 2820, 0, 0, 39, '2819'),
	(377, 1, 0, -50242, 2821, 0, 0, 39, '2820'),
	(377, 1, 0, -50242, 2822, 0, 0, 39, '2821'),
	(377, 1, 0, -50242, 2823, 0, 0, 39, '2822'),
	(377, 1, 0, -50242, 2824, 0, 0, 39, '2823'),
	(377, 1, 0, -50242, 2825, 0, 0, 39, '2824'),
	(377, 1, 0, -50242, 2826, 0, 0, 39, '2825'),
	(377, 1, 0, -50242, 2827, 0, 0, 39, '2826'),
	(377, 1, 0, -50242, 2828, 0, 0, 39, '2827'),
	(377, 1, 0, -50242, 2829, 0, 0, 39, '2828'),
	(377, 1, 0, -50242, 2830, 0, 0, 39, '2829'),
	(377, 1, 0, -50242, 2831, 0, 0, 39, '2830'),
	(377, 1, 0, -50242, 2832, 0, 0, 39, '2831'),
	(377, 1, 0, -50242, 2833, 0, 0, 39, '2832'),
	(377, 1, 0, -50242, 2834, 0, 0, 39, '2833'),
	(377, 1, 0, -50242, 2835, 0, 0, 39, '2834'),
	(377, 1, 0, -50242, 2836, 0, 0, 39, '2835'),
	(377, 1, 0, -50242, 2837, 0, 0, 39, '2836'),
	(377, 1, 0, -50242, 2838, 0, 0, 39, '2837'),
	(377, 1, 0, -50242, 2839, 0, 0, 39, '2838'),
	(377, 1, 0, -50242, 2840, 0, 0, 39, '2839'),
	(377, 1, 0, -50242, 2841, 0, 0, 39, '2840'),
	(377, 1, 0, -50242, 2842, 0, 0, 39, '2841'),
	(377, 1, 0, -50242, 2843, 0, 0, 39, '2842'),
	(377, 1, 0, -50242, 2844, 0, 0, 39, '2843'),
	(377, 1, 0, -50242, 2845, 0, 0, 39, '2844'),
	(377, 1, 0, -50242, 2846, 0, 0, 39, '2845'),
	(377, 1, 0, -50242, 2847, 0, 0, 39, '2846'),
	(377, 1, 0, -50242, 2848, 0, 0, 39, '2847'),
	(377, 1, 0, -50242, 2849, 0, 0, 39, '2848'),
	(377, 1, 0, -50242, 2850, 0, 0, 39, '2849'),
	(377, 1, 0, -50242, 2851, 0, 0, 39, '2850'),
	(377, 1, 0, -50242, 2852, 0, 0, 39, '2851'),
	(377, 1, 0, -50242, 2853, 0, 0, 39, '2852'),
	(377, 1, 0, -50242, 2854, 0, 0, 39, '2853'),
	(377, 1, 0, -50242, 2855, 0, 0, 39, '2854'),
	(377, 1, 0, -50242, 2856, 0, 0, 39, '2855'),
	(377, 1, 0, -50242, 2857, 0, 0, 39, '2856'),
	(377, 1, 0, -50242, 2858, 0, 0, 39, '2857'),
	(377, 1, 0, -50242, 2859, 0, 0, 39, '2858'),
	(377, 1, 0, -50242, 2860, 0, 0, 39, '2859'),
	(377, 1, 0, -50242, 2861, 0, 0, 39, '2860'),
	(377, 1, 0, -50242, 2862, 0, 0, 39, '2861'),
	(377, 1, 0, -50242, 2863, 0, 0, 39, '2862'),
	(377, 1, 0, -50242, 2864, 0, 0, 39, '2863'),
	(377, 1, 0, -50242, 2865, 0, 0, 39, '2864'),
	(377, 1, 0, -50242, 2866, 0, 0, 39, '2865'),
	(377, 1, 0, -50242, 2867, 0, 0, 39, '2866'),
	(377, 1, 0, -50242, 2868, 0, 0, 39, '2867'),
	(377, 1, 0, -50242, 2869, 0, 0, 39, '2868'),
	(377, 1, 0, -50242, 2870, 0, 0, 39, '2869'),
	(377, 1, 0, -50242, 2871, 0, 0, 39, '2870'),
	(377, 1, 0, -50242, 2872, 0, 0, 39, '2871'),
	(377, 1, 0, -50242, 2873, 0, 0, 39, '2872'),
	(377, 1, 0, -50242, 2874, 0, 0, 39, '2873'),
	(377, 1, 0, -50242, 2875, 0, 0, 39, '2874'),
	(377, 1, 0, -50242, 2876, 0, 0, 39, '2875'),
	(377, 1, 0, -50242, 2877, 0, 0, 39, '2876'),
	(377, 1, 0, -50242, 2878, 0, 0, 39, '2877'),
	(377, 1, 0, -50242, 2879, 0, 0, 39, '2878'),
	(377, 1, 0, -50242, 2880, 0, 0, 39, '2879'),
	(377, 1, 0, -50242, 2881, 0, 0, 39, '2880'),
	(377, 1, 0, -50242, 2882, 0, 0, 39, '2881'),
	(377, 1, 0, -50242, 2883, 0, 0, 39, '2882'),
	(377, 1, 0, -50242, 2884, 0, 0, 39, '2883'),
	(377, 1, 0, -50242, 2885, 0, 0, 39, '2884'),
	(377, 1, 0, -50242, 2886, 0, 0, 39, '2885'),
	(377, 1, 0, -50242, 2887, 0, 0, 39, '2886'),
	(377, 1, 0, -50242, 2888, 0, 0, 39, '2887'),
	(377, 1, 0, -50242, 2889, 0, 0, 39, '2888'),
	(377, 1, 0, -50242, 2890, 0, 0, 39, '2889'),
	(377, 1, 0, -50242, 2891, 0, 0, 39, '2890'),
	(377, 1, 0, -50242, 2892, 0, 0, 39, '2891'),
	(377, 1, 0, -50242, 2893, 0, 0, 39, '2892'),
	(377, 1, 0, -50242, 2894, 0, 0, 39, '2893'),
	(377, 1, 0, -50242, 2895, 0, 0, 39, '2894'),
	(377, 1, 0, -50242, 2896, 0, 0, 39, '2895'),
	(377, 1, 0, -50242, 2897, 0, 0, 39, '2896'),
	(377, 1, 0, -50242, 2898, 0, 0, 39, '2897'),
	(377, 1, 0, -50242, 2899, 0, 0, 39, '2898'),
	(377, 1, 0, -50242, 2900, 0, 0, 39, '2899'),
	(377, 1, 0, -50242, 2901, 0, 0, 39, '2900'),
	(377, 1, 0, -50242, 2902, 0, 0, 39, '2901'),
	(377, 1, 0, -50242, 2903, 0, 0, 39, '2902'),
	(377, 1, 0, -50242, 2904, 0, 0, 39, '2903'),
	(377, 1, 0, -50242, 2905, 0, 0, 39, '2904'),
	(377, 1, 0, -50242, 2906, 0, 0, 39, '2905'),
	(377, 1, 0, -50242, 2907, 0, 0, 39, '2906'),
	(377, 1, 0, -50242, 2908, 0, 0, 39, '2907'),
	(377, 1, 0, -50242, 2909, 0, 0, 39, '2908'),
	(377, 1, 0, -50242, 2910, 0, 0, 39, '2909'),
	(377, 1, 0, -50242, 2911, 0, 0, 39, '2910'),
	(377, 1, 0, -50242, 2912, 0, 0, 39, '2911'),
	(377, 1, 0, -50242, 2913, 0, 0, 39, '2912'),
	(377, 1, 0, -50242, 2914, 0, 0, 39, '2913'),
	(377, 1, 0, -50242, 2915, 0, 0, 39, '2914'),
	(377, 1, 0, -50242, 2916, 0, 0, 39, '2915'),
	(377, 1, 0, -50242, 2917, 0, 0, 39, '2916'),
	(377, 1, 0, -50242, 2918, 0, 0, 39, '2917'),
	(377, 1, 0, -50242, 2919, 0, 0, 39, '2918'),
	(377, 1, 0, -50242, 2920, 0, 0, 39, '2919'),
	(377, 1, 0, -50242, 2921, 0, 0, 39, '2920'),
	(377, 1, 0, -50242, 2922, 0, 0, 39, '2921'),
	(377, 1, 0, -50242, 2923, 0, 0, 39, '2922'),
	(377, 1, 0, -50242, 2924, 0, 0, 39, '2923'),
	(377, 1, 0, -50242, 2925, 0, 0, 39, '2924'),
	(377, 1, 0, -50242, 2926, 0, 0, 39, '2925'),
	(377, 1, 0, -50242, 2927, 0, 0, 39, '2926'),
	(377, 1, 0, -50242, 2928, 0, 0, 39, '2927'),
	(377, 1, 0, -50242, 2929, 0, 0, 39, '2928'),
	(377, 1, 0, -50242, 2930, 0, 0, 39, '2929'),
	(377, 1, 0, -50242, 2931, 0, 0, 39, '2930'),
	(377, 1, 0, -50242, 2932, 0, 0, 39, '2931'),
	(377, 1, 0, -50242, 2933, 0, 0, 39, '2932'),
	(377, 1, 0, -50242, 2934, 0, 0, 39, '2933'),
	(377, 1, 0, -50242, 2935, 0, 0, 39, '2934'),
	(377, 1, 0, -50242, 2936, 0, 0, 39, '2935'),
	(377, 1, 0, -50242, 2937, 0, 0, 39, '2936'),
	(377, 1, 0, -50242, 2938, 0, 0, 39, '2937'),
	(377, 1, 0, -50242, 2939, 0, 0, 39, '2938'),
	(377, 1, 0, -50242, 2940, 0, 0, 39, '2939'),
	(377, 1, 0, -50242, 2941, 0, 0, 39, '2940'),
	(377, 1, 0, -50242, 2942, 0, 0, 39, '2941'),
	(377, 1, 0, -50242, 2943, 0, 0, 39, '2942'),
	(377, 1, 0, -50242, 2944, 0, 0, 39, '2943'),
	(377, 1, 0, -50242, 2945, 0, 0, 39, '2944'),
	(377, 1, 0, -50242, 2946, 0, 0, 39, '2945'),
	(377, 1, 0, -50242, 2947, 0, 0, 39, '2946'),
	(377, 1, 0, -50242, 2948, 0, 0, 39, '2947'),
	(377, 1, 0, -50242, 2949, 0, 0, 39, '2948'),
	(377, 1, 0, -50242, 2950, 0, 0, 39, '2949'),
	(377, 1, 0, -50242, 2951, 0, 0, 39, '2950'),
	(377, 1, 0, -50242, 2952, 0, 0, 39, '2951'),
	(377, 1, 0, -50242, 2953, 0, 0, 39, '2952'),
	(377, 1, 0, -50242, 2954, 0, 0, 39, '2953'),
	(377, 1, 0, -50242, 2955, 0, 0, 39, '2954'),
	(377, 1, 0, -50242, 2956, 0, 0, 39, '2955'),
	(377, 1, 0, -50242, 2957, 0, 0, 39, '2956'),
	(377, 1, 0, -50242, 2958, 0, 0, 39, '2957'),
	(377, 1, 0, -50242, 2959, 0, 0, 39, '2958'),
	(377, 1, 0, -50242, 2960, 0, 0, 39, '2959'),
	(377, 1, 0, -50242, 2961, 0, 0, 39, '2960'),
	(377, 1, 0, -50242, 2962, 0, 0, 39, '2961'),
	(377, 1, 0, -50242, 2963, 0, 0, 39, '2962'),
	(377, 1, 0, -50242, 2964, 0, 0, 39, '2963'),
	(377, 1, 0, -50242, 2965, 0, 0, 39, '2964'),
	(377, 1, 0, -50242, 2966, 0, 0, 39, '2965'),
	(377, 1, 0, -50242, 2967, 0, 0, 39, '2966'),
	(377, 1, 0, -50242, 2968, 0, 0, 39, '2967'),
	(377, 1, 0, -50242, 2969, 0, 0, 39, '2968'),
	(377, 1, 0, -50242, 2970, 0, 0, 39, '2969'),
	(377, 1, 0, -50242, 2971, 0, 0, 39, '2970'),
	(377, 1, 0, -50242, 2972, 0, 0, 39, '2971'),
	(377, 1, 0, -50242, 2973, 0, 0, 39, '2972'),
	(377, 1, 0, -50242, 2974, 0, 0, 39, '2973'),
	(377, 1, 0, -50242, 2975, 0, 0, 39, '2974'),
	(377, 1, 0, -50242, 2976, 0, 0, 39, '2975'),
	(377, 1, 0, -50242, 2977, 0, 0, 39, '2976'),
	(377, 1, 0, -50242, 2978, 0, 0, 39, '2977'),
	(377, 1, 0, -50242, 2979, 0, 0, 39, '2978'),
	(377, 1, 0, -50242, 2980, 0, 0, 39, '2979'),
	(377, 1, 0, -50242, 2981, 0, 0, 39, '2980'),
	(377, 1, 0, -50242, 2982, 0, 0, 39, '2981'),
	(377, 1, 0, -50242, 2983, 0, 0, 39, '2982'),
	(377, 1, 0, -50242, 2984, 0, 0, 39, '2983'),
	(377, 1, 0, -50242, 2985, 0, 0, 39, '2984'),
	(377, 1, 0, -50242, 2986, 0, 0, 39, '2985'),
	(377, 1, 0, -50242, 2987, 0, 0, 39, '2986'),
	(377, 1, 0, -50242, 2988, 0, 0, 39, '2987'),
	(377, 1, 0, -50242, 2989, 0, 0, 39, '2988'),
	(377, 1, 0, -50242, 2990, 0, 0, 39, '2989'),
	(377, 1, 0, -50242, 2991, 0, 0, 39, '2990'),
	(377, 1, 0, -50242, 2992, 0, 0, 39, '2991'),
	(377, 1, 0, -50242, 2993, 0, 0, 39, '2992'),
	(377, 1, 0, -50242, 2994, 0, 0, 39, '2993'),
	(377, 1, 0, -50242, 2995, 0, 0, 39, '2994'),
	(377, 1, 0, -50242, 2996, 0, 0, 39, '2995'),
	(377, 1, 0, -50242, 2997, 0, 0, 39, '2996'),
	(377, 1, 0, -50242, 2998, 0, 0, 39, '2997'),
	(377, 1, 0, -50242, 2999, 0, 0, 39, '2998'),
	(377, 1, 0, -50242, 3000, 0, 0, 39, '2999'),
	(377, 1, 0, -50242, 3001, 0, 0, 39, '3000'),
	(377, 1, 0, -50242, 3002, 0, 0, 39, '3001'),
	(377, 1, 0, -50242, 3003, 0, 0, 39, '3002'),
	(377, 1, 0, -50242, 3004, 0, 0, 39, '3003'),
	(377, 1, 0, -50242, 3005, 0, 0, 39, '3004'),
	(377, 1, 0, -50242, 3006, 0, 0, 39, '3005'),
	(377, 1, 0, -50242, 3007, 0, 0, 39, '3006'),
	(377, 1, 0, -50242, 3008, 0, 0, 39, '3007'),
	(377, 1, 0, -50242, 3009, 0, 0, 39, '3008'),
	(377, 1, 0, -50242, 3010, 0, 0, 39, '3009'),
	(377, 1, 0, -50242, 3011, 0, 0, 39, '3010'),
	(377, 1, 0, -50242, 3012, 0, 0, 39, '3011'),
	(377, 1, 0, -50242, 3013, 0, 0, 39, '3012'),
	(377, 1, 0, -50242, 3014, 0, 0, 39, '3013'),
	(377, 1, 0, -50242, 3015, 0, 0, 39, '3014'),
	(377, 1, 0, -50242, 3016, 0, 0, 39, '3015'),
	(377, 1, 0, -50242, 3017, 0, 0, 39, '3016'),
	(377, 1, 0, -50242, 3018, 0, 0, 39, '3017'),
	(377, 1, 0, -50242, 3019, 0, 0, 39, '3018'),
	(377, 1, 0, -50242, 3020, 0, 0, 39, '3019'),
	(377, 1, 0, -50242, 3021, 0, 0, 39, '3020'),
	(377, 1, 0, -50242, 3022, 0, 0, 39, '3021'),
	(377, 1, 0, -50242, 3023, 0, 0, 39, '3022'),
	(377, 1, 0, -50242, 3024, 0, 0, 39, '3023'),
	(377, 1, 0, -50242, 3025, 0, 0, 39, '3024'),
	(377, 1, 0, -50242, 3026, 0, 0, 39, '3025'),
	(377, 1, 0, -50242, 3027, 0, 0, 39, '3026'),
	(377, 1, 0, -50242, 3028, 0, 0, 39, '3027'),
	(377, 1, 0, -50242, 3029, 0, 0, 39, '3028'),
	(377, 1, 0, -50242, 3030, 0, 0, 39, '3029'),
	(377, 1, 0, -50242, 3031, 0, 0, 39, '3030'),
	(377, 1, 0, -50242, 3032, 0, 0, 39, '3031'),
	(377, 1, 0, -50242, 3033, 0, 0, 39, '3032'),
	(377, 1, 0, -50242, 3034, 0, 0, 39, '3033'),
	(377, 1, 0, -50242, 3035, 0, 0, 39, '3034'),
	(377, 1, 0, -50242, 3036, 0, 0, 39, '3035'),
	(377, 1, 0, -50242, 3037, 0, 0, 39, '3036'),
	(377, 1, 0, -50242, 3038, 0, 0, 39, '3037'),
	(377, 1, 0, -50242, 3039, 0, 0, 39, '3038'),
	(377, 1, 0, -50242, 3040, 0, 0, 39, '3039'),
	(377, 1, 0, -50242, 3041, 0, 0, 39, '3040'),
	(377, 1, 0, -50242, 3042, 0, 0, 39, '3041'),
	(377, 1, 0, -50242, 3043, 0, 0, 39, '3042'),
	(377, 1, 0, -50242, 3044, 0, 0, 39, '3043'),
	(377, 1, 0, -50242, 3045, 0, 0, 39, '3044'),
	(377, 1, 0, -50242, 3046, 0, 0, 39, '3045'),
	(377, 1, 0, -50242, 3047, 0, 0, 39, '3046'),
	(377, 1, 0, -50242, 3048, 0, 0, 39, '3047'),
	(377, 1, 0, -50242, 3049, 0, 0, 39, '3048'),
	(377, 1, 0, -50242, 3050, 0, 0, 39, '3049'),
	(377, 1, 0, -50242, 3051, 0, 0, 39, '3050'),
	(377, 1, 0, -50242, 3052, 0, 0, 39, '3051'),
	(377, 1, 0, -50242, 3053, 0, 0, 39, '3052'),
	(377, 1, 0, -50242, 3054, 0, 0, 39, '3053'),
	(377, 1, 0, -50242, 3055, 0, 0, 39, '3054'),
	(377, 1, 0, -50242, 3056, 0, 0, 39, '3055'),
	(377, 1, 0, -50242, 3057, 0, 0, 39, '3056'),
	(377, 1, 0, -50242, 3058, 0, 0, 39, '3057'),
	(377, 1, 0, -50242, 3059, 0, 0, 39, '3058'),
	(377, 1, 0, -50242, 3060, 0, 0, 39, '3059'),
	(377, 1, 0, -50242, 3061, 0, 0, 39, '3060'),
	(377, 1, 0, -50242, 3062, 0, 0, 39, '3061'),
	(377, 1, 0, -50242, 3063, 0, 0, 39, '3062'),
	(377, 1, 0, -50242, 3064, 0, 0, 39, '3063'),
	(377, 1, 0, -50242, 3065, 0, 0, 39, '3064'),
	(377, 1, 0, -50242, 3066, 0, 0, 39, '3065'),
	(377, 1, 0, -50242, 3067, 0, 0, 39, '3066'),
	(377, 1, 0, -50242, 3068, 0, 0, 39, '3067'),
	(377, 1, 0, -50242, 3069, 0, 0, 39, '3068'),
	(377, 1, 0, -50242, 3070, 0, 0, 39, '3069'),
	(377, 1, 0, -50242, 3071, 0, 0, 39, '3070'),
	(377, 1, 0, -50242, 3072, 0, 0, 39, '3071'),
	(377, 1, 0, -50242, 3073, 0, 0, 39, '3072'),
	(377, 1, 0, -50242, 3074, 0, 0, 39, '3073'),
	(377, 1, 0, -50242, 3075, 0, 0, 39, '3074'),
	(377, 1, 0, -50242, 3076, 0, 0, 39, '3075'),
	(377, 1, 0, -50242, 3077, 0, 0, 39, '3076'),
	(377, 1, 0, -50242, 3078, 0, 0, 39, '3077'),
	(377, 1, 0, -50242, 3079, 0, 0, 39, '3078'),
	(377, 1, 0, -50242, 3080, 0, 0, 39, '3079'),
	(377, 1, 0, -50242, 3081, 0, 0, 39, '3080'),
	(377, 1, 0, -50242, 3082, 0, 0, 39, '3081'),
	(377, 1, 0, -50242, 3083, 0, 0, 39, '3082'),
	(377, 1, 0, -50242, 3084, 0, 0, 39, '3083'),
	(377, 1, 0, -50242, 3085, 0, 0, 39, '3084'),
	(377, 1, 0, -50242, 3086, 0, 0, 39, '3085'),
	(377, 1, 0, -50242, 3087, 0, 0, 39, '3086'),
	(377, 1, 0, -50242, 3088, 0, 0, 39, '3087'),
	(377, 1, 0, -50242, 3089, 0, 0, 39, '3088'),
	(377, 1, 0, -50242, 3090, 0, 0, 39, '3089'),
	(377, 1, 0, -50242, 3091, 0, 0, 39, '3090'),
	(377, 1, 0, -50242, 3092, 0, 0, 39, '3091'),
	(377, 1, 0, -50242, 3093, 0, 0, 39, '3092'),
	(377, 1, 0, -50242, 3094, 0, 0, 39, '3093'),
	(377, 1, 0, -50242, 3095, 0, 0, 39, '3094'),
	(377, 1, 0, -50242, 3096, 0, 0, 39, '3095'),
	(377, 1, 0, -50242, 3097, 0, 0, 39, '3096'),
	(377, 1, 0, -50242, 3098, 0, 0, 39, '3097'),
	(377, 1, 0, -50242, 3099, 0, 0, 39, '3098'),
	(377, 1, 0, -50242, 3100, 0, 0, 39, '3099'),
	(377, 1, 0, -50242, 3101, 0, 0, 39, '3100'),
	(377, 1, 0, -50242, 3102, 0, 0, 39, '3101'),
	(377, 1, 0, -50242, 3103, 0, 0, 39, '3102'),
	(377, 1, 0, -50242, 3104, 0, 0, 39, '3103'),
	(377, 1, 0, -50242, 3105, 0, 0, 39, '3104'),
	(377, 1, 0, -50242, 3106, 0, 0, 39, '3105'),
	(377, 1, 0, -50242, 3107, 0, 0, 39, '3106'),
	(377, 1, 0, -50242, 3108, 0, 0, 39, '3107'),
	(377, 1, 0, -50242, 3109, 0, 0, 39, '3108'),
	(377, 1, 0, -50242, 3110, 0, 0, 39, '3109'),
	(377, 1, 0, -50242, 3111, 0, 0, 39, '3110'),
	(377, 1, 0, -50242, 3112, 0, 0, 39, '3111'),
	(377, 1, 0, -50242, 3113, 0, 0, 39, '3112'),
	(377, 1, 0, -50242, 3114, 0, 0, 39, '3113'),
	(377, 1, 0, -50242, 3115, 0, 0, 39, '3114'),
	(377, 1, 0, -50242, 3116, 0, 0, 39, '3115'),
	(377, 1, 0, -50242, 3117, 0, 0, 39, '3116'),
	(377, 1, 0, -50242, 3118, 0, 0, 39, '3117'),
	(377, 1, 0, -50242, 3119, 0, 0, 39, '3118'),
	(377, 1, 0, -50242, 3120, 0, 0, 39, '3119'),
	(377, 1, 0, -50242, 3121, 0, 0, 39, '3120'),
	(377, 1, 0, -50242, 3122, 0, 0, 39, '3121'),
	(377, 1, 0, -50242, 3123, 0, 0, 39, '3122'),
	(377, 1, 0, -50242, 3124, 0, 0, 39, '3123'),
	(377, 1, 0, -50242, 3125, 0, 0, 39, '3124'),
	(377, 1, 0, -50242, 3126, 0, 0, 39, '3125'),
	(377, 1, 0, -50242, 3127, 0, 0, 39, '3126'),
	(377, 1, 0, -50242, 3128, 0, 0, 39, '3127'),
	(377, 1, 0, -50242, 3129, 0, 0, 39, '3128'),
	(377, 1, 0, -50242, 3130, 0, 0, 39, '3129'),
	(377, 1, 0, -50242, 3131, 0, 0, 39, '3130'),
	(377, 1, 0, -50242, 3132, 0, 0, 39, '3131'),
	(377, 1, 0, -50242, 3133, 0, 0, 39, '3132'),
	(377, 1, 0, -50242, 3134, 0, 0, 39, '3133'),
	(377, 1, 0, -50242, 3135, 0, 0, 39, '3134'),
	(377, 1, 0, -50242, 3136, 0, 0, 39, '3135'),
	(377, 1, 0, -50242, 3137, 0, 0, 39, '3136'),
	(377, 1, 0, -50242, 3138, 0, 0, 39, '3137'),
	(377, 1, 0, -50242, 3139, 0, 0, 39, '3138'),
	(377, 1, 0, -50242, 3140, 0, 0, 39, '3139'),
	(377, 1, 0, -50242, 3141, 0, 0, 39, '3140'),
	(377, 1, 0, -50242, 3142, 0, 0, 39, '3141'),
	(377, 1, 0, -50242, 3143, 0, 0, 39, '3142'),
	(377, 1, 0, -50242, 3144, 0, 0, 39, '3143'),
	(377, 1, 0, -50242, 3145, 0, 0, 39, '3144'),
	(377, 1, 0, -50242, 3146, 0, 0, 39, '3145'),
	(377, 1, 0, -50242, 3147, 0, 0, 39, '3146'),
	(377, 1, 0, -50242, 3148, 0, 0, 39, '3147'),
	(377, 1, 0, -50242, 3149, 0, 0, 39, '3148'),
	(377, 1, 0, -50242, 3150, 0, 0, 39, '3149'),
	(377, 1, 0, -50242, 3151, 0, 0, 39, '3150'),
	(377, 1, 0, -50242, 3152, 0, 0, 39, '3151'),
	(377, 1, 0, -50242, 3153, 0, 0, 39, '3152'),
	(377, 1, 0, -50242, 3154, 0, 0, 39, '3153'),
	(377, 1, 0, -50242, 3155, 0, 0, 39, '3154'),
	(377, 1, 0, -50242, 3156, 0, 0, 39, '3155'),
	(377, 1, 0, -50242, 3157, 0, 0, 39, '3156'),
	(377, 1, 0, -50242, 3158, 0, 0, 39, '3157'),
	(377, 1, 0, -50242, 3159, 0, 0, 39, '3158'),
	(377, 1, 0, -50242, 3160, 0, 0, 39, '3159'),
	(377, 1, 0, -50242, 3161, 0, 0, 39, '3160'),
	(377, 1, 0, -50242, 3162, 0, 0, 39, '3161'),
	(377, 1, 0, -50242, 3163, 0, 0, 39, '3162'),
	(377, 1, 0, -50242, 3164, 0, 0, 39, '3163'),
	(377, 1, 0, -50242, 3165, 0, 0, 39, '3164'),
	(377, 1, 0, -50242, 3166, 0, 0, 39, '3165'),
	(377, 1, 0, -50242, 3167, 0, 0, 39, '3166'),
	(377, 1, 0, -50242, 3168, 0, 0, 39, '3167'),
	(377, 1, 0, -50242, 3169, 0, 0, 39, '3168'),
	(377, 1, 0, -50242, 3170, 0, 0, 39, '3169'),
	(377, 1, 0, -50242, 3171, 0, 0, 39, '3170'),
	(377, 1, 0, -50242, 3172, 0, 0, 39, '3171'),
	(377, 1, 0, -50242, 3173, 0, 0, 39, '3172'),
	(377, 1, 0, -50242, 3174, 0, 0, 39, '3173'),
	(377, 1, 0, -50242, 3175, 0, 0, 39, '3174'),
	(377, 1, 0, -50242, 3176, 0, 0, 39, '3175'),
	(377, 1, 0, -50242, 3177, 0, 0, 39, '3176'),
	(377, 1, 0, -50242, 3178, 0, 0, 39, '3177'),
	(377, 1, 0, -50242, 3179, 0, 0, 39, '3178'),
	(377, 1, 0, -50242, 3180, 0, 0, 39, '3179'),
	(377, 1, 0, -50242, 3181, 0, 0, 39, '3180'),
	(377, 1, 0, -50242, 3182, 0, 0, 39, '3181'),
	(377, 1, 0, -50242, 3183, 0, 0, 39, '3182'),
	(377, 1, 0, -50242, 3184, 0, 0, 39, '3183'),
	(377, 1, 0, -50242, 3185, 0, 0, 39, '3184'),
	(377, 1, 0, -50242, 3186, 0, 0, 39, '3185'),
	(377, 1, 0, -50242, 3187, 0, 0, 39, '3186'),
	(377, 1, 0, -50242, 3188, 0, 0, 39, '3187'),
	(377, 1, 0, -50242, 3189, 0, 0, 39, '3188'),
	(377, 1, 0, -50242, 3190, 0, 0, 39, '3189'),
	(377, 1, 0, -50242, 3191, 0, 0, 39, '3190'),
	(377, 1, 0, -50242, 3192, 0, 0, 39, '3191'),
	(377, 1, 0, -50242, 3193, 0, 0, 39, '3192'),
	(377, 1, 0, -50242, 3194, 0, 0, 39, '3193'),
	(377, 1, 0, -50242, 3195, 0, 0, 39, '3194'),
	(377, 1, 0, -50242, 3196, 0, 0, 39, '3195'),
	(377, 1, 0, -50242, 3197, 0, 0, 39, '3196'),
	(377, 1, 0, -50242, 3198, 0, 0, 39, '3197'),
	(377, 1, 0, -50242, 3199, 0, 0, 39, '3198'),
	(377, 1, 0, -50242, 3200, 0, 0, 39, '3199'),
	(377, 1, 0, -50242, 3201, 0, 0, 39, '3200'),
	(377, 1, 0, -50242, 3202, 0, 0, 39, '3201'),
	(377, 1, 0, -50242, 3203, 0, 0, 39, '3202'),
	(377, 1, 0, -50242, 3204, 0, 0, 39, '3203'),
	(377, 1, 0, -50242, 3205, 0, 0, 39, '3204'),
	(377, 1, 0, -50242, 3206, 0, 0, 39, '3205'),
	(377, 1, 0, -50242, 3207, 0, 0, 39, '3206'),
	(377, 1, 0, -50242, 3208, 0, 0, 39, '3207'),
	(377, 1, 0, -50242, 3209, 0, 0, 39, '3208'),
	(377, 1, 0, -50242, 3210, 0, 0, 39, '3209'),
	(377, 1, 0, -50242, 3211, 0, 0, 39, '3210'),
	(377, 1, 0, -50242, 3212, 0, 0, 39, '3211'),
	(377, 1, 0, -50242, 3213, 0, 0, 39, '3212'),
	(377, 1, 0, -50242, 3214, 0, 0, 39, '3213'),
	(377, 1, 0, -50242, 3215, 0, 0, 39, '3214'),
	(377, 1, 0, -50242, 3216, 0, 0, 39, '3215'),
	(377, 1, 0, -50242, 3217, 0, 0, 39, '3216'),
	(377, 1, 0, -50242, 3218, 0, 0, 39, '3217'),
	(377, 1, 0, -50242, 3219, 0, 0, 39, '3218'),
	(377, 1, 0, -50242, 3220, 0, 0, 39, '3219'),
	(377, 1, 0, -50242, 3221, 0, 0, 39, '3220'),
	(377, 1, 0, -50242, 3222, 0, 0, 39, '3221'),
	(377, 1, 0, -50242, 3223, 0, 0, 39, '3222'),
	(377, 1, 0, -50242, 3224, 0, 0, 39, '3223'),
	(377, 1, 0, -50242, 3225, 0, 0, 39, '3224'),
	(377, 1, 0, -50242, 3226, 0, 0, 39, '3225'),
	(377, 1, 0, -50242, 3227, 0, 0, 39, '3226'),
	(377, 1, 0, -50242, 3228, 0, 0, 39, '3227'),
	(377, 1, 0, -50242, 3229, 0, 0, 39, '3228'),
	(377, 1, 0, -50242, 3230, 0, 0, 39, '3229'),
	(377, 1, 0, -50242, 3231, 0, 0, 39, '3230'),
	(377, 1, 0, -50242, 3232, 0, 0, 39, '3231'),
	(377, 1, 0, -50242, 3233, 0, 0, 39, '3232'),
	(377, 1, 0, -50242, 3234, 0, 0, 39, '3233'),
	(377, 1, 0, -50242, 3235, 0, 0, 39, '3234'),
	(377, 1, 0, -50242, 3236, 0, 0, 39, '3235'),
	(377, 1, 0, -50242, 3237, 0, 0, 39, '3236'),
	(377, 1, 0, -50242, 3238, 0, 0, 39, '3237'),
	(377, 1, 0, -50242, 3239, 0, 0, 39, '3238'),
	(377, 1, 0, -50242, 3240, 0, 0, 39, '3239'),
	(377, 1, 0, -50242, 3241, 0, 0, 39, '3240'),
	(377, 1, 0, -50242, 3242, 0, 0, 39, '3241'),
	(377, 1, 0, -50242, 3243, 0, 0, 39, '3242'),
	(377, 1, 0, -50242, 3244, 0, 0, 39, '3243'),
	(377, 1, 0, -50242, 3245, 0, 0, 39, '3244'),
	(377, 1, 0, -50242, 3246, 0, 0, 39, '3245'),
	(377, 1, 0, -50242, 3247, 0, 0, 39, '3246'),
	(377, 1, 0, -50242, 3248, 0, 0, 39, '3247'),
	(377, 1, 0, -50242, 3249, 0, 0, 39, '3248'),
	(377, 1, 0, -50242, 3250, 0, 0, 39, '3249'),
	(377, 1, 0, -50242, 3251, 0, 0, 39, '3250'),
	(377, 1, 0, -50242, 3252, 0, 0, 39, '3251'),
	(377, 1, 0, -50242, 3253, 0, 0, 39, '3252'),
	(377, 1, 0, -50242, 3254, 0, 0, 39, '3253'),
	(377, 1, 0, -50242, 3255, 0, 0, 39, '3254'),
	(377, 1, 0, -50242, 3256, 0, 0, 39, '3255'),
	(377, 1, 0, -50242, 3257, 0, 0, 39, '3256'),
	(377, 1, 0, -50242, 3258, 0, 0, 39, '3257'),
	(377, 1, 0, -50242, 3259, 0, 0, 39, '3258'),
	(377, 1, 0, -50242, 3260, 0, 0, 39, '3259'),
	(377, 1, 0, -50242, 3261, 0, 0, 39, '3260'),
	(377, 1, 0, -50242, 3262, 0, 0, 39, '3261'),
	(377, 1, 0, -50242, 3263, 0, 0, 39, '3262'),
	(377, 1, 0, -50242, 3264, 0, 0, 39, '3263'),
	(377, 1, 0, -50242, 3265, 0, 0, 39, '3264'),
	(377, 1, 0, -50242, 3266, 0, 0, 39, '3265'),
	(377, 1, 0, -50242, 3267, 0, 0, 39, '3266'),
	(377, 1, 0, -50242, 3268, 0, 0, 39, '3267'),
	(377, 1, 0, -50242, 3269, 0, 0, 39, '3268'),
	(377, 1, 0, -50242, 3270, 0, 0, 39, '3269'),
	(377, 1, 0, -50242, 3271, 0, 0, 39, '3270'),
	(377, 1, 0, -50242, 3272, 0, 0, 39, '3271'),
	(377, 1, 0, -50242, 3273, 0, 0, 39, '3272'),
	(377, 1, 0, -50242, 3274, 0, 0, 39, '3273'),
	(377, 1, 0, -50242, 3275, 0, 0, 39, '3274'),
	(377, 1, 0, -50242, 3276, 0, 0, 39, '3275'),
	(377, 1, 0, -50242, 3277, 0, 0, 39, '3276'),
	(377, 1, 0, -50242, 3278, 0, 0, 39, '3277'),
	(377, 1, 0, -50242, 3279, 0, 0, 39, '3278'),
	(377, 1, 0, -50242, 3280, 0, 0, 39, '3279'),
	(377, 1, 0, -50242, 3281, 0, 0, 39, '3280'),
	(377, 1, 0, -50242, 3282, 0, 0, 39, '3281'),
	(377, 1, 0, -50242, 3283, 0, 0, 39, '3282'),
	(377, 1, 0, -50242, 3284, 0, 0, 39, '3283'),
	(377, 1, 0, -50242, 3285, 0, 0, 39, '3284'),
	(377, 1, 0, -50242, 3286, 0, 0, 39, '3285'),
	(377, 1, 0, -50242, 3287, 0, 0, 39, '3286'),
	(377, 1, 0, -50242, 3288, 0, 0, 39, '3287'),
	(377, 1, 0, -50242, 3289, 0, 0, 39, '3288'),
	(377, 1, 0, -50242, 3290, 0, 0, 39, '3289'),
	(377, 1, 0, -50242, 3291, 0, 0, 39, '3290'),
	(377, 1, 0, -50242, 3292, 0, 0, 39, '3291'),
	(377, 1, 0, -50242, 3293, 0, 0, 39, '3292'),
	(377, 1, 0, -50242, 3294, 0, 0, 39, '3293'),
	(377, 1, 0, -50242, 3295, 0, 0, 39, '3294'),
	(377, 1, 0, -50242, 3296, 0, 0, 39, '3295'),
	(377, 1, 0, -50242, 3297, 0, 0, 39, '3296'),
	(377, 1, 0, -50242, 3298, 0, 0, 39, '3297'),
	(377, 1, 0, -50242, 3299, 0, 0, 39, '3298'),
	(377, 1, 0, -50242, 3300, 0, 0, 39, '3299'),
	(377, 1, 0, -50242, 3301, 0, 0, 39, '3300'),
	(377, 1, 0, -50242, 3302, 0, 0, 39, '3301'),
	(377, 1, 0, -50242, 3303, 0, 0, 39, '3302'),
	(377, 1, 0, -50242, 3304, 0, 0, 39, '3303'),
	(377, 1, 0, -50242, 3305, 0, 0, 39, '3304'),
	(377, 1, 0, -50242, 3306, 0, 0, 39, '3305'),
	(377, 1, 0, -50242, 3307, 0, 0, 39, '3306'),
	(377, 1, 0, -50242, 3308, 0, 0, 39, '3307'),
	(377, 1, 0, -50242, 3309, 0, 0, 39, '3308'),
	(377, 1, 0, -50242, 3310, 0, 0, 39, '3309'),
	(377, 1, 0, -50242, 3311, 0, 0, 39, '3310'),
	(377, 1, 0, -50242, 3312, 0, 0, 39, '3311'),
	(377, 1, 0, -50242, 3313, 0, 0, 39, '3312'),
	(377, 1, 0, -50242, 3314, 0, 0, 39, '3313'),
	(377, 1, 0, -50242, 3315, 0, 0, 39, '3314'),
	(377, 1, 0, -50242, 3316, 0, 0, 39, '3315'),
	(377, 1, 0, -50242, 3317, 0, 0, 39, '3316'),
	(377, 1, 0, -50242, 3318, 0, 0, 39, '3317'),
	(377, 1, 0, -50242, 3319, 0, 0, 39, '3318'),
	(377, 1, 0, -50242, 3320, 0, 0, 39, '3319'),
	(377, 1, 0, -50242, 3321, 0, 0, 39, '3320'),
	(377, 1, 0, -50242, 3322, 0, 0, 39, '3321'),
	(377, 1, 0, -50242, 3323, 0, 0, 39, '3322'),
	(377, 1, 0, -50242, 3324, 0, 0, 39, '3323'),
	(377, 1, 0, -50242, 3325, 0, 0, 39, '3324'),
	(377, 1, 0, -50242, 3326, 0, 0, 39, '3325'),
	(377, 1, 0, -50242, 3327, 0, 0, 39, '3326'),
	(377, 1, 0, -50242, 3328, 0, 0, 39, '3327'),
	(377, 1, 0, -50242, 3329, 0, 0, 39, '3328'),
	(377, 1, 0, -50242, 3330, 0, 0, 39, '3329'),
	(377, 1, 0, -50242, 3331, 0, 0, 39, '3330'),
	(377, 1, 0, -50242, 3332, 0, 0, 39, '3331'),
	(377, 1, 0, -50242, 3333, 0, 0, 39, '3332'),
	(377, 1, 0, -50242, 3334, 0, 0, 39, '3333'),
	(377, 1, 0, -50242, 3335, 0, 0, 39, '3334'),
	(377, 1, 0, -50242, 3336, 0, 0, 39, '3335'),
	(377, 1, 0, -50242, 3337, 0, 0, 39, '3336'),
	(377, 1, 0, -50242, 3338, 0, 0, 39, '3337'),
	(377, 1, 0, -50242, 3339, 0, 0, 39, '3338'),
	(377, 1, 0, -50242, 3340, 0, 0, 39, '3339'),
	(377, 1, 0, -50242, 3341, 0, 0, 39, '3340'),
	(377, 1, 0, -50242, 3342, 0, 0, 39, '3341'),
	(377, 1, 0, -50242, 3343, 0, 0, 39, '3342'),
	(377, 1, 0, -50242, 3344, 0, 0, 39, '3343'),
	(377, 1, 0, -50242, 3345, 0, 0, 39, '3344'),
	(377, 1, 0, -50242, 3346, 0, 0, 39, '3345'),
	(377, 1, 0, -50242, 3347, 0, 0, 39, '3346'),
	(377, 1, 0, -50242, 3348, 0, 0, 39, '3347'),
	(377, 1, 0, -50242, 3349, 0, 0, 39, '3348'),
	(377, 1, 0, -50242, 3350, 0, 0, 39, '3349'),
	(377, 1, 0, -50242, 3351, 0, 0, 39, '3350'),
	(377, 1, 0, -50242, 3352, 0, 0, 39, '3351'),
	(377, 1, 0, -50242, 3353, 0, 0, 39, '3352'),
	(377, 1, 0, -50242, 3354, 0, 0, 39, '3353'),
	(377, 1, 0, -50242, 3355, 0, 0, 39, '3354'),
	(377, 1, 0, -50242, 3356, 0, 0, 39, '3355'),
	(377, 1, 0, -50242, 3357, 0, 0, 39, '3356'),
	(377, 1, 0, -50242, 3358, 0, 0, 39, '3357'),
	(377, 1, 0, -50242, 3359, 0, 0, 39, '3358'),
	(377, 1, 0, -50242, 3360, 0, 0, 39, '3359'),
	(377, 1, 0, -50242, 3361, 0, 0, 39, '3360'),
	(377, 1, 0, -50242, 3362, 0, 0, 39, '3361'),
	(377, 1, 0, -50242, 3363, 0, 0, 39, '3362'),
	(377, 1, 0, -50242, 3364, 0, 0, 39, '3363'),
	(377, 1, 0, -50242, 3365, 0, 0, 39, '3364'),
	(377, 1, 0, -50242, 3366, 0, 0, 39, '3365'),
	(377, 1, 0, -50242, 3367, 0, 0, 39, '3366'),
	(377, 1, 0, -50242, 3368, 0, 0, 39, '3367'),
	(377, 1, 0, -50242, 3369, 0, 0, 39, '3368'),
	(377, 1, 0, -50242, 3370, 0, 0, 39, '3369'),
	(377, 1, 0, -50242, 3371, 0, 0, 39, '3370'),
	(377, 1, 0, -50242, 3372, 0, 0, 39, '3371'),
	(377, 1, 0, -50242, 3373, 0, 0, 39, '3372'),
	(377, 1, 0, -50242, 3374, 0, 0, 39, '3373'),
	(377, 1, 0, -50242, 3375, 0, 0, 39, '3374'),
	(377, 1, 0, -50242, 3376, 0, 0, 39, '3375'),
	(377, 1, 0, -50242, 3377, 0, 0, 39, '3376'),
	(377, 1, 0, -50242, 3378, 0, 0, 39, '3377'),
	(377, 1, 0, -50242, 3379, 0, 0, 39, '3378'),
	(377, 1, 0, -50242, 3380, 0, 0, 39, '3379'),
	(377, 1, 0, -50242, 3381, 0, 0, 39, '3380'),
	(377, 1, 0, -50242, 3382, 0, 0, 39, '3381'),
	(377, 1, 0, -50242, 3383, 0, 0, 39, '3382'),
	(377, 1, 0, -50242, 3384, 0, 0, 39, '3383'),
	(377, 1, 0, -50242, 3385, 0, 0, 39, '3384'),
	(377, 1, 0, -50242, 3386, 0, 0, 39, '3385'),
	(377, 1, 0, -50242, 3387, 0, 0, 39, '3386'),
	(377, 1, 0, -50242, 3388, 0, 0, 39, '3387'),
	(377, 1, 0, -50242, 3389, 0, 0, 39, '3388'),
	(377, 1, 0, -50242, 3390, 0, 0, 39, '3389'),
	(377, 1, 0, -50242, 3391, 0, 0, 39, '3390'),
	(377, 1, 0, -50242, 3392, 0, 0, 39, '3391'),
	(377, 1, 0, -50242, 3393, 0, 0, 39, '3392'),
	(377, 1, 0, -50242, 3394, 0, 0, 39, '3393'),
	(377, 1, 0, -50242, 3395, 0, 0, 39, '3394'),
	(377, 1, 0, -50242, 3396, 0, 0, 39, '3395'),
	(377, 1, 0, -50242, 3397, 0, 0, 39, '3396'),
	(377, 1, 0, -50242, 3398, 0, 0, 39, '3397'),
	(377, 1, 0, -50242, 3399, 0, 0, 39, '3398'),
	(377, 1, 0, -50242, 3400, 0, 0, 39, '3399'),
	(377, 1, 0, -50242, 3401, 0, 0, 39, '3400'),
	(377, 1, 0, -50242, 3402, 0, 0, 39, '3401'),
	(377, 1, 0, -50242, 3403, 0, 0, 39, '3402'),
	(377, 1, 0, -50242, 3404, 0, 0, 39, '3403'),
	(377, 1, 0, -50242, 3405, 0, 0, 39, '3404'),
	(377, 1, 0, -50242, 3406, 0, 0, 39, '3405'),
	(377, 1, 0, -50242, 3407, 0, 0, 39, '3406'),
	(377, 1, 0, -50242, 3408, 0, 0, 39, '3407'),
	(377, 1, 0, -50242, 3409, 0, 0, 39, '3408'),
	(377, 1, 0, -50242, 3410, 0, 0, 39, '3409'),
	(377, 1, 0, -50242, 3411, 0, 0, 39, '3410'),
	(377, 1, 0, -50242, 3412, 0, 0, 39, '3411'),
	(377, 1, 0, -50242, 3413, 0, 0, 39, '3412'),
	(377, 1, 0, -50242, 3414, 0, 0, 39, '3413'),
	(377, 1, 0, -50242, 3415, 0, 0, 39, '3414'),
	(377, 1, 0, -50242, 3416, 0, 0, 39, '3415'),
	(377, 1, 0, -50242, 3417, 0, 0, 39, '3416'),
	(377, 1, 0, -50242, 3418, 0, 0, 39, '3417'),
	(377, 1, 0, -50242, 3419, 0, 0, 39, '3418'),
	(377, 1, 0, -50242, 3420, 0, 0, 39, '3419'),
	(377, 1, 0, -50242, 3421, 0, 0, 39, '3420'),
	(377, 1, 0, -50242, 3422, 0, 0, 39, '3421'),
	(377, 1, 0, -50242, 3423, 0, 0, 39, '3422'),
	(377, 1, 0, -50242, 3424, 0, 0, 39, '3423'),
	(377, 1, 0, -50242, 3425, 0, 0, 39, '3424'),
	(377, 1, 0, -50242, 3426, 0, 0, 39, '3425'),
	(377, 1, 0, -50242, 3427, 0, 0, 39, '3426'),
	(377, 1, 0, -50242, 3428, 0, 0, 39, '3427'),
	(377, 1, 0, -50242, 3429, 0, 0, 39, '3428'),
	(377, 1, 0, -50242, 3430, 0, 0, 39, '3429'),
	(377, 1, 0, -50242, 3431, 0, 0, 39, '3430'),
	(377, 1, 0, -50242, 3432, 0, 0, 39, '3431'),
	(377, 1, 0, -50242, 3433, 0, 0, 39, '3432'),
	(377, 1, 0, -50242, 3434, 0, 0, 39, '3433'),
	(377, 1, 0, -50242, 3435, 0, 0, 39, '3434'),
	(377, 1, 0, -50242, 3436, 0, 0, 39, '3435'),
	(377, 1, 0, -50242, 3437, 0, 0, 39, '3436'),
	(377, 1, 0, -50242, 3438, 0, 0, 39, '3437'),
	(377, 1, 0, -50242, 3439, 0, 0, 39, '3438'),
	(377, 1, 0, -50242, 3440, 0, 0, 39, '3439'),
	(377, 1, 0, -50242, 3441, 0, 0, 39, '3440'),
	(377, 1, 0, -50242, 3442, 0, 0, 39, '3441'),
	(377, 1, 0, -50242, 3443, 0, 0, 39, '3442'),
	(377, 1, 0, -50242, 3444, 0, 0, 39, '3443'),
	(377, 1, 0, -50242, 3445, 0, 0, 39, '3444'),
	(377, 1, 0, -50242, 3446, 0, 0, 39, '3445'),
	(377, 1, 0, -50242, 3447, 0, 0, 39, '3446'),
	(377, 1, 0, -50242, 3448, 0, 0, 39, '3447'),
	(377, 1, 0, -50242, 3449, 0, 0, 39, '3448'),
	(377, 1, 0, -50242, 3450, 0, 0, 39, '3449'),
	(377, 1, 0, -50242, 3451, 0, 0, 39, '3450'),
	(377, 1, 0, -50242, 3452, 0, 0, 39, '3451'),
	(377, 1, 0, -50242, 3453, 0, 0, 39, '3452'),
	(377, 1, 0, -50242, 3454, 0, 0, 39, '3453'),
	(377, 1, 0, -50242, 3455, 0, 0, 39, '3454'),
	(377, 1, 0, -50242, 3456, 0, 0, 39, '3455'),
	(377, 1, 0, -50242, 3457, 0, 0, 39, '3456'),
	(377, 1, 0, -50242, 3458, 0, 0, 39, '3457'),
	(377, 1, 0, -50242, 3459, 0, 0, 39, '3458'),
	(377, 1, 0, -50242, 3460, 0, 0, 39, '3459'),
	(377, 1, 0, -50242, 3461, 0, 0, 39, '3460'),
	(377, 1, 0, -50242, 3462, 0, 0, 39, '3461'),
	(377, 1, 0, -50242, 3463, 0, 0, 39, '3462'),
	(377, 1, 0, -50242, 3464, 0, 0, 39, '3463'),
	(377, 1, 0, -50242, 3465, 0, 0, 39, '3464'),
	(377, 1, 0, -50242, 3466, 0, 0, 39, '3465'),
	(377, 1, 0, -50242, 3467, 0, 0, 39, '3466'),
	(377, 1, 0, -50242, 3468, 0, 0, 39, '3467'),
	(377, 1, 0, -50242, 3469, 0, 0, 39, '3468'),
	(377, 1, 0, -50242, 3470, 0, 0, 39, '3469'),
	(377, 1, 0, -50242, 3471, 0, 0, 39, '3470'),
	(377, 1, 0, -50242, 3472, 0, 0, 39, '3471'),
	(377, 1, 0, -50242, 3473, 0, 0, 39, '3472'),
	(377, 1, 0, -50242, 3474, 0, 0, 39, '3473'),
	(377, 1, 0, -50242, 3475, 0, 0, 39, '3474'),
	(377, 1, 0, -50242, 3476, 0, 0, 39, '3475'),
	(377, 1, 0, -50242, 3477, 0, 0, 39, '3476'),
	(377, 1, 0, -50242, 3478, 0, 0, 39, '3477'),
	(377, 1, 0, -50242, 3479, 0, 0, 39, '3478'),
	(377, 1, 0, -50242, 3480, 0, 0, 39, '3479'),
	(377, 1, 0, -50242, 3481, 0, 0, 39, '3480'),
	(377, 1, 0, -50242, 3482, 0, 0, 39, '3481'),
	(377, 1, 0, -50242, 3483, 0, 0, 39, '3482'),
	(377, 1, 0, -50242, 3484, 0, 0, 39, '3483'),
	(377, 1, 0, -50242, 3485, 0, 0, 39, '3484'),
	(377, 1, 0, -50242, 3486, 0, 0, 39, '3485'),
	(377, 1, 0, -50242, 3487, 0, 0, 39, '3486'),
	(377, 1, 0, -50242, 3488, 0, 0, 39, '3487'),
	(377, 1, 0, -50242, 3489, 0, 0, 39, '3488'),
	(377, 1, 0, -50242, 3490, 0, 0, 39, '3489'),
	(377, 1, 0, -50242, 3491, 0, 0, 39, '3490'),
	(377, 1, 0, -50242, 3492, 0, 0, 39, '3491'),
	(377, 1, 0, -50242, 3493, 0, 0, 39, '3492'),
	(377, 1, 0, -50242, 3494, 0, 0, 39, '3493'),
	(377, 1, 0, -50242, 3495, 0, 0, 39, '3494'),
	(377, 1, 0, -50242, 3496, 0, 0, 39, '3495'),
	(377, 1, 0, -50242, 3497, 0, 0, 39, '3496'),
	(377, 1, 0, -50242, 3498, 0, 0, 39, '3497'),
	(377, 1, 0, -50242, 3499, 0, 0, 39, '3498'),
	(377, 1, 0, -50242, 3500, 0, 0, 39, '3499'),
	(377, 1, 0, -50242, 3501, 0, 0, 39, '3500'),
	(377, 1, 0, -50242, 3502, 0, 0, 39, '3501'),
	(377, 1, 0, -50242, 3503, 0, 0, 39, '3502'),
	(377, 1, 0, -50242, 3504, 0, 0, 39, '3503'),
	(377, 1, 0, -50242, 3505, 0, 0, 39, '3504'),
	(377, 1, 0, -50242, 3506, 0, 0, 39, '3505'),
	(377, 1, 0, -50242, 3507, 0, 0, 39, '3506'),
	(377, 1, 0, -50242, 3508, 0, 0, 39, '3507'),
	(377, 1, 0, -50242, 3509, 0, 0, 39, '3508'),
	(377, 1, 0, -50242, 3510, 0, 0, 39, '3509'),
	(377, 1, 0, -50242, 3511, 0, 0, 39, '3510'),
	(377, 1, 0, -50242, 3512, 0, 0, 39, '3511'),
	(377, 1, 0, -50242, 3513, 0, 0, 39, '3512'),
	(377, 1, 0, -50242, 3514, 0, 0, 39, '3513'),
	(377, 1, 0, -50242, 3515, 0, 0, 39, '3514'),
	(377, 1, 0, -50242, 3516, 0, 0, 39, '3515'),
	(377, 1, 0, -50242, 3517, 0, 0, 39, '3516'),
	(377, 1, 0, -50242, 3518, 0, 0, 39, '3517'),
	(377, 1, 0, -50242, 3519, 0, 0, 39, '3518'),
	(377, 1, 0, -50242, 3520, 0, 0, 39, '3519'),
	(377, 1, 0, -50242, 3521, 0, 0, 39, '3520'),
	(377, 1, 0, -50242, 3522, 0, 0, 39, '3521'),
	(377, 1, 0, -50242, 3523, 0, 0, 39, '3522'),
	(377, 1, 0, -50242, 3524, 0, 0, 39, '3523'),
	(377, 1, 0, -50242, 3525, 0, 0, 39, '3524'),
	(377, 1, 0, -50242, 3526, 0, 0, 39, '3525'),
	(377, 1, 0, -50242, 3527, 0, 0, 39, '3526'),
	(377, 1, 0, -50242, 3528, 0, 0, 39, '3527'),
	(377, 1, 0, -50242, 3529, 0, 0, 39, '3528'),
	(377, 1, 0, -50242, 3530, 0, 0, 39, '3529'),
	(377, 1, 0, -50242, 3531, 0, 0, 39, '3530'),
	(377, 1, 0, -50242, 3532, 0, 0, 39, '3531'),
	(377, 1, 0, -50242, 3533, 0, 0, 39, '3532'),
	(377, 1, 0, -50242, 3534, 0, 0, 39, '3533'),
	(377, 1, 0, -50242, 3535, 0, 0, 39, '3534'),
	(377, 1, 0, -50242, 3536, 0, 0, 39, '3535'),
	(377, 1, 0, -50242, 3537, 0, 0, 39, '3536'),
	(377, 1, 0, -50242, 3538, 0, 0, 39, '3537'),
	(377, 1, 0, -50242, 3539, 0, 0, 39, '3538'),
	(377, 1, 0, -50242, 3540, 0, 0, 39, '3539'),
	(377, 1, 0, -50242, 3541, 0, 0, 39, '3540'),
	(377, 1, 0, -50242, 3542, 0, 0, 39, '3541'),
	(377, 1, 0, -50242, 3543, 0, 0, 39, '3542'),
	(377, 1, 0, -50242, 3544, 0, 0, 39, '3543'),
	(377, 1, 0, -50242, 3545, 0, 0, 39, '3544'),
	(377, 1, 0, -50242, 3546, 0, 0, 39, '3545'),
	(377, 1, 0, -50242, 3547, 0, 0, 39, '3546'),
	(377, 1, 0, -50242, 3548, 0, 0, 39, '3547'),
	(377, 1, 0, -50242, 3549, 0, 0, 39, '3548'),
	(377, 1, 0, -50242, 3550, 0, 0, 39, '3549'),
	(377, 1, 0, -50242, 3551, 0, 0, 39, '3550'),
	(377, 1, 0, -50242, 3552, 0, 0, 39, '3551'),
	(377, 1, 0, -50242, 3553, 0, 0, 39, '3552'),
	(377, 1, 0, -50242, 3554, 0, 0, 39, '3553'),
	(377, 1, 0, -50242, 3555, 0, 0, 39, '3554'),
	(377, 1, 0, -50242, 3556, 0, 0, 39, '3555'),
	(377, 1, 0, -50242, 3557, 0, 0, 39, '3556'),
	(377, 1, 0, -50242, 3558, 0, 0, 39, '3557'),
	(377, 1, 0, -50242, 3559, 0, 0, 39, '3558'),
	(377, 1, 0, -50242, 3560, 0, 0, 39, '3559'),
	(377, 1, 0, -50242, 3561, 0, 0, 39, '3560'),
	(377, 1, 0, -50242, 3562, 0, 0, 39, '3561'),
	(377, 1, 0, -50242, 3563, 0, 0, 39, '3562'),
	(377, 1, 0, -50242, 3564, 0, 0, 39, '3563'),
	(377, 1, 0, -50242, 3565, 0, 0, 39, '3564'),
	(377, 1, 0, -50242, 3566, 0, 0, 39, '3565'),
	(377, 1, 0, -50242, 3567, 0, 0, 39, '3566'),
	(377, 1, 0, -50242, 3568, 0, 0, 39, '3567'),
	(377, 1, 0, -50242, 3569, 0, 0, 39, '3568'),
	(377, 1, 0, -50242, 3570, 0, 0, 39, '3569'),
	(377, 1, 0, -50242, 3571, 0, 0, 39, '3570'),
	(377, 1, 0, -50242, 3572, 0, 0, 39, '3571'),
	(377, 1, 0, -50242, 3573, 0, 0, 39, '3572'),
	(377, 1, 0, -50242, 3574, 0, 0, 39, '3573'),
	(377, 1, 0, -50242, 3575, 0, 0, 39, '3574'),
	(377, 1, 0, -50242, 3576, 0, 0, 39, '3575'),
	(377, 1, 0, -50242, 3577, 0, 0, 39, '3576'),
	(377, 1, 0, -50242, 3578, 0, 0, 39, '3577'),
	(377, 1, 0, -50242, 3579, 0, 0, 39, '3578'),
	(377, 1, 0, -50242, 3580, 0, 0, 39, '3579'),
	(377, 1, 0, -50242, 3581, 0, 0, 39, '3580'),
	(377, 1, 0, -50242, 3582, 0, 0, 39, '3581'),
	(377, 1, 0, -50242, 3583, 0, 0, 39, '3582'),
	(377, 1, 0, -50242, 3584, 0, 0, 39, '3583'),
	(377, 1, 0, -50242, 3585, 0, 0, 39, '3584'),
	(377, 1, 0, -50242, 3586, 0, 0, 39, '3585'),
	(377, 1, 0, -50242, 3587, 0, 0, 39, '3586'),
	(377, 1, 0, -50242, 3588, 0, 0, 39, '3587'),
	(377, 1, 0, -50242, 3589, 0, 0, 39, '3588'),
	(377, 1, 0, -50242, 3590, 0, 0, 39, '3589'),
	(377, 1, 0, -50242, 3591, 0, 0, 39, '3590'),
	(377, 1, 0, -50242, 3592, 0, 0, 39, '3591'),
	(377, 1, 0, -50242, 3593, 0, 0, 39, '3592'),
	(377, 1, 0, -50242, 3594, 0, 0, 39, '3593'),
	(377, 1, 0, -50242, 3595, 0, 0, 39, '3594'),
	(377, 1, 0, -50242, 3596, 0, 0, 39, '3595'),
	(377, 1, 0, -50242, 3597, 0, 0, 39, '3596'),
	(377, 1, 0, -50242, 3598, 0, 0, 39, '3597'),
	(377, 1, 0, -50242, 3599, 0, 0, 39, '3598'),
	(377, 1, 0, -50242, 3600, 0, 0, 39, '3599'),
	(377, 1, 0, -50242, 3601, 0, 0, 39, '3600'),
	(377, 1, 0, -50242, 3602, 0, 0, 39, '3601'),
	(377, 1, 0, -50242, 3603, 0, 0, 39, '3602'),
	(377, 1, 0, -50242, 3604, 0, 0, 39, '3603'),
	(377, 1, 0, -50242, 3605, 0, 0, 39, '3604'),
	(377, 1, 0, -50242, 3606, 0, 0, 39, '3605'),
	(377, 1, 0, -50242, 3607, 0, 0, 39, '3606'),
	(377, 1, 0, -50242, 3608, 0, 0, 39, '3607'),
	(377, 1, 0, -50242, 3609, 0, 0, 39, '3608'),
	(377, 1, 0, -50242, 3610, 0, 0, 39, '3609'),
	(377, 1, 0, -50242, 3611, 0, 0, 39, '3610'),
	(377, 1, 0, -50242, 3612, 0, 0, 39, '3611'),
	(377, 1, 0, -50242, 3613, 0, 0, 39, '3612'),
	(377, 1, 0, -50242, 3614, 0, 0, 39, '3613'),
	(377, 1, 0, -50242, 3615, 0, 0, 39, '3614'),
	(377, 1, 0, -50242, 3616, 0, 0, 39, '3615'),
	(377, 1, 0, -50242, 3617, 0, 0, 39, '3616'),
	(377, 1, 0, -50242, 3618, 0, 0, 39, '3617'),
	(377, 1, 0, -50242, 3619, 0, 0, 39, '3618'),
	(377, 1, 0, -50242, 3620, 0, 0, 39, '3619'),
	(377, 1, 0, -50242, 3621, 0, 0, 39, '3620'),
	(377, 1, 0, -50242, 3622, 0, 0, 39, '3621'),
	(377, 1, 0, -50242, 3623, 0, 0, 39, '3622'),
	(377, 1, 0, -50242, 3624, 0, 0, 39, '3623'),
	(377, 1, 0, -50242, 3625, 0, 0, 39, '3624'),
	(377, 1, 0, -50242, 3626, 0, 0, 39, '3625'),
	(377, 1, 0, -50242, 3627, 0, 0, 39, '3626'),
	(377, 1, 0, -50242, 3628, 0, 0, 39, '3627'),
	(377, 1, 0, -50242, 3629, 0, 0, 39, '3628'),
	(377, 1, 0, -50242, 3630, 0, 0, 39, '3629'),
	(377, 1, 0, -50242, 3631, 0, 0, 39, '3630'),
	(377, 1, 0, -50242, 3632, 0, 0, 39, '3631'),
	(377, 1, 0, -50242, 3633, 0, 0, 39, '3632'),
	(377, 1, 0, -50242, 3634, 0, 0, 39, '3633'),
	(377, 1, 0, -50242, 3635, 0, 0, 39, '3634'),
	(377, 1, 0, -50242, 3636, 0, 0, 39, '3635'),
	(377, 1, 0, -50242, 3637, 0, 0, 39, '3636'),
	(377, 1, 0, -50242, 3638, 0, 0, 39, '3637'),
	(377, 1, 0, -50242, 3639, 0, 0, 39, '3638'),
	(377, 1, 0, -50242, 3640, 0, 0, 39, '3639'),
	(377, 1, 0, -50242, 3641, 0, 0, 39, '3640'),
	(377, 1, 0, -50242, 3642, 0, 0, 39, '3641'),
	(377, 1, 0, -50242, 3643, 0, 0, 39, '3642'),
	(377, 1, 0, -50242, 3644, 0, 0, 39, '3643'),
	(377, 1, 0, -50242, 3645, 0, 0, 39, '3644'),
	(377, 1, 0, -50242, 3646, 0, 0, 39, '3645'),
	(377, 1, 0, -50242, 3647, 0, 0, 39, '3646'),
	(377, 1, 0, -50242, 3648, 0, 0, 39, '3647'),
	(377, 1, 0, -50242, 3649, 0, 0, 39, '3648'),
	(377, 1, 0, -50242, 3650, 0, 0, 39, '3649'),
	(377, 1, 0, -50242, 3651, 0, 0, 39, '3650'),
	(377, 1, 0, -50242, 3652, 0, 0, 39, '3651'),
	(377, 1, 0, -50242, 3653, 0, 0, 39, '3652'),
	(377, 1, 0, -50242, 3654, 0, 0, 39, '3653'),
	(377, 1, 0, -50242, 3655, 0, 0, 39, '3654'),
	(377, 1, 0, -50242, 3656, 0, 0, 39, '3655'),
	(377, 1, 0, -50242, 3657, 0, 0, 39, '3656'),
	(377, 1, 0, -50242, 3658, 0, 0, 39, '3657'),
	(377, 1, 0, -50242, 3659, 0, 0, 39, '3658'),
	(377, 1, 0, -50242, 3660, 0, 0, 39, '3659'),
	(377, 1, 0, -50242, 3661, 0, 0, 39, '3660'),
	(377, 1, 0, -50242, 3662, 0, 0, 39, '3661'),
	(377, 1, 0, -50242, 3663, 0, 0, 39, '3662'),
	(377, 1, 0, -50242, 3664, 0, 0, 39, '3663'),
	(377, 1, 0, -50242, 3665, 0, 0, 39, '3664'),
	(377, 1, 0, -50242, 3666, 0, 0, 39, '3665'),
	(377, 1, 0, -50242, 3667, 0, 0, 39, '3666'),
	(377, 1, 0, -50242, 3668, 0, 0, 39, '3667'),
	(377, 1, 0, -50242, 3669, 0, 0, 39, '3668'),
	(377, 1, 0, -50242, 3670, 0, 0, 39, '3669'),
	(377, 1, 0, -50242, 3671, 0, 0, 39, '3670'),
	(377, 1, 0, -50242, 3672, 0, 0, 39, '3671'),
	(377, 1, 0, -50242, 3673, 0, 0, 39, '3672'),
	(377, 1, 0, -50242, 3674, 0, 0, 39, '3673'),
	(377, 1, 0, -50242, 3675, 0, 0, 39, '3674'),
	(377, 1, 0, -50242, 3676, 0, 0, 39, '3675'),
	(377, 1, 0, -50242, 3677, 0, 0, 39, '3676'),
	(377, 1, 0, -50242, 3678, 0, 0, 39, '3677'),
	(377, 1, 0, -50242, 3679, 0, 0, 39, '3678'),
	(377, 1, 0, -50242, 3680, 0, 0, 39, '3679'),
	(377, 1, 0, -50242, 3681, 0, 0, 39, '3680'),
	(377, 1, 0, -50242, 3682, 0, 0, 39, '3681'),
	(377, 1, 0, -50242, 3683, 0, 0, 39, '3682'),
	(377, 1, 0, -50242, 3684, 0, 0, 39, '3683'),
	(377, 1, 0, -50242, 3685, 0, 0, 39, '3684'),
	(377, 1, 0, -50242, 3686, 0, 0, 39, '3685'),
	(377, 1, 0, -50242, 3687, 0, 0, 39, '3686'),
	(377, 1, 0, -50242, 3688, 0, 0, 39, '3687'),
	(377, 1, 0, -50242, 3689, 0, 0, 39, '3688'),
	(377, 1, 0, -50242, 3690, 0, 0, 39, '3689'),
	(377, 1, 0, -50242, 3691, 0, 0, 39, '3690'),
	(377, 1, 0, -50242, 3692, 0, 0, 39, '3691'),
	(377, 1, 0, -50242, 3693, 0, 0, 39, '3692'),
	(377, 1, 0, -50242, 3694, 0, 0, 39, '3693'),
	(377, 1, 0, -50242, 3695, 0, 0, 39, '3694'),
	(377, 1, 0, -50242, 3696, 0, 0, 39, '3695'),
	(377, 1, 0, -50242, 3697, 0, 0, 39, '3696'),
	(377, 1, 0, -50242, 3698, 0, 0, 39, '3697'),
	(377, 1, 0, -50242, 3699, 0, 0, 39, '3698'),
	(377, 1, 0, -50242, 3700, 0, 0, 39, '3699'),
	(377, 1, 0, -50242, 3701, 0, 0, 39, '3700'),
	(377, 1, 0, -50242, 3702, 0, 0, 39, '3701'),
	(377, 1, 0, -50242, 3703, 0, 0, 39, '3702'),
	(377, 1, 0, -50242, 3704, 0, 0, 39, '3703'),
	(377, 1, 0, -50242, 3705, 0, 0, 39, '3704'),
	(377, 1, 0, -50242, 3706, 0, 0, 39, '3705'),
	(377, 1, 0, -50242, 3707, 0, 0, 39, '3706'),
	(377, 1, 0, -50242, 3708, 0, 0, 39, '3707'),
	(377, 1, 0, -50242, 3709, 0, 0, 39, '3708'),
	(377, 1, 0, -50242, 3710, 0, 0, 39, '3709'),
	(377, 1, 0, -50242, 3711, 0, 0, 39, '3710'),
	(377, 1, 0, -50242, 3712, 0, 0, 39, '3711'),
	(377, 1, 0, -50242, 3713, 0, 0, 39, '3712'),
	(377, 1, 0, -50242, 3714, 0, 0, 39, '3713'),
	(377, 1, 0, -50242, 3715, 0, 0, 39, '3714'),
	(377, 1, 0, -50242, 3716, 0, 0, 39, '3715'),
	(377, 1, 0, -50242, 3717, 0, 0, 39, '3716'),
	(377, 1, 0, -50242, 3718, 0, 0, 39, '3717'),
	(377, 1, 0, -50242, 3719, 0, 0, 39, '3718'),
	(377, 1, 0, -50242, 3720, 0, 0, 39, '3719'),
	(377, 1, 0, -50242, 3721, 0, 0, 39, '3720'),
	(377, 1, 0, -50242, 3722, 0, 0, 39, '3721'),
	(377, 1, 0, -50242, 3723, 0, 0, 39, '3722'),
	(377, 1, 0, -50242, 3724, 0, 0, 39, '3723'),
	(377, 1, 0, -50242, 3725, 0, 0, 39, '3724'),
	(377, 1, 0, -50242, 3726, 0, 0, 39, '3725'),
	(377, 1, 0, -50242, 3727, 0, 0, 39, '3726'),
	(377, 1, 0, -50242, 3728, 0, 0, 39, '3727'),
	(377, 1, 0, -50242, 3729, 0, 0, 39, '3728'),
	(377, 1, 0, -50242, 3730, 0, 0, 39, '3729'),
	(377, 1, 0, -50242, 3731, 0, 0, 39, '3730'),
	(377, 1, 0, -50242, 3732, 0, 0, 39, '3731'),
	(377, 1, 0, -50242, 3733, 0, 0, 39, '3732'),
	(377, 1, 0, -50242, 3734, 0, 0, 39, '3733'),
	(377, 1, 0, -50242, 3735, 0, 0, 39, '3734'),
	(377, 1, 0, -50242, 3736, 0, 0, 39, '3735'),
	(377, 1, 0, -50242, 3737, 0, 0, 39, '3736'),
	(377, 1, 0, -50242, 3738, 0, 0, 39, '3737'),
	(377, 1, 0, -50242, 3739, 0, 0, 39, '3738'),
	(377, 1, 0, -50242, 3740, 0, 0, 39, '3739'),
	(377, 1, 0, -50242, 3741, 0, 0, 39, '3740'),
	(377, 1, 0, -50242, 3742, 0, 0, 39, '3741'),
	(377, 1, 0, -50242, 3743, 0, 0, 39, '3742'),
	(377, 1, 0, -50242, 3744, 0, 0, 39, '3743'),
	(377, 1, 0, -50242, 3745, 0, 0, 39, '3744'),
	(377, 1, 0, -50242, 3746, 0, 0, 39, '3745'),
	(377, 1, 0, -50242, 3747, 0, 0, 39, '3746'),
	(377, 1, 0, -50242, 3748, 0, 0, 39, '3747'),
	(377, 1, 0, -50242, 3749, 0, 0, 39, '3748'),
	(377, 1, 0, -50242, 3750, 0, 0, 39, '3749'),
	(377, 1, 0, -50242, 3751, 0, 0, 39, '3750'),
	(377, 1, 0, -50242, 3752, 0, 0, 39, '3751'),
	(377, 1, 0, -50242, 3753, 0, 0, 39, '3752'),
	(377, 1, 0, -50242, 3754, 0, 0, 39, '3753'),
	(377, 1, 0, -50242, 3755, 0, 0, 39, '3754'),
	(377, 1, 0, -50242, 3756, 0, 0, 39, '3755'),
	(377, 1, 0, -50242, 3757, 0, 0, 39, '3756'),
	(377, 1, 0, -50242, 3758, 0, 0, 39, '3757'),
	(377, 1, 0, -50242, 3759, 0, 0, 39, '3758'),
	(377, 1, 0, -50242, 3760, 0, 0, 39, '3759'),
	(377, 1, 0, -50242, 3761, 0, 0, 39, '3760'),
	(377, 1, 0, -50242, 3762, 0, 0, 39, '3761'),
	(377, 1, 0, -50242, 3763, 0, 0, 39, '3762'),
	(377, 1, 0, -50242, 3764, 0, 0, 39, '3763'),
	(377, 1, 0, -50242, 3765, 0, 0, 39, '3764'),
	(377, 1, 0, -50242, 3766, 0, 0, 39, '3765'),
	(377, 1, 0, -50242, 3767, 0, 0, 39, '3766'),
	(377, 1, 0, -50242, 3768, 0, 0, 39, '3767'),
	(377, 1, 0, -50242, 3769, 0, 0, 39, '3768'),
	(377, 1, 0, -50242, 3770, 0, 0, 39, '3769'),
	(377, 1, 0, -50242, 3771, 0, 0, 39, '3770'),
	(377, 1, 0, -50242, 3772, 0, 0, 39, '3771'),
	(377, 1, 0, -50242, 3773, 0, 0, 39, '3772'),
	(377, 1, 0, -50242, 3774, 0, 0, 39, '3773'),
	(377, 1, 0, -50242, 3775, 0, 0, 39, '3774'),
	(377, 1, 0, -50242, 3776, 0, 0, 39, '3775'),
	(377, 1, 0, -50242, 3777, 0, 0, 39, '3776'),
	(377, 1, 0, -50242, 3778, 0, 0, 39, '3777'),
	(377, 1, 0, -50242, 3779, 0, 0, 39, '3778'),
	(377, 1, 0, -50242, 3780, 0, 0, 39, '3779'),
	(377, 1, 0, -50242, 3781, 0, 0, 39, '3780'),
	(377, 1, 0, -50242, 3782, 0, 0, 39, '3781'),
	(377, 1, 0, -50242, 3783, 0, 0, 39, '3782'),
	(377, 1, 0, -50242, 3784, 0, 0, 39, '3783'),
	(377, 1, 0, -50242, 3785, 0, 0, 39, '3784'),
	(377, 1, 0, -50242, 3786, 0, 0, 39, '3785'),
	(377, 1, 0, -50242, 3787, 0, 0, 39, '3786'),
	(377, 1, 0, -50242, 3788, 0, 0, 39, '3787'),
	(377, 1, 0, -50242, 3789, 0, 0, 39, '3788'),
	(377, 1, 0, -50242, 3790, 0, 0, 39, '3789'),
	(377, 1, 0, -50242, 3791, 0, 0, 39, '3790'),
	(377, 1, 0, -50242, 3792, 0, 0, 39, '3791'),
	(377, 1, 0, -50242, 3793, 0, 0, 39, '3792'),
	(377, 1, 0, -50242, 3794, 0, 0, 39, '3793'),
	(377, 1, 0, -50242, 3795, 0, 0, 39, '3794'),
	(377, 1, 0, -50242, 3796, 0, 0, 39, '3795'),
	(377, 1, 0, -50242, 3797, 0, 0, 39, '3796'),
	(377, 1, 0, -50242, 3798, 0, 0, 39, '3797'),
	(377, 1, 0, -50242, 3799, 0, 0, 39, '3798'),
	(377, 1, 0, -50242, 3800, 0, 0, 39, '3799'),
	(377, 1, 0, -50242, 3801, 0, 0, 39, '3800'),
	(377, 1, 0, -50242, 3802, 0, 0, 39, '3801'),
	(377, 1, 0, -50242, 3803, 0, 0, 39, '3802'),
	(377, 1, 0, -50242, 3804, 0, 0, 39, '3803'),
	(377, 1, 0, -50242, 3805, 0, 0, 39, '3804'),
	(377, 1, 0, -50242, 3806, 0, 0, 39, '3805'),
	(377, 1, 0, -50242, 3807, 0, 0, 39, '3806'),
	(377, 1, 0, -50242, 3808, 0, 0, 39, '3807'),
	(377, 1, 0, -50242, 3809, 0, 0, 39, '3808'),
	(377, 1, 0, -50242, 3810, 0, 0, 39, '3809'),
	(377, 1, 0, -50242, 3811, 0, 0, 39, '3810'),
	(377, 1, 0, -50242, 3812, 0, 0, 39, '3811'),
	(377, 1, 0, -50242, 3813, 0, 0, 39, '3812'),
	(377, 1, 0, -50242, 3814, 0, 0, 39, '3813'),
	(377, 1, 0, -50242, 3815, 0, 0, 39, '3814'),
	(377, 1, 0, -50242, 3816, 0, 0, 39, '3815'),
	(377, 1, 0, -50242, 3817, 0, 0, 39, '3816'),
	(377, 1, 0, -50242, 3818, 0, 0, 39, '3817'),
	(377, 1, 0, -50242, 3819, 0, 0, 39, '3818'),
	(377, 1, 0, -50242, 3820, 0, 0, 39, '3819'),
	(377, 1, 0, -50242, 3821, 0, 0, 39, '3820'),
	(377, 1, 0, -50242, 3822, 0, 0, 39, '3821'),
	(377, 1, 0, -50242, 3823, 0, 0, 39, '3822'),
	(377, 1, 0, -50242, 3824, 0, 0, 39, '3823'),
	(377, 1, 0, -50242, 3825, 0, 0, 39, '3824'),
	(377, 1, 0, -50242, 3826, 0, 0, 39, '3825'),
	(377, 1, 0, -50242, 3827, 0, 0, 39, '3826'),
	(377, 1, 0, -50242, 3828, 0, 0, 39, '3827'),
	(377, 1, 0, -50242, 3829, 0, 0, 39, '3828'),
	(377, 1, 0, -50242, 3830, 0, 0, 39, '3829'),
	(377, 1, 0, -50242, 3831, 0, 0, 39, '3830'),
	(377, 1, 0, -50242, 3832, 0, 0, 39, '3831'),
	(377, 1, 0, -50242, 3833, 0, 0, 39, '3832'),
	(377, 1, 0, -50242, 3834, 0, 0, 39, '3833'),
	(377, 1, 0, -50242, 3835, 0, 0, 39, '3834'),
	(377, 1, 0, -50242, 3836, 0, 0, 39, '3835'),
	(377, 1, 0, -50242, 3837, 0, 0, 39, '3836'),
	(377, 1, 0, -50242, 3838, 0, 0, 39, '3837'),
	(377, 1, 0, -50242, 3839, 0, 0, 39, '3838'),
	(377, 1, 0, -50242, 3840, 0, 0, 39, '3839'),
	(377, 1, 0, -50242, 3841, 0, 0, 39, '3840'),
	(377, 1, 0, -50242, 3842, 0, 0, 39, '3841'),
	(377, 1, 0, -50242, 3843, 0, 0, 39, '3842'),
	(377, 1, 0, -50242, 3844, 0, 0, 39, '3843'),
	(377, 1, 0, -50242, 3845, 0, 0, 39, '3844'),
	(377, 1, 0, -50242, 3846, 0, 0, 39, '3845'),
	(377, 1, 0, -50242, 3847, 0, 0, 39, '3846'),
	(377, 1, 0, -50242, 3848, 0, 0, 39, '3847'),
	(377, 1, 0, -50242, 3849, 0, 0, 39, '3848'),
	(377, 1, 0, -50242, 3850, 0, 0, 39, '3849'),
	(377, 1, 0, -50242, 3851, 0, 0, 39, '3850'),
	(377, 1, 0, -50242, 3852, 0, 0, 39, '3851'),
	(377, 1, 0, -50242, 3853, 0, 0, 39, '3852'),
	(377, 1, 0, -50242, 3854, 0, 0, 39, '3853'),
	(377, 1, 0, -50242, 3855, 0, 0, 39, '3854'),
	(377, 1, 0, -50242, 3856, 0, 0, 39, '3855'),
	(377, 1, 0, -50242, 3857, 0, 0, 39, '3856'),
	(377, 1, 0, -50242, 3858, 0, 0, 39, '3857'),
	(377, 1, 0, -50242, 3859, 0, 0, 39, '3858'),
	(377, 1, 0, -50242, 3860, 0, 0, 39, '3859'),
	(377, 1, 0, -50242, 3861, 0, 0, 39, '3860'),
	(377, 1, 0, -50242, 3862, 0, 0, 39, '3861'),
	(377, 1, 0, -50242, 3863, 0, 0, 39, '3862'),
	(377, 1, 0, -50242, 3864, 0, 0, 39, '3863'),
	(377, 1, 0, -50242, 3865, 0, 0, 39, '3864'),
	(377, 1, 0, -50242, 3866, 0, 0, 39, '3865'),
	(377, 1, 0, -50242, 3867, 0, 0, 39, '3866'),
	(377, 1, 0, -50242, 3868, 0, 0, 39, '3867'),
	(377, 1, 0, -50242, 3869, 0, 0, 39, '3868'),
	(377, 1, 0, -50242, 3870, 0, 0, 39, '3869'),
	(377, 1, 0, -50242, 3871, 0, 0, 39, '3870'),
	(377, 1, 0, -50242, 3872, 0, 0, 39, '3871'),
	(377, 1, 0, -50242, 3873, 0, 0, 39, '3872'),
	(377, 1, 0, -50242, 3874, 0, 0, 39, '3873'),
	(377, 1, 0, -50242, 3875, 0, 0, 39, '3874'),
	(377, 1, 0, -50242, 3876, 0, 0, 39, '3875'),
	(377, 1, 0, -50242, 3877, 0, 0, 39, '3876'),
	(377, 1, 0, -50242, 3878, 0, 0, 39, '3877'),
	(377, 1, 0, -50242, 3879, 0, 0, 39, '3878'),
	(377, 1, 0, -50242, 3880, 0, 0, 39, '3879'),
	(377, 1, 0, -50242, 3881, 0, 0, 39, '3880'),
	(377, 1, 0, -50242, 3882, 0, 0, 39, '3881'),
	(377, 1, 0, -50242, 3883, 0, 0, 39, '3882'),
	(377, 1, 0, -50242, 3884, 0, 0, 39, '3883'),
	(377, 1, 0, -50242, 3885, 0, 0, 39, '3884'),
	(377, 1, 0, -50242, 3886, 0, 0, 39, '3885'),
	(377, 1, 0, -50242, 3887, 0, 0, 39, '3886'),
	(377, 1, 0, -50242, 3888, 0, 0, 39, '3887'),
	(377, 1, 0, -50242, 3889, 0, 0, 39, '3888'),
	(377, 1, 0, -50242, 3890, 0, 0, 39, '3889'),
	(377, 1, 0, -50242, 3891, 0, 0, 39, '3890'),
	(377, 1, 0, -50242, 3892, 0, 0, 39, '3891'),
	(377, 1, 0, -50242, 3893, 0, 0, 39, '3892'),
	(377, 1, 0, -50242, 3894, 0, 0, 39, '3893'),
	(377, 1, 0, -50242, 3895, 0, 0, 39, '3894'),
	(377, 1, 0, -50242, 3896, 0, 0, 39, '3895'),
	(377, 1, 0, -50242, 3897, 0, 0, 39, '3896'),
	(377, 1, 0, -50242, 3898, 0, 0, 39, '3897'),
	(377, 1, 0, -50242, 3899, 0, 0, 39, '3898'),
	(377, 1, 0, -50242, 3900, 0, 0, 39, '3899'),
	(377, 1, 0, -50242, 3901, 0, 0, 39, '3900'),
	(377, 1, 0, -50242, 3902, 0, 0, 39, '3901'),
	(377, 1, 0, -50242, 3903, 0, 0, 39, '3902'),
	(377, 1, 0, -50242, 3904, 0, 0, 39, '3903'),
	(377, 1, 0, -50242, 3905, 0, 0, 39, '3904'),
	(377, 1, 0, -50242, 3906, 0, 0, 39, '3905'),
	(377, 1, 0, -50242, 3907, 0, 0, 39, '3906'),
	(377, 1, 0, -50242, 3908, 0, 0, 39, '3907'),
	(377, 1, 0, -50242, 3909, 0, 0, 39, '3908'),
	(377, 1, 0, -50242, 3910, 0, 0, 39, '3909'),
	(377, 1, 0, -50242, 3911, 0, 0, 39, '3910'),
	(377, 1, 0, -50242, 3912, 0, 0, 39, '3911'),
	(377, 1, 0, -50242, 3913, 0, 0, 39, '3912'),
	(377, 1, 0, -50242, 3914, 0, 0, 39, '3913'),
	(377, 1, 0, -50242, 3915, 0, 0, 39, '3914'),
	(377, 1, 0, -50242, 3916, 0, 0, 39, '3915'),
	(377, 1, 0, -50242, 3917, 0, 0, 39, '3916'),
	(377, 1, 0, -50242, 3918, 0, 0, 39, '3917'),
	(377, 1, 0, -50242, 3919, 0, 0, 39, '3918'),
	(377, 1, 0, -50242, 3920, 0, 0, 39, '3919'),
	(377, 1, 0, -50242, 3921, 0, 0, 39, '3920'),
	(377, 1, 0, -50242, 3922, 0, 0, 39, '3921'),
	(377, 1, 0, -50242, 3923, 0, 0, 39, '3922'),
	(377, 1, 0, -50242, 3924, 0, 0, 39, '3923'),
	(377, 1, 0, -50242, 3925, 0, 0, 39, '3924'),
	(377, 1, 0, -50242, 3926, 0, 0, 39, '3925'),
	(377, 1, 0, -50242, 3927, 0, 0, 39, '3926'),
	(377, 1, 0, -50242, 3928, 0, 0, 39, '3927'),
	(377, 1, 0, -50242, 3929, 0, 0, 39, '3928'),
	(377, 1, 0, -50242, 3930, 0, 0, 39, '3929'),
	(377, 1, 0, -50242, 3931, 0, 0, 39, '3930'),
	(377, 1, 0, -50242, 3932, 0, 0, 39, '3931'),
	(377, 1, 0, -50242, 3933, 0, 0, 39, '3932'),
	(377, 1, 0, -50242, 3934, 0, 0, 39, '3933'),
	(377, 1, 0, -50242, 3935, 0, 0, 39, '3934'),
	(377, 1, 0, -50242, 3936, 0, 0, 39, '3935'),
	(377, 1, 0, -50242, 3937, 0, 0, 39, '3936'),
	(377, 1, 0, -50242, 3938, 0, 0, 39, '3937'),
	(377, 1, 0, -50242, 3939, 0, 0, 39, '3938'),
	(377, 1, 0, -50242, 3940, 0, 0, 39, '3939'),
	(377, 1, 0, -50242, 3941, 0, 0, 39, '3940'),
	(377, 1, 0, -50242, 3942, 0, 0, 39, '3941'),
	(377, 1, 0, -50242, 3943, 0, 0, 39, '3942'),
	(377, 1, 0, -50242, 3944, 0, 0, 39, '3943'),
	(377, 1, 0, -50242, 3945, 0, 0, 39, '3944'),
	(377, 1, 0, -50242, 3946, 0, 0, 39, '3945'),
	(377, 1, 0, -50242, 3947, 0, 0, 39, '3946'),
	(377, 1, 0, -50242, 3948, 0, 0, 39, '3947'),
	(377, 1, 0, -50242, 3949, 0, 0, 39, '3948'),
	(377, 1, 0, -50242, 3950, 0, 0, 39, '3949'),
	(377, 1, 0, -50242, 3951, 0, 0, 39, '3950'),
	(377, 1, 0, -50242, 3952, 0, 0, 39, '3951'),
	(377, 1, 0, -50242, 3953, 0, 0, 39, '3952'),
	(377, 1, 0, -50242, 3954, 0, 0, 39, '3953'),
	(377, 1, 0, -50242, 3955, 0, 0, 39, '3954'),
	(377, 1, 0, -50242, 3956, 0, 0, 39, '3955'),
	(377, 1, 0, -50242, 3957, 0, 0, 39, '3956'),
	(377, 1, 0, -50242, 3958, 0, 0, 39, '3957'),
	(377, 1, 0, -50242, 3959, 0, 0, 39, '3958'),
	(377, 1, 0, -50242, 3960, 0, 0, 39, '3959'),
	(377, 1, 0, -50242, 3961, 0, 0, 39, '3960'),
	(377, 1, 0, -50242, 3962, 0, 0, 39, '3961'),
	(377, 1, 0, -50242, 3963, 0, 0, 39, '3962'),
	(377, 1, 0, -50242, 3964, 0, 0, 39, '3963'),
	(377, 1, 0, -50242, 3965, 0, 0, 39, '3964'),
	(377, 1, 0, -50242, 3966, 0, 0, 39, '3965'),
	(377, 1, 0, -50242, 3967, 0, 0, 39, '3966'),
	(377, 1, 0, -50242, 3968, 0, 0, 39, '3967'),
	(377, 1, 0, -50242, 3969, 0, 0, 39, '3968'),
	(377, 1, 0, -50242, 3970, 0, 0, 39, '3969'),
	(377, 1, 0, -50242, 3971, 0, 0, 39, '3970'),
	(377, 1, 0, -50242, 3972, 0, 0, 39, '3971'),
	(377, 1, 0, -50242, 3973, 0, 0, 39, '3972'),
	(377, 1, 0, -50242, 3974, 0, 0, 39, '3973'),
	(377, 1, 0, -50242, 3975, 0, 0, 39, '3974'),
	(377, 1, 0, -50242, 3976, 0, 0, 39, '3975'),
	(377, 1, 0, -50242, 3977, 0, 0, 39, '3976'),
	(377, 1, 0, -50242, 3978, 0, 0, 39, '3977'),
	(377, 1, 0, -50242, 3979, 0, 0, 39, '3978'),
	(377, 1, 0, -50242, 3980, 0, 0, 39, '3979'),
	(377, 1, 0, -50242, 3981, 0, 0, 39, '3980'),
	(377, 1, 0, -50242, 3982, 0, 0, 39, '3981'),
	(377, 1, 0, -50242, 3983, 0, 0, 39, '3982'),
	(377, 1, 0, -50242, 3984, 0, 0, 39, '3983'),
	(377, 1, 0, -50242, 3985, 0, 0, 39, '3984'),
	(377, 1, 0, -50242, 3986, 0, 0, 39, '3985'),
	(377, 1, 0, -50242, 3987, 0, 0, 39, '3986'),
	(377, 1, 0, -50242, 3988, 0, 0, 39, '3987'),
	(377, 1, 0, -50242, 3989, 0, 0, 39, '3988'),
	(377, 1, 0, -50242, 3990, 0, 0, 39, '3989'),
	(377, 1, 0, -50242, 3991, 0, 0, 39, '3990'),
	(377, 1, 0, -50242, 3992, 0, 0, 39, '3991'),
	(377, 1, 0, -50242, 3993, 0, 0, 39, '3992'),
	(377, 1, 0, -50242, 3994, 0, 0, 39, '3993'),
	(377, 1, 0, -50242, 3995, 0, 0, 39, '3994'),
	(377, 1, 0, -50242, 3996, 0, 0, 39, '3995'),
	(377, 1, 0, -50242, 3997, 0, 0, 39, '3996'),
	(377, 1, 0, -50242, 3998, 0, 0, 39, '3997'),
	(377, 1, 0, -50242, 3999, 0, 0, 39, '3998'),
	(377, 1, 0, -50242, 4000, 0, 0, 39, '3999'),
	(377, 1, 0, -50221, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50221, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50221, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50220, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50220, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50220, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50219, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50219, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50219, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50218, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50218, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50218, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50217, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50217, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50217, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50216, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50216, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50216, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50203, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50203, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50203, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50203, 4, 0, 0, 39, '3'),
	(377, 1, 0, -50203, 5, 0, 0, 39, '4'),
	(377, 1, 0, -50203, 6, 0, 0, 39, '5'),
	(377, 1, 0, -50203, 7, 0, 0, 39, '6'),
	(377, 1, 0, -50203, 8, 0, 0, 39, '7'),
	(377, 1, 0, -50203, 9, 0, 0, 39, '8'),
	(377, 1, 0, -50203, 10, 0, 0, 39, '9'),
	(377, 1, 0, -50203, 11, 0, 0, 39, '10'),
	(377, 1, 0, -50203, 12, 0, 0, 39, '11'),
	(377, 1, 0, -50203, 13, 0, 0, 39, '12'),
	(377, 1, 0, -50203, 14, 0, 0, 39, '13'),
	(377, 1, 0, -50203, 15, 0, 0, 39, '14'),
	(377, 1, 0, -50203, 16, 0, 0, 39, '15'),
	(377, 1, 0, -50203, 17, 0, 0, 39, '16'),
	(377, 1, 0, -50203, 18, 0, 0, 39, '17'),
	(377, 1, 0, -50203, 19, 0, 0, 39, '18'),
	(377, 1, 0, -50203, 20, 0, 0, 39, '19'),
	(377, 1, 0, -50203, 21, 0, 0, 39, '20'),
	(377, 1, 0, -50203, 22, 0, 0, 39, '21'),
	(377, 1, 0, -50203, 23, 0, 0, 39, '22'),
	(377, 1, 0, -50203, 24, 0, 0, 39, '23'),
	(377, 1, 0, -50203, 25, 0, 0, 39, '24'),
	(377, 1, 0, -50203, 26, 0, 0, 39, '25'),
	(377, 1, 0, -50203, 27, 0, 0, 39, '26'),
	(377, 1, 0, -50203, 28, 0, 0, 39, '27'),
	(377, 1, 0, -50203, 29, 0, 0, 39, '28'),
	(377, 1, 0, -50203, 30, 0, 0, 39, '29'),
	(377, 1, 0, -50203, 31, 0, 0, 39, '30'),
	(377, 1, 0, -50203, 32, 0, 0, 39, '31'),
	(377, 1, 0, -50203, 33, 0, 0, 39, '32'),
	(377, 1, 0, -50203, 34, 0, 0, 39, '33'),
	(377, 1, 0, -50203, 35, 0, 0, 39, '34'),
	(377, 1, 0, -50203, 36, 0, 0, 39, '35'),
	(377, 1, 0, -50203, 37, 0, 0, 39, '36'),
	(377, 1, 0, -50203, 38, 0, 0, 39, '37'),
	(377, 1, 0, -50203, 39, 0, 0, 39, '38'),
	(377, 1, 0, -50203, 40, 0, 0, 39, '39'),
	(377, 1, 0, -50203, 41, 0, 0, 39, '40'),
	(377, 1, 0, -50203, 42, 0, 0, 39, '41'),
	(377, 1, 0, -50203, 43, 0, 0, 39, '42'),
	(377, 1, 0, -50203, 44, 0, 0, 39, '43'),
	(377, 1, 0, -50203, 45, 0, 0, 39, '44'),
	(377, 1, 0, -50203, 46, 0, 0, 39, '45'),
	(377, 1, 0, -50203, 47, 0, 0, 39, '46'),
	(377, 1, 0, -50203, 48, 0, 0, 39, '47'),
	(377, 1, 0, -50203, 49, 0, 0, 39, '48'),
	(377, 1, 0, -50203, 50, 0, 0, 39, '49'),
	(377, 1, 0, -50203, 51, 0, 0, 39, '50'),
	(377, 1, 0, -50203, 52, 0, 0, 39, '51'),
	(377, 1, 0, -50203, 53, 0, 0, 39, '52'),
	(377, 1, 0, -50203, 54, 0, 0, 39, '53'),
	(377, 1, 0, -50203, 55, 0, 0, 39, '54'),
	(377, 1, 0, -50203, 56, 0, 0, 39, '55'),
	(377, 1, 0, -50203, 57, 0, 0, 39, '56'),
	(377, 1, 0, -50203, 58, 0, 0, 39, '57'),
	(377, 1, 0, -50203, 59, 0, 0, 39, '58'),
	(377, 1, 0, -50203, 60, 0, 0, 39, '59'),
	(377, 1, 0, -50203, 61, 0, 0, 39, '60'),
	(377, 1, 0, -50203, 62, 0, 0, 39, '61'),
	(377, 1, 0, -50203, 63, 0, 0, 39, '62'),
	(377, 1, 0, -50203, 64, 0, 0, 39, '63'),
	(377, 1, 0, -50181, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50181, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50181, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50181, 4, 0, 0, 39, '3'),
	(377, 1, 0, -50181, 5, 0, 0, 39, '4'),
	(377, 1, 0, -50181, 6, 0, 0, 39, '5'),
	(377, 1, 0, -50181, 7, 0, 0, 39, '6'),
	(377, 1, 0, -50181, 8, 0, 0, 39, '7'),
	(377, 1, 0, -50181, 9, 0, 0, 39, '8'),
	(377, 1, 0, -50181, 10, 0, 0, 39, '9'),
	(377, 1, 0, -50181, 11, 0, 0, 39, '10'),
	(377, 1, 0, -50181, 12, 0, 0, 39, '11'),
	(377, 1, 0, -50181, 13, 0, 0, 39, '12'),
	(377, 1, 0, -50181, 14, 0, 0, 39, '13'),
	(377, 1, 0, -50181, 15, 0, 0, 39, '14'),
	(377, 1, 0, -50181, 16, 0, 0, 39, '15'),
	(377, 1, 0, -50022, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50022, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50022, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50022, 4, 0, 0, 39, '3'),
	(377, 1, 0, -50022, 5, 0, 0, 39, '4'),
	(377, 1, 0, -50022, 6, 0, 0, 39, '5'),
	(377, 1, 0, -50022, 7, 0, 0, 39, '6'),
	(377, 1, 0, -50022, 8, 0, 0, 39, '7'),
	(377, 1, 0, -50022, 9, 0, 0, 39, '8'),
	(377, 1, 0, -50022, 10, 0, 0, 39, '9'),
	(377, 1, 0, -50022, 11, 0, 0, 39, '10'),
	(377, 1, 0, -50022, 12, 0, 0, 39, '11'),
	(377, 1, 0, -50022, 13, 0, 0, 39, '12'),
	(377, 1, 0, -50022, 14, 0, 0, 39, '13'),
	(377, 1, 0, -50022, 15, 0, 0, 39, '14'),
	(377, 1, 0, -50022, 16, 0, 0, 39, '15'),
	(377, 1, 0, -50020, 1, 1, 0, 37, '14'),
	(377, 1, 0, -50020, 1, 1, 0, 39, '0'),
	(377, 1, 0, -50020, 1, 2, 0, 37, '15'),
	(377, 1, 0, -50020, 1, 2, 0, 39, '0'),
	(377, 1, 0, -50020, 1, 3, 0, 37, '16'),
	(377, 1, 0, -50020, 1, 3, 0, 39, '0'),
	(377, 1, 0, -50020, 1, 4, 0, 37, '17'),
	(377, 1, 0, -50020, 1, 4, 0, 39, '0'),
	(377, 1, 0, -50020, 2, 1, 0, 37, '14'),
	(377, 1, 0, -50020, 2, 1, 0, 39, '1'),
	(377, 1, 0, -50020, 2, 2, 0, 37, '15'),
	(377, 1, 0, -50020, 2, 2, 0, 39, '1'),
	(377, 1, 0, -50020, 2, 3, 0, 37, '16'),
	(377, 1, 0, -50020, 2, 3, 0, 39, '1'),
	(377, 1, 0, -50020, 2, 4, 0, 37, '17'),
	(377, 1, 0, -50020, 2, 4, 0, 39, '1'),
	(377, 1, 0, -50020, 3, 1, 0, 37, '14'),
	(377, 1, 0, -50020, 3, 1, 0, 39, '2'),
	(377, 1, 0, -50020, 3, 2, 0, 37, '15'),
	(377, 1, 0, -50020, 3, 2, 0, 39, '2'),
	(377, 1, 0, -50020, 3, 3, 0, 37, '16'),
	(377, 1, 0, -50020, 3, 3, 0, 39, '2'),
	(377, 1, 0, -50020, 3, 4, 0, 37, '17'),
	(377, 1, 0, -50020, 3, 4, 0, 39, '2'),
	(377, 1, 0, -50020, 4, 1, 0, 37, '14'),
	(377, 1, 0, -50020, 4, 1, 0, 39, '3'),
	(377, 1, 0, -50020, 4, 2, 0, 37, '15'),
	(377, 1, 0, -50020, 4, 2, 0, 39, '3'),
	(377, 1, 0, -50020, 4, 3, 0, 37, '16'),
	(377, 1, 0, -50020, 4, 3, 0, 39, '3'),
	(377, 1, 0, -50020, 4, 4, 0, 37, '17'),
	(377, 1, 0, -50020, 4, 4, 0, 39, '3'),
	(377, 1, 0, -50020, 5, 1, 0, 37, '14'),
	(377, 1, 0, -50020, 5, 1, 0, 39, '4'),
	(377, 1, 0, -50020, 5, 2, 0, 37, '15'),
	(377, 1, 0, -50020, 5, 2, 0, 39, '4'),
	(377, 1, 0, -50020, 5, 3, 0, 37, '16'),
	(377, 1, 0, -50020, 5, 3, 0, 39, '4'),
	(377, 1, 0, -50020, 5, 4, 0, 37, '17'),
	(377, 1, 0, -50020, 5, 4, 0, 39, '4'),
	(377, 1, 0, -50020, 6, 1, 0, 37, '14'),
	(377, 1, 0, -50020, 6, 1, 0, 39, '5'),
	(377, 1, 0, -50020, 6, 2, 0, 37, '15'),
	(377, 1, 0, -50020, 6, 2, 0, 39, '5'),
	(377, 1, 0, -50020, 6, 3, 0, 37, '16'),
	(377, 1, 0, -50020, 6, 3, 0, 39, '5'),
	(377, 1, 0, -50020, 6, 4, 0, 37, '17'),
	(377, 1, 0, -50020, 6, 4, 0, 39, '5'),
	(377, 1, 0, -50020, 7, 1, 0, 37, '14'),
	(377, 1, 0, -50020, 7, 1, 0, 39, '6'),
	(377, 1, 0, -50020, 7, 2, 0, 37, '15'),
	(377, 1, 0, -50020, 7, 2, 0, 39, '6'),
	(377, 1, 0, -50020, 7, 3, 0, 37, '16'),
	(377, 1, 0, -50020, 7, 3, 0, 39, '6'),
	(377, 1, 0, -50020, 7, 4, 0, 37, '17'),
	(377, 1, 0, -50020, 7, 4, 0, 39, '6'),
	(377, 1, 0, -50020, 8, 1, 0, 37, '14'),
	(377, 1, 0, -50020, 8, 1, 0, 39, '7'),
	(377, 1, 0, -50020, 8, 2, 0, 37, '15'),
	(377, 1, 0, -50020, 8, 2, 0, 39, '7'),
	(377, 1, 0, -50020, 8, 3, 0, 37, '16'),
	(377, 1, 0, -50020, 8, 3, 0, 39, '7'),
	(377, 1, 0, -50020, 8, 4, 0, 37, '17'),
	(377, 1, 0, -50020, 8, 4, 0, 39, '7'),
	(377, 1, 0, -50020, 9, 1, 0, 37, '14'),
	(377, 1, 0, -50020, 9, 1, 0, 39, '8'),
	(377, 1, 0, -50020, 9, 2, 0, 37, '15'),
	(377, 1, 0, -50020, 9, 2, 0, 39, '8'),
	(377, 1, 0, -50020, 9, 3, 0, 37, '16'),
	(377, 1, 0, -50020, 9, 3, 0, 39, '8'),
	(377, 1, 0, -50020, 9, 4, 0, 37, '17'),
	(377, 1, 0, -50020, 9, 4, 0, 39, '8'),
	(377, 1, 0, -50020, 10, 1, 0, 37, '14'),
	(377, 1, 0, -50020, 10, 1, 0, 39, '9'),
	(377, 1, 0, -50020, 10, 2, 0, 37, '15'),
	(377, 1, 0, -50020, 10, 2, 0, 39, '9'),
	(377, 1, 0, -50020, 10, 3, 0, 37, '16'),
	(377, 1, 0, -50020, 10, 3, 0, 39, '9'),
	(377, 1, 0, -50020, 10, 4, 0, 37, '17'),
	(377, 1, 0, -50020, 10, 4, 0, 39, '9'),
	(377, 1, 0, -50020, 11, 1, 0, 37, '14'),
	(377, 1, 0, -50020, 11, 1, 0, 39, '10'),
	(377, 1, 0, -50020, 11, 2, 0, 37, '15'),
	(377, 1, 0, -50020, 11, 2, 0, 39, '10'),
	(377, 1, 0, -50020, 11, 3, 0, 37, '16'),
	(377, 1, 0, -50020, 11, 3, 0, 39, '10'),
	(377, 1, 0, -50020, 11, 4, 0, 37, '17'),
	(377, 1, 0, -50020, 11, 4, 0, 39, '10'),
	(377, 1, 0, -50020, 12, 1, 0, 37, '14'),
	(377, 1, 0, -50020, 12, 1, 0, 39, '11'),
	(377, 1, 0, -50020, 12, 2, 0, 37, '15'),
	(377, 1, 0, -50020, 12, 2, 0, 39, '11'),
	(377, 1, 0, -50020, 12, 3, 0, 37, '16'),
	(377, 1, 0, -50020, 12, 3, 0, 39, '11'),
	(377, 1, 0, -50020, 12, 4, 0, 37, '17'),
	(377, 1, 0, -50020, 12, 4, 0, 39, '11'),
	(377, 1, 0, -50020, 13, 1, 0, 37, '14'),
	(377, 1, 0, -50020, 13, 1, 0, 39, '12'),
	(377, 1, 0, -50020, 13, 2, 0, 37, '15'),
	(377, 1, 0, -50020, 13, 2, 0, 39, '12'),
	(377, 1, 0, -50020, 13, 3, 0, 37, '16'),
	(377, 1, 0, -50020, 13, 3, 0, 39, '12'),
	(377, 1, 0, -50020, 13, 4, 0, 37, '17'),
	(377, 1, 0, -50020, 13, 4, 0, 39, '12'),
	(377, 1, 0, -50020, 14, 1, 0, 37, '14'),
	(377, 1, 0, -50020, 14, 1, 0, 39, '13'),
	(377, 1, 0, -50020, 14, 2, 0, 37, '15'),
	(377, 1, 0, -50020, 14, 2, 0, 39, '13'),
	(377, 1, 0, -50020, 14, 3, 0, 37, '16'),
	(377, 1, 0, -50020, 14, 3, 0, 39, '13'),
	(377, 1, 0, -50020, 14, 4, 0, 37, '17'),
	(377, 1, 0, -50020, 14, 4, 0, 39, '13'),
	(377, 1, 0, -50020, 15, 1, 0, 37, '14'),
	(377, 1, 0, -50020, 15, 1, 0, 39, '14'),
	(377, 1, 0, -50020, 15, 2, 0, 37, '15'),
	(377, 1, 0, -50020, 15, 2, 0, 39, '14'),
	(377, 1, 0, -50020, 15, 3, 0, 37, '16'),
	(377, 1, 0, -50020, 15, 3, 0, 39, '14'),
	(377, 1, 0, -50020, 15, 4, 0, 37, '17'),
	(377, 1, 0, -50020, 15, 4, 0, 39, '14'),
	(377, 1, 0, -50020, 16, 1, 0, 37, '14'),
	(377, 1, 0, -50020, 16, 1, 0, 39, '15'),
	(377, 1, 0, -50020, 16, 2, 0, 37, '15'),
	(377, 1, 0, -50020, 16, 2, 0, 39, '15'),
	(377, 1, 0, -50020, 16, 3, 0, 37, '16'),
	(377, 1, 0, -50020, 16, 3, 0, 39, '15'),
	(377, 1, 0, -50020, 16, 4, 0, 37, '17'),
	(377, 1, 0, -50020, 16, 4, 0, 39, '15'),
	(377, 1, 0, -50018, 1, 1, 0, 37, '14'),
	(377, 1, 0, -50018, 1, 1, 0, 39, '0'),
	(377, 1, 0, -50018, 1, 2, 0, 37, '15'),
	(377, 1, 0, -50018, 1, 2, 0, 39, '0'),
	(377, 1, 0, -50018, 1, 3, 0, 37, '16'),
	(377, 1, 0, -50018, 1, 3, 0, 39, '0'),
	(377, 1, 0, -50018, 1, 4, 0, 37, '17'),
	(377, 1, 0, -50018, 1, 4, 0, 39, '0'),
	(377, 1, 0, -50018, 2, 1, 0, 37, '14'),
	(377, 1, 0, -50018, 2, 1, 0, 39, '1'),
	(377, 1, 0, -50018, 2, 2, 0, 37, '15'),
	(377, 1, 0, -50018, 2, 2, 0, 39, '1'),
	(377, 1, 0, -50018, 2, 3, 0, 37, '16'),
	(377, 1, 0, -50018, 2, 3, 0, 39, '1'),
	(377, 1, 0, -50018, 2, 4, 0, 37, '17'),
	(377, 1, 0, -50018, 2, 4, 0, 39, '1'),
	(377, 1, 0, -50018, 3, 1, 0, 37, '14'),
	(377, 1, 0, -50018, 3, 1, 0, 39, '2'),
	(377, 1, 0, -50018, 3, 2, 0, 37, '15'),
	(377, 1, 0, -50018, 3, 2, 0, 39, '2'),
	(377, 1, 0, -50018, 3, 3, 0, 37, '16'),
	(377, 1, 0, -50018, 3, 3, 0, 39, '2'),
	(377, 1, 0, -50018, 3, 4, 0, 37, '17'),
	(377, 1, 0, -50018, 3, 4, 0, 39, '2'),
	(377, 1, 0, -50018, 4, 1, 0, 37, '14'),
	(377, 1, 0, -50018, 4, 1, 0, 39, '3'),
	(377, 1, 0, -50018, 4, 2, 0, 37, '15'),
	(377, 1, 0, -50018, 4, 2, 0, 39, '3'),
	(377, 1, 0, -50018, 4, 3, 0, 37, '16'),
	(377, 1, 0, -50018, 4, 3, 0, 39, '3'),
	(377, 1, 0, -50018, 4, 4, 0, 37, '17'),
	(377, 1, 0, -50018, 4, 4, 0, 39, '3'),
	(377, 1, 0, -50018, 5, 1, 0, 37, '14'),
	(377, 1, 0, -50018, 5, 1, 0, 39, '4'),
	(377, 1, 0, -50018, 5, 2, 0, 37, '15'),
	(377, 1, 0, -50018, 5, 2, 0, 39, '4'),
	(377, 1, 0, -50018, 5, 3, 0, 37, '16'),
	(377, 1, 0, -50018, 5, 3, 0, 39, '4'),
	(377, 1, 0, -50018, 5, 4, 0, 37, '17'),
	(377, 1, 0, -50018, 5, 4, 0, 39, '4'),
	(377, 1, 0, -50018, 6, 1, 0, 37, '14'),
	(377, 1, 0, -50018, 6, 1, 0, 39, '5'),
	(377, 1, 0, -50018, 6, 2, 0, 37, '15'),
	(377, 1, 0, -50018, 6, 2, 0, 39, '5'),
	(377, 1, 0, -50018, 6, 3, 0, 37, '16'),
	(377, 1, 0, -50018, 6, 3, 0, 39, '5'),
	(377, 1, 0, -50018, 6, 4, 0, 37, '17'),
	(377, 1, 0, -50018, 6, 4, 0, 39, '5'),
	(377, 1, 0, -50018, 7, 1, 0, 37, '14'),
	(377, 1, 0, -50018, 7, 1, 0, 39, '6'),
	(377, 1, 0, -50018, 7, 2, 0, 37, '15'),
	(377, 1, 0, -50018, 7, 2, 0, 39, '6'),
	(377, 1, 0, -50018, 7, 3, 0, 37, '16'),
	(377, 1, 0, -50018, 7, 3, 0, 39, '6'),
	(377, 1, 0, -50018, 7, 4, 0, 37, '17'),
	(377, 1, 0, -50018, 7, 4, 0, 39, '6'),
	(377, 1, 0, -50018, 8, 1, 0, 37, '14'),
	(377, 1, 0, -50018, 8, 1, 0, 39, '7'),
	(377, 1, 0, -50018, 8, 2, 0, 37, '15'),
	(377, 1, 0, -50018, 8, 2, 0, 39, '7'),
	(377, 1, 0, -50018, 8, 3, 0, 37, '16'),
	(377, 1, 0, -50018, 8, 3, 0, 39, '7'),
	(377, 1, 0, -50018, 8, 4, 0, 37, '17'),
	(377, 1, 0, -50018, 8, 4, 0, 39, '7'),
	(377, 1, 0, -50018, 9, 1, 0, 37, '14'),
	(377, 1, 0, -50018, 9, 1, 0, 39, '8'),
	(377, 1, 0, -50018, 9, 2, 0, 37, '15'),
	(377, 1, 0, -50018, 9, 2, 0, 39, '8'),
	(377, 1, 0, -50018, 9, 3, 0, 37, '16'),
	(377, 1, 0, -50018, 9, 3, 0, 39, '8'),
	(377, 1, 0, -50018, 9, 4, 0, 37, '17'),
	(377, 1, 0, -50018, 9, 4, 0, 39, '8'),
	(377, 1, 0, -50018, 10, 1, 0, 37, '14'),
	(377, 1, 0, -50018, 10, 1, 0, 39, '9'),
	(377, 1, 0, -50018, 10, 2, 0, 37, '15'),
	(377, 1, 0, -50018, 10, 2, 0, 39, '9'),
	(377, 1, 0, -50018, 10, 3, 0, 37, '16'),
	(377, 1, 0, -50018, 10, 3, 0, 39, '9'),
	(377, 1, 0, -50018, 10, 4, 0, 37, '17'),
	(377, 1, 0, -50018, 10, 4, 0, 39, '9'),
	(377, 1, 0, -50018, 11, 1, 0, 37, '14'),
	(377, 1, 0, -50018, 11, 1, 0, 39, '10'),
	(377, 1, 0, -50018, 11, 2, 0, 37, '15'),
	(377, 1, 0, -50018, 11, 2, 0, 39, '10'),
	(377, 1, 0, -50018, 11, 3, 0, 37, '16'),
	(377, 1, 0, -50018, 11, 3, 0, 39, '10'),
	(377, 1, 0, -50018, 11, 4, 0, 37, '17'),
	(377, 1, 0, -50018, 11, 4, 0, 39, '10'),
	(377, 1, 0, -50018, 12, 1, 0, 37, '14'),
	(377, 1, 0, -50018, 12, 1, 0, 39, '11'),
	(377, 1, 0, -50018, 12, 2, 0, 37, '15'),
	(377, 1, 0, -50018, 12, 2, 0, 39, '11'),
	(377, 1, 0, -50018, 12, 3, 0, 37, '16'),
	(377, 1, 0, -50018, 12, 3, 0, 39, '11'),
	(377, 1, 0, -50018, 12, 4, 0, 37, '17'),
	(377, 1, 0, -50018, 12, 4, 0, 39, '11'),
	(377, 1, 0, -50017, 1, 1, 0, 37, '14'),
	(377, 1, 0, -50017, 1, 1, 0, 39, '0'),
	(377, 1, 0, -50017, 1, 2, 0, 37, '15'),
	(377, 1, 0, -50017, 1, 2, 0, 39, '0'),
	(377, 1, 0, -50017, 1, 3, 0, 37, '16'),
	(377, 1, 0, -50017, 1, 3, 0, 39, '0'),
	(377, 1, 0, -50017, 1, 4, 0, 37, '17'),
	(377, 1, 0, -50017, 1, 4, 0, 39, '0'),
	(377, 1, 0, -50017, 2, 1, 0, 37, '14'),
	(377, 1, 0, -50017, 2, 1, 0, 39, '1'),
	(377, 1, 0, -50017, 2, 2, 0, 37, '15'),
	(377, 1, 0, -50017, 2, 2, 0, 39, '1'),
	(377, 1, 0, -50017, 2, 3, 0, 37, '16'),
	(377, 1, 0, -50017, 2, 3, 0, 39, '1'),
	(377, 1, 0, -50017, 2, 4, 0, 37, '17'),
	(377, 1, 0, -50017, 2, 4, 0, 39, '1'),
	(377, 1, 0, -50017, 3, 1, 0, 37, '14'),
	(377, 1, 0, -50017, 3, 1, 0, 39, '2'),
	(377, 1, 0, -50017, 3, 2, 0, 37, '15'),
	(377, 1, 0, -50017, 3, 2, 0, 39, '2'),
	(377, 1, 0, -50017, 3, 3, 0, 37, '16'),
	(377, 1, 0, -50017, 3, 3, 0, 39, '2'),
	(377, 1, 0, -50017, 3, 4, 0, 37, '17'),
	(377, 1, 0, -50017, 3, 4, 0, 39, '2'),
	(377, 1, 0, -50017, 4, 1, 0, 37, '14'),
	(377, 1, 0, -50017, 4, 1, 0, 39, '3'),
	(377, 1, 0, -50017, 4, 2, 0, 37, '15'),
	(377, 1, 0, -50017, 4, 2, 0, 39, '3'),
	(377, 1, 0, -50017, 4, 3, 0, 37, '16'),
	(377, 1, 0, -50017, 4, 3, 0, 39, '3'),
	(377, 1, 0, -50017, 4, 4, 0, 37, '17'),
	(377, 1, 0, -50017, 4, 4, 0, 39, '3'),
	(377, 1, 0, -50017, 5, 1, 0, 37, '14'),
	(377, 1, 0, -50017, 5, 1, 0, 39, '4'),
	(377, 1, 0, -50017, 5, 2, 0, 37, '15'),
	(377, 1, 0, -50017, 5, 2, 0, 39, '4'),
	(377, 1, 0, -50017, 5, 3, 0, 37, '16'),
	(377, 1, 0, -50017, 5, 3, 0, 39, '4'),
	(377, 1, 0, -50017, 5, 4, 0, 37, '17'),
	(377, 1, 0, -50017, 5, 4, 0, 39, '4'),
	(377, 1, 0, -50017, 6, 1, 0, 37, '14'),
	(377, 1, 0, -50017, 6, 1, 0, 39, '5'),
	(377, 1, 0, -50017, 6, 2, 0, 37, '15'),
	(377, 1, 0, -50017, 6, 2, 0, 39, '5'),
	(377, 1, 0, -50017, 6, 3, 0, 37, '16'),
	(377, 1, 0, -50017, 6, 3, 0, 39, '5'),
	(377, 1, 0, -50017, 6, 4, 0, 37, '17'),
	(377, 1, 0, -50017, 6, 4, 0, 39, '5'),
	(377, 1, 0, -50017, 7, 1, 0, 37, '14'),
	(377, 1, 0, -50017, 7, 1, 0, 39, '6'),
	(377, 1, 0, -50017, 7, 2, 0, 37, '15'),
	(377, 1, 0, -50017, 7, 2, 0, 39, '6'),
	(377, 1, 0, -50017, 7, 3, 0, 37, '16'),
	(377, 1, 0, -50017, 7, 3, 0, 39, '6'),
	(377, 1, 0, -50017, 7, 4, 0, 37, '17'),
	(377, 1, 0, -50017, 7, 4, 0, 39, '6'),
	(377, 1, 0, -50017, 8, 1, 0, 37, '14'),
	(377, 1, 0, -50017, 8, 1, 0, 39, '7'),
	(377, 1, 0, -50017, 8, 2, 0, 37, '15'),
	(377, 1, 0, -50017, 8, 2, 0, 39, '7'),
	(377, 1, 0, -50017, 8, 3, 0, 37, '16'),
	(377, 1, 0, -50017, 8, 3, 0, 39, '7'),
	(377, 1, 0, -50017, 8, 4, 0, 37, '17'),
	(377, 1, 0, -50017, 8, 4, 0, 39, '7'),
	(377, 1, 0, -50017, 9, 1, 0, 37, '14'),
	(377, 1, 0, -50017, 9, 1, 0, 39, '8'),
	(377, 1, 0, -50017, 9, 2, 0, 37, '15'),
	(377, 1, 0, -50017, 9, 2, 0, 39, '8'),
	(377, 1, 0, -50017, 9, 3, 0, 37, '16'),
	(377, 1, 0, -50017, 9, 3, 0, 39, '8'),
	(377, 1, 0, -50017, 9, 4, 0, 37, '17'),
	(377, 1, 0, -50017, 9, 4, 0, 39, '8'),
	(377, 1, 0, -50017, 10, 1, 0, 37, '14'),
	(377, 1, 0, -50017, 10, 1, 0, 39, '9'),
	(377, 1, 0, -50017, 10, 2, 0, 37, '15'),
	(377, 1, 0, -50017, 10, 2, 0, 39, '9'),
	(377, 1, 0, -50017, 10, 3, 0, 37, '16'),
	(377, 1, 0, -50017, 10, 3, 0, 39, '9'),
	(377, 1, 0, -50017, 10, 4, 0, 37, '17'),
	(377, 1, 0, -50017, 10, 4, 0, 39, '9'),
	(377, 1, 0, -50017, 11, 1, 0, 37, '14'),
	(377, 1, 0, -50017, 11, 1, 0, 39, '10'),
	(377, 1, 0, -50017, 11, 2, 0, 37, '15'),
	(377, 1, 0, -50017, 11, 2, 0, 39, '10'),
	(377, 1, 0, -50017, 11, 3, 0, 37, '16'),
	(377, 1, 0, -50017, 11, 3, 0, 39, '10'),
	(377, 1, 0, -50017, 11, 4, 0, 37, '17'),
	(377, 1, 0, -50017, 11, 4, 0, 39, '10'),
	(377, 1, 0, -50017, 12, 1, 0, 37, '14'),
	(377, 1, 0, -50017, 12, 1, 0, 39, '11'),
	(377, 1, 0, -50017, 12, 2, 0, 37, '15'),
	(377, 1, 0, -50017, 12, 2, 0, 39, '11'),
	(377, 1, 0, -50017, 12, 3, 0, 37, '16'),
	(377, 1, 0, -50017, 12, 3, 0, 39, '11'),
	(377, 1, 0, -50017, 12, 4, 0, 37, '17'),
	(377, 1, 0, -50017, 12, 4, 0, 39, '11'),
	(377, 1, 0, -50016, 1, 1, 0, 37, '14'),
	(377, 1, 0, -50016, 1, 1, 0, 39, '0'),
	(377, 1, 0, -50016, 1, 2, 0, 37, '15'),
	(377, 1, 0, -50016, 1, 2, 0, 39, '0'),
	(377, 1, 0, -50016, 1, 3, 0, 37, '16'),
	(377, 1, 0, -50016, 1, 3, 0, 39, '0'),
	(377, 1, 0, -50016, 1, 4, 0, 37, '17'),
	(377, 1, 0, -50016, 1, 4, 0, 39, '0'),
	(377, 1, 0, -50016, 2, 1, 0, 37, '14'),
	(377, 1, 0, -50016, 2, 1, 0, 39, '1'),
	(377, 1, 0, -50016, 2, 2, 0, 37, '15'),
	(377, 1, 0, -50016, 2, 2, 0, 39, '1'),
	(377, 1, 0, -50016, 2, 3, 0, 37, '16'),
	(377, 1, 0, -50016, 2, 3, 0, 39, '1'),
	(377, 1, 0, -50016, 2, 4, 0, 37, '17'),
	(377, 1, 0, -50016, 2, 4, 0, 39, '1'),
	(377, 1, 0, -50016, 3, 1, 0, 37, '14'),
	(377, 1, 0, -50016, 3, 1, 0, 39, '2'),
	(377, 1, 0, -50016, 3, 2, 0, 37, '15'),
	(377, 1, 0, -50016, 3, 2, 0, 39, '2'),
	(377, 1, 0, -50016, 3, 3, 0, 37, '16'),
	(377, 1, 0, -50016, 3, 3, 0, 39, '2'),
	(377, 1, 0, -50016, 3, 4, 0, 37, '17'),
	(377, 1, 0, -50016, 3, 4, 0, 39, '2'),
	(377, 1, 0, -50016, 4, 1, 0, 37, '14'),
	(377, 1, 0, -50016, 4, 1, 0, 39, '3'),
	(377, 1, 0, -50016, 4, 2, 0, 37, '15'),
	(377, 1, 0, -50016, 4, 2, 0, 39, '3'),
	(377, 1, 0, -50016, 4, 3, 0, 37, '16'),
	(377, 1, 0, -50016, 4, 3, 0, 39, '3'),
	(377, 1, 0, -50016, 4, 4, 0, 37, '17'),
	(377, 1, 0, -50016, 4, 4, 0, 39, '3'),
	(377, 1, 0, -50016, 5, 1, 0, 37, '14'),
	(377, 1, 0, -50016, 5, 1, 0, 39, '4'),
	(377, 1, 0, -50016, 5, 2, 0, 37, '15'),
	(377, 1, 0, -50016, 5, 2, 0, 39, '4'),
	(377, 1, 0, -50016, 5, 3, 0, 37, '16'),
	(377, 1, 0, -50016, 5, 3, 0, 39, '4'),
	(377, 1, 0, -50016, 5, 4, 0, 37, '17'),
	(377, 1, 0, -50016, 5, 4, 0, 39, '4'),
	(377, 1, 0, -50016, 6, 1, 0, 37, '14'),
	(377, 1, 0, -50016, 6, 1, 0, 39, '5'),
	(377, 1, 0, -50016, 6, 2, 0, 37, '15'),
	(377, 1, 0, -50016, 6, 2, 0, 39, '5'),
	(377, 1, 0, -50016, 6, 3, 0, 37, '16'),
	(377, 1, 0, -50016, 6, 3, 0, 39, '5'),
	(377, 1, 0, -50016, 6, 4, 0, 37, '17'),
	(377, 1, 0, -50016, 6, 4, 0, 39, '5'),
	(377, 1, 0, -50016, 7, 1, 0, 37, '14'),
	(377, 1, 0, -50016, 7, 1, 0, 39, '6'),
	(377, 1, 0, -50016, 7, 2, 0, 37, '15'),
	(377, 1, 0, -50016, 7, 2, 0, 39, '6'),
	(377, 1, 0, -50016, 7, 3, 0, 37, '16'),
	(377, 1, 0, -50016, 7, 3, 0, 39, '6'),
	(377, 1, 0, -50016, 7, 4, 0, 37, '17'),
	(377, 1, 0, -50016, 7, 4, 0, 39, '6'),
	(377, 1, 0, -50016, 8, 1, 0, 37, '14'),
	(377, 1, 0, -50016, 8, 1, 0, 39, '7'),
	(377, 1, 0, -50016, 8, 2, 0, 37, '15'),
	(377, 1, 0, -50016, 8, 2, 0, 39, '7'),
	(377, 1, 0, -50016, 8, 3, 0, 37, '16'),
	(377, 1, 0, -50016, 8, 3, 0, 39, '7'),
	(377, 1, 0, -50016, 8, 4, 0, 37, '17'),
	(377, 1, 0, -50016, 8, 4, 0, 39, '7'),
	(377, 1, 0, -50016, 9, 1, 0, 37, '14'),
	(377, 1, 0, -50016, 9, 1, 0, 39, '8'),
	(377, 1, 0, -50016, 9, 2, 0, 37, '15'),
	(377, 1, 0, -50016, 9, 2, 0, 39, '8'),
	(377, 1, 0, -50016, 9, 3, 0, 37, '16'),
	(377, 1, 0, -50016, 9, 3, 0, 39, '8'),
	(377, 1, 0, -50016, 9, 4, 0, 37, '17'),
	(377, 1, 0, -50016, 9, 4, 0, 39, '8'),
	(377, 1, 0, -50016, 10, 1, 0, 37, '14'),
	(377, 1, 0, -50016, 10, 1, 0, 39, '9'),
	(377, 1, 0, -50016, 10, 2, 0, 37, '15'),
	(377, 1, 0, -50016, 10, 2, 0, 39, '9'),
	(377, 1, 0, -50016, 10, 3, 0, 37, '16'),
	(377, 1, 0, -50016, 10, 3, 0, 39, '9'),
	(377, 1, 0, -50016, 10, 4, 0, 37, '17'),
	(377, 1, 0, -50016, 10, 4, 0, 39, '9'),
	(377, 1, 0, -50016, 11, 1, 0, 37, '14'),
	(377, 1, 0, -50016, 11, 1, 0, 39, '10'),
	(377, 1, 0, -50016, 11, 2, 0, 37, '15'),
	(377, 1, 0, -50016, 11, 2, 0, 39, '10'),
	(377, 1, 0, -50016, 11, 3, 0, 37, '16'),
	(377, 1, 0, -50016, 11, 3, 0, 39, '10'),
	(377, 1, 0, -50016, 11, 4, 0, 37, '17'),
	(377, 1, 0, -50016, 11, 4, 0, 39, '10'),
	(377, 1, 0, -50016, 12, 1, 0, 37, '14'),
	(377, 1, 0, -50016, 12, 1, 0, 39, '11'),
	(377, 1, 0, -50016, 12, 2, 0, 37, '15'),
	(377, 1, 0, -50016, 12, 2, 0, 39, '11'),
	(377, 1, 0, -50016, 12, 3, 0, 37, '16'),
	(377, 1, 0, -50016, 12, 3, 0, 39, '11'),
	(377, 1, 0, -50016, 12, 4, 0, 37, '17'),
	(377, 1, 0, -50016, 12, 4, 0, 39, '11'),
	(377, 1, 0, -50015, 1, 1, 0, 37, '14'),
	(377, 1, 0, -50015, 1, 1, 0, 39, '0'),
	(377, 1, 0, -50015, 1, 2, 0, 37, '15'),
	(377, 1, 0, -50015, 1, 2, 0, 39, '0'),
	(377, 1, 0, -50015, 1, 3, 0, 37, '16'),
	(377, 1, 0, -50015, 1, 3, 0, 39, '0'),
	(377, 1, 0, -50015, 1, 4, 0, 37, '17'),
	(377, 1, 0, -50015, 1, 4, 0, 39, '0'),
	(377, 1, 0, -50015, 2, 1, 0, 37, '14'),
	(377, 1, 0, -50015, 2, 1, 0, 39, '1'),
	(377, 1, 0, -50015, 2, 2, 0, 37, '15'),
	(377, 1, 0, -50015, 2, 2, 0, 39, '1'),
	(377, 1, 0, -50015, 2, 3, 0, 37, '16'),
	(377, 1, 0, -50015, 2, 3, 0, 39, '1'),
	(377, 1, 0, -50015, 2, 4, 0, 37, '17'),
	(377, 1, 0, -50015, 2, 4, 0, 39, '1'),
	(377, 1, 0, -50015, 3, 1, 0, 37, '14'),
	(377, 1, 0, -50015, 3, 1, 0, 39, '2'),
	(377, 1, 0, -50015, 3, 2, 0, 37, '15'),
	(377, 1, 0, -50015, 3, 2, 0, 39, '2'),
	(377, 1, 0, -50015, 3, 3, 0, 37, '16'),
	(377, 1, 0, -50015, 3, 3, 0, 39, '2'),
	(377, 1, 0, -50015, 3, 4, 0, 37, '17'),
	(377, 1, 0, -50015, 3, 4, 0, 39, '2'),
	(377, 1, 0, -50015, 4, 1, 0, 37, '14'),
	(377, 1, 0, -50015, 4, 1, 0, 39, '3'),
	(377, 1, 0, -50015, 4, 2, 0, 37, '15'),
	(377, 1, 0, -50015, 4, 2, 0, 39, '3'),
	(377, 1, 0, -50015, 4, 3, 0, 37, '16'),
	(377, 1, 0, -50015, 4, 3, 0, 39, '3'),
	(377, 1, 0, -50015, 4, 4, 0, 37, '17'),
	(377, 1, 0, -50015, 4, 4, 0, 39, '3'),
	(377, 1, 0, -50015, 5, 1, 0, 37, '14'),
	(377, 1, 0, -50015, 5, 1, 0, 39, '4'),
	(377, 1, 0, -50015, 5, 2, 0, 37, '15'),
	(377, 1, 0, -50015, 5, 2, 0, 39, '4'),
	(377, 1, 0, -50015, 5, 3, 0, 37, '16'),
	(377, 1, 0, -50015, 5, 3, 0, 39, '4'),
	(377, 1, 0, -50015, 5, 4, 0, 37, '17'),
	(377, 1, 0, -50015, 5, 4, 0, 39, '4'),
	(377, 1, 0, -50015, 6, 1, 0, 37, '14'),
	(377, 1, 0, -50015, 6, 1, 0, 39, '5'),
	(377, 1, 0, -50015, 6, 2, 0, 37, '15'),
	(377, 1, 0, -50015, 6, 2, 0, 39, '5'),
	(377, 1, 0, -50015, 6, 3, 0, 37, '16'),
	(377, 1, 0, -50015, 6, 3, 0, 39, '5'),
	(377, 1, 0, -50015, 6, 4, 0, 37, '17'),
	(377, 1, 0, -50015, 6, 4, 0, 39, '5'),
	(377, 1, 0, -50015, 7, 1, 0, 37, '14'),
	(377, 1, 0, -50015, 7, 1, 0, 39, '6'),
	(377, 1, 0, -50015, 7, 2, 0, 37, '15'),
	(377, 1, 0, -50015, 7, 2, 0, 39, '6'),
	(377, 1, 0, -50015, 7, 3, 0, 37, '16'),
	(377, 1, 0, -50015, 7, 3, 0, 39, '6'),
	(377, 1, 0, -50015, 7, 4, 0, 37, '17'),
	(377, 1, 0, -50015, 7, 4, 0, 39, '6'),
	(377, 1, 0, -50015, 8, 1, 0, 37, '14'),
	(377, 1, 0, -50015, 8, 1, 0, 39, '7'),
	(377, 1, 0, -50015, 8, 2, 0, 37, '15'),
	(377, 1, 0, -50015, 8, 2, 0, 39, '7'),
	(377, 1, 0, -50015, 8, 3, 0, 37, '16'),
	(377, 1, 0, -50015, 8, 3, 0, 39, '7'),
	(377, 1, 0, -50015, 8, 4, 0, 37, '17'),
	(377, 1, 0, -50015, 8, 4, 0, 39, '7'),
	(377, 1, 0, -50015, 9, 1, 0, 37, '14'),
	(377, 1, 0, -50015, 9, 1, 0, 39, '8'),
	(377, 1, 0, -50015, 9, 2, 0, 37, '15'),
	(377, 1, 0, -50015, 9, 2, 0, 39, '8'),
	(377, 1, 0, -50015, 9, 3, 0, 37, '16'),
	(377, 1, 0, -50015, 9, 3, 0, 39, '8'),
	(377, 1, 0, -50015, 9, 4, 0, 37, '17'),
	(377, 1, 0, -50015, 9, 4, 0, 39, '8'),
	(377, 1, 0, -50015, 10, 1, 0, 37, '14'),
	(377, 1, 0, -50015, 10, 1, 0, 39, '9'),
	(377, 1, 0, -50015, 10, 2, 0, 37, '15'),
	(377, 1, 0, -50015, 10, 2, 0, 39, '9'),
	(377, 1, 0, -50015, 10, 3, 0, 37, '16'),
	(377, 1, 0, -50015, 10, 3, 0, 39, '9'),
	(377, 1, 0, -50015, 10, 4, 0, 37, '17'),
	(377, 1, 0, -50015, 10, 4, 0, 39, '9'),
	(377, 1, 0, -50015, 11, 1, 0, 37, '14'),
	(377, 1, 0, -50015, 11, 1, 0, 39, '10'),
	(377, 1, 0, -50015, 11, 2, 0, 37, '15'),
	(377, 1, 0, -50015, 11, 2, 0, 39, '10'),
	(377, 1, 0, -50015, 11, 3, 0, 37, '16'),
	(377, 1, 0, -50015, 11, 3, 0, 39, '10'),
	(377, 1, 0, -50015, 11, 4, 0, 37, '17'),
	(377, 1, 0, -50015, 11, 4, 0, 39, '10'),
	(377, 1, 0, -50015, 12, 1, 0, 37, '14'),
	(377, 1, 0, -50015, 12, 1, 0, 39, '11'),
	(377, 1, 0, -50015, 12, 2, 0, 37, '15'),
	(377, 1, 0, -50015, 12, 2, 0, 39, '11'),
	(377, 1, 0, -50015, 12, 3, 0, 37, '16'),
	(377, 1, 0, -50015, 12, 3, 0, 39, '11'),
	(377, 1, 0, -50015, 12, 4, 0, 37, '17'),
	(377, 1, 0, -50015, 12, 4, 0, 39, '11'),
	(377, 1, 0, -50014, 1, 1, 0, 37, '14'),
	(377, 1, 0, -50014, 1, 1, 0, 39, '0'),
	(377, 1, 0, -50014, 1, 2, 0, 37, '15'),
	(377, 1, 0, -50014, 1, 2, 0, 39, '0'),
	(377, 1, 0, -50014, 1, 3, 0, 37, '16'),
	(377, 1, 0, -50014, 1, 3, 0, 39, '0'),
	(377, 1, 0, -50014, 1, 4, 0, 37, '17'),
	(377, 1, 0, -50014, 1, 4, 0, 39, '0'),
	(377, 1, 0, -50014, 2, 1, 0, 37, '14'),
	(377, 1, 0, -50014, 2, 1, 0, 39, '1'),
	(377, 1, 0, -50014, 2, 2, 0, 37, '15'),
	(377, 1, 0, -50014, 2, 2, 0, 39, '1'),
	(377, 1, 0, -50014, 2, 3, 0, 37, '16'),
	(377, 1, 0, -50014, 2, 3, 0, 39, '1'),
	(377, 1, 0, -50014, 2, 4, 0, 37, '17'),
	(377, 1, 0, -50014, 2, 4, 0, 39, '1'),
	(377, 1, 0, -50014, 3, 1, 0, 37, '14'),
	(377, 1, 0, -50014, 3, 1, 0, 39, '2'),
	(377, 1, 0, -50014, 3, 2, 0, 37, '15'),
	(377, 1, 0, -50014, 3, 2, 0, 39, '2'),
	(377, 1, 0, -50014, 3, 3, 0, 37, '16'),
	(377, 1, 0, -50014, 3, 3, 0, 39, '2'),
	(377, 1, 0, -50014, 3, 4, 0, 37, '17'),
	(377, 1, 0, -50014, 3, 4, 0, 39, '2'),
	(377, 1, 0, -50014, 4, 1, 0, 37, '14'),
	(377, 1, 0, -50014, 4, 1, 0, 39, '3'),
	(377, 1, 0, -50014, 4, 2, 0, 37, '15'),
	(377, 1, 0, -50014, 4, 2, 0, 39, '3'),
	(377, 1, 0, -50014, 4, 3, 0, 37, '16'),
	(377, 1, 0, -50014, 4, 3, 0, 39, '3'),
	(377, 1, 0, -50014, 4, 4, 0, 37, '17'),
	(377, 1, 0, -50014, 4, 4, 0, 39, '3'),
	(377, 1, 0, -50014, 5, 1, 0, 37, '14'),
	(377, 1, 0, -50014, 5, 1, 0, 39, '4'),
	(377, 1, 0, -50014, 5, 2, 0, 37, '15'),
	(377, 1, 0, -50014, 5, 2, 0, 39, '4'),
	(377, 1, 0, -50014, 5, 3, 0, 37, '16'),
	(377, 1, 0, -50014, 5, 3, 0, 39, '4'),
	(377, 1, 0, -50014, 5, 4, 0, 37, '17'),
	(377, 1, 0, -50014, 5, 4, 0, 39, '4'),
	(377, 1, 0, -50014, 6, 1, 0, 37, '14'),
	(377, 1, 0, -50014, 6, 1, 0, 39, '5'),
	(377, 1, 0, -50014, 6, 2, 0, 37, '15'),
	(377, 1, 0, -50014, 6, 2, 0, 39, '5'),
	(377, 1, 0, -50014, 6, 3, 0, 37, '16'),
	(377, 1, 0, -50014, 6, 3, 0, 39, '5'),
	(377, 1, 0, -50014, 6, 4, 0, 37, '17'),
	(377, 1, 0, -50014, 6, 4, 0, 39, '5'),
	(377, 1, 0, -50014, 7, 1, 0, 37, '14'),
	(377, 1, 0, -50014, 7, 1, 0, 39, '6'),
	(377, 1, 0, -50014, 7, 2, 0, 37, '15'),
	(377, 1, 0, -50014, 7, 2, 0, 39, '6'),
	(377, 1, 0, -50014, 7, 3, 0, 37, '16'),
	(377, 1, 0, -50014, 7, 3, 0, 39, '6'),
	(377, 1, 0, -50014, 7, 4, 0, 37, '17'),
	(377, 1, 0, -50014, 7, 4, 0, 39, '6'),
	(377, 1, 0, -50014, 8, 1, 0, 37, '14'),
	(377, 1, 0, -50014, 8, 1, 0, 39, '7'),
	(377, 1, 0, -50014, 8, 2, 0, 37, '15'),
	(377, 1, 0, -50014, 8, 2, 0, 39, '7'),
	(377, 1, 0, -50014, 8, 3, 0, 37, '16'),
	(377, 1, 0, -50014, 8, 3, 0, 39, '7'),
	(377, 1, 0, -50014, 8, 4, 0, 37, '17'),
	(377, 1, 0, -50014, 8, 4, 0, 39, '7'),
	(377, 1, 0, -50014, 9, 1, 0, 37, '14'),
	(377, 1, 0, -50014, 9, 1, 0, 39, '8'),
	(377, 1, 0, -50014, 9, 2, 0, 37, '15'),
	(377, 1, 0, -50014, 9, 2, 0, 39, '8'),
	(377, 1, 0, -50014, 9, 3, 0, 37, '16'),
	(377, 1, 0, -50014, 9, 3, 0, 39, '8'),
	(377, 1, 0, -50014, 9, 4, 0, 37, '17'),
	(377, 1, 0, -50014, 9, 4, 0, 39, '8'),
	(377, 1, 0, -50014, 10, 1, 0, 37, '14'),
	(377, 1, 0, -50014, 10, 1, 0, 39, '9'),
	(377, 1, 0, -50014, 10, 2, 0, 37, '15'),
	(377, 1, 0, -50014, 10, 2, 0, 39, '9'),
	(377, 1, 0, -50014, 10, 3, 0, 37, '16'),
	(377, 1, 0, -50014, 10, 3, 0, 39, '9'),
	(377, 1, 0, -50014, 10, 4, 0, 37, '17'),
	(377, 1, 0, -50014, 10, 4, 0, 39, '9'),
	(377, 1, 0, -50014, 11, 1, 0, 37, '14'),
	(377, 1, 0, -50014, 11, 1, 0, 39, '10'),
	(377, 1, 0, -50014, 11, 2, 0, 37, '15'),
	(377, 1, 0, -50014, 11, 2, 0, 39, '10'),
	(377, 1, 0, -50014, 11, 3, 0, 37, '16'),
	(377, 1, 0, -50014, 11, 3, 0, 39, '10'),
	(377, 1, 0, -50014, 11, 4, 0, 37, '17'),
	(377, 1, 0, -50014, 11, 4, 0, 39, '10'),
	(377, 1, 0, -50014, 12, 1, 0, 37, '14'),
	(377, 1, 0, -50014, 12, 1, 0, 39, '11'),
	(377, 1, 0, -50014, 12, 2, 0, 37, '15'),
	(377, 1, 0, -50014, 12, 2, 0, 39, '11'),
	(377, 1, 0, -50014, 12, 3, 0, 37, '16'),
	(377, 1, 0, -50014, 12, 3, 0, 39, '11'),
	(377, 1, 0, -50014, 12, 4, 0, 37, '17'),
	(377, 1, 0, -50014, 12, 4, 0, 39, '11'),
	(377, 1, 0, -50013, 1, 1, 0, 37, '14'),
	(377, 1, 0, -50013, 1, 1, 0, 39, '0'),
	(377, 1, 0, -50013, 1, 2, 0, 37, '15'),
	(377, 1, 0, -50013, 1, 2, 0, 39, '0'),
	(377, 1, 0, -50013, 1, 3, 0, 37, '16'),
	(377, 1, 0, -50013, 1, 3, 0, 39, '0'),
	(377, 1, 0, -50013, 1, 4, 0, 37, '17'),
	(377, 1, 0, -50013, 1, 4, 0, 39, '0'),
	(377, 1, 0, -50013, 2, 1, 0, 37, '14'),
	(377, 1, 0, -50013, 2, 1, 0, 39, '1'),
	(377, 1, 0, -50013, 2, 2, 0, 37, '15'),
	(377, 1, 0, -50013, 2, 2, 0, 39, '1'),
	(377, 1, 0, -50013, 2, 3, 0, 37, '16'),
	(377, 1, 0, -50013, 2, 3, 0, 39, '1'),
	(377, 1, 0, -50013, 2, 4, 0, 37, '17'),
	(377, 1, 0, -50013, 2, 4, 0, 39, '1'),
	(377, 1, 0, -50013, 3, 1, 0, 37, '14'),
	(377, 1, 0, -50013, 3, 1, 0, 39, '2'),
	(377, 1, 0, -50013, 3, 2, 0, 37, '15'),
	(377, 1, 0, -50013, 3, 2, 0, 39, '2'),
	(377, 1, 0, -50013, 3, 3, 0, 37, '16'),
	(377, 1, 0, -50013, 3, 3, 0, 39, '2'),
	(377, 1, 0, -50013, 3, 4, 0, 37, '17'),
	(377, 1, 0, -50013, 3, 4, 0, 39, '2'),
	(377, 1, 0, -50013, 4, 1, 0, 37, '14'),
	(377, 1, 0, -50013, 4, 1, 0, 39, '3'),
	(377, 1, 0, -50013, 4, 2, 0, 37, '15'),
	(377, 1, 0, -50013, 4, 2, 0, 39, '3'),
	(377, 1, 0, -50013, 4, 3, 0, 37, '16'),
	(377, 1, 0, -50013, 4, 3, 0, 39, '3'),
	(377, 1, 0, -50013, 4, 4, 0, 37, '17'),
	(377, 1, 0, -50013, 4, 4, 0, 39, '3'),
	(377, 1, 0, -50013, 5, 1, 0, 37, '14'),
	(377, 1, 0, -50013, 5, 1, 0, 39, '4'),
	(377, 1, 0, -50013, 5, 2, 0, 37, '15'),
	(377, 1, 0, -50013, 5, 2, 0, 39, '4'),
	(377, 1, 0, -50013, 5, 3, 0, 37, '16'),
	(377, 1, 0, -50013, 5, 3, 0, 39, '4'),
	(377, 1, 0, -50013, 5, 4, 0, 37, '17'),
	(377, 1, 0, -50013, 5, 4, 0, 39, '4'),
	(377, 1, 0, -50013, 6, 1, 0, 37, '14'),
	(377, 1, 0, -50013, 6, 1, 0, 39, '5'),
	(377, 1, 0, -50013, 6, 2, 0, 37, '15'),
	(377, 1, 0, -50013, 6, 2, 0, 39, '5'),
	(377, 1, 0, -50013, 6, 3, 0, 37, '16'),
	(377, 1, 0, -50013, 6, 3, 0, 39, '5'),
	(377, 1, 0, -50013, 6, 4, 0, 37, '17'),
	(377, 1, 0, -50013, 6, 4, 0, 39, '5'),
	(377, 1, 0, -50013, 7, 1, 0, 37, '14'),
	(377, 1, 0, -50013, 7, 1, 0, 39, '6'),
	(377, 1, 0, -50013, 7, 2, 0, 37, '15'),
	(377, 1, 0, -50013, 7, 2, 0, 39, '6'),
	(377, 1, 0, -50013, 7, 3, 0, 37, '16'),
	(377, 1, 0, -50013, 7, 3, 0, 39, '6'),
	(377, 1, 0, -50013, 7, 4, 0, 37, '17'),
	(377, 1, 0, -50013, 7, 4, 0, 39, '6'),
	(377, 1, 0, -50013, 8, 1, 0, 37, '14'),
	(377, 1, 0, -50013, 8, 1, 0, 39, '7'),
	(377, 1, 0, -50013, 8, 2, 0, 37, '15'),
	(377, 1, 0, -50013, 8, 2, 0, 39, '7'),
	(377, 1, 0, -50013, 8, 3, 0, 37, '16'),
	(377, 1, 0, -50013, 8, 3, 0, 39, '7'),
	(377, 1, 0, -50013, 8, 4, 0, 37, '17'),
	(377, 1, 0, -50013, 8, 4, 0, 39, '7'),
	(377, 1, 0, -50013, 9, 1, 0, 37, '14'),
	(377, 1, 0, -50013, 9, 1, 0, 39, '8'),
	(377, 1, 0, -50013, 9, 2, 0, 37, '15'),
	(377, 1, 0, -50013, 9, 2, 0, 39, '8'),
	(377, 1, 0, -50013, 9, 3, 0, 37, '16'),
	(377, 1, 0, -50013, 9, 3, 0, 39, '8'),
	(377, 1, 0, -50013, 9, 4, 0, 37, '17'),
	(377, 1, 0, -50013, 9, 4, 0, 39, '8'),
	(377, 1, 0, -50013, 10, 1, 0, 37, '14'),
	(377, 1, 0, -50013, 10, 1, 0, 39, '9'),
	(377, 1, 0, -50013, 10, 2, 0, 37, '15'),
	(377, 1, 0, -50013, 10, 2, 0, 39, '9'),
	(377, 1, 0, -50013, 10, 3, 0, 37, '16'),
	(377, 1, 0, -50013, 10, 3, 0, 39, '9'),
	(377, 1, 0, -50013, 10, 4, 0, 37, '17'),
	(377, 1, 0, -50013, 10, 4, 0, 39, '9'),
	(377, 1, 0, -50013, 11, 1, 0, 37, '14'),
	(377, 1, 0, -50013, 11, 1, 0, 39, '10'),
	(377, 1, 0, -50013, 11, 2, 0, 37, '15'),
	(377, 1, 0, -50013, 11, 2, 0, 39, '10'),
	(377, 1, 0, -50013, 11, 3, 0, 37, '16'),
	(377, 1, 0, -50013, 11, 3, 0, 39, '10'),
	(377, 1, 0, -50013, 11, 4, 0, 37, '17'),
	(377, 1, 0, -50013, 11, 4, 0, 39, '10'),
	(377, 1, 0, -50013, 12, 1, 0, 37, '14'),
	(377, 1, 0, -50013, 12, 1, 0, 39, '11'),
	(377, 1, 0, -50013, 12, 2, 0, 37, '15'),
	(377, 1, 0, -50013, 12, 2, 0, 39, '11'),
	(377, 1, 0, -50013, 12, 3, 0, 37, '16'),
	(377, 1, 0, -50013, 12, 3, 0, 39, '11'),
	(377, 1, 0, -50013, 12, 4, 0, 37, '17'),
	(377, 1, 0, -50013, 12, 4, 0, 39, '11'),
	(377, 1, 0, -50012, 1, 1, 0, 37, '14'),
	(377, 1, 0, -50012, 1, 1, 0, 39, '0'),
	(377, 1, 0, -50012, 1, 2, 0, 37, '15'),
	(377, 1, 0, -50012, 1, 2, 0, 39, '0'),
	(377, 1, 0, -50012, 1, 3, 0, 37, '16'),
	(377, 1, 0, -50012, 1, 3, 0, 39, '0'),
	(377, 1, 0, -50012, 1, 4, 0, 37, '17'),
	(377, 1, 0, -50012, 1, 4, 0, 39, '0'),
	(377, 1, 0, -50012, 2, 1, 0, 37, '14'),
	(377, 1, 0, -50012, 2, 1, 0, 39, '1'),
	(377, 1, 0, -50012, 2, 2, 0, 37, '15'),
	(377, 1, 0, -50012, 2, 2, 0, 39, '1'),
	(377, 1, 0, -50012, 2, 3, 0, 37, '16'),
	(377, 1, 0, -50012, 2, 3, 0, 39, '1'),
	(377, 1, 0, -50012, 2, 4, 0, 37, '17'),
	(377, 1, 0, -50012, 2, 4, 0, 39, '1'),
	(377, 1, 0, -50012, 3, 1, 0, 37, '14'),
	(377, 1, 0, -50012, 3, 1, 0, 39, '2'),
	(377, 1, 0, -50012, 3, 2, 0, 37, '15'),
	(377, 1, 0, -50012, 3, 2, 0, 39, '2'),
	(377, 1, 0, -50012, 3, 3, 0, 37, '16'),
	(377, 1, 0, -50012, 3, 3, 0, 39, '2'),
	(377, 1, 0, -50012, 3, 4, 0, 37, '17'),
	(377, 1, 0, -50012, 3, 4, 0, 39, '2'),
	(377, 1, 0, -50012, 4, 1, 0, 37, '14'),
	(377, 1, 0, -50012, 4, 1, 0, 39, '3'),
	(377, 1, 0, -50012, 4, 2, 0, 37, '15'),
	(377, 1, 0, -50012, 4, 2, 0, 39, '3'),
	(377, 1, 0, -50012, 4, 3, 0, 37, '16'),
	(377, 1, 0, -50012, 4, 3, 0, 39, '3'),
	(377, 1, 0, -50012, 4, 4, 0, 37, '17'),
	(377, 1, 0, -50012, 4, 4, 0, 39, '3'),
	(377, 1, 0, -50012, 5, 1, 0, 37, '14'),
	(377, 1, 0, -50012, 5, 1, 0, 39, '4'),
	(377, 1, 0, -50012, 5, 2, 0, 37, '15'),
	(377, 1, 0, -50012, 5, 2, 0, 39, '4'),
	(377, 1, 0, -50012, 5, 3, 0, 37, '16'),
	(377, 1, 0, -50012, 5, 3, 0, 39, '4'),
	(377, 1, 0, -50012, 5, 4, 0, 37, '17'),
	(377, 1, 0, -50012, 5, 4, 0, 39, '4'),
	(377, 1, 0, -50012, 6, 1, 0, 37, '14'),
	(377, 1, 0, -50012, 6, 1, 0, 39, '5'),
	(377, 1, 0, -50012, 6, 2, 0, 37, '15'),
	(377, 1, 0, -50012, 6, 2, 0, 39, '5'),
	(377, 1, 0, -50012, 6, 3, 0, 37, '16'),
	(377, 1, 0, -50012, 6, 3, 0, 39, '5'),
	(377, 1, 0, -50012, 6, 4, 0, 37, '17'),
	(377, 1, 0, -50012, 6, 4, 0, 39, '5'),
	(377, 1, 0, -50012, 7, 1, 0, 37, '14'),
	(377, 1, 0, -50012, 7, 1, 0, 39, '6'),
	(377, 1, 0, -50012, 7, 2, 0, 37, '15'),
	(377, 1, 0, -50012, 7, 2, 0, 39, '6'),
	(377, 1, 0, -50012, 7, 3, 0, 37, '16'),
	(377, 1, 0, -50012, 7, 3, 0, 39, '6'),
	(377, 1, 0, -50012, 7, 4, 0, 37, '17'),
	(377, 1, 0, -50012, 7, 4, 0, 39, '6'),
	(377, 1, 0, -50012, 8, 1, 0, 37, '14'),
	(377, 1, 0, -50012, 8, 1, 0, 39, '7'),
	(377, 1, 0, -50012, 8, 2, 0, 37, '15'),
	(377, 1, 0, -50012, 8, 2, 0, 39, '7'),
	(377, 1, 0, -50012, 8, 3, 0, 37, '16'),
	(377, 1, 0, -50012, 8, 3, 0, 39, '7'),
	(377, 1, 0, -50012, 8, 4, 0, 37, '17'),
	(377, 1, 0, -50012, 8, 4, 0, 39, '7'),
	(377, 1, 0, -50012, 9, 1, 0, 37, '14'),
	(377, 1, 0, -50012, 9, 1, 0, 39, '8'),
	(377, 1, 0, -50012, 9, 2, 0, 37, '15'),
	(377, 1, 0, -50012, 9, 2, 0, 39, '8'),
	(377, 1, 0, -50012, 9, 3, 0, 37, '16'),
	(377, 1, 0, -50012, 9, 3, 0, 39, '8'),
	(377, 1, 0, -50012, 9, 4, 0, 37, '17'),
	(377, 1, 0, -50012, 9, 4, 0, 39, '8'),
	(377, 1, 0, -50012, 10, 1, 0, 37, '14'),
	(377, 1, 0, -50012, 10, 1, 0, 39, '9'),
	(377, 1, 0, -50012, 10, 2, 0, 37, '15'),
	(377, 1, 0, -50012, 10, 2, 0, 39, '9'),
	(377, 1, 0, -50012, 10, 3, 0, 37, '16'),
	(377, 1, 0, -50012, 10, 3, 0, 39, '9'),
	(377, 1, 0, -50012, 10, 4, 0, 37, '17'),
	(377, 1, 0, -50012, 10, 4, 0, 39, '9'),
	(377, 1, 0, -50012, 11, 1, 0, 37, '14'),
	(377, 1, 0, -50012, 11, 1, 0, 39, '10'),
	(377, 1, 0, -50012, 11, 2, 0, 37, '15'),
	(377, 1, 0, -50012, 11, 2, 0, 39, '10'),
	(377, 1, 0, -50012, 11, 3, 0, 37, '16'),
	(377, 1, 0, -50012, 11, 3, 0, 39, '10'),
	(377, 1, 0, -50012, 11, 4, 0, 37, '17'),
	(377, 1, 0, -50012, 11, 4, 0, 39, '10'),
	(377, 1, 0, -50012, 12, 1, 0, 37, '14'),
	(377, 1, 0, -50012, 12, 1, 0, 39, '11'),
	(377, 1, 0, -50012, 12, 2, 0, 37, '15'),
	(377, 1, 0, -50012, 12, 2, 0, 39, '11'),
	(377, 1, 0, -50012, 12, 3, 0, 37, '16'),
	(377, 1, 0, -50012, 12, 3, 0, 39, '11'),
	(377, 1, 0, -50012, 12, 4, 0, 37, '17'),
	(377, 1, 0, -50012, 12, 4, 0, 39, '11'),
	(377, 1, 0, -50011, 1, 1, 0, 37, '14'),
	(377, 1, 0, -50011, 1, 1, 0, 39, '0'),
	(377, 1, 0, -50011, 1, 2, 0, 37, '15'),
	(377, 1, 0, -50011, 1, 2, 0, 39, '0'),
	(377, 1, 0, -50011, 1, 3, 0, 37, '16'),
	(377, 1, 0, -50011, 1, 3, 0, 39, '0'),
	(377, 1, 0, -50011, 1, 4, 0, 37, '17'),
	(377, 1, 0, -50011, 1, 4, 0, 39, '0'),
	(377, 1, 0, -50011, 2, 1, 0, 37, '14'),
	(377, 1, 0, -50011, 2, 1, 0, 39, '1'),
	(377, 1, 0, -50011, 2, 2, 0, 37, '15'),
	(377, 1, 0, -50011, 2, 2, 0, 39, '1'),
	(377, 1, 0, -50011, 2, 3, 0, 37, '16'),
	(377, 1, 0, -50011, 2, 3, 0, 39, '1'),
	(377, 1, 0, -50011, 2, 4, 0, 37, '17'),
	(377, 1, 0, -50011, 2, 4, 0, 39, '1'),
	(377, 1, 0, -50011, 3, 1, 0, 37, '14'),
	(377, 1, 0, -50011, 3, 1, 0, 39, '2'),
	(377, 1, 0, -50011, 3, 2, 0, 37, '15'),
	(377, 1, 0, -50011, 3, 2, 0, 39, '2'),
	(377, 1, 0, -50011, 3, 3, 0, 37, '16'),
	(377, 1, 0, -50011, 3, 3, 0, 39, '2'),
	(377, 1, 0, -50011, 3, 4, 0, 37, '17'),
	(377, 1, 0, -50011, 3, 4, 0, 39, '2'),
	(377, 1, 0, -50011, 4, 1, 0, 37, '14'),
	(377, 1, 0, -50011, 4, 1, 0, 39, '3'),
	(377, 1, 0, -50011, 4, 2, 0, 37, '15'),
	(377, 1, 0, -50011, 4, 2, 0, 39, '3'),
	(377, 1, 0, -50011, 4, 3, 0, 37, '16'),
	(377, 1, 0, -50011, 4, 3, 0, 39, '3'),
	(377, 1, 0, -50011, 4, 4, 0, 37, '17'),
	(377, 1, 0, -50011, 4, 4, 0, 39, '3'),
	(377, 1, 0, -50011, 5, 1, 0, 37, '14'),
	(377, 1, 0, -50011, 5, 1, 0, 39, '4'),
	(377, 1, 0, -50011, 5, 2, 0, 37, '15'),
	(377, 1, 0, -50011, 5, 2, 0, 39, '4'),
	(377, 1, 0, -50011, 5, 3, 0, 37, '16'),
	(377, 1, 0, -50011, 5, 3, 0, 39, '4'),
	(377, 1, 0, -50011, 5, 4, 0, 37, '17'),
	(377, 1, 0, -50011, 5, 4, 0, 39, '4'),
	(377, 1, 0, -50011, 6, 1, 0, 37, '14'),
	(377, 1, 0, -50011, 6, 1, 0, 39, '5'),
	(377, 1, 0, -50011, 6, 2, 0, 37, '15'),
	(377, 1, 0, -50011, 6, 2, 0, 39, '5'),
	(377, 1, 0, -50011, 6, 3, 0, 37, '16'),
	(377, 1, 0, -50011, 6, 3, 0, 39, '5'),
	(377, 1, 0, -50011, 6, 4, 0, 37, '17'),
	(377, 1, 0, -50011, 6, 4, 0, 39, '5'),
	(377, 1, 0, -50011, 7, 1, 0, 37, '14'),
	(377, 1, 0, -50011, 7, 1, 0, 39, '6'),
	(377, 1, 0, -50011, 7, 2, 0, 37, '15'),
	(377, 1, 0, -50011, 7, 2, 0, 39, '6'),
	(377, 1, 0, -50011, 7, 3, 0, 37, '16'),
	(377, 1, 0, -50011, 7, 3, 0, 39, '6'),
	(377, 1, 0, -50011, 7, 4, 0, 37, '17'),
	(377, 1, 0, -50011, 7, 4, 0, 39, '6'),
	(377, 1, 0, -50011, 8, 1, 0, 37, '14'),
	(377, 1, 0, -50011, 8, 1, 0, 39, '7'),
	(377, 1, 0, -50011, 8, 2, 0, 37, '15'),
	(377, 1, 0, -50011, 8, 2, 0, 39, '7'),
	(377, 1, 0, -50011, 8, 3, 0, 37, '16'),
	(377, 1, 0, -50011, 8, 3, 0, 39, '7'),
	(377, 1, 0, -50011, 8, 4, 0, 37, '17'),
	(377, 1, 0, -50011, 8, 4, 0, 39, '7'),
	(377, 1, 0, -50011, 9, 1, 0, 37, '14'),
	(377, 1, 0, -50011, 9, 1, 0, 39, '8'),
	(377, 1, 0, -50011, 9, 2, 0, 37, '15'),
	(377, 1, 0, -50011, 9, 2, 0, 39, '8'),
	(377, 1, 0, -50011, 9, 3, 0, 37, '16'),
	(377, 1, 0, -50011, 9, 3, 0, 39, '8'),
	(377, 1, 0, -50011, 9, 4, 0, 37, '17'),
	(377, 1, 0, -50011, 9, 4, 0, 39, '8'),
	(377, 1, 0, -50011, 10, 1, 0, 37, '14'),
	(377, 1, 0, -50011, 10, 1, 0, 39, '9'),
	(377, 1, 0, -50011, 10, 2, 0, 37, '15'),
	(377, 1, 0, -50011, 10, 2, 0, 39, '9'),
	(377, 1, 0, -50011, 10, 3, 0, 37, '16'),
	(377, 1, 0, -50011, 10, 3, 0, 39, '9'),
	(377, 1, 0, -50011, 10, 4, 0, 37, '17'),
	(377, 1, 0, -50011, 10, 4, 0, 39, '9'),
	(377, 1, 0, -50011, 11, 1, 0, 37, '14'),
	(377, 1, 0, -50011, 11, 1, 0, 39, '10'),
	(377, 1, 0, -50011, 11, 2, 0, 37, '15'),
	(377, 1, 0, -50011, 11, 2, 0, 39, '10'),
	(377, 1, 0, -50011, 11, 3, 0, 37, '16'),
	(377, 1, 0, -50011, 11, 3, 0, 39, '10'),
	(377, 1, 0, -50011, 11, 4, 0, 37, '17'),
	(377, 1, 0, -50011, 11, 4, 0, 39, '10'),
	(377, 1, 0, -50011, 12, 1, 0, 37, '14'),
	(377, 1, 0, -50011, 12, 1, 0, 39, '11'),
	(377, 1, 0, -50011, 12, 2, 0, 37, '15'),
	(377, 1, 0, -50011, 12, 2, 0, 39, '11'),
	(377, 1, 0, -50011, 12, 3, 0, 37, '16'),
	(377, 1, 0, -50011, 12, 3, 0, 39, '11'),
	(377, 1, 0, -50011, 12, 4, 0, 37, '17'),
	(377, 1, 0, -50011, 12, 4, 0, 39, '11'),
	(377, 1, 0, -50008, 1, 1, 0, 37, '14'),
	(377, 1, 0, -50008, 1, 1, 0, 39, '0'),
	(377, 1, 0, -50008, 1, 2, 0, 37, '15'),
	(377, 1, 0, -50008, 1, 2, 0, 39, '0'),
	(377, 1, 0, -50008, 1, 3, 0, 37, '16'),
	(377, 1, 0, -50008, 1, 3, 0, 39, '0'),
	(377, 1, 0, -50008, 1, 4, 0, 37, '17'),
	(377, 1, 0, -50008, 1, 4, 0, 39, '0'),
	(377, 1, 0, -50008, 2, 1, 0, 37, '14'),
	(377, 1, 0, -50008, 2, 1, 0, 39, '1'),
	(377, 1, 0, -50008, 2, 2, 0, 37, '15'),
	(377, 1, 0, -50008, 2, 2, 0, 39, '1'),
	(377, 1, 0, -50008, 2, 3, 0, 37, '16'),
	(377, 1, 0, -50008, 2, 3, 0, 39, '1'),
	(377, 1, 0, -50008, 2, 4, 0, 37, '17'),
	(377, 1, 0, -50008, 2, 4, 0, 39, '1'),
	(377, 1, 0, -50008, 3, 1, 0, 37, '14'),
	(377, 1, 0, -50008, 3, 1, 0, 39, '2'),
	(377, 1, 0, -50008, 3, 2, 0, 37, '15'),
	(377, 1, 0, -50008, 3, 2, 0, 39, '2'),
	(377, 1, 0, -50008, 3, 3, 0, 37, '16'),
	(377, 1, 0, -50008, 3, 3, 0, 39, '2'),
	(377, 1, 0, -50008, 3, 4, 0, 37, '17'),
	(377, 1, 0, -50008, 3, 4, 0, 39, '2'),
	(377, 1, 0, -50008, 4, 1, 0, 37, '14'),
	(377, 1, 0, -50008, 4, 1, 0, 39, '3'),
	(377, 1, 0, -50008, 4, 2, 0, 37, '15'),
	(377, 1, 0, -50008, 4, 2, 0, 39, '3'),
	(377, 1, 0, -50008, 4, 3, 0, 37, '16'),
	(377, 1, 0, -50008, 4, 3, 0, 39, '3'),
	(377, 1, 0, -50008, 4, 4, 0, 37, '17'),
	(377, 1, 0, -50008, 4, 4, 0, 39, '3'),
	(377, 1, 0, -50008, 5, 1, 0, 37, '14'),
	(377, 1, 0, -50008, 5, 1, 0, 39, '4'),
	(377, 1, 0, -50008, 5, 2, 0, 37, '15'),
	(377, 1, 0, -50008, 5, 2, 0, 39, '4'),
	(377, 1, 0, -50008, 5, 3, 0, 37, '16'),
	(377, 1, 0, -50008, 5, 3, 0, 39, '4'),
	(377, 1, 0, -50008, 5, 4, 0, 37, '17'),
	(377, 1, 0, -50008, 5, 4, 0, 39, '4'),
	(377, 1, 0, -50008, 6, 1, 0, 37, '14'),
	(377, 1, 0, -50008, 6, 1, 0, 39, '5'),
	(377, 1, 0, -50008, 6, 2, 0, 37, '15'),
	(377, 1, 0, -50008, 6, 2, 0, 39, '5'),
	(377, 1, 0, -50008, 6, 3, 0, 37, '16'),
	(377, 1, 0, -50008, 6, 3, 0, 39, '5'),
	(377, 1, 0, -50008, 6, 4, 0, 37, '17'),
	(377, 1, 0, -50008, 6, 4, 0, 39, '5'),
	(377, 1, 0, -50008, 7, 1, 0, 37, '14'),
	(377, 1, 0, -50008, 7, 1, 0, 39, '6'),
	(377, 1, 0, -50008, 7, 2, 0, 37, '15'),
	(377, 1, 0, -50008, 7, 2, 0, 39, '6'),
	(377, 1, 0, -50008, 7, 3, 0, 37, '16'),
	(377, 1, 0, -50008, 7, 3, 0, 39, '6'),
	(377, 1, 0, -50008, 7, 4, 0, 37, '17'),
	(377, 1, 0, -50008, 7, 4, 0, 39, '6'),
	(377, 1, 0, -50008, 8, 1, 0, 37, '14'),
	(377, 1, 0, -50008, 8, 1, 0, 39, '7'),
	(377, 1, 0, -50008, 8, 2, 0, 37, '15'),
	(377, 1, 0, -50008, 8, 2, 0, 39, '7'),
	(377, 1, 0, -50008, 8, 3, 0, 37, '16'),
	(377, 1, 0, -50008, 8, 3, 0, 39, '7'),
	(377, 1, 0, -50008, 8, 4, 0, 37, '17'),
	(377, 1, 0, -50008, 8, 4, 0, 39, '7'),
	(377, 1, 0, -50008, 9, 1, 0, 37, '14'),
	(377, 1, 0, -50008, 9, 1, 0, 39, '8'),
	(377, 1, 0, -50008, 9, 2, 0, 37, '15'),
	(377, 1, 0, -50008, 9, 2, 0, 39, '8'),
	(377, 1, 0, -50008, 9, 3, 0, 37, '16'),
	(377, 1, 0, -50008, 9, 3, 0, 39, '8'),
	(377, 1, 0, -50008, 9, 4, 0, 37, '17'),
	(377, 1, 0, -50008, 9, 4, 0, 39, '8'),
	(377, 1, 0, -50008, 10, 1, 0, 37, '14'),
	(377, 1, 0, -50008, 10, 1, 0, 39, '9'),
	(377, 1, 0, -50008, 10, 2, 0, 37, '15'),
	(377, 1, 0, -50008, 10, 2, 0, 39, '9'),
	(377, 1, 0, -50008, 10, 3, 0, 37, '16'),
	(377, 1, 0, -50008, 10, 3, 0, 39, '9'),
	(377, 1, 0, -50008, 10, 4, 0, 37, '17'),
	(377, 1, 0, -50008, 10, 4, 0, 39, '9'),
	(377, 1, 0, -50008, 11, 1, 0, 37, '14'),
	(377, 1, 0, -50008, 11, 1, 0, 39, '10'),
	(377, 1, 0, -50008, 11, 2, 0, 37, '15'),
	(377, 1, 0, -50008, 11, 2, 0, 39, '10'),
	(377, 1, 0, -50008, 11, 3, 0, 37, '16'),
	(377, 1, 0, -50008, 11, 3, 0, 39, '10'),
	(377, 1, 0, -50008, 11, 4, 0, 37, '17'),
	(377, 1, 0, -50008, 11, 4, 0, 39, '10'),
	(377, 1, 0, -50008, 12, 1, 0, 37, '14'),
	(377, 1, 0, -50008, 12, 1, 0, 39, '11'),
	(377, 1, 0, -50008, 12, 2, 0, 37, '15'),
	(377, 1, 0, -50008, 12, 2, 0, 39, '11'),
	(377, 1, 0, -50008, 12, 3, 0, 37, '16'),
	(377, 1, 0, -50008, 12, 3, 0, 39, '11'),
	(377, 1, 0, -50008, 12, 4, 0, 37, '17'),
	(377, 1, 0, -50008, 12, 4, 0, 39, '11'),
	(377, 1, 0, -50006, 1, 0, 0, 39, '0'),
	(377, 1, 0, -50006, 2, 0, 0, 39, '1'),
	(377, 1, 0, -50006, 3, 0, 0, 39, '2'),
	(377, 1, 0, -50006, 4, 0, 0, 39, '3'),
	(377, 1, 0, -50006, 5, 0, 0, 39, '4'),
	(377, 1, 0, -50006, 6, 0, 0, 39, '5'),
	(377, 1, 0, -50006, 7, 0, 0, 39, '6'),
	(377, 1, 0, -50006, 8, 0, 0, 39, '7'),
	(377, 1, 0, -50006, 9, 0, 0, 39, '8'),
	(377, 1, 0, -50006, 10, 0, 0, 39, '9'),
	(377, 1, 0, -50006, 11, 0, 0, 39, '10'),
	(377, 1, 0, -50006, 12, 0, 0, 39, '11'),
	(377, 1, 0, -50006, 13, 0, 0, 39, '12'),
	(377, 1, 0, -50006, 14, 0, 0, 39, '13'),
	(377, 1, 0, -50006, 15, 0, 0, 39, '14'),
	(377, 1, 0, -50006, 16, 0, 0, 39, '15'),
	(377, 1, 0, -50006, 17, 0, 0, 39, '16'),
	(377, 1, 0, -50006, 18, 0, 0, 39, '17'),
	(377, 1, 0, -50006, 19, 0, 0, 39, '18'),
	(377, 1, 0, -50006, 20, 0, 0, 39, '19'),
	(377, 1, 0, -50006, 21, 0, 0, 39, '20'),
	(377, 1, 0, -50006, 22, 0, 0, 39, '21'),
	(377, 1, 0, -50006, 23, 0, 0, 39, '22'),
	(377, 1, 0, -50006, 24, 0, 0, 39, '23'),
	(377, 1, 0, -50006, 25, 0, 0, 39, '24'),
	(377, 1, 0, -50006, 26, 0, 0, 39, '25'),
	(377, 1, 0, -50006, 27, 0, 0, 39, '26'),
	(377, 1, 0, -50006, 28, 0, 0, 39, '27'),
	(377, 1, 0, -50006, 29, 0, 0, 39, '28'),
	(377, 1, 0, -50006, 30, 0, 0, 39, '29'),
	(377, 1, 0, -50006, 31, 0, 0, 39, '30'),
	(377, 1, 0, -50006, 32, 0, 0, 39, '31'),
	(377, 1, 0, -50006, 33, 0, 0, 39, '32'),
	(377, 1, 0, -50006, 34, 0, 0, 39, '33'),
	(377, 1, 0, -50006, 35, 0, 0, 39, '34'),
	(377, 1, 0, -50006, 36, 0, 0, 39, '35'),
	(377, 1, 0, -50006, 37, 0, 0, 39, '36'),
	(377, 1, 0, -50006, 38, 0, 0, 39, '37'),
	(377, 1, 0, -50006, 39, 0, 0, 39, '38'),
	(377, 1, 0, -50006, 40, 0, 0, 39, '39'),
	(377, 1, 0, -50006, 41, 0, 0, 39, '40'),
	(377, 1, 0, -50006, 42, 0, 0, 39, '41'),
	(377, 1, 0, -50006, 43, 0, 0, 39, '42'),
	(377, 1, 0, -50006, 44, 0, 0, 39, '43'),
	(377, 1, 0, -50006, 45, 0, 0, 39, '44'),
	(377, 1, 0, -50006, 46, 0, 0, 39, '45'),
	(377, 1, 0, -50006, 47, 0, 0, 39, '46'),
	(377, 1, 0, -50006, 48, 0, 0, 39, '47'),
	(377, 1, 0, -50006, 49, 0, 0, 39, '48'),
	(377, 1, 0, -50006, 50, 0, 0, 39, '49'),
	(377, 1, 0, -50006, 51, 0, 0, 39, '50'),
	(377, 1, 0, -50006, 52, 0, 0, 39, '51'),
	(377, 1, 0, -50006, 53, 0, 0, 39, '52'),
	(377, 1, 0, -50006, 54, 0, 0, 39, '53'),
	(377, 1, 0, -50006, 55, 0, 0, 39, '54'),
	(377, 1, 0, -50006, 56, 0, 0, 39, '55'),
	(377, 1, 0, -50006, 57, 0, 0, 39, '56'),
	(377, 1, 0, -50006, 58, 0, 0, 39, '57'),
	(377, 1, 0, -50006, 59, 0, 0, 39, '58'),
	(377, 1, 0, -50006, 60, 0, 0, 39, '59'),
	(377, 1, 0, -50006, 61, 0, 0, 39, '60'),
	(377, 1, 0, -50006, 62, 0, 0, 39, '61'),
	(377, 1, 0, -50006, 63, 0, 0, 39, '62'),
	(377, 1, 0, -50006, 64, 0, 0, 39, '63'),
	(379, 1, 1, -50921, 1, 0, 0, 12, '1.0.99.1.0.255'),
	(379, 1, 1, -50921, 2, 0, 0, 12, '0.0.98.1.0.255'),
	(379, 1, 1, -50920, 1, 0, 0, 12, '1.0.99.1.0.255'),
	(379, 1, 1, -50920, 2, 0, 0, 12, '0.0.98.1.0.255'),
	(379, 1, 1, -50919, 1, 0, 0, 12, '1.0.99.1.0.255'),
	(379, 1, 1, -50919, 2, 0, 0, 12, '0.0.98.1.0.255'),
	(379, 1, 1, -50918, 1, 0, 0, 12, '1.0.99.1.0.255'),
	(379, 1, 1, -50918, 2, 0, 0, 12, '0.0.98.1.0.255'),
	(379, 1, 1, -50304, 1, 0, 0, 12, '1.0.99.1.0.255'),
	(379, 1, 1, -50304, 2, 0, 0, 12, '0.0.98.1.0.255');
/*!40000 ALTER TABLE `src_type_mod_withe#opty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod_withe_const
CREATE TABLE IF NOT EXISTS `src_type_mod_withe_const` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `is_point` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  PRIMARY KEY (`src_type_id`,`src_type_mod_nr`,`is_point`,`withe_id`),
  CONSTRAINT `src_type_mod_withe_const_wfk` FOREIGN KEY (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) REFERENCES `src_type_mod_withe` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Prietaisų modifikacijų konfigūraciniai parametrai, kurių reikšmės pastovios tai pačiai implementacijai';

-- Dumping data for table emcor.src_type_mod_withe_const: ~12 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod_withe_const` DISABLE KEYS */;
INSERT INTO `src_type_mod_withe_const` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) VALUES
	(140, 1, 1, -50490),
	(140, 1, 1, -50489),
	(140, 1, 1, -50488),
	(209, 1, 1, -50490),
	(209, 1, 1, -50489),
	(209, 1, 1, -50488),
	(232, 1, 1, -50490),
	(232, 1, 1, -50489),
	(232, 1, 1, -50488),
	(248, 1, 1, -50490),
	(248, 1, 1, -50489),
	(248, 1, 1, -50488);
/*!40000 ALTER TABLE `src_type_mod_withe_const` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod_withe_event
CREATE TABLE IF NOT EXISTS `src_type_mod_withe_event` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `is_point` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  `withe_id` mediumint(8) DEFAULT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `event_withe_id` mediumint(8) NOT NULL COMMENT 'Įvykių vytelės identifikatorius',
  `eidl` tinyint(1) DEFAULT NULL COMMENT 'Požymis, ar įvykis sukelia rodmenų numetimą',
  UNIQUE KEY `src_type_mod_withe_event_u` (`src_type_id`,`src_type_mod_nr`,`is_point`,`withe_id`,`event_withe_id`),
  KEY `src_type_mod_withe_event_ev_i` (`event_withe_id`,`src_type_id`,`src_type_mod_nr`,`is_point`),
  CONSTRAINT `src_type_mod_withe_event_fk` FOREIGN KEY (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) REFERENCES `src_type_mod_withe` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_mod_withe_event_wt_fk` FOREIGN KEY (`event_withe_id`) REFERENCES `withe` (`withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Šaltinio tipo modifikaciją atitinkančios parametrų ir įvykių vytelių poros';

-- Dumping data for table emcor.src_type_mod_withe_event: ~179 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod_withe_event` DISABLE KEYS */;
INSERT INTO `src_type_mod_withe_event` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`, `event_withe_id`, `eidl`) VALUES
	(33, 1, 1, NULL, 10015, 1),
	(33, 1, 1, NULL, 10017, NULL),
	(25, 1, 1, NULL, 10017, NULL),
	(25, 2, 1, NULL, 10017, NULL),
	(25, 3, 1, NULL, 10017, NULL),
	(1, 1, 1, NULL, 10017, NULL),
	(127, 1, 1, NULL, 10018, NULL),
	(30, 1, 1, NULL, 10017, NULL),
	(30, 1, 1, NULL, 10018, NULL),
	(25, 2, 1, NULL, 10018, NULL),
	(25, 3, 1, NULL, 10018, NULL),
	(25, 1, 1, NULL, 10018, NULL),
	(127, 1, 1, NULL, 10017, NULL),
	(30, 1, 1, NULL, 10085, 1),
	(1, 1, 1, NULL, 10085, 1),
	(51, 1, 1, -50058, 10017, NULL),
	(51, 1, 1, -50058, 10085, 1),
	(51, 1, 1, -50057, 10017, NULL),
	(51, 1, 1, -50057, 10085, 1),
	(51, 1, 1, -50055, 10017, NULL),
	(51, 1, 1, -50055, 10085, 1),
	(51, 1, 1, -50054, 10017, NULL),
	(51, 1, 1, -50054, 10085, 1),
	(51, 1, 1, -50053, 10017, NULL),
	(51, 1, 1, -50053, 10085, 1),
	(51, 1, 1, -50052, 10017, NULL),
	(51, 1, 1, -50052, 10085, 1),
	(51, 1, 1, -50051, 10017, NULL),
	(51, 1, 1, -50051, 10085, 1),
	(51, 1, 1, -50050, 10017, NULL),
	(51, 1, 1, -50050, 10085, 1),
	(51, 1, 1, -50049, 10017, NULL),
	(51, 1, 1, -50049, 10085, 1),
	(51, 1, 1, -50048, 10017, NULL),
	(51, 1, 1, -50048, 10085, 1),
	(51, 1, 1, -50047, 10017, NULL),
	(51, 1, 1, -50047, 10085, 1),
	(51, 1, 1, -50046, 10017, NULL),
	(51, 1, 1, -50046, 10085, 1),
	(51, 1, 1, -50045, 10017, NULL),
	(51, 1, 1, -50045, 10085, 1),
	(51, 1, 1, -50044, 10017, NULL),
	(51, 1, 1, -50044, 10085, 1),
	(51, 1, 1, -50041, 10017, NULL),
	(51, 1, 1, -50041, 10085, 1),
	(51, 1, 1, -50040, 10017, NULL),
	(51, 1, 1, -50040, 10085, 1),
	(51, 1, 1, -50038, 10017, NULL),
	(51, 1, 1, -50038, 10085, 1),
	(51, 1, 1, -50037, 10017, NULL),
	(51, 1, 1, -50037, 10085, 1),
	(51, 1, 1, -50036, 10017, NULL),
	(51, 1, 1, -50036, 10085, 1),
	(51, 1, 1, -50035, 10017, NULL),
	(51, 1, 1, -50035, 10085, 1),
	(51, 1, 1, -50034, 10017, NULL),
	(51, 1, 1, -50034, 10085, 1),
	(51, 1, 1, -50033, 10017, NULL),
	(51, 1, 1, -50033, 10085, 1),
	(51, 1, 1, -50019, 10017, NULL),
	(51, 1, 1, -50019, 10085, 1),
	(51, 1, 1, -50018, 10017, NULL),
	(51, 1, 1, -50018, 10085, 1),
	(51, 1, 1, -50017, 10017, NULL),
	(51, 1, 1, -50017, 10085, 1),
	(51, 1, 1, -50016, 10017, NULL),
	(51, 1, 1, -50016, 10085, 1),
	(51, 1, 1, -50015, 10017, NULL),
	(51, 1, 1, -50015, 10085, 1),
	(51, 1, 1, -50014, 10017, NULL),
	(51, 1, 1, -50014, 10085, 1),
	(51, 1, 1, -50013, 10017, NULL),
	(51, 1, 1, -50013, 10085, 1),
	(51, 1, 1, -50012, 10017, NULL),
	(51, 1, 1, -50012, 10085, 1),
	(51, 1, 1, -50011, 10017, NULL),
	(51, 1, 1, -50011, 10085, 1),
	(51, 1, 1, -50008, 10017, NULL),
	(51, 1, 1, -50008, 10085, 1),
	(51, 1, 1, -50005, 10017, NULL),
	(51, 1, 1, -50005, 10085, 1),
	(51, 1, 1, -50003, 10017, NULL),
	(51, 1, 1, -50003, 10085, 1),
	(51, 1, 1, -50002, 10017, NULL),
	(51, 1, 1, -50002, 10085, 1),
	(51, 1, 1, -8, 10017, NULL),
	(51, 1, 1, -8, 10085, 1),
	(140, 1, 1, -50496, 10850, NULL),
	(140, 1, 1, -50495, 10850, NULL),
	(140, 1, 1, -50494, 10850, NULL),
	(140, 1, 1, -50493, 10850, NULL),
	(140, 1, 1, -50416, 10427, NULL),
	(140, 1, 1, -50415, 10850, NULL),
	(140, 1, 1, -50414, 10850, NULL),
	(140, 1, 1, -50413, 10850, NULL),
	(140, 1, 1, -50412, 10850, NULL),
	(140, 1, 1, -50411, 10850, NULL),
	(140, 1, 1, -50410, 10850, NULL),
	(140, 1, 1, -50409, 10850, NULL),
	(140, 1, 1, -50408, 10850, NULL),
	(140, 1, 1, -50407, 10850, NULL),
	(140, 1, 1, -50406, 10850, NULL),
	(140, 1, 1, -50405, 10850, NULL),
	(140, 1, 1, -50404, 10850, NULL),
	(140, 1, 1, -50403, 10850, NULL),
	(140, 1, 1, -50402, 10850, NULL),
	(140, 1, 1, -50388, 10850, NULL),
	(140, 1, 1, -50359, 10109, NULL),
	(140, 1, 1, -50358, 10109, NULL),
	(140, 1, 1, -50357, 10109, NULL),
	(140, 1, 1, -50356, 10109, NULL),
	(140, 1, 1, -50355, 10109, NULL),
	(140, 1, 1, -50352, 10109, NULL),
	(140, 1, 1, -50351, 10109, NULL),
	(140, 1, 1, -50348, 10109, NULL),
	(140, 1, 1, -50347, 10109, NULL),
	(140, 1, 1, -50344, 10109, NULL),
	(140, 1, 1, -50343, 10109, NULL),
	(140, 1, 1, -50342, 10109, NULL),
	(140, 1, 1, -50341, 10109, NULL),
	(140, 1, 1, -50338, 10109, NULL),
	(140, 1, 1, -50337, 10109, NULL),
	(140, 1, 1, -50336, 10850, NULL),
	(140, 1, 1, -50319, 10850, NULL),
	(140, 1, 1, -50304, 10850, NULL),
	(140, 1, 1, -50222, 10427, NULL),
	(140, 1, 1, -50217, 10427, NULL),
	(140, 1, 1, -50079, 10853, NULL),
	(140, 1, 1, -50078, 10852, NULL),
	(140, 1, 1, -50022, 10852, NULL),
	(140, 1, 1, -50003, 10853, NULL),
	(140, 1, 1, -50002, 10853, NULL),
	(140, 1, 1, -8, 10850, NULL),
	(209, 1, 1, -50496, 10850, NULL),
	(209, 1, 1, -50495, 10850, NULL),
	(209, 1, 1, -50494, 10850, NULL),
	(209, 1, 1, -50493, 10850, NULL),
	(209, 1, 1, -50416, 10427, NULL),
	(209, 1, 1, -50415, 10850, NULL),
	(209, 1, 1, -50414, 10850, NULL),
	(209, 1, 1, -50413, 10850, NULL),
	(209, 1, 1, -50412, 10850, NULL),
	(209, 1, 1, -50411, 10850, NULL),
	(209, 1, 1, -50410, 10850, NULL),
	(209, 1, 1, -50409, 10850, NULL),
	(209, 1, 1, -50408, 10850, NULL),
	(209, 1, 1, -50407, 10850, NULL),
	(209, 1, 1, -50406, 10850, NULL),
	(209, 1, 1, -50405, 10850, NULL),
	(209, 1, 1, -50404, 10850, NULL),
	(209, 1, 1, -50403, 10850, NULL),
	(209, 1, 1, -50402, 10850, NULL),
	(209, 1, 1, -50388, 10850, NULL),
	(209, 1, 1, -50359, 10109, NULL),
	(209, 1, 1, -50358, 10109, NULL),
	(209, 1, 1, -50357, 10109, NULL),
	(209, 1, 1, -50356, 10109, NULL),
	(209, 1, 1, -50355, 10109, NULL),
	(209, 1, 1, -50352, 10109, NULL),
	(209, 1, 1, -50351, 10109, NULL),
	(209, 1, 1, -50348, 10109, NULL),
	(209, 1, 1, -50347, 10109, NULL),
	(209, 1, 1, -50344, 10109, NULL),
	(209, 1, 1, -50343, 10109, NULL),
	(209, 1, 1, -50342, 10109, NULL),
	(209, 1, 1, -50341, 10109, NULL),
	(209, 1, 1, -50338, 10109, NULL),
	(209, 1, 1, -50337, 10109, NULL),
	(209, 1, 1, -50336, 10850, NULL),
	(209, 1, 1, -50319, 10850, NULL),
	(209, 1, 1, -50304, 10850, NULL),
	(209, 1, 1, -50222, 10427, NULL),
	(209, 1, 1, -50217, 10427, NULL),
	(209, 1, 1, -50079, 10853, NULL),
	(209, 1, 1, -50078, 10852, NULL),
	(209, 1, 1, -50022, 10852, NULL),
	(209, 1, 1, -50003, 10853, NULL),
	(209, 1, 1, -50002, 10853, NULL),
	(209, 1, 1, -8, 10850, NULL);
/*!40000 ALTER TABLE `src_type_mod_withe_event` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod_withe_iopty
CREATE TABLE IF NOT EXISTS `src_type_mod_withe_iopty` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `is_point` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `src_type_mod_impl_code` varchar(80) COLLATE utf8_bin NOT NULL COMMENT 'Šaltinių tipo modifikacijos implementacijos kodas',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`src_type_id`,`src_type_mod_nr`,`is_point`,`withe_id`,`src_type_mod_impl_code`,`opty_id`),
  KEY `src_type_mod_withe_iopty_o_fk` (`opty_id`),
  CONSTRAINT `src_type_mod_withe_iopty_o_fk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_mod_withe_iopty_w_fk` FOREIGN KEY (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) REFERENCES `src_type_mod_withe` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Prietaisų modifikacijų implementacijų konfigūracinių parametrų nuskaitymui reikalingų parametrų reikšmės';

-- Dumping data for table emcor.src_type_mod_withe_iopty: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod_withe_iopty` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_type_mod_withe_iopty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod_withe_opty
CREATE TABLE IF NOT EXISTS `src_type_mod_withe_opty` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `is_point` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `rc_in` tinyint(1) DEFAULT NULL COMMENT 'Nuskaitymo užklausų požymis',
  `opty_value` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`src_type_id`,`src_type_mod_nr`,`is_point`,`withe_id`,`opty_id`),
  KEY `src_type_mod_withe_opty_opt_fk` (`opty_id`),
  CONSTRAINT `src_type_mod_withe_opty_opt_fk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_mod_withe_opty_wth_fk` FOREIGN KEY (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) REFERENCES `src_type_mod_withe` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Prietaisų modifikacijų konfigūracinių parametrų nuskaitymui reikalingų parametrų reikšmės';

-- Dumping data for table emcor.src_type_mod_withe_opty: ~615 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod_withe_opty` DISABLE KEYS */;
INSERT INTO `src_type_mod_withe_opty` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`, `opty_id`, `rc_in`, `opty_value`) VALUES
	(140, 1, 1, -50511, 16, NULL, NULL),
	(140, 1, 1, -50500, 13, NULL, NULL),
	(140, 1, 1, -50500, 16, NULL, NULL),
	(140, 1, 1, -50499, 13, NULL, NULL),
	(140, 1, 1, -50499, 16, NULL, NULL),
	(140, 1, 1, -50498, 13, NULL, NULL),
	(140, 1, 1, -50498, 16, NULL, NULL),
	(140, 1, 1, -50497, 13, NULL, NULL),
	(140, 1, 1, -50497, 16, NULL, NULL),
	(140, 1, 1, -50496, 13, NULL, NULL),
	(140, 1, 1, -50496, 16, NULL, NULL),
	(140, 1, 1, -50495, 13, NULL, NULL),
	(140, 1, 1, -50495, 16, NULL, NULL),
	(140, 1, 1, -50494, 13, NULL, NULL),
	(140, 1, 1, -50494, 16, NULL, NULL),
	(140, 1, 1, -50493, 13, NULL, NULL),
	(140, 1, 1, -50493, 16, NULL, NULL),
	(140, 1, 1, -50491, 13, NULL, NULL),
	(140, 1, 1, -50491, 16, NULL, NULL),
	(140, 1, 1, -50416, 16, NULL, NULL),
	(140, 1, 1, -50415, 16, NULL, NULL),
	(140, 1, 1, -50414, 16, NULL, NULL),
	(140, 1, 1, -50413, 16, NULL, NULL),
	(140, 1, 1, -50412, 16, NULL, NULL),
	(140, 1, 1, -50411, 16, NULL, NULL),
	(140, 1, 1, -50410, 16, NULL, NULL),
	(140, 1, 1, -50409, 16, NULL, NULL),
	(140, 1, 1, -50408, 16, NULL, NULL),
	(140, 1, 1, -50407, 16, NULL, NULL),
	(140, 1, 1, -50406, 16, NULL, NULL),
	(140, 1, 1, -50405, 16, NULL, NULL),
	(140, 1, 1, -50404, 16, NULL, NULL),
	(140, 1, 1, -50403, 16, NULL, NULL),
	(140, 1, 1, -50402, 16, NULL, NULL),
	(140, 1, 1, -50388, 16, NULL, NULL),
	(140, 1, 1, -50359, 16, NULL, NULL),
	(140, 1, 1, -50358, 16, NULL, NULL),
	(140, 1, 1, -50357, 16, NULL, NULL),
	(140, 1, 1, -50356, 16, NULL, NULL),
	(140, 1, 1, -50355, 16, NULL, NULL),
	(140, 1, 1, -50352, 16, NULL, NULL),
	(140, 1, 1, -50352, 18, 0, NULL),
	(140, 1, 1, -50352, 19, 0, NULL),
	(140, 1, 1, -50352, 20, 0, NULL),
	(140, 1, 1, -50352, 21, 0, NULL),
	(140, 1, 1, -50352, 22, 0, NULL),
	(140, 1, 1, -50352, 23, 0, NULL),
	(140, 1, 1, -50352, 24, 0, NULL),
	(140, 1, 1, -50352, 25, 0, NULL),
	(140, 1, 1, -50352, 26, 0, NULL),
	(140, 1, 1, -50352, 27, 0, NULL),
	(140, 1, 1, -50352, 28, 0, NULL),
	(140, 1, 1, -50352, 29, 0, NULL),
	(140, 1, 1, -50352, 30, 0, NULL),
	(140, 1, 1, -50352, 31, 0, NULL),
	(140, 1, 1, -50352, 32, 0, NULL),
	(140, 1, 1, -50351, 16, NULL, NULL),
	(140, 1, 1, -50351, 18, 0, NULL),
	(140, 1, 1, -50351, 19, 0, NULL),
	(140, 1, 1, -50351, 20, 0, NULL),
	(140, 1, 1, -50351, 21, 0, NULL),
	(140, 1, 1, -50351, 22, 0, NULL),
	(140, 1, 1, -50351, 23, 0, NULL),
	(140, 1, 1, -50351, 24, 0, NULL),
	(140, 1, 1, -50351, 25, 0, NULL),
	(140, 1, 1, -50351, 26, 0, NULL),
	(140, 1, 1, -50351, 27, 0, NULL),
	(140, 1, 1, -50351, 28, 0, NULL),
	(140, 1, 1, -50351, 29, 0, NULL),
	(140, 1, 1, -50351, 30, 0, NULL),
	(140, 1, 1, -50351, 31, 0, NULL),
	(140, 1, 1, -50351, 32, 0, NULL),
	(140, 1, 1, -50348, 16, NULL, NULL),
	(140, 1, 1, -50348, 18, 0, NULL),
	(140, 1, 1, -50348, 19, 0, NULL),
	(140, 1, 1, -50347, 16, NULL, NULL),
	(140, 1, 1, -50347, 18, 0, NULL),
	(140, 1, 1, -50347, 19, 0, NULL),
	(140, 1, 1, -50344, 16, NULL, NULL),
	(140, 1, 1, -50344, 18, 0, NULL),
	(140, 1, 1, -50343, 16, NULL, NULL),
	(140, 1, 1, -50343, 18, 0, NULL),
	(140, 1, 1, -50342, 16, NULL, NULL),
	(140, 1, 1, -50342, 18, 0, NULL),
	(140, 1, 1, -50341, 16, NULL, NULL),
	(140, 1, 1, -50341, 18, 0, NULL),
	(140, 1, 1, -50338, 16, NULL, NULL),
	(140, 1, 1, -50337, 16, NULL, NULL),
	(140, 1, 1, -50336, 16, NULL, NULL),
	(140, 1, 1, -50319, 16, NULL, NULL),
	(140, 1, 1, -50304, 16, NULL, NULL),
	(140, 1, 1, -50222, 16, NULL, NULL),
	(140, 1, 1, -50217, 16, NULL, NULL),
	(140, 1, 1, -50163, 16, NULL, NULL),
	(140, 1, 1, -50079, 16, NULL, NULL),
	(140, 1, 1, -50078, 16, NULL, NULL),
	(140, 1, 1, -50077, 16, NULL, NULL),
	(140, 1, 1, -50073, 16, NULL, NULL),
	(140, 1, 1, -50022, 16, NULL, NULL),
	(140, 1, 1, -50003, 16, NULL, NULL),
	(140, 1, 1, -50002, 16, NULL, NULL),
	(140, 1, 1, -8, 16, NULL, NULL),
	(140, 1, 1, -7, 16, NULL, NULL),
	(140, 1, 1, -5, 16, NULL, NULL),
	(140, 1, 1, 10881, 16, NULL, NULL),
	(209, 1, 1, -50511, 16, NULL, NULL),
	(209, 1, 1, -50500, 13, NULL, NULL),
	(209, 1, 1, -50500, 16, NULL, NULL),
	(209, 1, 1, -50499, 13, NULL, NULL),
	(209, 1, 1, -50499, 16, NULL, NULL),
	(209, 1, 1, -50498, 13, NULL, NULL),
	(209, 1, 1, -50498, 16, NULL, NULL),
	(209, 1, 1, -50497, 13, NULL, NULL),
	(209, 1, 1, -50497, 16, NULL, NULL),
	(209, 1, 1, -50496, 13, NULL, NULL),
	(209, 1, 1, -50496, 16, NULL, NULL),
	(209, 1, 1, -50495, 13, NULL, NULL),
	(209, 1, 1, -50495, 16, NULL, NULL),
	(209, 1, 1, -50494, 13, NULL, NULL),
	(209, 1, 1, -50494, 16, NULL, NULL),
	(209, 1, 1, -50493, 13, NULL, NULL),
	(209, 1, 1, -50493, 16, NULL, NULL),
	(209, 1, 1, -50491, 13, NULL, NULL),
	(209, 1, 1, -50491, 16, NULL, NULL),
	(209, 1, 1, -50416, 16, NULL, NULL),
	(209, 1, 1, -50415, 16, NULL, NULL),
	(209, 1, 1, -50414, 16, NULL, NULL),
	(209, 1, 1, -50413, 16, NULL, NULL),
	(209, 1, 1, -50412, 16, NULL, NULL),
	(209, 1, 1, -50411, 16, NULL, NULL),
	(209, 1, 1, -50410, 16, NULL, NULL),
	(209, 1, 1, -50409, 16, NULL, NULL),
	(209, 1, 1, -50408, 16, NULL, NULL),
	(209, 1, 1, -50407, 16, NULL, NULL),
	(209, 1, 1, -50406, 16, NULL, NULL),
	(209, 1, 1, -50405, 16, NULL, NULL),
	(209, 1, 1, -50404, 16, NULL, NULL),
	(209, 1, 1, -50403, 16, NULL, NULL),
	(209, 1, 1, -50402, 16, NULL, NULL),
	(209, 1, 1, -50388, 16, NULL, NULL),
	(209, 1, 1, -50359, 16, NULL, NULL),
	(209, 1, 1, -50358, 16, NULL, NULL),
	(209, 1, 1, -50357, 16, NULL, NULL),
	(209, 1, 1, -50356, 16, NULL, NULL),
	(209, 1, 1, -50355, 16, NULL, NULL),
	(209, 1, 1, -50352, 16, NULL, NULL),
	(209, 1, 1, -50352, 18, 0, NULL),
	(209, 1, 1, -50352, 19, 0, NULL),
	(209, 1, 1, -50352, 20, 0, NULL),
	(209, 1, 1, -50352, 21, 0, NULL),
	(209, 1, 1, -50352, 22, 0, NULL),
	(209, 1, 1, -50352, 23, 0, NULL),
	(209, 1, 1, -50352, 24, 0, NULL),
	(209, 1, 1, -50352, 25, 0, NULL),
	(209, 1, 1, -50352, 26, 0, NULL),
	(209, 1, 1, -50352, 27, 0, NULL),
	(209, 1, 1, -50352, 28, 0, NULL),
	(209, 1, 1, -50352, 29, 0, NULL),
	(209, 1, 1, -50352, 30, 0, NULL),
	(209, 1, 1, -50352, 31, 0, NULL),
	(209, 1, 1, -50352, 32, 0, NULL),
	(209, 1, 1, -50351, 16, NULL, NULL),
	(209, 1, 1, -50351, 18, 0, NULL),
	(209, 1, 1, -50351, 19, 0, NULL),
	(209, 1, 1, -50351, 20, 0, NULL),
	(209, 1, 1, -50351, 21, 0, NULL),
	(209, 1, 1, -50351, 22, 0, NULL),
	(209, 1, 1, -50351, 23, 0, NULL),
	(209, 1, 1, -50351, 24, 0, NULL),
	(209, 1, 1, -50351, 25, 0, NULL),
	(209, 1, 1, -50351, 26, 0, NULL),
	(209, 1, 1, -50351, 27, 0, NULL),
	(209, 1, 1, -50351, 28, 0, NULL),
	(209, 1, 1, -50351, 29, 0, NULL),
	(209, 1, 1, -50351, 30, 0, NULL),
	(209, 1, 1, -50351, 31, 0, NULL),
	(209, 1, 1, -50351, 32, 0, NULL),
	(209, 1, 1, -50348, 16, NULL, NULL),
	(209, 1, 1, -50348, 18, 0, NULL),
	(209, 1, 1, -50348, 19, 0, NULL),
	(209, 1, 1, -50347, 16, NULL, NULL),
	(209, 1, 1, -50347, 18, 0, NULL),
	(209, 1, 1, -50347, 19, 0, NULL),
	(209, 1, 1, -50344, 16, NULL, NULL),
	(209, 1, 1, -50344, 18, 0, NULL),
	(209, 1, 1, -50343, 16, NULL, NULL),
	(209, 1, 1, -50343, 18, 0, NULL),
	(209, 1, 1, -50342, 16, NULL, NULL),
	(209, 1, 1, -50342, 18, 0, NULL),
	(209, 1, 1, -50341, 16, NULL, NULL),
	(209, 1, 1, -50341, 18, 0, NULL),
	(209, 1, 1, -50338, 16, NULL, NULL),
	(209, 1, 1, -50337, 16, NULL, NULL),
	(209, 1, 1, -50336, 16, NULL, NULL),
	(209, 1, 1, -50319, 16, NULL, NULL),
	(209, 1, 1, -50304, 16, NULL, NULL),
	(209, 1, 1, -50222, 16, NULL, NULL),
	(209, 1, 1, -50217, 16, NULL, NULL),
	(209, 1, 1, -50163, 16, NULL, NULL),
	(209, 1, 1, -50079, 16, NULL, NULL),
	(209, 1, 1, -50078, 16, NULL, NULL),
	(209, 1, 1, -50077, 16, NULL, NULL),
	(209, 1, 1, -50073, 16, NULL, NULL),
	(209, 1, 1, -50022, 16, NULL, NULL),
	(209, 1, 1, -50003, 16, NULL, NULL),
	(209, 1, 1, -50002, 16, NULL, NULL),
	(209, 1, 1, -8, 16, NULL, NULL),
	(209, 1, 1, -7, 16, NULL, NULL),
	(209, 1, 1, -5, 16, NULL, NULL),
	(209, 1, 1, 10881, 16, NULL, NULL),
	(232, 1, 1, -50511, 12, NULL, NULL),
	(232, 1, 1, -50511, 13, NULL, NULL),
	(232, 1, 1, -50500, 12, NULL, NULL),
	(232, 1, 1, -50500, 13, NULL, NULL),
	(232, 1, 1, -50499, 12, NULL, NULL),
	(232, 1, 1, -50499, 13, NULL, NULL),
	(232, 1, 1, -50498, 12, NULL, NULL),
	(232, 1, 1, -50498, 13, NULL, NULL),
	(232, 1, 1, -50497, 12, NULL, NULL),
	(232, 1, 1, -50497, 13, NULL, NULL),
	(232, 1, 1, -50496, 12, NULL, NULL),
	(232, 1, 1, -50496, 13, NULL, NULL),
	(232, 1, 1, -50495, 12, NULL, NULL),
	(232, 1, 1, -50495, 13, NULL, NULL),
	(232, 1, 1, -50494, 12, NULL, NULL),
	(232, 1, 1, -50494, 13, NULL, NULL),
	(232, 1, 1, -50493, 12, NULL, NULL),
	(232, 1, 1, -50493, 13, NULL, NULL),
	(232, 1, 1, -50491, 12, NULL, NULL),
	(232, 1, 1, -50491, 13, NULL, NULL),
	(232, 1, 1, -50304, 12, NULL, NULL),
	(232, 1, 1, -50304, 13, NULL, NULL),
	(232, 1, 1, -50022, 12, NULL, NULL),
	(232, 1, 1, 10010, 12, NULL, NULL),
	(243, 1, 0, -50945, 37, NULL, '3'),
	(243, 1, 0, -50945, 38, NULL, '0'),
	(243, 1, 0, -50945, 40, NULL, '9'),
	(243, 1, 0, -50945, 41, NULL, '0'),
	(243, 1, 0, -50944, 37, NULL, '3'),
	(243, 1, 0, -50944, 38, NULL, '0'),
	(243, 1, 0, -50944, 40, NULL, '8'),
	(243, 1, 0, -50944, 41, NULL, '0'),
	(243, 1, 0, -50943, 37, NULL, '3'),
	(243, 1, 0, -50943, 38, NULL, '0'),
	(243, 1, 0, -50943, 40, NULL, '7'),
	(243, 1, 0, -50943, 41, NULL, '0'),
	(243, 1, 0, -50942, 37, NULL, '3'),
	(243, 1, 0, -50942, 38, NULL, '0'),
	(243, 1, 0, -50942, 40, NULL, '6'),
	(243, 1, 0, -50942, 41, NULL, '0'),
	(243, 1, 0, -50941, 37, NULL, '25'),
	(243, 1, 0, -50941, 38, NULL, '0'),
	(243, 1, 0, -50941, 40, NULL, '4'),
	(243, 1, 0, -50941, 41, NULL, '1'),
	(243, 1, 0, -50940, 37, NULL, '25'),
	(243, 1, 0, -50940, 38, NULL, '0'),
	(243, 1, 0, -50940, 40, NULL, '3'),
	(243, 1, 0, -50940, 41, NULL, '1'),
	(243, 1, 0, -50939, 37, NULL, '25'),
	(243, 1, 0, -50939, 38, NULL, '0'),
	(243, 1, 0, -50939, 40, NULL, '2'),
	(243, 1, 0, -50939, 41, NULL, '1'),
	(243, 1, 0, -50938, 37, NULL, '25'),
	(243, 1, 0, -50938, 38, NULL, '0'),
	(243, 1, 0, -50938, 40, NULL, '1'),
	(243, 1, 0, -50938, 41, NULL, '1'),
	(243, 1, 0, -50937, 37, NULL, '25'),
	(243, 1, 0, -50937, 38, NULL, '0'),
	(243, 1, 0, -50937, 40, NULL, '0'),
	(243, 1, 0, -50937, 41, NULL, '1'),
	(243, 1, 0, -50934, 38, NULL, '1'),
	(243, 1, 0, -50934, 39, NULL, '0'),
	(243, 1, 0, -50934, 40, NULL, '5'),
	(243, 1, 0, -50934, 41, NULL, '1'),
	(243, 1, 0, -50933, 38, NULL, '1'),
	(243, 1, 0, -50933, 39, NULL, '0'),
	(243, 1, 0, -50933, 40, NULL, '4'),
	(243, 1, 0, -50933, 41, NULL, '1'),
	(243, 1, 0, -50932, 38, NULL, '1'),
	(243, 1, 0, -50932, 39, NULL, '0'),
	(243, 1, 0, -50932, 40, NULL, '3'),
	(243, 1, 0, -50932, 41, NULL, '1'),
	(243, 1, 0, -50931, 38, NULL, '1'),
	(243, 1, 0, -50931, 39, NULL, '0'),
	(243, 1, 0, -50931, 40, NULL, '2'),
	(243, 1, 0, -50931, 41, NULL, '1'),
	(243, 1, 0, -50930, 38, NULL, '1'),
	(243, 1, 0, -50930, 39, NULL, '0'),
	(243, 1, 0, -50930, 40, NULL, '1'),
	(243, 1, 0, -50930, 41, NULL, '1'),
	(243, 1, 0, -50929, 38, NULL, '1'),
	(243, 1, 0, -50929, 39, NULL, '0'),
	(243, 1, 0, -50929, 40, NULL, '0'),
	(243, 1, 0, -50929, 41, NULL, '1'),
	(243, 1, 0, -50928, 38, NULL, '0'),
	(243, 1, 0, -50928, 39, NULL, '2'),
	(243, 1, 0, -50928, 40, NULL, '0'),
	(243, 1, 0, -50928, 41, NULL, '1'),
	(243, 1, 0, -50927, 38, NULL, '0'),
	(243, 1, 0, -50927, 39, NULL, '1'),
	(243, 1, 0, -50927, 40, NULL, '0'),
	(243, 1, 0, -50927, 41, NULL, '1'),
	(243, 1, 0, -50926, 38, NULL, '0'),
	(243, 1, 0, -50926, 39, NULL, '0'),
	(243, 1, 0, -50926, 40, NULL, '0'),
	(243, 1, 0, -50926, 41, NULL, '1'),
	(243, 1, 0, -50924, 37, NULL, '3'),
	(243, 1, 0, -50924, 38, NULL, '0'),
	(243, 1, 0, -50924, 40, NULL, '3'),
	(243, 1, 0, -50924, 41, NULL, '0'),
	(243, 1, 0, -50553, 37, NULL, '1077'),
	(243, 1, 0, -50553, 38, NULL, '1'),
	(243, 1, 0, -50553, 40, NULL, '1'),
	(243, 1, 0, -50553, 41, NULL, '0'),
	(243, 1, 0, -50512, 38, NULL, '5'),
	(243, 1, 0, -50512, 40, NULL, '1'),
	(243, 1, 0, -50512, 41, NULL, '1'),
	(243, 1, 0, -50378, 37, NULL, '1077'),
	(243, 1, 0, -50378, 38, NULL, '1'),
	(243, 1, 0, -50378, 40, NULL, '2'),
	(243, 1, 0, -50378, 41, NULL, '0'),
	(243, 1, 0, -50242, 37, NULL, '1077'),
	(243, 1, 0, -50242, 38, NULL, '1'),
	(243, 1, 0, -50242, 40, NULL, '0'),
	(243, 1, 0, -50242, 41, NULL, '0'),
	(243, 1, 0, -50020, 38, NULL, '2'),
	(243, 1, 0, -50020, 40, NULL, '-1'),
	(243, 1, 0, -50020, 41, NULL, '1'),
	(243, 1, 0, -50017, 38, NULL, '3'),
	(243, 1, 0, -50017, 40, NULL, '7'),
	(243, 1, 0, -50017, 41, NULL, '1'),
	(243, 1, 0, -50016, 38, NULL, '3'),
	(243, 1, 0, -50016, 40, NULL, '6'),
	(243, 1, 0, -50016, 41, NULL, '1'),
	(243, 1, 0, -50015, 38, NULL, '3'),
	(243, 1, 0, -50015, 40, NULL, '5'),
	(243, 1, 0, -50015, 41, NULL, '1'),
	(243, 1, 0, -50014, 38, NULL, '3'),
	(243, 1, 0, -50014, 40, NULL, '4'),
	(243, 1, 0, -50014, 41, NULL, '1'),
	(243, 1, 0, -50013, 38, NULL, '3'),
	(243, 1, 0, -50013, 40, NULL, '3'),
	(243, 1, 0, -50013, 41, NULL, '1'),
	(243, 1, 0, -50012, 38, NULL, '3'),
	(243, 1, 0, -50012, 40, NULL, '2'),
	(243, 1, 0, -50012, 41, NULL, '1'),
	(243, 1, 0, -50011, 38, NULL, '3'),
	(243, 1, 0, -50011, 40, NULL, '1'),
	(243, 1, 0, -50011, 41, NULL, '1'),
	(243, 1, 0, -50008, 38, NULL, '3'),
	(243, 1, 0, -50008, 40, NULL, '0'),
	(243, 1, 0, -50008, 41, NULL, '1'),
	(243, 1, 0, -50007, 38, NULL, '4'),
	(243, 1, 0, -50007, 40, NULL, '1'),
	(243, 1, 0, -50007, 41, NULL, '1'),
	(243, 1, 0, -50006, 38, NULL, '4'),
	(243, 1, 0, -50006, 40, NULL, '0'),
	(243, 1, 0, -50006, 41, NULL, '1'),
	(243, 1, 0, -50005, 38, NULL, '5'),
	(243, 1, 0, -50005, 40, NULL, '0'),
	(243, 1, 0, -50005, 41, NULL, '1'),
	(243, 1, 0, -10, 37, NULL, '3'),
	(243, 1, 0, -10, 38, NULL, '0'),
	(243, 1, 0, -10, 40, NULL, '4'),
	(243, 1, 0, -10, 41, NULL, '0'),
	(243, 1, 0, -9, 37, NULL, '3'),
	(243, 1, 0, -9, 38, NULL, '0'),
	(243, 1, 0, -9, 40, NULL, '5'),
	(243, 1, 0, -9, 41, NULL, '0'),
	(248, 1, 1, -50511, 12, NULL, NULL),
	(248, 1, 1, -50511, 13, NULL, NULL),
	(248, 1, 1, -50500, 12, NULL, NULL),
	(248, 1, 1, -50500, 13, NULL, NULL),
	(248, 1, 1, -50499, 12, NULL, NULL),
	(248, 1, 1, -50499, 13, NULL, NULL),
	(248, 1, 1, -50498, 12, NULL, NULL),
	(248, 1, 1, -50498, 13, NULL, NULL),
	(248, 1, 1, -50497, 12, NULL, NULL),
	(248, 1, 1, -50497, 13, NULL, NULL),
	(248, 1, 1, -50496, 12, NULL, NULL),
	(248, 1, 1, -50496, 13, NULL, NULL),
	(248, 1, 1, -50495, 12, NULL, NULL),
	(248, 1, 1, -50495, 13, NULL, NULL),
	(248, 1, 1, -50494, 12, NULL, NULL),
	(248, 1, 1, -50494, 13, NULL, NULL),
	(248, 1, 1, -50493, 12, NULL, NULL),
	(248, 1, 1, -50493, 13, NULL, NULL),
	(248, 1, 1, -50491, 12, NULL, NULL),
	(248, 1, 1, -50491, 13, NULL, NULL),
	(248, 1, 1, -50304, 12, NULL, NULL),
	(248, 1, 1, -50304, 13, NULL, NULL),
	(248, 1, 1, -50022, 12, NULL, NULL),
	(248, 1, 1, 10010, 12, NULL, NULL),
	(377, 1, 0, -50925, 37, NULL, '6'),
	(377, 1, 0, -50925, 38, NULL, '0'),
	(377, 1, 0, -50925, 40, NULL, '0'),
	(377, 1, 0, -50925, 41, NULL, '1'),
	(377, 1, 0, -50924, 37, NULL, '6'),
	(377, 1, 0, -50924, 38, NULL, '0'),
	(377, 1, 0, -50924, 40, NULL, '3'),
	(377, 1, 0, -50924, 41, NULL, '1'),
	(377, 1, 0, -50594, 37, NULL, '1'),
	(377, 1, 0, -50594, 38, NULL, '2'),
	(377, 1, 0, -50594, 39, NULL, '3'),
	(377, 1, 0, -50594, 40, NULL, '0'),
	(377, 1, 0, -50594, 41, NULL, '1'),
	(377, 1, 0, -50593, 37, NULL, '1'),
	(377, 1, 0, -50593, 38, NULL, '2'),
	(377, 1, 0, -50593, 39, NULL, '2'),
	(377, 1, 0, -50593, 40, NULL, '0'),
	(377, 1, 0, -50593, 41, NULL, '1'),
	(377, 1, 0, -50592, 37, NULL, '1'),
	(377, 1, 0, -50592, 38, NULL, '2'),
	(377, 1, 0, -50592, 39, NULL, '0'),
	(377, 1, 0, -50592, 40, NULL, '0'),
	(377, 1, 0, -50592, 41, NULL, '1'),
	(377, 1, 0, -50583, 37, NULL, '1'),
	(377, 1, 0, -50583, 38, NULL, '1'),
	(377, 1, 0, -50583, 40, NULL, '0'),
	(377, 1, 0, -50583, 41, NULL, '1'),
	(377, 1, 0, -50553, 37, NULL, '6'),
	(377, 1, 0, -50553, 38, NULL, '0'),
	(377, 1, 0, -50553, 40, NULL, '1'),
	(377, 1, 0, -50553, 41, NULL, '1'),
	(377, 1, 0, -50486, 37, NULL, '1'),
	(377, 1, 0, -50486, 38, NULL, '2'),
	(377, 1, 0, -50486, 39, NULL, '1'),
	(377, 1, 0, -50486, 40, NULL, '0'),
	(377, 1, 0, -50486, 41, NULL, '1'),
	(377, 1, 0, -50384, 37, NULL, '2'),
	(377, 1, 0, -50384, 38, NULL, '0'),
	(377, 1, 0, -50384, 39, NULL, '5'),
	(377, 1, 0, -50384, 40, NULL, '0'),
	(377, 1, 0, -50384, 41, NULL, '1'),
	(377, 1, 0, -50378, 37, NULL, '6'),
	(377, 1, 0, -50378, 38, NULL, '0'),
	(377, 1, 0, -50378, 40, NULL, '6'),
	(377, 1, 0, -50378, 41, NULL, '1'),
	(377, 1, 0, -50331, 37, NULL, '6'),
	(377, 1, 0, -50331, 38, NULL, '0'),
	(377, 1, 0, -50331, 40, NULL, '8'),
	(377, 1, 0, -50331, 41, NULL, '1'),
	(377, 1, 0, -50295, 37, NULL, '0'),
	(377, 1, 0, -50295, 38, NULL, '0'),
	(377, 1, 0, -50295, 40, NULL, '0'),
	(377, 1, 0, -50295, 41, NULL, '1'),
	(377, 1, 0, -50282, 37, NULL, '6'),
	(377, 1, 0, -50282, 38, NULL, '0'),
	(377, 1, 0, -50282, 40, NULL, '5'),
	(377, 1, 0, -50282, 41, NULL, '1'),
	(377, 1, 0, -50267, 37, NULL, '1'),
	(377, 1, 0, -50267, 38, NULL, '0'),
	(377, 1, 0, -50267, 39, NULL, '5'),
	(377, 1, 0, -50267, 40, NULL, '0'),
	(377, 1, 0, -50267, 41, NULL, '1'),
	(377, 1, 0, -50246, 37, NULL, '6'),
	(377, 1, 0, -50246, 38, NULL, '0'),
	(377, 1, 0, -50246, 40, NULL, '4'),
	(377, 1, 0, -50246, 41, NULL, '1'),
	(377, 1, 0, -50244, 37, NULL, '6'),
	(377, 1, 0, -50244, 38, NULL, '0'),
	(377, 1, 0, -50244, 40, NULL, '7'),
	(377, 1, 0, -50244, 41, NULL, '1'),
	(377, 1, 0, -50242, 37, NULL, '6'),
	(377, 1, 0, -50242, 38, NULL, '0'),
	(377, 1, 0, -50242, 40, NULL, '2'),
	(377, 1, 0, -50242, 41, NULL, '1'),
	(377, 1, 0, -50223, 37, NULL, '1'),
	(377, 1, 0, -50223, 38, NULL, '0'),
	(377, 1, 0, -50223, 39, NULL, '4'),
	(377, 1, 0, -50223, 40, NULL, '0'),
	(377, 1, 0, -50223, 41, NULL, '1'),
	(377, 1, 0, -50222, 37, NULL, '1'),
	(377, 1, 0, -50222, 38, NULL, '0'),
	(377, 1, 0, -50222, 39, NULL, '3'),
	(377, 1, 0, -50222, 40, NULL, '0'),
	(377, 1, 0, -50222, 41, NULL, '1'),
	(377, 1, 0, -50221, 37, NULL, '1'),
	(377, 1, 0, -50221, 38, NULL, '1'),
	(377, 1, 0, -50221, 40, NULL, '3'),
	(377, 1, 0, -50221, 41, NULL, '1'),
	(377, 1, 0, -50220, 37, NULL, '1'),
	(377, 1, 0, -50220, 38, NULL, '1'),
	(377, 1, 0, -50220, 40, NULL, '4'),
	(377, 1, 0, -50220, 41, NULL, '1'),
	(377, 1, 0, -50219, 37, NULL, '1'),
	(377, 1, 0, -50219, 38, NULL, '1'),
	(377, 1, 0, -50219, 40, NULL, '5'),
	(377, 1, 0, -50219, 41, NULL, '1'),
	(377, 1, 0, -50218, 37, NULL, '1'),
	(377, 1, 0, -50218, 38, NULL, '1'),
	(377, 1, 0, -50218, 40, NULL, '1'),
	(377, 1, 0, -50218, 41, NULL, '1'),
	(377, 1, 0, -50217, 37, NULL, '1'),
	(377, 1, 0, -50217, 38, NULL, '1'),
	(377, 1, 0, -50217, 40, NULL, '2'),
	(377, 1, 0, -50217, 41, NULL, '1'),
	(377, 1, 0, -50216, 37, NULL, '1'),
	(377, 1, 0, -50216, 38, NULL, '1'),
	(377, 1, 0, -50216, 40, NULL, '0'),
	(377, 1, 0, -50216, 41, NULL, '1'),
	(377, 1, 0, -50213, 37, NULL, '1'),
	(377, 1, 0, -50213, 38, NULL, '0'),
	(377, 1, 0, -50213, 39, NULL, '2'),
	(377, 1, 0, -50213, 40, NULL, '0'),
	(377, 1, 0, -50213, 41, NULL, '1'),
	(377, 1, 0, -50212, 37, NULL, '1'),
	(377, 1, 0, -50212, 38, NULL, '0'),
	(377, 1, 0, -50212, 39, NULL, '1'),
	(377, 1, 0, -50212, 40, NULL, '0'),
	(377, 1, 0, -50212, 41, NULL, '1'),
	(377, 1, 0, -50210, 37, NULL, '1'),
	(377, 1, 0, -50210, 38, NULL, '0'),
	(377, 1, 0, -50210, 39, NULL, '0'),
	(377, 1, 0, -50210, 40, NULL, '0'),
	(377, 1, 0, -50210, 41, NULL, '1'),
	(377, 1, 0, -50209, 37, NULL, '2'),
	(377, 1, 0, -50209, 38, NULL, '0'),
	(377, 1, 0, -50209, 39, NULL, '8'),
	(377, 1, 0, -50209, 40, NULL, '0'),
	(377, 1, 0, -50209, 41, NULL, '1'),
	(377, 1, 0, -50208, 37, NULL, '2'),
	(377, 1, 0, -50208, 38, NULL, '0'),
	(377, 1, 0, -50208, 39, NULL, '7'),
	(377, 1, 0, -50208, 40, NULL, '0'),
	(377, 1, 0, -50208, 41, NULL, '1'),
	(377, 1, 0, -50207, 37, NULL, '2'),
	(377, 1, 0, -50207, 38, NULL, '0'),
	(377, 1, 0, -50207, 39, NULL, '6'),
	(377, 1, 0, -50207, 40, NULL, '0'),
	(377, 1, 0, -50207, 41, NULL, '1'),
	(377, 1, 0, -50203, 37, NULL, '18'),
	(377, 1, 0, -50203, 38, NULL, '0'),
	(377, 1, 0, -50203, 40, NULL, '1'),
	(377, 1, 0, -50203, 41, NULL, '1'),
	(377, 1, 0, -50201, 37, NULL, '4'),
	(377, 1, 0, -50201, 40, NULL, '1'),
	(377, 1, 0, -50198, 37, NULL, '2'),
	(377, 1, 0, -50198, 38, NULL, '0'),
	(377, 1, 0, -50198, 39, NULL, '0'),
	(377, 1, 0, -50198, 40, NULL, '0'),
	(377, 1, 0, -50198, 41, NULL, '1'),
	(377, 1, 0, -50181, 37, NULL, '0'),
	(377, 1, 0, -50181, 38, NULL, '0'),
	(377, 1, 0, -50181, 40, NULL, '2'),
	(377, 1, 0, -50181, 41, NULL, '1'),
	(377, 1, 0, -50165, 37, NULL, '4'),
	(377, 1, 0, -50165, 40, NULL, '2'),
	(377, 1, 0, -50079, 37, NULL, '2'),
	(377, 1, 0, -50079, 38, NULL, '0'),
	(377, 1, 0, -50079, 39, NULL, '1'),
	(377, 1, 0, -50079, 40, NULL, '0'),
	(377, 1, 0, -50079, 41, NULL, '1'),
	(377, 1, 0, -50022, 37, NULL, '0'),
	(377, 1, 0, -50022, 38, NULL, '0'),
	(377, 1, 0, -50022, 40, NULL, '1'),
	(377, 1, 0, -50022, 41, NULL, '1'),
	(377, 1, 0, -50020, 38, NULL, '0'),
	(377, 1, 0, -50020, 40, NULL, '-1'),
	(377, 1, 0, -50020, 41, NULL, '1'),
	(377, 1, 0, -50018, 38, NULL, '1'),
	(377, 1, 0, -50018, 40, NULL, '8'),
	(377, 1, 0, -50018, 41, NULL, '1'),
	(377, 1, 0, -50017, 38, NULL, '1'),
	(377, 1, 0, -50017, 40, NULL, '7'),
	(377, 1, 0, -50017, 41, NULL, '1'),
	(377, 1, 0, -50016, 38, NULL, '1'),
	(377, 1, 0, -50016, 40, NULL, '6'),
	(377, 1, 0, -50016, 41, NULL, '1'),
	(377, 1, 0, -50015, 38, NULL, '1'),
	(377, 1, 0, -50015, 40, NULL, '5'),
	(377, 1, 0, -50015, 41, NULL, '1'),
	(377, 1, 0, -50014, 38, NULL, '1'),
	(377, 1, 0, -50014, 40, NULL, '4'),
	(377, 1, 0, -50014, 41, NULL, '1'),
	(377, 1, 0, -50013, 38, NULL, '1'),
	(377, 1, 0, -50013, 40, NULL, '3'),
	(377, 1, 0, -50013, 41, NULL, '1'),
	(377, 1, 0, -50012, 38, NULL, '1'),
	(377, 1, 0, -50012, 40, NULL, '2'),
	(377, 1, 0, -50012, 41, NULL, '1'),
	(377, 1, 0, -50011, 38, NULL, '1'),
	(377, 1, 0, -50011, 40, NULL, '1'),
	(377, 1, 0, -50011, 41, NULL, '1'),
	(377, 1, 0, -50008, 38, NULL, '1'),
	(377, 1, 0, -50008, 40, NULL, '0'),
	(377, 1, 0, -50008, 41, NULL, '1'),
	(377, 1, 0, -50006, 37, NULL, '18'),
	(377, 1, 0, -50006, 38, NULL, '0'),
	(377, 1, 0, -50006, 40, NULL, '0'),
	(377, 1, 0, -50006, 41, NULL, '1'),
	(377, 1, 0, -50003, 37, NULL, '2'),
	(377, 1, 0, -50003, 38, NULL, '0'),
	(377, 1, 0, -50003, 39, NULL, '2'),
	(377, 1, 0, -50003, 40, NULL, '0'),
	(377, 1, 0, -50003, 41, NULL, '1'),
	(377, 1, 0, -50002, 37, NULL, '2'),
	(377, 1, 0, -50002, 38, NULL, '0'),
	(377, 1, 0, -50002, 39, NULL, '4'),
	(377, 1, 0, -50002, 40, NULL, '0'),
	(377, 1, 0, -50002, 41, NULL, '1'),
	(377, 1, 0, 10842, 37, NULL, '4'),
	(377, 1, 0, 10842, 40, NULL, '0'),
	(377, 1, 1, -50310, 37, 0, '1000'),
	(377, 1, 1, -50310, 40, 0, '1'),
	(377, 1, 1, -50163, 37, 0, '1000'),
	(377, 1, 1, -50163, 40, 0, '2'),
	(377, 1, 1, 10010, 37, NULL, NULL),
	(377, 1, 1, 10010, 38, 1, '0'),
	(377, 1, 1, 10010, 40, NULL, '0'),
	(377, 1, 1, 10010, 41, 1, '0'),
	(377, 1, 1, 10011, 37, NULL, NULL),
	(377, 1, 1, 10011, 38, 1, '1'),
	(377, 1, 1, 10011, 40, NULL, '0'),
	(377, 1, 1, 10011, 41, 1, '0');
/*!40000 ALTER TABLE `src_type_mod_withe_opty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod_withe_rc#iopty
CREATE TABLE IF NOT EXISTS `src_type_mod_withe_rc#iopty` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `is_point` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `rc_in` tinyint(1) NOT NULL COMMENT 'Nuskaitymo užklausų požymis',
  `src_type_mod_impl_code` varchar(80) COLLATE utf8_bin NOT NULL COMMENT 'Šaltinių tipo modifikacijos implementacijos kodas',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`src_type_id`,`src_type_mod_nr`,`is_point`,`withe_id`,`ind1`,`ind2`,`ind3`,`rc_in`,`src_type_mod_impl_code`,`opty_id`),
  KEY `src_type_mod_withe_rc#iopty_of` (`opty_id`),
  CONSTRAINT `src_type_mod_withe_rc#iopty_of` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_mod_withe_rc#iopty_wf` FOREIGN KEY (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) REFERENCES `src_type_mod_withe` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Prietaisų modifikacijų implementacijų konfigūracinių masyvinių parametrų nuskaitymui/įrašymui reikalingų parametrų reikšmės';

-- Dumping data for table emcor.src_type_mod_withe_rc#iopty: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod_withe_rc#iopty` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_type_mod_withe_rc#iopty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod_withe_rc#opty
CREATE TABLE IF NOT EXISTS `src_type_mod_withe_rc#opty` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `is_point` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `rc_in` tinyint(1) NOT NULL COMMENT 'Nuskaitymo užklausų požymis',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`src_type_id`,`src_type_mod_nr`,`is_point`,`withe_id`,`ind1`,`ind2`,`ind3`,`rc_in`,`opty_id`),
  KEY `src_type_mod_withe_rc#opty_ofk` (`opty_id`),
  CONSTRAINT `src_type_mod_withe_rc#opty_ofk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_mod_withe_rc#opty_wfk` FOREIGN KEY (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) REFERENCES `src_type_mod_withe` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Prietaisų modifikacijų konfigūracinių masyvinių parametrų nuskaitymui/įrašymui reikalingų parametrų reikšmės';

-- Dumping data for table emcor.src_type_mod_withe_rc#opty: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod_withe_rc#opty` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_type_mod_withe_rc#opty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod_withe_rc_iopty
CREATE TABLE IF NOT EXISTS `src_type_mod_withe_rc_iopty` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `is_point` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `rc_in` tinyint(1) NOT NULL COMMENT 'Nuskaitymo užklausų požymis',
  `src_type_mod_impl_code` varchar(80) COLLATE utf8_bin NOT NULL COMMENT 'Šaltinių tipo modifikacijos implementacijos kodas',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`src_type_id`,`src_type_mod_nr`,`is_point`,`withe_id`,`rc_in`,`src_type_mod_impl_code`,`opty_id`),
  KEY `src_type_mod_withe_rc_iopty_of` (`opty_id`),
  CONSTRAINT `src_type_mod_withe_rc_iopty_of` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_mod_withe_rc_iopty_wf` FOREIGN KEY (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) REFERENCES `src_type_mod_withe` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Prietaisų modifikacijų implementacijų konfigūracinių parametrų nuskaitymui/įrašymui reikalingų parametrų reikšmės';

-- Dumping data for table emcor.src_type_mod_withe_rc_iopty: ~0 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod_withe_rc_iopty` DISABLE KEYS */;
/*!40000 ALTER TABLE `src_type_mod_withe_rc_iopty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_mod_withe_rc_opty
CREATE TABLE IF NOT EXISTS `src_type_mod_withe_rc_opty` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_mod_nr` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
  `is_point` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `rc_in` tinyint(1) NOT NULL COMMENT 'Nuskaitymo užklausų požymis',
  `opty_id` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
  `opty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė',
  PRIMARY KEY (`src_type_id`,`src_type_mod_nr`,`is_point`,`withe_id`,`rc_in`,`opty_id`),
  KEY `src_type_mod_withe_rc_opty_ofk` (`opty_id`),
  CONSTRAINT `src_type_mod_withe_rc_opty_ofk` FOREIGN KEY (`opty_id`) REFERENCES `opty` (`opty_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_mod_withe_rc_opty_wfk` FOREIGN KEY (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) REFERENCES `src_type_mod_withe` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Prietaisų modifikacijų konfigūracinių parametrų nuskaitymui/įrašymui reikalingų parametrų reikšmės';

-- Dumping data for table emcor.src_type_mod_withe_rc_opty: ~108 rows (approximately)
/*!40000 ALTER TABLE `src_type_mod_withe_rc_opty` DISABLE KEYS */;
INSERT INTO `src_type_mod_withe_rc_opty` (`src_type_id`, `src_type_mod_nr`, `is_point`, `withe_id`, `rc_in`, `opty_id`, `opty_value`) VALUES
	(140, 1, 1, -50511, 0, 17, '1'),
	(140, 1, 1, -50491, 0, 17, '1'),
	(140, 1, 1, -50490, 0, 17, '1'),
	(140, 1, 1, -50489, 0, 17, '1'),
	(140, 1, 1, -50488, 0, 17, '1'),
	(140, 1, 1, -50416, 0, 17, '1'),
	(140, 1, 1, -50415, 0, 17, '1'),
	(140, 1, 1, -50414, 0, 17, '1'),
	(140, 1, 1, -50413, 0, 17, '1'),
	(140, 1, 1, -50412, 0, 17, '1'),
	(140, 1, 1, -50411, 0, 17, '1'),
	(140, 1, 1, -50410, 0, 17, '1'),
	(140, 1, 1, -50409, 0, 17, '1'),
	(140, 1, 1, -50408, 0, 17, '1'),
	(140, 1, 1, -50407, 0, 17, '1'),
	(140, 1, 1, -50406, 0, 17, '1'),
	(140, 1, 1, -50405, 0, 17, '1'),
	(140, 1, 1, -50404, 0, 17, '1'),
	(140, 1, 1, -50403, 0, 17, '1'),
	(140, 1, 1, -50402, 0, 17, '1'),
	(140, 1, 1, -50388, 0, 17, '1'),
	(140, 1, 1, -50357, 0, 17, '1'),
	(140, 1, 1, -50356, 0, 17, '1'),
	(140, 1, 1, -50355, 0, 17, '1'),
	(140, 1, 1, -50352, 0, 17, '1'),
	(140, 1, 1, -50351, 0, 17, '1'),
	(140, 1, 1, -50348, 0, 17, '1'),
	(140, 1, 1, -50347, 0, 17, '1'),
	(140, 1, 1, -50344, 0, 17, '1'),
	(140, 1, 1, -50343, 0, 17, '1'),
	(140, 1, 1, -50342, 0, 17, '1'),
	(140, 1, 1, -50341, 0, 17, '1'),
	(140, 1, 1, -50338, 0, 17, '1'),
	(140, 1, 1, -50337, 0, 17, '1'),
	(140, 1, 1, -50336, 0, 17, '1'),
	(140, 1, 1, -50319, 0, 17, '1'),
	(140, 1, 1, -50304, 0, 17, '1'),
	(140, 1, 1, -50222, 0, 17, '1'),
	(140, 1, 1, -50217, 0, 17, '1'),
	(140, 1, 1, -50163, 0, 17, '1'),
	(140, 1, 1, -50079, 0, 17, '1'),
	(140, 1, 1, -50078, 0, 17, '1'),
	(140, 1, 1, -50077, 0, 17, '1'),
	(140, 1, 1, -50073, 0, 17, '1'),
	(140, 1, 1, -50022, 0, 17, '1'),
	(140, 1, 1, -50003, 0, 17, '1'),
	(140, 1, 1, -50002, 0, 17, '1'),
	(140, 1, 1, -8, 0, 17, '1'),
	(140, 1, 1, -7, 0, 17, '1'),
	(140, 1, 1, -5, 0, 17, '1'),
	(140, 1, 1, -3, 0, 17, '1'),
	(140, 1, 1, 10010, 0, 17, '1'),
	(209, 1, 1, -50511, 0, 17, '1'),
	(209, 1, 1, -50491, 0, 17, '1'),
	(209, 1, 1, -50490, 0, 17, '1'),
	(209, 1, 1, -50489, 0, 17, '1'),
	(209, 1, 1, -50488, 0, 17, '1'),
	(209, 1, 1, -50416, 0, 17, '1'),
	(209, 1, 1, -50415, 0, 17, '1'),
	(209, 1, 1, -50414, 0, 17, '1'),
	(209, 1, 1, -50413, 0, 17, '1'),
	(209, 1, 1, -50412, 0, 17, '1'),
	(209, 1, 1, -50411, 0, 17, '1'),
	(209, 1, 1, -50410, 0, 17, '1'),
	(209, 1, 1, -50409, 0, 17, '1'),
	(209, 1, 1, -50408, 0, 17, '1'),
	(209, 1, 1, -50407, 0, 17, '1'),
	(209, 1, 1, -50406, 0, 17, '1'),
	(209, 1, 1, -50405, 0, 17, '1'),
	(209, 1, 1, -50404, 0, 17, '1'),
	(209, 1, 1, -50403, 0, 17, '1'),
	(209, 1, 1, -50402, 0, 17, '1'),
	(209, 1, 1, -50388, 0, 17, '1'),
	(209, 1, 1, -50357, 0, 17, '1'),
	(209, 1, 1, -50356, 0, 17, '1'),
	(209, 1, 1, -50355, 0, 17, '1'),
	(209, 1, 1, -50352, 0, 17, '1'),
	(209, 1, 1, -50351, 0, 17, '1'),
	(209, 1, 1, -50348, 0, 17, '1'),
	(209, 1, 1, -50347, 0, 17, '1'),
	(209, 1, 1, -50344, 0, 17, '1'),
	(209, 1, 1, -50343, 0, 17, '1'),
	(209, 1, 1, -50342, 0, 17, '1'),
	(209, 1, 1, -50341, 0, 17, '1'),
	(209, 1, 1, -50338, 0, 17, '1'),
	(209, 1, 1, -50337, 0, 17, '1'),
	(209, 1, 1, -50336, 0, 17, '1'),
	(209, 1, 1, -50319, 0, 17, '1'),
	(209, 1, 1, -50304, 0, 17, '1'),
	(209, 1, 1, -50222, 0, 17, '1'),
	(209, 1, 1, -50217, 0, 17, '1'),
	(209, 1, 1, -50163, 0, 17, '1'),
	(209, 1, 1, -50079, 0, 17, '1'),
	(209, 1, 1, -50078, 0, 17, '1'),
	(209, 1, 1, -50077, 0, 17, '1'),
	(209, 1, 1, -50073, 0, 17, '1'),
	(209, 1, 1, -50022, 0, 17, '1'),
	(209, 1, 1, -50003, 0, 17, '1'),
	(209, 1, 1, -50002, 0, 17, '1'),
	(209, 1, 1, -8, 0, 17, '1'),
	(209, 1, 1, -7, 0, 17, '1'),
	(209, 1, 1, -5, 0, 17, '1'),
	(209, 1, 1, -3, 0, 17, '1'),
	(209, 1, 1, 10010, 0, 17, '1'),
	(377, 1, 1, 10010, 0, 37, '1000'),
	(377, 1, 1, 10010, 1, 37, '1001'),
	(377, 1, 1, 10011, 0, 37, '1000'),
	(377, 1, 1, 10011, 1, 37, '1001');
/*!40000 ALTER TABLE `src_type_mod_withe_rc_opty` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_sheaf_rc
CREATE TABLE IF NOT EXISTS `src_type_sheaf_rc` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `sheaf_id` mediumint(8) unsigned NOT NULL COMMENT 'Duomenų pluošto identifikatorius',
  `rc_id` tinyint(3) unsigned NOT NULL COMMENT 'Užklausų priežasties identifikatorius',
  `password_required` tinyint(1) NOT NULL COMMENT 'Slaptažodžio būtinumo požymis',
  `action_desc` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'Veiksmo aprašymas',
  PRIMARY KEY (`src_type_id`,`sheaf_id`,`rc_id`),
  KEY `src_type_sheaf_rc_rc_fk` (`rc_id`),
  KEY `src_type_sheaf_rc_sheaf_fk` (`sheaf_id`),
  CONSTRAINT `src_type_sheaf_rc_rc_fk` FOREIGN KEY (`rc_id`) REFERENCES `rc` (`rc_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_sheaf_rc_sheaf_fk` FOREIGN KEY (`sheaf_id`) REFERENCES `sheaf` (`sheaf_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_sheaf_rc_src_type_fk` FOREIGN KEY (`src_type_id`) REFERENCES `src_type` (`src_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų pluoštų galimos užklausų priežastys per atitinkamų tipų šaltinius';

-- Dumping data for table emcor.src_type_sheaf_rc: ~2 625 rows (approximately)
/*!40000 ALTER TABLE `src_type_sheaf_rc` DISABLE KEYS */;
INSERT INTO `src_type_sheaf_rc` (`src_type_id`, `sheaf_id`, `rc_id`, `password_required`, `action_desc`) VALUES
	(-4, 1, 2, 0, NULL),
	(-4, 1, 4, 0, NULL),
	(-4, 1, 6, 0, NULL),
	(-4, 1, 7, 0, NULL),
	(-4, 1, 11, 0, NULL),
	(-4, 1, 14, 0, NULL),
	(-4, 2, 2, 0, NULL),
	(-4, 2, 4, 0, NULL),
	(-4, 2, 14, 0, NULL),
	(-4, 19, 2, 0, NULL),
	(-4, 19, 4, 0, NULL),
	(-4, 19, 14, 0, NULL),
	(-4, 22, 2, 0, NULL),
	(-4, 22, 4, 0, NULL),
	(-4, 22, 14, 0, NULL),
	(-1, 1, 2, 0, NULL),
	(-1, 1, 4, 0, NULL),
	(-1, 1, 11, 0, NULL),
	(-1, 1, 14, 0, NULL),
	(-1, 2, 2, 0, NULL),
	(-1, 2, 4, 0, NULL),
	(-1, 2, 14, 0, NULL),
	(-1, 22, 2, 0, NULL),
	(-1, 22, 4, 0, NULL),
	(-1, 22, 14, 0, NULL),
	(1, 1, 2, 0, NULL),
	(1, 1, 4, 0, NULL),
	(1, 1, 6, 1, 'Laiko nustatymo metu duomenys bus ištrinti.'),
	(1, 1, 7, 1, 'Laiko nustatymo metu duomenys bus ištrinti.'),
	(1, 1, 11, 0, NULL),
	(1, 1, 14, 0, NULL),
	(1, 2, 2, 0, NULL),
	(1, 2, 4, 0, NULL),
	(1, 2, 14, 0, NULL),
	(1, 14, 6, 0, 'Koregavimas galimas tik +-5 sek. intervale.'),
	(1, 14, 7, 0, 'Koregavimas galimas tik +-5 sek. intervale.'),
	(1, 16, 2, 0, NULL),
	(1, 16, 4, 0, NULL),
	(1, 16, 14, 0, NULL),
	(1, 19, 2, 0, NULL),
	(1, 19, 4, 0, NULL),
	(1, 19, 14, 0, NULL),
	(1, 22, 2, 0, NULL),
	(1, 22, 4, 0, NULL),
	(1, 22, 14, 0, NULL),
	(14, 1, 2, 0, NULL),
	(14, 1, 4, 0, NULL),
	(14, 1, 11, 0, NULL),
	(14, 1, 14, 0, NULL),
	(24, 1, 2, 0, NULL),
	(24, 1, 4, 0, NULL),
	(24, 1, 11, 0, NULL),
	(24, 1, 14, 0, NULL),
	(24, 2, 2, 0, NULL),
	(24, 2, 4, 0, NULL),
	(24, 2, 14, 0, NULL),
	(24, 14, 6, 0, 'Koregavimas galimas tik +-5 sek. intervale.'),
	(24, 14, 7, 0, 'Koregavimas galimas tik +-5 sek. intervale.'),
	(24, 16, 4, 0, NULL),
	(24, 16, 14, 0, NULL),
	(24, 19, 2, 0, NULL),
	(24, 19, 4, 0, NULL),
	(24, 19, 14, 0, NULL),
	(24, 22, 2, 0, NULL),
	(24, 22, 4, 0, NULL),
	(24, 22, 14, 0, NULL),
	(25, 1, 2, 0, NULL),
	(25, 1, 4, 0, NULL),
	(25, 1, 6, 0, NULL),
	(25, 1, 7, 0, NULL),
	(25, 1, 11, 0, NULL),
	(25, 1, 14, 0, NULL),
	(25, 2, 2, 0, NULL),
	(25, 2, 4, 0, NULL),
	(25, 2, 14, 0, NULL),
	(25, 14, 6, 0, 'Koregavimas galimas tik +-5 sek. intervale.'),
	(25, 14, 7, 0, 'Koregavimas galimas tik +-5 sek. intervale.'),
	(25, 16, 2, 0, NULL),
	(25, 16, 4, 0, NULL),
	(25, 16, 14, 0, NULL),
	(25, 19, 2, 0, NULL),
	(25, 19, 4, 0, NULL),
	(25, 19, 14, 0, NULL),
	(25, 22, 2, 0, NULL),
	(25, 22, 4, 0, NULL),
	(25, 22, 14, 0, NULL),
	(26, 1, 2, 0, NULL),
	(26, 1, 4, 0, NULL),
	(26, 1, 14, 0, NULL),
	(26, 2, 2, 0, NULL),
	(26, 2, 4, 0, NULL),
	(26, 2, 14, 0, NULL),
	(26, 22, 2, 0, NULL),
	(26, 22, 4, 0, NULL),
	(26, 22, 14, 0, NULL),
	(30, 1, 2, 0, NULL),
	(30, 1, 4, 0, NULL),
	(30, 1, 6, 1, 'Laiko nustatymo metu duomenys bus ištrinti.'),
	(30, 1, 7, 1, 'Laiko nustatymo metu duomenys bus ištrinti.'),
	(30, 1, 11, 0, NULL),
	(30, 1, 14, 0, NULL),
	(30, 2, 2, 0, NULL),
	(30, 2, 4, 0, NULL),
	(30, 2, 14, 0, NULL),
	(30, 14, 6, 0, 'Koregavimas galimas tik +-5 sek. intervale.'),
	(30, 14, 7, 0, 'Koregavimas galimas tik +-5 sek. intervale.'),
	(30, 16, 2, 0, NULL),
	(30, 16, 4, 0, NULL),
	(30, 16, 14, 0, NULL),
	(30, 19, 2, 0, NULL),
	(30, 19, 4, 0, NULL),
	(30, 19, 14, 0, NULL),
	(30, 22, 2, 0, NULL),
	(30, 22, 4, 0, NULL),
	(30, 22, 14, 0, NULL),
	(32, 1, 2, 0, NULL),
	(32, 1, 4, 0, NULL),
	(32, 1, 11, 0, NULL),
	(32, 1, 14, 0, NULL),
	(33, 1, 2, 0, NULL),
	(33, 1, 4, 0, NULL),
	(33, 1, 6, 1, 'Laiko nustatymo metu duomenys bus ištrinti.'),
	(33, 1, 7, 1, 'Laiko nustatymo metu duomenys bus ištrinti.'),
	(33, 1, 11, 0, NULL),
	(33, 1, 14, 0, NULL),
	(33, 2, 2, 0, NULL),
	(33, 2, 4, 0, NULL),
	(33, 2, 14, 0, NULL),
	(33, 14, 6, 0, 'Koregavimas galimas tik +-50 sek. intervale.'),
	(33, 14, 7, 0, 'Koregavimas galimas tik +-50 sek. intervale.'),
	(33, 16, 2, 0, NULL),
	(33, 16, 4, 0, NULL),
	(33, 16, 14, 0, NULL),
	(33, 19, 2, 0, NULL),
	(33, 19, 4, 0, NULL),
	(33, 19, 14, 0, NULL),
	(33, 22, 2, 0, NULL),
	(33, 22, 4, 0, NULL),
	(33, 22, 14, 0, NULL),
	(35, 1, 2, 0, NULL),
	(35, 1, 4, 0, NULL),
	(35, 1, 6, 1, 'Jeigu pradinis vartotojas ir slaptažodis pirmo lygmens, draiveris prieš nustatydamas laiką, persijungia į antro lygmens vartotoja, naudojant Password2.'),
	(35, 1, 7, 1, 'Jeigu pradinis vartotojas ir slaptažodis pirmo lygmens, draiveris prieš nustatydamas laiką, persijungia į antro lygmens vartotoja, naudojant Password2.'),
	(35, 1, 11, 0, NULL),
	(35, 1, 14, 0, NULL),
	(35, 14, 6, 1, 'Prietaisas priima korekciją iki 240sek. Vieną kartą per parą.'),
	(35, 14, 7, 1, 'Prietaisas priima korekciją iki 240sek. Vieną kartą per parą.'),
	(35, 16, 2, 0, NULL),
	(35, 16, 4, 0, NULL),
	(35, 16, 14, 0, NULL),
	(35, 10010, 2, 0, NULL),
	(35, 10010, 4, 0, NULL),
	(35, 10010, 6, 0, NULL),
	(35, 10010, 7, 0, NULL),
	(35, 10010, 14, 0, NULL),
	(35, 10010, 16, 0, NULL),
	(35, 10010, 17, 0, NULL),
	(38, 1, 2, 0, NULL),
	(38, 1, 4, 0, NULL),
	(38, 1, 6, 1, 'Realizuota komanda “laiko nustatymas” palaiko tik laiko keitimą toje pačioje paroje. Prieš nustatydamas laiką, draiveris patikrina ar neperžengiamos paros ribos.'),
	(38, 1, 7, 1, 'Realizuota komanda “laiko nustatymas” palaiko tik laiko keitimą toje pačioje paroje. Prieš nustatydamas laiką, draiveris patikrina ar neperžengiamos paros ribos.'),
	(38, 1, 11, 0, NULL),
	(38, 1, 14, 0, NULL),
	(38, 2, 2, 0, NULL),
	(38, 2, 4, 0, NULL),
	(38, 2, 14, 0, NULL),
	(38, 14, 6, 1, 'Prietaisas turi ne standartinę korekciją, o laiko sinchronizavimą – komandos gavimo metu suapvalina laiką iki artimiausios valandos (hh:00:00). Todėl galima maksimali korekcija +-30min. Sinchronizuojant laiką būtina kuo tiksliau (arčiau teisingo 00:00) pataikyti iškviesti komandą. '),
	(38, 14, 7, 1, 'Prietaisas turi ne standartinę korekciją, o laiko sinchronizavimą – komandos gavimo metu suapvalina laiką iki artimiausios valandos (hh:00:00). Todėl galima maksimali korekcija +-30min. Sinchronizuojant laiką būtina kuo tiksliau (arčiau teisingo 00:00) pataikyti iškviesti komandą. '),
	(39, 1, 2, 0, NULL),
	(39, 1, 4, 0, NULL),
	(39, 1, 6, 0, NULL),
	(39, 1, 11, 0, NULL),
	(39, 1, 14, 0, NULL),
	(39, 2, 2, 0, NULL),
	(39, 2, 4, 0, NULL),
	(39, 2, 14, 0, NULL),
	(39, 16, 2, 0, NULL),
	(39, 16, 4, 0, NULL),
	(39, 16, 14, 0, NULL),
	(39, 22, 2, 0, NULL),
	(39, 22, 4, 0, NULL),
	(39, 22, 14, 0, NULL),
	(42, 1, 2, 0, NULL),
	(42, 1, 4, 0, NULL),
	(42, 1, 11, 0, NULL),
	(42, 1, 14, 0, NULL),
	(51, 1, 2, 0, NULL),
	(51, 1, 4, 0, NULL),
	(51, 1, 6, 1, 'Laiko nustatymo metu duomenys bus ištrinti.'),
	(51, 1, 7, 1, 'Laiko nustatymo metu duomenys bus ištrinti.'),
	(51, 1, 11, 0, NULL),
	(51, 1, 14, 0, NULL),
	(51, 2, 2, 0, NULL),
	(51, 2, 4, 0, NULL),
	(51, 2, 14, 0, NULL),
	(51, 14, 6, 0, 'Koregavimas galimas tik +-5 sek. intervale.'),
	(51, 14, 7, 0, 'Koregavimas galimas tik +-5 sek. intervale.'),
	(51, 16, 2, 0, NULL),
	(51, 16, 4, 0, NULL),
	(51, 16, 14, 0, NULL),
	(51, 19, 2, 0, NULL),
	(51, 19, 4, 0, NULL),
	(51, 19, 14, 0, NULL),
	(51, 22, 2, 0, NULL),
	(51, 22, 4, 0, NULL),
	(51, 22, 14, 0, NULL),
	(52, 1, 2, 0, NULL),
	(52, 1, 4, 0, NULL),
	(52, 1, 11, 0, NULL),
	(52, 1, 14, 0, NULL),
	(53, 1, 2, 0, NULL),
	(53, 1, 4, 0, NULL),
	(53, 1, 11, 0, NULL),
	(53, 1, 14, 0, NULL),
	(53, 2, 2, 0, NULL),
	(53, 2, 4, 0, NULL),
	(53, 2, 14, 0, NULL),
	(53, 14, 6, 0, 'Koregavimas galimas tik +-30 sek. intervale.'),
	(53, 14, 7, 0, 'Koregavimas galimas tik +-30 sek. intervale.'),
	(53, 22, 2, 0, NULL),
	(53, 22, 4, 0, NULL),
	(53, 22, 14, 0, NULL),
	(56, 2, 2, 0, NULL),
	(56, 2, 4, 0, NULL),
	(56, 2, 14, 0, NULL),
	(56, 22, 2, 0, NULL),
	(56, 22, 4, 0, NULL),
	(56, 22, 14, 0, NULL),
	(58, 2, 2, 0, NULL),
	(58, 2, 4, 0, NULL),
	(58, 2, 14, 0, NULL),
	(58, 22, 2, 0, NULL),
	(58, 22, 4, 0, NULL),
	(58, 22, 14, 0, NULL),
	(63, 1, 2, 0, NULL),
	(63, 1, 4, 0, NULL),
	(63, 1, 6, 1, NULL),
	(63, 1, 7, 1, NULL),
	(63, 1, 11, 0, NULL),
	(63, 1, 14, 0, NULL),
	(63, 2, 2, 0, NULL),
	(63, 2, 4, 0, NULL),
	(63, 2, 14, 0, NULL),
	(63, 14, 6, 0, NULL),
	(63, 14, 7, 0, NULL),
	(66, 1, 2, 0, NULL),
	(66, 1, 4, 0, NULL),
	(66, 1, 11, 0, NULL),
	(66, 1, 14, 0, NULL),
	(66, 2, 2, 0, NULL),
	(66, 2, 4, 0, NULL),
	(66, 2, 14, 0, NULL),
	(67, 1, 2, 0, NULL),
	(67, 1, 4, 0, NULL),
	(67, 1, 6, 1, 'Laiko nustatymo procedūra gali sukelti sukauptos ir profilio energijos duomenų chronologijos pažeidimą.'),
	(67, 1, 7, 1, 'Laiko nustatymo procedūra gali sukelti sukauptos ir profilio energijos duomenų chronologijos pažeidimą.'),
	(67, 1, 11, 0, NULL),
	(67, 1, 14, 0, NULL),
	(67, 2, 2, 0, NULL),
	(67, 2, 4, 0, NULL),
	(67, 2, 14, 0, NULL),
	(67, 14, 6, 0, 'Koregavimas galimas tik +-127 sek. intervale vieną kartą per parą.'),
	(67, 14, 7, 0, 'Koregavimas galimas tik +-127 sek. intervale vieną kartą per parą.'),
	(67, 22, 2, 0, NULL),
	(67, 22, 4, 0, NULL),
	(67, 22, 14, 0, NULL),
	(68, 1, 2, 0, NULL),
	(68, 1, 4, 0, NULL),
	(68, 1, 6, 1, 'Laiko nustatymo procedūra gali sukelti sukauptos ir profilio energijos duomenų chronologijos pažeidimą.'),
	(68, 1, 7, 1, 'Laiko nustatymo procedūra gali sukelti sukauptos ir profilio energijos duomenų chronologijos pažeidimą.'),
	(68, 1, 11, 0, NULL),
	(68, 1, 14, 0, NULL),
	(68, 2, 2, 0, NULL),
	(68, 2, 4, 0, NULL),
	(68, 2, 14, 0, NULL),
	(68, 14, 6, 0, 'Koregavimas galimas tik +-127 sek. intervale vieną kartą per parą.'),
	(68, 14, 7, 0, 'Koregavimas galimas tik +-127 sek. intervale vieną kartą per parą.'),
	(68, 16, 4, 0, NULL),
	(68, 16, 14, 0, NULL),
	(68, 22, 2, 0, NULL),
	(68, 22, 4, 0, NULL),
	(68, 22, 14, 0, NULL),
	(69, 1, 2, 0, NULL),
	(69, 1, 4, 0, NULL),
	(69, 1, 6, 1, 'Laiko nustatymo procedūra gali sukelti sukauptos ir profilio energijos duomenų chronologijos pažeidimą.'),
	(69, 1, 7, 1, 'Laiko nustatymo procedūra gali sukelti sukauptos ir profilio energijos duomenų chronologijos pažeidimą.'),
	(69, 1, 11, 0, NULL),
	(69, 1, 14, 0, NULL),
	(69, 2, 2, 0, NULL),
	(69, 2, 4, 0, NULL),
	(69, 2, 14, 0, NULL),
	(69, 14, 6, 0, 'Koregavimas galimas tik +-127 sek. intervale vieną kartą per parą.'),
	(69, 14, 7, 0, 'Koregavimas galimas tik +-127 sek. intervale vieną kartą per parą.'),
	(69, 16, 4, 0, NULL),
	(69, 16, 14, 0, NULL),
	(69, 22, 2, 0, NULL),
	(69, 22, 4, 0, NULL),
	(69, 22, 14, 0, NULL),
	(77, 1, 2, 0, NULL),
	(77, 1, 4, 0, NULL),
	(77, 1, 11, 0, NULL),
	(77, 1, 14, 0, NULL),
	(77, 2, 2, 0, NULL),
	(77, 2, 4, 0, NULL),
	(77, 2, 14, 0, NULL),
	(77, 14, 6, 1, 'Koregavimas galimas tik +-1800 sek. intervale.'),
	(77, 14, 7, 1, 'Koregavimas galimas tik +-1800 sek. intervale.'),
	(78, 1, 2, 0, NULL),
	(78, 1, 4, 0, NULL),
	(78, 1, 6, 1, NULL),
	(78, 1, 7, 1, NULL),
	(78, 1, 11, 0, NULL),
	(78, 1, 14, 0, NULL),
	(78, 2, 2, 0, NULL),
	(78, 2, 4, 0, NULL),
	(78, 2, 14, 0, NULL),
	(78, 14, 6, 0, NULL),
	(78, 14, 7, 0, NULL),
	(79, 1, 2, 0, NULL),
	(79, 1, 4, 0, NULL),
	(79, 1, 6, 1, 'Laiko nustatymo procedūra gali sukelti sukauptos ir profilio energijos duomenų chronologijos pažeidimą.'),
	(79, 1, 7, 1, 'Laiko nustatymo procedūra gali sukelti sukauptos ir profilio energijos duomenų chronologijos pažeidimą.'),
	(79, 1, 11, 0, NULL),
	(79, 1, 14, 0, NULL),
	(79, 2, 2, 0, NULL),
	(79, 2, 4, 0, NULL),
	(79, 2, 14, 0, NULL),
	(79, 14, 6, 0, 'Koregavimas galimas tik +-127 sek. intervale vieną kartą per parą.'),
	(79, 14, 7, 0, 'Koregavimas galimas tik +-127 sek. intervale vieną kartą per parą.'),
	(79, 16, 4, 0, NULL),
	(79, 16, 14, 0, NULL),
	(79, 22, 2, 0, NULL),
	(79, 22, 4, 0, NULL),
	(79, 22, 14, 0, NULL),
	(80, 1, 2, 0, NULL),
	(80, 1, 4, 0, NULL),
	(80, 1, 6, 1, 'Laiko nustatymo procedūra gali sukelti sukauptos ir profilio energijos duomenų chronologijos pažeidimą.'),
	(80, 1, 7, 1, 'Laiko nustatymo procedūra gali sukelti sukauptos ir profilio energijos duomenų chronologijos pažeidimą.'),
	(80, 1, 11, 0, NULL),
	(80, 1, 14, 0, NULL),
	(80, 2, 2, 0, NULL),
	(80, 2, 4, 0, NULL),
	(80, 2, 14, 0, NULL),
	(80, 14, 6, 0, 'Koregavimas galimas tik +-127 sek. intervale vieną kartą per parą.'),
	(80, 14, 7, 0, 'Koregavimas galimas tik +-127 sek. intervale vieną kartą per parą.'),
	(80, 22, 2, 0, NULL),
	(80, 22, 4, 0, NULL),
	(80, 22, 14, 0, NULL),
	(81, 1, 2, 0, NULL),
	(81, 1, 4, 0, NULL),
	(81, 1, 6, 0, 'Užklausimas nekeičia esamo sezono (vasaros laiko į žiemos laiką ir atvirkščiai).'),
	(81, 1, 7, 0, 'Užklausimas nekeičia esamo sezono (vasaros laiko į žiemos laiką ir atvirkščiai).'),
	(81, 1, 11, 0, NULL),
	(81, 1, 14, 0, NULL),
	(81, 2, 2, 0, NULL),
	(81, 2, 4, 0, NULL),
	(81, 2, 14, 0, NULL),
	(81, 16, 4, 0, NULL),
	(81, 16, 14, 0, NULL),
	(82, 1, 2, 0, NULL),
	(82, 1, 4, 0, NULL),
	(82, 1, 6, 0, NULL),
	(82, 1, 7, 0, NULL),
	(82, 1, 11, 0, NULL),
	(82, 1, 14, 0, NULL),
	(85, 1, 2, 0, NULL),
	(85, 1, 4, 0, NULL),
	(85, 1, 11, 0, NULL),
	(85, 1, 14, 0, NULL),
	(86, 1, 2, 0, NULL),
	(86, 1, 4, 0, NULL),
	(86, 1, 11, 0, NULL),
	(86, 1, 14, 0, NULL),
	(87, 1, 2, 0, NULL),
	(87, 1, 4, 0, NULL),
	(87, 1, 6, 0, NULL),
	(87, 1, 7, 0, NULL),
	(87, 1, 11, 0, NULL),
	(87, 1, 14, 0, NULL),
	(87, 2, 2, 0, NULL),
	(87, 2, 4, 0, NULL),
	(87, 2, 14, 0, NULL),
	(87, 14, 6, 0, 'Laiko korekciją DKEG-10 palaiko nuo versijos 158.'),
	(87, 14, 7, 0, 'Laiko korekciją DKEG-10 palaiko nuo versijos 158.'),
	(88, 1, 2, 0, NULL),
	(88, 1, 4, 0, NULL),
	(88, 1, 11, 0, NULL),
	(88, 1, 14, 0, NULL),
	(93, 1, 2, 0, NULL),
	(93, 1, 4, 0, NULL),
	(93, 1, 11, 0, NULL),
	(93, 1, 14, 0, NULL),
	(94, 1, 2, 0, NULL),
	(94, 1, 4, 0, NULL),
	(94, 1, 11, 0, NULL),
	(94, 1, 14, 0, NULL),
	(95, 1, 2, 0, NULL),
	(95, 1, 4, 0, NULL),
	(95, 1, 11, 0, NULL),
	(95, 1, 14, 0, NULL),
	(95, 2, 2, 0, NULL),
	(95, 2, 4, 0, NULL),
	(95, 2, 14, 0, NULL),
	(95, 14, 6, 0, 'Koregavimas galimas tik +-30 sek. intervale.'),
	(95, 14, 7, 0, 'Koregavimas galimas tik +-30 sek. intervale.'),
	(99, 1, 2, 0, NULL),
	(99, 1, 4, 0, NULL),
	(99, 1, 11, 0, NULL),
	(99, 1, 14, 0, NULL),
	(101, 1, 2, 0, NULL),
	(101, 1, 4, 0, NULL),
	(101, 1, 6, 1, NULL),
	(101, 1, 7, 1, NULL),
	(101, 1, 11, 0, NULL),
	(101, 1, 14, 0, NULL),
	(101, 2, 2, 0, NULL),
	(101, 2, 4, 0, NULL),
	(101, 2, 14, 0, NULL),
	(101, 14, 6, 0, 'Koregavimas galimas tik +-127 sek. intervale.'),
	(101, 14, 7, 0, 'Koregavimas galimas tik +-127 sek. intervale.'),
	(102, 1, 2, 0, NULL),
	(102, 1, 4, 0, NULL),
	(102, 1, 6, 1, NULL),
	(102, 1, 7, 1, NULL),
	(102, 1, 11, 0, NULL),
	(102, 1, 14, 0, NULL),
	(102, 2, 2, 0, NULL),
	(102, 2, 4, 0, NULL),
	(102, 2, 14, 0, NULL),
	(102, 14, 6, 1, 'Koregavimas galimas tik +-30 sek. intervale.'),
	(102, 14, 7, 1, 'Koregavimas galimas tik +-30 sek. intervale.'),
	(102, 22, 2, 0, NULL),
	(102, 22, 4, 0, NULL),
	(102, 22, 14, 0, NULL),
	(103, 1, 2, 0, NULL),
	(103, 1, 4, 0, NULL),
	(103, 1, 6, 1, NULL),
	(103, 1, 7, 1, NULL),
	(103, 1, 11, 0, NULL),
	(103, 1, 14, 0, NULL),
	(103, 2, 2, 0, NULL),
	(103, 2, 4, 0, NULL),
	(103, 2, 14, 0, NULL),
	(103, 14, 6, 0, 'Koregavimas galimas tik +-30 min. intervale. Esamo skaitiklio laiko pusvalandžiai turi sutapti su naujo laiko reikšme.'),
	(103, 14, 7, 0, 'Koregavimas galimas tik +-30 min. intervale. Esamo skaitiklio laiko pusvalandžiai turi sutapti su naujo laiko reikšme.'),
	(103, 16, 4, 0, NULL),
	(103, 16, 14, 0, NULL),
	(104, 1, 2, 0, NULL),
	(104, 1, 4, 0, NULL),
	(104, 1, 11, 0, NULL),
	(104, 1, 14, 0, NULL),
	(104, 2, 2, 0, NULL),
	(104, 2, 4, 0, NULL),
	(104, 2, 14, 0, NULL),
	(105, 1, 2, 1, NULL),
	(105, 1, 4, 0, NULL),
	(105, 1, 6, 1, NULL),
	(105, 1, 7, 1, NULL),
	(105, 1, 11, 1, NULL),
	(105, 1, 14, 0, NULL),
	(106, 1, 2, 0, NULL),
	(106, 1, 4, 0, NULL),
	(106, 1, 11, 0, NULL),
	(106, 1, 14, 0, NULL),
	(114, 1, 2, 0, NULL),
	(114, 1, 4, 0, NULL),
	(114, 1, 11, 0, NULL),
	(114, 1, 14, 0, NULL),
	(115, 1, 2, 0, NULL),
	(115, 1, 4, 0, NULL),
	(115, 1, 11, 0, NULL),
	(115, 1, 14, 0, NULL),
	(116, 1, 2, 0, NULL),
	(116, 1, 4, 0, NULL),
	(116, 1, 11, 0, NULL),
	(116, 1, 14, 0, NULL),
	(117, 1, 2, 0, NULL),
	(117, 1, 4, 0, NULL),
	(117, 1, 6, 0, NULL),
	(117, 1, 7, 0, NULL),
	(117, 1, 11, 0, NULL),
	(117, 1, 14, 0, NULL),
	(117, 2, 2, 0, NULL),
	(117, 2, 4, 0, NULL),
	(117, 2, 14, 0, NULL),
	(118, 1, 2, 0, NULL),
	(118, 1, 4, 0, NULL),
	(118, 1, 6, 0, NULL),
	(118, 1, 7, 0, NULL),
	(118, 1, 11, 0, NULL),
	(118, 1, 14, 0, NULL),
	(118, 2, 2, 0, NULL),
	(118, 2, 4, 0, NULL),
	(118, 2, 14, 0, NULL),
	(119, 1, 2, 0, NULL),
	(119, 1, 4, 0, NULL),
	(119, 1, 11, 0, NULL),
	(119, 1, 14, 0, NULL),
	(120, 1, 2, 0, NULL),
	(120, 1, 4, 0, NULL),
	(120, 1, 11, 0, NULL),
	(120, 1, 14, 0, NULL),
	(121, 1, 2, 0, NULL),
	(121, 1, 4, 0, NULL),
	(121, 1, 11, 0, NULL),
	(121, 1, 14, 0, NULL),
	(122, 1, 2, 0, NULL),
	(122, 1, 4, 0, NULL),
	(122, 1, 11, 0, NULL),
	(122, 1, 14, 0, NULL),
	(123, 1, 2, 0, NULL),
	(123, 1, 4, 0, NULL),
	(123, 1, 11, 0, NULL),
	(123, 1, 14, 0, NULL),
	(124, 1, 2, 0, NULL),
	(124, 1, 4, 0, NULL),
	(124, 1, 11, 0, NULL),
	(124, 1, 14, 0, NULL),
	(125, 1, 2, 0, NULL),
	(125, 1, 4, 0, NULL),
	(125, 1, 11, 0, NULL),
	(125, 1, 14, 0, NULL),
	(126, 1, 2, 0, NULL),
	(126, 1, 4, 0, NULL),
	(126, 1, 11, 0, NULL),
	(126, 1, 14, 0, NULL),
	(127, 1, 2, 0, NULL),
	(127, 1, 4, 0, NULL),
	(127, 1, 11, 0, NULL),
	(127, 1, 14, 0, NULL),
	(127, 2, 2, 0, NULL),
	(127, 2, 4, 0, NULL),
	(127, 2, 14, 0, NULL),
	(127, 14, 6, 0, 'Koregavimas galimas tik +-5 sek. intervale.'),
	(127, 14, 7, 0, 'Koregavimas galimas tik +-5 sek. intervale.'),
	(127, 16, 2, 0, NULL),
	(127, 16, 4, 0, NULL),
	(127, 16, 14, 0, NULL),
	(127, 19, 2, 0, NULL),
	(127, 19, 4, 0, NULL),
	(127, 19, 14, 0, NULL),
	(127, 22, 2, 0, NULL),
	(127, 22, 4, 0, NULL),
	(127, 22, 14, 0, NULL),
	(128, 1, 2, 0, NULL),
	(128, 1, 4, 0, NULL),
	(128, 1, 11, 0, NULL),
	(128, 1, 14, 0, NULL),
	(128, 2, 2, 0, NULL),
	(128, 2, 4, 0, NULL),
	(128, 2, 14, 0, NULL),
	(128, 19, 2, 0, NULL),
	(128, 19, 4, 0, NULL),
	(128, 19, 14, 0, NULL),
	(128, 22, 2, 0, NULL),
	(128, 22, 4, 0, NULL),
	(128, 22, 14, 0, NULL),
	(129, 1, 2, 0, NULL),
	(129, 1, 4, 0, NULL),
	(129, 1, 6, 1, NULL),
	(129, 1, 7, 1, NULL),
	(129, 1, 11, 0, NULL),
	(129, 1, 14, 0, NULL),
	(129, 2, 2, 0, NULL),
	(129, 2, 4, 0, NULL),
	(129, 2, 14, 0, NULL),
	(130, 1, 2, 0, NULL),
	(130, 1, 4, 0, NULL),
	(130, 1, 6, 1, NULL),
	(130, 1, 7, 1, NULL),
	(130, 1, 11, 0, NULL),
	(130, 1, 14, 0, NULL),
	(130, 2, 2, 0, NULL),
	(130, 2, 4, 0, NULL),
	(130, 2, 14, 0, NULL),
	(131, 1, 2, 0, NULL),
	(131, 1, 4, 0, NULL),
	(131, 1, 11, 0, NULL),
	(131, 1, 14, 0, NULL),
	(131, 2, 2, 0, NULL),
	(131, 2, 4, 0, NULL),
	(131, 2, 14, 0, NULL),
	(133, 1, 2, 0, NULL),
	(133, 1, 4, 0, NULL),
	(133, 1, 11, 0, NULL),
	(133, 1, 14, 0, NULL),
	(134, 1, 2, 0, NULL),
	(134, 1, 4, 0, NULL),
	(134, 1, 11, 0, NULL),
	(134, 1, 14, 0, NULL),
	(135, 1, 2, 0, NULL),
	(135, 1, 4, 0, NULL),
	(135, 1, 6, 1, NULL),
	(135, 1, 7, 1, NULL),
	(135, 1, 11, 0, NULL),
	(135, 1, 14, 0, NULL),
	(135, 2, 2, 0, NULL),
	(135, 2, 4, 0, NULL),
	(135, 2, 14, 0, NULL),
	(135, 14, 6, 0, 'Koregavimas galimas tik +-30 sek. intervale.'),
	(135, 14, 7, 0, 'Koregavimas galimas tik +-30 sek. intervale.'),
	(135, 16, 4, 0, NULL),
	(135, 16, 14, 0, NULL),
	(135, 19, 2, 0, NULL),
	(135, 19, 4, 0, NULL),
	(135, 19, 14, 0, NULL),
	(135, 22, 2, 0, NULL),
	(135, 22, 4, 0, NULL),
	(135, 22, 14, 0, NULL),
	(136, 1, 2, 0, NULL),
	(136, 1, 4, 0, NULL),
	(136, 1, 6, 0, NULL),
	(136, 1, 7, 0, NULL),
	(136, 1, 11, 0, NULL),
	(136, 1, 14, 0, NULL),
	(136, 2, 2, 0, NULL),
	(136, 2, 4, 0, NULL),
	(136, 2, 14, 0, NULL),
	(137, 1, 2, 0, NULL),
	(137, 1, 4, 0, NULL),
	(137, 1, 6, 1, NULL),
	(137, 1, 7, 1, NULL),
	(137, 1, 11, 0, NULL),
	(137, 1, 14, 0, NULL),
	(137, 2, 2, 0, NULL),
	(137, 2, 4, 0, NULL),
	(137, 2, 14, 0, NULL),
	(137, 14, 6, 1, 'Koregavimas galimas tik +-30 sek. intervale.'),
	(137, 14, 7, 1, 'Koregavimas galimas tik +-30 sek. intervale.'),
	(137, 16, 2, 0, NULL),
	(137, 16, 4, 0, NULL),
	(137, 16, 14, 0, NULL),
	(137, 19, 2, 0, NULL),
	(137, 19, 4, 0, NULL),
	(137, 19, 14, 0, NULL),
	(137, 22, 2, 0, NULL),
	(137, 22, 4, 0, NULL),
	(137, 22, 14, 0, NULL),
	(137, 10010, 2, 0, NULL),
	(137, 10010, 4, 0, NULL),
	(137, 10010, 6, 0, NULL),
	(137, 10010, 7, 0, NULL),
	(137, 10010, 14, 0, NULL),
	(137, 10010, 16, 0, NULL),
	(137, 10010, 17, 0, NULL),
	(137, 10011, 2, 0, NULL),
	(137, 10011, 4, 0, NULL),
	(137, 10011, 6, 0, NULL),
	(137, 10011, 7, 0, NULL),
	(137, 10011, 14, 0, NULL),
	(137, 10011, 16, 0, NULL),
	(137, 10011, 17, 0, NULL),
	(139, 1, 2, 0, NULL),
	(139, 1, 4, 0, NULL),
	(139, 1, 11, 0, NULL),
	(139, 1, 14, 0, NULL),
	(139, 2, 2, 0, NULL),
	(139, 2, 4, 0, NULL),
	(139, 2, 14, 0, NULL),
	(139, 16, 4, 0, NULL),
	(139, 16, 14, 0, NULL),
	(139, 22, 2, 0, NULL),
	(139, 22, 4, 0, NULL),
	(139, 22, 14, 0, NULL),
	(139, 10010, 2, 0, NULL),
	(139, 10010, 4, 0, NULL),
	(139, 10010, 6, 0, NULL),
	(139, 10010, 7, 0, NULL),
	(139, 10010, 14, 0, NULL),
	(139, 10010, 16, 0, NULL),
	(139, 10010, 17, 0, NULL),
	(139, 10011, 2, 0, NULL),
	(139, 10011, 4, 0, NULL),
	(139, 10011, 6, 0, NULL),
	(139, 10011, 7, 0, NULL),
	(139, 10011, 14, 0, NULL),
	(139, 10011, 16, 0, NULL),
	(139, 10011, 17, 0, NULL),
	(139, 10951, 2, 0, NULL),
	(139, 10951, 4, 0, NULL),
	(139, 10951, 6, 0, NULL),
	(139, 10951, 7, 0, NULL),
	(139, 10951, 14, 0, NULL),
	(139, 10951, 16, 0, NULL),
	(139, 10951, 17, 0, NULL),
	(140, 1, 2, 0, NULL),
	(140, 1, 4, 0, NULL),
	(140, 1, 6, 0, NULL),
	(140, 1, 7, 0, NULL),
	(140, 1, 11, 0, NULL),
	(140, 1, 14, 0, NULL),
	(140, 2, 2, 0, NULL),
	(140, 2, 4, 0, NULL),
	(140, 2, 14, 0, NULL),
	(140, 14, 6, 0, 'Koregavimas galimas tik +-59 sek. intervale vienos operacijos metu'),
	(140, 14, 7, 0, 'Koregavimas galimas tik +-59 sek. intervale vienos operacijos metu'),
	(140, 16, 4, 0, NULL),
	(140, 16, 14, 0, NULL),
	(140, 22, 2, 0, NULL),
	(140, 22, 4, 0, NULL),
	(140, 22, 14, 0, NULL),
	(140, 10010, 2, 0, NULL),
	(140, 10010, 4, 0, NULL),
	(140, 10010, 6, 0, NULL),
	(140, 10010, 7, 0, NULL),
	(140, 10010, 14, 0, NULL),
	(140, 10010, 16, 0, NULL),
	(140, 10010, 17, 0, NULL),
	(141, 1, 2, 0, NULL),
	(141, 1, 4, 0, NULL),
	(141, 1, 11, 0, NULL),
	(141, 1, 14, 0, NULL),
	(142, 1, 2, 0, NULL),
	(142, 1, 4, 0, NULL),
	(142, 1, 11, 0, NULL),
	(142, 1, 14, 0, NULL),
	(143, 1, 2, 0, NULL),
	(143, 1, 4, 0, NULL),
	(143, 1, 11, 0, NULL),
	(143, 1, 14, 0, NULL),
	(143, 2, 2, 0, NULL),
	(143, 2, 4, 0, NULL),
	(143, 2, 14, 0, NULL),
	(143, 16, 2, 0, NULL),
	(143, 16, 4, 0, NULL),
	(143, 16, 14, 0, NULL),
	(143, 22, 2, 0, NULL),
	(143, 22, 4, 0, NULL),
	(143, 22, 14, 0, NULL),
	(144, 1, 2, 0, NULL),
	(144, 1, 4, 0, NULL),
	(144, 1, 6, 1, NULL),
	(144, 1, 7, 1, NULL),
	(144, 1, 11, 0, NULL),
	(144, 1, 14, 0, NULL),
	(144, 2, 2, 0, NULL),
	(144, 2, 4, 0, NULL),
	(144, 2, 14, 0, NULL),
	(144, 14, 6, 0, 'Koregavimas galimas tik +-127 sek. intervale.'),
	(144, 14, 7, 0, 'Koregavimas galimas tik +-127 sek. intervale.'),
	(144, 22, 2, 0, NULL),
	(144, 22, 4, 0, NULL),
	(144, 22, 14, 0, NULL),
	(145, 1, 2, 0, NULL),
	(145, 1, 4, 0, NULL),
	(145, 1, 6, 1, NULL),
	(145, 1, 7, 1, NULL),
	(145, 1, 11, 0, NULL),
	(145, 1, 14, 0, NULL),
	(145, 2, 2, 0, NULL),
	(145, 2, 4, 0, NULL),
	(145, 2, 14, 0, NULL),
	(145, 16, 2, 0, NULL),
	(145, 16, 4, 0, NULL),
	(145, 16, 14, 0, NULL),
	(145, 19, 2, 0, NULL),
	(145, 19, 4, 0, NULL),
	(145, 19, 14, 0, NULL),
	(145, 22, 2, 0, NULL),
	(145, 22, 4, 0, NULL),
	(145, 22, 14, 0, NULL),
	(147, 1, 2, 0, NULL),
	(147, 1, 4, 0, NULL),
	(147, 1, 6, 0, NULL),
	(147, 1, 7, 0, NULL),
	(147, 1, 11, 0, NULL),
	(147, 1, 14, 0, NULL),
	(147, 2, 2, 0, NULL),
	(147, 2, 4, 0, NULL),
	(147, 2, 14, 0, NULL),
	(147, 14, 6, 0, 'Prietaisas priima korekciją iki 450sek. ir koregavimą vykdo palaipsniui - daugiausiai 5sek. per integravimo periodą.'),
	(147, 14, 7, 0, 'Prietaisas priima korekciją iki 450sek. ir koregavimą vykdo palaipsniui - daugiausiai 5sek. per integravimo periodą.'),
	(147, 22, 2, 0, NULL),
	(147, 22, 4, 0, NULL),
	(147, 22, 14, 0, NULL),
	(148, 1, 2, 0, NULL),
	(148, 1, 4, 0, NULL),
	(148, 1, 6, 0, NULL),
	(148, 1, 7, 0, NULL),
	(148, 1, 11, 0, NULL),
	(148, 1, 14, 0, NULL),
	(148, 2, 2, 0, NULL),
	(148, 2, 4, 0, NULL),
	(148, 2, 14, 0, NULL),
	(148, 14, 6, 0, 'Koregavimas galimas tik +-450 sek. intervale vienos operacijos metu, koreguojama tolygiai po 5 sek. per vieną int.periodą'),
	(148, 14, 7, 0, 'Koregavimas galimas tik +-450 sek. intervale vienos operacijos metu, koreguojama tolygiai po 5 sek. per vieną int.periodą'),
	(148, 19, 2, 0, NULL),
	(148, 19, 4, 0, NULL),
	(148, 19, 14, 0, NULL),
	(148, 22, 2, 0, NULL),
	(148, 22, 4, 0, NULL),
	(148, 22, 14, 0, NULL),
	(151, 1, 2, 0, NULL),
	(151, 1, 4, 0, NULL),
	(151, 1, 11, 0, NULL),
	(151, 1, 14, 0, NULL),
	(153, 22, 2, 0, NULL),
	(153, 22, 4, 0, NULL),
	(153, 22, 14, 0, NULL),
	(154, 1, 2, 0, NULL),
	(154, 1, 4, 0, NULL),
	(154, 1, 6, 0, NULL),
	(154, 1, 7, 0, NULL),
	(154, 1, 11, 0, NULL),
	(154, 1, 14, 0, NULL),
	(154, 2, 2, 0, NULL),
	(154, 2, 4, 0, NULL),
	(154, 2, 14, 0, NULL),
	(154, 16, 4, 0, NULL),
	(154, 16, 14, 0, NULL),
	(154, 22, 2, 0, NULL),
	(154, 22, 4, 0, NULL),
	(154, 22, 14, 0, NULL),
	(157, 2, 2, 0, NULL),
	(157, 2, 4, 0, NULL),
	(157, 2, 14, 0, NULL),
	(157, 16, 2, 0, NULL),
	(157, 16, 4, 0, NULL),
	(157, 16, 14, 0, NULL),
	(157, 19, 2, 0, NULL),
	(157, 19, 4, 0, NULL),
	(157, 19, 14, 0, NULL),
	(157, 22, 2, 0, NULL),
	(157, 22, 4, 0, NULL),
	(157, 22, 14, 0, NULL),
	(160, 1, 2, 0, NULL),
	(160, 1, 4, 0, NULL),
	(160, 1, 11, 0, NULL),
	(160, 1, 14, 0, NULL),
	(160, 2, 2, 0, NULL),
	(160, 2, 4, 0, NULL),
	(160, 2, 14, 0, NULL),
	(162, 16, 4, 0, NULL),
	(162, 16, 14, 0, NULL),
	(165, 1, 2, 0, NULL),
	(165, 1, 4, 0, NULL),
	(165, 1, 6, 1, NULL),
	(165, 1, 7, 1, NULL),
	(165, 1, 11, 0, NULL),
	(165, 1, 14, 0, NULL),
	(165, 2, 2, 0, NULL),
	(165, 2, 4, 0, NULL),
	(165, 2, 14, 0, NULL),
	(166, 1, 2, 0, NULL),
	(166, 1, 4, 0, NULL),
	(166, 1, 6, 0, NULL),
	(166, 1, 7, 0, NULL),
	(166, 1, 11, 0, NULL),
	(166, 1, 14, 0, NULL),
	(167, 1, 2, 0, NULL),
	(167, 1, 4, 0, NULL),
	(167, 1, 6, 1, NULL),
	(167, 1, 7, 1, NULL),
	(167, 1, 11, 0, NULL),
	(167, 1, 14, 0, NULL),
	(167, 2, 2, 0, NULL),
	(167, 2, 4, 0, NULL),
	(167, 2, 14, 0, NULL),
	(168, 1, 2, 0, NULL),
	(168, 1, 4, 0, NULL),
	(168, 1, 6, 1, NULL),
	(168, 1, 7, 1, NULL),
	(168, 1, 11, 0, NULL),
	(168, 1, 14, 0, NULL),
	(168, 2, 2, 0, NULL),
	(168, 2, 4, 0, NULL),
	(168, 2, 14, 0, NULL),
	(168, 14, 6, 1, 'Koregavimas galimas tik +-3600 sek. intervale.'),
	(168, 14, 7, 1, 'Koregavimas galimas tik +-3600 sek. intervale.'),
	(174, 14, 6, 0, NULL),
	(174, 14, 7, 0, NULL),
	(180, 1, 2, 0, NULL),
	(180, 1, 4, 0, NULL),
	(180, 1, 11, 0, NULL),
	(180, 1, 14, 0, NULL),
	(185, 1, 2, 0, NULL),
	(185, 1, 4, 0, NULL),
	(185, 1, 11, 0, NULL),
	(185, 1, 14, 0, NULL),
	(185, 16, 4, 0, NULL),
	(185, 16, 14, 0, NULL),
	(186, 1, 2, 0, NULL),
	(186, 1, 4, 0, NULL),
	(186, 1, 11, 0, NULL),
	(186, 1, 14, 0, NULL),
	(186, 2, 2, 0, NULL),
	(186, 2, 4, 0, NULL),
	(186, 2, 14, 0, NULL),
	(188, 1, 2, 0, NULL),
	(188, 1, 4, 0, NULL),
	(188, 1, 6, 1, NULL),
	(188, 1, 7, 1, NULL),
	(188, 1, 11, 0, NULL),
	(188, 1, 14, 0, NULL),
	(188, 2, 2, 0, NULL),
	(188, 2, 4, 0, NULL),
	(188, 2, 14, 0, NULL),
	(188, 14, 6, 0, 'Koregavimas galimas tik +-30 min. intervale. Esamo skaitiklio laiko pusvalandžiai turi sutapti su naujo laiko reikšme.'),
	(188, 14, 7, 0, 'Koregavimas galimas tik +-30 min. intervale. Esamo skaitiklio laiko pusvalandžiai turi sutapti su naujo laiko reikšme.'),
	(188, 16, 4, 0, NULL),
	(188, 16, 14, 0, NULL),
	(189, 1, 2, 1, NULL),
	(189, 1, 4, 1, NULL),
	(189, 1, 6, 1, NULL),
	(189, 1, 7, 1, NULL),
	(189, 1, 11, 1, NULL),
	(189, 1, 14, 1, NULL),
	(189, 2, 2, 0, NULL),
	(189, 2, 4, 0, NULL),
	(189, 2, 14, 0, NULL),
	(189, 16, 2, 0, NULL),
	(189, 16, 4, 0, NULL),
	(189, 16, 14, 0, NULL),
	(189, 22, 2, 0, NULL),
	(189, 22, 4, 0, NULL),
	(189, 22, 14, 0, NULL),
	(190, 1, 2, 0, NULL),
	(190, 1, 4, 0, NULL),
	(190, 1, 6, 0, NULL),
	(190, 1, 7, 0, NULL),
	(190, 1, 11, 0, NULL),
	(190, 1, 14, 0, NULL),
	(190, 2, 2, 0, NULL),
	(190, 2, 4, 0, NULL),
	(190, 2, 14, 0, NULL),
	(191, 1, 2, 0, NULL),
	(191, 1, 4, 0, NULL),
	(191, 1, 11, 0, NULL),
	(191, 1, 14, 0, NULL),
	(197, 1, 2, 0, NULL),
	(197, 1, 4, 0, NULL),
	(197, 1, 6, 1, NULL),
	(197, 1, 7, 1, NULL),
	(197, 1, 11, 0, NULL),
	(197, 1, 14, 0, NULL),
	(197, 2, 2, 0, NULL),
	(197, 2, 4, 0, NULL),
	(197, 2, 14, 0, NULL),
	(197, 14, 6, 1, 'Koregavimas galimas tik +-30 sek. intervale.'),
	(197, 14, 7, 1, 'Koregavimas galimas tik +-30 sek. intervale.'),
	(197, 16, 2, 0, NULL),
	(197, 16, 4, 0, NULL),
	(197, 16, 14, 0, NULL),
	(197, 19, 2, 0, NULL),
	(197, 19, 4, 0, NULL),
	(197, 19, 14, 0, NULL),
	(197, 22, 2, 0, NULL),
	(197, 22, 4, 0, NULL),
	(197, 22, 14, 0, NULL),
	(197, 10010, 2, 0, NULL),
	(197, 10010, 4, 0, NULL),
	(197, 10010, 6, 0, NULL),
	(197, 10010, 7, 0, NULL),
	(197, 10010, 14, 0, NULL),
	(197, 10010, 16, 0, NULL),
	(197, 10010, 17, 0, NULL),
	(197, 10011, 2, 0, NULL),
	(197, 10011, 4, 0, NULL),
	(197, 10011, 6, 0, NULL),
	(197, 10011, 7, 0, NULL),
	(197, 10011, 14, 0, NULL),
	(197, 10011, 16, 0, NULL),
	(197, 10011, 17, 0, NULL),
	(200, 1, 2, 0, NULL),
	(200, 1, 4, 0, NULL),
	(200, 1, 11, 0, NULL),
	(200, 1, 14, 0, NULL),
	(200, 2, 2, 0, NULL),
	(200, 2, 4, 0, NULL),
	(200, 2, 14, 0, NULL),
	(200, 14, 6, 0, 'Koregavimas galimas tik +-24 sek. intervale vienos operacijos metu'),
	(200, 14, 7, 0, 'Koregavimas galimas tik +-24 sek. intervale vienos operacijos metu'),
	(200, 16, 2, 0, NULL),
	(200, 16, 4, 0, NULL),
	(200, 16, 14, 0, NULL),
	(202, 1, 2, 0, NULL),
	(202, 1, 4, 0, NULL),
	(202, 1, 11, 0, NULL),
	(202, 1, 14, 0, NULL),
	(202, 14, 6, 0, 'Koregavimas galimas tik +-1800 sek. intervale.'),
	(202, 14, 7, 0, 'Koregavimas galimas tik +-1800 sek. intervale.'),
	(203, 1, 2, 0, NULL),
	(203, 1, 4, 0, NULL),
	(203, 1, 6, 1, NULL),
	(203, 1, 7, 1, NULL),
	(203, 1, 11, 0, NULL),
	(203, 1, 14, 0, NULL),
	(203, 2, 2, 0, NULL),
	(203, 2, 4, 0, NULL),
	(203, 2, 14, 0, NULL),
	(203, 16, 4, 0, NULL),
	(203, 16, 14, 0, NULL),
	(203, 19, 2, 0, NULL),
	(203, 19, 4, 0, NULL),
	(203, 19, 14, 0, NULL),
	(203, 22, 2, 0, NULL),
	(203, 22, 4, 0, NULL),
	(203, 22, 14, 0, NULL),
	(205, 1, 2, 0, NULL),
	(205, 1, 4, 0, NULL),
	(205, 1, 6, 0, NULL),
	(205, 1, 7, 0, NULL),
	(205, 1, 11, 0, NULL),
	(205, 1, 14, 0, NULL),
	(205, 2, 2, 0, NULL),
	(205, 2, 4, 0, NULL),
	(205, 2, 14, 0, NULL),
	(205, 19, 2, 0, NULL),
	(205, 19, 4, 0, NULL),
	(205, 19, 14, 0, NULL),
	(205, 22, 2, 0, NULL),
	(205, 22, 4, 0, NULL),
	(205, 22, 14, 0, NULL),
	(205, 10010, 2, 0, NULL),
	(205, 10010, 4, 0, NULL),
	(205, 10010, 6, 0, NULL),
	(205, 10010, 7, 0, NULL),
	(205, 10010, 14, 0, NULL),
	(205, 10010, 16, 0, NULL),
	(205, 10010, 17, 0, NULL),
	(206, 1, 2, 0, NULL),
	(206, 1, 4, 0, NULL),
	(206, 1, 6, 0, NULL),
	(206, 1, 7, 0, NULL),
	(206, 1, 11, 0, NULL),
	(206, 1, 14, 0, NULL),
	(206, 2, 2, 0, NULL),
	(206, 2, 4, 0, NULL),
	(206, 2, 14, 0, NULL),
	(206, 19, 2, 0, NULL),
	(206, 19, 4, 0, NULL),
	(206, 19, 14, 0, NULL),
	(206, 22, 2, 0, NULL),
	(206, 22, 4, 0, NULL),
	(206, 22, 14, 0, NULL),
	(206, 10010, 2, 0, NULL),
	(206, 10010, 4, 0, NULL),
	(206, 10010, 6, 0, NULL),
	(206, 10010, 7, 0, NULL),
	(206, 10010, 14, 0, NULL),
	(206, 10010, 16, 0, NULL),
	(206, 10010, 17, 0, NULL),
	(207, 1, 2, 0, NULL),
	(207, 1, 4, 0, NULL),
	(207, 1, 6, 1, NULL),
	(207, 1, 7, 1, NULL),
	(207, 1, 11, 0, NULL),
	(207, 1, 14, 0, NULL),
	(207, 2, 2, 0, NULL),
	(207, 2, 4, 0, NULL),
	(207, 2, 14, 0, NULL),
	(207, 14, 6, 0, 'Koregavimas galimas tik +-30 sek. intervale.'),
	(207, 14, 7, 0, 'Koregavimas galimas tik +-30 sek. intervale.'),
	(207, 16, 4, 0, NULL),
	(207, 16, 14, 0, NULL),
	(207, 19, 2, 0, NULL),
	(207, 19, 4, 0, NULL),
	(207, 19, 14, 0, NULL),
	(207, 22, 2, 0, NULL),
	(207, 22, 4, 0, NULL),
	(207, 22, 14, 0, NULL),
	(208, 1, 2, 0, NULL),
	(208, 1, 4, 0, NULL),
	(208, 1, 6, 1, NULL),
	(208, 1, 7, 1, NULL),
	(208, 1, 11, 0, NULL),
	(208, 1, 14, 0, NULL),
	(208, 2, 2, 0, NULL),
	(208, 2, 4, 0, NULL),
	(208, 2, 14, 0, NULL),
	(208, 16, 2, 0, NULL),
	(208, 16, 4, 0, NULL),
	(208, 16, 14, 0, NULL),
	(208, 19, 2, 0, NULL),
	(208, 19, 4, 0, NULL),
	(208, 19, 14, 0, NULL),
	(208, 22, 2, 0, NULL),
	(208, 22, 4, 0, NULL),
	(208, 22, 14, 0, NULL),
	(209, 1, 2, 0, NULL),
	(209, 1, 4, 0, NULL),
	(209, 1, 6, 0, NULL),
	(209, 1, 7, 0, NULL),
	(209, 1, 11, 0, NULL),
	(209, 1, 14, 0, NULL),
	(209, 2, 2, 0, NULL),
	(209, 2, 4, 0, NULL),
	(209, 2, 14, 0, NULL),
	(209, 14, 6, 0, 'Koregavimas galimas tik +-59 sek. intervale vienos operacijos metu'),
	(209, 14, 7, 0, 'Koregavimas galimas tik +-59 sek. intervale vienos operacijos metu'),
	(209, 16, 4, 0, NULL),
	(209, 16, 14, 0, NULL),
	(209, 22, 2, 0, NULL),
	(209, 22, 4, 0, NULL),
	(209, 22, 14, 0, NULL),
	(209, 10010, 2, 0, NULL),
	(209, 10010, 4, 0, NULL),
	(209, 10010, 6, 0, NULL),
	(209, 10010, 7, 0, NULL),
	(209, 10010, 14, 0, NULL),
	(209, 10010, 16, 0, NULL),
	(209, 10010, 17, 0, NULL),
	(210, 1, 2, 0, NULL),
	(210, 1, 4, 0, NULL),
	(210, 1, 6, 0, NULL),
	(210, 1, 7, 0, NULL),
	(210, 1, 11, 0, NULL),
	(210, 1, 14, 0, NULL),
	(210, 2, 2, 0, NULL),
	(210, 2, 4, 0, NULL),
	(210, 2, 14, 0, NULL),
	(210, 14, 6, 0, 'Koregavimas galimas tik +-58 sek. intervale vieną kartą per parą.'),
	(210, 14, 7, 0, 'Koregavimas galimas tik +-58 sek. intervale vieną kartą per parą.'),
	(210, 16, 2, 0, NULL),
	(210, 16, 4, 0, NULL),
	(210, 16, 14, 0, NULL),
	(210, 19, 2, 0, NULL),
	(210, 19, 4, 0, NULL),
	(210, 19, 14, 0, NULL),
	(210, 22, 2, 0, NULL),
	(210, 22, 4, 0, NULL),
	(210, 22, 14, 0, NULL),
	(211, 1, 2, 0, NULL),
	(211, 1, 4, 0, NULL),
	(211, 1, 11, 0, NULL),
	(211, 1, 14, 0, NULL),
	(214, 1, 2, 0, NULL),
	(214, 1, 4, 0, NULL),
	(214, 1, 11, 0, NULL),
	(214, 1, 14, 0, NULL),
	(215, 16, 2, 0, NULL),
	(215, 16, 4, 0, NULL),
	(215, 16, 14, 0, NULL),
	(216, 2, 2, 0, NULL),
	(216, 2, 4, 0, NULL),
	(216, 2, 14, 0, NULL),
	(216, 19, 2, 0, NULL),
	(216, 19, 4, 0, NULL),
	(216, 19, 14, 0, NULL),
	(217, 2, 2, 0, NULL),
	(217, 2, 4, 0, NULL),
	(217, 2, 14, 0, NULL),
	(217, 22, 2, 0, NULL),
	(217, 22, 4, 0, NULL),
	(217, 22, 14, 0, NULL),
	(218, 1, 2, 0, NULL),
	(218, 1, 4, 0, NULL),
	(218, 1, 6, 0, NULL),
	(218, 1, 7, 0, NULL),
	(218, 1, 11, 0, NULL),
	(218, 1, 14, 0, NULL),
	(218, 2, 2, 0, NULL),
	(218, 2, 4, 0, NULL),
	(218, 2, 14, 0, NULL),
	(218, 19, 2, 0, NULL),
	(218, 19, 4, 0, NULL),
	(218, 19, 14, 0, NULL),
	(218, 22, 2, 0, NULL),
	(218, 22, 4, 0, NULL),
	(218, 22, 14, 0, NULL),
	(221, 1, 2, 0, NULL),
	(221, 1, 4, 0, NULL),
	(221, 1, 11, 0, NULL),
	(221, 1, 14, 0, NULL),
	(223, 2, 2, 0, NULL),
	(223, 2, 4, 0, NULL),
	(223, 2, 14, 0, NULL),
	(223, 19, 2, 0, NULL),
	(223, 19, 4, 0, NULL),
	(223, 19, 14, 0, NULL),
	(224, 2, 2, 0, NULL),
	(224, 2, 4, 0, NULL),
	(224, 2, 14, 0, NULL),
	(224, 19, 2, 0, NULL),
	(224, 19, 4, 0, NULL),
	(224, 19, 14, 0, NULL),
	(225, 2, 2, 0, NULL),
	(225, 2, 4, 0, NULL),
	(225, 2, 14, 0, NULL),
	(225, 19, 2, 0, NULL),
	(225, 19, 4, 0, NULL),
	(225, 19, 14, 0, NULL),
	(226, 1, 2, 0, NULL),
	(226, 1, 4, 0, NULL),
	(226, 1, 6, 1, NULL),
	(226, 1, 7, 1, NULL),
	(226, 1, 11, 0, NULL),
	(226, 1, 14, 0, NULL),
	(226, 2, 2, 0, NULL),
	(226, 2, 4, 0, NULL),
	(226, 2, 14, 0, NULL),
	(226, 14, 6, 0, 'Koregavimas galimas tik +-127 sek. intervale.'),
	(226, 14, 7, 0, 'Koregavimas galimas tik +-127 sek. intervale.'),
	(226, 22, 2, 0, NULL),
	(226, 22, 4, 0, NULL),
	(226, 22, 14, 0, NULL),
	(228, 1, 2, 0, NULL),
	(228, 1, 4, 0, NULL),
	(228, 1, 6, 1, NULL),
	(228, 1, 7, 1, NULL),
	(228, 1, 11, 0, NULL),
	(228, 1, 14, 0, NULL),
	(228, 2, 2, 0, NULL),
	(228, 2, 4, 0, NULL),
	(228, 2, 14, 0, NULL),
	(228, 14, 6, 0, 'Koregavimas galimas tik +-127 sek. intervale.'),
	(228, 14, 7, 0, 'Koregavimas galimas tik +-127 sek. intervale.'),
	(228, 22, 2, 0, NULL),
	(228, 22, 4, 0, NULL),
	(228, 22, 14, 0, NULL),
	(229, 1, 2, 0, NULL),
	(229, 1, 4, 0, NULL),
	(229, 1, 6, 1, NULL),
	(229, 1, 7, 1, NULL),
	(229, 1, 11, 0, NULL),
	(229, 1, 14, 0, NULL),
	(229, 2, 2, 0, NULL),
	(229, 2, 4, 0, NULL),
	(229, 2, 14, 0, NULL),
	(229, 14, 6, 0, 'Koregavimas galimas tik +-127 sek. intervale.'),
	(229, 14, 7, 0, 'Koregavimas galimas tik +-127 sek. intervale.'),
	(229, 22, 2, 0, NULL),
	(229, 22, 4, 0, NULL),
	(229, 22, 14, 0, NULL),
	(232, 1, 2, 0, NULL),
	(232, 1, 4, 0, NULL),
	(232, 1, 11, 0, NULL),
	(232, 1, 14, 0, NULL),
	(232, 2, 2, 0, NULL),
	(232, 2, 4, 0, NULL),
	(232, 2, 14, 0, NULL),
	(232, 16, 4, 0, NULL),
	(232, 16, 14, 0, NULL),
	(232, 22, 2, 0, NULL),
	(232, 22, 4, 0, NULL),
	(232, 22, 14, 0, NULL),
	(232, 10010, 2, 0, NULL),
	(232, 10010, 4, 0, NULL),
	(232, 10010, 6, 0, NULL),
	(232, 10010, 7, 0, NULL),
	(232, 10010, 14, 0, NULL),
	(232, 10010, 16, 0, NULL),
	(232, 10010, 17, 0, NULL),
	(234, 16, 4, 0, NULL),
	(234, 16, 14, 0, NULL),
	(235, 1, 2, 0, NULL),
	(235, 1, 4, 0, NULL),
	(235, 1, 6, 0, NULL),
	(235, 1, 7, 0, NULL),
	(235, 1, 11, 0, NULL),
	(235, 1, 14, 0, NULL),
	(235, 2, 2, 0, NULL),
	(235, 2, 4, 0, NULL),
	(235, 2, 14, 0, NULL),
	(235, 14, 6, 0, NULL),
	(235, 14, 7, 0, NULL),
	(235, 19, 2, 0, NULL),
	(235, 19, 4, 0, NULL),
	(235, 19, 14, 0, NULL),
	(235, 22, 2, 0, NULL),
	(235, 22, 4, 0, NULL),
	(235, 22, 14, 0, NULL),
	(236, 2, 2, 0, NULL),
	(236, 2, 4, 0, NULL),
	(236, 2, 14, 0, NULL),
	(236, 19, 2, 0, NULL),
	(236, 19, 4, 0, NULL),
	(236, 19, 14, 0, NULL),
	(236, 22, 2, 0, NULL),
	(236, 22, 4, 0, NULL),
	(236, 22, 14, 0, NULL),
	(243, 1, 2, 0, NULL),
	(243, 1, 4, 0, NULL),
	(243, 1, 6, 0, NULL),
	(243, 1, 7, 0, NULL),
	(243, 1, 11, 0, NULL),
	(243, 1, 14, 0, NULL),
	(243, 2, 2, 0, NULL),
	(243, 2, 4, 0, NULL),
	(243, 2, 14, 0, NULL),
	(243, 14, 6, 0, NULL),
	(243, 14, 7, 0, NULL),
	(243, 16, 2, 0, NULL),
	(243, 16, 4, 0, NULL),
	(243, 16, 14, 0, NULL),
	(243, 19, 2, 0, NULL),
	(243, 19, 4, 0, NULL),
	(243, 19, 14, 0, NULL),
	(243, 22, 2, 0, NULL),
	(243, 22, 4, 0, NULL),
	(243, 22, 14, 0, NULL),
	(244, 1, 2, 0, NULL),
	(244, 1, 4, 0, NULL),
	(244, 1, 11, 0, NULL),
	(244, 1, 14, 0, NULL),
	(244, 16, 4, 0, NULL),
	(244, 16, 14, 0, NULL),
	(244, 10010, 2, 0, NULL),
	(244, 10010, 4, 0, NULL),
	(244, 10010, 14, 0, NULL),
	(246, 1, 2, 0, NULL),
	(246, 1, 4, 0, NULL),
	(246, 1, 6, 1, NULL),
	(246, 1, 7, 1, NULL),
	(246, 1, 14, 0, NULL),
	(246, 2, 2, 0, NULL),
	(246, 2, 4, 0, NULL),
	(246, 2, 14, 0, NULL),
	(246, 22, 2, 0, NULL),
	(246, 22, 4, 0, NULL),
	(246, 22, 14, 0, NULL),
	(248, 1, 2, 0, NULL),
	(248, 1, 4, 0, NULL),
	(248, 1, 11, 0, NULL),
	(248, 1, 14, 0, NULL),
	(248, 2, 2, 0, NULL),
	(248, 2, 4, 0, NULL),
	(248, 2, 14, 0, NULL),
	(248, 16, 4, 0, NULL),
	(248, 16, 14, 0, NULL),
	(248, 22, 2, 0, NULL),
	(248, 22, 4, 0, NULL),
	(248, 22, 14, 0, NULL),
	(248, 10010, 2, 0, NULL),
	(248, 10010, 4, 0, NULL),
	(248, 10010, 6, 0, NULL),
	(248, 10010, 7, 0, NULL),
	(248, 10010, 14, 0, NULL),
	(248, 10010, 16, 0, NULL),
	(248, 10010, 17, 0, NULL),
	(249, 1, 2, 1, NULL),
	(249, 1, 4, 1, NULL),
	(249, 1, 6, 1, NULL),
	(249, 1, 7, 1, NULL),
	(249, 1, 11, 1, NULL),
	(249, 1, 14, 1, NULL),
	(249, 2, 2, 0, NULL),
	(249, 2, 4, 0, NULL),
	(249, 2, 14, 0, NULL),
	(249, 14, 6, 1, 'Koregavimas galimas tik +-1 sek. intervale.'),
	(249, 14, 7, 1, 'Koregavimas galimas tik +-1 sek. intervale.'),
	(249, 16, 4, 0, NULL),
	(249, 16, 14, 0, NULL),
	(249, 19, 2, 0, NULL),
	(249, 19, 4, 0, NULL),
	(249, 19, 14, 0, NULL),
	(249, 22, 2, 0, NULL),
	(249, 22, 4, 0, NULL),
	(249, 22, 14, 0, NULL),
	(249, 10010, 2, 0, NULL),
	(249, 10010, 4, 0, NULL),
	(249, 10010, 6, 0, NULL),
	(249, 10010, 7, 0, NULL),
	(249, 10010, 14, 0, NULL),
	(249, 10010, 16, 0, NULL),
	(249, 10010, 17, 0, NULL),
	(249, 10011, 2, 0, NULL),
	(249, 10011, 4, 0, NULL),
	(249, 10011, 6, 0, NULL),
	(249, 10011, 7, 0, NULL),
	(249, 10011, 14, 0, NULL),
	(249, 10011, 16, 0, NULL),
	(249, 10011, 17, 0, NULL),
	(251, 1, 2, 0, NULL),
	(251, 1, 4, 0, NULL),
	(251, 1, 6, 1, NULL),
	(251, 1, 7, 1, NULL),
	(251, 1, 11, 0, NULL),
	(251, 1, 14, 0, NULL),
	(251, 2, 2, 0, NULL),
	(251, 2, 4, 0, NULL),
	(251, 2, 14, 0, NULL),
	(251, 14, 6, 1, 'Koregavimas galimas tik +-1800 sek. intervale.'),
	(251, 14, 7, 1, 'Koregavimas galimas tik +-1800 sek. intervale.'),
	(251, 16, 4, 0, NULL),
	(251, 16, 14, 0, NULL),
	(251, 19, 2, 0, NULL),
	(251, 19, 4, 0, NULL),
	(251, 19, 14, 0, NULL),
	(251, 22, 2, 0, NULL),
	(251, 22, 4, 0, NULL),
	(251, 22, 14, 0, NULL),
	(252, 2, 2, 0, NULL),
	(252, 2, 4, 0, NULL),
	(252, 2, 14, 0, NULL),
	(252, 16, 4, 0, NULL),
	(252, 16, 14, 0, NULL),
	(252, 19, 2, 0, NULL),
	(252, 19, 4, 0, NULL),
	(252, 19, 14, 0, NULL),
	(252, 22, 2, 0, NULL),
	(252, 22, 4, 0, NULL),
	(252, 22, 14, 0, NULL),
	(253, 16, 4, 0, NULL),
	(253, 16, 14, 0, NULL),
	(253, 19, 2, 0, NULL),
	(253, 19, 4, 0, NULL),
	(253, 19, 14, 0, NULL),
	(255, 16, 4, 0, NULL),
	(255, 16, 14, 0, NULL),
	(255, 19, 2, 0, NULL),
	(255, 19, 4, 0, NULL),
	(255, 19, 14, 0, NULL),
	(256, 16, 4, 0, NULL),
	(256, 16, 14, 0, NULL),
	(256, 19, 2, 0, NULL),
	(256, 19, 4, 0, NULL),
	(256, 19, 14, 0, NULL),
	(257, 1, 2, 0, NULL),
	(257, 1, 4, 0, NULL),
	(257, 1, 11, 0, NULL),
	(257, 1, 14, 0, NULL),
	(257, 16, 4, 0, NULL),
	(257, 16, 14, 0, NULL),
	(258, 1, 2, 0, NULL),
	(258, 1, 4, 0, NULL),
	(258, 1, 6, 0, NULL),
	(258, 1, 7, 0, NULL),
	(258, 1, 11, 0, NULL),
	(258, 1, 14, 0, NULL),
	(258, 2, 2, 0, NULL),
	(258, 2, 4, 0, NULL),
	(258, 2, 14, 0, NULL),
	(258, 14, 6, 0, NULL),
	(258, 14, 7, 0, NULL),
	(258, 19, 2, 0, NULL),
	(258, 19, 4, 0, NULL),
	(258, 19, 14, 0, NULL),
	(258, 22, 2, 0, NULL),
	(258, 22, 4, 0, NULL),
	(258, 22, 14, 0, NULL),
	(259, 1, 2, 0, NULL),
	(259, 1, 4, 0, NULL),
	(259, 1, 6, 0, NULL),
	(259, 1, 7, 0, NULL),
	(259, 1, 11, 0, NULL),
	(259, 1, 14, 0, NULL),
	(259, 2, 2, 0, NULL),
	(259, 2, 4, 0, NULL),
	(259, 2, 14, 0, NULL),
	(259, 14, 6, 0, NULL),
	(259, 14, 7, 0, NULL),
	(259, 19, 2, 0, NULL),
	(259, 19, 4, 0, NULL),
	(259, 19, 14, 0, NULL),
	(259, 22, 2, 0, NULL),
	(259, 22, 4, 0, NULL),
	(259, 22, 14, 0, NULL),
	(260, 1, 2, 0, NULL),
	(260, 1, 4, 0, NULL),
	(260, 1, 6, 0, NULL),
	(260, 1, 7, 0, NULL),
	(260, 1, 11, 0, NULL),
	(260, 1, 14, 0, NULL),
	(260, 2, 2, 0, NULL),
	(260, 2, 4, 0, NULL),
	(260, 2, 14, 0, NULL),
	(260, 14, 6, 0, NULL),
	(260, 14, 7, 0, NULL),
	(260, 19, 2, 0, NULL),
	(260, 19, 4, 0, NULL),
	(260, 19, 14, 0, NULL),
	(260, 22, 2, 0, NULL),
	(260, 22, 4, 0, NULL),
	(260, 22, 14, 0, NULL),
	(261, 1, 2, 0, NULL),
	(261, 1, 4, 0, NULL),
	(261, 1, 6, 0, NULL),
	(261, 1, 7, 0, NULL),
	(261, 1, 11, 0, NULL),
	(261, 1, 14, 0, NULL),
	(261, 2, 2, 0, NULL),
	(261, 2, 4, 0, NULL),
	(261, 2, 14, 0, NULL),
	(261, 14, 6, 0, NULL),
	(261, 14, 7, 0, NULL),
	(261, 19, 2, 0, NULL),
	(261, 19, 4, 0, NULL),
	(261, 19, 14, 0, NULL),
	(261, 22, 2, 0, NULL),
	(261, 22, 4, 0, NULL),
	(261, 22, 14, 0, NULL),
	(262, 1, 2, 0, NULL),
	(262, 1, 4, 0, NULL),
	(262, 1, 6, 0, NULL),
	(262, 1, 7, 0, NULL),
	(262, 1, 11, 0, NULL),
	(262, 1, 14, 0, NULL),
	(262, 2, 2, 0, NULL),
	(262, 2, 4, 0, NULL),
	(262, 2, 14, 0, NULL),
	(262, 14, 6, 0, NULL),
	(262, 14, 7, 0, NULL),
	(262, 19, 2, 0, NULL),
	(262, 19, 4, 0, NULL),
	(262, 19, 14, 0, NULL),
	(262, 22, 2, 0, NULL),
	(262, 22, 4, 0, NULL),
	(262, 22, 14, 0, NULL),
	(263, 1, 2, 0, NULL),
	(263, 1, 4, 0, NULL),
	(263, 1, 6, 0, NULL),
	(263, 1, 7, 0, NULL),
	(263, 1, 11, 0, NULL),
	(263, 1, 14, 0, NULL),
	(263, 2, 2, 0, NULL),
	(263, 2, 4, 0, NULL),
	(263, 2, 14, 0, NULL),
	(263, 14, 6, 0, NULL),
	(263, 14, 7, 0, NULL),
	(263, 19, 2, 0, NULL),
	(263, 19, 4, 0, NULL),
	(263, 19, 14, 0, NULL),
	(263, 22, 2, 0, NULL),
	(263, 22, 4, 0, NULL),
	(263, 22, 14, 0, NULL),
	(264, 1, 2, 0, NULL),
	(264, 1, 4, 0, NULL),
	(264, 1, 6, 0, NULL),
	(264, 1, 7, 0, NULL),
	(264, 1, 11, 0, NULL),
	(264, 1, 14, 0, NULL),
	(264, 2, 2, 0, NULL),
	(264, 2, 4, 0, NULL),
	(264, 2, 14, 0, NULL),
	(264, 14, 6, 0, NULL),
	(264, 14, 7, 0, NULL),
	(264, 19, 2, 0, NULL),
	(264, 19, 4, 0, NULL),
	(264, 19, 14, 0, NULL),
	(264, 22, 2, 0, NULL),
	(264, 22, 4, 0, NULL),
	(264, 22, 14, 0, NULL),
	(265, 1, 2, 0, NULL),
	(265, 1, 4, 0, NULL),
	(265, 1, 6, 0, NULL),
	(265, 1, 7, 0, NULL),
	(265, 1, 11, 0, NULL),
	(265, 1, 14, 0, NULL),
	(265, 2, 2, 0, NULL),
	(265, 2, 4, 0, NULL),
	(265, 2, 14, 0, NULL),
	(265, 14, 6, 0, NULL),
	(265, 14, 7, 0, NULL),
	(265, 19, 2, 0, NULL),
	(265, 19, 4, 0, NULL),
	(265, 19, 14, 0, NULL),
	(265, 22, 2, 0, NULL),
	(265, 22, 4, 0, NULL),
	(265, 22, 14, 0, NULL),
	(266, 1, 2, 0, NULL),
	(266, 1, 4, 0, NULL),
	(266, 1, 6, 0, NULL),
	(266, 1, 7, 0, NULL),
	(266, 1, 11, 0, NULL),
	(266, 1, 14, 0, NULL),
	(266, 2, 2, 0, NULL),
	(266, 2, 4, 0, NULL),
	(266, 2, 14, 0, NULL),
	(266, 14, 6, 0, NULL),
	(266, 14, 7, 0, NULL),
	(266, 19, 2, 0, NULL),
	(266, 19, 4, 0, NULL),
	(266, 19, 14, 0, NULL),
	(266, 22, 2, 0, NULL),
	(266, 22, 4, 0, NULL),
	(266, 22, 14, 0, NULL),
	(267, 1, 2, 0, NULL),
	(267, 1, 4, 0, NULL),
	(267, 1, 6, 0, NULL),
	(267, 1, 7, 0, NULL),
	(267, 1, 11, 0, NULL),
	(267, 1, 14, 0, NULL),
	(267, 2, 2, 0, NULL),
	(267, 2, 4, 0, NULL),
	(267, 2, 14, 0, NULL),
	(267, 14, 6, 0, NULL),
	(267, 14, 7, 0, NULL),
	(267, 19, 2, 0, NULL),
	(267, 19, 4, 0, NULL),
	(267, 19, 14, 0, NULL),
	(267, 22, 2, 0, NULL),
	(267, 22, 4, 0, NULL),
	(267, 22, 14, 0, NULL),
	(268, 1, 2, 0, NULL),
	(268, 1, 4, 0, NULL),
	(268, 1, 6, 0, NULL),
	(268, 1, 7, 0, NULL),
	(268, 1, 11, 0, NULL),
	(268, 1, 14, 0, NULL),
	(268, 2, 2, 0, NULL),
	(268, 2, 4, 0, NULL),
	(268, 2, 14, 0, NULL),
	(268, 14, 6, 0, NULL),
	(268, 14, 7, 0, NULL),
	(268, 19, 2, 0, NULL),
	(268, 19, 4, 0, NULL),
	(268, 19, 14, 0, NULL),
	(268, 22, 2, 0, NULL),
	(268, 22, 4, 0, NULL),
	(268, 22, 14, 0, NULL),
	(269, 1, 2, 0, NULL),
	(269, 1, 4, 0, NULL),
	(269, 1, 6, 0, NULL),
	(269, 1, 7, 0, NULL),
	(269, 1, 11, 0, NULL),
	(269, 1, 14, 0, NULL),
	(269, 2, 2, 0, NULL),
	(269, 2, 4, 0, NULL),
	(269, 2, 14, 0, NULL),
	(269, 14, 6, 0, NULL),
	(269, 14, 7, 0, NULL),
	(269, 19, 2, 0, NULL),
	(269, 19, 4, 0, NULL),
	(269, 19, 14, 0, NULL),
	(269, 22, 2, 0, NULL),
	(269, 22, 4, 0, NULL),
	(269, 22, 14, 0, NULL),
	(270, 1, 2, 0, NULL),
	(270, 1, 4, 0, NULL),
	(270, 1, 6, 0, NULL),
	(270, 1, 7, 0, NULL),
	(270, 1, 11, 0, NULL),
	(270, 1, 14, 0, NULL),
	(270, 2, 2, 0, NULL),
	(270, 2, 4, 0, NULL),
	(270, 2, 14, 0, NULL),
	(270, 14, 6, 0, NULL),
	(270, 14, 7, 0, NULL),
	(270, 19, 2, 0, NULL),
	(270, 19, 4, 0, NULL),
	(270, 19, 14, 0, NULL),
	(270, 22, 2, 0, NULL),
	(270, 22, 4, 0, NULL),
	(270, 22, 14, 0, NULL),
	(271, 1, 2, 0, NULL),
	(271, 1, 4, 0, NULL),
	(271, 1, 6, 0, NULL),
	(271, 1, 7, 0, NULL),
	(271, 1, 11, 0, NULL),
	(271, 1, 14, 0, NULL),
	(271, 2, 2, 0, NULL),
	(271, 2, 4, 0, NULL),
	(271, 2, 14, 0, NULL),
	(271, 14, 6, 0, NULL),
	(271, 14, 7, 0, NULL),
	(271, 19, 2, 0, NULL),
	(271, 19, 4, 0, NULL),
	(271, 19, 14, 0, NULL),
	(271, 22, 2, 0, NULL),
	(271, 22, 4, 0, NULL),
	(271, 22, 14, 0, NULL),
	(272, 1, 2, 0, NULL),
	(272, 1, 4, 0, NULL),
	(272, 1, 6, 0, NULL),
	(272, 1, 7, 0, NULL),
	(272, 1, 11, 0, NULL),
	(272, 1, 14, 0, NULL),
	(272, 2, 2, 0, NULL),
	(272, 2, 4, 0, NULL),
	(272, 2, 14, 0, NULL),
	(272, 14, 6, 0, NULL),
	(272, 14, 7, 0, NULL),
	(272, 19, 2, 0, NULL),
	(272, 19, 4, 0, NULL),
	(272, 19, 14, 0, NULL),
	(272, 22, 2, 0, NULL),
	(272, 22, 4, 0, NULL),
	(272, 22, 14, 0, NULL),
	(273, 1, 2, 0, NULL),
	(273, 1, 4, 0, NULL),
	(273, 1, 6, 0, NULL),
	(273, 1, 7, 0, NULL),
	(273, 1, 11, 0, NULL),
	(273, 1, 14, 0, NULL),
	(273, 2, 2, 0, NULL),
	(273, 2, 4, 0, NULL),
	(273, 2, 14, 0, NULL),
	(273, 14, 6, 0, NULL),
	(273, 14, 7, 0, NULL),
	(273, 19, 2, 0, NULL),
	(273, 19, 4, 0, NULL),
	(273, 19, 14, 0, NULL),
	(273, 22, 2, 0, NULL),
	(273, 22, 4, 0, NULL),
	(273, 22, 14, 0, NULL),
	(274, 1, 2, 0, NULL),
	(274, 1, 4, 0, NULL),
	(274, 1, 6, 0, NULL),
	(274, 1, 7, 0, NULL),
	(274, 1, 11, 0, NULL),
	(274, 1, 14, 0, NULL),
	(274, 2, 2, 0, NULL),
	(274, 2, 4, 0, NULL),
	(274, 2, 14, 0, NULL),
	(274, 14, 6, 0, NULL),
	(274, 14, 7, 0, NULL),
	(274, 19, 2, 0, NULL),
	(274, 19, 4, 0, NULL),
	(274, 19, 14, 0, NULL),
	(274, 22, 2, 0, NULL),
	(274, 22, 4, 0, NULL),
	(274, 22, 14, 0, NULL),
	(275, 1, 2, 0, NULL),
	(275, 1, 4, 0, NULL),
	(275, 1, 6, 0, NULL),
	(275, 1, 7, 0, NULL),
	(275, 1, 11, 0, NULL),
	(275, 1, 14, 0, NULL),
	(275, 2, 2, 0, NULL),
	(275, 2, 4, 0, NULL),
	(275, 2, 14, 0, NULL),
	(275, 14, 6, 0, NULL),
	(275, 14, 7, 0, NULL),
	(275, 19, 2, 0, NULL),
	(275, 19, 4, 0, NULL),
	(275, 19, 14, 0, NULL),
	(275, 22, 2, 0, NULL),
	(275, 22, 4, 0, NULL),
	(275, 22, 14, 0, NULL),
	(276, 1, 2, 0, NULL),
	(276, 1, 4, 0, NULL),
	(276, 1, 6, 0, NULL),
	(276, 1, 7, 0, NULL),
	(276, 1, 11, 0, NULL),
	(276, 1, 14, 0, NULL),
	(276, 2, 2, 0, NULL),
	(276, 2, 4, 0, NULL),
	(276, 2, 14, 0, NULL),
	(276, 14, 6, 0, NULL),
	(276, 14, 7, 0, NULL),
	(276, 19, 2, 0, NULL),
	(276, 19, 4, 0, NULL),
	(276, 19, 14, 0, NULL),
	(276, 22, 2, 0, NULL),
	(276, 22, 4, 0, NULL),
	(276, 22, 14, 0, NULL),
	(277, 1, 2, 0, NULL),
	(277, 1, 4, 0, NULL),
	(277, 1, 6, 0, NULL),
	(277, 1, 7, 0, NULL),
	(277, 1, 11, 0, NULL),
	(277, 1, 14, 0, NULL),
	(277, 2, 2, 0, NULL),
	(277, 2, 4, 0, NULL),
	(277, 2, 14, 0, NULL),
	(277, 14, 6, 0, NULL),
	(277, 14, 7, 0, NULL),
	(277, 19, 2, 0, NULL),
	(277, 19, 4, 0, NULL),
	(277, 19, 14, 0, NULL),
	(277, 22, 2, 0, NULL),
	(277, 22, 4, 0, NULL),
	(277, 22, 14, 0, NULL),
	(278, 1, 2, 0, NULL),
	(278, 1, 4, 0, NULL),
	(278, 1, 6, 0, NULL),
	(278, 1, 7, 0, NULL),
	(278, 1, 11, 0, NULL),
	(278, 1, 14, 0, NULL),
	(278, 2, 2, 0, NULL),
	(278, 2, 4, 0, NULL),
	(278, 2, 14, 0, NULL),
	(278, 14, 6, 0, NULL),
	(278, 14, 7, 0, NULL),
	(278, 19, 2, 0, NULL),
	(278, 19, 4, 0, NULL),
	(278, 19, 14, 0, NULL),
	(278, 22, 2, 0, NULL),
	(278, 22, 4, 0, NULL),
	(278, 22, 14, 0, NULL),
	(279, 1, 2, 0, NULL),
	(279, 1, 4, 0, NULL),
	(279, 1, 6, 0, NULL),
	(279, 1, 7, 0, NULL),
	(279, 1, 11, 0, NULL),
	(279, 1, 14, 0, NULL),
	(279, 2, 2, 0, NULL),
	(279, 2, 4, 0, NULL),
	(279, 2, 14, 0, NULL),
	(279, 14, 6, 0, NULL),
	(279, 14, 7, 0, NULL),
	(279, 19, 2, 0, NULL),
	(279, 19, 4, 0, NULL),
	(279, 19, 14, 0, NULL),
	(279, 22, 2, 0, NULL),
	(279, 22, 4, 0, NULL),
	(279, 22, 14, 0, NULL),
	(280, 1, 2, 0, NULL),
	(280, 1, 4, 0, NULL),
	(280, 1, 6, 0, NULL),
	(280, 1, 7, 0, NULL),
	(280, 1, 11, 0, NULL),
	(280, 1, 14, 0, NULL),
	(280, 2, 2, 0, NULL),
	(280, 2, 4, 0, NULL),
	(280, 2, 14, 0, NULL),
	(280, 14, 6, 0, NULL),
	(280, 14, 7, 0, NULL),
	(280, 19, 2, 0, NULL),
	(280, 19, 4, 0, NULL),
	(280, 19, 14, 0, NULL),
	(280, 22, 2, 0, NULL),
	(280, 22, 4, 0, NULL),
	(280, 22, 14, 0, NULL),
	(281, 1, 2, 0, NULL),
	(281, 1, 4, 0, NULL),
	(281, 1, 6, 0, NULL),
	(281, 1, 7, 0, NULL),
	(281, 1, 11, 0, NULL),
	(281, 1, 14, 0, NULL),
	(281, 2, 2, 0, NULL),
	(281, 2, 4, 0, NULL),
	(281, 2, 14, 0, NULL),
	(281, 14, 6, 0, NULL),
	(281, 14, 7, 0, NULL),
	(281, 19, 2, 0, NULL),
	(281, 19, 4, 0, NULL),
	(281, 19, 14, 0, NULL),
	(281, 22, 2, 0, NULL),
	(281, 22, 4, 0, NULL),
	(281, 22, 14, 0, NULL),
	(282, 1, 2, 0, NULL),
	(282, 1, 4, 0, NULL),
	(282, 1, 6, 0, NULL),
	(282, 1, 7, 0, NULL),
	(282, 1, 11, 0, NULL),
	(282, 1, 14, 0, NULL),
	(282, 2, 2, 0, NULL),
	(282, 2, 4, 0, NULL),
	(282, 2, 11, 0, NULL),
	(282, 2, 14, 0, NULL),
	(283, 1, 2, 0, NULL),
	(283, 1, 4, 0, NULL),
	(283, 1, 6, 1, NULL),
	(283, 1, 7, 1, NULL),
	(283, 1, 11, 0, NULL),
	(283, 1, 14, 0, NULL),
	(283, 2, 2, 0, NULL),
	(283, 2, 4, 0, NULL),
	(283, 2, 14, 0, NULL),
	(283, 16, 2, 0, NULL),
	(283, 16, 4, 0, NULL),
	(283, 16, 14, 0, NULL),
	(283, 19, 2, 0, NULL),
	(283, 19, 4, 0, NULL),
	(283, 19, 14, 0, NULL),
	(283, 22, 2, 0, NULL),
	(283, 22, 4, 0, NULL),
	(283, 22, 14, 0, NULL),
	(283, 10010, 2, 0, NULL),
	(283, 10010, 4, 0, NULL),
	(283, 10010, 14, 0, NULL),
	(284, 1, 2, 0, NULL),
	(284, 1, 4, 0, NULL),
	(284, 1, 6, 0, NULL),
	(284, 1, 7, 0, NULL),
	(284, 1, 11, 0, NULL),
	(284, 1, 14, 0, NULL),
	(284, 16, 2, 0, NULL),
	(284, 16, 4, 0, NULL),
	(284, 16, 14, 0, NULL),
	(284, 22, 2, 0, NULL),
	(284, 22, 4, 0, NULL),
	(284, 22, 14, 0, NULL),
	(285, 16, 4, 0, NULL),
	(285, 16, 14, 0, NULL),
	(285, 19, 2, 0, NULL),
	(285, 19, 4, 0, NULL),
	(285, 19, 14, 0, NULL),
	(287, 1, 2, 0, NULL),
	(287, 1, 4, 0, NULL),
	(287, 1, 6, 0, NULL),
	(287, 1, 7, 0, NULL),
	(287, 1, 11, 0, NULL),
	(287, 1, 14, 0, NULL),
	(287, 16, 4, 0, NULL),
	(287, 16, 14, 0, NULL),
	(288, 1, 2, 0, NULL),
	(288, 1, 4, 0, NULL),
	(288, 1, 6, 1, NULL),
	(288, 1, 7, 1, NULL),
	(288, 1, 11, 0, NULL),
	(288, 1, 14, 0, NULL),
	(288, 2, 2, 0, NULL),
	(288, 2, 4, 0, NULL),
	(288, 2, 14, 0, NULL),
	(288, 16, 2, 0, NULL),
	(288, 16, 4, 0, NULL),
	(288, 16, 14, 0, NULL),
	(288, 19, 2, 0, NULL),
	(288, 19, 4, 0, NULL),
	(288, 19, 14, 0, NULL),
	(288, 22, 2, 0, NULL),
	(288, 22, 4, 0, NULL),
	(288, 22, 14, 0, NULL),
	(288, 10010, 2, 0, NULL),
	(288, 10010, 4, 0, NULL),
	(288, 10010, 14, 0, NULL),
	(290, 1, 2, 0, NULL),
	(290, 1, 4, 0, NULL),
	(290, 1, 11, 0, NULL),
	(290, 1, 14, 0, NULL),
	(290, 14, 6, 0, 'Koregavimas galimas tik +-1800 sek. intervale.'),
	(290, 14, 7, 0, 'Koregavimas galimas tik +-1800 sek. intervale.'),
	(290, 16, 2, 0, NULL),
	(290, 16, 4, 0, NULL),
	(290, 16, 14, 0, NULL),
	(291, 16, 4, 0, NULL),
	(291, 16, 14, 0, NULL),
	(292, 1, 2, 1, NULL),
	(292, 1, 4, 1, NULL),
	(292, 1, 6, 1, NULL),
	(292, 1, 7, 1, NULL),
	(292, 1, 11, 1, NULL),
	(292, 1, 14, 1, NULL),
	(292, 2, 2, 0, NULL),
	(292, 2, 4, 0, NULL),
	(292, 2, 14, 0, NULL),
	(292, 16, 2, 0, NULL),
	(292, 16, 4, 0, NULL),
	(292, 16, 14, 0, NULL),
	(292, 19, 2, 0, NULL),
	(292, 19, 4, 0, NULL),
	(292, 19, 14, 0, NULL),
	(292, 22, 2, 0, NULL),
	(292, 22, 4, 0, NULL),
	(292, 22, 14, 0, NULL),
	(292, 10010, 2, 0, NULL),
	(292, 10010, 4, 0, NULL),
	(292, 10010, 6, 0, NULL),
	(292, 10010, 7, 0, NULL),
	(292, 10010, 14, 0, NULL),
	(292, 10010, 16, 0, NULL),
	(292, 10010, 17, 0, NULL),
	(292, 10011, 2, 0, NULL),
	(292, 10011, 4, 0, NULL),
	(292, 10011, 6, 0, NULL),
	(292, 10011, 7, 0, NULL),
	(292, 10011, 14, 0, NULL),
	(292, 10011, 16, 0, NULL),
	(292, 10011, 17, 0, NULL),
	(292, 10951, 2, 0, NULL),
	(292, 10951, 4, 0, NULL),
	(292, 10951, 6, 0, NULL),
	(292, 10951, 7, 0, NULL),
	(292, 10951, 14, 0, NULL),
	(292, 10951, 16, 0, NULL),
	(292, 10951, 17, 0, NULL),
	(292, 11293, 2, 0, NULL),
	(292, 11293, 4, 0, NULL),
	(292, 11293, 6, 0, NULL),
	(292, 11293, 7, 0, NULL),
	(292, 11293, 14, 0, NULL),
	(292, 11293, 16, 0, NULL),
	(292, 11293, 17, 0, NULL),
	(292, 11294, 2, 0, NULL),
	(292, 11294, 4, 0, NULL),
	(292, 11294, 6, 0, NULL),
	(292, 11294, 7, 0, NULL),
	(292, 11294, 14, 0, NULL),
	(292, 11294, 16, 0, NULL),
	(292, 11294, 17, 0, NULL),
	(293, 1, 2, 0, NULL),
	(293, 1, 4, 0, NULL),
	(293, 1, 6, 0, NULL),
	(293, 1, 7, 0, NULL),
	(293, 1, 11, 0, NULL),
	(293, 1, 14, 0, NULL),
	(293, 2, 2, 0, NULL),
	(293, 2, 4, 0, NULL),
	(293, 2, 14, 0, NULL),
	(294, 1, 2, 0, NULL),
	(294, 1, 4, 0, NULL),
	(294, 1, 6, 0, NULL),
	(294, 1, 7, 0, NULL),
	(294, 1, 11, 0, NULL),
	(294, 1, 14, 0, NULL),
	(294, 2, 2, 0, NULL),
	(294, 2, 4, 0, NULL),
	(294, 2, 14, 0, NULL),
	(294, 19, 2, 0, NULL),
	(294, 19, 4, 0, NULL),
	(294, 19, 14, 0, NULL),
	(294, 22, 2, 0, NULL),
	(294, 22, 4, 0, NULL),
	(294, 22, 14, 0, NULL),
	(296, 1, 2, 1, NULL),
	(296, 1, 4, 1, NULL),
	(296, 1, 14, 1, NULL),
	(296, 2, 2, 0, NULL),
	(296, 2, 4, 0, NULL),
	(296, 2, 14, 0, NULL),
	(296, 16, 4, 0, NULL),
	(296, 16, 14, 0, NULL),
	(296, 19, 2, 0, NULL),
	(296, 19, 4, 0, NULL),
	(296, 19, 14, 0, NULL),
	(296, 22, 2, 0, NULL),
	(296, 22, 4, 0, NULL),
	(296, 22, 14, 0, NULL),
	(299, 1, 2, 0, NULL),
	(299, 1, 4, 0, NULL),
	(299, 1, 11, 0, NULL),
	(299, 1, 14, 0, NULL),
	(299, 2, 2, 0, NULL),
	(299, 2, 4, 0, NULL),
	(299, 2, 14, 0, NULL),
	(299, 14, 6, 0, NULL),
	(299, 14, 7, 0, NULL),
	(299, 16, 2, 0, NULL),
	(299, 16, 4, 0, NULL),
	(299, 16, 14, 0, NULL),
	(299, 19, 2, 0, NULL),
	(299, 19, 4, 0, NULL),
	(299, 19, 14, 0, NULL),
	(299, 22, 2, 0, NULL),
	(299, 22, 4, 0, NULL),
	(299, 22, 14, 0, NULL),
	(300, 1, 2, 0, NULL),
	(300, 1, 4, 0, NULL),
	(300, 1, 11, 0, NULL),
	(300, 1, 14, 0, NULL),
	(303, 16, 2, 0, NULL),
	(303, 16, 4, 0, NULL),
	(303, 16, 14, 0, NULL),
	(306, 1, 2, 0, NULL),
	(306, 1, 4, 0, NULL),
	(306, 1, 6, 0, NULL),
	(306, 1, 7, 0, NULL),
	(306, 1, 11, 0, NULL),
	(306, 1, 14, 0, NULL),
	(306, 2, 2, 0, NULL),
	(306, 2, 4, 0, NULL),
	(306, 2, 14, 0, NULL),
	(306, 14, 6, 0, NULL),
	(306, 14, 7, 0, NULL),
	(306, 19, 2, 0, NULL),
	(306, 19, 4, 0, NULL),
	(306, 19, 14, 0, NULL),
	(306, 22, 2, 0, NULL),
	(306, 22, 4, 0, NULL),
	(306, 22, 14, 0, NULL),
	(306, 10010, 2, 0, NULL),
	(306, 10010, 4, 0, NULL),
	(306, 10010, 6, 0, NULL),
	(306, 10010, 7, 0, NULL),
	(306, 10010, 14, 0, NULL),
	(306, 10010, 16, 0, NULL),
	(306, 10010, 17, 0, NULL),
	(306, 10011, 2, 0, NULL),
	(306, 10011, 4, 0, NULL),
	(306, 10011, 6, 0, NULL),
	(306, 10011, 7, 0, NULL),
	(306, 10011, 14, 0, NULL),
	(306, 10011, 16, 0, NULL),
	(306, 10011, 17, 0, NULL),
	(307, 1, 2, 0, NULL),
	(307, 1, 4, 0, NULL),
	(307, 1, 6, 0, NULL),
	(307, 1, 7, 0, NULL),
	(307, 1, 11, 0, NULL),
	(307, 1, 14, 0, NULL),
	(307, 2, 2, 0, NULL),
	(307, 2, 4, 0, NULL),
	(307, 2, 14, 0, NULL),
	(307, 14, 6, 0, NULL),
	(307, 14, 7, 0, NULL),
	(307, 19, 2, 0, NULL),
	(307, 19, 4, 0, NULL),
	(307, 19, 14, 0, NULL),
	(307, 22, 2, 0, NULL),
	(307, 22, 4, 0, NULL),
	(307, 22, 14, 0, NULL),
	(308, 1, 2, 0, NULL),
	(308, 1, 4, 0, NULL),
	(308, 1, 6, 0, NULL),
	(308, 1, 7, 0, NULL),
	(308, 1, 11, 0, NULL),
	(308, 1, 14, 0, NULL),
	(308, 2, 2, 0, NULL),
	(308, 2, 4, 0, NULL),
	(308, 2, 14, 0, NULL),
	(308, 14, 6, 0, NULL),
	(308, 14, 7, 0, NULL),
	(308, 19, 2, 0, NULL),
	(308, 19, 4, 0, NULL),
	(308, 19, 14, 0, NULL),
	(308, 22, 2, 0, NULL),
	(308, 22, 4, 0, NULL),
	(308, 22, 14, 0, NULL),
	(337, 1, 2, 0, NULL),
	(337, 1, 4, 0, NULL),
	(337, 1, 11, 0, NULL),
	(337, 1, 14, 0, NULL),
	(337, 16, 2, 0, NULL),
	(337, 16, 4, 0, NULL),
	(337, 16, 14, 0, NULL),
	(338, 1, 2, 0, NULL),
	(338, 1, 4, 0, NULL),
	(338, 1, 14, 0, NULL),
	(338, 16, 2, 0, NULL),
	(338, 16, 4, 0, NULL),
	(338, 16, 14, 0, NULL),
	(340, 1, 2, 0, NULL),
	(340, 1, 4, 0, NULL),
	(340, 1, 11, 0, NULL),
	(340, 1, 14, 0, NULL),
	(341, 1, 2, 0, NULL),
	(341, 1, 4, 0, NULL),
	(341, 1, 11, 0, NULL),
	(341, 1, 14, 0, NULL),
	(342, 1, 2, 0, NULL),
	(342, 1, 4, 0, NULL),
	(342, 1, 11, 0, NULL),
	(342, 1, 14, 0, NULL),
	(342, 2, 2, 0, NULL),
	(342, 2, 4, 0, NULL),
	(342, 2, 14, 0, NULL),
	(342, 19, 2, 0, NULL),
	(342, 19, 4, 0, NULL),
	(342, 19, 14, 0, NULL),
	(342, 22, 2, 0, NULL),
	(342, 22, 4, 0, NULL),
	(342, 22, 14, 0, NULL),
	(344, 1, 2, 0, NULL),
	(344, 1, 4, 0, NULL),
	(344, 1, 11, 0, NULL),
	(344, 1, 14, 0, NULL),
	(344, 2, 2, 0, NULL),
	(344, 2, 4, 0, NULL),
	(344, 2, 14, 0, NULL),
	(346, 1, 2, 0, NULL),
	(346, 1, 4, 0, NULL),
	(346, 1, 11, 0, NULL),
	(346, 1, 14, 0, NULL),
	(346, 2, 2, 0, NULL),
	(346, 2, 4, 0, NULL),
	(346, 2, 14, 0, NULL),
	(346, 22, 2, 0, NULL),
	(346, 22, 4, 0, NULL),
	(346, 22, 14, 0, NULL),
	(346, 10010, 2, 0, NULL),
	(346, 10010, 4, 0, NULL),
	(346, 10010, 6, 0, NULL),
	(346, 10010, 7, 0, NULL),
	(346, 10010, 14, 0, NULL),
	(346, 10010, 16, 0, NULL),
	(346, 10010, 17, 0, NULL),
	(348, 1, 2, 0, NULL),
	(348, 1, 4, 0, NULL),
	(348, 1, 14, 0, NULL),
	(348, 14, 6, 0, NULL),
	(348, 14, 7, 0, NULL),
	(348, 16, 2, 0, NULL),
	(348, 16, 4, 0, NULL),
	(348, 16, 14, 0, NULL),
	(348, 19, 2, 0, NULL),
	(348, 19, 4, 0, NULL),
	(348, 19, 14, 0, NULL),
	(349, 1, 2, 0, NULL),
	(349, 1, 4, 0, NULL),
	(349, 1, 14, 0, NULL),
	(349, 2, 2, 0, NULL),
	(349, 2, 4, 0, NULL),
	(349, 2, 14, 0, NULL),
	(349, 14, 6, 0, NULL),
	(349, 14, 7, 0, NULL),
	(349, 16, 2, 0, NULL),
	(349, 16, 4, 0, NULL),
	(349, 16, 14, 0, NULL),
	(349, 19, 2, 0, NULL),
	(349, 19, 4, 0, NULL),
	(349, 19, 14, 0, NULL),
	(349, 22, 2, 0, NULL),
	(349, 22, 4, 0, NULL),
	(349, 22, 14, 0, NULL),
	(352, 1, 2, 0, NULL),
	(352, 1, 4, 0, NULL),
	(352, 1, 11, 0, NULL),
	(352, 1, 14, 0, NULL),
	(352, 16, 4, 0, NULL),
	(352, 16, 14, 0, NULL),
	(353, 1, 2, 1, NULL),
	(353, 1, 4, 1, NULL),
	(353, 1, 6, 1, NULL),
	(353, 1, 7, 1, NULL),
	(353, 1, 11, 1, NULL),
	(353, 1, 14, 1, NULL),
	(353, 2, 2, 0, NULL),
	(353, 2, 4, 0, NULL),
	(353, 2, 14, 0, NULL),
	(353, 16, 2, 0, NULL),
	(353, 16, 4, 0, NULL),
	(353, 16, 14, 0, NULL),
	(353, 22, 2, 0, NULL),
	(353, 22, 4, 0, NULL),
	(353, 22, 14, 0, NULL),
	(353, 10010, 2, 0, NULL),
	(353, 10010, 4, 0, NULL),
	(353, 10010, 6, 0, NULL),
	(353, 10010, 7, 0, NULL),
	(353, 10010, 14, 0, NULL),
	(353, 10010, 16, 0, NULL),
	(353, 10010, 17, 0, NULL),
	(354, 1, 2, 0, NULL),
	(354, 1, 4, 0, NULL),
	(354, 1, 11, 0, NULL),
	(354, 1, 14, 0, NULL),
	(356, 1, 2, 1, NULL),
	(356, 1, 4, 1, NULL),
	(356, 1, 11, 1, NULL),
	(356, 1, 14, 1, NULL),
	(356, 2, 2, 0, NULL),
	(356, 2, 4, 0, NULL),
	(356, 2, 14, 0, NULL),
	(356, 19, 2, 0, NULL),
	(356, 19, 4, 0, NULL),
	(356, 19, 14, 0, NULL),
	(356, 22, 2, 0, NULL),
	(356, 22, 4, 0, NULL),
	(356, 22, 14, 0, NULL),
	(357, 1, 2, 0, NULL),
	(357, 1, 4, 0, NULL),
	(357, 1, 6, 1, 'Jeigu pradinis vartotojas ir slaptažodis pirmo lygmens, draiveris prieš nustatydamas laiką, persijungia į antro lygmens vartotoja, naudojant Password2.'),
	(357, 1, 7, 1, 'Jeigu pradinis vartotojas ir slaptažodis pirmo lygmens, draiveris prieš nustatydamas laiką, persijungia į antro lygmens vartotoja, naudojant Password2.'),
	(357, 1, 11, 0, NULL),
	(357, 1, 14, 0, NULL),
	(357, 14, 6, 1, 'Prietaisas priima korekciją iki 240sek. Vieną kartą per parą.'),
	(357, 14, 7, 1, 'Prietaisas priima korekciją iki 240sek. Vieną kartą per parą.'),
	(357, 16, 2, 0, NULL),
	(357, 16, 4, 0, NULL),
	(357, 16, 14, 0, NULL),
	(357, 10010, 2, 0, NULL),
	(357, 10010, 4, 0, NULL),
	(357, 10010, 6, 0, NULL),
	(357, 10010, 7, 0, NULL),
	(357, 10010, 14, 0, NULL),
	(357, 10010, 16, 0, NULL),
	(357, 10010, 17, 0, NULL),
	(358, 1, 2, 0, NULL),
	(358, 1, 4, 0, NULL),
	(358, 1, 6, 1, 'Jeigu pradinis vartotojas ir slaptažodis pirmo lygmens, draiveris prieš nustatydamas laiką, persijungia į antro lygmens vartotoja, naudojant Password2.'),
	(358, 1, 7, 1, 'Jeigu pradinis vartotojas ir slaptažodis pirmo lygmens, draiveris prieš nustatydamas laiką, persijungia į antro lygmens vartotoja, naudojant Password2.'),
	(358, 1, 11, 0, NULL),
	(358, 1, 14, 0, NULL),
	(358, 14, 6, 1, 'Prietaisas priima korekciją iki 240sek. Vieną kartą per parą.'),
	(358, 14, 7, 1, 'Prietaisas priima korekciją iki 240sek. Vieną kartą per parą.'),
	(358, 16, 2, 0, NULL),
	(358, 16, 4, 0, NULL),
	(358, 16, 14, 0, NULL),
	(358, 10010, 2, 0, NULL),
	(358, 10010, 4, 0, NULL),
	(358, 10010, 6, 0, NULL),
	(358, 10010, 7, 0, NULL),
	(358, 10010, 14, 0, NULL),
	(358, 10010, 16, 0, NULL),
	(358, 10010, 17, 0, NULL),
	(359, 1, 2, 0, NULL),
	(359, 1, 4, 0, NULL),
	(359, 1, 6, 1, 'Jeigu pradinis vartotojas ir slaptažodis pirmo lygmens, draiveris prieš nustatydamas laiką, persijungia į antro lygmens vartotoja, naudojant Password2.'),
	(359, 1, 7, 1, 'Jeigu pradinis vartotojas ir slaptažodis pirmo lygmens, draiveris prieš nustatydamas laiką, persijungia į antro lygmens vartotoja, naudojant Password2.'),
	(359, 1, 11, 0, NULL),
	(359, 1, 14, 0, NULL),
	(359, 14, 6, 1, 'Prietaisas priima korekciją iki 240sek. Vieną kartą per parą.'),
	(359, 14, 7, 1, 'Prietaisas priima korekciją iki 240sek. Vieną kartą per parą.'),
	(359, 16, 2, 0, NULL),
	(359, 16, 4, 0, NULL),
	(359, 16, 14, 0, NULL),
	(359, 10010, 2, 0, NULL),
	(359, 10010, 4, 0, NULL),
	(359, 10010, 6, 0, NULL),
	(359, 10010, 7, 0, NULL),
	(359, 10010, 14, 0, NULL),
	(359, 10010, 16, 0, NULL),
	(359, 10010, 17, 0, NULL),
	(360, 1, 2, 0, NULL),
	(360, 1, 4, 0, NULL),
	(360, 1, 6, 1, 'Jeigu pradinis vartotojas ir slaptažodis pirmo lygmens, draiveris prieš nustatydamas laiką, persijungia į antro lygmens vartotoja, naudojant Password2.'),
	(360, 1, 7, 1, 'Jeigu pradinis vartotojas ir slaptažodis pirmo lygmens, draiveris prieš nustatydamas laiką, persijungia į antro lygmens vartotoja, naudojant Password2.'),
	(360, 1, 11, 0, NULL),
	(360, 1, 14, 0, NULL),
	(360, 14, 6, 1, 'Prietaisas priima korekciją iki 240sek. Vieną kartą per parą.'),
	(360, 14, 7, 1, 'Prietaisas priima korekciją iki 240sek. Vieną kartą per parą.'),
	(360, 16, 2, 0, NULL),
	(360, 16, 4, 0, NULL),
	(360, 16, 14, 0, NULL),
	(360, 10010, 2, 0, NULL),
	(360, 10010, 4, 0, NULL),
	(360, 10010, 6, 0, NULL),
	(360, 10010, 7, 0, NULL),
	(360, 10010, 14, 0, NULL),
	(360, 10010, 16, 0, NULL),
	(360, 10010, 17, 0, NULL),
	(361, 1, 2, 0, NULL),
	(361, 1, 4, 0, NULL),
	(361, 1, 6, 1, 'Jeigu pradinis vartotojas ir slaptažodis pirmo lygmens, draiveris prieš nustatydamas laiką, persijungia į antro lygmens vartotoja, naudojant Password2.'),
	(361, 1, 7, 1, 'Jeigu pradinis vartotojas ir slaptažodis pirmo lygmens, draiveris prieš nustatydamas laiką, persijungia į antro lygmens vartotoja, naudojant Password2.'),
	(361, 1, 11, 0, NULL),
	(361, 1, 14, 0, NULL),
	(361, 14, 6, 1, 'Prietaisas priima korekciją iki 240sek. Vieną kartą per parą.'),
	(361, 14, 7, 1, 'Prietaisas priima korekciją iki 240sek. Vieną kartą per parą.'),
	(361, 16, 2, 0, NULL),
	(361, 16, 4, 0, NULL),
	(361, 16, 14, 0, NULL),
	(361, 10010, 2, 0, NULL),
	(361, 10010, 4, 0, NULL),
	(361, 10010, 6, 0, NULL),
	(361, 10010, 7, 0, NULL),
	(361, 10010, 14, 0, NULL),
	(361, 10010, 16, 0, NULL),
	(361, 10010, 17, 0, NULL),
	(362, 1, 2, 0, NULL),
	(362, 1, 4, 0, NULL),
	(362, 1, 6, 1, 'Jeigu pradinis vartotojas ir slaptažodis pirmo lygmens, draiveris prieš nustatydamas laiką, persijungia į antro lygmens vartotoja, naudojant Password2.'),
	(362, 1, 7, 1, 'Jeigu pradinis vartotojas ir slaptažodis pirmo lygmens, draiveris prieš nustatydamas laiką, persijungia į antro lygmens vartotoja, naudojant Password2.'),
	(362, 1, 11, 0, NULL),
	(362, 1, 14, 0, NULL),
	(362, 14, 6, 1, 'Prietaisas priima korekciją iki 240sek. Vieną kartą per parą.'),
	(362, 14, 7, 1, 'Prietaisas priima korekciją iki 240sek. Vieną kartą per parą.'),
	(362, 16, 2, 0, NULL),
	(362, 16, 4, 0, NULL),
	(362, 16, 14, 0, NULL),
	(362, 10010, 2, 0, NULL),
	(362, 10010, 4, 0, NULL),
	(362, 10010, 6, 0, NULL),
	(362, 10010, 7, 0, NULL),
	(362, 10010, 14, 0, NULL),
	(362, 10010, 16, 0, NULL),
	(362, 10010, 17, 0, NULL),
	(363, 1, 2, 0, NULL),
	(363, 1, 4, 0, NULL),
	(363, 1, 11, 0, NULL),
	(363, 1, 14, 0, NULL),
	(363, 2, 2, 0, NULL),
	(363, 2, 4, 0, NULL),
	(363, 2, 14, 0, NULL),
	(363, 19, 2, 0, NULL),
	(363, 19, 4, 0, NULL),
	(363, 19, 14, 0, NULL),
	(363, 22, 2, 0, NULL),
	(363, 22, 4, 0, NULL),
	(363, 22, 14, 0, NULL),
	(363, 10010, 2, 0, NULL),
	(363, 10010, 4, 0, NULL),
	(363, 10010, 6, 0, NULL),
	(363, 10010, 7, 0, NULL),
	(363, 10010, 14, 0, NULL),
	(363, 10010, 16, 0, NULL),
	(363, 10010, 17, 0, NULL),
	(365, 1, 2, 0, NULL),
	(365, 1, 4, 0, NULL),
	(365, 1, 11, 0, NULL),
	(365, 1, 14, 0, NULL),
	(366, 1, 2, 0, NULL),
	(366, 1, 4, 0, NULL),
	(366, 1, 11, 0, NULL),
	(366, 1, 14, 0, NULL),
	(367, 1, 2, 0, NULL),
	(367, 1, 4, 0, NULL),
	(367, 1, 11, 0, NULL),
	(367, 1, 14, 0, NULL),
	(367, 2, 2, 0, NULL),
	(367, 2, 4, 0, NULL),
	(367, 2, 14, 0, NULL),
	(367, 22, 2, 0, NULL),
	(367, 22, 4, 0, NULL),
	(367, 22, 14, 0, NULL),
	(367, 10010, 2, 0, NULL),
	(367, 10010, 4, 0, NULL),
	(367, 10010, 6, 0, NULL),
	(367, 10010, 7, 0, NULL),
	(367, 10010, 14, 0, NULL),
	(367, 10010, 16, 0, NULL),
	(367, 10010, 17, 0, NULL),
	(369, 1, 2, 1, NULL),
	(369, 1, 4, 1, NULL),
	(369, 1, 6, 1, NULL),
	(369, 1, 7, 1, NULL),
	(369, 1, 11, 1, NULL),
	(369, 1, 14, 1, NULL),
	(369, 2, 2, 0, NULL),
	(369, 2, 4, 0, NULL),
	(369, 2, 14, 0, NULL),
	(369, 16, 2, 0, NULL),
	(369, 16, 4, 0, NULL),
	(369, 16, 14, 0, NULL),
	(369, 19, 2, 0, NULL),
	(369, 19, 4, 0, NULL),
	(369, 19, 14, 0, NULL),
	(369, 22, 2, 0, NULL),
	(369, 22, 4, 0, NULL),
	(369, 22, 14, 0, NULL),
	(370, 1, 2, 0, NULL),
	(370, 1, 4, 0, NULL),
	(370, 1, 6, 0, NULL),
	(370, 1, 7, 0, NULL),
	(370, 1, 11, 0, NULL),
	(370, 1, 14, 0, NULL),
	(370, 2, 2, 0, NULL),
	(370, 2, 4, 0, NULL),
	(370, 2, 14, 0, NULL),
	(370, 14, 6, 0, NULL),
	(370, 14, 7, 0, NULL),
	(370, 16, 2, 0, NULL),
	(370, 16, 4, 0, NULL),
	(370, 16, 14, 0, NULL),
	(370, 22, 2, 0, NULL),
	(370, 22, 4, 0, NULL),
	(370, 22, 14, 0, NULL),
	(371, 1, 2, 0, NULL),
	(371, 1, 4, 0, NULL),
	(371, 1, 6, 0, NULL),
	(371, 1, 7, 0, NULL),
	(371, 1, 11, 0, NULL),
	(371, 1, 14, 0, NULL),
	(371, 2, 2, 0, NULL),
	(371, 2, 4, 0, NULL),
	(371, 2, 14, 0, NULL),
	(371, 14, 6, 0, NULL),
	(371, 14, 7, 0, NULL),
	(371, 16, 2, 0, NULL),
	(371, 16, 4, 0, NULL),
	(371, 16, 14, 0, NULL),
	(371, 22, 2, 0, NULL),
	(371, 22, 4, 0, NULL),
	(371, 22, 14, 0, NULL),
	(372, 1, 2, 0, NULL),
	(372, 1, 4, 0, NULL),
	(372, 1, 6, 0, NULL),
	(372, 1, 7, 0, NULL),
	(372, 1, 11, 0, NULL),
	(372, 1, 14, 0, NULL),
	(372, 2, 2, 0, NULL),
	(372, 2, 4, 0, NULL),
	(372, 2, 14, 0, NULL),
	(372, 14, 6, 0, NULL),
	(372, 14, 7, 0, NULL),
	(372, 16, 2, 0, NULL),
	(372, 16, 4, 0, NULL),
	(372, 16, 14, 0, NULL),
	(372, 22, 2, 0, NULL),
	(372, 22, 4, 0, NULL),
	(372, 22, 14, 0, NULL),
	(373, 1, 2, 0, NULL),
	(373, 1, 4, 0, NULL),
	(373, 1, 11, 0, NULL),
	(373, 1, 14, 0, NULL),
	(373, 16, 4, 0, NULL),
	(373, 16, 14, 0, NULL),
	(374, 1, 2, 0, NULL),
	(374, 1, 4, 0, NULL),
	(374, 1, 6, 0, NULL),
	(374, 1, 7, 0, NULL),
	(374, 1, 11, 0, NULL),
	(374, 1, 14, 0, NULL),
	(374, 2, 2, 0, NULL),
	(374, 2, 4, 0, NULL),
	(374, 2, 14, 0, NULL),
	(374, 14, 6, 0, NULL),
	(374, 14, 7, 0, NULL),
	(374, 19, 2, 0, NULL),
	(374, 19, 4, 0, NULL),
	(374, 19, 14, 0, NULL),
	(374, 22, 2, 0, NULL),
	(374, 22, 4, 0, NULL),
	(374, 22, 14, 0, NULL),
	(375, 1, 2, 0, NULL),
	(375, 1, 4, 0, NULL),
	(375, 1, 6, 0, NULL),
	(375, 1, 7, 0, NULL),
	(375, 1, 11, 0, NULL),
	(375, 1, 14, 0, NULL),
	(375, 2, 2, 0, NULL),
	(375, 2, 4, 0, NULL),
	(375, 2, 14, 0, NULL),
	(375, 14, 6, 0, NULL),
	(375, 14, 7, 0, NULL),
	(375, 19, 2, 0, NULL),
	(375, 19, 4, 0, NULL),
	(375, 19, 14, 0, NULL),
	(375, 22, 2, 0, NULL),
	(375, 22, 4, 0, NULL),
	(375, 22, 14, 0, NULL),
	(376, 1, 2, 0, NULL),
	(376, 1, 4, 0, NULL),
	(376, 1, 6, 0, NULL),
	(376, 1, 7, 0, NULL),
	(376, 1, 11, 0, NULL),
	(376, 1, 14, 0, NULL),
	(376, 2, 2, 0, NULL),
	(376, 2, 4, 0, NULL),
	(376, 2, 14, 0, NULL),
	(376, 14, 6, 0, NULL),
	(376, 14, 7, 0, NULL),
	(376, 19, 2, 0, NULL),
	(376, 19, 4, 0, NULL),
	(376, 19, 14, 0, NULL),
	(376, 22, 2, 0, NULL),
	(376, 22, 4, 0, NULL),
	(376, 22, 14, 0, NULL),
	(377, 1, 2, 0, NULL),
	(377, 1, 4, 0, NULL),
	(377, 1, 6, 0, NULL),
	(377, 1, 7, 0, NULL),
	(377, 1, 11, 0, NULL),
	(377, 1, 14, 0, NULL),
	(377, 2, 2, 0, NULL),
	(377, 2, 4, 0, NULL),
	(377, 2, 14, 0, NULL),
	(377, 14, 6, 0, NULL),
	(377, 14, 7, 0, NULL),
	(377, 16, 2, 0, NULL),
	(377, 16, 4, 0, NULL),
	(377, 16, 14, 0, NULL),
	(377, 19, 2, 0, NULL),
	(377, 19, 4, 0, NULL),
	(377, 19, 14, 0, NULL),
	(377, 22, 2, 0, NULL),
	(377, 22, 4, 0, NULL),
	(377, 22, 14, 0, NULL),
	(377, 10010, 2, 0, NULL),
	(377, 10010, 4, 0, NULL),
	(377, 10010, 6, 0, NULL),
	(377, 10010, 7, 0, NULL),
	(377, 10010, 14, 0, NULL),
	(377, 10010, 16, 0, NULL),
	(377, 10010, 17, 0, NULL),
	(377, 10011, 2, 0, NULL),
	(377, 10011, 4, 0, NULL),
	(377, 10011, 6, 0, NULL),
	(377, 10011, 7, 0, NULL),
	(377, 10011, 14, 0, NULL),
	(377, 10011, 16, 0, NULL),
	(377, 10011, 17, 0, NULL),
	(379, 16, 2, 0, NULL),
	(379, 16, 4, 0, NULL),
	(379, 16, 14, 0, NULL),
	(381, 1, 2, 0, NULL),
	(381, 1, 4, 0, NULL),
	(381, 1, 6, 0, NULL),
	(381, 1, 7, 1, NULL),
	(381, 1, 11, 0, NULL),
	(381, 1, 14, 0, NULL),
	(382, 1, 2, 1, NULL),
	(382, 1, 4, 1, NULL),
	(382, 1, 6, 1, NULL),
	(382, 1, 7, 1, NULL),
	(382, 1, 11, 1, NULL),
	(382, 1, 14, 1, NULL),
	(382, 2, 2, 0, NULL),
	(382, 2, 4, 0, NULL),
	(382, 2, 14, 0, NULL),
	(382, 14, 6, 1, 'Koregavimas galimas tik +-1 sek. intervale.'),
	(382, 14, 7, 1, 'Koregavimas galimas tik +-1 sek. intervale.'),
	(382, 16, 4, 0, NULL),
	(382, 16, 14, 0, NULL),
	(382, 19, 2, 0, NULL),
	(382, 19, 4, 0, NULL),
	(382, 19, 14, 0, NULL),
	(382, 22, 2, 0, NULL),
	(382, 22, 4, 0, NULL),
	(382, 22, 14, 0, NULL),
	(382, 10010, 2, 0, NULL),
	(382, 10010, 4, 0, NULL),
	(382, 10010, 14, 0, NULL),
	(382, 10011, 2, 0, NULL),
	(382, 10011, 4, 0, NULL),
	(382, 10011, 14, 0, NULL),
	(383, 16, 4, 0, NULL),
	(383, 16, 14, 0, NULL),
	(383, 19, 2, 0, NULL),
	(383, 19, 4, 0, NULL),
	(383, 19, 14, 0, NULL),
	(384, 1, 2, 0, NULL),
	(384, 1, 4, 0, NULL),
	(384, 1, 6, 0, NULL),
	(384, 1, 7, 0, NULL),
	(384, 1, 11, 0, NULL),
	(384, 1, 14, 0, NULL),
	(384, 16, 4, 0, NULL),
	(384, 16, 7, 0, NULL),
	(384, 16, 14, 0, NULL),
	(385, 1, 2, 0, NULL),
	(385, 1, 4, 0, NULL),
	(385, 1, 6, 0, NULL),
	(385, 1, 7, 1, NULL),
	(385, 1, 11, 0, NULL),
	(385, 1, 14, 0, NULL),
	(385, 2, 4, 0, NULL),
	(385, 2, 7, 0, NULL),
	(385, 2, 14, 0, NULL),
	(385, 16, 4, 0, NULL),
	(385, 16, 14, 0, NULL),
	(385, 22, 4, 0, NULL),
	(385, 22, 7, 0, NULL),
	(385, 22, 14, 0, NULL),
	(386, 1, 2, 0, NULL),
	(386, 1, 4, 0, NULL),
	(386, 1, 6, 0, NULL),
	(386, 1, 7, 1, NULL),
	(386, 1, 11, 0, NULL),
	(386, 1, 14, 0, NULL),
	(386, 2, 4, 0, NULL),
	(386, 2, 7, 0, NULL),
	(386, 2, 14, 0, NULL),
	(386, 16, 4, 0, NULL),
	(386, 16, 14, 0, NULL),
	(386, 22, 4, 0, NULL),
	(386, 22, 7, 0, NULL),
	(386, 22, 14, 0, NULL),
	(387, 1, 2, 0, NULL),
	(387, 1, 4, 0, NULL),
	(387, 1, 6, 0, NULL),
	(387, 1, 7, 1, NULL),
	(387, 1, 11, 0, NULL),
	(387, 1, 14, 0, NULL),
	(387, 2, 4, 0, NULL),
	(387, 2, 7, 0, NULL),
	(387, 2, 14, 0, NULL),
	(387, 16, 4, 0, NULL),
	(387, 16, 14, 0, NULL),
	(387, 22, 4, 0, NULL),
	(387, 22, 7, 0, NULL),
	(387, 22, 14, 0, NULL);
/*!40000 ALTER TABLE `src_type_sheaf_rc` ENABLE KEYS */;

-- Dumping structure for table emcor.src_type_withe
CREATE TABLE IF NOT EXISTS `src_type_withe` (
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `is_point` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `has_current_state` tinyint(1) DEFAULT NULL COMMENT 'Požymis ar atitinkamai duomenų vytelei galimas būsenos nuskaitymas',
  `has_journal` tinyint(1) DEFAULT NULL COMMENT 'Požymis ar atitinkamai duomenų vytelei galimas žurnalo nuskaitymas',
  PRIMARY KEY (`src_type_id`,`is_point`,`withe_id`),
  KEY `src_type_withe_withe_fk` (`withe_id`),
  CONSTRAINT `src_type_withe_src_type_fk` FOREIGN KEY (`src_type_id`) REFERENCES `src_type` (`src_type_id`) ON DELETE CASCADE,
  CONSTRAINT `src_type_withe_withe_fk` FOREIGN KEY (`withe_id`) REFERENCES `withe` (`withe_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Šaltinių tipų palaikomi įvykių žurnalų ir būsenų kodai';

-- Dumping data for table emcor.src_type_withe: ~6 317 rows (approximately)
/*!40000 ALTER TABLE `src_type_withe` DISABLE KEYS */;
INSERT INTO `src_type_withe` (`src_type_id`, `is_point`, `withe_id`, `has_current_state`, `has_journal`) VALUES
	(-4, 1, 10000, NULL, NULL),
	(-4, 1, 10001, NULL, NULL),
	(-4, 1, 10002, NULL, NULL),
	(-4, 1, 10014, NULL, NULL),
	(-4, 1, 10015, NULL, NULL),
	(-4, 1, 10029, NULL, NULL),
	(-4, 1, 10030, NULL, NULL),
	(-4, 1, 10031, NULL, NULL),
	(-4, 1, 10038, NULL, NULL),
	(-4, 1, 10043, NULL, NULL),
	(-4, 1, 10046, NULL, NULL),
	(-4, 1, 10047, NULL, NULL),
	(-4, 1, 10048, NULL, NULL),
	(-4, 1, 10049, NULL, NULL),
	(-4, 1, 10213, NULL, NULL),
	(-4, 1, 10243, NULL, NULL),
	(-4, 1, 10268, NULL, NULL),
	(-4, 1, 10272, NULL, NULL),
	(-4, 1, 10273, NULL, NULL),
	(-4, 1, 10432, NULL, NULL),
	(-4, 1, 10479, NULL, NULL),
	(-4, 1, 10548, NULL, NULL),
	(-4, 1, 10552, NULL, NULL),
	(-4, 1, 10553, NULL, NULL),
	(-4, 1, 10753, NULL, NULL),
	(-4, 1, 10800, NULL, NULL),
	(-4, 1, 10833, NULL, NULL),
	(-4, 1, 11220, NULL, NULL),
	(-4, 1, 11509, NULL, NULL),
	(-4, 1, 11510, NULL, NULL),
	(-4, 1, 11511, NULL, NULL),
	(-4, 1, 11512, NULL, NULL),
	(-4, 1, 11513, NULL, NULL),
	(-4, 1, 11514, NULL, NULL),
	(-4, 1, 11515, NULL, NULL),
	(-4, 1, 11516, NULL, NULL),
	(-4, 1, 11517, NULL, NULL),
	(-4, 1, 11518, NULL, NULL),
	(-4, 1, 11519, NULL, NULL),
	(-4, 1, 11520, NULL, NULL),
	(-4, 1, 11521, NULL, NULL),
	(-4, 1, 11522, NULL, NULL),
	(-4, 1, 11523, NULL, NULL),
	(-1, 1, 10000, NULL, NULL),
	(-1, 1, 10001, NULL, NULL),
	(-1, 1, 10002, NULL, NULL),
	(-1, 1, 10003, NULL, NULL),
	(-1, 1, 10029, NULL, NULL),
	(-1, 1, 10085, NULL, NULL),
	(-1, 1, 10351, NULL, NULL),
	(1, 1, 10000, 0, NULL),
	(1, 1, 10001, 0, NULL),
	(1, 1, 10002, 0, NULL),
	(1, 1, 10003, 0, NULL),
	(1, 1, 10008, NULL, 0),
	(1, 1, 10017, 0, NULL),
	(1, 1, 10029, NULL, NULL),
	(1, 1, 10045, NULL, 0),
	(1, 1, 10085, 0, NULL),
	(1, 1, 10351, 0, NULL),
	(1, 1, 10586, 0, NULL),
	(1, 1, 10587, NULL, 0),
	(1, 1, 10588, NULL, 0),
	(1, 1, 10687, NULL, 0),
	(1, 1, 10688, NULL, 0),
	(1, 1, 10690, NULL, 0),
	(1, 1, 10691, NULL, 0),
	(1, 1, 10692, NULL, 0),
	(1, 1, 10693, NULL, 0),
	(1, 1, 10694, NULL, 0),
	(1, 1, 10695, NULL, 0),
	(1, 1, 10696, NULL, 0),
	(1, 1, 10697, NULL, 0),
	(1, 1, 10698, NULL, 0),
	(1, 1, 10699, NULL, 0),
	(1, 1, 10700, NULL, 0),
	(1, 1, 10701, NULL, 0),
	(24, 1, 10003, NULL, NULL),
	(24, 1, 10009, NULL, 0),
	(24, 1, 10010, NULL, 0),
	(24, 1, 10012, NULL, 0),
	(24, 1, 10014, NULL, NULL),
	(24, 1, 10017, NULL, NULL),
	(24, 1, 10029, NULL, NULL),
	(24, 1, 10109, NULL, 0),
	(24, 1, 10586, NULL, NULL),
	(24, 1, 10587, NULL, 0),
	(24, 1, 10588, NULL, 0),
	(24, 1, 10589, NULL, 0),
	(24, 1, 10590, NULL, 0),
	(24, 1, 10591, NULL, 0),
	(24, 1, 10594, NULL, 0),
	(24, 1, 10597, NULL, 0),
	(24, 1, 10603, NULL, 0),
	(24, 1, 10705, NULL, 0),
	(24, 1, 11083, NULL, 0),
	(25, 1, 10000, NULL, NULL),
	(25, 1, 10001, NULL, NULL),
	(25, 1, 10002, NULL, NULL),
	(25, 1, 10003, NULL, NULL),
	(25, 1, 10007, NULL, 0),
	(25, 1, 10009, NULL, 0),
	(25, 1, 10010, NULL, 0),
	(25, 1, 10012, NULL, 0),
	(25, 1, 10014, NULL, 0),
	(25, 1, 10017, 0, NULL),
	(25, 1, 10018, 0, NULL),
	(25, 1, 10029, 0, NULL),
	(25, 1, 10109, NULL, 0),
	(25, 1, 10586, 0, NULL),
	(25, 1, 10587, NULL, 0),
	(25, 1, 10588, NULL, 0),
	(25, 1, 10589, NULL, 0),
	(25, 1, 10590, NULL, 0),
	(25, 1, 10591, NULL, 0),
	(25, 1, 10592, NULL, 0),
	(25, 1, 10593, NULL, 0),
	(25, 1, 10594, NULL, 0),
	(25, 1, 10595, NULL, 0),
	(25, 1, 10596, NULL, 0),
	(25, 1, 10597, NULL, 0),
	(25, 1, 10598, NULL, 0),
	(25, 1, 10599, NULL, 0),
	(25, 1, 10600, NULL, 0),
	(25, 1, 10602, NULL, 0),
	(25, 1, 10603, NULL, 0),
	(25, 1, 10604, NULL, 0),
	(25, 1, 10605, NULL, 0),
	(25, 1, 10606, NULL, 0),
	(26, 1, 10029, NULL, NULL),
	(26, 1, 10269, NULL, NULL),
	(26, 1, 10270, NULL, NULL),
	(30, 1, 10000, 0, NULL),
	(30, 1, 10001, 0, NULL),
	(30, 1, 10002, 0, NULL),
	(30, 1, 10003, 0, NULL),
	(30, 1, 10008, NULL, 0),
	(30, 1, 10017, 0, NULL),
	(30, 1, 10018, 0, NULL),
	(30, 1, 10029, NULL, NULL),
	(30, 1, 10045, NULL, 0),
	(30, 1, 10085, 0, NULL),
	(30, 1, 10351, 0, NULL),
	(30, 1, 10586, 0, NULL),
	(30, 1, 10587, NULL, 0),
	(30, 1, 10588, NULL, 0),
	(30, 1, 10605, NULL, 0),
	(30, 1, 10687, NULL, 0),
	(30, 1, 10688, NULL, 0),
	(30, 1, 10689, NULL, 0),
	(30, 1, 10690, NULL, 0),
	(30, 1, 10691, NULL, 0),
	(30, 1, 10692, NULL, 0),
	(30, 1, 10693, NULL, 0),
	(30, 1, 10694, NULL, 0),
	(30, 1, 10695, NULL, 0),
	(30, 1, 10696, NULL, 0),
	(30, 1, 10697, NULL, 0),
	(30, 1, 10698, NULL, 0),
	(30, 1, 10699, NULL, 0),
	(30, 1, 10700, NULL, 0),
	(30, 1, 10701, NULL, 0),
	(33, 1, 10000, NULL, NULL),
	(33, 1, 10001, NULL, NULL),
	(33, 1, 10002, NULL, NULL),
	(33, 1, 10003, NULL, NULL),
	(33, 1, 10004, NULL, NULL),
	(33, 1, 10005, NULL, NULL),
	(33, 1, 10006, NULL, NULL),
	(33, 1, 10007, NULL, NULL),
	(33, 1, 10008, NULL, NULL),
	(33, 1, 10009, NULL, NULL),
	(33, 1, 10010, NULL, NULL),
	(33, 1, 10011, NULL, NULL),
	(33, 1, 10012, NULL, NULL),
	(33, 1, 10013, NULL, NULL),
	(33, 1, 10014, NULL, NULL),
	(33, 1, 10015, NULL, NULL),
	(33, 1, 10016, NULL, NULL),
	(33, 1, 10017, NULL, NULL),
	(33, 1, 10019, NULL, NULL),
	(33, 1, 10020, NULL, NULL),
	(33, 1, 10021, NULL, NULL),
	(33, 1, 10022, NULL, NULL),
	(33, 1, 10023, NULL, NULL),
	(33, 1, 10024, NULL, NULL),
	(33, 1, 10025, NULL, NULL),
	(33, 1, 10026, NULL, NULL),
	(33, 1, 10027, NULL, NULL),
	(33, 1, 10028, NULL, NULL),
	(33, 1, 10109, NULL, 0),
	(33, 1, 10302, NULL, 0),
	(33, 1, 10587, NULL, 0),
	(33, 1, 10588, NULL, 0),
	(33, 1, 10589, NULL, 0),
	(33, 1, 10597, NULL, 0),
	(33, 1, 10605, NULL, 0),
	(33, 1, 10684, NULL, 0),
	(33, 1, 10685, NULL, 0),
	(33, 1, 10686, NULL, 0),
	(33, 1, 10701, NULL, 0),
	(33, 1, 10702, NULL, 0),
	(33, 1, 10703, NULL, 0),
	(33, 1, 10704, NULL, 0),
	(33, 1, 10705, NULL, 0),
	(33, 1, 10706, NULL, 0),
	(33, 1, 10707, NULL, 0),
	(33, 1, 10708, NULL, 0),
	(33, 1, 10709, NULL, 0),
	(33, 1, 10710, NULL, 0),
	(33, 1, 10711, NULL, 0),
	(33, 1, 10712, NULL, 0),
	(33, 1, 10713, NULL, 0),
	(33, 1, 10714, NULL, 0),
	(38, 1, 10015, NULL, NULL),
	(38, 1, 10029, NULL, NULL),
	(38, 1, 10044, NULL, NULL),
	(38, 1, 10063, NULL, NULL),
	(38, 1, 10547, NULL, NULL),
	(39, 1, 10000, NULL, NULL),
	(39, 1, 10001, NULL, NULL),
	(39, 1, 10002, NULL, NULL),
	(39, 1, 10012, NULL, NULL),
	(39, 1, 10014, NULL, NULL),
	(39, 1, 10015, NULL, NULL),
	(39, 1, 10029, NULL, NULL),
	(39, 1, 10048, NULL, NULL),
	(39, 1, 10549, NULL, NULL),
	(39, 1, 10550, NULL, NULL),
	(39, 1, 10551, NULL, NULL),
	(39, 1, 10607, NULL, NULL),
	(39, 1, 10608, NULL, NULL),
	(39, 1, 10609, NULL, NULL),
	(39, 1, 10610, NULL, NULL),
	(39, 1, 10611, NULL, NULL),
	(39, 1, 10612, NULL, NULL),
	(39, 1, 10613, NULL, NULL),
	(39, 1, 10614, NULL, NULL),
	(39, 1, 10615, NULL, NULL),
	(39, 1, 10616, NULL, NULL),
	(39, 1, 10617, NULL, NULL),
	(39, 1, 10618, NULL, NULL),
	(39, 1, 10619, NULL, NULL),
	(39, 1, 10620, NULL, NULL),
	(39, 1, 10621, NULL, NULL),
	(39, 1, 10622, NULL, NULL),
	(39, 1, 10623, NULL, NULL),
	(39, 1, 10624, NULL, NULL),
	(39, 1, 10625, NULL, NULL),
	(39, 1, 10626, NULL, NULL),
	(39, 1, 10627, NULL, NULL),
	(39, 1, 10628, NULL, NULL),
	(39, 1, 10629, NULL, NULL),
	(39, 1, 10630, NULL, NULL),
	(39, 1, 10631, NULL, NULL),
	(39, 1, 10632, NULL, NULL),
	(39, 1, 10633, NULL, NULL),
	(39, 1, 10634, NULL, NULL),
	(39, 1, 10635, NULL, NULL),
	(39, 1, 10636, NULL, NULL),
	(39, 1, 10637, NULL, NULL),
	(39, 1, 10638, NULL, NULL),
	(39, 1, 10639, NULL, NULL),
	(39, 1, 10640, NULL, NULL),
	(39, 1, 10641, NULL, NULL),
	(39, 1, 10642, NULL, NULL),
	(39, 1, 10643, NULL, NULL),
	(39, 1, 10644, NULL, NULL),
	(39, 1, 10645, NULL, NULL),
	(39, 1, 10646, NULL, NULL),
	(39, 1, 10647, NULL, NULL),
	(39, 1, 10648, NULL, NULL),
	(39, 1, 10649, NULL, NULL),
	(39, 1, 10650, NULL, NULL),
	(39, 1, 10651, NULL, NULL),
	(39, 1, 10652, NULL, NULL),
	(39, 1, 10653, NULL, NULL),
	(39, 1, 10654, NULL, NULL),
	(39, 1, 10655, NULL, NULL),
	(39, 1, 10656, NULL, NULL),
	(39, 1, 10657, NULL, NULL),
	(39, 1, 10658, NULL, NULL),
	(39, 1, 10659, NULL, NULL),
	(39, 1, 10660, NULL, NULL),
	(39, 1, 10661, NULL, NULL),
	(39, 1, 10662, NULL, NULL),
	(39, 1, 10663, NULL, NULL),
	(39, 1, 10664, NULL, NULL),
	(39, 1, 10665, NULL, NULL),
	(39, 1, 10668, NULL, NULL),
	(39, 1, 10669, NULL, NULL),
	(39, 1, 10674, NULL, NULL),
	(39, 1, 10675, NULL, NULL),
	(39, 1, 10676, NULL, NULL),
	(39, 1, 10677, NULL, NULL),
	(39, 1, 10678, NULL, NULL),
	(39, 1, 10679, NULL, NULL),
	(39, 1, 10682, NULL, NULL),
	(39, 1, 10733, NULL, NULL),
	(39, 1, 10744, NULL, NULL),
	(39, 1, 10894, NULL, NULL),
	(39, 1, 10895, NULL, NULL),
	(39, 1, 10896, NULL, NULL),
	(51, 1, 10000, 0, NULL),
	(51, 1, 10001, 0, NULL),
	(51, 1, 10002, 0, NULL),
	(51, 1, 10003, 0, NULL),
	(51, 1, 10008, NULL, 0),
	(51, 1, 10017, 0, NULL),
	(51, 1, 10029, NULL, NULL),
	(51, 1, 10045, NULL, 0),
	(51, 1, 10085, 0, NULL),
	(51, 1, 10351, 0, NULL),
	(51, 1, 10586, 0, NULL),
	(51, 1, 10587, NULL, 0),
	(51, 1, 10588, NULL, 0),
	(51, 1, 10687, NULL, 0),
	(51, 1, 10688, NULL, 0),
	(51, 1, 10690, NULL, 0),
	(51, 1, 10691, NULL, 0),
	(51, 1, 10692, NULL, 0),
	(51, 1, 10693, NULL, 0),
	(51, 1, 10694, NULL, 0),
	(51, 1, 10695, NULL, 0),
	(51, 1, 10696, NULL, 0),
	(51, 1, 10697, NULL, 0),
	(51, 1, 10698, NULL, 0),
	(51, 1, 10699, NULL, 0),
	(51, 1, 10700, NULL, 0),
	(51, 1, 10701, NULL, 0),
	(56, 0, 10284, NULL, NULL),
	(58, 0, 10284, NULL, NULL),
	(63, 0, 10015, NULL, NULL),
	(63, 0, 10026, NULL, NULL),
	(63, 0, 10043, NULL, NULL),
	(63, 0, 10045, NULL, NULL),
	(63, 0, 10079, NULL, NULL),
	(63, 0, 10259, NULL, NULL),
	(63, 0, 10260, NULL, NULL),
	(63, 0, 11090, NULL, NULL),
	(63, 0, 11091, NULL, NULL),
	(63, 0, 11092, NULL, NULL),
	(63, 0, 11093, NULL, NULL),
	(63, 0, 11094, NULL, NULL),
	(63, 0, 11095, NULL, NULL),
	(63, 0, 11096, NULL, NULL),
	(63, 0, 11097, NULL, NULL),
	(63, 0, 11098, NULL, NULL),
	(63, 0, 11099, NULL, NULL),
	(63, 0, 11100, NULL, NULL),
	(63, 0, 11101, NULL, NULL),
	(63, 0, 11102, NULL, NULL),
	(63, 0, 11103, NULL, NULL),
	(63, 0, 11104, NULL, NULL),
	(63, 0, 11105, NULL, NULL),
	(63, 0, 11106, NULL, NULL),
	(63, 0, 11107, NULL, NULL),
	(63, 0, 11108, NULL, NULL),
	(63, 0, 11109, NULL, NULL),
	(63, 0, 11110, NULL, NULL),
	(66, 0, 10000, NULL, NULL),
	(66, 0, 10001, NULL, NULL),
	(66, 0, 10002, NULL, NULL),
	(66, 0, 10013, NULL, NULL),
	(66, 0, 10014, NULL, NULL),
	(66, 0, 10029, NULL, NULL),
	(66, 0, 10030, NULL, NULL),
	(66, 0, 10038, NULL, NULL),
	(66, 0, 10043, NULL, NULL),
	(66, 0, 10045, NULL, NULL),
	(66, 0, 10081, NULL, NULL),
	(66, 0, 10242, NULL, NULL),
	(66, 0, 10252, NULL, NULL),
	(66, 0, 10253, NULL, NULL),
	(66, 0, 10254, NULL, NULL),
	(66, 0, 10255, NULL, NULL),
	(66, 0, 10256, NULL, NULL),
	(66, 0, 10257, NULL, NULL),
	(66, 0, 10258, NULL, NULL),
	(66, 0, 10271, NULL, NULL),
	(66, 0, 10274, NULL, NULL),
	(67, 1, 10000, NULL, NULL),
	(67, 1, 10001, NULL, NULL),
	(67, 1, 10002, NULL, NULL),
	(67, 1, 10014, NULL, NULL),
	(67, 1, 10029, NULL, NULL),
	(67, 1, 10030, NULL, NULL),
	(67, 1, 10031, NULL, NULL),
	(67, 1, 10033, NULL, NULL),
	(67, 1, 10034, NULL, NULL),
	(67, 1, 10038, NULL, NULL),
	(67, 1, 10045, NULL, NULL),
	(67, 1, 10108, NULL, NULL),
	(67, 1, 10109, NULL, NULL),
	(67, 1, 10110, NULL, NULL),
	(67, 1, 10111, NULL, NULL),
	(67, 1, 10112, NULL, NULL),
	(67, 1, 10113, NULL, NULL),
	(67, 1, 10114, NULL, NULL),
	(67, 1, 10115, NULL, NULL),
	(67, 1, 10116, NULL, NULL),
	(67, 1, 10117, NULL, NULL),
	(67, 1, 10118, NULL, NULL),
	(67, 1, 10119, NULL, NULL),
	(67, 1, 10120, NULL, NULL),
	(67, 1, 10121, NULL, NULL),
	(67, 1, 10122, NULL, NULL),
	(67, 1, 10123, NULL, NULL),
	(67, 1, 10124, NULL, NULL),
	(67, 1, 10125, NULL, NULL),
	(67, 1, 10126, NULL, NULL),
	(67, 1, 10127, NULL, NULL),
	(67, 1, 10128, NULL, NULL),
	(67, 1, 10129, NULL, NULL),
	(67, 1, 10130, NULL, NULL),
	(67, 1, 10131, NULL, NULL),
	(67, 1, 10132, NULL, NULL),
	(67, 1, 10133, NULL, NULL),
	(67, 1, 10134, NULL, NULL),
	(67, 1, 10135, NULL, NULL),
	(67, 1, 10136, NULL, NULL),
	(67, 1, 10137, NULL, NULL),
	(67, 1, 10138, NULL, NULL),
	(67, 1, 10139, NULL, NULL),
	(67, 1, 10140, NULL, NULL),
	(67, 1, 10141, NULL, NULL),
	(67, 1, 10142, NULL, NULL),
	(67, 1, 10143, NULL, NULL),
	(67, 1, 10144, NULL, NULL),
	(67, 1, 10145, NULL, NULL),
	(67, 1, 10146, NULL, NULL),
	(67, 1, 10147, NULL, NULL),
	(67, 1, 10148, NULL, NULL),
	(67, 1, 10149, NULL, NULL),
	(67, 1, 10150, NULL, NULL),
	(67, 1, 10151, NULL, NULL),
	(67, 1, 10152, NULL, NULL),
	(67, 1, 10153, NULL, NULL),
	(67, 1, 10154, NULL, NULL),
	(67, 1, 10155, NULL, NULL),
	(67, 1, 10156, NULL, NULL),
	(67, 1, 10157, NULL, NULL),
	(67, 1, 10158, NULL, NULL),
	(67, 1, 10159, NULL, NULL),
	(67, 1, 10160, NULL, NULL),
	(67, 1, 10161, NULL, NULL),
	(67, 1, 10162, NULL, NULL),
	(67, 1, 10163, NULL, NULL),
	(67, 1, 10164, NULL, NULL),
	(67, 1, 10165, NULL, NULL),
	(67, 1, 10166, NULL, NULL),
	(68, 1, 10000, NULL, NULL),
	(68, 1, 10001, NULL, NULL),
	(68, 1, 10002, NULL, NULL),
	(68, 1, 10014, NULL, NULL),
	(68, 1, 10029, NULL, NULL),
	(68, 1, 10030, NULL, NULL),
	(68, 1, 10031, NULL, NULL),
	(68, 1, 10033, NULL, NULL),
	(68, 1, 10034, NULL, NULL),
	(68, 1, 10038, NULL, NULL),
	(68, 1, 10045, NULL, NULL),
	(68, 1, 10108, NULL, NULL),
	(68, 1, 10109, NULL, NULL),
	(68, 1, 10110, NULL, NULL),
	(68, 1, 10111, NULL, NULL),
	(68, 1, 10112, NULL, NULL),
	(68, 1, 10113, NULL, NULL),
	(68, 1, 10114, NULL, NULL),
	(68, 1, 10115, NULL, NULL),
	(68, 1, 10116, NULL, NULL),
	(68, 1, 10117, NULL, NULL),
	(68, 1, 10118, NULL, NULL),
	(68, 1, 10119, NULL, NULL),
	(68, 1, 10120, NULL, NULL),
	(68, 1, 10121, NULL, NULL),
	(68, 1, 10122, NULL, NULL),
	(68, 1, 10123, NULL, NULL),
	(68, 1, 10124, NULL, NULL),
	(68, 1, 10125, NULL, NULL),
	(68, 1, 10126, NULL, NULL),
	(68, 1, 10127, NULL, NULL),
	(68, 1, 10128, NULL, NULL),
	(68, 1, 10129, NULL, NULL),
	(68, 1, 10130, NULL, NULL),
	(68, 1, 10131, NULL, NULL),
	(68, 1, 10132, NULL, NULL),
	(68, 1, 10133, NULL, NULL),
	(68, 1, 10134, NULL, NULL),
	(68, 1, 10135, NULL, NULL),
	(68, 1, 10136, NULL, NULL),
	(68, 1, 10137, NULL, NULL),
	(68, 1, 10138, NULL, NULL),
	(68, 1, 10139, NULL, NULL),
	(68, 1, 10140, NULL, NULL),
	(68, 1, 10141, NULL, NULL),
	(68, 1, 10142, NULL, NULL),
	(68, 1, 10143, NULL, NULL),
	(68, 1, 10144, NULL, NULL),
	(68, 1, 10145, NULL, NULL),
	(68, 1, 10146, NULL, NULL),
	(68, 1, 10147, NULL, NULL),
	(68, 1, 10148, NULL, NULL),
	(68, 1, 10149, NULL, NULL),
	(68, 1, 10150, NULL, NULL),
	(68, 1, 10151, NULL, NULL),
	(68, 1, 10152, NULL, NULL),
	(68, 1, 10153, NULL, NULL),
	(68, 1, 10154, NULL, NULL),
	(68, 1, 10155, NULL, NULL),
	(68, 1, 10156, NULL, NULL),
	(68, 1, 10157, NULL, NULL),
	(68, 1, 10158, NULL, NULL),
	(68, 1, 10159, NULL, NULL),
	(68, 1, 10160, NULL, NULL),
	(68, 1, 10161, NULL, NULL),
	(68, 1, 10162, NULL, NULL),
	(68, 1, 10163, NULL, NULL),
	(68, 1, 10164, NULL, NULL),
	(68, 1, 10165, NULL, NULL),
	(68, 1, 10166, NULL, NULL),
	(68, 1, 10257, NULL, NULL),
	(68, 1, 10351, NULL, NULL),
	(68, 1, 10449, NULL, NULL),
	(68, 1, 10553, NULL, NULL),
	(68, 1, 10840, NULL, NULL),
	(68, 1, 10841, NULL, NULL),
	(68, 1, 10979, NULL, NULL),
	(68, 1, 11141, NULL, NULL),
	(68, 1, 11235, NULL, NULL),
	(68, 1, 11236, NULL, NULL),
	(68, 1, 11238, NULL, NULL),
	(69, 1, 10000, NULL, NULL),
	(69, 1, 10001, NULL, NULL),
	(69, 1, 10002, NULL, NULL),
	(69, 1, 10014, NULL, NULL),
	(69, 1, 10029, NULL, NULL),
	(69, 1, 10030, NULL, NULL),
	(69, 1, 10031, NULL, NULL),
	(69, 1, 10033, NULL, NULL),
	(69, 1, 10034, NULL, NULL),
	(69, 1, 10038, NULL, NULL),
	(69, 1, 10041, NULL, NULL),
	(69, 1, 10045, NULL, NULL),
	(69, 1, 10108, NULL, NULL),
	(69, 1, 10109, NULL, NULL),
	(69, 1, 10110, NULL, NULL),
	(69, 1, 10111, NULL, NULL),
	(69, 1, 10112, NULL, NULL),
	(69, 1, 10113, NULL, NULL),
	(69, 1, 10114, NULL, NULL),
	(69, 1, 10115, NULL, NULL),
	(69, 1, 10116, NULL, NULL),
	(69, 1, 10117, NULL, NULL),
	(69, 1, 10118, NULL, NULL),
	(69, 1, 10119, NULL, NULL),
	(69, 1, 10120, NULL, NULL),
	(69, 1, 10121, NULL, NULL),
	(69, 1, 10122, NULL, NULL),
	(69, 1, 10123, NULL, NULL),
	(69, 1, 10124, NULL, NULL),
	(69, 1, 10125, NULL, NULL),
	(69, 1, 10126, NULL, NULL),
	(69, 1, 10127, NULL, NULL),
	(69, 1, 10128, NULL, NULL),
	(69, 1, 10129, NULL, NULL),
	(69, 1, 10130, NULL, NULL),
	(69, 1, 10131, NULL, NULL),
	(69, 1, 10132, NULL, NULL),
	(69, 1, 10133, NULL, NULL),
	(69, 1, 10134, NULL, NULL),
	(69, 1, 10135, NULL, NULL),
	(69, 1, 10136, NULL, NULL),
	(69, 1, 10137, NULL, NULL),
	(69, 1, 10138, NULL, NULL),
	(69, 1, 10139, NULL, NULL),
	(69, 1, 10140, NULL, NULL),
	(69, 1, 10141, NULL, NULL),
	(69, 1, 10142, NULL, NULL),
	(69, 1, 10143, NULL, NULL),
	(69, 1, 10144, NULL, NULL),
	(69, 1, 10145, NULL, NULL),
	(69, 1, 10146, NULL, NULL),
	(69, 1, 10147, NULL, NULL),
	(69, 1, 10148, NULL, NULL),
	(69, 1, 10149, NULL, NULL),
	(69, 1, 10150, NULL, NULL),
	(69, 1, 10151, NULL, NULL),
	(69, 1, 10152, NULL, NULL),
	(69, 1, 10153, NULL, NULL),
	(69, 1, 10154, NULL, NULL),
	(69, 1, 10155, NULL, NULL),
	(69, 1, 10156, NULL, NULL),
	(69, 1, 10157, NULL, NULL),
	(69, 1, 10158, NULL, NULL),
	(69, 1, 10159, NULL, NULL),
	(69, 1, 10160, NULL, NULL),
	(69, 1, 10161, NULL, NULL),
	(69, 1, 10162, NULL, NULL),
	(69, 1, 10163, NULL, NULL),
	(69, 1, 10164, NULL, NULL),
	(69, 1, 10165, NULL, NULL),
	(69, 1, 10166, NULL, NULL),
	(69, 1, 10257, NULL, NULL),
	(69, 1, 10351, NULL, NULL),
	(69, 1, 10553, NULL, NULL),
	(69, 1, 10841, NULL, NULL),
	(69, 1, 10979, NULL, NULL),
	(69, 1, 11237, NULL, NULL),
	(69, 1, 11238, NULL, NULL),
	(77, 0, 10000, NULL, NULL),
	(77, 0, 10001, NULL, NULL),
	(77, 0, 10002, NULL, NULL),
	(77, 0, 10007, NULL, NULL),
	(77, 0, 10013, NULL, NULL),
	(77, 0, 10015, NULL, NULL),
	(77, 0, 10029, NULL, NULL),
	(77, 0, 10030, NULL, NULL),
	(77, 0, 10038, NULL, NULL),
	(77, 0, 10041, NULL, NULL),
	(77, 0, 10043, NULL, NULL),
	(77, 0, 10044, NULL, NULL),
	(77, 0, 10045, NULL, NULL),
	(77, 0, 10046, NULL, NULL),
	(77, 0, 10047, NULL, NULL),
	(77, 0, 10048, NULL, NULL),
	(77, 0, 10049, NULL, NULL),
	(77, 0, 10050, NULL, NULL),
	(77, 0, 10051, NULL, NULL),
	(77, 0, 10052, NULL, NULL),
	(77, 0, 10053, NULL, NULL),
	(77, 0, 10054, NULL, NULL),
	(77, 0, 10055, NULL, NULL),
	(77, 0, 10056, NULL, NULL),
	(77, 0, 10057, NULL, NULL),
	(77, 0, 10058, NULL, NULL),
	(77, 0, 10059, NULL, NULL),
	(77, 0, 10060, NULL, NULL),
	(77, 0, 10061, NULL, NULL),
	(77, 0, 10167, NULL, NULL),
	(77, 0, 10168, NULL, NULL),
	(77, 0, 10169, NULL, NULL),
	(77, 0, 10170, NULL, NULL),
	(77, 0, 10171, NULL, NULL),
	(77, 0, 10172, NULL, NULL),
	(77, 0, 10173, NULL, NULL),
	(77, 0, 10174, NULL, NULL),
	(77, 0, 10175, NULL, NULL),
	(77, 0, 10176, NULL, NULL),
	(77, 0, 10177, NULL, NULL),
	(77, 0, 10178, NULL, NULL),
	(77, 0, 10179, NULL, NULL),
	(77, 0, 10180, NULL, NULL),
	(77, 0, 10181, NULL, NULL),
	(77, 0, 10182, NULL, NULL),
	(77, 0, 10183, NULL, NULL),
	(77, 0, 10184, NULL, NULL),
	(77, 0, 10185, NULL, NULL),
	(77, 0, 10186, NULL, NULL),
	(77, 0, 10187, NULL, NULL),
	(77, 0, 10188, NULL, NULL),
	(77, 0, 10189, NULL, NULL),
	(77, 0, 10190, NULL, NULL),
	(77, 0, 10191, NULL, NULL),
	(77, 0, 10192, NULL, NULL),
	(77, 0, 10193, NULL, NULL),
	(77, 0, 10194, NULL, NULL),
	(77, 0, 10195, NULL, NULL),
	(77, 0, 10196, NULL, NULL),
	(77, 0, 10197, NULL, NULL),
	(77, 0, 10198, NULL, NULL),
	(77, 0, 10199, NULL, NULL),
	(77, 0, 10200, NULL, NULL),
	(77, 0, 10201, NULL, NULL),
	(77, 0, 10202, NULL, NULL),
	(77, 0, 10203, NULL, NULL),
	(77, 0, 10204, NULL, NULL),
	(77, 0, 10205, NULL, NULL),
	(77, 0, 10206, NULL, NULL),
	(77, 0, 10207, NULL, NULL),
	(77, 0, 10208, NULL, NULL),
	(77, 0, 10209, NULL, NULL),
	(77, 0, 10210, NULL, NULL),
	(77, 0, 10211, NULL, NULL),
	(77, 0, 10212, NULL, NULL),
	(77, 0, 10213, NULL, NULL),
	(77, 0, 10214, NULL, NULL),
	(77, 0, 10215, NULL, NULL),
	(77, 0, 10216, NULL, NULL),
	(77, 0, 10217, NULL, NULL),
	(77, 0, 10218, NULL, NULL),
	(77, 0, 10219, NULL, NULL),
	(77, 0, 10220, NULL, NULL),
	(77, 0, 10221, NULL, NULL),
	(77, 0, 10222, NULL, NULL),
	(77, 0, 10223, NULL, NULL),
	(77, 0, 10224, NULL, NULL),
	(77, 0, 10225, NULL, NULL),
	(77, 0, 10226, NULL, NULL),
	(77, 0, 10227, NULL, NULL),
	(77, 0, 10228, NULL, NULL),
	(77, 0, 10229, NULL, NULL),
	(77, 0, 10230, NULL, NULL),
	(77, 0, 10231, NULL, NULL),
	(77, 0, 10232, NULL, NULL),
	(77, 0, 10233, NULL, NULL),
	(77, 0, 10234, NULL, NULL),
	(77, 0, 10235, NULL, NULL),
	(77, 0, 10236, NULL, NULL),
	(77, 0, 10237, NULL, NULL),
	(77, 0, 10238, NULL, NULL),
	(77, 0, 10239, NULL, NULL),
	(77, 0, 10240, NULL, NULL),
	(77, 0, 10241, NULL, NULL),
	(77, 0, 10242, NULL, NULL),
	(77, 0, 10243, NULL, NULL),
	(77, 0, 10244, NULL, NULL),
	(77, 0, 10245, NULL, NULL),
	(77, 0, 10246, NULL, NULL),
	(77, 0, 10247, NULL, NULL),
	(77, 0, 10248, NULL, NULL),
	(77, 0, 10249, NULL, NULL),
	(77, 0, 10450, NULL, NULL),
	(77, 0, 10451, NULL, NULL),
	(77, 0, 10452, NULL, NULL),
	(78, 0, 10015, NULL, NULL),
	(78, 0, 10026, NULL, NULL),
	(78, 0, 10043, NULL, NULL),
	(78, 0, 10045, NULL, NULL),
	(78, 0, 10079, NULL, NULL),
	(78, 0, 10259, NULL, NULL),
	(78, 0, 10260, NULL, NULL),
	(78, 0, 11090, NULL, NULL),
	(78, 0, 11091, NULL, NULL),
	(78, 0, 11092, NULL, NULL),
	(78, 0, 11093, NULL, NULL),
	(78, 0, 11094, NULL, NULL),
	(78, 0, 11095, NULL, NULL),
	(78, 0, 11096, NULL, NULL),
	(78, 0, 11097, NULL, NULL),
	(78, 0, 11098, NULL, NULL),
	(78, 0, 11099, NULL, NULL),
	(78, 0, 11100, NULL, NULL),
	(78, 0, 11101, NULL, NULL),
	(78, 0, 11102, NULL, NULL),
	(78, 0, 11103, NULL, NULL),
	(78, 0, 11104, NULL, NULL),
	(78, 0, 11105, NULL, NULL),
	(78, 0, 11106, NULL, NULL),
	(78, 0, 11107, NULL, NULL),
	(78, 0, 11108, NULL, NULL),
	(78, 0, 11109, NULL, NULL),
	(78, 0, 11110, NULL, NULL),
	(79, 1, 10000, NULL, NULL),
	(79, 1, 10001, NULL, NULL),
	(79, 1, 10002, NULL, NULL),
	(79, 1, 10014, NULL, NULL),
	(79, 1, 10029, NULL, NULL),
	(79, 1, 10030, NULL, NULL),
	(79, 1, 10031, NULL, NULL),
	(79, 1, 10033, NULL, NULL),
	(79, 1, 10034, NULL, NULL),
	(79, 1, 10038, NULL, NULL),
	(79, 1, 10045, NULL, NULL),
	(79, 1, 10108, NULL, NULL),
	(79, 1, 10109, NULL, NULL),
	(79, 1, 10110, NULL, NULL),
	(79, 1, 10111, NULL, NULL),
	(79, 1, 10112, NULL, NULL),
	(79, 1, 10113, NULL, NULL),
	(79, 1, 10114, NULL, NULL),
	(79, 1, 10115, NULL, NULL),
	(79, 1, 10116, NULL, NULL),
	(79, 1, 10117, NULL, NULL),
	(79, 1, 10118, NULL, NULL),
	(79, 1, 10119, NULL, NULL),
	(79, 1, 10120, NULL, NULL),
	(79, 1, 10121, NULL, NULL),
	(79, 1, 10122, NULL, NULL),
	(79, 1, 10123, NULL, NULL),
	(79, 1, 10124, NULL, NULL),
	(79, 1, 10125, NULL, NULL),
	(79, 1, 10126, NULL, NULL),
	(79, 1, 10127, NULL, NULL),
	(79, 1, 10128, NULL, NULL),
	(79, 1, 10129, NULL, NULL),
	(79, 1, 10130, NULL, NULL),
	(79, 1, 10131, NULL, NULL),
	(79, 1, 10132, NULL, NULL),
	(79, 1, 10133, NULL, NULL),
	(79, 1, 10134, NULL, NULL),
	(79, 1, 10135, NULL, NULL),
	(79, 1, 10136, NULL, NULL),
	(79, 1, 10137, NULL, NULL),
	(79, 1, 10138, NULL, NULL),
	(79, 1, 10139, NULL, NULL),
	(79, 1, 10140, NULL, NULL),
	(79, 1, 10141, NULL, NULL),
	(79, 1, 10142, NULL, NULL),
	(79, 1, 10143, NULL, NULL),
	(79, 1, 10144, NULL, NULL),
	(79, 1, 10145, NULL, NULL),
	(79, 1, 10146, NULL, NULL),
	(79, 1, 10147, NULL, NULL),
	(79, 1, 10148, NULL, NULL),
	(79, 1, 10149, NULL, NULL),
	(79, 1, 10150, NULL, NULL),
	(79, 1, 10151, NULL, NULL),
	(79, 1, 10152, NULL, NULL),
	(79, 1, 10153, NULL, NULL),
	(79, 1, 10154, NULL, NULL),
	(79, 1, 10155, NULL, NULL),
	(79, 1, 10156, NULL, NULL),
	(79, 1, 10157, NULL, NULL),
	(79, 1, 10158, NULL, NULL),
	(79, 1, 10159, NULL, NULL),
	(79, 1, 10160, NULL, NULL),
	(79, 1, 10161, NULL, NULL),
	(79, 1, 10162, NULL, NULL),
	(79, 1, 10163, NULL, NULL),
	(79, 1, 10164, NULL, NULL),
	(79, 1, 10165, NULL, NULL),
	(79, 1, 10166, NULL, NULL),
	(80, 1, 10000, NULL, NULL),
	(80, 1, 10001, NULL, NULL),
	(80, 1, 10002, NULL, NULL),
	(80, 1, 10014, NULL, NULL),
	(80, 1, 10029, NULL, NULL),
	(80, 1, 10030, NULL, NULL),
	(80, 1, 10031, NULL, NULL),
	(80, 1, 10033, NULL, NULL),
	(80, 1, 10034, NULL, NULL),
	(80, 1, 10038, NULL, NULL),
	(80, 1, 10045, NULL, NULL),
	(80, 1, 10108, NULL, NULL),
	(80, 1, 10109, NULL, NULL),
	(80, 1, 10110, NULL, NULL),
	(80, 1, 10111, NULL, NULL),
	(80, 1, 10112, NULL, NULL),
	(80, 1, 10113, NULL, NULL),
	(80, 1, 10114, NULL, NULL),
	(80, 1, 10115, NULL, NULL),
	(80, 1, 10116, NULL, NULL),
	(80, 1, 10117, NULL, NULL),
	(80, 1, 10118, NULL, NULL),
	(80, 1, 10119, NULL, NULL),
	(80, 1, 10120, NULL, NULL),
	(80, 1, 10121, NULL, NULL),
	(80, 1, 10122, NULL, NULL),
	(80, 1, 10123, NULL, NULL),
	(80, 1, 10124, NULL, NULL),
	(80, 1, 10125, NULL, NULL),
	(80, 1, 10126, NULL, NULL),
	(80, 1, 10127, NULL, NULL),
	(80, 1, 10128, NULL, NULL),
	(80, 1, 10129, NULL, NULL),
	(80, 1, 10130, NULL, NULL),
	(80, 1, 10131, NULL, NULL),
	(80, 1, 10132, NULL, NULL),
	(80, 1, 10133, NULL, NULL),
	(80, 1, 10134, NULL, NULL),
	(80, 1, 10135, NULL, NULL),
	(80, 1, 10136, NULL, NULL),
	(80, 1, 10137, NULL, NULL),
	(80, 1, 10138, NULL, NULL),
	(80, 1, 10139, NULL, NULL),
	(80, 1, 10140, NULL, NULL),
	(80, 1, 10141, NULL, NULL),
	(80, 1, 10142, NULL, NULL),
	(80, 1, 10143, NULL, NULL),
	(80, 1, 10144, NULL, NULL),
	(80, 1, 10145, NULL, NULL),
	(80, 1, 10146, NULL, NULL),
	(80, 1, 10147, NULL, NULL),
	(80, 1, 10148, NULL, NULL),
	(80, 1, 10149, NULL, NULL),
	(80, 1, 10150, NULL, NULL),
	(80, 1, 10151, NULL, NULL),
	(80, 1, 10152, NULL, NULL),
	(80, 1, 10153, NULL, NULL),
	(80, 1, 10154, NULL, NULL),
	(80, 1, 10155, NULL, NULL),
	(80, 1, 10156, NULL, NULL),
	(80, 1, 10157, NULL, NULL),
	(80, 1, 10158, NULL, NULL),
	(80, 1, 10159, NULL, NULL),
	(80, 1, 10160, NULL, NULL),
	(80, 1, 10161, NULL, NULL),
	(80, 1, 10162, NULL, NULL),
	(80, 1, 10163, NULL, NULL),
	(80, 1, 10164, NULL, NULL),
	(80, 1, 10165, NULL, NULL),
	(80, 1, 10166, NULL, NULL),
	(81, 0, 10000, NULL, NULL),
	(81, 0, 10001, NULL, NULL),
	(81, 0, 10002, NULL, NULL),
	(81, 0, 10007, NULL, NULL),
	(81, 0, 10008, NULL, NULL),
	(81, 0, 10012, NULL, NULL),
	(81, 0, 10013, NULL, NULL),
	(81, 0, 10014, NULL, NULL),
	(81, 0, 10029, NULL, NULL),
	(81, 0, 10030, NULL, NULL),
	(81, 0, 10031, NULL, NULL),
	(81, 0, 10038, NULL, NULL),
	(81, 0, 10043, NULL, NULL),
	(81, 0, 10044, NULL, NULL),
	(81, 0, 10045, NULL, NULL),
	(81, 0, 10046, NULL, NULL),
	(81, 0, 10047, NULL, NULL),
	(81, 0, 10048, NULL, NULL),
	(81, 0, 10053, NULL, NULL),
	(81, 0, 10062, NULL, NULL),
	(81, 0, 10063, NULL, NULL),
	(81, 0, 10064, NULL, NULL),
	(81, 0, 10065, NULL, NULL),
	(81, 0, 10066, NULL, NULL),
	(81, 0, 10067, NULL, NULL),
	(81, 0, 10068, NULL, NULL),
	(81, 0, 10069, NULL, NULL),
	(81, 0, 10070, NULL, NULL),
	(81, 0, 10071, NULL, NULL),
	(81, 0, 10072, NULL, NULL),
	(81, 0, 10073, NULL, NULL),
	(81, 0, 10074, NULL, NULL),
	(81, 0, 10075, NULL, NULL),
	(81, 0, 10076, NULL, NULL),
	(81, 0, 10077, NULL, NULL),
	(81, 0, 10078, NULL, NULL),
	(81, 0, 10079, NULL, NULL),
	(81, 0, 10080, NULL, NULL),
	(81, 0, 10081, NULL, NULL),
	(81, 0, 10084, NULL, NULL),
	(81, 0, 10085, NULL, NULL),
	(81, 0, 10086, NULL, NULL),
	(81, 0, 10087, NULL, NULL),
	(81, 0, 10088, NULL, NULL),
	(81, 0, 10089, NULL, NULL),
	(81, 0, 10090, NULL, NULL),
	(81, 0, 10091, NULL, NULL),
	(81, 0, 10092, NULL, NULL),
	(81, 0, 10093, NULL, NULL),
	(81, 0, 10094, NULL, NULL),
	(81, 0, 10095, NULL, NULL),
	(81, 0, 10096, NULL, NULL),
	(81, 0, 10097, NULL, NULL),
	(81, 0, 10098, NULL, NULL),
	(81, 0, 10099, NULL, NULL),
	(81, 0, 10100, NULL, NULL),
	(81, 0, 10101, NULL, NULL),
	(81, 0, 10102, NULL, NULL),
	(81, 0, 10103, NULL, NULL),
	(81, 0, 10104, NULL, NULL),
	(81, 0, 10105, NULL, NULL),
	(81, 0, 10106, NULL, NULL),
	(81, 0, 10107, NULL, NULL),
	(81, 0, 10108, NULL, NULL),
	(81, 0, 10109, NULL, NULL),
	(81, 0, 10110, NULL, NULL),
	(81, 0, 10111, NULL, NULL),
	(81, 0, 10112, NULL, NULL),
	(81, 0, 10113, NULL, NULL),
	(81, 0, 10114, NULL, NULL),
	(81, 0, 10115, NULL, NULL),
	(81, 0, 10116, NULL, NULL),
	(81, 0, 10117, NULL, NULL),
	(81, 0, 10118, NULL, NULL),
	(81, 0, 10119, NULL, NULL),
	(81, 0, 10120, NULL, NULL),
	(81, 0, 10121, NULL, NULL),
	(81, 0, 10122, NULL, NULL),
	(81, 0, 10123, NULL, NULL),
	(81, 0, 10124, NULL, NULL),
	(81, 0, 10125, NULL, NULL),
	(81, 0, 10126, NULL, NULL),
	(81, 0, 10127, NULL, NULL),
	(81, 0, 10128, NULL, NULL),
	(81, 0, 10129, NULL, NULL),
	(81, 0, 10130, NULL, NULL),
	(81, 0, 10131, NULL, NULL),
	(81, 0, 10132, NULL, NULL),
	(81, 0, 10133, NULL, NULL),
	(81, 0, 10134, NULL, NULL),
	(81, 0, 10135, NULL, NULL),
	(81, 0, 10136, NULL, NULL),
	(81, 0, 10137, NULL, NULL),
	(81, 0, 10138, NULL, NULL),
	(81, 0, 10139, NULL, NULL),
	(81, 0, 10140, NULL, NULL),
	(81, 0, 10141, NULL, NULL),
	(81, 0, 10142, NULL, NULL),
	(81, 0, 10143, NULL, NULL),
	(81, 0, 10144, NULL, NULL),
	(81, 0, 10145, NULL, NULL),
	(81, 0, 10146, NULL, NULL),
	(81, 0, 10147, NULL, NULL),
	(81, 0, 10148, NULL, NULL),
	(81, 0, 10149, NULL, NULL),
	(81, 0, 10150, NULL, NULL),
	(81, 0, 10151, NULL, NULL),
	(81, 0, 10152, NULL, NULL),
	(81, 0, 10153, NULL, NULL),
	(81, 0, 10154, NULL, NULL),
	(81, 0, 10155, NULL, NULL),
	(81, 0, 10156, NULL, NULL),
	(81, 0, 10157, NULL, NULL),
	(81, 0, 10158, NULL, NULL),
	(81, 0, 10159, NULL, NULL),
	(81, 0, 10160, NULL, NULL),
	(81, 0, 10161, NULL, NULL),
	(81, 0, 10162, NULL, NULL),
	(81, 0, 10163, NULL, NULL),
	(81, 0, 10164, NULL, NULL),
	(81, 0, 10165, NULL, NULL),
	(81, 0, 10166, NULL, NULL),
	(81, 0, 10261, NULL, NULL),
	(81, 0, 10262, NULL, NULL),
	(81, 0, 10263, NULL, NULL),
	(81, 0, 10264, NULL, NULL),
	(81, 0, 10265, NULL, NULL),
	(81, 0, 10266, NULL, NULL),
	(81, 0, 10267, NULL, NULL),
	(81, 0, 10268, NULL, NULL),
	(81, 0, 10269, NULL, NULL),
	(81, 0, 10270, NULL, NULL),
	(81, 0, 10291, NULL, NULL),
	(81, 0, 10292, NULL, NULL),
	(81, 0, 10293, NULL, NULL),
	(81, 0, 10294, NULL, NULL),
	(81, 0, 10295, NULL, NULL),
	(81, 0, 10296, NULL, NULL),
	(81, 0, 10297, NULL, NULL),
	(81, 0, 10298, NULL, NULL),
	(81, 0, 10299, NULL, NULL),
	(81, 0, 10300, NULL, NULL),
	(81, 0, 10301, NULL, NULL),
	(81, 0, 10302, NULL, NULL),
	(81, 0, 10303, NULL, NULL),
	(81, 0, 10304, NULL, NULL),
	(81, 0, 10305, NULL, NULL),
	(81, 0, 10306, NULL, NULL),
	(81, 0, 10307, NULL, NULL),
	(81, 0, 10308, NULL, NULL),
	(81, 0, 10309, NULL, NULL),
	(81, 0, 10310, NULL, NULL),
	(81, 0, 10311, NULL, NULL),
	(81, 0, 10312, NULL, NULL),
	(81, 0, 10313, NULL, NULL),
	(81, 0, 10314, NULL, NULL),
	(81, 0, 10315, NULL, NULL),
	(81, 0, 10316, NULL, NULL),
	(81, 0, 10317, NULL, NULL),
	(81, 0, 10318, NULL, NULL),
	(81, 0, 10319, NULL, NULL),
	(81, 0, 10320, NULL, NULL),
	(81, 0, 10321, NULL, NULL),
	(81, 0, 10322, NULL, NULL),
	(81, 0, 10323, NULL, NULL),
	(81, 0, 10324, NULL, NULL),
	(81, 0, 10325, NULL, NULL),
	(81, 0, 10326, NULL, NULL),
	(81, 0, 10327, NULL, NULL),
	(81, 0, 10328, NULL, NULL),
	(81, 0, 10329, NULL, NULL),
	(81, 0, 10330, NULL, NULL),
	(81, 0, 10331, NULL, NULL),
	(81, 0, 10332, NULL, NULL),
	(81, 0, 10333, NULL, NULL),
	(81, 0, 10334, NULL, NULL),
	(81, 0, 10335, NULL, NULL),
	(81, 0, 10336, NULL, NULL),
	(81, 0, 10337, NULL, NULL),
	(81, 0, 10338, NULL, NULL),
	(81, 0, 10339, NULL, NULL),
	(81, 0, 10340, NULL, NULL),
	(81, 0, 10341, NULL, NULL),
	(81, 0, 10342, NULL, NULL),
	(81, 0, 10343, NULL, NULL),
	(81, 0, 10344, NULL, NULL),
	(81, 0, 10345, NULL, NULL),
	(81, 0, 10346, NULL, NULL),
	(81, 0, 10347, NULL, NULL),
	(81, 0, 10348, NULL, NULL),
	(81, 0, 10349, NULL, NULL),
	(81, 0, 10350, NULL, NULL),
	(81, 0, 10423, NULL, NULL),
	(81, 0, 10429, NULL, NULL),
	(81, 0, 10446, NULL, NULL),
	(81, 0, 10447, NULL, NULL),
	(81, 0, 10448, NULL, NULL),
	(81, 0, 10449, NULL, NULL),
	(81, 0, 10450, NULL, NULL),
	(81, 0, 10451, NULL, NULL),
	(81, 0, 10452, NULL, NULL),
	(81, 0, 10453, NULL, NULL),
	(81, 0, 10454, NULL, NULL),
	(81, 0, 10455, NULL, NULL),
	(81, 0, 10456, NULL, NULL),
	(81, 0, 10457, NULL, NULL),
	(81, 0, 10458, NULL, NULL),
	(81, 0, 10459, NULL, NULL),
	(81, 0, 10460, NULL, NULL),
	(81, 0, 10461, NULL, NULL),
	(81, 0, 10462, NULL, NULL),
	(81, 0, 10463, NULL, NULL),
	(81, 0, 10464, NULL, NULL),
	(81, 0, 10465, NULL, NULL),
	(81, 0, 10466, NULL, NULL),
	(81, 0, 10467, NULL, NULL),
	(81, 0, 10468, NULL, NULL),
	(81, 0, 10469, NULL, NULL),
	(81, 0, 10470, NULL, NULL),
	(81, 0, 10471, NULL, NULL),
	(81, 0, 10472, NULL, NULL),
	(81, 0, 10473, NULL, NULL),
	(81, 0, 10474, NULL, NULL),
	(81, 0, 10475, NULL, NULL),
	(81, 0, 10476, NULL, NULL),
	(81, 0, 10477, NULL, NULL),
	(81, 0, 10478, NULL, NULL),
	(81, 0, 10479, NULL, NULL),
	(81, 0, 10480, NULL, NULL),
	(81, 0, 10481, NULL, NULL),
	(81, 0, 10482, NULL, NULL),
	(81, 0, 10483, NULL, NULL),
	(81, 0, 10484, NULL, NULL),
	(81, 0, 10485, NULL, NULL),
	(81, 0, 10486, NULL, NULL),
	(81, 0, 10487, NULL, NULL),
	(81, 0, 10488, NULL, NULL),
	(81, 0, 10489, NULL, NULL),
	(81, 0, 10490, NULL, NULL),
	(81, 0, 10491, NULL, NULL),
	(81, 0, 10492, NULL, NULL),
	(81, 0, 10493, NULL, NULL),
	(81, 0, 10494, NULL, NULL),
	(81, 0, 10495, NULL, NULL),
	(81, 0, 10496, NULL, NULL),
	(81, 0, 10497, NULL, NULL),
	(81, 0, 10498, NULL, NULL),
	(81, 0, 10499, NULL, NULL),
	(81, 0, 10500, NULL, NULL),
	(81, 0, 10501, NULL, NULL),
	(81, 0, 10502, NULL, NULL),
	(81, 0, 10503, NULL, NULL),
	(81, 0, 10504, NULL, NULL),
	(81, 0, 10505, NULL, NULL),
	(81, 0, 10506, NULL, NULL),
	(81, 0, 10507, NULL, NULL),
	(81, 0, 10508, NULL, NULL),
	(81, 0, 10509, NULL, NULL),
	(81, 0, 10510, NULL, NULL),
	(81, 0, 10511, NULL, NULL),
	(81, 0, 10512, NULL, NULL),
	(81, 0, 10513, NULL, NULL),
	(81, 0, 10514, NULL, NULL),
	(81, 0, 10515, NULL, NULL),
	(81, 0, 10516, NULL, NULL),
	(81, 0, 10517, NULL, NULL),
	(81, 0, 10518, NULL, NULL),
	(87, 0, 10400, NULL, NULL),
	(87, 0, 10401, NULL, NULL),
	(93, 1, 10009, NULL, NULL),
	(93, 1, 10038, NULL, NULL),
	(93, 1, 10045, NULL, NULL),
	(93, 1, 10066, NULL, NULL),
	(93, 1, 10321, NULL, NULL),
	(93, 1, 10322, NULL, NULL),
	(93, 1, 10402, NULL, NULL),
	(93, 1, 10403, NULL, NULL),
	(93, 1, 10404, NULL, NULL),
	(93, 1, 10405, NULL, NULL),
	(93, 1, 10406, NULL, NULL),
	(95, 1, 10000, NULL, NULL),
	(95, 1, 10001, NULL, NULL),
	(95, 1, 10002, NULL, NULL),
	(95, 1, 10015, NULL, NULL),
	(95, 1, 10029, NULL, NULL),
	(95, 1, 10038, NULL, NULL),
	(95, 1, 10041, NULL, NULL),
	(95, 1, 10085, NULL, NULL),
	(95, 1, 10102, NULL, NULL),
	(95, 1, 10103, NULL, NULL),
	(95, 1, 10104, NULL, NULL),
	(95, 1, 10105, NULL, NULL),
	(95, 1, 10106, NULL, NULL),
	(95, 1, 10107, NULL, NULL),
	(95, 1, 10109, NULL, NULL),
	(95, 1, 10291, NULL, NULL),
	(95, 1, 10407, NULL, NULL),
	(101, 0, 9999, NULL, NULL),
	(101, 0, 10000, NULL, NULL),
	(101, 0, 10001, NULL, NULL),
	(101, 0, 10002, NULL, NULL),
	(101, 0, 10008, NULL, NULL),
	(101, 0, 10009, NULL, NULL),
	(101, 0, 10014, NULL, NULL),
	(101, 0, 10021, NULL, NULL),
	(101, 0, 10022, NULL, NULL),
	(101, 0, 10039, NULL, NULL),
	(101, 0, 10040, NULL, NULL),
	(101, 0, 10041, NULL, NULL),
	(101, 0, 10042, NULL, NULL),
	(101, 0, 10045, NULL, NULL),
	(101, 0, 10048, NULL, NULL),
	(101, 0, 10049, NULL, NULL),
	(101, 0, 10088, NULL, NULL),
	(101, 0, 10108, NULL, NULL),
	(101, 0, 10209, NULL, NULL),
	(101, 0, 10273, NULL, NULL),
	(101, 0, 10274, NULL, NULL),
	(101, 0, 10407, NULL, NULL),
	(101, 0, 10414, NULL, NULL),
	(101, 0, 10415, NULL, NULL),
	(101, 0, 10416, NULL, NULL),
	(101, 0, 10417, NULL, NULL),
	(101, 0, 10418, NULL, NULL),
	(101, 0, 10419, NULL, NULL),
	(101, 0, 10420, NULL, NULL),
	(101, 0, 10421, NULL, NULL),
	(101, 0, 10422, NULL, NULL),
	(101, 0, 10423, NULL, NULL),
	(101, 0, 10424, NULL, NULL),
	(101, 0, 10425, NULL, NULL),
	(101, 0, 10426, NULL, NULL),
	(101, 0, 10427, NULL, NULL),
	(101, 0, 10428, NULL, NULL),
	(101, 0, 10429, NULL, NULL),
	(101, 0, 10430, NULL, NULL),
	(101, 0, 10431, NULL, NULL),
	(101, 0, 10432, NULL, NULL),
	(101, 0, 10433, NULL, NULL),
	(101, 0, 10434, NULL, NULL),
	(101, 0, 10435, NULL, NULL),
	(101, 0, 10436, NULL, NULL),
	(102, 0, 10045, NULL, NULL),
	(102, 0, 10078, NULL, NULL),
	(102, 0, 10213, NULL, NULL),
	(102, 0, 10254, NULL, NULL),
	(102, 0, 10255, NULL, NULL),
	(102, 0, 10409, NULL, NULL),
	(102, 0, 10410, NULL, NULL),
	(102, 0, 10411, NULL, NULL),
	(102, 0, 10412, NULL, NULL),
	(102, 0, 10413, NULL, NULL),
	(103, 1, 10000, NULL, NULL),
	(103, 1, 10001, NULL, NULL),
	(103, 1, 10002, NULL, NULL),
	(103, 1, 10008, NULL, NULL),
	(103, 1, 10009, NULL, NULL),
	(103, 1, 10012, NULL, NULL),
	(103, 1, 10014, NULL, NULL),
	(103, 1, 10021, NULL, NULL),
	(103, 1, 10022, NULL, NULL),
	(103, 1, 10039, NULL, NULL),
	(103, 1, 10040, NULL, NULL),
	(103, 1, 10041, NULL, NULL),
	(103, 1, 10042, NULL, NULL),
	(103, 1, 10045, NULL, NULL),
	(103, 1, 10048, NULL, NULL),
	(103, 1, 10049, NULL, NULL),
	(103, 1, 10088, NULL, NULL),
	(103, 1, 10108, NULL, NULL),
	(103, 1, 10274, NULL, NULL),
	(103, 1, 10407, NULL, NULL),
	(103, 1, 10414, NULL, NULL),
	(103, 1, 10415, NULL, NULL),
	(103, 1, 10416, NULL, NULL),
	(103, 1, 10417, NULL, NULL),
	(103, 1, 10418, NULL, NULL),
	(103, 1, 10419, NULL, NULL),
	(103, 1, 10420, NULL, NULL),
	(103, 1, 10421, NULL, NULL),
	(103, 1, 10422, NULL, NULL),
	(103, 1, 10423, NULL, NULL),
	(103, 1, 10424, NULL, NULL),
	(103, 1, 10425, NULL, NULL),
	(103, 1, 10426, NULL, NULL),
	(103, 1, 10427, NULL, NULL),
	(103, 1, 10428, NULL, NULL),
	(103, 1, 10429, NULL, NULL),
	(103, 1, 10430, NULL, NULL),
	(103, 1, 10431, NULL, NULL),
	(103, 1, 10432, NULL, NULL),
	(103, 1, 10433, NULL, NULL),
	(103, 1, 10434, NULL, NULL),
	(103, 1, 10435, NULL, NULL),
	(103, 1, 10436, NULL, NULL),
	(103, 1, 10597, NULL, NULL),
	(104, 1, 10029, NULL, NULL),
	(104, 1, 10038, NULL, NULL),
	(104, 1, 10050, NULL, NULL),
	(104, 1, 10063, NULL, NULL),
	(104, 1, 10292, NULL, NULL),
	(104, 1, 10519, NULL, NULL),
	(104, 1, 10520, NULL, NULL),
	(104, 1, 10521, NULL, NULL),
	(104, 1, 10522, NULL, NULL),
	(104, 1, 10523, NULL, NULL),
	(104, 1, 10524, NULL, NULL),
	(104, 1, 10525, NULL, NULL),
	(104, 1, 10526, NULL, NULL),
	(117, 0, 10400, NULL, NULL),
	(117, 0, 10401, NULL, NULL),
	(118, 0, 10400, NULL, NULL),
	(118, 0, 10401, NULL, NULL),
	(127, 1, 10000, NULL, NULL),
	(127, 1, 10001, NULL, NULL),
	(127, 1, 10002, NULL, NULL),
	(127, 1, 10003, NULL, NULL),
	(127, 1, 10007, NULL, 0),
	(127, 1, 10009, NULL, 0),
	(127, 1, 10010, NULL, 0),
	(127, 1, 10012, NULL, 0),
	(127, 1, 10014, NULL, 0),
	(127, 1, 10017, 0, NULL),
	(127, 1, 10018, 0, NULL),
	(127, 1, 10029, 0, NULL),
	(127, 1, 10109, NULL, 0),
	(127, 1, 10586, 0, NULL),
	(127, 1, 10587, NULL, 0),
	(127, 1, 10588, NULL, 0),
	(127, 1, 10589, NULL, 0),
	(127, 1, 10590, NULL, 0),
	(127, 1, 10591, NULL, 0),
	(127, 1, 10592, NULL, 0),
	(127, 1, 10593, NULL, 0),
	(127, 1, 10594, NULL, 0),
	(127, 1, 10595, NULL, 0),
	(127, 1, 10596, NULL, 0),
	(127, 1, 10597, NULL, 0),
	(127, 1, 10598, NULL, 0),
	(127, 1, 10599, NULL, 0),
	(127, 1, 10600, NULL, 0),
	(127, 1, 10602, NULL, 0),
	(127, 1, 10603, NULL, 0),
	(127, 1, 10604, NULL, 0),
	(127, 1, 10605, NULL, 0),
	(127, 1, 10606, NULL, 0),
	(128, 0, -1, NULL, NULL),
	(128, 0, 9999, NULL, NULL),
	(128, 0, 10000, NULL, NULL),
	(128, 0, 10001, NULL, NULL),
	(128, 0, 10002, NULL, NULL),
	(128, 0, 10003, NULL, NULL),
	(128, 0, 10004, NULL, NULL),
	(128, 0, 10005, NULL, NULL),
	(128, 0, 10006, NULL, NULL),
	(128, 0, 10007, NULL, NULL),
	(128, 0, 10008, NULL, NULL),
	(128, 0, 10009, NULL, NULL),
	(128, 0, 10010, NULL, NULL),
	(128, 0, 10011, NULL, NULL),
	(128, 0, 10012, NULL, NULL),
	(128, 0, 10013, NULL, NULL),
	(128, 0, 10014, NULL, NULL),
	(128, 0, 10015, NULL, NULL),
	(128, 0, 10016, NULL, NULL),
	(128, 0, 10017, NULL, NULL),
	(128, 0, 10018, NULL, NULL),
	(128, 0, 10019, NULL, NULL),
	(128, 0, 10020, NULL, NULL),
	(128, 0, 10021, NULL, NULL),
	(128, 0, 10022, NULL, NULL),
	(128, 0, 10023, NULL, NULL),
	(128, 0, 10024, NULL, NULL),
	(128, 0, 10025, NULL, NULL),
	(128, 0, 10026, NULL, NULL),
	(128, 0, 10027, NULL, NULL),
	(128, 0, 10028, NULL, NULL),
	(128, 0, 10029, NULL, NULL),
	(128, 0, 10030, NULL, NULL),
	(128, 0, 10031, NULL, NULL),
	(128, 0, 10032, NULL, NULL),
	(128, 0, 10033, NULL, NULL),
	(128, 0, 10034, NULL, NULL),
	(128, 0, 10035, NULL, NULL),
	(128, 0, 10036, NULL, NULL),
	(128, 0, 10037, NULL, NULL),
	(128, 0, 10038, NULL, NULL),
	(128, 0, 10039, NULL, NULL),
	(128, 0, 10040, NULL, NULL),
	(128, 0, 10041, NULL, NULL),
	(128, 0, 10042, NULL, NULL),
	(128, 0, 10043, NULL, NULL),
	(128, 0, 10044, NULL, NULL),
	(128, 0, 10045, NULL, NULL),
	(128, 0, 10046, NULL, NULL),
	(128, 0, 10047, NULL, NULL),
	(128, 0, 10048, NULL, NULL),
	(128, 0, 10049, NULL, NULL),
	(128, 0, 10050, NULL, NULL),
	(128, 0, 10051, NULL, NULL),
	(128, 0, 10052, NULL, NULL),
	(128, 0, 10053, NULL, NULL),
	(128, 0, 10054, NULL, NULL),
	(128, 0, 10055, NULL, NULL),
	(128, 0, 10056, NULL, NULL),
	(128, 0, 10057, NULL, NULL),
	(128, 0, 10058, NULL, NULL),
	(128, 0, 10059, NULL, NULL),
	(128, 0, 10060, NULL, NULL),
	(128, 0, 10061, NULL, NULL),
	(128, 0, 10062, NULL, NULL),
	(128, 0, 10063, NULL, NULL),
	(128, 0, 10064, NULL, NULL),
	(128, 0, 10065, NULL, NULL),
	(128, 0, 10066, NULL, NULL),
	(128, 0, 10067, NULL, NULL),
	(128, 0, 10068, NULL, NULL),
	(128, 0, 10069, NULL, NULL),
	(128, 0, 10070, NULL, NULL),
	(128, 0, 10071, NULL, NULL),
	(128, 0, 10072, NULL, NULL),
	(128, 0, 10073, NULL, NULL),
	(128, 0, 10074, NULL, NULL),
	(128, 0, 10075, NULL, NULL),
	(128, 0, 10076, NULL, NULL),
	(128, 0, 10077, NULL, NULL),
	(128, 0, 10078, NULL, NULL),
	(128, 0, 10079, NULL, NULL),
	(128, 0, 10080, NULL, NULL),
	(128, 0, 10081, NULL, NULL),
	(128, 0, 10082, NULL, NULL),
	(128, 0, 10083, NULL, NULL),
	(128, 0, 10084, NULL, NULL),
	(128, 0, 10085, NULL, NULL),
	(128, 0, 10086, NULL, NULL),
	(128, 0, 10087, NULL, NULL),
	(128, 0, 10088, NULL, NULL),
	(128, 0, 10089, NULL, NULL),
	(128, 0, 10090, NULL, NULL),
	(128, 0, 10091, NULL, NULL),
	(128, 0, 10092, NULL, NULL),
	(128, 0, 10093, NULL, NULL),
	(128, 0, 10094, NULL, NULL),
	(128, 0, 10095, NULL, NULL),
	(128, 0, 10096, NULL, NULL),
	(128, 0, 10097, NULL, NULL),
	(128, 0, 10098, NULL, NULL),
	(128, 0, 10099, NULL, NULL),
	(128, 0, 10100, NULL, NULL),
	(128, 0, 10101, NULL, NULL),
	(128, 0, 10102, NULL, NULL),
	(128, 0, 10103, NULL, NULL),
	(128, 0, 10104, NULL, NULL),
	(128, 0, 10105, NULL, NULL),
	(128, 0, 10106, NULL, NULL),
	(128, 0, 10107, NULL, NULL),
	(128, 0, 10108, NULL, NULL),
	(128, 0, 10109, NULL, NULL),
	(128, 0, 10110, NULL, NULL),
	(128, 0, 10111, NULL, NULL),
	(128, 0, 10112, NULL, NULL),
	(128, 0, 10113, NULL, NULL),
	(128, 0, 10114, NULL, NULL),
	(128, 0, 10115, NULL, NULL),
	(128, 0, 10116, NULL, NULL),
	(128, 0, 10117, NULL, NULL),
	(128, 0, 10118, NULL, NULL),
	(128, 0, 10119, NULL, NULL),
	(128, 0, 10120, NULL, NULL),
	(128, 0, 10121, NULL, NULL),
	(128, 0, 10122, NULL, NULL),
	(128, 0, 10123, NULL, NULL),
	(128, 0, 10124, NULL, NULL),
	(128, 0, 10125, NULL, NULL),
	(128, 0, 10126, NULL, NULL),
	(128, 0, 10127, NULL, NULL),
	(128, 0, 10128, NULL, NULL),
	(128, 0, 10129, NULL, NULL),
	(128, 0, 10130, NULL, NULL),
	(128, 0, 10131, NULL, NULL),
	(128, 0, 10132, NULL, NULL),
	(128, 0, 10133, NULL, NULL),
	(128, 0, 10134, NULL, NULL),
	(128, 0, 10135, NULL, NULL),
	(128, 0, 10136, NULL, NULL),
	(128, 0, 10137, NULL, NULL),
	(128, 0, 10138, NULL, NULL),
	(128, 0, 10139, NULL, NULL),
	(128, 0, 10140, NULL, NULL),
	(128, 0, 10141, NULL, NULL),
	(128, 0, 10142, NULL, NULL),
	(128, 0, 10143, NULL, NULL),
	(128, 0, 10144, NULL, NULL),
	(128, 0, 10145, NULL, NULL),
	(128, 0, 10146, NULL, NULL),
	(128, 0, 10147, NULL, NULL),
	(128, 0, 10148, NULL, NULL),
	(128, 0, 10149, NULL, NULL),
	(128, 0, 10150, NULL, NULL),
	(128, 0, 10151, NULL, NULL),
	(128, 0, 10152, NULL, NULL),
	(128, 0, 10153, NULL, NULL),
	(128, 0, 10154, NULL, NULL),
	(128, 0, 10155, NULL, NULL),
	(128, 0, 10156, NULL, NULL),
	(128, 0, 10157, NULL, NULL),
	(128, 0, 10158, NULL, NULL),
	(128, 0, 10159, NULL, NULL),
	(128, 0, 10160, NULL, NULL),
	(128, 0, 10161, NULL, NULL),
	(128, 0, 10162, NULL, NULL),
	(128, 0, 10163, NULL, NULL),
	(128, 0, 10164, NULL, NULL),
	(128, 0, 10165, NULL, NULL),
	(128, 0, 10166, NULL, NULL),
	(128, 0, 10167, NULL, NULL),
	(128, 0, 10168, NULL, NULL),
	(128, 0, 10169, NULL, NULL),
	(128, 0, 10170, NULL, NULL),
	(128, 0, 10171, NULL, NULL),
	(128, 0, 10172, NULL, NULL),
	(128, 0, 10173, NULL, NULL),
	(128, 0, 10174, NULL, NULL),
	(128, 0, 10175, NULL, NULL),
	(128, 0, 10176, NULL, NULL),
	(128, 0, 10177, NULL, NULL),
	(128, 0, 10178, NULL, NULL),
	(128, 0, 10179, NULL, NULL),
	(128, 0, 10180, NULL, NULL),
	(128, 0, 10181, NULL, NULL),
	(128, 0, 10182, NULL, NULL),
	(128, 0, 10183, NULL, NULL),
	(128, 0, 10184, NULL, NULL),
	(128, 0, 10185, NULL, NULL),
	(128, 0, 10186, NULL, NULL),
	(128, 0, 10187, NULL, NULL),
	(128, 0, 10188, NULL, NULL),
	(128, 0, 10189, NULL, NULL),
	(128, 0, 10190, NULL, NULL),
	(128, 0, 10191, NULL, NULL),
	(128, 0, 10192, NULL, NULL),
	(128, 0, 10193, NULL, NULL),
	(128, 0, 10194, NULL, NULL),
	(128, 0, 10195, NULL, NULL),
	(128, 0, 10196, NULL, NULL),
	(128, 0, 10197, NULL, NULL),
	(128, 0, 10198, NULL, NULL),
	(128, 0, 10199, NULL, NULL),
	(128, 0, 10200, NULL, NULL),
	(128, 0, 10201, NULL, NULL),
	(128, 0, 10202, NULL, NULL),
	(128, 0, 10203, NULL, NULL),
	(128, 0, 10204, NULL, NULL),
	(128, 0, 10205, NULL, NULL),
	(128, 0, 10206, NULL, NULL),
	(128, 0, 10207, NULL, NULL),
	(128, 0, 10208, NULL, NULL),
	(128, 0, 10209, NULL, NULL),
	(128, 0, 10210, NULL, NULL),
	(128, 0, 10211, NULL, NULL),
	(128, 0, 10212, NULL, NULL),
	(128, 0, 10213, NULL, NULL),
	(128, 0, 10214, NULL, NULL),
	(128, 0, 10215, NULL, NULL),
	(128, 0, 10216, NULL, NULL),
	(128, 0, 10217, NULL, NULL),
	(128, 0, 10218, NULL, NULL),
	(128, 0, 10219, NULL, NULL),
	(128, 0, 10220, NULL, NULL),
	(128, 0, 10221, NULL, NULL),
	(128, 0, 10222, NULL, NULL),
	(128, 0, 10223, NULL, NULL),
	(128, 0, 10224, NULL, NULL),
	(128, 0, 10225, NULL, NULL),
	(128, 0, 10226, NULL, NULL),
	(128, 0, 10227, NULL, NULL),
	(128, 0, 10228, NULL, NULL),
	(128, 0, 10229, NULL, NULL),
	(128, 0, 10230, NULL, NULL),
	(128, 0, 10231, NULL, NULL),
	(128, 0, 10232, NULL, NULL),
	(128, 0, 10233, NULL, NULL),
	(128, 0, 10234, NULL, NULL),
	(128, 0, 10235, NULL, NULL),
	(128, 0, 10236, NULL, NULL),
	(128, 0, 10237, NULL, NULL),
	(128, 0, 10238, NULL, NULL),
	(128, 0, 10239, NULL, NULL),
	(128, 0, 10240, NULL, NULL),
	(128, 0, 10241, NULL, NULL),
	(128, 0, 10242, NULL, NULL),
	(128, 0, 10243, NULL, NULL),
	(128, 0, 10244, NULL, NULL),
	(128, 0, 10245, NULL, NULL),
	(128, 0, 10246, NULL, NULL),
	(128, 0, 10247, NULL, NULL),
	(128, 0, 10248, NULL, NULL),
	(128, 0, 10249, NULL, NULL),
	(128, 0, 10252, NULL, NULL),
	(128, 0, 10253, NULL, NULL),
	(128, 0, 10254, NULL, NULL),
	(128, 0, 10255, NULL, NULL),
	(128, 0, 10256, NULL, NULL),
	(128, 0, 10257, NULL, NULL),
	(128, 0, 10258, NULL, NULL),
	(128, 0, 10259, NULL, NULL),
	(128, 0, 10260, NULL, NULL),
	(128, 0, 10261, NULL, NULL),
	(128, 0, 10262, NULL, NULL),
	(128, 0, 10263, NULL, NULL),
	(128, 0, 10264, NULL, NULL),
	(128, 0, 10265, NULL, NULL),
	(128, 0, 10266, NULL, NULL),
	(128, 0, 10267, NULL, NULL),
	(128, 0, 10268, NULL, NULL),
	(128, 0, 10269, NULL, NULL),
	(128, 0, 10270, NULL, NULL),
	(128, 0, 10271, NULL, NULL),
	(128, 0, 10272, NULL, NULL),
	(128, 0, 10273, NULL, NULL),
	(128, 0, 10274, NULL, NULL),
	(128, 0, 10275, NULL, NULL),
	(128, 0, 10276, NULL, NULL),
	(128, 0, 10284, NULL, NULL),
	(128, 0, 10291, NULL, NULL),
	(128, 0, 10292, NULL, NULL),
	(128, 0, 10293, NULL, NULL),
	(128, 0, 10294, NULL, NULL),
	(128, 0, 10295, NULL, NULL),
	(128, 0, 10296, NULL, NULL),
	(128, 0, 10297, NULL, NULL),
	(128, 0, 10298, NULL, NULL),
	(128, 0, 10299, NULL, NULL),
	(128, 0, 10300, NULL, NULL),
	(128, 0, 10301, NULL, NULL),
	(128, 0, 10302, NULL, NULL),
	(128, 0, 10303, NULL, NULL),
	(128, 0, 10304, NULL, NULL),
	(128, 0, 10305, NULL, NULL),
	(128, 0, 10306, NULL, NULL),
	(128, 0, 10307, NULL, NULL),
	(128, 0, 10308, NULL, NULL),
	(128, 0, 10309, NULL, NULL),
	(128, 0, 10310, NULL, NULL),
	(128, 0, 10311, NULL, NULL),
	(128, 0, 10312, NULL, NULL),
	(128, 0, 10313, NULL, NULL),
	(128, 0, 10314, NULL, NULL),
	(128, 0, 10315, NULL, NULL),
	(128, 0, 10316, NULL, NULL),
	(128, 0, 10317, NULL, NULL),
	(128, 0, 10318, NULL, NULL),
	(128, 0, 10319, NULL, NULL),
	(128, 0, 10320, NULL, NULL),
	(128, 0, 10321, NULL, NULL),
	(128, 0, 10322, NULL, NULL),
	(128, 0, 10323, NULL, NULL),
	(128, 0, 10324, NULL, NULL),
	(128, 0, 10325, NULL, NULL),
	(128, 0, 10326, NULL, NULL),
	(128, 0, 10327, NULL, NULL),
	(128, 0, 10328, NULL, NULL),
	(128, 0, 10329, NULL, NULL),
	(128, 0, 10330, NULL, NULL),
	(128, 0, 10331, NULL, NULL),
	(128, 0, 10332, NULL, NULL),
	(128, 0, 10333, NULL, NULL),
	(128, 0, 10334, NULL, NULL),
	(128, 0, 10335, NULL, NULL),
	(128, 0, 10336, NULL, NULL),
	(128, 0, 10337, NULL, NULL),
	(128, 0, 10338, NULL, NULL),
	(128, 0, 10339, NULL, NULL),
	(128, 0, 10340, NULL, NULL),
	(128, 0, 10341, NULL, NULL),
	(128, 0, 10342, NULL, NULL),
	(128, 0, 10343, NULL, NULL),
	(128, 0, 10344, NULL, NULL),
	(128, 0, 10345, NULL, NULL),
	(128, 0, 10346, NULL, NULL),
	(128, 0, 10347, NULL, NULL),
	(128, 0, 10348, NULL, NULL),
	(128, 0, 10349, NULL, NULL),
	(128, 0, 10350, NULL, NULL),
	(128, 0, 10351, NULL, NULL),
	(128, 0, 10400, NULL, NULL),
	(128, 0, 10401, NULL, NULL),
	(128, 0, 10402, NULL, NULL),
	(128, 0, 10403, NULL, NULL),
	(128, 0, 10404, NULL, NULL),
	(128, 0, 10405, NULL, NULL),
	(128, 0, 10406, NULL, NULL),
	(128, 0, 10407, NULL, NULL),
	(128, 0, 10409, NULL, NULL),
	(128, 0, 10410, NULL, NULL),
	(128, 0, 10411, NULL, NULL),
	(128, 0, 10412, NULL, NULL),
	(128, 0, 10413, NULL, NULL),
	(128, 0, 10414, NULL, NULL),
	(128, 0, 10415, NULL, NULL),
	(128, 0, 10416, NULL, NULL),
	(128, 0, 10417, NULL, NULL),
	(128, 0, 10418, NULL, NULL),
	(128, 0, 10419, NULL, NULL),
	(128, 0, 10420, NULL, NULL),
	(128, 0, 10421, NULL, NULL),
	(128, 0, 10422, NULL, NULL),
	(128, 0, 10423, NULL, NULL),
	(128, 0, 10424, NULL, NULL),
	(128, 0, 10425, NULL, NULL),
	(128, 0, 10426, NULL, NULL),
	(128, 0, 10427, NULL, NULL),
	(128, 0, 10428, NULL, NULL),
	(128, 0, 10429, NULL, NULL),
	(128, 0, 10430, NULL, NULL),
	(128, 0, 10431, NULL, NULL),
	(128, 0, 10432, NULL, NULL),
	(128, 0, 10433, NULL, NULL),
	(128, 0, 10434, NULL, NULL),
	(128, 0, 10435, NULL, NULL),
	(128, 0, 10436, NULL, NULL),
	(128, 0, 10437, NULL, NULL),
	(128, 0, 10438, NULL, NULL),
	(128, 0, 10439, NULL, NULL),
	(128, 0, 10440, NULL, NULL),
	(128, 0, 10441, NULL, NULL),
	(128, 0, 10442, NULL, NULL),
	(128, 0, 10443, NULL, NULL),
	(128, 0, 10444, NULL, NULL),
	(128, 0, 10445, NULL, NULL),
	(128, 0, 10446, NULL, NULL),
	(128, 0, 10447, NULL, NULL),
	(128, 0, 10448, NULL, NULL),
	(128, 0, 10449, NULL, NULL),
	(128, 0, 10450, NULL, NULL),
	(128, 0, 10451, NULL, NULL),
	(128, 0, 10452, NULL, NULL),
	(128, 0, 10453, NULL, NULL),
	(128, 0, 10454, NULL, NULL),
	(128, 0, 10455, NULL, NULL),
	(128, 0, 10456, NULL, NULL),
	(128, 0, 10457, NULL, NULL),
	(128, 0, 10458, NULL, NULL),
	(128, 0, 10459, NULL, NULL),
	(128, 0, 10460, NULL, NULL),
	(128, 0, 10461, NULL, NULL),
	(128, 0, 10462, NULL, NULL),
	(128, 0, 10463, NULL, NULL),
	(128, 0, 10464, NULL, NULL),
	(128, 0, 10465, NULL, NULL),
	(128, 0, 10466, NULL, NULL),
	(128, 0, 10467, NULL, NULL),
	(128, 0, 10468, NULL, NULL),
	(128, 0, 10469, NULL, NULL),
	(128, 0, 10470, NULL, NULL),
	(128, 0, 10471, NULL, NULL),
	(128, 0, 10472, NULL, NULL),
	(128, 0, 10473, NULL, NULL),
	(128, 0, 10474, NULL, NULL),
	(128, 0, 10475, NULL, NULL),
	(128, 0, 10476, NULL, NULL),
	(128, 0, 10477, NULL, NULL),
	(128, 0, 10478, NULL, NULL),
	(128, 0, 10479, NULL, NULL),
	(128, 0, 10480, NULL, NULL),
	(128, 0, 10481, NULL, NULL),
	(128, 0, 10482, NULL, NULL),
	(128, 0, 10483, NULL, NULL),
	(128, 0, 10484, NULL, NULL),
	(128, 0, 10485, NULL, NULL),
	(128, 0, 10486, NULL, NULL),
	(128, 0, 10487, NULL, NULL),
	(128, 0, 10488, NULL, NULL),
	(128, 0, 10489, NULL, NULL),
	(128, 0, 10490, NULL, NULL),
	(128, 0, 10491, NULL, NULL),
	(128, 0, 10492, NULL, NULL),
	(128, 0, 10493, NULL, NULL),
	(128, 0, 10494, NULL, NULL),
	(128, 0, 10495, NULL, NULL),
	(128, 0, 10496, NULL, NULL),
	(128, 0, 10497, NULL, NULL),
	(128, 0, 10498, NULL, NULL),
	(128, 0, 10499, NULL, NULL),
	(128, 0, 10500, NULL, NULL),
	(128, 0, 10501, NULL, NULL),
	(128, 0, 10502, NULL, NULL),
	(128, 0, 10503, NULL, NULL),
	(128, 0, 10504, NULL, NULL),
	(128, 0, 10505, NULL, NULL),
	(128, 0, 10506, NULL, NULL),
	(128, 0, 10507, NULL, NULL),
	(128, 0, 10508, NULL, NULL),
	(128, 0, 10509, NULL, NULL),
	(128, 0, 10510, NULL, NULL),
	(128, 0, 10511, NULL, NULL),
	(128, 0, 10512, NULL, NULL),
	(128, 0, 10513, NULL, NULL),
	(128, 0, 10514, NULL, NULL),
	(128, 0, 10515, NULL, NULL),
	(128, 0, 10516, NULL, NULL),
	(128, 0, 10517, NULL, NULL),
	(128, 0, 10518, NULL, NULL),
	(128, 0, 10519, NULL, NULL),
	(128, 0, 10520, NULL, NULL),
	(128, 0, 10521, NULL, NULL),
	(128, 0, 10522, NULL, NULL),
	(128, 0, 10523, NULL, NULL),
	(128, 0, 10524, NULL, NULL),
	(128, 0, 10525, NULL, NULL),
	(128, 0, 10526, NULL, NULL),
	(128, 0, 10527, NULL, NULL),
	(128, 0, 10528, NULL, NULL),
	(128, 0, 10529, NULL, NULL),
	(128, 0, 10530, NULL, NULL),
	(128, 0, 10531, NULL, NULL),
	(128, 0, 10532, NULL, NULL),
	(128, 0, 10533, NULL, NULL),
	(128, 0, 10534, NULL, NULL),
	(128, 0, 10535, NULL, NULL),
	(128, 0, 10536, NULL, NULL),
	(128, 0, 10537, NULL, NULL),
	(128, 0, 10538, NULL, NULL),
	(128, 0, 10539, NULL, NULL),
	(128, 0, 10540, NULL, NULL),
	(128, 0, 10541, NULL, NULL),
	(128, 0, 10542, NULL, NULL),
	(128, 0, 10543, NULL, NULL),
	(128, 0, 10544, NULL, NULL),
	(128, 0, 10545, NULL, NULL),
	(128, 0, 10546, NULL, NULL),
	(128, 0, 10547, NULL, NULL),
	(128, 0, 10548, NULL, NULL),
	(128, 0, 10549, NULL, NULL),
	(128, 0, 10550, NULL, NULL),
	(128, 0, 10551, NULL, NULL),
	(128, 0, 10552, NULL, NULL),
	(128, 0, 10553, NULL, NULL),
	(128, 0, 10554, NULL, NULL),
	(128, 0, 10555, NULL, NULL),
	(128, 0, 10556, NULL, NULL),
	(128, 0, 10557, NULL, NULL),
	(128, 0, 10558, NULL, NULL),
	(128, 0, 10559, NULL, NULL),
	(128, 0, 10560, NULL, NULL),
	(128, 0, 10561, NULL, NULL),
	(128, 0, 10562, NULL, NULL),
	(128, 0, 10563, NULL, NULL),
	(128, 0, 10564, NULL, NULL),
	(128, 0, 10565, NULL, NULL),
	(128, 0, 10566, NULL, NULL),
	(128, 0, 10567, NULL, NULL),
	(128, 0, 10568, NULL, NULL),
	(128, 0, 10569, NULL, NULL),
	(128, 0, 10570, NULL, NULL),
	(128, 0, 10571, NULL, NULL),
	(128, 0, 10572, NULL, NULL),
	(128, 0, 10573, NULL, NULL),
	(128, 0, 10574, NULL, NULL),
	(128, 0, 10575, NULL, NULL),
	(128, 0, 10576, NULL, NULL),
	(128, 0, 10577, NULL, NULL),
	(128, 0, 10578, NULL, NULL),
	(128, 0, 10579, NULL, NULL),
	(128, 0, 10580, NULL, NULL),
	(128, 0, 10581, NULL, NULL),
	(128, 0, 10582, NULL, NULL),
	(128, 0, 10583, NULL, NULL),
	(128, 0, 10584, NULL, NULL),
	(128, 0, 10585, NULL, NULL),
	(128, 0, 10586, NULL, NULL),
	(128, 0, 10587, NULL, NULL),
	(128, 0, 10588, NULL, NULL),
	(128, 0, 10589, NULL, NULL),
	(128, 0, 10590, NULL, NULL),
	(128, 0, 10591, NULL, NULL),
	(128, 0, 10592, NULL, NULL),
	(128, 0, 10593, NULL, NULL),
	(128, 0, 10594, NULL, NULL),
	(128, 0, 10595, NULL, NULL),
	(128, 0, 10596, NULL, NULL),
	(128, 0, 10597, NULL, NULL),
	(128, 0, 10598, NULL, NULL),
	(128, 0, 10599, NULL, NULL),
	(128, 0, 10600, NULL, NULL),
	(128, 0, 10602, NULL, NULL),
	(128, 0, 10603, NULL, NULL),
	(128, 0, 10604, NULL, NULL),
	(128, 0, 10605, NULL, NULL),
	(128, 0, 10606, NULL, NULL),
	(128, 0, 10607, NULL, NULL),
	(128, 0, 10608, NULL, NULL),
	(128, 0, 10609, NULL, NULL),
	(128, 0, 10610, NULL, NULL),
	(128, 0, 10611, NULL, NULL),
	(128, 0, 10612, NULL, NULL),
	(128, 0, 10613, NULL, NULL),
	(128, 0, 10614, NULL, NULL),
	(128, 0, 10615, NULL, NULL),
	(128, 0, 10616, NULL, NULL),
	(128, 0, 10617, NULL, NULL),
	(128, 0, 10618, NULL, NULL),
	(128, 0, 10619, NULL, NULL),
	(128, 0, 10620, NULL, NULL),
	(128, 0, 10621, NULL, NULL),
	(128, 0, 10622, NULL, NULL),
	(128, 0, 10623, NULL, NULL),
	(128, 0, 10624, NULL, NULL),
	(128, 0, 10625, NULL, NULL),
	(128, 0, 10626, NULL, NULL),
	(128, 0, 10627, NULL, NULL),
	(128, 0, 10628, NULL, NULL),
	(128, 0, 10629, NULL, NULL),
	(128, 0, 10630, NULL, NULL),
	(128, 0, 10631, NULL, NULL),
	(128, 0, 10632, NULL, NULL),
	(128, 0, 10633, NULL, NULL),
	(128, 0, 10634, NULL, NULL),
	(128, 0, 10635, NULL, NULL),
	(128, 0, 10636, NULL, NULL),
	(128, 0, 10637, NULL, NULL),
	(128, 0, 10638, NULL, NULL),
	(128, 0, 10639, NULL, NULL),
	(128, 0, 10640, NULL, NULL),
	(128, 0, 10641, NULL, NULL),
	(128, 0, 10642, NULL, NULL),
	(128, 0, 10643, NULL, NULL),
	(128, 0, 10644, NULL, NULL),
	(128, 0, 10645, NULL, NULL),
	(128, 0, 10646, NULL, NULL),
	(128, 0, 10647, NULL, NULL),
	(128, 0, 10648, NULL, NULL),
	(128, 0, 10649, NULL, NULL),
	(128, 0, 10650, NULL, NULL),
	(128, 0, 10651, NULL, NULL),
	(128, 0, 10652, NULL, NULL),
	(128, 0, 10653, NULL, NULL),
	(128, 0, 10654, NULL, NULL),
	(128, 0, 10655, NULL, NULL),
	(128, 0, 10656, NULL, NULL),
	(128, 0, 10657, NULL, NULL),
	(128, 0, 10658, NULL, NULL),
	(128, 0, 10659, NULL, NULL),
	(128, 0, 10660, NULL, NULL),
	(128, 0, 10661, NULL, NULL),
	(128, 0, 10662, NULL, NULL),
	(128, 0, 10663, NULL, NULL),
	(128, 0, 10664, NULL, NULL),
	(128, 0, 10665, NULL, NULL),
	(128, 0, 10668, NULL, NULL),
	(128, 0, 10669, NULL, NULL),
	(128, 0, 10674, NULL, NULL),
	(128, 0, 10675, NULL, NULL),
	(128, 0, 10676, NULL, NULL),
	(128, 0, 10677, NULL, NULL),
	(128, 0, 10678, NULL, NULL),
	(128, 0, 10679, NULL, NULL),
	(128, 0, 10680, NULL, NULL),
	(128, 0, 10682, NULL, NULL),
	(128, 0, 10685, NULL, NULL),
	(128, 0, 10686, NULL, NULL),
	(128, 0, 10687, NULL, NULL),
	(128, 0, 10689, NULL, NULL),
	(128, 0, 10690, NULL, NULL),
	(128, 0, 10691, NULL, NULL),
	(128, 0, 10692, NULL, NULL),
	(128, 0, 10693, NULL, NULL),
	(128, 0, 10694, NULL, NULL),
	(128, 0, 10695, NULL, NULL),
	(128, 0, 10696, NULL, NULL),
	(128, 0, 10697, NULL, NULL),
	(128, 0, 10698, NULL, NULL),
	(128, 0, 10699, NULL, NULL),
	(128, 0, 10700, NULL, NULL),
	(128, 0, 10701, NULL, NULL),
	(128, 0, 10702, NULL, NULL),
	(128, 0, 10703, NULL, NULL),
	(128, 0, 10704, NULL, NULL),
	(128, 0, 10705, NULL, NULL),
	(128, 0, 10706, NULL, NULL),
	(128, 0, 10707, NULL, NULL),
	(128, 0, 10708, NULL, NULL),
	(128, 0, 10709, NULL, NULL),
	(128, 0, 10710, NULL, NULL),
	(128, 0, 10711, NULL, NULL),
	(128, 0, 10712, NULL, NULL),
	(128, 0, 10713, NULL, NULL),
	(128, 0, 10714, NULL, NULL),
	(128, 0, 10715, NULL, NULL),
	(128, 0, 10716, NULL, NULL),
	(128, 0, 10717, NULL, NULL),
	(128, 0, 10718, NULL, NULL),
	(128, 0, 10719, NULL, NULL),
	(128, 0, 10720, NULL, NULL),
	(128, 0, 10721, NULL, NULL),
	(128, 0, 10722, NULL, NULL),
	(128, 0, 10723, NULL, NULL),
	(128, 0, 10724, NULL, NULL),
	(128, 0, 10725, NULL, NULL),
	(128, 0, 10726, NULL, NULL),
	(128, 0, 10727, NULL, NULL),
	(128, 0, 10728, NULL, NULL),
	(128, 0, 10729, NULL, NULL),
	(128, 0, 10730, NULL, NULL),
	(128, 0, 10731, NULL, NULL),
	(128, 0, 10732, NULL, NULL),
	(128, 0, 10733, NULL, NULL),
	(128, 0, 10734, NULL, NULL),
	(128, 0, 10735, NULL, NULL),
	(128, 0, 10736, NULL, NULL),
	(128, 0, 10737, NULL, NULL),
	(128, 0, 10738, NULL, NULL),
	(128, 0, 10739, NULL, NULL),
	(128, 0, 10740, NULL, NULL),
	(128, 0, 10741, NULL, NULL),
	(128, 0, 10742, NULL, NULL),
	(128, 0, 10743, NULL, NULL),
	(128, 0, 10744, NULL, NULL),
	(128, 0, 10745, NULL, NULL),
	(128, 0, 10746, NULL, NULL),
	(128, 0, 10747, NULL, NULL),
	(128, 0, 10748, NULL, NULL),
	(128, 0, 10749, NULL, NULL),
	(128, 0, 10750, NULL, NULL),
	(128, 0, 10751, NULL, NULL),
	(128, 0, 10752, NULL, NULL),
	(128, 0, 10753, NULL, NULL),
	(128, 0, 10754, NULL, NULL),
	(128, 0, 10755, NULL, NULL),
	(128, 0, 10756, NULL, NULL),
	(128, 0, 10757, NULL, NULL),
	(128, 0, 10758, NULL, NULL),
	(128, 0, 10759, NULL, NULL),
	(128, 0, 10760, NULL, NULL),
	(128, 0, 10761, NULL, NULL),
	(128, 0, 10762, NULL, NULL),
	(128, 0, 10763, NULL, NULL),
	(128, 0, 10764, NULL, NULL),
	(128, 0, 10765, NULL, NULL),
	(128, 0, 10766, NULL, NULL),
	(128, 0, 10767, NULL, NULL),
	(128, 0, 10768, NULL, NULL),
	(128, 0, 10769, NULL, NULL),
	(128, 0, 10770, NULL, NULL),
	(128, 0, 10771, NULL, NULL),
	(128, 0, 10772, NULL, NULL),
	(128, 0, 10773, NULL, NULL),
	(128, 0, 10774, NULL, NULL),
	(128, 0, 10775, NULL, NULL),
	(128, 0, 10776, NULL, NULL),
	(128, 0, 10777, NULL, NULL),
	(128, 0, 10778, NULL, NULL),
	(128, 0, 10779, NULL, NULL),
	(128, 0, 10780, NULL, NULL),
	(128, 0, 10781, NULL, NULL),
	(128, 0, 10782, NULL, NULL),
	(128, 0, 10783, NULL, NULL),
	(128, 0, 10784, NULL, NULL),
	(128, 0, 10785, NULL, NULL),
	(128, 0, 10786, NULL, NULL),
	(128, 0, 10787, NULL, NULL),
	(128, 0, 10788, NULL, NULL),
	(128, 0, 10789, NULL, NULL),
	(128, 0, 10790, NULL, NULL),
	(128, 0, 10791, NULL, NULL),
	(128, 0, 10792, NULL, NULL),
	(128, 0, 10793, NULL, NULL),
	(128, 0, 10794, NULL, NULL),
	(128, 0, 10795, NULL, NULL),
	(128, 0, 10796, NULL, NULL),
	(128, 0, 10797, NULL, NULL),
	(128, 0, 10798, NULL, NULL),
	(128, 0, 10799, NULL, NULL),
	(128, 0, 10800, NULL, NULL),
	(128, 0, 10801, NULL, NULL),
	(128, 0, 10802, NULL, NULL),
	(128, 0, 10803, NULL, NULL),
	(128, 0, 10804, NULL, NULL),
	(128, 0, 10805, NULL, NULL),
	(128, 0, 10806, NULL, NULL),
	(128, 0, 10807, NULL, NULL),
	(128, 0, 10808, NULL, NULL),
	(128, 0, 10809, NULL, NULL),
	(128, 0, 10810, NULL, NULL),
	(128, 0, 10811, NULL, NULL),
	(128, 0, 10812, NULL, NULL),
	(128, 0, 10813, NULL, NULL),
	(128, 0, 10814, NULL, NULL),
	(128, 0, 10815, NULL, NULL),
	(128, 0, 10816, NULL, NULL),
	(128, 0, 10817, NULL, NULL),
	(128, 0, 10818, NULL, NULL),
	(128, 0, 10819, NULL, NULL),
	(128, 0, 10820, NULL, NULL),
	(128, 0, 10821, NULL, NULL),
	(128, 0, 10822, NULL, NULL),
	(128, 0, 10823, NULL, NULL),
	(128, 0, 10824, NULL, NULL),
	(128, 0, 10825, NULL, NULL),
	(128, 0, 10826, NULL, NULL),
	(128, 0, 10827, NULL, NULL),
	(128, 0, 10828, NULL, NULL),
	(128, 0, 10829, NULL, NULL),
	(128, 0, 10830, NULL, NULL),
	(128, 0, 10831, NULL, NULL),
	(128, 0, 10832, NULL, NULL),
	(128, 0, 10833, NULL, NULL),
	(128, 0, 10834, NULL, NULL),
	(128, 0, 10835, NULL, NULL),
	(128, 0, 10836, NULL, NULL),
	(128, 0, 10837, NULL, NULL),
	(128, 0, 10838, NULL, NULL),
	(128, 0, 10839, NULL, NULL),
	(128, 0, 10840, NULL, NULL),
	(128, 0, 10841, NULL, NULL),
	(128, 0, 10842, NULL, NULL),
	(128, 0, 10849, NULL, NULL),
	(128, 0, 10850, NULL, NULL),
	(128, 0, 10851, NULL, NULL),
	(128, 0, 10852, NULL, NULL),
	(128, 0, 10853, NULL, NULL),
	(128, 0, 10854, NULL, NULL),
	(128, 0, 10855, NULL, NULL),
	(128, 0, 10856, NULL, NULL),
	(128, 0, 10857, NULL, NULL),
	(128, 0, 10858, NULL, NULL),
	(128, 0, 10859, NULL, NULL),
	(128, 0, 10860, NULL, NULL),
	(128, 0, 10861, NULL, NULL),
	(128, 0, 10862, NULL, NULL),
	(128, 0, 10863, NULL, NULL),
	(128, 0, 10864, NULL, NULL),
	(128, 0, 10865, NULL, NULL),
	(128, 0, 10866, NULL, NULL),
	(128, 0, 10867, NULL, NULL),
	(128, 0, 10868, NULL, NULL),
	(128, 0, 10869, NULL, NULL),
	(128, 0, 10870, NULL, NULL),
	(128, 0, 10871, NULL, NULL),
	(128, 0, 10872, NULL, NULL),
	(128, 0, 10873, NULL, NULL),
	(128, 0, 10874, NULL, NULL),
	(128, 0, 10875, NULL, NULL),
	(128, 0, 10876, NULL, NULL),
	(128, 0, 10877, NULL, NULL),
	(128, 0, 10878, NULL, NULL),
	(128, 0, 10879, NULL, NULL),
	(128, 0, 10880, NULL, NULL),
	(128, 0, 10881, NULL, NULL),
	(128, 0, 10882, NULL, NULL),
	(128, 0, 10883, NULL, NULL),
	(128, 0, 10884, NULL, NULL),
	(128, 0, 10885, NULL, NULL),
	(128, 0, 10886, NULL, NULL),
	(128, 0, 10887, NULL, NULL),
	(128, 0, 10888, NULL, NULL),
	(128, 0, 10889, NULL, NULL),
	(128, 0, 10890, NULL, NULL),
	(128, 0, 10891, NULL, NULL),
	(128, 0, 10892, NULL, NULL),
	(128, 0, 10893, NULL, NULL),
	(128, 0, 10894, NULL, NULL),
	(128, 0, 10895, NULL, NULL),
	(128, 0, 10896, NULL, NULL),
	(128, 0, 10897, NULL, NULL),
	(128, 0, 10898, NULL, NULL),
	(128, 0, 10899, NULL, NULL),
	(128, 0, 10900, NULL, NULL),
	(128, 0, 10901, NULL, NULL),
	(128, 0, 10902, NULL, NULL),
	(128, 0, 10903, NULL, NULL),
	(128, 0, 10904, NULL, NULL),
	(128, 0, 10905, NULL, NULL),
	(128, 0, 10906, NULL, NULL),
	(128, 0, 10907, NULL, NULL),
	(128, 0, 10908, NULL, NULL),
	(128, 0, 10909, NULL, NULL),
	(128, 0, 10910, NULL, NULL),
	(128, 0, 10911, NULL, NULL),
	(128, 0, 10912, NULL, NULL),
	(128, 0, 10913, NULL, NULL),
	(128, 0, 10914, NULL, NULL),
	(128, 0, 10915, NULL, NULL),
	(128, 0, 10916, NULL, NULL),
	(128, 0, 10917, NULL, NULL),
	(128, 0, 10918, NULL, NULL),
	(128, 0, 10919, NULL, NULL),
	(128, 0, 10920, NULL, NULL),
	(128, 0, 10921, NULL, NULL),
	(128, 0, 10922, NULL, NULL),
	(128, 0, 10923, NULL, NULL),
	(128, 0, 10924, NULL, NULL),
	(128, 0, 10925, NULL, NULL),
	(128, 0, 10926, NULL, NULL),
	(128, 0, 10927, NULL, NULL),
	(128, 0, 10928, NULL, NULL),
	(128, 0, 10929, NULL, NULL),
	(128, 0, 10930, NULL, NULL),
	(128, 0, 10931, NULL, NULL),
	(128, 0, 10932, NULL, NULL),
	(128, 0, 10933, NULL, NULL),
	(128, 0, 10934, NULL, NULL),
	(128, 0, 10935, NULL, NULL),
	(128, 0, 10936, NULL, NULL),
	(128, 0, 10937, NULL, NULL),
	(128, 0, 10938, NULL, NULL),
	(128, 0, 10939, NULL, NULL),
	(128, 0, 10940, NULL, NULL),
	(128, 0, 10941, NULL, NULL),
	(128, 0, 10942, NULL, NULL),
	(128, 0, 10943, NULL, NULL),
	(128, 0, 10944, NULL, NULL),
	(128, 0, 10945, NULL, NULL),
	(128, 0, 10946, NULL, NULL),
	(128, 0, 10947, NULL, NULL),
	(128, 0, 10948, NULL, NULL),
	(128, 0, 10949, NULL, NULL),
	(128, 0, 10950, NULL, NULL),
	(128, 0, 10951, NULL, NULL),
	(128, 0, 10952, NULL, NULL),
	(128, 0, 10953, NULL, NULL),
	(128, 0, 10954, NULL, NULL),
	(128, 0, 10955, NULL, NULL),
	(128, 0, 10956, NULL, NULL),
	(128, 0, 10957, NULL, NULL),
	(128, 0, 10958, NULL, NULL),
	(128, 0, 10959, NULL, NULL),
	(128, 0, 10960, NULL, NULL),
	(128, 0, 10961, NULL, NULL),
	(128, 0, 10962, NULL, NULL),
	(128, 0, 10963, NULL, NULL),
	(128, 0, 10964, NULL, NULL),
	(128, 0, 10965, NULL, NULL),
	(128, 0, 10966, NULL, NULL),
	(128, 0, 10967, NULL, NULL),
	(128, 0, 10968, NULL, NULL),
	(128, 0, 10969, NULL, NULL),
	(128, 0, 10970, NULL, NULL),
	(128, 0, 10971, NULL, NULL),
	(128, 0, 10972, NULL, NULL),
	(128, 0, 10973, NULL, NULL),
	(128, 0, 10974, NULL, NULL),
	(128, 0, 10975, NULL, NULL),
	(128, 0, 10976, NULL, NULL),
	(128, 0, 10977, NULL, NULL),
	(128, 0, 10978, NULL, NULL),
	(128, 0, 10979, NULL, NULL),
	(128, 0, 10980, NULL, NULL),
	(128, 0, 10981, NULL, NULL),
	(128, 0, 10982, NULL, NULL),
	(128, 0, 10983, NULL, NULL),
	(128, 0, 10984, NULL, NULL),
	(128, 0, 10985, NULL, NULL),
	(128, 0, 10986, NULL, NULL),
	(128, 0, 10987, NULL, NULL),
	(128, 0, 10988, NULL, NULL),
	(128, 0, 10989, NULL, NULL),
	(128, 0, 10990, NULL, NULL),
	(128, 0, 10991, NULL, NULL),
	(128, 0, 10992, NULL, NULL),
	(128, 0, 10993, NULL, NULL),
	(128, 0, 10994, NULL, NULL),
	(128, 0, 10995, NULL, NULL),
	(128, 0, 10996, NULL, NULL),
	(128, 0, 10997, NULL, NULL),
	(128, 0, 10998, NULL, NULL),
	(128, 0, 10999, NULL, NULL),
	(128, 0, 11000, NULL, NULL),
	(128, 0, 11001, NULL, NULL),
	(128, 0, 11002, NULL, NULL),
	(128, 0, 11003, NULL, NULL),
	(128, 0, 11004, NULL, NULL),
	(128, 0, 11005, NULL, NULL),
	(128, 0, 11006, NULL, NULL),
	(128, 0, 11007, NULL, NULL),
	(128, 0, 11008, NULL, NULL),
	(128, 0, 11009, NULL, NULL),
	(128, 0, 11010, NULL, NULL),
	(128, 0, 11011, NULL, NULL),
	(128, 0, 11012, NULL, NULL),
	(128, 0, 11013, NULL, NULL),
	(128, 0, 11014, NULL, NULL),
	(128, 0, 11015, NULL, NULL),
	(128, 0, 11016, NULL, NULL),
	(128, 0, 11017, NULL, NULL),
	(128, 0, 11018, NULL, NULL),
	(128, 0, 11019, NULL, NULL),
	(128, 0, 11020, NULL, NULL),
	(128, 0, 11021, NULL, NULL),
	(128, 0, 11022, NULL, NULL),
	(128, 0, 11023, NULL, NULL),
	(128, 0, 11024, NULL, NULL),
	(128, 0, 11025, NULL, NULL),
	(128, 0, 11026, NULL, NULL),
	(128, 0, 11027, NULL, NULL),
	(128, 0, 11028, NULL, NULL),
	(128, 0, 11029, NULL, NULL),
	(128, 0, 11030, NULL, NULL),
	(128, 0, 11031, NULL, NULL),
	(128, 0, 11032, NULL, NULL),
	(128, 0, 11033, NULL, NULL),
	(128, 0, 11034, NULL, NULL),
	(128, 0, 11035, NULL, NULL),
	(128, 0, 11036, NULL, NULL),
	(128, 0, 11037, NULL, NULL),
	(128, 0, 11038, NULL, NULL),
	(128, 0, 11039, NULL, NULL),
	(128, 0, 11040, NULL, NULL),
	(128, 0, 11041, NULL, NULL),
	(128, 0, 11042, NULL, NULL),
	(128, 0, 11043, NULL, NULL),
	(128, 0, 11044, NULL, NULL),
	(128, 0, 11045, NULL, NULL),
	(128, 0, 11046, NULL, NULL),
	(128, 0, 11047, NULL, NULL),
	(128, 0, 11048, NULL, NULL),
	(128, 0, 11049, NULL, NULL),
	(128, 0, 11050, NULL, NULL),
	(128, 0, 11051, NULL, NULL),
	(128, 0, 11052, NULL, NULL),
	(128, 0, 11053, NULL, NULL),
	(128, 0, 11054, NULL, NULL),
	(128, 0, 11055, NULL, NULL),
	(128, 0, 11056, NULL, NULL),
	(128, 0, 11057, NULL, NULL),
	(128, 0, 11058, NULL, NULL),
	(128, 0, 11059, NULL, NULL),
	(128, 0, 11060, NULL, NULL),
	(128, 0, 11061, NULL, NULL),
	(128, 0, 11062, NULL, NULL),
	(128, 0, 11063, NULL, NULL),
	(128, 0, 11064, NULL, NULL),
	(128, 0, 11065, NULL, NULL),
	(128, 0, 11066, NULL, NULL),
	(128, 0, 11067, NULL, NULL),
	(128, 0, 11068, NULL, NULL),
	(128, 0, 11069, NULL, NULL),
	(128, 0, 11070, NULL, NULL),
	(128, 0, 11071, NULL, NULL),
	(128, 0, 11072, NULL, NULL),
	(128, 0, 11073, NULL, NULL),
	(128, 0, 11074, NULL, NULL),
	(128, 0, 11075, NULL, NULL),
	(128, 0, 11076, NULL, NULL),
	(128, 0, 11077, NULL, NULL),
	(128, 0, 11078, NULL, NULL),
	(128, 0, 11079, NULL, NULL),
	(128, 0, 11080, NULL, NULL),
	(128, 0, 11081, NULL, NULL),
	(128, 0, 11082, NULL, NULL),
	(128, 0, 11083, NULL, NULL),
	(128, 0, 11084, NULL, NULL),
	(128, 0, 11085, NULL, NULL),
	(128, 0, 11086, NULL, NULL),
	(128, 0, 11087, NULL, NULL),
	(128, 0, 11088, NULL, NULL),
	(128, 0, 11089, NULL, NULL),
	(128, 0, 11090, NULL, NULL),
	(128, 0, 11091, NULL, NULL),
	(128, 0, 11092, NULL, NULL),
	(128, 0, 11093, NULL, NULL),
	(128, 0, 11094, NULL, NULL),
	(128, 0, 11095, NULL, NULL),
	(128, 0, 11096, NULL, NULL),
	(128, 0, 11097, NULL, NULL),
	(128, 0, 11098, NULL, NULL),
	(128, 0, 11099, NULL, NULL),
	(128, 0, 11100, NULL, NULL),
	(128, 0, 11101, NULL, NULL),
	(128, 0, 11102, NULL, NULL),
	(128, 0, 11103, NULL, NULL),
	(128, 0, 11104, NULL, NULL),
	(128, 0, 11105, NULL, NULL),
	(128, 0, 11106, NULL, NULL),
	(128, 0, 11107, NULL, NULL),
	(128, 0, 11108, NULL, NULL),
	(128, 0, 11109, NULL, NULL),
	(128, 0, 11110, NULL, NULL),
	(128, 0, 11111, NULL, NULL),
	(128, 0, 11112, NULL, NULL),
	(128, 0, 11113, NULL, NULL),
	(128, 0, 11114, NULL, NULL),
	(128, 0, 11115, NULL, NULL),
	(128, 0, 11116, NULL, NULL),
	(128, 0, 11117, NULL, NULL),
	(128, 0, 11118, NULL, NULL),
	(128, 0, 11119, NULL, NULL),
	(128, 0, 11120, NULL, NULL),
	(128, 0, 11121, NULL, NULL),
	(128, 0, 11122, NULL, NULL),
	(128, 0, 11123, NULL, NULL),
	(128, 0, 11124, NULL, NULL),
	(128, 0, 11125, NULL, NULL),
	(128, 0, 11126, NULL, NULL),
	(128, 1, -1, NULL, NULL),
	(128, 1, 9999, NULL, NULL),
	(128, 1, 10000, NULL, NULL),
	(128, 1, 10001, NULL, NULL),
	(128, 1, 10002, NULL, NULL),
	(128, 1, 10003, NULL, NULL),
	(128, 1, 10004, NULL, NULL),
	(128, 1, 10005, NULL, NULL),
	(128, 1, 10006, NULL, NULL),
	(128, 1, 10007, NULL, NULL),
	(128, 1, 10008, NULL, NULL),
	(128, 1, 10009, NULL, NULL),
	(128, 1, 10010, NULL, NULL),
	(128, 1, 10011, NULL, NULL),
	(128, 1, 10012, NULL, NULL),
	(128, 1, 10013, NULL, NULL),
	(128, 1, 10014, NULL, NULL),
	(128, 1, 10015, NULL, NULL),
	(128, 1, 10016, NULL, NULL),
	(128, 1, 10017, NULL, NULL),
	(128, 1, 10018, NULL, NULL),
	(128, 1, 10019, NULL, NULL),
	(128, 1, 10020, NULL, NULL),
	(128, 1, 10021, NULL, NULL),
	(128, 1, 10022, NULL, NULL),
	(128, 1, 10023, NULL, NULL),
	(128, 1, 10024, NULL, NULL),
	(128, 1, 10025, NULL, NULL),
	(128, 1, 10026, NULL, NULL),
	(128, 1, 10027, NULL, NULL),
	(128, 1, 10028, NULL, NULL),
	(128, 1, 10029, NULL, NULL),
	(128, 1, 10030, NULL, NULL),
	(128, 1, 10031, NULL, NULL),
	(128, 1, 10032, NULL, NULL),
	(128, 1, 10033, NULL, NULL),
	(128, 1, 10034, NULL, NULL),
	(128, 1, 10035, NULL, NULL),
	(128, 1, 10036, NULL, NULL),
	(128, 1, 10037, NULL, NULL),
	(128, 1, 10038, NULL, NULL),
	(128, 1, 10039, NULL, NULL),
	(128, 1, 10040, NULL, NULL),
	(128, 1, 10041, NULL, NULL),
	(128, 1, 10042, NULL, NULL),
	(128, 1, 10043, NULL, NULL),
	(128, 1, 10044, NULL, NULL),
	(128, 1, 10045, NULL, NULL),
	(128, 1, 10046, NULL, NULL),
	(128, 1, 10047, NULL, NULL),
	(128, 1, 10048, NULL, NULL),
	(128, 1, 10049, NULL, NULL),
	(128, 1, 10050, NULL, NULL),
	(128, 1, 10051, NULL, NULL),
	(128, 1, 10052, NULL, NULL),
	(128, 1, 10053, NULL, NULL),
	(128, 1, 10054, NULL, NULL),
	(128, 1, 10055, NULL, NULL),
	(128, 1, 10056, NULL, NULL),
	(128, 1, 10057, NULL, NULL),
	(128, 1, 10058, NULL, NULL),
	(128, 1, 10059, NULL, NULL),
	(128, 1, 10060, NULL, NULL),
	(128, 1, 10061, NULL, NULL),
	(128, 1, 10062, NULL, NULL),
	(128, 1, 10063, NULL, NULL),
	(128, 1, 10064, NULL, NULL),
	(128, 1, 10065, NULL, NULL),
	(128, 1, 10066, NULL, NULL),
	(128, 1, 10067, NULL, NULL),
	(128, 1, 10068, NULL, NULL),
	(128, 1, 10069, NULL, NULL),
	(128, 1, 10070, NULL, NULL),
	(128, 1, 10071, NULL, NULL),
	(128, 1, 10072, NULL, NULL),
	(128, 1, 10073, NULL, NULL),
	(128, 1, 10074, NULL, NULL),
	(128, 1, 10075, NULL, NULL),
	(128, 1, 10076, NULL, NULL),
	(128, 1, 10077, NULL, NULL),
	(128, 1, 10078, NULL, NULL),
	(128, 1, 10079, NULL, NULL),
	(128, 1, 10080, NULL, NULL),
	(128, 1, 10081, NULL, NULL),
	(128, 1, 10082, NULL, NULL),
	(128, 1, 10083, NULL, NULL),
	(128, 1, 10084, NULL, NULL),
	(128, 1, 10085, NULL, NULL),
	(128, 1, 10086, NULL, NULL),
	(128, 1, 10087, NULL, NULL),
	(128, 1, 10088, NULL, NULL),
	(128, 1, 10089, NULL, NULL),
	(128, 1, 10090, NULL, NULL),
	(128, 1, 10091, NULL, NULL),
	(128, 1, 10092, NULL, NULL),
	(128, 1, 10093, NULL, NULL),
	(128, 1, 10094, NULL, NULL),
	(128, 1, 10095, NULL, NULL),
	(128, 1, 10096, NULL, NULL),
	(128, 1, 10097, NULL, NULL),
	(128, 1, 10098, NULL, NULL),
	(128, 1, 10099, NULL, NULL),
	(128, 1, 10100, NULL, NULL),
	(128, 1, 10101, NULL, NULL),
	(128, 1, 10102, NULL, NULL),
	(128, 1, 10103, NULL, NULL),
	(128, 1, 10104, NULL, NULL),
	(128, 1, 10105, NULL, NULL),
	(128, 1, 10106, NULL, NULL),
	(128, 1, 10107, NULL, NULL),
	(128, 1, 10108, NULL, NULL),
	(128, 1, 10109, NULL, NULL),
	(128, 1, 10110, NULL, NULL),
	(128, 1, 10111, NULL, NULL),
	(128, 1, 10112, NULL, NULL),
	(128, 1, 10113, NULL, NULL),
	(128, 1, 10114, NULL, NULL),
	(128, 1, 10115, NULL, NULL),
	(128, 1, 10116, NULL, NULL),
	(128, 1, 10117, NULL, NULL),
	(128, 1, 10118, NULL, NULL),
	(128, 1, 10119, NULL, NULL),
	(128, 1, 10120, NULL, NULL),
	(128, 1, 10121, NULL, NULL),
	(128, 1, 10122, NULL, NULL),
	(128, 1, 10123, NULL, NULL),
	(128, 1, 10124, NULL, NULL),
	(128, 1, 10125, NULL, NULL),
	(128, 1, 10126, NULL, NULL),
	(128, 1, 10127, NULL, NULL),
	(128, 1, 10128, NULL, NULL),
	(128, 1, 10129, NULL, NULL),
	(128, 1, 10130, NULL, NULL),
	(128, 1, 10131, NULL, NULL),
	(128, 1, 10132, NULL, NULL),
	(128, 1, 10133, NULL, NULL),
	(128, 1, 10134, NULL, NULL),
	(128, 1, 10135, NULL, NULL),
	(128, 1, 10136, NULL, NULL),
	(128, 1, 10137, NULL, NULL),
	(128, 1, 10138, NULL, NULL),
	(128, 1, 10139, NULL, NULL),
	(128, 1, 10140, NULL, NULL),
	(128, 1, 10141, NULL, NULL),
	(128, 1, 10142, NULL, NULL),
	(128, 1, 10143, NULL, NULL),
	(128, 1, 10144, NULL, NULL),
	(128, 1, 10145, NULL, NULL),
	(128, 1, 10146, NULL, NULL),
	(128, 1, 10147, NULL, NULL),
	(128, 1, 10148, NULL, NULL),
	(128, 1, 10149, NULL, NULL),
	(128, 1, 10150, NULL, NULL),
	(128, 1, 10151, NULL, NULL),
	(128, 1, 10152, NULL, NULL),
	(128, 1, 10153, NULL, NULL),
	(128, 1, 10154, NULL, NULL),
	(128, 1, 10155, NULL, NULL),
	(128, 1, 10156, NULL, NULL),
	(128, 1, 10157, NULL, NULL),
	(128, 1, 10158, NULL, NULL),
	(128, 1, 10159, NULL, NULL),
	(128, 1, 10160, NULL, NULL),
	(128, 1, 10161, NULL, NULL),
	(128, 1, 10162, NULL, NULL),
	(128, 1, 10163, NULL, NULL),
	(128, 1, 10164, NULL, NULL),
	(128, 1, 10165, NULL, NULL),
	(128, 1, 10166, NULL, NULL),
	(128, 1, 10167, NULL, NULL),
	(128, 1, 10168, NULL, NULL),
	(128, 1, 10169, NULL, NULL),
	(128, 1, 10170, NULL, NULL),
	(128, 1, 10171, NULL, NULL),
	(128, 1, 10172, NULL, NULL),
	(128, 1, 10173, NULL, NULL),
	(128, 1, 10174, NULL, NULL),
	(128, 1, 10175, NULL, NULL),
	(128, 1, 10176, NULL, NULL),
	(128, 1, 10177, NULL, NULL),
	(128, 1, 10178, NULL, NULL),
	(128, 1, 10179, NULL, NULL),
	(128, 1, 10180, NULL, NULL),
	(128, 1, 10181, NULL, NULL),
	(128, 1, 10182, NULL, NULL),
	(128, 1, 10183, NULL, NULL),
	(128, 1, 10184, NULL, NULL),
	(128, 1, 10185, NULL, NULL),
	(128, 1, 10186, NULL, NULL),
	(128, 1, 10187, NULL, NULL),
	(128, 1, 10188, NULL, NULL),
	(128, 1, 10189, NULL, NULL),
	(128, 1, 10190, NULL, NULL),
	(128, 1, 10191, NULL, NULL),
	(128, 1, 10192, NULL, NULL),
	(128, 1, 10193, NULL, NULL),
	(128, 1, 10194, NULL, NULL),
	(128, 1, 10195, NULL, NULL),
	(128, 1, 10196, NULL, NULL),
	(128, 1, 10197, NULL, NULL),
	(128, 1, 10198, NULL, NULL),
	(128, 1, 10199, NULL, NULL),
	(128, 1, 10200, NULL, NULL),
	(128, 1, 10201, NULL, NULL),
	(128, 1, 10202, NULL, NULL),
	(128, 1, 10203, NULL, NULL),
	(128, 1, 10204, NULL, NULL),
	(128, 1, 10205, NULL, NULL),
	(128, 1, 10206, NULL, NULL),
	(128, 1, 10207, NULL, NULL),
	(128, 1, 10208, NULL, NULL),
	(128, 1, 10209, NULL, NULL),
	(128, 1, 10210, NULL, NULL),
	(128, 1, 10211, NULL, NULL),
	(128, 1, 10212, NULL, NULL),
	(128, 1, 10213, NULL, NULL),
	(128, 1, 10214, NULL, NULL),
	(128, 1, 10215, NULL, NULL),
	(128, 1, 10216, NULL, NULL),
	(128, 1, 10217, NULL, NULL),
	(128, 1, 10218, NULL, NULL),
	(128, 1, 10219, NULL, NULL),
	(128, 1, 10220, NULL, NULL),
	(128, 1, 10221, NULL, NULL),
	(128, 1, 10222, NULL, NULL),
	(128, 1, 10223, NULL, NULL),
	(128, 1, 10224, NULL, NULL),
	(128, 1, 10225, NULL, NULL),
	(128, 1, 10226, NULL, NULL),
	(128, 1, 10227, NULL, NULL),
	(128, 1, 10228, NULL, NULL),
	(128, 1, 10229, NULL, NULL),
	(128, 1, 10230, NULL, NULL),
	(128, 1, 10231, NULL, NULL),
	(128, 1, 10232, NULL, NULL),
	(128, 1, 10233, NULL, NULL),
	(128, 1, 10234, NULL, NULL),
	(128, 1, 10235, NULL, NULL),
	(128, 1, 10236, NULL, NULL),
	(128, 1, 10237, NULL, NULL),
	(128, 1, 10238, NULL, NULL),
	(128, 1, 10239, NULL, NULL),
	(128, 1, 10240, NULL, NULL),
	(128, 1, 10241, NULL, NULL),
	(128, 1, 10242, NULL, NULL),
	(128, 1, 10243, NULL, NULL),
	(128, 1, 10244, NULL, NULL),
	(128, 1, 10245, NULL, NULL),
	(128, 1, 10246, NULL, NULL),
	(128, 1, 10247, NULL, NULL),
	(128, 1, 10248, NULL, NULL),
	(128, 1, 10249, NULL, NULL),
	(128, 1, 10252, NULL, NULL),
	(128, 1, 10253, NULL, NULL),
	(128, 1, 10254, NULL, NULL),
	(128, 1, 10255, NULL, NULL),
	(128, 1, 10256, NULL, NULL),
	(128, 1, 10257, NULL, NULL),
	(128, 1, 10258, NULL, NULL),
	(128, 1, 10259, NULL, NULL),
	(128, 1, 10260, NULL, NULL),
	(128, 1, 10261, NULL, NULL),
	(128, 1, 10262, NULL, NULL),
	(128, 1, 10263, NULL, NULL),
	(128, 1, 10264, NULL, NULL),
	(128, 1, 10265, NULL, NULL),
	(128, 1, 10266, NULL, NULL),
	(128, 1, 10267, NULL, NULL),
	(128, 1, 10268, NULL, NULL),
	(128, 1, 10269, NULL, NULL),
	(128, 1, 10270, NULL, NULL),
	(128, 1, 10271, NULL, NULL),
	(128, 1, 10272, NULL, NULL),
	(128, 1, 10273, NULL, NULL),
	(128, 1, 10274, NULL, NULL),
	(128, 1, 10275, NULL, NULL),
	(128, 1, 10276, NULL, NULL),
	(128, 1, 10284, NULL, NULL),
	(128, 1, 10291, NULL, NULL),
	(128, 1, 10292, NULL, NULL),
	(128, 1, 10293, NULL, NULL),
	(128, 1, 10294, NULL, NULL),
	(128, 1, 10295, NULL, NULL),
	(128, 1, 10296, NULL, NULL),
	(128, 1, 10297, NULL, NULL),
	(128, 1, 10298, NULL, NULL),
	(128, 1, 10299, NULL, NULL),
	(128, 1, 10300, NULL, NULL),
	(128, 1, 10301, NULL, NULL),
	(128, 1, 10302, NULL, NULL),
	(128, 1, 10303, NULL, NULL),
	(128, 1, 10304, NULL, NULL),
	(128, 1, 10305, NULL, NULL),
	(128, 1, 10306, NULL, NULL),
	(128, 1, 10307, NULL, NULL),
	(128, 1, 10308, NULL, NULL),
	(128, 1, 10309, NULL, NULL),
	(128, 1, 10310, NULL, NULL),
	(128, 1, 10311, NULL, NULL),
	(128, 1, 10312, NULL, NULL),
	(128, 1, 10313, NULL, NULL),
	(128, 1, 10314, NULL, NULL),
	(128, 1, 10315, NULL, NULL),
	(128, 1, 10316, NULL, NULL),
	(128, 1, 10317, NULL, NULL),
	(128, 1, 10318, NULL, NULL),
	(128, 1, 10319, NULL, NULL),
	(128, 1, 10320, NULL, NULL),
	(128, 1, 10321, NULL, NULL),
	(128, 1, 10322, NULL, NULL),
	(128, 1, 10323, NULL, NULL),
	(128, 1, 10324, NULL, NULL),
	(128, 1, 10325, NULL, NULL),
	(128, 1, 10326, NULL, NULL),
	(128, 1, 10327, NULL, NULL),
	(128, 1, 10328, NULL, NULL),
	(128, 1, 10329, NULL, NULL),
	(128, 1, 10330, NULL, NULL),
	(128, 1, 10331, NULL, NULL),
	(128, 1, 10332, NULL, NULL),
	(128, 1, 10333, NULL, NULL),
	(128, 1, 10334, NULL, NULL),
	(128, 1, 10335, NULL, NULL),
	(128, 1, 10336, NULL, NULL),
	(128, 1, 10337, NULL, NULL),
	(128, 1, 10338, NULL, NULL),
	(128, 1, 10339, NULL, NULL),
	(128, 1, 10340, NULL, NULL),
	(128, 1, 10341, NULL, NULL),
	(128, 1, 10342, NULL, NULL),
	(128, 1, 10343, NULL, NULL),
	(128, 1, 10344, NULL, NULL),
	(128, 1, 10345, NULL, NULL),
	(128, 1, 10346, NULL, NULL),
	(128, 1, 10347, NULL, NULL),
	(128, 1, 10348, NULL, NULL),
	(128, 1, 10349, NULL, NULL),
	(128, 1, 10350, NULL, NULL),
	(128, 1, 10351, NULL, NULL),
	(128, 1, 10400, NULL, NULL),
	(128, 1, 10401, NULL, NULL),
	(128, 1, 10402, NULL, NULL),
	(128, 1, 10403, NULL, NULL),
	(128, 1, 10404, NULL, NULL),
	(128, 1, 10405, NULL, NULL),
	(128, 1, 10406, NULL, NULL),
	(128, 1, 10407, NULL, NULL),
	(128, 1, 10409, NULL, NULL),
	(128, 1, 10410, NULL, NULL),
	(128, 1, 10411, NULL, NULL),
	(128, 1, 10412, NULL, NULL),
	(128, 1, 10413, NULL, NULL),
	(128, 1, 10414, NULL, NULL),
	(128, 1, 10415, NULL, NULL),
	(128, 1, 10416, NULL, NULL),
	(128, 1, 10417, NULL, NULL),
	(128, 1, 10418, NULL, NULL),
	(128, 1, 10419, NULL, NULL),
	(128, 1, 10420, NULL, NULL),
	(128, 1, 10421, NULL, NULL),
	(128, 1, 10422, NULL, NULL),
	(128, 1, 10423, NULL, NULL),
	(128, 1, 10424, NULL, NULL),
	(128, 1, 10425, NULL, NULL),
	(128, 1, 10426, NULL, NULL),
	(128, 1, 10427, NULL, NULL),
	(128, 1, 10428, NULL, NULL),
	(128, 1, 10429, NULL, NULL),
	(128, 1, 10430, NULL, NULL),
	(128, 1, 10431, NULL, NULL),
	(128, 1, 10432, NULL, NULL),
	(128, 1, 10433, NULL, NULL),
	(128, 1, 10434, NULL, NULL),
	(128, 1, 10435, NULL, NULL),
	(128, 1, 10436, NULL, NULL),
	(128, 1, 10437, NULL, NULL),
	(128, 1, 10438, NULL, NULL),
	(128, 1, 10439, NULL, NULL),
	(128, 1, 10440, NULL, NULL),
	(128, 1, 10441, NULL, NULL),
	(128, 1, 10442, NULL, NULL),
	(128, 1, 10443, NULL, NULL),
	(128, 1, 10444, NULL, NULL),
	(128, 1, 10445, NULL, NULL),
	(128, 1, 10446, NULL, NULL),
	(128, 1, 10447, NULL, NULL),
	(128, 1, 10448, NULL, NULL),
	(128, 1, 10449, NULL, NULL),
	(128, 1, 10450, NULL, NULL),
	(128, 1, 10451, NULL, NULL),
	(128, 1, 10452, NULL, NULL),
	(128, 1, 10453, NULL, NULL),
	(128, 1, 10454, NULL, NULL),
	(128, 1, 10455, NULL, NULL),
	(128, 1, 10456, NULL, NULL),
	(128, 1, 10457, NULL, NULL),
	(128, 1, 10458, NULL, NULL),
	(128, 1, 10459, NULL, NULL),
	(128, 1, 10460, NULL, NULL),
	(128, 1, 10461, NULL, NULL),
	(128, 1, 10462, NULL, NULL),
	(128, 1, 10463, NULL, NULL),
	(128, 1, 10464, NULL, NULL),
	(128, 1, 10465, NULL, NULL),
	(128, 1, 10466, NULL, NULL),
	(128, 1, 10467, NULL, NULL),
	(128, 1, 10468, NULL, NULL),
	(128, 1, 10469, NULL, NULL),
	(128, 1, 10470, NULL, NULL),
	(128, 1, 10471, NULL, NULL),
	(128, 1, 10472, NULL, NULL),
	(128, 1, 10473, NULL, NULL),
	(128, 1, 10474, NULL, NULL),
	(128, 1, 10475, NULL, NULL),
	(128, 1, 10476, NULL, NULL),
	(128, 1, 10477, NULL, NULL),
	(128, 1, 10478, NULL, NULL),
	(128, 1, 10479, NULL, NULL),
	(128, 1, 10480, NULL, NULL),
	(128, 1, 10481, NULL, NULL),
	(128, 1, 10482, NULL, NULL),
	(128, 1, 10483, NULL, NULL),
	(128, 1, 10484, NULL, NULL),
	(128, 1, 10485, NULL, NULL),
	(128, 1, 10486, NULL, NULL),
	(128, 1, 10487, NULL, NULL),
	(128, 1, 10488, NULL, NULL),
	(128, 1, 10489, NULL, NULL),
	(128, 1, 10490, NULL, NULL),
	(128, 1, 10491, NULL, NULL),
	(128, 1, 10492, NULL, NULL),
	(128, 1, 10493, NULL, NULL),
	(128, 1, 10494, NULL, NULL),
	(128, 1, 10495, NULL, NULL),
	(128, 1, 10496, NULL, NULL),
	(128, 1, 10497, NULL, NULL),
	(128, 1, 10498, NULL, NULL),
	(128, 1, 10499, NULL, NULL),
	(128, 1, 10500, NULL, NULL),
	(128, 1, 10501, NULL, NULL),
	(128, 1, 10502, NULL, NULL),
	(128, 1, 10503, NULL, NULL),
	(128, 1, 10504, NULL, NULL),
	(128, 1, 10505, NULL, NULL),
	(128, 1, 10506, NULL, NULL),
	(128, 1, 10507, NULL, NULL),
	(128, 1, 10508, NULL, NULL),
	(128, 1, 10509, NULL, NULL),
	(128, 1, 10510, NULL, NULL),
	(128, 1, 10511, NULL, NULL),
	(128, 1, 10512, NULL, NULL),
	(128, 1, 10513, NULL, NULL),
	(128, 1, 10514, NULL, NULL),
	(128, 1, 10515, NULL, NULL),
	(128, 1, 10516, NULL, NULL),
	(128, 1, 10517, NULL, NULL),
	(128, 1, 10518, NULL, NULL),
	(128, 1, 10519, NULL, NULL),
	(128, 1, 10520, NULL, NULL),
	(128, 1, 10521, NULL, NULL),
	(128, 1, 10522, NULL, NULL),
	(128, 1, 10523, NULL, NULL),
	(128, 1, 10524, NULL, NULL),
	(128, 1, 10525, NULL, NULL),
	(128, 1, 10526, NULL, NULL),
	(128, 1, 10527, NULL, NULL),
	(128, 1, 10528, NULL, NULL),
	(128, 1, 10529, NULL, NULL),
	(128, 1, 10530, NULL, NULL),
	(128, 1, 10531, NULL, NULL),
	(128, 1, 10532, NULL, NULL),
	(128, 1, 10533, NULL, NULL),
	(128, 1, 10534, NULL, NULL),
	(128, 1, 10535, NULL, NULL),
	(128, 1, 10536, NULL, NULL),
	(128, 1, 10537, NULL, NULL),
	(128, 1, 10538, NULL, NULL),
	(128, 1, 10539, NULL, NULL),
	(128, 1, 10540, NULL, NULL),
	(128, 1, 10541, NULL, NULL),
	(128, 1, 10542, NULL, NULL),
	(128, 1, 10543, NULL, NULL),
	(128, 1, 10544, NULL, NULL),
	(128, 1, 10545, NULL, NULL),
	(128, 1, 10546, NULL, NULL),
	(128, 1, 10547, NULL, NULL),
	(128, 1, 10548, NULL, NULL),
	(128, 1, 10549, NULL, NULL),
	(128, 1, 10550, NULL, NULL),
	(128, 1, 10551, NULL, NULL),
	(128, 1, 10552, NULL, NULL),
	(128, 1, 10553, NULL, NULL),
	(128, 1, 10554, NULL, NULL),
	(128, 1, 10555, NULL, NULL),
	(128, 1, 10556, NULL, NULL),
	(128, 1, 10557, NULL, NULL),
	(128, 1, 10558, NULL, NULL),
	(128, 1, 10559, NULL, NULL),
	(128, 1, 10560, NULL, NULL),
	(128, 1, 10561, NULL, NULL),
	(128, 1, 10562, NULL, NULL),
	(128, 1, 10563, NULL, NULL),
	(128, 1, 10564, NULL, NULL),
	(128, 1, 10565, NULL, NULL),
	(128, 1, 10566, NULL, NULL),
	(128, 1, 10567, NULL, NULL),
	(128, 1, 10568, NULL, NULL),
	(128, 1, 10569, NULL, NULL),
	(128, 1, 10570, NULL, NULL),
	(128, 1, 10571, NULL, NULL),
	(128, 1, 10572, NULL, NULL),
	(128, 1, 10573, NULL, NULL),
	(128, 1, 10574, NULL, NULL),
	(128, 1, 10575, NULL, NULL),
	(128, 1, 10576, NULL, NULL),
	(128, 1, 10577, NULL, NULL),
	(128, 1, 10578, NULL, NULL),
	(128, 1, 10579, NULL, NULL),
	(128, 1, 10580, NULL, NULL),
	(128, 1, 10581, NULL, NULL),
	(128, 1, 10582, NULL, NULL),
	(128, 1, 10583, NULL, NULL),
	(128, 1, 10584, NULL, NULL),
	(128, 1, 10585, NULL, NULL),
	(128, 1, 10586, NULL, NULL),
	(128, 1, 10587, NULL, NULL),
	(128, 1, 10588, NULL, NULL),
	(128, 1, 10589, NULL, NULL),
	(128, 1, 10590, NULL, NULL),
	(128, 1, 10591, NULL, NULL),
	(128, 1, 10592, NULL, NULL),
	(128, 1, 10593, NULL, NULL),
	(128, 1, 10594, NULL, NULL),
	(128, 1, 10595, NULL, NULL),
	(128, 1, 10596, NULL, NULL),
	(128, 1, 10597, NULL, NULL),
	(128, 1, 10598, NULL, NULL),
	(128, 1, 10599, NULL, NULL),
	(128, 1, 10600, NULL, NULL),
	(128, 1, 10602, NULL, NULL),
	(128, 1, 10603, NULL, NULL),
	(128, 1, 10604, NULL, NULL),
	(128, 1, 10605, NULL, NULL),
	(128, 1, 10606, NULL, NULL),
	(128, 1, 10607, NULL, NULL),
	(128, 1, 10608, NULL, NULL),
	(128, 1, 10609, NULL, NULL),
	(128, 1, 10610, NULL, NULL),
	(128, 1, 10611, NULL, NULL),
	(128, 1, 10612, NULL, NULL),
	(128, 1, 10613, NULL, NULL),
	(128, 1, 10614, NULL, NULL),
	(128, 1, 10615, NULL, NULL),
	(128, 1, 10616, NULL, NULL),
	(128, 1, 10617, NULL, NULL),
	(128, 1, 10618, NULL, NULL),
	(128, 1, 10619, NULL, NULL),
	(128, 1, 10620, NULL, NULL),
	(128, 1, 10621, NULL, NULL),
	(128, 1, 10622, NULL, NULL),
	(128, 1, 10623, NULL, NULL),
	(128, 1, 10624, NULL, NULL),
	(128, 1, 10625, NULL, NULL),
	(128, 1, 10626, NULL, NULL),
	(128, 1, 10627, NULL, NULL),
	(128, 1, 10628, NULL, NULL),
	(128, 1, 10629, NULL, NULL),
	(128, 1, 10630, NULL, NULL),
	(128, 1, 10631, NULL, NULL),
	(128, 1, 10632, NULL, NULL),
	(128, 1, 10633, NULL, NULL),
	(128, 1, 10634, NULL, NULL),
	(128, 1, 10635, NULL, NULL),
	(128, 1, 10636, NULL, NULL),
	(128, 1, 10637, NULL, NULL),
	(128, 1, 10638, NULL, NULL),
	(128, 1, 10639, NULL, NULL),
	(128, 1, 10640, NULL, NULL),
	(128, 1, 10641, NULL, NULL),
	(128, 1, 10642, NULL, NULL),
	(128, 1, 10643, NULL, NULL),
	(128, 1, 10644, NULL, NULL),
	(128, 1, 10645, NULL, NULL),
	(128, 1, 10646, NULL, NULL),
	(128, 1, 10647, NULL, NULL),
	(128, 1, 10648, NULL, NULL),
	(128, 1, 10649, NULL, NULL),
	(128, 1, 10650, NULL, NULL),
	(128, 1, 10651, NULL, NULL),
	(128, 1, 10652, NULL, NULL),
	(128, 1, 10653, NULL, NULL),
	(128, 1, 10654, NULL, NULL),
	(128, 1, 10655, NULL, NULL),
	(128, 1, 10656, NULL, NULL),
	(128, 1, 10657, NULL, NULL),
	(128, 1, 10658, NULL, NULL),
	(128, 1, 10659, NULL, NULL),
	(128, 1, 10660, NULL, NULL),
	(128, 1, 10661, NULL, NULL),
	(128, 1, 10662, NULL, NULL),
	(128, 1, 10663, NULL, NULL),
	(128, 1, 10664, NULL, NULL),
	(128, 1, 10665, NULL, NULL),
	(128, 1, 10668, NULL, NULL),
	(128, 1, 10669, NULL, NULL),
	(128, 1, 10674, NULL, NULL),
	(128, 1, 10675, NULL, NULL),
	(128, 1, 10676, NULL, NULL),
	(128, 1, 10677, NULL, NULL),
	(128, 1, 10678, NULL, NULL),
	(128, 1, 10679, NULL, NULL),
	(128, 1, 10680, NULL, NULL),
	(128, 1, 10682, NULL, NULL),
	(128, 1, 10685, NULL, NULL),
	(128, 1, 10686, NULL, NULL),
	(128, 1, 10687, NULL, NULL),
	(128, 1, 10689, NULL, NULL),
	(128, 1, 10690, NULL, NULL),
	(128, 1, 10691, NULL, NULL),
	(128, 1, 10692, NULL, NULL),
	(128, 1, 10693, NULL, NULL),
	(128, 1, 10694, NULL, NULL),
	(128, 1, 10695, NULL, NULL),
	(128, 1, 10696, NULL, NULL),
	(128, 1, 10697, NULL, NULL),
	(128, 1, 10698, NULL, NULL),
	(128, 1, 10699, NULL, NULL),
	(128, 1, 10700, NULL, NULL),
	(128, 1, 10701, NULL, NULL),
	(128, 1, 10702, NULL, NULL),
	(128, 1, 10703, NULL, NULL),
	(128, 1, 10704, NULL, NULL),
	(128, 1, 10705, NULL, NULL),
	(128, 1, 10706, NULL, NULL),
	(128, 1, 10707, NULL, NULL),
	(128, 1, 10708, NULL, NULL),
	(128, 1, 10709, NULL, NULL),
	(128, 1, 10710, NULL, NULL),
	(128, 1, 10711, NULL, NULL),
	(128, 1, 10712, NULL, NULL),
	(128, 1, 10713, NULL, NULL),
	(128, 1, 10714, NULL, NULL),
	(128, 1, 10715, NULL, NULL),
	(128, 1, 10716, NULL, NULL),
	(128, 1, 10717, NULL, NULL),
	(128, 1, 10718, NULL, NULL),
	(128, 1, 10719, NULL, NULL),
	(128, 1, 10720, NULL, NULL),
	(128, 1, 10721, NULL, NULL),
	(128, 1, 10722, NULL, NULL),
	(128, 1, 10723, NULL, NULL),
	(128, 1, 10724, NULL, NULL),
	(128, 1, 10725, NULL, NULL),
	(128, 1, 10726, NULL, NULL),
	(128, 1, 10727, NULL, NULL),
	(128, 1, 10728, NULL, NULL),
	(128, 1, 10729, NULL, NULL),
	(128, 1, 10730, NULL, NULL),
	(128, 1, 10731, NULL, NULL),
	(128, 1, 10732, NULL, NULL),
	(128, 1, 10733, NULL, NULL),
	(128, 1, 10734, NULL, NULL),
	(128, 1, 10735, NULL, NULL),
	(128, 1, 10736, NULL, NULL),
	(128, 1, 10737, NULL, NULL),
	(128, 1, 10738, NULL, NULL),
	(128, 1, 10739, NULL, NULL),
	(128, 1, 10740, NULL, NULL),
	(128, 1, 10741, NULL, NULL),
	(128, 1, 10742, NULL, NULL),
	(128, 1, 10743, NULL, NULL),
	(128, 1, 10744, NULL, NULL),
	(128, 1, 10745, NULL, NULL),
	(128, 1, 10746, NULL, NULL),
	(128, 1, 10747, NULL, NULL),
	(128, 1, 10748, NULL, NULL),
	(128, 1, 10749, NULL, NULL),
	(128, 1, 10750, NULL, NULL),
	(128, 1, 10751, NULL, NULL),
	(128, 1, 10752, NULL, NULL),
	(128, 1, 10753, NULL, NULL),
	(128, 1, 10754, NULL, NULL),
	(128, 1, 10755, NULL, NULL),
	(128, 1, 10756, NULL, NULL),
	(128, 1, 10757, NULL, NULL),
	(128, 1, 10758, NULL, NULL),
	(128, 1, 10759, NULL, NULL),
	(128, 1, 10760, NULL, NULL),
	(128, 1, 10761, NULL, NULL),
	(128, 1, 10762, NULL, NULL),
	(128, 1, 10763, NULL, NULL),
	(128, 1, 10764, NULL, NULL),
	(128, 1, 10765, NULL, NULL),
	(128, 1, 10766, NULL, NULL),
	(128, 1, 10767, NULL, NULL),
	(128, 1, 10768, NULL, NULL),
	(128, 1, 10769, NULL, NULL),
	(128, 1, 10770, NULL, NULL),
	(128, 1, 10771, NULL, NULL),
	(128, 1, 10772, NULL, NULL),
	(128, 1, 10773, NULL, NULL),
	(128, 1, 10774, NULL, NULL),
	(128, 1, 10775, NULL, NULL),
	(128, 1, 10776, NULL, NULL),
	(128, 1, 10777, NULL, NULL),
	(128, 1, 10778, NULL, NULL),
	(128, 1, 10779, NULL, NULL),
	(128, 1, 10780, NULL, NULL),
	(128, 1, 10781, NULL, NULL),
	(128, 1, 10782, NULL, NULL),
	(128, 1, 10783, NULL, NULL),
	(128, 1, 10784, NULL, NULL),
	(128, 1, 10785, NULL, NULL),
	(128, 1, 10786, NULL, NULL),
	(128, 1, 10787, NULL, NULL),
	(128, 1, 10788, NULL, NULL),
	(128, 1, 10789, NULL, NULL),
	(128, 1, 10790, NULL, NULL),
	(128, 1, 10791, NULL, NULL),
	(128, 1, 10792, NULL, NULL),
	(128, 1, 10793, NULL, NULL),
	(128, 1, 10794, NULL, NULL),
	(128, 1, 10795, NULL, NULL),
	(128, 1, 10796, NULL, NULL),
	(128, 1, 10797, NULL, NULL),
	(128, 1, 10798, NULL, NULL),
	(128, 1, 10799, NULL, NULL),
	(128, 1, 10800, NULL, NULL),
	(128, 1, 10801, NULL, NULL),
	(128, 1, 10802, NULL, NULL),
	(128, 1, 10803, NULL, NULL),
	(128, 1, 10804, NULL, NULL),
	(128, 1, 10805, NULL, NULL),
	(128, 1, 10806, NULL, NULL),
	(128, 1, 10807, NULL, NULL),
	(128, 1, 10808, NULL, NULL),
	(128, 1, 10809, NULL, NULL),
	(128, 1, 10810, NULL, NULL),
	(128, 1, 10811, NULL, NULL),
	(128, 1, 10812, NULL, NULL),
	(128, 1, 10813, NULL, NULL),
	(128, 1, 10814, NULL, NULL),
	(128, 1, 10815, NULL, NULL),
	(128, 1, 10816, NULL, NULL),
	(128, 1, 10817, NULL, NULL),
	(128, 1, 10818, NULL, NULL),
	(128, 1, 10819, NULL, NULL),
	(128, 1, 10820, NULL, NULL),
	(128, 1, 10821, NULL, NULL),
	(128, 1, 10822, NULL, NULL),
	(128, 1, 10823, NULL, NULL),
	(128, 1, 10824, NULL, NULL),
	(128, 1, 10825, NULL, NULL),
	(128, 1, 10826, NULL, NULL),
	(128, 1, 10827, NULL, NULL),
	(128, 1, 10828, NULL, NULL),
	(128, 1, 10829, NULL, NULL),
	(128, 1, 10830, NULL, NULL),
	(128, 1, 10831, NULL, NULL),
	(128, 1, 10832, NULL, NULL),
	(128, 1, 10833, NULL, NULL),
	(128, 1, 10834, NULL, NULL),
	(128, 1, 10835, NULL, NULL),
	(128, 1, 10836, NULL, NULL),
	(128, 1, 10837, NULL, NULL),
	(128, 1, 10838, NULL, NULL),
	(128, 1, 10839, NULL, NULL),
	(128, 1, 10840, NULL, NULL),
	(128, 1, 10841, NULL, NULL),
	(128, 1, 10842, NULL, NULL),
	(128, 1, 10849, NULL, NULL),
	(128, 1, 10850, NULL, NULL),
	(128, 1, 10851, NULL, NULL),
	(128, 1, 10852, NULL, NULL),
	(128, 1, 10853, NULL, NULL),
	(128, 1, 10854, NULL, NULL),
	(128, 1, 10855, NULL, NULL),
	(128, 1, 10856, NULL, NULL),
	(128, 1, 10857, NULL, NULL),
	(128, 1, 10858, NULL, NULL),
	(128, 1, 10859, NULL, NULL),
	(128, 1, 10860, NULL, NULL),
	(128, 1, 10861, NULL, NULL),
	(128, 1, 10862, NULL, NULL),
	(128, 1, 10863, NULL, NULL),
	(128, 1, 10864, NULL, NULL),
	(128, 1, 10865, NULL, NULL),
	(128, 1, 10866, NULL, NULL),
	(128, 1, 10867, NULL, NULL),
	(128, 1, 10868, NULL, NULL),
	(128, 1, 10869, NULL, NULL),
	(128, 1, 10870, NULL, NULL),
	(128, 1, 10871, NULL, NULL),
	(128, 1, 10872, NULL, NULL),
	(128, 1, 10873, NULL, NULL),
	(128, 1, 10874, NULL, NULL),
	(128, 1, 10875, NULL, NULL),
	(128, 1, 10876, NULL, NULL),
	(128, 1, 10877, NULL, NULL),
	(128, 1, 10878, NULL, NULL),
	(128, 1, 10879, NULL, NULL),
	(128, 1, 10880, NULL, NULL),
	(128, 1, 10881, NULL, NULL),
	(128, 1, 10882, NULL, NULL),
	(128, 1, 10883, NULL, NULL),
	(128, 1, 10884, NULL, NULL),
	(128, 1, 10885, NULL, NULL),
	(128, 1, 10886, NULL, NULL),
	(128, 1, 10887, NULL, NULL),
	(128, 1, 10888, NULL, NULL),
	(128, 1, 10889, NULL, NULL),
	(128, 1, 10890, NULL, NULL),
	(128, 1, 10891, NULL, NULL),
	(128, 1, 10892, NULL, NULL),
	(128, 1, 10893, NULL, NULL),
	(128, 1, 10894, NULL, NULL),
	(128, 1, 10895, NULL, NULL),
	(128, 1, 10896, NULL, NULL),
	(128, 1, 10897, NULL, NULL),
	(128, 1, 10898, NULL, NULL),
	(128, 1, 10899, NULL, NULL),
	(128, 1, 10900, NULL, NULL),
	(128, 1, 10901, NULL, NULL),
	(128, 1, 10902, NULL, NULL),
	(128, 1, 10903, NULL, NULL),
	(128, 1, 10904, NULL, NULL),
	(128, 1, 10905, NULL, NULL),
	(128, 1, 10906, NULL, NULL),
	(128, 1, 10907, NULL, NULL),
	(128, 1, 10908, NULL, NULL),
	(128, 1, 10909, NULL, NULL),
	(128, 1, 10910, NULL, NULL),
	(128, 1, 10911, NULL, NULL),
	(128, 1, 10912, NULL, NULL),
	(128, 1, 10913, NULL, NULL),
	(128, 1, 10914, NULL, NULL),
	(128, 1, 10915, NULL, NULL),
	(128, 1, 10916, NULL, NULL),
	(128, 1, 10917, NULL, NULL),
	(128, 1, 10918, NULL, NULL),
	(128, 1, 10919, NULL, NULL),
	(128, 1, 10920, NULL, NULL),
	(128, 1, 10921, NULL, NULL),
	(128, 1, 10922, NULL, NULL),
	(128, 1, 10923, NULL, NULL),
	(128, 1, 10924, NULL, NULL),
	(128, 1, 10925, NULL, NULL),
	(128, 1, 10926, NULL, NULL),
	(128, 1, 10927, NULL, NULL),
	(128, 1, 10928, NULL, NULL),
	(128, 1, 10929, NULL, NULL),
	(128, 1, 10930, NULL, NULL),
	(128, 1, 10931, NULL, NULL),
	(128, 1, 10932, NULL, NULL),
	(128, 1, 10933, NULL, NULL),
	(128, 1, 10934, NULL, NULL),
	(128, 1, 10935, NULL, NULL),
	(128, 1, 10936, NULL, NULL),
	(128, 1, 10937, NULL, NULL),
	(128, 1, 10938, NULL, NULL),
	(128, 1, 10939, NULL, NULL),
	(128, 1, 10940, NULL, NULL),
	(128, 1, 10941, NULL, NULL),
	(128, 1, 10942, NULL, NULL),
	(128, 1, 10943, NULL, NULL),
	(128, 1, 10944, NULL, NULL),
	(128, 1, 10945, NULL, NULL),
	(128, 1, 10946, NULL, NULL),
	(128, 1, 10947, NULL, NULL),
	(128, 1, 10948, NULL, NULL),
	(128, 1, 10949, NULL, NULL),
	(128, 1, 10950, NULL, NULL),
	(128, 1, 10951, NULL, NULL),
	(128, 1, 10952, NULL, NULL),
	(128, 1, 10953, NULL, NULL),
	(128, 1, 10954, NULL, NULL),
	(128, 1, 10955, NULL, NULL),
	(128, 1, 10956, NULL, NULL),
	(128, 1, 10957, NULL, NULL),
	(128, 1, 10958, NULL, NULL),
	(128, 1, 10959, NULL, NULL),
	(128, 1, 10960, NULL, NULL),
	(128, 1, 10961, NULL, NULL),
	(128, 1, 10962, NULL, NULL),
	(128, 1, 10963, NULL, NULL),
	(128, 1, 10964, NULL, NULL),
	(128, 1, 10965, NULL, NULL),
	(128, 1, 10966, NULL, NULL),
	(128, 1, 10967, NULL, NULL),
	(128, 1, 10968, NULL, NULL),
	(128, 1, 10969, NULL, NULL),
	(128, 1, 10970, NULL, NULL),
	(128, 1, 10971, NULL, NULL),
	(128, 1, 10972, NULL, NULL),
	(128, 1, 10973, NULL, NULL),
	(128, 1, 10974, NULL, NULL),
	(128, 1, 10975, NULL, NULL),
	(128, 1, 10976, NULL, NULL),
	(128, 1, 10977, NULL, NULL),
	(128, 1, 10978, NULL, NULL),
	(128, 1, 10979, NULL, NULL),
	(128, 1, 10980, NULL, NULL),
	(128, 1, 10981, NULL, NULL),
	(128, 1, 10982, NULL, NULL),
	(128, 1, 10983, NULL, NULL),
	(128, 1, 10984, NULL, NULL),
	(128, 1, 10985, NULL, NULL),
	(128, 1, 10986, NULL, NULL),
	(128, 1, 10987, NULL, NULL),
	(128, 1, 10988, NULL, NULL),
	(128, 1, 10989, NULL, NULL),
	(128, 1, 10990, NULL, NULL),
	(128, 1, 10991, NULL, NULL),
	(128, 1, 10992, NULL, NULL),
	(128, 1, 10993, NULL, NULL),
	(128, 1, 10994, NULL, NULL),
	(128, 1, 10995, NULL, NULL),
	(128, 1, 10996, NULL, NULL),
	(128, 1, 10997, NULL, NULL),
	(128, 1, 10998, NULL, NULL),
	(128, 1, 10999, NULL, NULL),
	(128, 1, 11000, NULL, NULL),
	(128, 1, 11001, NULL, NULL),
	(128, 1, 11002, NULL, NULL),
	(128, 1, 11003, NULL, NULL),
	(128, 1, 11004, NULL, NULL),
	(128, 1, 11005, NULL, NULL),
	(128, 1, 11006, NULL, NULL),
	(128, 1, 11007, NULL, NULL),
	(128, 1, 11008, NULL, NULL),
	(128, 1, 11009, NULL, NULL),
	(128, 1, 11010, NULL, NULL),
	(128, 1, 11011, NULL, NULL),
	(128, 1, 11012, NULL, NULL),
	(128, 1, 11013, NULL, NULL),
	(128, 1, 11014, NULL, NULL),
	(128, 1, 11015, NULL, NULL),
	(128, 1, 11016, NULL, NULL),
	(128, 1, 11017, NULL, NULL),
	(128, 1, 11018, NULL, NULL),
	(128, 1, 11019, NULL, NULL),
	(128, 1, 11020, NULL, NULL),
	(128, 1, 11021, NULL, NULL),
	(128, 1, 11022, NULL, NULL),
	(128, 1, 11023, NULL, NULL),
	(128, 1, 11024, NULL, NULL),
	(128, 1, 11025, NULL, NULL),
	(128, 1, 11026, NULL, NULL),
	(128, 1, 11027, NULL, NULL),
	(128, 1, 11028, NULL, NULL),
	(128, 1, 11029, NULL, NULL),
	(128, 1, 11030, NULL, NULL),
	(128, 1, 11031, NULL, NULL),
	(128, 1, 11032, NULL, NULL),
	(128, 1, 11033, NULL, NULL),
	(128, 1, 11034, NULL, NULL),
	(128, 1, 11035, NULL, NULL),
	(128, 1, 11036, NULL, NULL),
	(128, 1, 11037, NULL, NULL),
	(128, 1, 11038, NULL, NULL),
	(128, 1, 11039, NULL, NULL),
	(128, 1, 11040, NULL, NULL),
	(128, 1, 11041, NULL, NULL),
	(128, 1, 11042, NULL, NULL),
	(128, 1, 11043, NULL, NULL),
	(128, 1, 11044, NULL, NULL),
	(128, 1, 11045, NULL, NULL),
	(128, 1, 11046, NULL, NULL),
	(128, 1, 11047, NULL, NULL),
	(128, 1, 11048, NULL, NULL),
	(128, 1, 11049, NULL, NULL),
	(128, 1, 11050, NULL, NULL),
	(128, 1, 11051, NULL, NULL),
	(128, 1, 11052, NULL, NULL),
	(128, 1, 11053, NULL, NULL),
	(128, 1, 11054, NULL, NULL),
	(128, 1, 11055, NULL, NULL),
	(128, 1, 11056, NULL, NULL),
	(128, 1, 11057, NULL, NULL),
	(128, 1, 11058, NULL, NULL),
	(128, 1, 11059, NULL, NULL),
	(128, 1, 11060, NULL, NULL),
	(128, 1, 11061, NULL, NULL),
	(128, 1, 11062, NULL, NULL),
	(128, 1, 11063, NULL, NULL),
	(128, 1, 11064, NULL, NULL),
	(128, 1, 11065, NULL, NULL),
	(128, 1, 11066, NULL, NULL),
	(128, 1, 11067, NULL, NULL),
	(128, 1, 11068, NULL, NULL),
	(128, 1, 11069, NULL, NULL),
	(128, 1, 11070, NULL, NULL),
	(128, 1, 11071, NULL, NULL),
	(128, 1, 11072, NULL, NULL),
	(128, 1, 11073, NULL, NULL),
	(128, 1, 11074, NULL, NULL),
	(128, 1, 11075, NULL, NULL),
	(128, 1, 11076, NULL, NULL),
	(128, 1, 11077, NULL, NULL),
	(128, 1, 11078, NULL, NULL),
	(128, 1, 11079, NULL, NULL),
	(128, 1, 11080, NULL, NULL),
	(128, 1, 11081, NULL, NULL),
	(128, 1, 11082, NULL, NULL),
	(128, 1, 11083, NULL, NULL),
	(128, 1, 11084, NULL, NULL),
	(128, 1, 11085, NULL, NULL),
	(128, 1, 11086, NULL, NULL),
	(128, 1, 11087, NULL, NULL),
	(128, 1, 11088, NULL, NULL),
	(128, 1, 11089, NULL, NULL),
	(128, 1, 11090, NULL, NULL),
	(128, 1, 11091, NULL, NULL),
	(128, 1, 11092, NULL, NULL),
	(128, 1, 11093, NULL, NULL),
	(128, 1, 11094, NULL, NULL),
	(128, 1, 11095, NULL, NULL),
	(128, 1, 11096, NULL, NULL),
	(128, 1, 11097, NULL, NULL),
	(128, 1, 11098, NULL, NULL),
	(128, 1, 11099, NULL, NULL),
	(128, 1, 11100, NULL, NULL),
	(128, 1, 11101, NULL, NULL),
	(128, 1, 11102, NULL, NULL),
	(128, 1, 11103, NULL, NULL),
	(128, 1, 11104, NULL, NULL),
	(128, 1, 11105, NULL, NULL),
	(128, 1, 11106, NULL, NULL),
	(128, 1, 11107, NULL, NULL),
	(128, 1, 11108, NULL, NULL),
	(128, 1, 11109, NULL, NULL),
	(128, 1, 11110, NULL, NULL),
	(128, 1, 11111, NULL, NULL),
	(128, 1, 11112, NULL, NULL),
	(128, 1, 11113, NULL, NULL),
	(128, 1, 11114, NULL, NULL),
	(128, 1, 11115, NULL, NULL),
	(128, 1, 11116, NULL, NULL),
	(128, 1, 11117, NULL, NULL),
	(128, 1, 11118, NULL, NULL),
	(128, 1, 11119, NULL, NULL),
	(128, 1, 11120, NULL, NULL),
	(128, 1, 11121, NULL, NULL),
	(128, 1, 11122, NULL, NULL),
	(128, 1, 11123, NULL, NULL),
	(128, 1, 11124, NULL, NULL),
	(128, 1, 11125, NULL, NULL),
	(128, 1, 11126, NULL, NULL),
	(129, 0, 9999, NULL, NULL),
	(129, 1, 9999, NULL, NULL),
	(130, 0, 9999, NULL, NULL),
	(130, 1, 9999, NULL, NULL),
	(131, 0, 10003, NULL, NULL),
	(131, 0, 10029, NULL, NULL),
	(135, 1, 10000, NULL, 0),
	(135, 1, 10001, NULL, 0),
	(135, 1, 10002, NULL, 0),
	(135, 1, 10010, NULL, 0),
	(135, 1, 10011, NULL, 0),
	(135, 1, 10012, NULL, 0),
	(135, 1, 10013, NULL, 0),
	(135, 1, 10015, NULL, NULL),
	(135, 1, 10029, NULL, 0),
	(135, 1, 10031, NULL, NULL),
	(135, 1, 10038, NULL, NULL),
	(135, 1, 10041, NULL, NULL),
	(135, 1, 10045, NULL, NULL),
	(135, 1, 10085, NULL, NULL),
	(135, 1, 10090, NULL, NULL),
	(135, 1, 10091, NULL, NULL),
	(135, 1, 10109, NULL, NULL),
	(135, 1, 10269, NULL, 0),
	(135, 1, 10427, NULL, NULL),
	(135, 1, 10450, NULL, 0),
	(135, 1, 10451, NULL, 0),
	(135, 1, 10452, NULL, 0),
	(135, 1, 10530, NULL, 0),
	(135, 1, 10531, NULL, 0),
	(135, 1, 10532, NULL, 0),
	(135, 1, 10533, NULL, 0),
	(135, 1, 10534, NULL, 0),
	(135, 1, 10535, NULL, 0),
	(135, 1, 10761, NULL, 0),
	(135, 1, 10795, NULL, 0),
	(135, 1, 10840, NULL, 0),
	(135, 1, 10952, NULL, NULL),
	(135, 1, 10978, NULL, NULL),
	(136, 1, 10029, NULL, NULL),
	(136, 1, 10032, NULL, NULL),
	(136, 1, 10088, NULL, NULL),
	(136, 1, 10450, NULL, NULL),
	(136, 1, 10451, NULL, NULL),
	(136, 1, 10452, NULL, NULL),
	(136, 1, 10530, NULL, NULL),
	(136, 1, 10531, NULL, NULL),
	(136, 1, 10532, NULL, NULL),
	(136, 1, 10533, NULL, NULL),
	(136, 1, 10534, NULL, NULL),
	(136, 1, 10535, NULL, NULL),
	(136, 1, 10554, NULL, NULL),
	(136, 1, 10555, NULL, NULL),
	(136, 1, 10556, NULL, NULL),
	(136, 1, 10557, NULL, NULL),
	(136, 1, 10558, NULL, NULL),
	(136, 1, 10559, NULL, NULL),
	(136, 1, 10560, NULL, NULL),
	(136, 1, 10561, NULL, NULL),
	(136, 1, 10562, NULL, NULL),
	(136, 1, 10566, NULL, NULL),
	(136, 1, 10567, NULL, NULL),
	(136, 1, 10568, NULL, NULL),
	(136, 1, 10569, NULL, NULL),
	(137, 0, 10013, NULL, 0),
	(137, 0, 10015, NULL, NULL),
	(137, 0, 10018, NULL, NULL),
	(137, 0, 10029, NULL, NULL),
	(137, 0, 10045, NULL, NULL),
	(137, 0, 10049, NULL, NULL),
	(137, 0, 10050, NULL, NULL),
	(137, 0, 10051, NULL, NULL),
	(137, 0, 10053, NULL, NULL),
	(137, 0, 10109, NULL, NULL),
	(137, 0, 10110, NULL, NULL),
	(137, 0, 10254, NULL, NULL),
	(137, 0, 10271, NULL, NULL),
	(137, 0, 10292, NULL, NULL),
	(137, 0, 10423, NULL, NULL),
	(137, 0, 10426, NULL, NULL),
	(137, 0, 10432, NULL, NULL),
	(137, 0, 10511, NULL, NULL),
	(137, 0, 10518, NULL, NULL),
	(137, 0, 10525, NULL, NULL),
	(137, 0, 10552, NULL, NULL),
	(137, 0, 10575, NULL, NULL),
	(137, 0, 10640, NULL, NULL),
	(137, 0, 10806, NULL, NULL),
	(137, 0, 10809, NULL, NULL),
	(137, 0, 10811, NULL, NULL),
	(137, 0, 10812, NULL, NULL),
	(137, 0, 10813, NULL, NULL),
	(137, 0, 10814, NULL, NULL),
	(137, 0, 10815, NULL, NULL),
	(137, 0, 10816, NULL, NULL),
	(137, 0, 10817, NULL, NULL),
	(137, 0, 10818, NULL, NULL),
	(137, 0, 10819, NULL, NULL),
	(137, 0, 10820, NULL, NULL),
	(137, 0, 10821, NULL, NULL),
	(137, 0, 10822, NULL, NULL),
	(137, 0, 10823, NULL, NULL),
	(137, 0, 10824, NULL, NULL),
	(137, 0, 10825, NULL, NULL),
	(137, 0, 10826, NULL, NULL),
	(137, 0, 10827, NULL, NULL),
	(137, 0, 10828, NULL, NULL),
	(137, 0, 10829, NULL, NULL),
	(137, 0, 10830, NULL, NULL),
	(137, 0, 10831, NULL, NULL),
	(137, 0, 10832, NULL, NULL),
	(137, 0, 10833, NULL, NULL),
	(137, 0, 10834, NULL, NULL),
	(137, 0, 10835, NULL, NULL),
	(137, 0, 10836, NULL, NULL),
	(137, 0, 10842, NULL, 0),
	(137, 0, 10845, NULL, NULL),
	(137, 0, 10846, NULL, NULL),
	(137, 0, 10847, NULL, NULL),
	(137, 0, 10855, NULL, NULL),
	(137, 0, 10856, NULL, NULL),
	(137, 0, 10857, NULL, NULL),
	(137, 0, 10858, NULL, NULL),
	(137, 0, 10859, NULL, NULL),
	(137, 0, 10860, NULL, NULL),
	(137, 0, 10861, NULL, NULL),
	(137, 0, 10862, NULL, NULL),
	(137, 0, 10863, NULL, NULL),
	(137, 0, 10864, NULL, NULL),
	(137, 0, 10865, NULL, NULL),
	(137, 0, 10866, NULL, NULL),
	(137, 0, 10867, NULL, NULL),
	(137, 0, 10868, NULL, NULL),
	(137, 0, 10869, NULL, NULL),
	(137, 0, 10870, NULL, NULL),
	(137, 0, 10871, NULL, NULL),
	(137, 0, 10872, NULL, NULL),
	(137, 0, 10876, NULL, 0),
	(137, 1, 10008, NULL, NULL),
	(137, 1, 10010, NULL, 0),
	(137, 1, 10011, NULL, 0),
	(137, 1, 10012, NULL, NULL),
	(137, 1, 10013, NULL, NULL),
	(137, 1, 10015, NULL, NULL),
	(137, 1, 10018, NULL, NULL),
	(137, 1, 10030, NULL, NULL),
	(137, 1, 10031, NULL, NULL),
	(137, 1, 10033, NULL, NULL),
	(137, 1, 10034, NULL, NULL),
	(137, 1, 10041, NULL, NULL),
	(137, 1, 10045, NULL, NULL),
	(137, 1, 10048, NULL, NULL),
	(137, 1, 10050, NULL, NULL),
	(137, 1, 10053, NULL, NULL),
	(137, 1, 10065, NULL, NULL),
	(137, 1, 10076, NULL, NULL),
	(137, 1, 10084, NULL, NULL),
	(137, 1, 10085, NULL, NULL),
	(137, 1, 10099, NULL, NULL),
	(137, 1, 10102, NULL, NULL),
	(137, 1, 10104, NULL, NULL),
	(137, 1, 10105, NULL, NULL),
	(137, 1, 10106, NULL, NULL),
	(137, 1, 10107, NULL, NULL),
	(137, 1, 10108, NULL, NULL),
	(137, 1, 10109, NULL, NULL),
	(137, 1, 10110, NULL, NULL),
	(137, 1, 10112, NULL, NULL),
	(137, 1, 10113, NULL, NULL),
	(137, 1, 10114, NULL, NULL),
	(137, 1, 10213, NULL, NULL),
	(137, 1, 10252, NULL, NULL),
	(137, 1, 10257, NULL, NULL),
	(137, 1, 10291, NULL, NULL),
	(137, 1, 10294, NULL, NULL),
	(137, 1, 10418, NULL, NULL),
	(137, 1, 10432, NULL, NULL),
	(137, 1, 10450, NULL, NULL),
	(137, 1, 10451, NULL, NULL),
	(137, 1, 10452, NULL, NULL),
	(137, 1, 10465, NULL, NULL),
	(137, 1, 10485, NULL, NULL),
	(137, 1, 10583, NULL, NULL),
	(137, 1, 10584, NULL, NULL),
	(137, 1, 10585, NULL, NULL),
	(137, 1, 10590, NULL, NULL),
	(137, 1, 10591, NULL, NULL),
	(137, 1, 10592, NULL, NULL),
	(137, 1, 10593, NULL, NULL),
	(137, 1, 10642, NULL, NULL),
	(137, 1, 10748, NULL, NULL),
	(137, 1, 10749, NULL, NULL),
	(137, 1, 10750, NULL, NULL),
	(137, 1, 10751, NULL, NULL),
	(137, 1, 10752, NULL, NULL),
	(137, 1, 10753, NULL, NULL),
	(137, 1, 10754, NULL, NULL),
	(137, 1, 10755, NULL, NULL),
	(137, 1, 10756, NULL, NULL),
	(137, 1, 10757, NULL, NULL),
	(137, 1, 10758, NULL, NULL),
	(137, 1, 10759, NULL, NULL),
	(137, 1, 10760, NULL, NULL),
	(137, 1, 10761, NULL, NULL),
	(137, 1, 10762, NULL, NULL),
	(137, 1, 10763, NULL, NULL),
	(137, 1, 10764, NULL, NULL),
	(137, 1, 10765, NULL, NULL),
	(137, 1, 10766, NULL, NULL),
	(137, 1, 10767, NULL, NULL),
	(137, 1, 10768, NULL, NULL),
	(137, 1, 10837, NULL, NULL),
	(137, 1, 10838, NULL, NULL),
	(137, 1, 10839, NULL, NULL),
	(137, 1, 10840, NULL, NULL),
	(137, 1, 10842, NULL, 0),
	(137, 1, 10843, NULL, 0),
	(137, 1, 10844, NULL, 0),
	(137, 1, 10854, NULL, NULL),
	(137, 1, 10873, NULL, NULL),
	(137, 1, 10874, NULL, NULL),
	(137, 1, 10875, NULL, NULL),
	(137, 1, 10876, NULL, NULL),
	(137, 1, 10887, NULL, NULL),
	(139, 0, 10000, NULL, NULL),
	(139, 0, 10001, NULL, NULL),
	(139, 0, 10002, NULL, NULL),
	(139, 0, 10003, NULL, NULL),
	(139, 0, 10004, NULL, NULL),
	(139, 0, 10007, NULL, NULL),
	(139, 0, 10012, NULL, NULL),
	(139, 0, 10014, NULL, NULL),
	(139, 0, 10015, NULL, NULL),
	(139, 0, 10029, NULL, NULL),
	(139, 0, 10038, NULL, NULL),
	(139, 0, 10041, NULL, NULL),
	(139, 0, 10044, NULL, NULL),
	(139, 0, 10098, NULL, NULL),
	(139, 0, 10099, NULL, NULL),
	(139, 0, 10423, NULL, NULL),
	(139, 0, 10530, NULL, NULL),
	(139, 0, 10531, NULL, NULL),
	(139, 0, 10532, NULL, NULL),
	(139, 0, 10533, NULL, NULL),
	(139, 0, 10534, NULL, NULL),
	(139, 0, 10535, NULL, NULL),
	(139, 0, 10553, NULL, NULL),
	(139, 0, 10554, NULL, NULL),
	(139, 0, 10733, NULL, NULL),
	(139, 0, 10745, NULL, NULL),
	(139, 0, 10746, NULL, NULL),
	(139, 0, 10747, NULL, NULL),
	(139, 0, 10771, NULL, NULL),
	(139, 0, 10849, NULL, NULL),
	(139, 0, 10854, NULL, NULL),
	(139, 0, 10877, NULL, NULL),
	(139, 0, 10878, NULL, NULL),
	(139, 0, 10879, NULL, NULL),
	(139, 0, 10880, NULL, NULL),
	(139, 0, 10881, NULL, NULL),
	(139, 0, 10882, NULL, NULL),
	(139, 0, 10883, NULL, NULL),
	(139, 0, 10884, NULL, NULL),
	(139, 0, 10885, NULL, NULL),
	(139, 0, 10886, NULL, NULL),
	(139, 0, 10890, NULL, NULL),
	(139, 0, 10891, NULL, NULL),
	(139, 0, 10892, NULL, NULL),
	(139, 0, 10893, NULL, NULL),
	(139, 0, 10894, NULL, NULL),
	(139, 0, 10895, NULL, NULL),
	(139, 0, 10896, NULL, NULL),
	(139, 0, 10897, NULL, NULL),
	(139, 0, 10898, NULL, NULL),
	(139, 0, 10899, NULL, NULL),
	(139, 0, 10900, NULL, NULL),
	(139, 0, 10901, NULL, NULL),
	(139, 0, 10902, NULL, NULL),
	(139, 0, 10903, NULL, NULL),
	(139, 0, 10904, NULL, NULL),
	(139, 0, 10905, NULL, NULL),
	(139, 0, 10906, NULL, NULL),
	(139, 0, 10907, NULL, NULL),
	(139, 0, 10908, NULL, NULL),
	(139, 0, 10909, NULL, NULL),
	(139, 0, 10910, NULL, NULL),
	(139, 0, 10911, NULL, NULL),
	(139, 0, 10912, NULL, NULL),
	(139, 0, 10913, NULL, NULL),
	(139, 0, 10914, NULL, NULL),
	(139, 0, 10915, NULL, NULL),
	(139, 0, 10916, NULL, NULL),
	(139, 0, 10917, NULL, NULL),
	(139, 0, 10918, NULL, NULL),
	(139, 0, 10919, NULL, NULL),
	(139, 0, 10920, NULL, NULL),
	(139, 0, 10921, NULL, NULL),
	(139, 0, 10922, NULL, NULL),
	(139, 1, 10000, NULL, NULL),
	(139, 1, 10001, NULL, NULL),
	(139, 1, 10002, NULL, NULL),
	(139, 1, 10003, NULL, NULL),
	(139, 1, 10004, NULL, NULL),
	(139, 1, 10007, NULL, NULL),
	(139, 1, 10013, NULL, NULL),
	(139, 1, 10014, NULL, NULL),
	(139, 1, 10015, NULL, NULL),
	(139, 1, 10029, NULL, NULL),
	(139, 1, 10038, NULL, NULL),
	(139, 1, 10041, NULL, NULL),
	(139, 1, 10044, NULL, NULL),
	(139, 1, 10045, NULL, NULL),
	(139, 1, 10098, NULL, NULL),
	(139, 1, 10099, NULL, NULL),
	(139, 1, 10427, NULL, NULL),
	(139, 1, 10530, NULL, NULL),
	(139, 1, 10531, NULL, NULL),
	(139, 1, 10532, NULL, NULL),
	(139, 1, 10533, NULL, NULL),
	(139, 1, 10534, NULL, NULL),
	(139, 1, 10535, NULL, NULL),
	(139, 1, 10553, NULL, NULL),
	(139, 1, 10554, NULL, NULL),
	(139, 1, 10570, NULL, NULL),
	(139, 1, 10586, NULL, NULL),
	(139, 1, 10733, NULL, NULL),
	(139, 1, 10745, NULL, NULL),
	(139, 1, 10746, NULL, NULL),
	(139, 1, 10747, NULL, NULL),
	(139, 1, 10771, NULL, NULL),
	(139, 1, 10833, NULL, NULL),
	(139, 1, 10849, NULL, NULL),
	(139, 1, 10853, NULL, NULL),
	(139, 1, 10854, NULL, NULL),
	(139, 1, 10877, NULL, NULL),
	(139, 1, 10878, NULL, NULL),
	(139, 1, 10879, NULL, NULL),
	(139, 1, 10880, NULL, NULL),
	(139, 1, 10881, NULL, NULL),
	(139, 1, 10882, NULL, NULL),
	(139, 1, 10883, NULL, NULL),
	(139, 1, 10884, NULL, NULL),
	(139, 1, 10885, NULL, NULL),
	(139, 1, 10886, NULL, NULL),
	(139, 1, 10890, NULL, NULL),
	(139, 1, 10891, NULL, NULL),
	(139, 1, 10892, NULL, NULL),
	(139, 1, 10893, NULL, NULL),
	(139, 1, 10894, NULL, NULL),
	(139, 1, 10895, NULL, NULL),
	(139, 1, 10896, NULL, NULL),
	(139, 1, 10897, NULL, NULL),
	(139, 1, 10898, NULL, NULL),
	(139, 1, 10899, NULL, NULL),
	(139, 1, 10900, NULL, NULL),
	(139, 1, 10901, NULL, NULL),
	(139, 1, 10902, NULL, NULL),
	(139, 1, 10903, NULL, NULL),
	(139, 1, 10904, NULL, NULL),
	(139, 1, 10905, NULL, NULL),
	(139, 1, 10906, NULL, NULL),
	(139, 1, 10907, NULL, NULL),
	(139, 1, 10908, NULL, NULL),
	(139, 1, 10909, NULL, NULL),
	(139, 1, 10910, NULL, NULL),
	(139, 1, 10911, NULL, NULL),
	(139, 1, 10912, NULL, NULL),
	(139, 1, 10913, NULL, NULL),
	(139, 1, 10914, NULL, NULL),
	(139, 1, 10915, NULL, NULL),
	(139, 1, 10916, NULL, NULL),
	(139, 1, 10917, NULL, NULL),
	(139, 1, 10918, NULL, NULL),
	(139, 1, 10919, NULL, NULL),
	(139, 1, 10920, NULL, NULL),
	(139, 1, 10921, NULL, NULL),
	(139, 1, 10922, NULL, NULL),
	(139, 1, 11102, NULL, NULL),
	(139, 1, 11448, NULL, NULL),
	(139, 1, 11449, NULL, NULL),
	(139, 1, 11450, NULL, NULL),
	(139, 1, 11451, NULL, NULL),
	(139, 1, 11452, NULL, NULL),
	(139, 1, 11453, NULL, NULL),
	(139, 1, 11454, NULL, NULL),
	(139, 1, 11455, NULL, NULL),
	(139, 1, 11456, NULL, NULL),
	(139, 1, 11457, NULL, NULL),
	(139, 1, 11458, NULL, NULL),
	(139, 1, 11459, NULL, NULL),
	(139, 1, 11460, NULL, NULL),
	(139, 1, 11461, NULL, NULL),
	(139, 1, 11462, NULL, NULL),
	(139, 1, 11463, NULL, NULL),
	(139, 1, 11464, NULL, NULL),
	(139, 1, 11465, NULL, NULL),
	(139, 1, 11466, NULL, NULL),
	(139, 1, 11467, NULL, NULL),
	(139, 1, 11468, NULL, NULL),
	(139, 1, 11469, NULL, NULL),
	(139, 1, 11470, NULL, NULL),
	(139, 1, 11471, NULL, NULL),
	(139, 1, 11472, NULL, NULL),
	(139, 1, 11473, NULL, NULL),
	(139, 1, 11474, NULL, NULL),
	(139, 1, 11475, NULL, NULL),
	(139, 1, 11476, NULL, NULL),
	(139, 1, 11477, NULL, NULL),
	(139, 1, 11478, NULL, NULL),
	(139, 1, 11479, NULL, NULL),
	(139, 1, 11480, NULL, NULL),
	(139, 1, 11481, NULL, NULL),
	(139, 1, 11482, NULL, NULL),
	(139, 1, 11483, NULL, NULL),
	(139, 1, 11484, NULL, NULL),
	(139, 1, 11485, NULL, NULL),
	(139, 1, 11486, NULL, NULL),
	(139, 1, 11487, NULL, NULL),
	(139, 1, 11488, NULL, NULL),
	(139, 1, 11489, NULL, NULL),
	(139, 1, 11490, NULL, NULL),
	(139, 1, 11491, NULL, NULL),
	(139, 1, 11492, NULL, NULL),
	(139, 1, 11493, NULL, NULL),
	(139, 1, 11494, NULL, NULL),
	(139, 1, 11495, NULL, NULL),
	(139, 1, 11496, NULL, NULL),
	(139, 1, 11497, NULL, NULL),
	(139, 1, 11498, NULL, NULL),
	(139, 1, 11499, NULL, NULL),
	(139, 1, 11500, NULL, NULL),
	(139, 1, 11501, NULL, NULL),
	(139, 1, 11502, NULL, NULL),
	(139, 1, 11503, NULL, NULL),
	(139, 1, 11504, NULL, NULL),
	(139, 1, 11505, NULL, NULL),
	(139, 1, 11506, NULL, NULL),
	(139, 1, 11507, NULL, NULL),
	(139, 1, 11508, NULL, NULL),
	(139, 1, 11524, NULL, NULL),
	(139, 1, 11525, NULL, NULL),
	(139, 1, 11526, NULL, NULL),
	(139, 1, 11528, NULL, NULL),
	(139, 1, 11529, NULL, NULL),
	(139, 1, 11530, NULL, NULL),
	(139, 1, 11531, NULL, NULL),
	(139, 1, 11532, NULL, NULL),
	(139, 1, 11533, NULL, NULL),
	(139, 1, 11534, NULL, NULL),
	(139, 1, 11535, NULL, NULL),
	(140, 1, 10000, NULL, NULL),
	(140, 1, 10001, NULL, NULL),
	(140, 1, 10002, NULL, NULL),
	(140, 1, 10003, NULL, NULL),
	(140, 1, 10014, NULL, NULL),
	(140, 1, 10015, NULL, NULL),
	(140, 1, 10029, NULL, NULL),
	(140, 1, 10096, NULL, NULL),
	(140, 1, 10109, NULL, NULL),
	(140, 1, 10427, NULL, NULL),
	(140, 1, 10524, NULL, NULL),
	(140, 1, 10530, NULL, NULL),
	(140, 1, 10531, NULL, NULL),
	(140, 1, 10532, NULL, NULL),
	(140, 1, 10533, NULL, NULL),
	(140, 1, 10534, NULL, NULL),
	(140, 1, 10535, NULL, NULL),
	(140, 1, 10548, NULL, NULL),
	(140, 1, 10553, NULL, NULL),
	(140, 1, 10597, NULL, NULL),
	(140, 1, 10744, NULL, NULL),
	(140, 1, 10745, NULL, NULL),
	(140, 1, 10746, NULL, NULL),
	(140, 1, 10747, NULL, NULL),
	(140, 1, 10776, NULL, NULL),
	(140, 1, 10777, NULL, NULL),
	(140, 1, 10849, NULL, NULL),
	(140, 1, 10850, NULL, NULL),
	(140, 1, 10851, NULL, NULL),
	(140, 1, 10852, NULL, NULL),
	(140, 1, 10853, NULL, NULL),
	(143, 1, 10000, NULL, NULL),
	(143, 1, 10001, NULL, NULL),
	(143, 1, 10002, NULL, NULL),
	(143, 1, 10012, NULL, NULL),
	(143, 1, 10014, NULL, NULL),
	(143, 1, 10015, NULL, NULL),
	(143, 1, 10029, NULL, NULL),
	(143, 1, 10048, NULL, NULL),
	(143, 1, 10549, NULL, NULL),
	(143, 1, 10550, NULL, NULL),
	(143, 1, 10551, NULL, NULL),
	(143, 1, 10607, NULL, NULL),
	(143, 1, 10608, NULL, NULL),
	(143, 1, 10609, NULL, NULL),
	(143, 1, 10610, NULL, NULL),
	(143, 1, 10611, NULL, NULL),
	(143, 1, 10612, NULL, NULL),
	(143, 1, 10613, NULL, NULL),
	(143, 1, 10614, NULL, NULL),
	(143, 1, 10615, NULL, NULL),
	(143, 1, 10616, NULL, NULL),
	(143, 1, 10617, NULL, NULL),
	(143, 1, 10618, NULL, NULL),
	(143, 1, 10619, NULL, NULL),
	(143, 1, 10620, NULL, NULL),
	(143, 1, 10621, NULL, NULL),
	(143, 1, 10622, NULL, NULL),
	(143, 1, 10623, NULL, NULL),
	(143, 1, 10624, NULL, NULL),
	(143, 1, 10625, NULL, NULL),
	(143, 1, 10626, NULL, NULL),
	(143, 1, 10627, NULL, NULL),
	(143, 1, 10628, NULL, NULL),
	(143, 1, 10629, NULL, NULL),
	(143, 1, 10630, NULL, NULL),
	(143, 1, 10631, NULL, NULL),
	(143, 1, 10632, NULL, NULL),
	(143, 1, 10633, NULL, NULL),
	(143, 1, 10634, NULL, NULL),
	(143, 1, 10635, NULL, NULL),
	(143, 1, 10636, NULL, NULL),
	(143, 1, 10637, NULL, NULL),
	(143, 1, 10638, NULL, NULL),
	(143, 1, 10639, NULL, NULL),
	(143, 1, 10640, NULL, NULL),
	(143, 1, 10641, NULL, NULL),
	(143, 1, 10642, NULL, NULL),
	(143, 1, 10643, NULL, NULL),
	(143, 1, 10644, NULL, NULL),
	(143, 1, 10645, NULL, NULL),
	(143, 1, 10646, NULL, NULL),
	(143, 1, 10647, NULL, NULL),
	(143, 1, 10648, NULL, NULL),
	(143, 1, 10649, NULL, NULL),
	(143, 1, 10650, NULL, NULL),
	(143, 1, 10651, NULL, NULL),
	(143, 1, 10652, NULL, NULL),
	(143, 1, 10653, NULL, NULL),
	(143, 1, 10654, NULL, NULL),
	(143, 1, 10655, NULL, NULL),
	(143, 1, 10656, NULL, NULL),
	(143, 1, 10657, NULL, NULL),
	(143, 1, 10658, NULL, NULL),
	(143, 1, 10659, NULL, NULL),
	(143, 1, 10660, NULL, NULL),
	(143, 1, 10661, NULL, NULL),
	(143, 1, 10662, NULL, NULL),
	(143, 1, 10663, NULL, NULL),
	(143, 1, 10664, NULL, NULL),
	(143, 1, 10665, NULL, NULL),
	(143, 1, 10668, NULL, NULL),
	(143, 1, 10669, NULL, NULL),
	(143, 1, 10674, NULL, NULL),
	(143, 1, 10675, NULL, NULL),
	(143, 1, 10676, NULL, NULL),
	(143, 1, 10677, NULL, NULL),
	(143, 1, 10678, NULL, NULL),
	(143, 1, 10679, NULL, NULL),
	(143, 1, 10682, NULL, NULL),
	(143, 1, 10733, NULL, NULL),
	(143, 1, 10744, NULL, NULL),
	(143, 1, 10894, NULL, NULL),
	(143, 1, 10895, NULL, NULL),
	(143, 1, 10896, NULL, NULL),
	(144, 0, 9999, NULL, NULL),
	(144, 0, 10437, NULL, NULL),
	(144, 0, 10438, NULL, NULL),
	(144, 0, 10439, NULL, NULL),
	(144, 0, 10440, NULL, NULL),
	(144, 0, 10441, NULL, NULL),
	(144, 0, 10442, NULL, NULL),
	(144, 0, 10443, NULL, NULL),
	(144, 0, 10444, NULL, NULL),
	(144, 0, 10445, NULL, NULL),
	(144, 1, 9999, NULL, NULL),
	(144, 1, 10000, NULL, NULL),
	(144, 1, 10001, NULL, NULL),
	(144, 1, 10002, NULL, NULL),
	(144, 1, 10008, NULL, NULL),
	(144, 1, 10009, NULL, NULL),
	(144, 1, 10014, NULL, NULL),
	(144, 1, 10021, NULL, NULL),
	(144, 1, 10022, NULL, NULL),
	(144, 1, 10039, NULL, NULL),
	(144, 1, 10040, NULL, NULL),
	(144, 1, 10041, NULL, NULL),
	(144, 1, 10042, NULL, NULL),
	(144, 1, 10045, NULL, NULL),
	(144, 1, 10048, NULL, NULL),
	(144, 1, 10049, NULL, NULL),
	(144, 1, 10088, NULL, NULL),
	(144, 1, 10108, NULL, NULL),
	(144, 1, 10209, NULL, NULL),
	(144, 1, 10273, NULL, NULL),
	(144, 1, 10274, NULL, NULL),
	(144, 1, 10407, NULL, NULL),
	(144, 1, 10414, NULL, NULL),
	(144, 1, 10415, NULL, NULL),
	(144, 1, 10416, NULL, NULL),
	(144, 1, 10417, NULL, NULL),
	(144, 1, 10418, NULL, NULL),
	(144, 1, 10419, NULL, NULL),
	(144, 1, 10420, NULL, NULL),
	(144, 1, 10421, NULL, NULL),
	(144, 1, 10422, NULL, NULL),
	(144, 1, 10423, NULL, NULL),
	(144, 1, 10424, NULL, NULL),
	(144, 1, 10425, NULL, NULL),
	(144, 1, 10426, NULL, NULL),
	(144, 1, 10427, NULL, NULL),
	(144, 1, 10428, NULL, NULL),
	(144, 1, 10429, NULL, NULL),
	(144, 1, 10430, NULL, NULL),
	(144, 1, 10431, NULL, NULL),
	(144, 1, 10432, NULL, NULL),
	(144, 1, 10433, NULL, NULL),
	(144, 1, 10434, NULL, NULL),
	(144, 1, 10435, NULL, NULL),
	(144, 1, 10436, NULL, NULL),
	(145, 1, 10008, NULL, NULL),
	(145, 1, 10010, NULL, 0),
	(145, 1, 10011, NULL, 0),
	(145, 1, 10012, NULL, NULL),
	(145, 1, 10013, NULL, NULL),
	(145, 1, 10015, NULL, NULL),
	(145, 1, 10029, NULL, NULL),
	(145, 1, 10041, NULL, NULL),
	(145, 1, 10042, NULL, NULL),
	(145, 1, 10045, NULL, NULL),
	(145, 1, 10046, NULL, NULL),
	(145, 1, 10048, NULL, NULL),
	(145, 1, 10085, NULL, NULL),
	(145, 1, 10090, NULL, NULL),
	(145, 1, 10091, NULL, NULL),
	(145, 1, 10096, NULL, NULL),
	(145, 1, 10097, NULL, NULL),
	(145, 1, 10109, NULL, 0),
	(145, 1, 10276, NULL, NULL),
	(145, 1, 10418, NULL, NULL),
	(145, 1, 10426, NULL, NULL),
	(145, 1, 10432, NULL, NULL),
	(145, 1, 10680, NULL, NULL),
	(145, 1, 10713, NULL, NULL),
	(145, 1, 10727, NULL, NULL),
	(145, 1, 10749, NULL, NULL),
	(145, 1, 10759, NULL, NULL),
	(145, 1, 10771, NULL, NULL),
	(145, 1, 10794, NULL, NULL),
	(145, 1, 10806, NULL, NULL),
	(145, 1, 10833, NULL, NULL),
	(145, 1, 10840, NULL, NULL),
	(145, 1, 10885, NULL, NULL),
	(145, 1, 10953, NULL, NULL),
	(145, 1, 10954, NULL, NULL),
	(145, 1, 10955, NULL, NULL),
	(145, 1, 10956, NULL, NULL),
	(145, 1, 10959, NULL, NULL),
	(145, 1, 10960, NULL, NULL),
	(145, 1, 10961, NULL, NULL),
	(145, 1, 10962, NULL, NULL),
	(145, 1, 10963, NULL, NULL),
	(145, 1, 10964, NULL, NULL),
	(145, 1, 10965, NULL, NULL),
	(145, 1, 10966, NULL, NULL),
	(145, 1, 10967, NULL, NULL),
	(145, 1, 10968, NULL, NULL),
	(145, 1, 10969, NULL, NULL),
	(145, 1, 10970, NULL, NULL),
	(145, 1, 10971, NULL, NULL),
	(145, 1, 10972, NULL, NULL),
	(145, 1, 10973, NULL, NULL),
	(145, 1, 10974, NULL, NULL),
	(145, 1, 10975, NULL, NULL),
	(145, 1, 10976, NULL, NULL),
	(145, 1, 10977, NULL, NULL),
	(145, 1, 10978, NULL, NULL),
	(145, 1, 10979, NULL, NULL),
	(145, 1, 10980, NULL, NULL),
	(145, 1, 10981, NULL, 0),
	(147, 1, 10000, NULL, NULL),
	(147, 1, 10001, NULL, NULL),
	(147, 1, 10002, NULL, NULL),
	(147, 1, 10029, NULL, NULL),
	(147, 1, 10547, NULL, NULL),
	(147, 1, 10548, NULL, NULL),
	(147, 1, 10745, NULL, NULL),
	(147, 1, 10746, NULL, NULL),
	(147, 1, 10747, NULL, NULL),
	(148, 1, 10000, NULL, 0),
	(148, 1, 10001, NULL, 0),
	(148, 1, 10002, NULL, 0),
	(148, 1, 10009, 0, NULL),
	(148, 1, 10012, NULL, NULL),
	(148, 1, 10013, NULL, NULL),
	(148, 1, 10014, 0, NULL),
	(148, 1, 10015, NULL, NULL),
	(148, 1, 10029, 0, NULL),
	(148, 1, 10038, 0, NULL),
	(148, 1, 10041, NULL, NULL),
	(148, 1, 10048, NULL, NULL),
	(148, 1, 10063, NULL, 0),
	(148, 1, 10284, NULL, NULL),
	(148, 1, 10429, NULL, 0),
	(148, 1, 10549, NULL, 0),
	(148, 1, 10550, NULL, 0),
	(148, 1, 10551, NULL, 0),
	(148, 1, 10553, 0, NULL),
	(148, 1, 10603, 0, NULL),
	(148, 1, 10680, 0, NULL),
	(148, 1, 10687, 0, NULL),
	(148, 1, 10704, 0, NULL),
	(148, 1, 10705, 0, NULL),
	(148, 1, 10716, NULL, NULL),
	(148, 1, 10772, 0, NULL),
	(148, 1, 10941, 0, NULL),
	(148, 1, 10942, 0, NULL),
	(148, 1, 10943, 0, NULL),
	(148, 1, 10944, 0, NULL),
	(148, 1, 10945, NULL, NULL),
	(148, 1, 10959, NULL, NULL),
	(148, 1, 11075, 0, NULL),
	(148, 1, 11076, 0, NULL),
	(148, 1, 11077, 0, NULL),
	(148, 1, 11078, 0, NULL),
	(148, 1, 11079, 0, NULL),
	(148, 1, 11080, 0, NULL),
	(148, 1, 11081, 0, NULL),
	(148, 1, 11082, 0, NULL),
	(148, 1, 11083, 0, NULL),
	(148, 1, 11084, NULL, 0),
	(148, 1, 11085, NULL, 0),
	(148, 1, 11086, NULL, 0),
	(148, 1, 11087, NULL, 0),
	(148, 1, 11088, NULL, 0),
	(154, 1, 10000, NULL, NULL),
	(154, 1, 10001, NULL, NULL),
	(154, 1, 10002, NULL, NULL),
	(154, 1, 10008, NULL, NULL),
	(154, 1, 10012, NULL, NULL),
	(154, 1, 10014, NULL, NULL),
	(154, 1, 10029, NULL, NULL),
	(154, 1, 10032, NULL, NULL),
	(154, 1, 10044, NULL, NULL),
	(154, 1, 10063, NULL, NULL),
	(154, 1, 10088, NULL, NULL),
	(154, 1, 10109, NULL, NULL),
	(154, 1, 10268, NULL, NULL),
	(154, 1, 10269, NULL, NULL),
	(154, 1, 10272, NULL, NULL),
	(154, 1, 10273, NULL, NULL),
	(154, 1, 10284, NULL, NULL),
	(154, 1, 10422, NULL, NULL),
	(154, 1, 10423, NULL, NULL),
	(154, 1, 10520, NULL, NULL),
	(154, 1, 10586, NULL, NULL),
	(154, 1, 10589, NULL, NULL),
	(154, 1, 10713, NULL, NULL),
	(154, 1, 10715, NULL, NULL),
	(154, 1, 10716, NULL, NULL),
	(154, 1, 10717, NULL, NULL),
	(154, 1, 10718, NULL, NULL),
	(154, 1, 10719, NULL, NULL),
	(154, 1, 10720, NULL, NULL),
	(154, 1, 10721, NULL, NULL),
	(154, 1, 10722, NULL, NULL),
	(154, 1, 10723, NULL, NULL),
	(154, 1, 10724, NULL, NULL),
	(154, 1, 10725, NULL, NULL),
	(154, 1, 10726, NULL, NULL),
	(154, 1, 10727, NULL, NULL),
	(154, 1, 10728, NULL, NULL),
	(154, 1, 10729, NULL, NULL),
	(154, 1, 10730, NULL, NULL),
	(154, 1, 10731, NULL, NULL),
	(154, 1, 10732, NULL, NULL),
	(154, 1, 10733, NULL, NULL),
	(154, 1, 10734, NULL, NULL),
	(154, 1, 10735, NULL, NULL),
	(154, 1, 10736, NULL, NULL),
	(154, 1, 10737, NULL, NULL),
	(154, 1, 10738, NULL, NULL),
	(154, 1, 10739, NULL, NULL),
	(154, 1, 10740, NULL, NULL),
	(157, 1, 3101, NULL, NULL),
	(157, 1, 10003, NULL, NULL),
	(157, 1, 10029, NULL, NULL),
	(157, 1, 10032, NULL, NULL),
	(157, 1, 10080, NULL, 0),
	(157, 1, 10085, NULL, NULL),
	(157, 1, 10109, NULL, NULL),
	(157, 1, 10302, NULL, NULL),
	(157, 1, 10587, NULL, NULL),
	(157, 1, 10588, NULL, NULL),
	(157, 1, 10589, NULL, NULL),
	(157, 1, 10597, NULL, NULL),
	(157, 1, 10602, NULL, 0),
	(157, 1, 10603, NULL, NULL),
	(157, 1, 10687, NULL, NULL),
	(157, 1, 10704, NULL, NULL),
	(157, 1, 10767, NULL, 0),
	(157, 1, 10854, NULL, 0),
	(157, 1, 10972, NULL, 0),
	(157, 1, 11074, NULL, NULL),
	(157, 1, 11077, NULL, NULL),
	(157, 1, 11111, NULL, NULL),
	(157, 1, 11112, NULL, NULL),
	(157, 1, 11113, NULL, NULL),
	(157, 1, 11114, NULL, NULL),
	(157, 1, 11552, NULL, NULL),
	(165, 1, 10000, NULL, NULL),
	(165, 1, 10001, NULL, NULL),
	(165, 1, 10002, NULL, NULL),
	(165, 1, 10015, NULL, NULL),
	(165, 1, 10053, NULL, NULL),
	(165, 1, 10087, NULL, NULL),
	(165, 1, 10802, NULL, NULL),
	(165, 1, 10803, NULL, NULL),
	(165, 1, 10804, NULL, NULL),
	(165, 1, 10805, NULL, NULL),
	(165, 1, 10806, NULL, NULL),
	(165, 1, 10807, NULL, NULL),
	(165, 1, 10808, NULL, NULL),
	(165, 1, 10809, NULL, NULL),
	(165, 1, 10810, NULL, NULL),
	(168, 1, 10000, NULL, NULL),
	(168, 1, 10001, NULL, NULL),
	(168, 1, 10002, NULL, NULL),
	(168, 1, 10029, NULL, NULL),
	(168, 1, 10701, NULL, NULL),
	(168, 1, 10707, NULL, NULL),
	(168, 1, 10769, NULL, NULL),
	(168, 1, 10770, NULL, NULL),
	(188, 1, 10008, NULL, NULL),
	(188, 1, 10009, NULL, NULL),
	(188, 1, 10012, NULL, NULL),
	(188, 1, 10029, NULL, NULL),
	(188, 1, 10039, NULL, NULL),
	(188, 1, 10040, NULL, NULL),
	(188, 1, 10041, NULL, NULL),
	(188, 1, 10042, NULL, NULL),
	(188, 1, 10045, NULL, NULL),
	(188, 1, 10049, NULL, NULL),
	(188, 1, 10108, NULL, NULL),
	(188, 1, 10407, NULL, NULL),
	(188, 1, 10414, NULL, NULL),
	(188, 1, 10415, NULL, NULL),
	(188, 1, 10416, NULL, NULL),
	(188, 1, 10417, NULL, NULL),
	(188, 1, 10418, NULL, NULL),
	(188, 1, 10422, NULL, NULL),
	(188, 1, 10423, NULL, NULL),
	(188, 1, 10424, NULL, NULL),
	(188, 1, 10425, NULL, NULL),
	(188, 1, 10426, NULL, NULL),
	(188, 1, 10427, NULL, NULL),
	(188, 1, 10428, NULL, NULL),
	(188, 1, 10429, NULL, NULL),
	(188, 1, 10430, NULL, NULL),
	(188, 1, 10431, NULL, NULL),
	(188, 1, 10432, NULL, NULL),
	(188, 1, 10435, NULL, NULL),
	(188, 1, 10436, NULL, NULL),
	(188, 1, 10447, NULL, NULL),
	(188, 1, 10597, NULL, NULL),
	(188, 1, 10799, NULL, NULL),
	(188, 1, 10800, NULL, NULL),
	(188, 1, 10801, NULL, NULL),
	(189, 0, 10000, NULL, NULL),
	(189, 0, 10001, NULL, NULL),
	(189, 0, 10002, NULL, NULL),
	(189, 0, 10003, NULL, NULL),
	(189, 0, 10014, NULL, NULL),
	(189, 0, 10015, NULL, NULL),
	(189, 0, 10109, NULL, NULL),
	(189, 0, 10111, NULL, NULL),
	(189, 0, 10292, NULL, NULL),
	(189, 0, 10553, NULL, NULL),
	(189, 0, 10610, NULL, NULL),
	(189, 0, 10806, NULL, NULL),
	(189, 0, 10833, NULL, NULL),
	(189, 0, 11074, NULL, NULL),
	(190, 0, 10400, NULL, NULL),
	(190, 0, 10401, NULL, NULL),
	(197, 0, 10013, NULL, 0),
	(197, 0, 10015, NULL, NULL),
	(197, 0, 10018, NULL, NULL),
	(197, 0, 10029, NULL, NULL),
	(197, 0, 10045, NULL, NULL),
	(197, 0, 10049, NULL, NULL),
	(197, 0, 10050, NULL, NULL),
	(197, 0, 10051, NULL, NULL),
	(197, 0, 10053, NULL, NULL),
	(197, 0, 10109, NULL, NULL),
	(197, 0, 10110, NULL, NULL),
	(197, 0, 10254, NULL, NULL),
	(197, 0, 10271, NULL, NULL),
	(197, 0, 10292, NULL, NULL),
	(197, 0, 10423, NULL, NULL),
	(197, 0, 10426, NULL, NULL),
	(197, 0, 10432, NULL, NULL),
	(197, 0, 10511, NULL, NULL),
	(197, 0, 10518, NULL, NULL),
	(197, 0, 10525, NULL, NULL),
	(197, 0, 10552, NULL, NULL),
	(197, 0, 10575, NULL, NULL),
	(197, 0, 10640, NULL, NULL),
	(197, 0, 10806, NULL, NULL),
	(197, 0, 10809, NULL, NULL),
	(197, 0, 10811, NULL, NULL),
	(197, 0, 10812, NULL, NULL),
	(197, 0, 10813, NULL, NULL),
	(197, 0, 10814, NULL, NULL),
	(197, 0, 10815, NULL, NULL),
	(197, 0, 10816, NULL, NULL),
	(197, 0, 10817, NULL, NULL),
	(197, 0, 10818, NULL, NULL),
	(197, 0, 10819, NULL, NULL),
	(197, 0, 10820, NULL, NULL),
	(197, 0, 10821, NULL, NULL),
	(197, 0, 10822, NULL, NULL),
	(197, 0, 10823, NULL, NULL),
	(197, 0, 10824, NULL, NULL),
	(197, 0, 10825, NULL, NULL),
	(197, 0, 10826, NULL, NULL),
	(197, 0, 10827, NULL, NULL),
	(197, 0, 10828, NULL, NULL),
	(197, 0, 10829, NULL, NULL),
	(197, 0, 10830, NULL, NULL),
	(197, 0, 10831, NULL, NULL),
	(197, 0, 10832, NULL, NULL),
	(197, 0, 10833, NULL, NULL),
	(197, 0, 10834, NULL, NULL),
	(197, 0, 10835, NULL, NULL),
	(197, 0, 10836, NULL, NULL),
	(197, 0, 10842, NULL, 0),
	(197, 0, 10845, NULL, NULL),
	(197, 0, 10846, NULL, NULL),
	(197, 0, 10847, NULL, NULL),
	(197, 0, 10855, NULL, NULL),
	(197, 0, 10856, NULL, NULL),
	(197, 0, 10857, NULL, NULL),
	(197, 0, 10858, NULL, NULL),
	(197, 0, 10859, NULL, NULL),
	(197, 0, 10860, NULL, NULL),
	(197, 0, 10861, NULL, NULL),
	(197, 0, 10862, NULL, NULL),
	(197, 0, 10863, NULL, NULL),
	(197, 0, 10864, NULL, NULL),
	(197, 0, 10865, NULL, NULL),
	(197, 0, 10866, NULL, NULL),
	(197, 0, 10867, NULL, NULL),
	(197, 0, 10868, NULL, NULL),
	(197, 0, 10869, NULL, NULL),
	(197, 0, 10870, NULL, NULL),
	(197, 0, 10871, NULL, NULL),
	(197, 0, 10872, NULL, NULL),
	(197, 0, 10876, NULL, 0),
	(197, 1, 10008, NULL, NULL),
	(197, 1, 10010, NULL, 0),
	(197, 1, 10011, NULL, 0),
	(197, 1, 10012, NULL, NULL),
	(197, 1, 10013, NULL, NULL),
	(197, 1, 10015, NULL, NULL),
	(197, 1, 10018, NULL, NULL),
	(197, 1, 10030, NULL, NULL),
	(197, 1, 10031, NULL, NULL),
	(197, 1, 10033, NULL, NULL),
	(197, 1, 10034, NULL, NULL),
	(197, 1, 10041, NULL, NULL),
	(197, 1, 10045, NULL, NULL),
	(197, 1, 10048, NULL, NULL),
	(197, 1, 10050, NULL, NULL),
	(197, 1, 10053, NULL, NULL),
	(197, 1, 10065, NULL, NULL),
	(197, 1, 10076, NULL, NULL),
	(197, 1, 10084, NULL, NULL),
	(197, 1, 10085, NULL, NULL),
	(197, 1, 10099, NULL, NULL),
	(197, 1, 10102, NULL, NULL),
	(197, 1, 10104, NULL, NULL),
	(197, 1, 10105, NULL, NULL),
	(197, 1, 10106, NULL, NULL),
	(197, 1, 10107, NULL, NULL),
	(197, 1, 10108, NULL, NULL),
	(197, 1, 10109, NULL, NULL),
	(197, 1, 10110, NULL, NULL),
	(197, 1, 10112, NULL, NULL),
	(197, 1, 10113, NULL, NULL),
	(197, 1, 10114, NULL, NULL),
	(197, 1, 10213, NULL, NULL),
	(197, 1, 10252, NULL, NULL),
	(197, 1, 10257, NULL, NULL),
	(197, 1, 10291, NULL, NULL),
	(197, 1, 10294, NULL, NULL),
	(197, 1, 10418, NULL, NULL),
	(197, 1, 10432, NULL, NULL),
	(197, 1, 10450, NULL, NULL),
	(197, 1, 10451, NULL, NULL),
	(197, 1, 10452, NULL, NULL),
	(197, 1, 10465, NULL, NULL),
	(197, 1, 10485, NULL, NULL),
	(197, 1, 10583, NULL, NULL),
	(197, 1, 10584, NULL, NULL),
	(197, 1, 10585, NULL, NULL),
	(197, 1, 10590, NULL, NULL),
	(197, 1, 10591, NULL, NULL),
	(197, 1, 10592, NULL, NULL),
	(197, 1, 10593, NULL, NULL),
	(197, 1, 10642, NULL, NULL),
	(197, 1, 10748, NULL, NULL),
	(197, 1, 10749, NULL, NULL),
	(197, 1, 10750, NULL, NULL),
	(197, 1, 10751, NULL, NULL),
	(197, 1, 10752, NULL, NULL),
	(197, 1, 10753, NULL, NULL),
	(197, 1, 10754, NULL, NULL),
	(197, 1, 10755, NULL, NULL),
	(197, 1, 10756, NULL, NULL),
	(197, 1, 10757, NULL, NULL),
	(197, 1, 10758, NULL, NULL),
	(197, 1, 10759, NULL, NULL),
	(197, 1, 10760, NULL, NULL),
	(197, 1, 10761, NULL, NULL),
	(197, 1, 10762, NULL, NULL),
	(197, 1, 10763, NULL, NULL),
	(197, 1, 10764, NULL, NULL),
	(197, 1, 10765, NULL, NULL),
	(197, 1, 10766, NULL, NULL),
	(197, 1, 10767, NULL, NULL),
	(197, 1, 10768, NULL, NULL),
	(197, 1, 10837, NULL, NULL),
	(197, 1, 10838, NULL, NULL),
	(197, 1, 10839, NULL, NULL),
	(197, 1, 10840, NULL, NULL),
	(197, 1, 10842, NULL, 0),
	(197, 1, 10843, NULL, 0),
	(197, 1, 10844, NULL, 0),
	(197, 1, 10854, NULL, NULL),
	(197, 1, 10873, NULL, NULL),
	(197, 1, 10874, NULL, NULL),
	(197, 1, 10875, NULL, NULL),
	(197, 1, 10876, NULL, NULL),
	(197, 1, 10887, NULL, NULL),
	(200, 1, 10008, NULL, NULL),
	(200, 1, 10029, NULL, NULL),
	(200, 1, 10043, NULL, NULL),
	(200, 1, 10242, NULL, NULL),
	(200, 1, 10323, NULL, NULL),
	(200, 1, 10324, NULL, NULL),
	(200, 1, 10325, NULL, NULL),
	(200, 1, 10326, NULL, NULL),
	(200, 1, 10327, NULL, NULL),
	(200, 1, 10328, NULL, NULL),
	(200, 1, 10329, NULL, NULL),
	(200, 1, 10330, NULL, NULL),
	(200, 1, 10429, NULL, NULL),
	(200, 1, 10430, NULL, NULL),
	(200, 1, 10431, NULL, NULL),
	(200, 1, 10540, NULL, NULL),
	(200, 1, 10982, NULL, NULL),
	(200, 1, 10983, NULL, NULL),
	(200, 1, 10984, NULL, NULL),
	(200, 1, 10985, NULL, NULL),
	(200, 1, 10986, NULL, NULL),
	(200, 1, 10987, NULL, NULL),
	(200, 1, 10988, NULL, NULL),
	(200, 1, 10989, NULL, NULL),
	(200, 1, 10990, NULL, NULL),
	(200, 1, 10991, NULL, NULL),
	(200, 1, 10992, NULL, NULL),
	(200, 1, 10993, NULL, NULL),
	(200, 1, 10994, NULL, NULL),
	(200, 1, 10995, NULL, NULL),
	(200, 1, 10996, NULL, NULL),
	(200, 1, 10997, NULL, NULL),
	(200, 1, 10998, NULL, NULL),
	(200, 1, 10999, NULL, NULL),
	(200, 1, 11000, NULL, NULL),
	(200, 1, 11001, NULL, NULL),
	(200, 1, 11002, NULL, NULL),
	(200, 1, 11003, NULL, NULL),
	(200, 1, 11004, NULL, NULL),
	(200, 1, 11005, NULL, NULL),
	(200, 1, 11006, NULL, NULL),
	(200, 1, 11007, NULL, NULL),
	(200, 1, 11008, NULL, NULL),
	(200, 1, 11009, NULL, NULL),
	(200, 1, 11010, NULL, NULL),
	(200, 1, 11011, NULL, NULL),
	(200, 1, 11012, NULL, NULL),
	(200, 1, 11013, NULL, NULL),
	(203, 0, 10015, NULL, NULL),
	(203, 0, 10108, NULL, NULL),
	(203, 0, 10110, NULL, NULL),
	(203, 0, 10259, NULL, NULL),
	(203, 0, 10265, NULL, NULL),
	(203, 0, 10292, NULL, NULL),
	(203, 0, 10432, NULL, NULL),
	(203, 0, 10923, NULL, NULL),
	(203, 0, 10924, NULL, NULL),
	(203, 0, 10925, NULL, NULL),
	(203, 0, 10926, NULL, NULL),
	(203, 0, 10927, NULL, NULL),
	(203, 0, 10928, NULL, NULL),
	(203, 0, 10929, NULL, NULL),
	(203, 0, 10930, NULL, NULL),
	(203, 0, 10931, NULL, NULL),
	(203, 0, 10932, NULL, NULL),
	(203, 0, 10933, NULL, NULL),
	(203, 0, 10934, NULL, NULL),
	(203, 0, 11239, NULL, NULL),
	(203, 0, 11240, NULL, NULL),
	(203, 0, 11241, NULL, NULL),
	(203, 0, 11242, NULL, NULL),
	(203, 0, 11243, NULL, NULL),
	(203, 0, 11244, NULL, NULL),
	(203, 1, 10000, NULL, NULL),
	(203, 1, 10001, NULL, NULL),
	(203, 1, 10002, NULL, NULL),
	(203, 1, 10029, NULL, NULL),
	(203, 1, 10041, NULL, NULL),
	(203, 1, 10053, NULL, NULL),
	(203, 1, 10098, NULL, NULL),
	(203, 1, 10099, NULL, NULL),
	(203, 1, 10102, NULL, NULL),
	(203, 1, 10103, NULL, NULL),
	(203, 1, 10104, NULL, NULL),
	(203, 1, 10105, NULL, NULL),
	(203, 1, 10106, NULL, NULL),
	(203, 1, 10107, NULL, NULL),
	(203, 1, 10108, NULL, NULL),
	(203, 1, 10109, NULL, NULL),
	(203, 1, 10110, NULL, NULL),
	(203, 1, 10111, NULL, NULL),
	(203, 1, 10112, NULL, NULL),
	(203, 1, 10213, NULL, NULL),
	(203, 1, 10253, NULL, NULL),
	(203, 1, 10432, NULL, NULL),
	(203, 1, 10530, NULL, NULL),
	(203, 1, 10531, NULL, NULL),
	(203, 1, 10532, NULL, NULL),
	(203, 1, 10533, NULL, NULL),
	(203, 1, 10534, NULL, NULL),
	(203, 1, 10535, NULL, NULL),
	(203, 1, 10640, NULL, NULL),
	(203, 1, 10760, NULL, NULL),
	(203, 1, 10819, NULL, NULL),
	(203, 1, 10833, NULL, NULL),
	(203, 1, 10840, NULL, NULL),
	(203, 1, 10931, NULL, NULL),
	(203, 1, 10935, NULL, NULL),
	(203, 1, 10936, NULL, NULL),
	(203, 1, 10937, NULL, NULL),
	(203, 1, 10938, NULL, NULL),
	(203, 1, 10939, NULL, NULL),
	(203, 1, 10940, NULL, NULL),
	(203, 1, 10946, NULL, NULL),
	(203, 1, 10947, NULL, NULL),
	(203, 1, 10948, NULL, NULL),
	(203, 1, 10949, NULL, NULL),
	(203, 1, 10978, NULL, NULL),
	(203, 1, 11245, NULL, NULL),
	(203, 1, 11246, NULL, NULL),
	(203, 1, 11247, NULL, NULL),
	(203, 1, 11248, NULL, NULL),
	(203, 1, 11249, NULL, NULL),
	(203, 1, 11250, NULL, NULL),
	(203, 1, 11251, NULL, NULL),
	(203, 1, 11252, NULL, NULL),
	(203, 1, 11253, NULL, NULL),
	(203, 1, 11254, NULL, NULL),
	(203, 1, 11255, NULL, NULL),
	(203, 1, 11256, NULL, NULL),
	(203, 1, 11257, NULL, NULL),
	(203, 1, 11258, NULL, NULL),
	(203, 1, 11259, NULL, NULL),
	(203, 1, 11260, NULL, NULL),
	(203, 1, 11261, NULL, NULL),
	(203, 1, 11262, NULL, NULL),
	(203, 1, 11263, NULL, NULL),
	(203, 1, 11264, NULL, NULL),
	(203, 1, 11265, NULL, NULL),
	(203, 1, 11266, NULL, NULL),
	(203, 1, 11267, NULL, NULL),
	(203, 1, 11268, NULL, NULL),
	(203, 1, 11269, NULL, NULL),
	(206, 1, 10008, NULL, 0),
	(206, 1, 10010, NULL, 0),
	(206, 1, 10012, NULL, 0),
	(206, 1, 10029, NULL, 0),
	(206, 1, 10076, NULL, 0),
	(206, 1, 10096, NULL, 0),
	(206, 1, 10242, NULL, 0),
	(206, 1, 10303, NULL, NULL),
	(206, 1, 10304, NULL, NULL),
	(206, 1, 10512, NULL, NULL),
	(206, 1, 10552, NULL, 0),
	(206, 1, 10731, NULL, 0),
	(206, 1, 10787, NULL, 0),
	(206, 1, 10854, NULL, 0),
	(207, 1, 10000, NULL, 0),
	(207, 1, 10001, NULL, 0),
	(207, 1, 10002, NULL, 0),
	(207, 1, 10010, NULL, 0),
	(207, 1, 10011, NULL, 0),
	(207, 1, 10012, NULL, 0),
	(207, 1, 10013, NULL, 0),
	(207, 1, 10015, NULL, NULL),
	(207, 1, 10029, NULL, 0),
	(207, 1, 10031, NULL, NULL),
	(207, 1, 10038, NULL, NULL),
	(207, 1, 10041, NULL, NULL),
	(207, 1, 10045, NULL, NULL),
	(207, 1, 10085, NULL, NULL),
	(207, 1, 10090, NULL, NULL),
	(207, 1, 10091, NULL, NULL),
	(207, 1, 10109, NULL, NULL),
	(207, 1, 10269, NULL, 0),
	(207, 1, 10427, NULL, NULL),
	(207, 1, 10450, NULL, 0),
	(207, 1, 10451, NULL, 0),
	(207, 1, 10452, NULL, 0),
	(207, 1, 10530, NULL, 0),
	(207, 1, 10531, NULL, 0),
	(207, 1, 10532, NULL, 0),
	(207, 1, 10533, NULL, 0),
	(207, 1, 10534, NULL, 0),
	(207, 1, 10535, NULL, 0),
	(207, 1, 10761, NULL, 0),
	(207, 1, 10795, NULL, 0),
	(207, 1, 10840, NULL, 0),
	(207, 1, 10952, NULL, NULL),
	(207, 1, 10978, NULL, NULL),
	(208, 1, 10008, NULL, NULL),
	(208, 1, 10010, NULL, 0),
	(208, 1, 10011, NULL, 0),
	(208, 1, 10012, NULL, NULL),
	(208, 1, 10013, NULL, NULL),
	(208, 1, 10015, NULL, NULL),
	(208, 1, 10029, NULL, NULL),
	(208, 1, 10041, NULL, NULL),
	(208, 1, 10042, NULL, NULL),
	(208, 1, 10045, NULL, NULL),
	(208, 1, 10046, NULL, NULL),
	(208, 1, 10048, NULL, NULL),
	(208, 1, 10085, NULL, NULL),
	(208, 1, 10090, NULL, NULL),
	(208, 1, 10091, NULL, NULL),
	(208, 1, 10096, NULL, NULL),
	(208, 1, 10097, NULL, NULL),
	(208, 1, 10109, NULL, 0),
	(208, 1, 10276, NULL, NULL),
	(208, 1, 10418, NULL, NULL),
	(208, 1, 10426, NULL, NULL),
	(208, 1, 10432, NULL, NULL),
	(208, 1, 10680, NULL, NULL),
	(208, 1, 10713, NULL, NULL),
	(208, 1, 10727, NULL, NULL),
	(208, 1, 10749, NULL, NULL),
	(208, 1, 10759, NULL, NULL),
	(208, 1, 10771, NULL, NULL),
	(208, 1, 10794, NULL, NULL),
	(208, 1, 10806, NULL, NULL),
	(208, 1, 10833, NULL, NULL),
	(208, 1, 10840, NULL, NULL),
	(208, 1, 10885, NULL, NULL),
	(208, 1, 10953, NULL, NULL),
	(208, 1, 10954, NULL, NULL),
	(208, 1, 10955, NULL, NULL),
	(208, 1, 10956, NULL, NULL),
	(208, 1, 10959, NULL, NULL),
	(208, 1, 10960, NULL, NULL),
	(208, 1, 10961, NULL, NULL),
	(208, 1, 10962, NULL, NULL),
	(208, 1, 10963, NULL, NULL),
	(208, 1, 10964, NULL, NULL),
	(208, 1, 10965, NULL, NULL),
	(208, 1, 10966, NULL, NULL),
	(208, 1, 10967, NULL, NULL),
	(208, 1, 10968, NULL, NULL),
	(208, 1, 10969, NULL, NULL),
	(208, 1, 10970, NULL, NULL),
	(208, 1, 10971, NULL, NULL),
	(208, 1, 10972, NULL, NULL),
	(208, 1, 10973, NULL, NULL),
	(208, 1, 10974, NULL, NULL),
	(208, 1, 10975, NULL, NULL),
	(208, 1, 10976, NULL, NULL),
	(208, 1, 10977, NULL, NULL),
	(208, 1, 10978, NULL, NULL),
	(208, 1, 10979, NULL, NULL),
	(208, 1, 10980, NULL, NULL),
	(208, 1, 10981, NULL, 0),
	(209, 1, 10000, NULL, NULL),
	(209, 1, 10001, NULL, NULL),
	(209, 1, 10002, NULL, NULL),
	(209, 1, 10003, NULL, NULL),
	(209, 1, 10014, NULL, NULL),
	(209, 1, 10015, NULL, NULL),
	(209, 1, 10029, NULL, NULL),
	(209, 1, 10096, NULL, NULL),
	(209, 1, 10109, NULL, NULL),
	(209, 1, 10427, NULL, NULL),
	(209, 1, 10524, NULL, NULL),
	(209, 1, 10530, NULL, NULL),
	(209, 1, 10531, NULL, NULL),
	(209, 1, 10532, NULL, NULL),
	(209, 1, 10533, NULL, NULL),
	(209, 1, 10534, NULL, NULL),
	(209, 1, 10535, NULL, NULL),
	(209, 1, 10548, NULL, NULL),
	(209, 1, 10553, NULL, NULL),
	(209, 1, 10597, NULL, NULL),
	(209, 1, 10744, NULL, NULL),
	(209, 1, 10745, NULL, NULL),
	(209, 1, 10746, NULL, NULL),
	(209, 1, 10747, NULL, NULL),
	(209, 1, 10776, NULL, NULL),
	(209, 1, 10777, NULL, NULL),
	(209, 1, 10849, NULL, NULL),
	(209, 1, 10850, NULL, NULL),
	(209, 1, 10851, NULL, NULL),
	(209, 1, 10852, NULL, NULL),
	(210, 1, 10018, NULL, NULL),
	(210, 1, 10029, NULL, NULL),
	(210, 1, 10586, NULL, NULL),
	(215, 0, 4002, NULL, NULL),
	(215, 0, 10045, NULL, NULL),
	(215, 0, 10302, NULL, NULL),
	(215, 0, 10886, NULL, NULL),
	(216, 1, 10982, NULL, 0),
	(216, 1, 10983, NULL, 0),
	(216, 1, 10984, NULL, 0),
	(216, 1, 10985, NULL, 0),
	(216, 1, 11014, NULL, 0),
	(216, 1, 11015, NULL, 0),
	(216, 1, 11016, NULL, 0),
	(216, 1, 11017, NULL, 0),
	(216, 1, 11018, NULL, 0),
	(216, 1, 11019, NULL, 0),
	(216, 1, 11020, NULL, 0),
	(216, 1, 11021, NULL, 0),
	(216, 1, 11022, NULL, 0),
	(216, 1, 11023, NULL, 0),
	(216, 1, 11024, NULL, 0),
	(216, 1, 11025, NULL, 0),
	(216, 1, 11026, NULL, 0),
	(216, 1, 11027, NULL, 0),
	(217, 1, 10029, NULL, NULL),
	(217, 1, 10032, NULL, NULL),
	(217, 1, 10078, NULL, NULL),
	(217, 1, 10271, NULL, NULL),
	(217, 1, 10432, NULL, NULL),
	(217, 1, 10845, NULL, NULL),
	(217, 1, 10954, NULL, NULL),
	(217, 1, 10959, NULL, NULL),
	(217, 1, 11028, NULL, NULL),
	(217, 1, 11029, NULL, NULL),
	(217, 1, 11030, NULL, NULL),
	(217, 1, 11031, NULL, NULL),
	(217, 1, 11032, NULL, NULL),
	(217, 1, 11033, NULL, NULL),
	(217, 1, 11034, NULL, NULL),
	(217, 1, 11035, NULL, NULL),
	(218, 0, 10026, 0, NULL),
	(218, 0, 10029, 0, NULL),
	(218, 0, 10213, 0, NULL),
	(218, 0, 10303, NULL, NULL),
	(218, 0, 10305, NULL, NULL),
	(218, 0, 10323, 0, NULL),
	(218, 0, 10324, 0, NULL),
	(218, 0, 10325, 0, NULL),
	(218, 0, 10326, 0, NULL),
	(218, 0, 10327, 0, NULL),
	(218, 0, 10329, 0, NULL),
	(218, 0, 10402, 0, NULL),
	(218, 0, 10403, 0, NULL),
	(218, 0, 10404, 0, NULL),
	(218, 0, 10405, 0, NULL),
	(218, 0, 10422, NULL, 0),
	(218, 0, 10423, NULL, 0),
	(218, 0, 10462, 0, NULL),
	(218, 0, 10463, 0, NULL),
	(218, 0, 10464, 0, NULL),
	(218, 0, 10465, 0, NULL),
	(218, 0, 10469, NULL, NULL),
	(218, 0, 10477, NULL, NULL),
	(218, 0, 10480, 0, NULL),
	(218, 0, 10481, NULL, NULL),
	(218, 0, 10482, NULL, NULL),
	(218, 0, 10483, NULL, NULL),
	(218, 0, 10512, NULL, NULL),
	(218, 0, 10994, NULL, NULL),
	(218, 0, 10995, NULL, NULL),
	(218, 0, 10996, NULL, NULL),
	(218, 0, 10999, 0, NULL),
	(218, 0, 11036, 0, NULL),
	(218, 0, 11037, 0, NULL),
	(218, 0, 11038, 0, NULL),
	(218, 0, 11039, 0, NULL),
	(218, 0, 11040, 0, NULL),
	(218, 0, 11041, 0, NULL),
	(218, 0, 11042, 0, NULL),
	(218, 0, 11043, 0, NULL),
	(218, 0, 11044, 0, NULL),
	(218, 0, 11045, 0, NULL),
	(218, 0, 11046, 0, NULL),
	(218, 0, 11047, 0, NULL),
	(218, 0, 11048, NULL, NULL),
	(218, 0, 11049, 0, NULL),
	(218, 0, 11051, 0, NULL),
	(218, 0, 11052, 0, NULL),
	(218, 0, 11053, 0, NULL),
	(218, 0, 11054, NULL, NULL),
	(218, 0, 11055, NULL, NULL),
	(218, 0, 11056, NULL, NULL),
	(218, 0, 11057, NULL, 0),
	(218, 0, 11058, NULL, 0),
	(218, 0, 11059, NULL, 0),
	(218, 0, 11060, NULL, 0),
	(218, 0, 11061, NULL, 0),
	(218, 0, 11062, NULL, 0),
	(223, 1, 10982, NULL, 0),
	(223, 1, 10983, NULL, 0),
	(223, 1, 10984, NULL, 0),
	(223, 1, 10985, NULL, 0),
	(223, 1, 11014, NULL, 0),
	(223, 1, 11015, NULL, 0),
	(223, 1, 11016, NULL, 0),
	(223, 1, 11017, NULL, 0),
	(223, 1, 11018, NULL, 0),
	(223, 1, 11019, NULL, 0),
	(223, 1, 11020, NULL, 0),
	(223, 1, 11021, NULL, 0),
	(223, 1, 11022, NULL, 0),
	(223, 1, 11023, NULL, 0),
	(223, 1, 11024, NULL, 0),
	(223, 1, 11025, NULL, 0),
	(223, 1, 11026, NULL, 0),
	(223, 1, 11027, NULL, 0),
	(224, 1, 10982, NULL, 0),
	(224, 1, 10983, NULL, 0),
	(224, 1, 10984, NULL, 0),
	(224, 1, 10985, NULL, 0),
	(224, 1, 11014, NULL, 0),
	(224, 1, 11015, NULL, 0),
	(224, 1, 11016, NULL, 0),
	(224, 1, 11017, NULL, 0),
	(224, 1, 11018, NULL, 0),
	(224, 1, 11019, NULL, 0),
	(224, 1, 11020, NULL, 0),
	(224, 1, 11021, NULL, 0),
	(224, 1, 11022, NULL, 0),
	(224, 1, 11023, NULL, 0),
	(224, 1, 11024, NULL, 0),
	(224, 1, 11025, NULL, 0),
	(224, 1, 11026, NULL, 0),
	(224, 1, 11027, NULL, 0),
	(225, 1, 10982, NULL, 0),
	(225, 1, 10983, NULL, 0),
	(225, 1, 10984, NULL, 0),
	(225, 1, 10985, NULL, 0),
	(225, 1, 11014, NULL, 0),
	(225, 1, 11015, NULL, 0),
	(225, 1, 11016, NULL, 0),
	(225, 1, 11017, NULL, 0),
	(225, 1, 11018, NULL, 0),
	(225, 1, 11019, NULL, 0),
	(225, 1, 11020, NULL, 0),
	(225, 1, 11021, NULL, 0),
	(225, 1, 11022, NULL, 0),
	(225, 1, 11023, NULL, 0),
	(225, 1, 11024, NULL, 0),
	(225, 1, 11025, NULL, 0),
	(225, 1, 11026, NULL, 0),
	(225, 1, 11027, NULL, 0),
	(226, 0, 9999, NULL, NULL),
	(226, 0, 10437, NULL, NULL),
	(226, 0, 10438, NULL, NULL),
	(226, 0, 10439, NULL, NULL),
	(226, 0, 10440, NULL, NULL),
	(226, 0, 10441, NULL, NULL),
	(226, 0, 10442, NULL, NULL),
	(226, 0, 10443, NULL, NULL),
	(226, 0, 10444, NULL, NULL),
	(226, 0, 10445, NULL, NULL),
	(226, 1, 9999, NULL, NULL),
	(226, 1, 10000, NULL, NULL),
	(226, 1, 10001, NULL, NULL),
	(226, 1, 10002, NULL, NULL),
	(226, 1, 10008, NULL, NULL),
	(226, 1, 10009, NULL, NULL),
	(226, 1, 10014, NULL, NULL),
	(226, 1, 10021, NULL, NULL),
	(226, 1, 10022, NULL, NULL),
	(226, 1, 10039, NULL, NULL),
	(226, 1, 10040, NULL, NULL),
	(226, 1, 10041, NULL, NULL),
	(226, 1, 10042, NULL, NULL),
	(226, 1, 10045, NULL, NULL),
	(226, 1, 10048, NULL, NULL),
	(226, 1, 10049, NULL, NULL),
	(226, 1, 10088, NULL, NULL),
	(226, 1, 10108, NULL, NULL),
	(226, 1, 10209, NULL, NULL),
	(226, 1, 10273, NULL, NULL),
	(226, 1, 10274, NULL, NULL),
	(226, 1, 10407, NULL, NULL),
	(226, 1, 10414, NULL, NULL),
	(226, 1, 10415, NULL, NULL),
	(226, 1, 10416, NULL, NULL),
	(226, 1, 10417, NULL, NULL),
	(226, 1, 10418, NULL, NULL),
	(226, 1, 10419, NULL, NULL),
	(226, 1, 10420, NULL, NULL),
	(226, 1, 10421, NULL, NULL),
	(226, 1, 10422, NULL, NULL),
	(226, 1, 10423, NULL, NULL),
	(226, 1, 10424, NULL, NULL),
	(226, 1, 10425, NULL, NULL),
	(226, 1, 10426, NULL, NULL),
	(226, 1, 10427, NULL, NULL),
	(226, 1, 10428, NULL, NULL),
	(226, 1, 10429, NULL, NULL),
	(226, 1, 10430, NULL, NULL),
	(226, 1, 10431, NULL, NULL),
	(226, 1, 10432, NULL, NULL),
	(226, 1, 10433, NULL, NULL),
	(226, 1, 10434, NULL, NULL),
	(226, 1, 10435, NULL, NULL),
	(226, 1, 10436, NULL, NULL),
	(228, 0, 9999, NULL, NULL),
	(228, 0, 10437, NULL, NULL),
	(228, 0, 10438, NULL, NULL),
	(228, 0, 10439, NULL, NULL),
	(228, 0, 10440, NULL, NULL),
	(228, 0, 10441, NULL, NULL),
	(228, 0, 10442, NULL, NULL),
	(228, 0, 10443, NULL, NULL),
	(228, 0, 10444, NULL, NULL),
	(228, 0, 10445, NULL, NULL),
	(228, 1, 9999, NULL, NULL),
	(228, 1, 10000, NULL, NULL),
	(228, 1, 10001, NULL, NULL),
	(228, 1, 10002, NULL, NULL),
	(228, 1, 10008, NULL, NULL),
	(228, 1, 10009, NULL, NULL),
	(228, 1, 10014, NULL, NULL),
	(228, 1, 10021, NULL, NULL),
	(228, 1, 10022, NULL, NULL),
	(228, 1, 10039, NULL, NULL),
	(228, 1, 10040, NULL, NULL),
	(228, 1, 10041, NULL, NULL),
	(228, 1, 10042, NULL, NULL),
	(228, 1, 10045, NULL, NULL),
	(228, 1, 10048, NULL, NULL),
	(228, 1, 10049, NULL, NULL),
	(228, 1, 10088, NULL, NULL),
	(228, 1, 10108, NULL, NULL),
	(228, 1, 10209, NULL, NULL),
	(228, 1, 10273, NULL, NULL),
	(228, 1, 10274, NULL, NULL),
	(228, 1, 10407, NULL, NULL),
	(228, 1, 10414, NULL, NULL),
	(228, 1, 10415, NULL, NULL),
	(228, 1, 10416, NULL, NULL),
	(228, 1, 10417, NULL, NULL),
	(228, 1, 10418, NULL, NULL),
	(228, 1, 10419, NULL, NULL),
	(228, 1, 10420, NULL, NULL),
	(228, 1, 10421, NULL, NULL),
	(228, 1, 10422, NULL, NULL),
	(228, 1, 10423, NULL, NULL),
	(228, 1, 10424, NULL, NULL),
	(228, 1, 10425, NULL, NULL),
	(228, 1, 10426, NULL, NULL),
	(228, 1, 10427, NULL, NULL),
	(228, 1, 10428, NULL, NULL),
	(228, 1, 10429, NULL, NULL),
	(228, 1, 10430, NULL, NULL),
	(228, 1, 10431, NULL, NULL),
	(228, 1, 10432, NULL, NULL),
	(228, 1, 10433, NULL, NULL),
	(228, 1, 10434, NULL, NULL),
	(228, 1, 10435, NULL, NULL),
	(228, 1, 10436, NULL, NULL),
	(229, 0, 9999, NULL, NULL),
	(229, 0, 10437, NULL, NULL),
	(229, 0, 10438, NULL, NULL),
	(229, 0, 10439, NULL, NULL),
	(229, 0, 10440, NULL, NULL),
	(229, 0, 10441, NULL, NULL),
	(229, 0, 10442, NULL, NULL),
	(229, 0, 10443, NULL, NULL),
	(229, 0, 10444, NULL, NULL),
	(229, 0, 10445, NULL, NULL),
	(229, 1, 9999, NULL, NULL),
	(229, 1, 10000, NULL, NULL),
	(229, 1, 10001, NULL, NULL),
	(229, 1, 10002, NULL, NULL),
	(229, 1, 10008, NULL, NULL),
	(229, 1, 10009, NULL, NULL),
	(229, 1, 10014, NULL, NULL),
	(229, 1, 10021, NULL, NULL),
	(229, 1, 10022, NULL, NULL),
	(229, 1, 10039, NULL, NULL),
	(229, 1, 10040, NULL, NULL),
	(229, 1, 10041, NULL, NULL),
	(229, 1, 10042, NULL, NULL),
	(229, 1, 10045, NULL, NULL),
	(229, 1, 10048, NULL, NULL),
	(229, 1, 10049, NULL, NULL),
	(229, 1, 10088, NULL, NULL),
	(229, 1, 10108, NULL, NULL),
	(229, 1, 10209, NULL, NULL),
	(229, 1, 10273, NULL, NULL),
	(229, 1, 10274, NULL, NULL),
	(229, 1, 10407, NULL, NULL),
	(229, 1, 10414, NULL, NULL),
	(229, 1, 10415, NULL, NULL),
	(229, 1, 10416, NULL, NULL),
	(229, 1, 10417, NULL, NULL),
	(229, 1, 10418, NULL, NULL),
	(229, 1, 10419, NULL, NULL),
	(229, 1, 10420, NULL, NULL),
	(229, 1, 10421, NULL, NULL),
	(229, 1, 10422, NULL, NULL),
	(229, 1, 10423, NULL, NULL),
	(229, 1, 10424, NULL, NULL),
	(229, 1, 10425, NULL, NULL),
	(229, 1, 10426, NULL, NULL),
	(229, 1, 10427, NULL, NULL),
	(229, 1, 10428, NULL, NULL),
	(229, 1, 10429, NULL, NULL),
	(229, 1, 10430, NULL, NULL),
	(229, 1, 10431, NULL, NULL),
	(229, 1, 10432, NULL, NULL),
	(229, 1, 10433, NULL, NULL),
	(229, 1, 10434, NULL, NULL),
	(229, 1, 10435, NULL, NULL),
	(229, 1, 10436, NULL, NULL),
	(235, 1, 10000, NULL, NULL),
	(235, 1, 10001, NULL, NULL),
	(235, 1, 10002, NULL, NULL),
	(235, 1, 10012, NULL, NULL),
	(235, 1, 10015, NULL, NULL),
	(235, 1, 10029, NULL, NULL),
	(235, 1, 10051, NULL, NULL),
	(235, 1, 10450, NULL, NULL),
	(235, 1, 10451, NULL, NULL),
	(235, 1, 10452, NULL, NULL),
	(235, 1, 10548, NULL, NULL),
	(235, 1, 10549, NULL, NULL),
	(235, 1, 10550, NULL, NULL),
	(235, 1, 10551, NULL, NULL),
	(235, 1, 10583, NULL, NULL),
	(235, 1, 10584, NULL, NULL),
	(235, 1, 10585, NULL, NULL),
	(235, 1, 10745, NULL, NULL),
	(235, 1, 10746, NULL, NULL),
	(235, 1, 10747, NULL, NULL),
	(235, 1, 10896, NULL, NULL),
	(235, 1, 10959, NULL, NULL),
	(236, 1, 10029, NULL, NULL),
	(236, 1, 10321, NULL, NULL),
	(236, 1, 10322, NULL, NULL),
	(236, 1, 10404, NULL, NULL),
	(236, 1, 11115, NULL, NULL),
	(236, 1, 11116, NULL, NULL),
	(236, 1, 11117, NULL, NULL),
	(236, 1, 11118, NULL, NULL),
	(236, 1, 11119, NULL, NULL),
	(236, 1, 11120, NULL, NULL),
	(236, 1, 11121, NULL, NULL),
	(236, 1, 11122, NULL, NULL),
	(236, 1, 11123, NULL, NULL),
	(236, 1, 11124, NULL, NULL),
	(236, 1, 11125, NULL, NULL),
	(236, 1, 11126, NULL, NULL),
	(244, 0, 11196, NULL, NULL),
	(244, 0, 11198, NULL, NULL),
	(246, 1, 10000, NULL, NULL),
	(246, 1, 10001, NULL, NULL),
	(246, 1, 10002, NULL, NULL),
	(246, 1, 10003, NULL, NULL),
	(246, 1, 10007, NULL, NULL),
	(246, 1, 10012, NULL, NULL),
	(246, 1, 10013, NULL, NULL),
	(246, 1, 10014, NULL, NULL),
	(246, 1, 10015, NULL, NULL),
	(246, 1, 10017, NULL, NULL),
	(246, 1, 10029, NULL, NULL),
	(246, 1, 10030, NULL, NULL),
	(246, 1, 10038, NULL, NULL),
	(246, 1, 10039, NULL, NULL),
	(246, 1, 10040, NULL, NULL),
	(246, 1, 10044, NULL, NULL),
	(246, 1, 10048, NULL, NULL),
	(246, 1, 10109, NULL, NULL),
	(246, 1, 10112, NULL, NULL),
	(246, 1, 10244, NULL, NULL),
	(246, 1, 10264, NULL, NULL),
	(246, 1, 10276, NULL, NULL),
	(246, 1, 10284, NULL, NULL),
	(246, 1, 10292, NULL, NULL),
	(246, 1, 10432, NULL, NULL),
	(246, 1, 10450, NULL, NULL),
	(246, 1, 10451, NULL, NULL),
	(246, 1, 10452, NULL, NULL),
	(246, 1, 10509, NULL, NULL),
	(246, 1, 10530, NULL, NULL),
	(246, 1, 10531, NULL, NULL),
	(246, 1, 10532, NULL, NULL),
	(246, 1, 10533, NULL, NULL),
	(246, 1, 10534, NULL, NULL),
	(246, 1, 10535, NULL, NULL),
	(246, 1, 10548, NULL, NULL),
	(246, 1, 10549, NULL, NULL),
	(246, 1, 10550, NULL, NULL),
	(246, 1, 10551, NULL, NULL),
	(246, 1, 10552, NULL, NULL),
	(246, 1, 10570, NULL, NULL),
	(246, 1, 10578, NULL, NULL),
	(246, 1, 10580, NULL, NULL),
	(246, 1, 10581, NULL, NULL),
	(246, 1, 10583, NULL, NULL),
	(246, 1, 10584, NULL, NULL),
	(246, 1, 10585, NULL, NULL),
	(246, 1, 10594, NULL, NULL),
	(246, 1, 10595, NULL, NULL),
	(246, 1, 10596, NULL, NULL),
	(246, 1, 10627, NULL, NULL),
	(246, 1, 10669, NULL, NULL),
	(246, 1, 10743, NULL, NULL),
	(246, 1, 10750, NULL, NULL),
	(246, 1, 10795, NULL, NULL),
	(246, 1, 10895, NULL, NULL),
	(246, 1, 10959, NULL, NULL),
	(246, 1, 11073, NULL, NULL),
	(246, 1, 11127, NULL, NULL),
	(246, 1, 11128, NULL, NULL),
	(246, 1, 11129, NULL, NULL),
	(246, 1, 11130, NULL, NULL),
	(246, 1, 11131, NULL, NULL),
	(246, 1, 11132, NULL, NULL),
	(246, 1, 11133, NULL, NULL),
	(246, 1, 11134, NULL, NULL),
	(246, 1, 11135, NULL, NULL),
	(246, 1, 11136, NULL, NULL),
	(246, 1, 11137, NULL, NULL),
	(246, 1, 11138, NULL, NULL),
	(246, 1, 11139, NULL, NULL),
	(246, 1, 11140, NULL, NULL),
	(246, 1, 11141, NULL, NULL),
	(246, 1, 11142, NULL, NULL),
	(246, 1, 11143, NULL, NULL),
	(246, 1, 11144, NULL, NULL),
	(246, 1, 11145, NULL, NULL),
	(246, 1, 11146, NULL, NULL),
	(246, 1, 11147, NULL, NULL),
	(246, 1, 11148, NULL, NULL),
	(246, 1, 11149, NULL, NULL),
	(246, 1, 11150, NULL, NULL),
	(246, 1, 11151, NULL, NULL),
	(246, 1, 11152, NULL, NULL),
	(246, 1, 11153, NULL, NULL),
	(246, 1, 11154, NULL, NULL),
	(246, 1, 11155, NULL, NULL),
	(246, 1, 11156, NULL, NULL),
	(246, 1, 11157, NULL, NULL),
	(246, 1, 11158, NULL, NULL),
	(246, 1, 11159, NULL, NULL),
	(246, 1, 11160, NULL, NULL),
	(246, 1, 11161, NULL, NULL),
	(246, 1, 11162, NULL, NULL),
	(246, 1, 11163, NULL, NULL),
	(246, 1, 11164, NULL, NULL),
	(246, 1, 11165, NULL, NULL),
	(246, 1, 11166, NULL, NULL),
	(246, 1, 11167, NULL, NULL),
	(246, 1, 11168, NULL, NULL),
	(246, 1, 11169, NULL, NULL),
	(246, 1, 11170, NULL, NULL),
	(246, 1, 11171, NULL, NULL),
	(246, 1, 11172, NULL, NULL),
	(246, 1, 11173, NULL, NULL),
	(249, 1, 4019, 1, 0),
	(249, 1, 10000, NULL, NULL),
	(249, 1, 10001, NULL, NULL),
	(249, 1, 10002, NULL, NULL),
	(249, 1, 10003, NULL, NULL),
	(249, 1, 10007, NULL, 0),
	(249, 1, 10008, NULL, 0),
	(249, 1, 10010, NULL, 0),
	(249, 1, 10011, NULL, 0),
	(249, 1, 10012, NULL, 0),
	(249, 1, 10013, NULL, 0),
	(249, 1, 10014, NULL, NULL),
	(249, 1, 10015, NULL, NULL),
	(249, 1, 10026, NULL, NULL),
	(249, 1, 10029, NULL, NULL),
	(249, 1, 10038, NULL, NULL),
	(249, 1, 10048, NULL, NULL),
	(249, 1, 10244, NULL, NULL),
	(249, 1, 10530, NULL, NULL),
	(249, 1, 10531, NULL, NULL),
	(249, 1, 10532, NULL, NULL),
	(249, 1, 10533, NULL, NULL),
	(249, 1, 10534, NULL, NULL),
	(249, 1, 10535, NULL, NULL),
	(249, 1, 10549, NULL, 0),
	(249, 1, 10550, NULL, 0),
	(249, 1, 10551, NULL, 0),
	(249, 1, 10553, NULL, NULL),
	(249, 1, 10587, NULL, NULL),
	(249, 1, 10588, NULL, NULL),
	(249, 1, 10594, NULL, 0),
	(249, 1, 10595, NULL, 0),
	(249, 1, 10596, NULL, 0),
	(249, 1, 10597, NULL, 0),
	(249, 1, 10603, NULL, NULL),
	(249, 1, 10705, NULL, NULL),
	(249, 1, 10709, NULL, NULL),
	(249, 1, 10770, NULL, NULL),
	(249, 1, 10806, NULL, NULL),
	(249, 1, 10882, NULL, 0),
	(249, 1, 10897, NULL, 0),
	(249, 1, 10899, NULL, 0),
	(249, 1, 10900, NULL, 0),
	(249, 1, 10901, NULL, 0),
	(249, 1, 11080, NULL, NULL),
	(249, 1, 11159, NULL, 0),
	(249, 1, 11556, NULL, NULL),
	(249, 1, 11557, NULL, NULL),
	(249, 1, 11561, NULL, 0),
	(249, 1, 11562, NULL, 0),
	(249, 1, 11563, NULL, 0),
	(249, 1, 11564, NULL, 0),
	(249, 1, 11565, NULL, 0),
	(249, 1, 11566, NULL, 0),
	(249, 1, 11567, NULL, 0),
	(249, 1, 11568, NULL, 0),
	(249, 1, 11569, NULL, 0),
	(249, 1, 11570, NULL, 0),
	(249, 1, 11571, NULL, NULL),
	(249, 1, 11573, NULL, 0),
	(249, 1, 11574, NULL, 0),
	(249, 1, 11575, NULL, 0),
	(249, 1, 11576, NULL, 0),
	(249, 1, 11577, NULL, 0),
	(249, 1, 11578, NULL, 0),
	(249, 1, 11579, NULL, 0),
	(249, 1, 11580, NULL, 0),
	(249, 1, 11581, NULL, 0),
	(249, 1, 11582, NULL, 0),
	(249, 1, 11583, NULL, 0),
	(249, 1, 11584, NULL, 0),
	(249, 1, 11585, NULL, 0),
	(249, 1, 11586, NULL, 0),
	(249, 1, 11587, NULL, 0),
	(249, 1, 11588, NULL, 0),
	(249, 1, 11589, NULL, 0),
	(249, 1, 11590, NULL, 0),
	(249, 1, 11591, NULL, 0),
	(249, 1, 11592, NULL, 0),
	(249, 1, 11593, NULL, 0),
	(249, 1, 11594, NULL, 0),
	(249, 1, 11595, NULL, 0),
	(249, 1, 11596, NULL, 0),
	(249, 1, 11597, NULL, 0),
	(249, 1, 11598, NULL, 0),
	(249, 1, 11599, NULL, 0),
	(249, 1, 11600, NULL, 0),
	(249, 1, 11601, NULL, NULL),
	(249, 1, 11602, NULL, NULL),
	(249, 1, 11603, NULL, NULL),
	(249, 1, 11604, NULL, NULL),
	(249, 1, 11605, NULL, NULL),
	(249, 1, 11606, NULL, NULL),
	(249, 1, 11607, NULL, NULL),
	(249, 1, 11608, NULL, NULL),
	(249, 1, 11609, NULL, NULL),
	(249, 1, 11610, NULL, NULL),
	(249, 1, 11611, NULL, NULL),
	(249, 1, 11612, NULL, NULL),
	(249, 1, 11613, NULL, NULL),
	(249, 1, 11614, NULL, NULL),
	(249, 1, 11615, NULL, NULL),
	(249, 1, 11616, NULL, NULL),
	(249, 1, 11617, NULL, NULL),
	(249, 1, 11618, NULL, NULL),
	(249, 1, 11619, NULL, NULL),
	(249, 1, 11620, NULL, NULL),
	(249, 1, 11621, NULL, NULL),
	(249, 1, 11622, NULL, NULL),
	(249, 1, 11623, NULL, NULL),
	(249, 1, 11626, NULL, NULL),
	(249, 1, 11627, NULL, NULL),
	(249, 1, 11628, NULL, NULL),
	(249, 1, 11629, NULL, NULL),
	(249, 1, 11630, NULL, NULL),
	(249, 1, 11631, NULL, NULL),
	(249, 1, 11632, NULL, NULL),
	(249, 1, 11633, NULL, NULL),
	(249, 1, 11634, NULL, NULL),
	(251, 1, 10000, 0, NULL),
	(251, 1, 10001, 0, NULL),
	(251, 1, 10002, 0, NULL),
	(251, 1, 10009, 0, NULL),
	(251, 1, 10014, 0, NULL),
	(251, 1, 10029, 0, NULL),
	(251, 1, 10030, 0, NULL),
	(251, 1, 10031, 0, NULL),
	(251, 1, 10038, 0, NULL),
	(251, 1, 10041, 0, NULL),
	(251, 1, 10045, 0, NULL),
	(251, 1, 10046, 0, NULL),
	(251, 1, 10085, 0, NULL),
	(251, 1, 10108, 0, NULL),
	(251, 1, 10109, 0, NULL),
	(251, 1, 10112, 0, NULL),
	(251, 1, 10432, 0, NULL),
	(251, 1, 10553, 0, NULL),
	(251, 1, 10589, NULL, 0),
	(251, 1, 10590, NULL, 0),
	(251, 1, 10603, 0, NULL),
	(251, 1, 10680, 0, NULL),
	(251, 1, 10687, 0, NULL),
	(251, 1, 10704, 0, NULL),
	(251, 1, 10705, 0, NULL),
	(251, 1, 10772, 0, NULL),
	(251, 1, 10941, 0, NULL),
	(251, 1, 10942, 0, NULL),
	(251, 1, 10943, 0, NULL),
	(251, 1, 10944, 0, NULL),
	(251, 1, 11075, 0, NULL),
	(251, 1, 11076, 0, NULL),
	(251, 1, 11077, 0, NULL),
	(251, 1, 11078, 0, NULL),
	(251, 1, 11079, 0, NULL),
	(251, 1, 11080, 0, NULL),
	(251, 1, 11081, 0, NULL),
	(251, 1, 11082, 0, NULL),
	(251, 1, 11083, 0, NULL),
	(251, 1, 11199, 0, NULL),
	(251, 1, 11200, 0, NULL),
	(251, 1, 11201, 0, NULL),
	(251, 1, 11202, 0, NULL),
	(251, 1, 11203, 0, NULL),
	(251, 1, 11204, 0, NULL),
	(251, 1, 11205, 0, NULL),
	(251, 1, 11206, 0, NULL),
	(251, 1, 11207, 0, NULL),
	(251, 1, 11208, 0, NULL),
	(251, 1, 11209, 0, NULL),
	(251, 1, 11210, 0, NULL),
	(251, 1, 11211, 0, NULL),
	(251, 1, 11212, 0, NULL),
	(251, 1, 11213, 0, NULL),
	(251, 1, 11214, 0, NULL),
	(251, 1, 11215, 0, NULL),
	(251, 1, 11216, 0, NULL),
	(251, 1, 11217, 0, NULL),
	(251, 1, 11218, 0, NULL),
	(251, 1, 11219, 0, NULL),
	(251, 1, 11220, 0, NULL),
	(251, 1, 11222, 0, NULL),
	(251, 1, 11223, 0, NULL),
	(251, 1, 11224, 0, NULL),
	(251, 1, 11225, 0, NULL),
	(251, 1, 11226, 0, NULL),
	(251, 1, 11227, 0, NULL),
	(251, 1, 11228, 0, NULL),
	(251, 1, 11229, 0, NULL),
	(251, 1, 11230, 0, NULL),
	(251, 1, 11231, 0, NULL),
	(251, 1, 11232, 0, NULL),
	(251, 1, 11233, 0, NULL),
	(251, 1, 11234, 0, NULL),
	(252, 1, 10010, NULL, NULL),
	(252, 1, 10011, NULL, NULL),
	(252, 1, 10012, NULL, NULL),
	(252, 1, 10029, NULL, NULL),
	(252, 1, 10038, NULL, NULL),
	(252, 1, 10044, NULL, NULL),
	(252, 1, 10245, NULL, NULL),
	(252, 1, 10247, NULL, NULL),
	(252, 1, 10274, NULL, NULL),
	(252, 1, 10434, NULL, NULL),
	(252, 1, 10597, NULL, NULL),
	(252, 1, 10951, NULL, NULL),
	(253, 0, 4001, 1, 0),
	(253, 0, 4011, 1, 0),
	(253, 0, 4012, 1, 0),
	(253, 0, 4013, 1, 0),
	(253, 0, 4014, 1, 0),
	(253, 0, 4015, 1, 0),
	(253, 0, 4017, 1, 0),
	(253, 0, 4019, 1, 0),
	(255, 0, 4012, 1, 0),
	(256, 0, 4012, 1, 0),
	(283, 1, 10733, NULL, NULL),
	(283, 1, 10878, NULL, NULL),
	(283, 1, 11270, NULL, NULL),
	(283, 1, 11271, NULL, NULL),
	(283, 1, 11272, NULL, NULL),
	(283, 1, 11273, NULL, NULL),
	(283, 1, 11321, NULL, NULL),
	(283, 1, 11322, NULL, NULL),
	(284, 1, 10038, 0, NULL),
	(284, 1, 10045, 0, NULL),
	(285, 0, 4001, 1, 0),
	(285, 0, 4011, 1, 0),
	(285, 0, 4012, 1, 0),
	(285, 0, 4013, 1, 0),
	(285, 0, 4014, 1, 0),
	(285, 0, 4015, 1, 0),
	(285, 0, 4017, 1, 0),
	(285, 0, 4019, 1, 0),
	(288, 1, 10733, NULL, NULL),
	(288, 1, 10878, NULL, NULL),
	(288, 1, 11270, NULL, NULL),
	(288, 1, 11271, NULL, NULL),
	(288, 1, 11272, NULL, NULL),
	(288, 1, 11273, NULL, NULL),
	(288, 1, 11321, NULL, NULL),
	(288, 1, 11322, NULL, NULL),
	(292, 1, -4, NULL, 0),
	(292, 1, 10003, NULL, 0),
	(292, 1, 10007, 0, NULL),
	(292, 1, 10010, NULL, 0),
	(292, 1, 10011, NULL, 0),
	(292, 1, 10012, 0, NULL),
	(292, 1, 10013, 0, NULL),
	(292, 1, 10014, NULL, NULL),
	(292, 1, 10015, 0, NULL),
	(292, 1, 10029, 0, NULL),
	(292, 1, 10041, 0, NULL),
	(292, 1, 10042, 0, NULL),
	(292, 1, 10043, 0, NULL),
	(292, 1, 10046, 0, NULL),
	(292, 1, 10078, 0, NULL),
	(292, 1, 10085, 0, NULL),
	(292, 1, 10090, 0, NULL),
	(292, 1, 10109, NULL, 0),
	(292, 1, 10112, 0, NULL),
	(292, 1, 10210, 0, NULL),
	(292, 1, 10213, 0, NULL),
	(292, 1, 10244, 0, NULL),
	(292, 1, 10418, 0, NULL),
	(292, 1, 10426, 0, NULL),
	(292, 1, 10432, 0, NULL),
	(292, 1, 10447, 0, NULL),
	(292, 1, 10477, 0, NULL),
	(292, 1, 10553, NULL, NULL),
	(292, 1, 10562, 0, NULL),
	(292, 1, 10684, NULL, 0),
	(292, 1, 10759, 0, NULL),
	(292, 1, 10794, 0, NULL),
	(292, 1, 10803, 0, NULL),
	(292, 1, 10804, 0, NULL),
	(292, 1, 10931, 0, NULL),
	(292, 1, 10951, NULL, 0),
	(292, 1, 10952, 0, NULL),
	(292, 1, 10959, 0, NULL),
	(292, 1, 10966, 0, NULL),
	(292, 1, 10967, 0, NULL),
	(292, 1, 10968, 0, NULL),
	(292, 1, 10972, 0, NULL),
	(292, 1, 10976, 0, NULL),
	(292, 1, 10978, 0, NULL),
	(292, 1, 10981, NULL, 0),
	(292, 1, 11159, NULL, NULL),
	(292, 1, 11215, 0, NULL),
	(292, 1, 11216, 0, NULL),
	(292, 1, 11218, 0, NULL),
	(292, 1, 11274, 0, NULL),
	(292, 1, 11275, 0, NULL),
	(292, 1, 11276, 0, NULL),
	(292, 1, 11277, 0, NULL),
	(292, 1, 11278, 0, NULL),
	(292, 1, 11279, 0, NULL),
	(292, 1, 11280, 0, NULL),
	(292, 1, 11281, 0, NULL),
	(292, 1, 11282, 0, NULL),
	(292, 1, 11283, 0, NULL),
	(292, 1, 11284, 0, NULL),
	(292, 1, 11285, 0, NULL),
	(292, 1, 11286, 0, NULL),
	(292, 1, 11287, 0, NULL),
	(292, 1, 11288, 0, NULL),
	(292, 1, 11289, 0, NULL),
	(292, 1, 11290, 0, NULL),
	(292, 1, 11291, 0, NULL),
	(292, 1, 11292, 0, NULL),
	(292, 1, 11293, NULL, 0),
	(292, 1, 11294, NULL, 0),
	(292, 1, 11295, 0, NULL),
	(292, 1, 11296, 0, NULL),
	(292, 1, 11297, 0, NULL),
	(292, 1, 11298, 0, NULL),
	(292, 1, 11299, 0, NULL),
	(292, 1, 11300, 0, NULL),
	(292, 1, 11301, 0, NULL),
	(292, 1, 11302, 0, NULL),
	(292, 1, 11303, 0, NULL),
	(292, 1, 11304, 0, NULL),
	(292, 1, 11305, 0, NULL),
	(292, 1, 11306, NULL, 0),
	(292, 1, 11307, 0, NULL),
	(292, 1, 11308, 0, NULL),
	(292, 1, 11309, 0, NULL),
	(292, 1, 11310, 0, NULL),
	(292, 1, 11311, 0, NULL),
	(292, 1, 11312, 0, NULL),
	(292, 1, 11313, 0, NULL),
	(292, 1, 11314, 0, NULL),
	(292, 1, 11315, 0, NULL),
	(292, 1, 11316, 0, NULL),
	(292, 1, 11317, 0, NULL),
	(292, 1, 11318, 0, NULL),
	(292, 1, 11319, NULL, 0),
	(292, 1, 11320, 0, NULL),
	(292, 1, 11323, 0, NULL),
	(292, 1, 11324, 0, NULL),
	(292, 1, 11553, NULL, 0),
	(292, 1, 11554, 0, NULL),
	(292, 1, 11555, 0, NULL),
	(292, 1, 11556, NULL, 0),
	(292, 1, 11557, NULL, 0),
	(292, 1, 11558, NULL, 0),
	(292, 1, 11559, NULL, 0),
	(292, 1, 11560, NULL, 0),
	(293, 0, 10400, NULL, NULL),
	(293, 0, 10401, NULL, NULL),
	(296, 1, -4, 1, 0),
	(296, 1, 10012, NULL, NULL),
	(296, 1, 10013, NULL, NULL),
	(296, 1, 10015, NULL, NULL),
	(296, 1, 10030, NULL, NULL),
	(296, 1, 10045, NULL, NULL),
	(296, 1, 10058, NULL, NULL),
	(296, 1, 10264, NULL, NULL),
	(296, 1, 10292, NULL, NULL),
	(296, 1, 10750, NULL, NULL),
	(296, 1, 10959, NULL, NULL),
	(296, 1, 11115, NULL, NULL),
	(296, 1, 11116, NULL, NULL),
	(296, 1, 11391, NULL, NULL),
	(296, 1, 11392, NULL, NULL),
	(296, 1, 11393, NULL, NULL),
	(296, 1, 11394, NULL, NULL),
	(296, 1, 11395, NULL, NULL),
	(296, 1, 11396, NULL, NULL),
	(296, 1, 11397, NULL, NULL),
	(296, 1, 11398, NULL, NULL),
	(296, 1, 11399, NULL, NULL),
	(296, 1, 11400, NULL, NULL),
	(296, 1, 11401, NULL, NULL),
	(296, 1, 11402, NULL, NULL),
	(296, 1, 11403, NULL, NULL),
	(296, 1, 11404, NULL, NULL),
	(296, 1, 11405, NULL, NULL),
	(296, 1, 11406, NULL, NULL),
	(296, 1, 11407, NULL, NULL),
	(296, 1, 11408, NULL, NULL),
	(296, 1, 11409, NULL, NULL),
	(296, 1, 11410, NULL, NULL),
	(296, 1, 11411, NULL, NULL),
	(296, 1, 11412, NULL, NULL),
	(296, 1, 11413, NULL, NULL),
	(296, 1, 11414, NULL, NULL),
	(296, 1, 11415, NULL, NULL),
	(296, 1, 11416, NULL, NULL),
	(296, 1, 11417, NULL, NULL),
	(296, 1, 11418, NULL, NULL),
	(296, 1, 11419, NULL, NULL),
	(296, 1, 11420, NULL, NULL),
	(296, 1, 11421, NULL, NULL),
	(296, 1, 11422, NULL, NULL),
	(296, 1, 11423, NULL, NULL),
	(296, 1, 11424, NULL, NULL),
	(296, 1, 11425, NULL, NULL),
	(296, 1, 11426, NULL, NULL),
	(296, 1, 11531, 1, 0),
	(300, 1, 10603, NULL, NULL),
	(300, 1, 10734, NULL, NULL),
	(300, 1, 11083, NULL, NULL),
	(342, 1, 10000, NULL, NULL),
	(342, 1, 10001, NULL, NULL),
	(342, 1, 10002, NULL, NULL),
	(342, 1, 10014, NULL, NULL),
	(342, 1, 10015, NULL, NULL),
	(342, 1, 10029, NULL, NULL),
	(342, 1, 10030, NULL, NULL),
	(342, 1, 10031, NULL, NULL),
	(342, 1, 10038, NULL, NULL),
	(342, 1, 10043, NULL, NULL),
	(342, 1, 10046, NULL, NULL),
	(342, 1, 10047, NULL, NULL),
	(342, 1, 10048, NULL, NULL),
	(342, 1, 10049, NULL, NULL),
	(342, 1, 10213, NULL, NULL),
	(342, 1, 10243, NULL, NULL),
	(342, 1, 10268, NULL, NULL),
	(342, 1, 10272, NULL, NULL),
	(342, 1, 10273, NULL, NULL),
	(342, 1, 10432, NULL, NULL),
	(342, 1, 10479, NULL, NULL),
	(342, 1, 10548, NULL, NULL),
	(342, 1, 10552, NULL, NULL),
	(342, 1, 10553, NULL, NULL),
	(342, 1, 10753, NULL, NULL),
	(342, 1, 10800, NULL, NULL),
	(342, 1, 10833, NULL, NULL),
	(342, 1, 11220, NULL, NULL),
	(342, 1, 11509, NULL, NULL),
	(342, 1, 11510, NULL, NULL),
	(342, 1, 11511, NULL, NULL),
	(342, 1, 11512, NULL, NULL),
	(342, 1, 11513, NULL, NULL),
	(342, 1, 11514, NULL, NULL),
	(342, 1, 11515, NULL, NULL),
	(342, 1, 11516, NULL, NULL),
	(342, 1, 11517, NULL, NULL),
	(342, 1, 11518, NULL, NULL),
	(342, 1, 11519, NULL, NULL),
	(342, 1, 11520, NULL, NULL),
	(342, 1, 11521, NULL, NULL),
	(342, 1, 11522, NULL, NULL),
	(342, 1, 11523, NULL, NULL),
	(344, 0, 10029, NULL, NULL),
	(344, 1, 10029, NULL, NULL),
	(346, 1, 10000, NULL, NULL),
	(346, 1, 10001, NULL, NULL),
	(346, 1, 10002, NULL, NULL),
	(346, 1, 10003, NULL, NULL),
	(346, 1, 10010, NULL, NULL),
	(346, 1, 10014, NULL, NULL),
	(346, 1, 10029, NULL, NULL),
	(346, 1, 10030, NULL, NULL),
	(346, 1, 10032, NULL, NULL),
	(346, 1, 10043, NULL, NULL),
	(346, 1, 10044, NULL, NULL),
	(346, 1, 10088, NULL, NULL),
	(346, 1, 10108, NULL, NULL),
	(346, 1, 10109, NULL, NULL),
	(346, 1, 10115, NULL, NULL),
	(346, 1, 10116, NULL, NULL),
	(346, 1, 10272, NULL, NULL),
	(346, 1, 10273, NULL, NULL),
	(346, 1, 10284, NULL, NULL),
	(346, 1, 10434, NULL, NULL),
	(346, 1, 10450, NULL, NULL),
	(346, 1, 10451, NULL, NULL),
	(346, 1, 10452, NULL, NULL),
	(346, 1, 10530, NULL, NULL),
	(346, 1, 10531, NULL, NULL),
	(346, 1, 10532, NULL, NULL),
	(346, 1, 10533, NULL, NULL),
	(346, 1, 10534, NULL, NULL),
	(346, 1, 10535, NULL, NULL),
	(346, 1, 10549, NULL, NULL),
	(346, 1, 10550, NULL, NULL),
	(346, 1, 10551, NULL, NULL),
	(346, 1, 10555, NULL, NULL),
	(346, 1, 10556, NULL, NULL),
	(346, 1, 10557, NULL, NULL),
	(346, 1, 10562, NULL, NULL),
	(346, 1, 10569, NULL, NULL),
	(346, 1, 10745, NULL, NULL),
	(346, 1, 10746, NULL, NULL),
	(346, 1, 10747, NULL, NULL),
	(346, 1, 10777, NULL, NULL),
	(346, 1, 10828, NULL, NULL),
	(346, 1, 10849, NULL, NULL),
	(346, 1, 10894, NULL, NULL),
	(346, 1, 10895, NULL, NULL),
	(346, 1, 10931, NULL, NULL),
	(346, 1, 11137, NULL, NULL),
	(346, 1, 11159, NULL, NULL),
	(346, 1, 11426, NULL, NULL),
	(346, 1, 11536, NULL, NULL),
	(346, 1, 11537, NULL, NULL),
	(346, 1, 11538, NULL, NULL),
	(346, 1, 11539, NULL, NULL),
	(346, 1, 11540, NULL, NULL),
	(346, 1, 11541, NULL, NULL),
	(346, 1, 11542, NULL, NULL),
	(346, 1, 11543, NULL, NULL),
	(346, 1, 11544, NULL, NULL),
	(346, 1, 11545, NULL, NULL),
	(346, 1, 11546, NULL, NULL),
	(346, 1, 11547, NULL, NULL),
	(346, 1, 11548, NULL, NULL),
	(346, 1, 11549, NULL, NULL),
	(346, 1, 11550, NULL, NULL),
	(346, 1, 11551, NULL, NULL),
	(348, 0, 4002, NULL, NULL),
	(348, 0, 4012, NULL, NULL),
	(348, 0, 4014, NULL, NULL),
	(349, 1, 3101, NULL, NULL),
	(349, 1, 10003, NULL, NULL),
	(349, 1, 10014, NULL, NULL),
	(349, 1, 10029, NULL, NULL),
	(349, 1, 10032, NULL, NULL),
	(349, 1, 10553, NULL, NULL),
	(349, 1, 10587, NULL, NULL),
	(349, 1, 10588, NULL, NULL),
	(349, 1, 10702, NULL, NULL),
	(349, 1, 10705, NULL, NULL),
	(349, 1, 10806, NULL, NULL),
	(349, 1, 11077, NULL, NULL),
	(349, 1, 11080, NULL, NULL),
	(349, 1, 11427, NULL, NULL),
	(349, 1, 11428, NULL, NULL),
	(353, 1, 10000, 0, NULL),
	(353, 1, 10001, 0, NULL),
	(353, 1, 10002, 0, NULL),
	(353, 1, 10008, 0, NULL),
	(353, 1, 10012, 0, NULL),
	(353, 1, 10013, 0, NULL),
	(353, 1, 10014, 0, NULL),
	(353, 1, 10029, 0, NULL),
	(353, 1, 10032, 0, NULL),
	(353, 1, 10033, 0, NULL),
	(353, 1, 10045, 0, NULL),
	(353, 1, 10046, 0, NULL),
	(353, 1, 10085, 0, NULL),
	(353, 1, 10092, 0, NULL),
	(353, 1, 10093, 0, NULL),
	(353, 1, 10094, 0, NULL),
	(353, 1, 10095, 0, NULL),
	(353, 1, 10096, 0, NULL),
	(353, 1, 10108, 0, NULL),
	(353, 1, 10109, 0, NULL),
	(353, 1, 10112, 0, NULL),
	(353, 1, 10127, 0, NULL),
	(353, 1, 10128, 0, NULL),
	(353, 1, 10129, 0, NULL),
	(353, 1, 10130, 0, NULL),
	(353, 1, 10131, 0, NULL),
	(353, 1, 10132, 0, NULL),
	(353, 1, 10133, 0, NULL),
	(353, 1, 10134, 0, NULL),
	(353, 1, 10135, 0, NULL),
	(353, 1, 10136, 0, NULL),
	(353, 1, 10137, 0, NULL),
	(353, 1, 10138, 0, NULL),
	(353, 1, 10272, 0, NULL),
	(353, 1, 10273, 0, NULL),
	(353, 1, 10419, 0, NULL),
	(353, 1, 10759, 0, NULL),
	(353, 1, 10760, 0, NULL),
	(353, 1, 10793, 0, NULL),
	(353, 1, 10833, 0, NULL),
	(353, 1, 10887, 0, NULL),
	(353, 1, 10954, 0, NULL),
	(353, 1, 10955, 0, NULL),
	(353, 1, 11237, 0, NULL),
	(353, 1, 11274, 0, NULL),
	(356, 1, 10010, 1, 1),
	(356, 1, 10014, 0, NULL),
	(356, 1, 10029, 0, NULL),
	(367, 1, 10000, 0, NULL),
	(367, 1, 10001, 0, NULL),
	(367, 1, 10002, 0, NULL),
	(367, 1, 10003, 0, NULL),
	(367, 1, 10010, 0, NULL),
	(367, 1, 10014, 0, NULL),
	(367, 1, 10029, 0, NULL),
	(367, 1, 10030, 0, NULL),
	(367, 1, 10032, 0, NULL),
	(367, 1, 10043, 0, NULL),
	(367, 1, 10044, 0, NULL),
	(367, 1, 10088, 0, NULL),
	(367, 1, 10108, 0, NULL),
	(367, 1, 10109, 0, NULL),
	(367, 1, 10115, 0, NULL),
	(367, 1, 10116, 0, NULL),
	(367, 1, 10272, 0, NULL),
	(367, 1, 10273, 0, NULL),
	(367, 1, 10284, 0, NULL),
	(367, 1, 10434, 0, NULL),
	(367, 1, 10450, 0, NULL),
	(367, 1, 10451, 0, NULL),
	(367, 1, 10452, 0, NULL),
	(367, 1, 10530, 0, NULL),
	(367, 1, 10531, 0, NULL),
	(367, 1, 10532, 0, NULL),
	(367, 1, 10533, 0, NULL),
	(367, 1, 10534, 0, NULL),
	(367, 1, 10535, 0, NULL),
	(367, 1, 10549, 0, NULL),
	(367, 1, 10550, 0, NULL),
	(367, 1, 10551, 0, NULL),
	(367, 1, 10555, 0, NULL),
	(367, 1, 10556, 0, NULL),
	(367, 1, 10557, 0, NULL),
	(367, 1, 10562, 0, NULL),
	(367, 1, 10569, 0, NULL),
	(367, 1, 10745, 0, NULL),
	(367, 1, 10746, 0, NULL),
	(367, 1, 10747, 0, NULL),
	(367, 1, 10777, 0, NULL),
	(367, 1, 10828, 0, NULL),
	(367, 1, 10849, 0, NULL),
	(367, 1, 10894, 0, NULL),
	(367, 1, 10895, 0, NULL),
	(367, 1, 10931, 0, NULL),
	(367, 1, 11137, 0, NULL),
	(367, 1, 11159, 0, NULL),
	(367, 1, 11426, 0, NULL),
	(367, 1, 11536, 0, NULL),
	(367, 1, 11537, 0, NULL),
	(367, 1, 11538, 0, NULL),
	(367, 1, 11539, 0, NULL),
	(367, 1, 11540, 0, NULL),
	(367, 1, 11541, 0, NULL),
	(367, 1, 11542, 0, NULL),
	(367, 1, 11543, 0, NULL),
	(367, 1, 11544, 0, NULL),
	(367, 1, 11545, 0, NULL),
	(367, 1, 11546, 0, NULL),
	(367, 1, 11547, 0, NULL),
	(367, 1, 11548, 0, NULL),
	(367, 1, 11549, 0, NULL),
	(367, 1, 11550, 0, NULL),
	(367, 1, 11551, 0, NULL),
	(369, 1, 10012, 1, 0),
	(369, 1, 10077, 1, 0),
	(369, 1, 10078, 1, 0),
	(369, 1, 10586, 0, 1),
	(369, 1, 10848, 0, 1),
	(369, 1, 10945, 1, 0),
	(370, 1, 10000, 0, 1),
	(370, 1, 10001, 0, 1),
	(370, 1, 10002, 0, 1),
	(370, 1, 10003, 0, 1),
	(370, 1, 10007, 0, 1),
	(370, 1, 10014, 0, 1),
	(370, 1, 10015, 0, 1),
	(370, 1, 10029, 0, 1),
	(370, 1, 10044, 0, 1),
	(370, 1, 10048, 0, 1),
	(370, 1, 10112, 0, 1),
	(370, 1, 10272, 0, 1),
	(370, 1, 10273, 0, 1),
	(370, 1, 10450, 0, 1),
	(370, 1, 10451, 0, 1),
	(370, 1, 10452, 0, 1),
	(370, 1, 10485, 0, 1),
	(370, 1, 10553, 0, 1),
	(370, 1, 10762, 0, 1),
	(370, 1, 10854, 0, 1),
	(370, 1, 10886, 0, 1),
	(370, 1, 11187, 0, 1),
	(370, 1, 11193, 0, 1),
	(370, 1, 11325, 0, 1),
	(370, 1, 11326, 0, 1),
	(370, 1, 11327, 0, 1),
	(370, 1, 11328, 0, 1),
	(370, 1, 11329, 0, 1),
	(370, 1, 11330, 0, 1),
	(370, 1, 11331, 0, 1),
	(370, 1, 11332, 0, 1),
	(370, 1, 11333, 0, 1),
	(370, 1, 11334, 0, 1),
	(370, 1, 11335, 0, 1),
	(370, 1, 11336, 0, 1),
	(370, 1, 11337, 0, 1),
	(370, 1, 11338, 0, 1),
	(370, 1, 11339, 0, 1),
	(370, 1, 11340, 0, 1),
	(370, 1, 11341, 0, 1),
	(370, 1, 11342, 0, 1),
	(370, 1, 11343, 0, 1),
	(370, 1, 11344, 0, 1),
	(370, 1, 11345, 0, 1),
	(370, 1, 11346, 0, 1),
	(370, 1, 11347, 0, 1),
	(370, 1, 11348, 0, 1),
	(370, 1, 11349, 0, 1),
	(370, 1, 11350, 0, 1),
	(370, 1, 11351, 0, 1),
	(370, 1, 11352, 0, 1),
	(370, 1, 11353, 0, 1),
	(370, 1, 11354, 0, 1),
	(370, 1, 11355, 0, 1),
	(370, 1, 11356, 0, 1),
	(370, 1, 11357, 0, 1),
	(370, 1, 11358, 0, 1),
	(370, 1, 11359, 0, 1),
	(370, 1, 11360, 0, 1),
	(370, 1, 11361, 0, 1),
	(370, 1, 11362, 0, 1),
	(370, 1, 11363, 0, 1),
	(370, 1, 11364, 0, 1),
	(370, 1, 11365, 0, 1),
	(370, 1, 11366, 0, 1),
	(370, 1, 11367, 0, 1),
	(370, 1, 11368, 0, 1),
	(370, 1, 11369, 0, 1),
	(370, 1, 11370, 0, 1),
	(370, 1, 11371, 0, 1),
	(370, 1, 11372, 0, 1),
	(370, 1, 11373, 0, 1),
	(370, 1, 11374, 0, 1),
	(371, 1, 10000, 0, 1),
	(371, 1, 10001, 0, 1),
	(371, 1, 10002, 0, 1),
	(371, 1, 10003, 0, 1),
	(371, 1, 10007, 0, 1),
	(371, 1, 10014, 0, 1),
	(371, 1, 10015, 0, 1),
	(371, 1, 10029, 0, 1),
	(371, 1, 10044, 0, 1),
	(371, 1, 10048, 0, 1),
	(371, 1, 10112, 0, 1),
	(371, 1, 10272, 0, 1),
	(371, 1, 10273, 0, 1),
	(371, 1, 10450, 0, 1),
	(371, 1, 10451, 0, 1),
	(371, 1, 10452, 0, 1),
	(371, 1, 10485, 0, 1),
	(371, 1, 10553, 0, 1),
	(371, 1, 10762, 0, 1),
	(371, 1, 10854, 0, 1),
	(371, 1, 10886, 0, 1),
	(371, 1, 11187, 0, 1),
	(371, 1, 11193, 0, 1),
	(371, 1, 11325, 0, 1),
	(371, 1, 11326, 0, 1),
	(371, 1, 11327, 0, 1),
	(371, 1, 11328, 0, 1),
	(371, 1, 11329, 0, 1),
	(371, 1, 11330, 0, 1),
	(371, 1, 11331, 0, 1),
	(371, 1, 11332, 0, 1),
	(371, 1, 11333, 0, 1),
	(371, 1, 11334, 0, 1),
	(371, 1, 11335, 0, 1),
	(371, 1, 11336, 0, 1),
	(371, 1, 11337, 0, 1),
	(371, 1, 11338, 0, 1),
	(371, 1, 11339, 0, 1),
	(371, 1, 11340, 0, 1),
	(371, 1, 11341, 0, 1),
	(371, 1, 11342, 0, 1),
	(371, 1, 11343, 0, 1),
	(371, 1, 11344, 0, 1),
	(371, 1, 11345, 0, 1),
	(371, 1, 11346, 0, 1),
	(371, 1, 11347, 0, 1),
	(371, 1, 11348, 0, 1),
	(371, 1, 11349, 0, 1),
	(371, 1, 11350, 0, 1),
	(371, 1, 11351, 0, 1),
	(371, 1, 11352, 0, 1),
	(371, 1, 11353, 0, 1),
	(371, 1, 11354, 0, 1),
	(371, 1, 11355, 0, 1),
	(371, 1, 11356, 0, 1),
	(371, 1, 11357, 0, 1),
	(371, 1, 11358, 0, 1),
	(371, 1, 11359, 0, 1),
	(371, 1, 11360, 0, 1),
	(371, 1, 11361, 0, 1),
	(371, 1, 11362, 0, 1),
	(371, 1, 11363, 0, 1),
	(371, 1, 11364, 0, 1),
	(371, 1, 11365, 0, 1),
	(371, 1, 11366, 0, 1),
	(371, 1, 11367, 0, 1),
	(371, 1, 11368, 0, 1),
	(371, 1, 11369, 0, 1),
	(371, 1, 11370, 0, 1),
	(371, 1, 11371, 0, 1),
	(371, 1, 11372, 0, 1),
	(371, 1, 11373, 0, 1),
	(371, 1, 11374, 0, 1),
	(372, 1, 10000, 0, 1),
	(372, 1, 10001, 0, 1),
	(372, 1, 10002, 0, 1),
	(372, 1, 10003, 0, 1),
	(372, 1, 10007, 0, 1),
	(372, 1, 10014, 0, 1),
	(372, 1, 10015, 0, 1),
	(372, 1, 10029, 0, 1),
	(372, 1, 10044, 0, 1),
	(372, 1, 10048, 0, 1),
	(372, 1, 10112, 0, 1),
	(372, 1, 10272, 0, 1),
	(372, 1, 10273, 0, 1),
	(372, 1, 10450, 0, 1),
	(372, 1, 10451, 0, 1),
	(372, 1, 10452, 0, 1),
	(372, 1, 10485, 0, 1),
	(372, 1, 10553, 0, 1),
	(372, 1, 10762, 0, 1),
	(372, 1, 10854, 0, 1),
	(372, 1, 10886, 0, 1),
	(372, 1, 11187, 0, 1),
	(372, 1, 11193, 0, 1),
	(372, 1, 11325, 0, 1),
	(372, 1, 11326, 0, 1),
	(372, 1, 11327, 0, 1),
	(372, 1, 11328, 0, 1),
	(372, 1, 11329, 0, 1),
	(372, 1, 11330, 0, 1),
	(372, 1, 11331, 0, 1),
	(372, 1, 11332, 0, 1),
	(372, 1, 11333, 0, 1),
	(372, 1, 11334, 0, 1),
	(372, 1, 11335, 0, 1),
	(372, 1, 11336, 0, 1),
	(372, 1, 11337, 0, 1),
	(372, 1, 11338, 0, 1),
	(372, 1, 11339, 0, 1),
	(372, 1, 11340, 0, 1),
	(372, 1, 11341, 0, 1),
	(372, 1, 11342, 0, 1),
	(372, 1, 11343, 0, 1),
	(372, 1, 11344, 0, 1),
	(372, 1, 11345, 0, 1),
	(372, 1, 11346, 0, 1),
	(372, 1, 11347, 0, 1),
	(372, 1, 11348, 0, 1),
	(372, 1, 11349, 0, 1),
	(372, 1, 11350, 0, 1),
	(372, 1, 11351, 0, 1),
	(372, 1, 11352, 0, 1),
	(372, 1, 11353, 0, 1),
	(372, 1, 11354, 0, 1),
	(372, 1, 11355, 0, 1),
	(372, 1, 11356, 0, 1),
	(372, 1, 11357, 0, 1),
	(372, 1, 11358, 0, 1),
	(372, 1, 11359, 0, 1),
	(372, 1, 11360, 0, 1),
	(372, 1, 11361, 0, 1),
	(372, 1, 11362, 0, 1),
	(372, 1, 11363, 0, 1),
	(372, 1, 11364, 0, 1),
	(372, 1, 11365, 0, 1),
	(372, 1, 11366, 0, 1),
	(372, 1, 11367, 0, 1),
	(372, 1, 11368, 0, 1),
	(372, 1, 11369, 0, 1),
	(372, 1, 11370, 0, 1),
	(372, 1, 11371, 0, 1),
	(372, 1, 11372, 0, 1),
	(372, 1, 11373, 0, 1),
	(372, 1, 11374, 0, 1),
	(374, 1, 10586, NULL, NULL),
	(375, 1, 10586, NULL, NULL),
	(376, 1, 10586, NULL, NULL),
	(377, 1, 10586, NULL, NULL),
	(382, 1, 4019, 1, 0),
	(382, 1, 10003, NULL, NULL),
	(382, 1, 10010, NULL, 0),
	(382, 1, 10011, NULL, 0),
	(382, 1, 10012, NULL, 0),
	(382, 1, 10014, NULL, NULL),
	(382, 1, 10015, NULL, NULL),
	(382, 1, 10026, NULL, NULL),
	(382, 1, 10029, NULL, NULL),
	(382, 1, 10038, NULL, NULL),
	(382, 1, 10530, NULL, NULL),
	(382, 1, 10531, NULL, NULL),
	(382, 1, 10532, NULL, NULL),
	(382, 1, 10533, NULL, NULL),
	(382, 1, 10534, NULL, NULL),
	(382, 1, 10535, NULL, NULL),
	(382, 1, 10549, NULL, 0),
	(382, 1, 10550, NULL, 0),
	(382, 1, 10551, NULL, 0),
	(382, 1, 10553, NULL, NULL),
	(382, 1, 10587, NULL, NULL),
	(382, 1, 10597, NULL, 0),
	(382, 1, 10705, NULL, NULL),
	(382, 1, 10709, NULL, NULL),
	(382, 1, 10770, NULL, NULL),
	(382, 1, 11080, NULL, NULL),
	(383, 0, 4012, 1, 0),
	(385, 1, 10012, NULL, NULL),
	(385, 1, 10015, NULL, NULL),
	(385, 1, 10050, NULL, NULL),
	(385, 1, 10078, NULL, NULL),
	(385, 1, 10269, NULL, NULL),
	(385, 1, 10294, NULL, NULL),
	(385, 1, 10771, NULL, NULL),
	(385, 1, 10878, NULL, NULL),
	(385, 1, 10881, NULL, NULL),
	(385, 1, 10886, NULL, NULL),
	(385, 1, 10945, NULL, NULL),
	(385, 1, 11116, NULL, NULL),
	(385, 1, 11276, NULL, NULL),
	(385, 1, 11325, NULL, NULL),
	(385, 1, 11635, NULL, NULL),
	(385, 1, 11636, NULL, NULL),
	(385, 1, 11637, NULL, NULL),
	(385, 1, 11638, NULL, NULL),
	(385, 1, 11639, NULL, NULL),
	(385, 1, 11640, NULL, NULL),
	(385, 1, 11641, NULL, NULL),
	(385, 1, 11642, NULL, NULL),
	(385, 1, 11643, NULL, NULL),
	(385, 1, 11644, NULL, NULL),
	(385, 1, 11645, NULL, NULL),
	(385, 1, 11646, NULL, NULL),
	(385, 1, 11647, NULL, NULL),
	(385, 1, 11648, NULL, NULL),
	(385, 1, 11649, NULL, NULL),
	(385, 1, 11650, NULL, NULL),
	(385, 1, 11651, NULL, NULL),
	(385, 1, 11652, NULL, NULL),
	(385, 1, 11653, NULL, NULL),
	(385, 1, 11654, NULL, NULL),
	(385, 1, 11655, NULL, NULL),
	(385, 1, 11656, NULL, NULL),
	(385, 1, 11657, NULL, NULL),
	(385, 1, 11658, NULL, NULL),
	(385, 1, 11659, NULL, NULL),
	(385, 1, 11660, NULL, NULL),
	(385, 1, 11661, NULL, NULL),
	(385, 1, 11662, NULL, NULL),
	(385, 1, 11663, NULL, NULL),
	(385, 1, 11664, NULL, NULL),
	(385, 1, 11665, NULL, NULL),
	(385, 1, 11666, NULL, NULL),
	(385, 1, 11667, NULL, NULL),
	(385, 1, 11668, NULL, NULL),
	(385, 1, 11669, NULL, NULL),
	(385, 1, 11670, NULL, NULL),
	(385, 1, 11671, NULL, NULL),
	(385, 1, 11672, NULL, NULL),
	(385, 1, 11673, NULL, NULL),
	(385, 1, 11674, NULL, NULL),
	(385, 1, 11675, NULL, NULL),
	(385, 1, 11676, NULL, NULL),
	(385, 1, 11677, NULL, NULL),
	(385, 1, 11678, NULL, NULL),
	(385, 1, 11679, NULL, NULL),
	(385, 1, 11680, NULL, NULL),
	(385, 1, 11681, NULL, NULL),
	(385, 1, 11682, NULL, NULL),
	(385, 1, 11683, NULL, NULL),
	(385, 1, 11684, NULL, NULL),
	(385, 1, 11685, NULL, NULL),
	(385, 1, 11686, NULL, NULL),
	(385, 1, 11687, NULL, NULL),
	(385, 1, 11688, NULL, NULL),
	(385, 1, 11689, NULL, NULL),
	(386, 1, 10008, NULL, NULL),
	(386, 1, 10012, NULL, NULL),
	(386, 1, 10015, NULL, NULL),
	(386, 1, 10030, NULL, NULL),
	(386, 1, 10078, NULL, NULL),
	(386, 1, 10085, NULL, NULL),
	(386, 1, 10269, NULL, NULL),
	(386, 1, 10280, NULL, NULL),
	(386, 1, 10771, NULL, NULL),
	(386, 1, 10878, NULL, NULL),
	(386, 1, 11116, NULL, NULL),
	(386, 1, 11276, NULL, NULL),
	(386, 1, 11635, NULL, NULL),
	(386, 1, 11636, NULL, NULL),
	(386, 1, 11637, NULL, NULL),
	(386, 1, 11638, NULL, NULL),
	(386, 1, 11642, NULL, NULL),
	(386, 1, 11644, NULL, NULL),
	(386, 1, 11645, NULL, NULL),
	(386, 1, 11646, NULL, NULL),
	(386, 1, 11647, NULL, NULL),
	(386, 1, 11648, NULL, NULL),
	(386, 1, 11651, NULL, NULL),
	(386, 1, 11653, NULL, NULL),
	(386, 1, 11660, NULL, NULL),
	(386, 1, 11663, NULL, NULL),
	(386, 1, 11665, NULL, NULL),
	(386, 1, 11676, NULL, NULL),
	(386, 1, 11677, NULL, NULL),
	(386, 1, 11678, NULL, NULL),
	(386, 1, 11689, NULL, NULL),
	(386, 1, 11753, NULL, NULL),
	(386, 1, 11754, NULL, NULL),
	(386, 1, 11755, NULL, NULL),
	(386, 1, 11756, NULL, NULL),
	(387, 1, 10012, NULL, NULL),
	(387, 1, 10015, NULL, NULL),
	(387, 1, 10029, NULL, NULL),
	(387, 1, 10078, NULL, NULL),
	(387, 1, 10269, NULL, NULL),
	(387, 1, 10432, NULL, NULL),
	(387, 1, 10771, NULL, NULL),
	(387, 1, 10886, NULL, NULL),
	(387, 1, 11115, NULL, NULL),
	(387, 1, 11116, NULL, NULL),
	(387, 1, 11276, NULL, NULL),
	(387, 1, 11635, NULL, NULL),
	(387, 1, 11638, NULL, NULL),
	(387, 1, 11639, NULL, NULL),
	(387, 1, 11640, NULL, NULL),
	(387, 1, 11641, NULL, NULL),
	(387, 1, 11642, NULL, NULL),
	(387, 1, 11643, NULL, NULL),
	(387, 1, 11644, NULL, NULL),
	(387, 1, 11648, NULL, NULL),
	(387, 1, 11649, NULL, NULL),
	(387, 1, 11651, NULL, NULL),
	(387, 1, 11652, NULL, NULL),
	(387, 1, 11653, NULL, NULL),
	(387, 1, 11654, NULL, NULL),
	(387, 1, 11655, NULL, NULL),
	(387, 1, 11656, NULL, NULL),
	(387, 1, 11662, NULL, NULL),
	(387, 1, 11684, NULL, NULL),
	(387, 1, 11690, NULL, NULL),
	(387, 1, 11691, NULL, NULL),
	(387, 1, 11692, NULL, NULL),
	(387, 1, 11693, NULL, NULL),
	(387, 1, 11694, NULL, NULL),
	(387, 1, 11695, NULL, NULL),
	(387, 1, 11696, NULL, NULL),
	(387, 1, 11697, NULL, NULL),
	(387, 1, 11698, NULL, NULL),
	(387, 1, 11699, NULL, NULL),
	(387, 1, 11700, NULL, NULL),
	(387, 1, 11701, NULL, NULL),
	(387, 1, 11702, NULL, NULL),
	(387, 1, 11703, NULL, NULL),
	(387, 1, 11704, NULL, NULL),
	(387, 1, 11705, NULL, NULL),
	(387, 1, 11706, NULL, NULL),
	(387, 1, 11707, NULL, NULL),
	(387, 1, 11708, NULL, NULL),
	(387, 1, 11709, NULL, NULL),
	(387, 1, 11710, NULL, NULL),
	(387, 1, 11711, NULL, NULL),
	(387, 1, 11712, NULL, NULL),
	(387, 1, 11713, NULL, NULL),
	(387, 1, 11714, NULL, NULL),
	(387, 1, 11715, NULL, NULL),
	(387, 1, 11716, NULL, NULL),
	(387, 1, 11717, NULL, NULL),
	(387, 1, 11718, NULL, NULL),
	(387, 1, 11719, NULL, NULL),
	(387, 1, 11720, NULL, NULL),
	(387, 1, 11721, NULL, NULL),
	(387, 1, 11722, NULL, NULL),
	(387, 1, 11723, NULL, NULL),
	(387, 1, 11724, NULL, NULL),
	(387, 1, 11725, NULL, NULL),
	(387, 1, 11726, NULL, NULL),
	(387, 1, 11727, NULL, NULL),
	(387, 1, 11728, NULL, NULL),
	(387, 1, 11729, NULL, NULL),
	(387, 1, 11730, NULL, NULL),
	(387, 1, 11731, NULL, NULL),
	(387, 1, 11732, NULL, NULL),
	(387, 1, 11733, NULL, NULL),
	(387, 1, 11734, NULL, NULL),
	(387, 1, 11735, NULL, NULL),
	(387, 1, 11736, NULL, NULL),
	(387, 1, 11737, NULL, NULL),
	(387, 1, 11738, NULL, NULL),
	(387, 1, 11739, NULL, NULL),
	(387, 1, 11740, NULL, NULL),
	(387, 1, 11741, NULL, NULL),
	(387, 1, 11742, NULL, NULL),
	(387, 1, 11743, NULL, NULL),
	(387, 1, 11744, NULL, NULL),
	(387, 1, 11745, NULL, NULL),
	(387, 1, 11746, NULL, NULL),
	(387, 1, 11747, NULL, NULL),
	(387, 1, 11748, NULL, NULL),
	(387, 1, 11749, NULL, NULL),
	(387, 1, 11750, NULL, NULL),
	(387, 1, 11751, NULL, NULL),
	(387, 1, 11752, NULL, NULL);
/*!40000 ALTER TABLE `src_type_withe` ENABLE KEYS */;

-- Dumping structure for table emcor.sta_gl
CREATE TABLE IF NOT EXISTS `sta_gl` (
  `mo` date NOT NULL COMMENT 'Mėnuo',
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  `ml_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo linijos identifikatorius',
  `user_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojo identifikatorius',
  `is_web_ses` tinyint(1) NOT NULL COMMENT 'Požymis, ar susiję su Web sesija',
  `cnt` int(10) unsigned NOT NULL COMMENT 'Kiekis',
  `da_cnt` int(10) unsigned NOT NULL COMMENT 'Dienų kiekis',
  PRIMARY KEY (`mo`,`gr_id`,`ml_id`,`user_id`,`is_web_ses`),
  KEY `sta_gl_gr_fk` (`gr_id`),
  KEY `sta_gl_ml_fk` (`ml_id`),
  KEY `sta_gl_user_fk` (`user_id`),
  CONSTRAINT `sta_gl_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE,
  CONSTRAINT `sta_gl_ml_fk` FOREIGN KEY (`ml_id`) REFERENCES `ml` (`ml_id`) ON DELETE CASCADE,
  CONSTRAINT `sta_gl_user_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Grupių matavimų archyvų užklausų statistika';

-- Dumping data for table emcor.sta_gl: ~0 rows (approximately)
/*!40000 ALTER TABLE `sta_gl` DISABLE KEYS */;
/*!40000 ALTER TABLE `sta_gl` ENABLE KEYS */;

-- Dumping structure for table emcor.sta_grq_data
CREATE TABLE IF NOT EXISTS `sta_grq_data` (
  `grq_time` datetime NOT NULL COMMENT 'Sugrupuotos užklausos draiveriui laikas',
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  `grq_nr` smallint(5) unsigned NOT NULL COMMENT 'Sugrupuotos užklausos draiveriui numeris',
  `grq_otype_id` smallint(5) unsigned NOT NULL COMMENT 'Sugrupuotos užklausos draiveriui operacijos tipas',
  `grq_otime` datetime NOT NULL COMMENT 'Sugrupuotos užklausos draiveriui operacijos laikas',
  `grq_onr` mediumint(8) unsigned NOT NULL COMMENT 'Sugrupuotos užklausos draiveriui operacijos numeris',
  `evc_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Sistemos įvykių klasės identifikatorius',
  `evt_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Sistemos įvykių tipo identifikatorius',
  `evd_id` int(10) unsigned DEFAULT NULL COMMENT 'Įvykio detalus ID',
  PRIMARY KEY (`grq_otime`,`das_id`,`grq_onr`),
  KEY `sta_grq_data_grq_i` (`grq_time`,`das_id`,`grq_nr`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Šaltinių statistikos sugrupuotų užklausų įvykiai'
 PARTITION BY RANGE (
    to_days(grq_otime))
(PARTITION par_201708 VALUES LESS THAN (736751) ENGINE = InnoDB,
 PARTITION par_201709 VALUES LESS THAN (736758) ENGINE = InnoDB,
 PARTITION par_201710 VALUES LESS THAN (736765) ENGINE = InnoDB);

-- Dumping data for table emcor.sta_grq_data: ~3 rows (approximately)
/*!40000 ALTER TABLE `sta_grq_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `sta_grq_data` ENABLE KEYS */;

-- Dumping structure for table emcor.sta_ph_data
CREATE TABLE IF NOT EXISTS `sta_ph_data` (
  `src_atime` datetime NOT NULL COMMENT 'Draiverio atsakymo laikas',
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  `src_anr` smallint(5) unsigned NOT NULL COMMENT 'Draiverio atsakymo numeris',
  `ph_otype_id` tinyint(3) unsigned NOT NULL COMMENT 'Transporto operacijos tipas',
  `ses_time` datetime NOT NULL COMMENT 'Sesijos laikas',
  `ses_nr` smallint(5) unsigned NOT NULL COMMENT 'Sesijos numeris',
  `ph_id` int(10) unsigned NOT NULL COMMENT 'Ryšio kanalo identifikatorius',
  `grq_time` datetime NOT NULL COMMENT 'Sugrupuotos užklausos draiveriui laikas',
  `grq_nr` smallint(5) unsigned NOT NULL COMMENT 'Sugrupuotos užklausos draiveriui numeris',
  `ph_otime` datetime DEFAULT NULL COMMENT 'Transporto operacijos laikas',
  `bytes_sent` int(10) unsigned DEFAULT NULL COMMENT 'Perduotų baitų skaičius',
  `bytes_received` int(10) unsigned DEFAULT NULL COMMENT 'Gautų baitų skaičius',
  `ph_etype_id` mediumint(8) DEFAULT NULL COMMENT 'Transporto klaidos tipas',
  PRIMARY KEY (`src_atime`,`das_id`,`src_anr`,`ph_otype_id`),
  KEY `sta_ph_data_grq_i` (`grq_time`,`das_id`,`grq_nr`),
  KEY `sta_ph_data_ph_i` (`ph_id`,`src_atime`),
  KEY `sta_ph_data_ses_i` (`ses_time`,`das_id`,`ses_nr`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Ryšio kanalų statistikos informacija'
 PARTITION BY RANGE (
    to_days(src_atime))
(PARTITION par_201708 VALUES LESS THAN (736751) ENGINE = InnoDB,
 PARTITION par_201709 VALUES LESS THAN (736758) ENGINE = InnoDB,
 PARTITION par_201710 VALUES LESS THAN (736765) ENGINE = InnoDB);

-- Dumping data for table emcor.sta_ph_data: ~3 rows (approximately)
/*!40000 ALTER TABLE `sta_ph_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `sta_ph_data` ENABLE KEYS */;

-- Dumping structure for table emcor.sta_prq
CREATE TABLE IF NOT EXISTS `sta_prq` (
  `prq_time` datetime NOT NULL COMMENT 'Pirminės užklausos draiveriui laikas',
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  `prq_nr` mediumint(8) unsigned NOT NULL COMMENT 'Pirminės užklausos draiveriui numeris',
  `grq_time` datetime NOT NULL COMMENT 'Sugrupuotos užklausos draiveriui laikas',
  `grq_nr` smallint(5) unsigned NOT NULL COMMENT 'Sugrupuotos užklausos draiveriui numeris',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `rc_id` tinyint(3) unsigned NOT NULL COMMENT 'Užklausų priežasties identifikatorius',
  `prq_from_time` datetime DEFAULT NULL COMMENT 'Pirminės užklausos draiveriui datos intervalo pradžia',
  `prq_to_time` datetime DEFAULT NULL COMMENT 'Pirminės užklausos draiveriui datos intervalo pabaiga',
  `sch_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Tvarkaraščio identifikatorius',
  `sch_time` datetime DEFAULT NULL COMMENT 'Tvarkaraščio suveikimo laikas',
  `prq_repeat` tinyint(3) unsigned DEFAULT NULL,
  `rodo_id` int(10) unsigned DEFAULT NULL COMMENT 'Užsakymo ID',
  `rodo_nr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Užsakymo elemento numeris',
  PRIMARY KEY (`prq_time`,`das_id`,`prq_nr`),
  KEY `sta_prq_grq_i` (`grq_time`,`das_id`,`grq_nr`),
  KEY `sta_prq_sch_i` (`sch_id`,`prq_time`),
  KEY `sta_prq_sep_i` (`sep_id`,`prq_time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Šaltinių statistikos pirminių užklausų informacija'
 PARTITION BY RANGE (
    to_days(prq_time))
(PARTITION par_201708 VALUES LESS THAN (736751) ENGINE = InnoDB,
 PARTITION par_201709 VALUES LESS THAN (736758) ENGINE = InnoDB,
 PARTITION par_201710 VALUES LESS THAN (736765) ENGINE = InnoDB);

-- Dumping data for table emcor.sta_prq: ~3 rows (approximately)
/*!40000 ALTER TABLE `sta_prq` DISABLE KEYS */;
/*!40000 ALTER TABLE `sta_prq` ENABLE KEYS */;

-- Dumping structure for table emcor.sta_prq_data
CREATE TABLE IF NOT EXISTS `sta_prq_data` (
  `prq_time` datetime NOT NULL COMMENT 'Pirminės užklausos draiveriui laikas',
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  `prq_nr` mediumint(8) unsigned NOT NULL COMMENT 'Pirminės užklausos draiveriui numeris',
  `src_atime` datetime NOT NULL COMMENT 'Draiverio atsakymo laikas',
  `src_anr` smallint(5) unsigned NOT NULL COMMENT 'Draiverio atsakymo numeris',
  `evc_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Sistemos įvykių klasės identifikatorius',
  `evt_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Sistemos įvykių tipo identifikatorius',
  `evd_id` int(10) unsigned DEFAULT NULL COMMENT 'Įvykio detalus ID',
  `src_aid` smallint(5) unsigned NOT NULL COMMENT 'Draiverio atsakymo identifikatorius',
  PRIMARY KEY (`prq_time`,`das_id`,`prq_nr`,`src_atime`,`src_anr`,`src_aid`),
  KEY `sta_prq_data_src_i` (`src_atime`,`das_id`,`src_anr`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Šaltinių statistikos pirminių užklausų atsakymų informacija'
 PARTITION BY RANGE (
    to_days(prq_time))
(PARTITION par_201708 VALUES LESS THAN (736751) ENGINE = InnoDB,
 PARTITION par_201709 VALUES LESS THAN (736758) ENGINE = InnoDB,
 PARTITION par_201710 VALUES LESS THAN (736765) ENGINE = InnoDB);

-- Dumping data for table emcor.sta_prq_data: ~3 rows (approximately)
/*!40000 ALTER TABLE `sta_prq_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `sta_prq_data` ENABLE KEYS */;

-- Dumping structure for table emcor.sta_src_data
CREATE TABLE IF NOT EXISTS `sta_src_data` (
  `src_atime` datetime NOT NULL COMMENT 'Draiverio atsakymo laikas',
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  `src_anr` smallint(5) unsigned NOT NULL COMMENT 'Draiverio atsakymo numeris',
  `pctimebefore` datetime(3) DEFAULT NULL COMMENT 'Kompiuterio laikas prieš operacija',
  `pctimeafter` datetime(3) DEFAULT NULL COMMENT 'Kompiuterio laikas po operacijos',
  `bytes_sent` int(10) unsigned DEFAULT NULL COMMENT 'Perduotų baitų skaičius',
  `bytes_received` int(10) unsigned DEFAULT NULL COMMENT 'Gautų baitų skaičius',
  `packets_sent` int(10) unsigned DEFAULT NULL COMMENT 'Perduotų paketų skaičius',
  `packets_received` int(10) unsigned DEFAULT NULL COMMENT 'Gautų paketų skaičius',
  `bytes_received_bad` int(10) unsigned DEFAULT NULL COMMENT 'Gautų baitų skaičius, kurie neatitiko protokolo reikalavimų',
  `evc_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Sistemos įvykių klasės identifikatorius',
  `evt_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Sistemos įvykių tipo identifikatorius',
  `evd_id` int(10) unsigned DEFAULT NULL COMMENT 'Įvykio detalus ID',
  `grq_time` datetime DEFAULT NULL COMMENT 'Sugrupuotos užklausos draiveriui laikas',
  `grq_nr` smallint(5) unsigned DEFAULT NULL COMMENT 'Sugrupuotos užklausos draiveriui numeris',
  PRIMARY KEY (`src_atime`,`das_id`,`src_anr`),
  KEY `sta_src_data_grq_i` (`grq_time`,`das_id`,`grq_nr`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Šaltinių statistikos sugrupuotų užklausų atsakymų informacija'
 PARTITION BY RANGE (
    to_days(src_atime))
(PARTITION par_201708 VALUES LESS THAN (736751) ENGINE = InnoDB,
 PARTITION par_201709 VALUES LESS THAN (736758) ENGINE = InnoDB,
 PARTITION par_201710 VALUES LESS THAN (736765) ENGINE = InnoDB);

-- Dumping data for table emcor.sta_src_data: ~3 rows (approximately)
/*!40000 ALTER TABLE `sta_src_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `sta_src_data` ENABLE KEYS */;

-- Dumping structure for table emcor.steady
CREATE TABLE IF NOT EXISTS `steady` (
  `eva_id` int(10) unsigned NOT NULL COMMENT 'Įvykių atvejo identifikatorius',
  `steady_id` int(10) unsigned NOT NULL COMMENT 'Objekto, kuriam identifikuojama nusistovėjusi būsena, identifikatorius',
  `steady_active` tinyint(1) NOT NULL COMMENT 'Aktyvaus nusistovėjusios būsenos nustatymo rėžimo požymis',
  `ev_time` datetime NOT NULL COMMENT 'Įvykio laikas',
  `ev_id` mediumint(8) unsigned NOT NULL COMMENT 'Įvykio ID',
  `db_time` datetime DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `dtime` datetime DEFAULT NULL COMMENT 'Duomenų laikas',
  `steady_val` int(10) unsigned DEFAULT NULL COMMENT 'Nusistovėjusios būsenos reikšmė',
  PRIMARY KEY (`eva_id`,`steady_id`),
  KEY `steady_ev_i` (`ev_id`),
  KEY `steady_steady_active_i` (`steady_active`),
  CONSTRAINT `steady_eva_fk` FOREIGN KEY (`eva_id`) REFERENCES `eva` (`eva_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Įvykių atvejų nusistovėjusių būsenų informacija';

-- Dumping data for table emcor.steady: ~0 rows (approximately)
/*!40000 ALTER TABLE `steady` DISABLE KEYS */;
/*!40000 ALTER TABLE `steady` ENABLE KEYS */;

-- Dumping structure for table emcor.store_ds_buf
CREATE TABLE IF NOT EXISTS `store_ds_buf` (
  `store_ds_buf_id` int(10) unsigned NOT NULL,
  `db_time` datetime NOT NULL DEFAULT current_timestamp(),
  `pck_t` datetime DEFAULT NULL,
  `pck_n` smallint(5) unsigned DEFAULT NULL,
  `ds_id` int(10) unsigned DEFAULT NULL,
  `sep_id` int(10) unsigned DEFAULT NULL,
  `t` varchar(50) COLLATE utf8_bin DEFAULT NULL,
  `ds_dst` tinyint(3) unsigned DEFAULT NULL,
  `ds_v` tinyint(3) unsigned DEFAULT NULL,
  `forced` smallint(5) unsigned DEFAULT NULL,
  `dstatus` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `ds_rt` datetime DEFAULT NULL,
  `ds_rdst` tinyint(3) unsigned DEFAULT NULL,
  `req_from` datetime DEFAULT NULL,
  `req_from_dst` tinyint(1) DEFAULT NULL,
  `req_to` datetime DEFAULT NULL,
  `req_to_dst` tinyint(1) DEFAULT NULL,
  PRIMARY KEY (`store_ds_buf_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- Dumping data for table emcor.store_ds_buf: ~0 rows (approximately)
/*!40000 ALTER TABLE `store_ds_buf` DISABLE KEYS */;
/*!40000 ALTER TABLE `store_ds_buf` ENABLE KEYS */;

-- Dumping structure for table emcor.store_ds_debug
CREATE TABLE IF NOT EXISTS `store_ds_debug` (
  `db_time` datetime NOT NULL DEFAULT current_timestamp(),
  `pck_t` datetime DEFAULT NULL,
  `pck_n` smallint(5) unsigned DEFAULT NULL,
  `ds_id` int(10) unsigned DEFAULT NULL,
  `sep_id` int(10) unsigned DEFAULT NULL,
  `t` varchar(50) COLLATE utf8_bin DEFAULT NULL,
  `ds_dst` tinyint(3) unsigned DEFAULT NULL,
  `ds_v` tinyint(3) unsigned DEFAULT NULL,
  `forced` smallint(5) unsigned DEFAULT NULL,
  `dstatus` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `ds_rt` datetime DEFAULT NULL,
  `ds_rdst` tinyint(3) unsigned DEFAULT NULL,
  `req_from` datetime DEFAULT NULL,
  `req_from_dst` tinyint(1) DEFAULT NULL,
  `req_to` datetime DEFAULT NULL,
  `req_to_dst` tinyint(1) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- Dumping data for table emcor.store_ds_debug: ~0 rows (approximately)
/*!40000 ALTER TABLE `store_ds_debug` DISABLE KEYS */;
/*!40000 ALTER TABLE `store_ds_debug` ENABLE KEYS */;

-- Dumping structure for table emcor.store_dw_debug
CREATE TABLE IF NOT EXISTS `store_dw_debug` (
  `pck_t` datetime DEFAULT NULL,
  `dp_id` int(10) unsigned DEFAULT NULL,
  `withe_id` mediumint(8) DEFAULT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `sep_id` int(10) unsigned DEFAULT NULL,
  `t` varchar(30) COLLATE utf8_bin DEFAULT NULL,
  `dst` tinyint(3) unsigned DEFAULT NULL,
  `v` varchar(4000) COLLATE utf8_bin DEFAULT NULL,
  `rt` datetime DEFAULT NULL,
  `rdst` tinyint(3) unsigned DEFAULT NULL,
  `req_from` datetime DEFAULT NULL,
  `req_from_dst` smallint(5) unsigned DEFAULT NULL,
  `req_to` datetime DEFAULT NULL,
  `req_to_dst` smallint(5) unsigned DEFAULT NULL,
  `ind1` mediumint(8) unsigned DEFAULT NULL,
  `ind2` mediumint(8) unsigned DEFAULT NULL,
  `ind3` mediumint(8) unsigned DEFAULT NULL,
  `enr` mediumint(8) unsigned DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- Dumping data for table emcor.store_dw_debug: ~0 rows (approximately)
/*!40000 ALTER TABLE `store_dw_debug` DISABLE KEYS */;
/*!40000 ALTER TABLE `store_dw_debug` ENABLE KEYS */;

-- Dumping structure for table emcor.store_ev2_debug
CREATE TABLE IF NOT EXISTS `store_ev2_debug` (
  `evc_id` tinyint(3) unsigned DEFAULT NULL,
  `evt_id` mediumint(8) unsigned DEFAULT NULL,
  `evd_id` int(10) unsigned DEFAULT NULL,
  `ev_priority` tinyint(3) unsigned DEFAULT NULL,
  `ev_time` datetime DEFAULT NULL,
  `ev_msg` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `mdl_code` varchar(40) COLLATE utf8_bin DEFAULT NULL,
  `src_id` int(10) unsigned DEFAULT NULL,
  `ph_id` int(10) unsigned DEFAULT NULL,
  `dp_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `point_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo taško identifikatorius',
  `gr_id` int(10) unsigned DEFAULT NULL COMMENT 'Grupės identifikatorius',
  `ds_id` int(10) unsigned DEFAULT NULL COMMENT 'Apskaitos būsenos signalo identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `sch_id` mediumint(8) unsigned DEFAULT NULL,
  `ml_id` mediumint(8) unsigned DEFAULT NULL,
  `sheaf_id` mediumint(8) unsigned DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Saugojamų sistemos įvykių derinimo duomenys';

-- Dumping data for table emcor.store_ev2_debug: ~0 rows (approximately)
/*!40000 ALTER TABLE `store_ev2_debug` DISABLE KEYS */;
/*!40000 ALTER TABLE `store_ev2_debug` ENABLE KEYS */;

-- Dumping structure for table emcor.store_pl_buf
CREATE TABLE IF NOT EXISTS `store_pl_buf` (
  `store_pl_buf_id` int(10) unsigned NOT NULL,
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `pl_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
  `sep_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `pl_t` datetime DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų laikas',
  `pl_dst` smallint(5) unsigned DEFAULT NULL,
  `pl_rv` double DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų pirminė reikšmė',
  `forced` smallint(5) unsigned DEFAULT NULL COMMENT 'Forsavimo požymis',
  `dstatus` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Duomenų statuso kodinė išraiška',
  `pl_rt` datetime DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų nuskaitymo laikas',
  `pl_rdst` smallint(5) unsigned DEFAULT NULL,
  `req_from` datetime DEFAULT NULL,
  `req_from_dst` smallint(5) unsigned DEFAULT NULL,
  `req_to` datetime DEFAULT NULL,
  `req_to_dst` smallint(5) unsigned DEFAULT NULL,
  `extreme_t` datetime DEFAULT NULL COMMENT 'Pasiektos ekstremalios reikšmės laiko žymė',
  PRIMARY KEY (`store_pl_buf_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Tarpinė lentelė saugojamų taškų matavimo linijų duomenims';

-- Dumping data for table emcor.store_pl_buf: ~0 rows (approximately)
/*!40000 ALTER TABLE `store_pl_buf` DISABLE KEYS */;
/*!40000 ALTER TABLE `store_pl_buf` ENABLE KEYS */;

-- Dumping structure for table emcor.store_pl_buf_nv
CREATE TABLE IF NOT EXISTS `store_pl_buf_nv` (
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `pl_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
  `sep_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `pl_t` datetime DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų laikas',
  `pl_dst` smallint(5) unsigned DEFAULT NULL,
  `pl_rv` double DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų pirminė reikšmė',
  `forced` smallint(5) unsigned DEFAULT NULL COMMENT 'Forsavimo požymis',
  `dstatus` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Duomenų statuso kodinė išraiška',
  `pl_rt` datetime DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų nuskaitymo laikas',
  `pl_rdst` smallint(5) unsigned DEFAULT NULL,
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `req_from` datetime DEFAULT NULL,
  `req_from_dst` smallint(5) unsigned DEFAULT NULL,
  `req_to` datetime DEFAULT NULL,
  `req_to_dst` smallint(5) unsigned DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Tarpinė lentelė saugojamų taškų matavimo linijų duomenims';

-- Dumping data for table emcor.store_pl_buf_nv: ~0 rows (approximately)
/*!40000 ALTER TABLE `store_pl_buf_nv` DISABLE KEYS */;
/*!40000 ALTER TABLE `store_pl_buf_nv` ENABLE KEYS */;

-- Dumping structure for table emcor.store_pl_debug
CREATE TABLE IF NOT EXISTS `store_pl_debug` (
  `pck_t` datetime DEFAULT NULL COMMENT 'Duomenų paketo laiko žymė',
  `pck_n` smallint(5) unsigned DEFAULT NULL COMMENT 'Duomenų paketo numeris',
  `pl_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
  `sep_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `pl_t` datetime DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų laikas',
  `pl_dst` smallint(5) unsigned DEFAULT NULL,
  `pl_rv` double DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų pirminė reikšmė',
  `forced` smallint(5) unsigned DEFAULT NULL COMMENT 'Forsavimo požymis',
  `dstatus` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Duomenų statuso kodinė išraiška',
  `pl_rt` datetime DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške duomenų nuskaitymo laikas',
  `pl_rdst` smallint(5) unsigned DEFAULT NULL,
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `req_from` datetime DEFAULT NULL,
  `req_from_dst` smallint(5) unsigned DEFAULT NULL,
  `req_to` datetime DEFAULT NULL,
  `req_to_dst` smallint(5) unsigned DEFAULT NULL,
  `extreme_t` datetime DEFAULT NULL COMMENT 'Pasiektos ekstremalios reikšmės laiko žymė'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Saugojamų taškų matavimo linijų duomenų derinimo duomenys';

-- Dumping data for table emcor.store_pl_debug: ~0 rows (approximately)
/*!40000 ALTER TABLE `store_pl_debug` DISABLE KEYS */;
/*!40000 ALTER TABLE `store_pl_debug` ENABLE KEYS */;

-- Dumping structure for table emcor.store_pw_buf
CREATE TABLE IF NOT EXISTS `store_pw_buf` (
  `store_pw_buf_id` int(10) unsigned NOT NULL,
  `db_time` datetime NOT NULL DEFAULT current_timestamp(),
  `pck_t` datetime DEFAULT NULL,
  `pck_n` smallint(5) unsigned DEFAULT NULL,
  `point_id` int(10) unsigned DEFAULT NULL,
  `withe_id` mediumint(8) DEFAULT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `sep_id` int(10) unsigned DEFAULT NULL,
  `t` varchar(50) COLLATE utf8_bin DEFAULT NULL,
  `dst` tinyint(3) unsigned DEFAULT NULL,
  `v` varchar(2048) COLLATE utf8_bin DEFAULT NULL,
  `rt` datetime DEFAULT NULL,
  `rdst` tinyint(3) unsigned DEFAULT NULL,
  `req_from` datetime DEFAULT NULL,
  `req_from_dst` tinyint(1) DEFAULT NULL,
  `req_to` datetime DEFAULT NULL,
  `req_to_dst` tinyint(1) DEFAULT NULL,
  `ind1` mediumint(8) unsigned DEFAULT NULL,
  `ind2` mediumint(8) unsigned DEFAULT NULL,
  `ind3` mediumint(8) unsigned DEFAULT NULL,
  `enr` mediumint(8) unsigned DEFAULT NULL,
  `count` mediumint(8) unsigned DEFAULT NULL,
  `req_withe_id` mediumint(8) unsigned DEFAULT NULL,
  PRIMARY KEY (`store_pw_buf_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- Dumping data for table emcor.store_pw_buf: ~0 rows (approximately)
/*!40000 ALTER TABLE `store_pw_buf` DISABLE KEYS */;
/*!40000 ALTER TABLE `store_pw_buf` ENABLE KEYS */;

-- Dumping structure for table emcor.store_pw_debug
CREATE TABLE IF NOT EXISTS `store_pw_debug` (
  `db_time` datetime NOT NULL DEFAULT current_timestamp(),
  `pck_t` datetime DEFAULT NULL,
  `pck_n` smallint(5) unsigned DEFAULT NULL,
  `point_id` int(10) unsigned DEFAULT NULL,
  `withe_id` mediumint(8) DEFAULT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `sep_id` int(10) unsigned DEFAULT NULL,
  `t` varchar(50) COLLATE utf8_bin DEFAULT NULL,
  `dst` tinyint(3) unsigned DEFAULT NULL,
  `v` varchar(2048) COLLATE utf8_bin DEFAULT NULL,
  `rt` datetime DEFAULT NULL,
  `rdst` tinyint(3) unsigned DEFAULT NULL,
  `req_from` datetime DEFAULT NULL,
  `req_from_dst` tinyint(1) DEFAULT NULL,
  `req_to` datetime DEFAULT NULL,
  `req_to_dst` tinyint(1) DEFAULT NULL,
  `ind1` mediumint(8) unsigned DEFAULT NULL,
  `ind2` mediumint(8) unsigned DEFAULT NULL,
  `ind3` mediumint(8) unsigned DEFAULT NULL,
  `enr` mediumint(8) unsigned DEFAULT NULL,
  `count` mediumint(8) unsigned DEFAULT NULL,
  `req_withe_id` mediumint(8) unsigned DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- Dumping data for table emcor.store_pw_debug: ~0 rows (approximately)
/*!40000 ALTER TABLE `store_pw_debug` DISABLE KEYS */;
/*!40000 ALTER TABLE `store_pw_debug` ENABLE KEYS */;

-- Dumping structure for table emcor.syta
CREATE TABLE IF NOT EXISTS `syta` (
  `table_name` varchar(30) COLLATE utf8_bin NOT NULL COMMENT 'Lentelės vardas',
  PRIMARY KEY (`table_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Iš anksto užpildomų sistemos klasifikatorių sąrašas';

-- Dumping data for table emcor.syta: ~134 rows (approximately)
/*!40000 ALTER TABLE `syta` DISABLE KEYS */;
INSERT INTO `syta` (`table_name`) VALUES
	('AGGF'),
	('AGGS'),
	('AGGS_TYPE'),
	('ALGR'),
	('AUD_TABLES'),
	('AUD_TYPE'),
	('BGA_CLASS'),
	('BGA_INFERIOR'),
	('BGA_TYPE'),
	('BGA_TYPE_PARAM'),
	('CAPTION'),
	('CAP_PARAM'),
	('CATALOG'),
	('CATALOG_ML'),
	('CATALOG_SHEAF'),
	('CATALOG_WITHE'),
	('COL'),
	('COLC'),
	('COLD'),
	('COL_ALIAS'),
	('COSTA'),
	('CP_NOTE'),
	('DAYS'),
	('DC'),
	('DIR'),
	('DT'),
	('EDEV_STEP_TYPE'),
	('ENUM'),
	('ENUM_DATA'),
	('ENUM_TYPE'),
	('ESTATUS'),
	('EU'),
	('EU_MAP'),
	('EVAC_TYPE'),
	('EVC'),
	('EVT'),
	('EWT'),
	('EXC_SRC_TYPE_MD'),
	('FFP_VAL_TYPE'),
	('FPTY'),
	('GRQ_OTYPE'),
	('IGER'),
	('ITEM_TYPE'),
	('LM'),
	('LPTY'),
	('LPTY_TYPE'),
	('LTC'),
	('MD'),
	('MDL'),
	('MDL_ALERT'),
	('ML'),
	('MLF'),
	('MS'),
	('MSF'),
	('MS_KIND'),
	('MS_TYPE'),
	('OPTY'),
	('PER'),
	('PH_ETYPE'),
	('PH_LAYER'),
	('PH_LAYER_LPTY'),
	('PH_OTYPE'),
	('PLAN_TABLE'),
	('PLEP_MD'),
	('PRQS'),
	('PWL'),
	('PWL_WITHE'),
	('PWM'),
	('PWM_WITHE'),
	('PWO'),
	('PWO_WITHE'),
	('RC'),
	('RPF'),
	('RPF_FPTY'),
	('RPIND'),
	('RPP'),
	('RPP_RPTY'),
	('RPQO'),
	('RPQU'),
	('RPTY'),
	('SAMW_TYPE'),
	('SCH_INT'),
	('SERVER_TZ'),
	('SF'),
	('SHEAF'),
	('SPTY'),
	('SPTY_TYPE'),
	('SP_TYPE_LPTY'),
	('SRC_TYPE'),
	('SRC_TYPE_GROWTH'),
	('SRC_TYPE_LPTY'),
	('SRC_TYPE_LPTY_FILTER'),
	('SRC_TYPE_LPTY_OPTY'),
	('SRC_TYPE_MLF'),
	('SRC_TYPE_MOD'),
	('SRC_TYPE_MOD_KEYS'),
	('SRC_TYPE_MOD_WITHE'),
	('SRC_TYPE_MOD_WITHE#CONST'),
	('SRC_TYPE_MOD_WITHE#OPTY'),
	('SRC_TYPE_MOD_WITHE_CONST'),
	('SRC_TYPE_MOD_WITHE_EVENT'),
	('SRC_TYPE_MOD_WITHE_OPTY'),
	('SRC_TYPE_MOD_WITHE_RC#OPTY'),
	('SRC_TYPE_MOD_WITHE_RC_OPTY'),
	('SRC_TYPE_SHEAF_RC'),
	('SRC_TYPE_WITHE'),
	('SRC_TYPE_WITHE_EVENT'),
	('SYTA'),
	('TAB'),
	('TAB_COL'),
	('TAB_TYPE'),
	('TFF'),
	('TS'),
	('TZ'),
	('VAPP_REASON'),
	('VDEV_STEP_TYPE'),
	('VERSION'),
	('VS'),
	('WITHE'),
	('WITHE_CLASS'),
	('WITHE_DTYPE'),
	('WITHE_TYPE'),
	('XE'),
	('XFAU_TYPE'),
	('XF_TYPE'),
	('XF_TYPE_AGGF'),
	('XF_TYPE_ML_FILTER'),
	('XF_TYPE_RPP'),
	('XF_TYPE_XE'),
	('XF_TYPE_XFAU_TYPE'),
	('XF_TYPE_XPTY'),
	('XO_TYPE'),
	('XPTY'),
	('XS');
/*!40000 ALTER TABLE `syta` ENABLE KEYS */;

-- Dumping structure for table emcor.t#act_360$point
CREATE TABLE IF NOT EXISTS `t#act_360$point` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `point_id` int(10) unsigned DEFAULT NULL,
  `cp_t` datetime DEFAULT NULL,
  `fp_id` int(10) unsigned DEFAULT NULL,
  `status` tinyint(3) unsigned DEFAULT NULL,
  KEY `t#act_360$point_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#act_360$point: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#act_360$point` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#act_360$point` ENABLE KEYS */;

-- Dumping structure for table emcor.t#bgao_gttla
CREATE TABLE IF NOT EXISTS `t#bgao_gttla` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `bgao_id` mediumint(8) unsigned NOT NULL COMMENT 'DB aplikacijos foninių užduočių vykdymo užsakymo ID',
  KEY `t#bgao_gttla_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#bgao_gttla: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#bgao_gttla` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#bgao_gttla` ENABLE KEYS */;

-- Dumping structure for table emcor.t#curr_das
CREATE TABLE IF NOT EXISTS `t#curr_das` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  PRIMARY KEY (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų surinkimo serverio sesijos informacija';

-- Dumping data for table emcor.t#curr_das: ~1 rows (approximately)
/*!40000 ALTER TABLE `t#curr_das` DISABLE KEYS */;
INSERT INTO `t#curr_das` (`cid`, `das_id`) VALUES
	(11, 6);
/*!40000 ALTER TABLE `t#curr_das` ENABLE KEYS */;

-- Dumping structure for table emcor.t#curr_rodo_das
CREATE TABLE IF NOT EXISTS `t#curr_rodo_das` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `rodo_id` int(10) unsigned NOT NULL,
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  KEY `t#curr_rodo_das_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#curr_rodo_das: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#curr_rodo_das` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#curr_rodo_das` ENABLE KEYS */;

-- Dumping structure for table emcor.t#dqp$pldi
CREATE TABLE IF NOT EXISTS `t#dqp$pldi` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `point_id` int(10) unsigned DEFAULT NULL,
  `pl_id` int(10) unsigned DEFAULT NULL,
  `pl_enabled` tinyint(1) DEFAULT NULL,
  `ml_id` mediumint(8) unsigned DEFAULT NULL,
  `md_id` smallint(5) unsigned DEFAULT NULL,
  `aggs_id` tinyint(3) unsigned DEFAULT NULL,
  `md_per_id` tinyint(3) unsigned DEFAULT NULL,
  `md_int_value` mediumint(8) unsigned DEFAULT NULL,
  `aggs_type_id` tinyint(3) unsigned DEFAULT NULL,
  `di_id` int(10) unsigned DEFAULT NULL,
  `di_enabled` tinyint(1) DEFAULT NULL,
  `bc` mediumint(8) unsigned DEFAULT NULL,
  `src_type_internal` tinyint(1) DEFAULT NULL,
  `mow_shift` float DEFAULT NULL,
  KEY `dqp$pldi_point_i` (`point_id`),
  KEY `t#dqp$pldi_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#dqp$pldi: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#dqp$pldi` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#dqp$pldi` ENABLE KEYS */;

-- Dumping structure for table emcor.t#dqp$sesep
CREATE TABLE IF NOT EXISTS `t#dqp$sesep` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `point_id` int(10) unsigned DEFAULT NULL,
  `pl_id` int(10) unsigned DEFAULT NULL,
  `se_enabled` tinyint(1) DEFAULT NULL,
  `se_h` tinyint(1) DEFAULT NULL,
  `se_h_per_id` tinyint(3) unsigned DEFAULT NULL,
  `se_h_depth` mediumint(8) unsigned DEFAULT NULL,
  `se_h_bound` datetime DEFAULT NULL,
  `se_h_restore_depth` mediumint(8) unsigned DEFAULT NULL,
  `se_h_restore_per_id` tinyint(3) unsigned DEFAULT NULL,
  `src_bt` datetime DEFAULT NULL,
  `src_et` datetime DEFAULT NULL,
  `src_enabled` tinyint(1) DEFAULT NULL,
  `tz_id` smallint(5) unsigned DEFAULT NULL,
  `src_tz_dst_used` tinyint(1) DEFAULT NULL,
  `src_type_id` int(10) DEFAULT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `src_type_internal` tinyint(1) DEFAULT NULL,
  `dp_enabled` tinyint(1) DEFAULT NULL,
  `dp_deleted` tinyint(1) DEFAULT NULL,
  `sep_id` int(10) unsigned DEFAULT NULL,
  `sep_enabled` tinyint(1) DEFAULT NULL,
  `sep_h_lag` mediumint(8) unsigned DEFAULT NULL,
  `sep_h_depth` mediumint(8) unsigned DEFAULT NULL,
  `sep_h_per_id` tinyint(1) DEFAULT NULL,
  `sep_h_sch_id` mediumint(8) unsigned DEFAULT NULL,
  `ph_enabled` tinyint(1) DEFAULT NULL,
  `ph_deleted` tinyint(1) DEFAULT NULL,
  `tzh_shift` tinyint(3) unsigned DEFAULT NULL,
  `ow_shift` float DEFAULT NULL,
  KEY `dqp$sesep_pl_i` (`pl_id`),
  KEY `dqp$sesep_point_i` (`point_id`),
  KEY `t#dqp$sesep_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#dqp$sesep: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#dqp$sesep` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#dqp$sesep` ENABLE KEYS */;

-- Dumping structure for table emcor.t#evla
CREATE TABLE IF NOT EXISTS `t#evla` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `ev_time` datetime DEFAULT NULL,
  `ev_id` mediumint(8) unsigned NOT NULL,
  KEY `t#evla_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#evla: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#evla` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#evla` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gen_adj$f0
CREATE TABLE IF NOT EXISTS `t#gen_adj$f0` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `da` date DEFAULT NULL COMMENT 'Diena',
  `bga_id` mediumint(8) unsigned NOT NULL COMMENT 'DB aplikacijos foninės užduoties ID',
  `src_name` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Šaltinio pavadinimas',
  `ml_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Matavimo linijos identifikatorius',
  `tpl_id` int(10) unsigned DEFAULT NULL,
  `sep_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `point_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo taško identifikatorius',
  `mou_id` int(10) unsigned DEFAULT NULL COMMENT 'Montažo identifikatorius',
  `mou_bt` datetime DEFAULT NULL COMMENT 'Montavimo data',
  `mou_et` datetime DEFAULT NULL COMMENT 'Išmontavimo data',
  `meter_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo priemonės identifikatorius',
  `ms_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Matavimo identifikatorius',
  `dir_id` tinyint(4) DEFAULT NULL COMMENT 'Krypties identifikatorius',
  `tff_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Tarifo identifikatorius',
  `pl_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
  `aggs_type_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  KEY `t#gen_adj$f0_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- Dumping data for table emcor.t#gen_adj$f0: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gen_adj$f0` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gen_adj$f0` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gen_adj$f1
CREATE TABLE IF NOT EXISTS `t#gen_adj$f1` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `pl_t1` datetime DEFAULT NULL,
  `da` date DEFAULT NULL COMMENT 'Diena',
  `bga_id` mediumint(8) unsigned NOT NULL COMMENT 'DB aplikacijos foninės užduoties ID',
  `src_name` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Šaltinio pavadinimas',
  `ml_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Matavimo linijos identifikatorius',
  `tpl_id` int(10) unsigned DEFAULT NULL,
  `sep_id` int(10) unsigned DEFAULT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `point_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo taško identifikatorius',
  `mou_id` int(10) unsigned DEFAULT NULL COMMENT 'Montažo identifikatorius',
  `mou_bt` datetime DEFAULT NULL COMMENT 'Montavimo data',
  `mou_et` datetime DEFAULT NULL COMMENT 'Išmontavimo data',
  `meter_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo priemonės identifikatorius',
  `ms_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Matavimo identifikatorius',
  `dir_id` tinyint(4) DEFAULT NULL COMMENT 'Krypties identifikatorius',
  `tff_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Tarifo identifikatorius',
  `pl_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
  `aggs_type_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  KEY `t#gen_adj$f1_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- Dumping data for table emcor.t#gen_adj$f1: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gen_adj$f1` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gen_adj$f1` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gr_filter
CREATE TABLE IF NOT EXISTS `t#gr_filter` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `gr_filter_visibility` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Grupių sujungimo matomumo požymis',
  `gr_filter_oper` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Grupių sujungimo požymis (1 - sąjunga, 0 - sankirta)',
  KEY `t#gr_filter_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Grupių filtro naudojimas';

-- Dumping data for table emcor.t#gr_filter: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gr_filter` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gr_filter` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gr_filter_data
CREATE TABLE IF NOT EXISTS `t#gr_filter_data` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  `visibility` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Grupės matomumo požymis',
  KEY `t#gr_filter_data_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Grupių filtro duomenys';

-- Dumping data for table emcor.t#gr_filter_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gr_filter_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gr_filter_data` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gtree_ds
CREATE TABLE IF NOT EXISTS `t#gtree_ds` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `ds_id` int(10) unsigned DEFAULT NULL COMMENT 'Apskaitos būsenos signalo identifikatorius',
  KEY `t#gtree_ds_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#gtree_ds: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gtree_ds` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gtree_ds` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gtree_gr
CREATE TABLE IF NOT EXISTS `t#gtree_gr` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `gr_id` int(10) unsigned DEFAULT NULL COMMENT 'Grupės identifikatorius',
  KEY `t#gtree_gr_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#gtree_gr: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gtree_gr` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gtree_gr` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gtree_m
CREATE TABLE IF NOT EXISTS `t#gtree_m` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `ms_type_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Matavimų tipo identifikatorius',
  `aggs_type_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  `msf_id` smallint(5) unsigned DEFAULT NULL,
  `md_id` smallint(5) unsigned DEFAULT NULL,
  `dir_id` tinyint(4) DEFAULT NULL,
  `ml_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Matavimo linijos identifikatorius',
  `sheaf_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Duomenų pluošto identifikatorius',
  KEY `t#gtree_m_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#gtree_m: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gtree_m` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gtree_m` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gtree_point
CREATE TABLE IF NOT EXISTS `t#gtree_point` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `point_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo taško identifikatorius',
  KEY `t#gtree_point_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#gtree_point: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gtree_point` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gtree_point` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gtt5
CREATE TABLE IF NOT EXISTS `t#gtt5` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `point_id` int(10) unsigned NOT NULL,
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `sep_id` int(10) unsigned NOT NULL,
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `di_id` int(10) unsigned NOT NULL,
  `dp_id` int(10) unsigned NOT NULL,
  `is_point` tinyint(1) NOT NULL,
  `ind1` mediumint(8) unsigned DEFAULT NULL,
  `ind2` mediumint(8) unsigned DEFAULT NULL,
  `ind3` mediumint(8) unsigned DEFAULT NULL,
  `enr` mediumint(8) unsigned DEFAULT NULL,
  KEY `t#gtt5_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Tarpinių sesijos duomenų saugykla';

-- Dumping data for table emcor.t#gtt5: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gtt5` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gtt5` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gtta
CREATE TABLE IF NOT EXISTS `t#gtta` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `show` tinyint(1) NOT NULL,
  KEY `t#gtta_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#gtta: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gtta` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gtta` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gttd
CREATE TABLE IF NOT EXISTS `t#gttd` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `d1` datetime DEFAULT NULL,
  KEY `t#gttd_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#gttd: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gttd` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gttd` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gttf
CREATE TABLE IF NOT EXISTS `t#gttf` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `show_generated` tinyint(1) DEFAULT NULL,
  `show_instant` tinyint(1) DEFAULT NULL,
  `mlset_id` int(10) unsigned DEFAULT NULL,
  `show_ml_selected` tinyint(1) DEFAULT NULL,
  `show_di_enabled` tinyint(1) DEFAULT NULL,
  `ignore_mcc` tinyint(1) DEFAULT NULL,
  `ignore_icc` tinyint(1) DEFAULT NULL,
  `ignore_act` tinyint(1) DEFAULT NULL,
  `show_point_anyway` tinyint(1) DEFAULT NULL,
  `include_monthly` tinyint(1) DEFAULT NULL,
  KEY `t#gttf_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų kokybės suvestinių filtrai';

-- Dumping data for table emcor.t#gttf: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gttf` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gttf` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gttn
CREATE TABLE IF NOT EXISTS `t#gttn` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `id1` bigint(20) unsigned DEFAULT NULL,
  `id2` bigint(20) unsigned DEFAULT NULL,
  `id3` bigint(20) unsigned DEFAULT NULL,
  `id4` bigint(20) unsigned DEFAULT NULL,
  `id5` bigint(20) unsigned DEFAULT NULL,
  `id6` bigint(20) unsigned DEFAULT NULL,
  `id7` bigint(20) unsigned DEFAULT NULL,
  `id8` bigint(20) unsigned DEFAULT NULL,
  `id9` bigint(20) unsigned DEFAULT NULL,
  `id0` bigint(20) unsigned DEFAULT NULL,
  `v1` double DEFAULT NULL,
  `v2` double DEFAULT NULL,
  `v3` double DEFAULT NULL,
  `v4` double DEFAULT NULL,
  `v5` double DEFAULT NULL,
  `v6` double DEFAULT NULL,
  `v7` double DEFAULT NULL,
  `v8` double DEFAULT NULL,
  `v9` double DEFAULT NULL,
  `v0` double DEFAULT NULL,
  `d1` datetime DEFAULT NULL,
  `d2` datetime DEFAULT NULL,
  `d3` datetime DEFAULT NULL,
  `d4` datetime DEFAULT NULL,
  `d5` datetime DEFAULT NULL,
  `d6` datetime DEFAULT NULL,
  `d7` datetime DEFAULT NULL,
  `d8` datetime DEFAULT NULL,
  `d9` datetime DEFAULT NULL,
  `d0` datetime DEFAULT NULL,
  `c1` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c2` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c3` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c4` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c5` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c6` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c7` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c8` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c9` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c0` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `cbig` varchar(4000) COLLATE utf8_bin DEFAULT NULL,
  KEY `t#gttn_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Tarpinių transakcijos duomenų saugykla';

-- Dumping data for table emcor.t#gttn: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gttn` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gttn` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gttn2
CREATE TABLE IF NOT EXISTS `t#gttn2` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `id1` bigint(20) unsigned DEFAULT NULL,
  `id2` bigint(20) unsigned DEFAULT NULL,
  `id3` bigint(20) unsigned DEFAULT NULL,
  `id4` bigint(20) unsigned DEFAULT NULL,
  `id5` bigint(20) unsigned DEFAULT NULL,
  `id6` bigint(20) unsigned DEFAULT NULL,
  `id7` bigint(20) unsigned DEFAULT NULL,
  `id8` bigint(20) unsigned DEFAULT NULL,
  `id9` bigint(20) unsigned DEFAULT NULL,
  `id0` bigint(20) unsigned DEFAULT NULL,
  `v1` double DEFAULT NULL,
  `v2` double DEFAULT NULL,
  `v3` double DEFAULT NULL,
  `v4` double DEFAULT NULL,
  `v5` double DEFAULT NULL,
  `v6` double DEFAULT NULL,
  `v7` double DEFAULT NULL,
  `v8` double DEFAULT NULL,
  `v9` double DEFAULT NULL,
  `v0` double DEFAULT NULL,
  `d1` datetime DEFAULT NULL,
  `d2` datetime DEFAULT NULL,
  `d3` datetime DEFAULT NULL,
  `d4` datetime DEFAULT NULL,
  `d5` datetime DEFAULT NULL,
  `d6` datetime DEFAULT NULL,
  `d7` datetime DEFAULT NULL,
  `d8` datetime DEFAULT NULL,
  `d9` datetime DEFAULT NULL,
  `d0` datetime DEFAULT NULL,
  `c1` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c2` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c3` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c4` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c5` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c6` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c7` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c8` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c9` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c0` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `cbig` varchar(4000) COLLATE utf8_bin DEFAULT NULL,
  KEY `t#gttn2_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Tarpinių transakcijos duomenų saugykla';

-- Dumping data for table emcor.t#gttn2: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gttn2` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gttn2` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gttq
CREATE TABLE IF NOT EXISTS `t#gttq` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `id1` bigint(20) unsigned DEFAULT NULL,
  `id2` bigint(20) unsigned DEFAULT NULL,
  `id3` bigint(20) unsigned DEFAULT NULL,
  `id4` bigint(20) unsigned DEFAULT NULL,
  `id5` bigint(20) unsigned DEFAULT NULL,
  `id6` bigint(20) unsigned DEFAULT NULL,
  `id7` bigint(20) unsigned DEFAULT NULL,
  `id8` bigint(20) unsigned DEFAULT NULL,
  `id9` bigint(20) unsigned DEFAULT NULL,
  `id0` bigint(20) unsigned DEFAULT NULL,
  `v1` double DEFAULT NULL,
  `v2` double DEFAULT NULL,
  `v3` double DEFAULT NULL,
  `v4` double DEFAULT NULL,
  `v5` double DEFAULT NULL,
  `v6` double DEFAULT NULL,
  `v7` double DEFAULT NULL,
  `v8` double DEFAULT NULL,
  `v9` double DEFAULT NULL,
  `v0` double DEFAULT NULL,
  `d1` datetime DEFAULT NULL,
  `d2` datetime DEFAULT NULL,
  `d3` datetime DEFAULT NULL,
  `d4` datetime DEFAULT NULL,
  `d5` datetime DEFAULT NULL,
  `d6` datetime DEFAULT NULL,
  `d7` datetime DEFAULT NULL,
  `d8` datetime DEFAULT NULL,
  `d9` datetime DEFAULT NULL,
  `d0` datetime DEFAULT NULL,
  `c1` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c2` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c3` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c4` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c5` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c6` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c7` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c8` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c9` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c0` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `cbig` varchar(4000) COLLATE utf8_bin DEFAULT NULL,
  KEY `t#gttq_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Tarpinių transakcijos duomenų saugykla';

-- Dumping data for table emcor.t#gttq: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gttq` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gttq` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gttr
CREATE TABLE IF NOT EXISTS `t#gttr` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `point_id` int(10) unsigned NOT NULL,
  `sheaf_id` mediumint(8) unsigned NOT NULL,
  `sep_id` int(10) unsigned NOT NULL,
  `src_type_id` int(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `di_id` int(10) unsigned NOT NULL,
  KEY `t#gttr_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Tarpinių sesijos duomenų saugykla';

-- Dumping data for table emcor.t#gttr: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gttr` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gttr` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gtts
CREATE TABLE IF NOT EXISTS `t#gtts` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `id1` bigint(20) unsigned DEFAULT NULL,
  `id2` bigint(20) unsigned DEFAULT NULL,
  `id3` bigint(20) unsigned DEFAULT NULL,
  `id4` bigint(20) unsigned DEFAULT NULL,
  `id5` bigint(20) unsigned DEFAULT NULL,
  `id6` bigint(20) unsigned DEFAULT NULL,
  `id7` bigint(20) unsigned DEFAULT NULL,
  `id8` bigint(20) unsigned DEFAULT NULL,
  `id9` bigint(20) unsigned DEFAULT NULL,
  `id0` bigint(20) unsigned DEFAULT NULL,
  `v1` double DEFAULT NULL,
  `v2` double DEFAULT NULL,
  `v3` double DEFAULT NULL,
  `v4` double DEFAULT NULL,
  `v5` double DEFAULT NULL,
  `v6` double DEFAULT NULL,
  `v7` double DEFAULT NULL,
  `v8` double DEFAULT NULL,
  `v9` double DEFAULT NULL,
  `v0` double DEFAULT NULL,
  `d1` datetime DEFAULT NULL,
  `d2` datetime DEFAULT NULL,
  `d3` datetime DEFAULT NULL,
  `d4` datetime DEFAULT NULL,
  `d5` datetime DEFAULT NULL,
  `d6` datetime DEFAULT NULL,
  `d7` datetime DEFAULT NULL,
  `d8` datetime DEFAULT NULL,
  `d9` datetime DEFAULT NULL,
  `d0` datetime DEFAULT NULL,
  `c1` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c2` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c3` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c4` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c5` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c6` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c7` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c8` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c9` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c0` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  KEY `t#gtts_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Tarpinių sesijos duomenų saugykla';

-- Dumping data for table emcor.t#gtts: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gtts` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gtts` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gttt
CREATE TABLE IF NOT EXISTS `t#gttt` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `id1` bigint(20) unsigned DEFAULT NULL,
  `id2` bigint(20) unsigned DEFAULT NULL,
  `id3` bigint(20) unsigned DEFAULT NULL,
  `id4` bigint(20) unsigned DEFAULT NULL,
  `id5` bigint(20) unsigned DEFAULT NULL,
  `id6` bigint(20) unsigned DEFAULT NULL,
  `id7` bigint(20) unsigned DEFAULT NULL,
  `id8` bigint(20) unsigned DEFAULT NULL,
  `id9` bigint(20) unsigned DEFAULT NULL,
  `id0` bigint(20) unsigned DEFAULT NULL,
  `v1` double DEFAULT NULL,
  `v2` double DEFAULT NULL,
  `v3` double DEFAULT NULL,
  `v4` double DEFAULT NULL,
  `v5` double DEFAULT NULL,
  `v6` double DEFAULT NULL,
  `v7` double DEFAULT NULL,
  `v8` double DEFAULT NULL,
  `v9` double DEFAULT NULL,
  `v0` double DEFAULT NULL,
  `d1` datetime DEFAULT NULL,
  `d2` datetime DEFAULT NULL,
  `d3` datetime DEFAULT NULL,
  `d4` datetime DEFAULT NULL,
  `d5` datetime DEFAULT NULL,
  `d6` datetime DEFAULT NULL,
  `d7` datetime DEFAULT NULL,
  `d8` datetime DEFAULT NULL,
  `d9` datetime DEFAULT NULL,
  `d0` datetime DEFAULT NULL,
  `c1` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c2` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c3` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c4` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c5` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c6` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c7` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c8` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c9` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c0` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `cbig` varchar(4000) COLLATE utf8_bin DEFAULT NULL,
  KEY `t#gttt_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Tarpinių transakcijos duomenų saugykla';

-- Dumping data for table emcor.t#gttt: ~5 rows (approximately)
/*!40000 ALTER TABLE `t#gttt` DISABLE KEYS */;
INSERT INTO `t#gttt` (`cid`, `id1`, `id2`, `id3`, `id4`, `id5`, `id6`, `id7`, `id8`, `id9`, `id0`, `v1`, `v2`, `v3`, `v4`, `v5`, `v6`, `v7`, `v8`, `v9`, `v0`, `d1`, `d2`, `d3`, `d4`, `d5`, `d6`, `d7`, `d8`, `d9`, `d0`, `c1`, `c2`, `c3`, `c4`, `c5`, `c6`, `c7`, `c8`, `c9`, `c0`, `cbig`) VALUES
	(8, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 158.35, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '2018-05-17 23:14:47', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL),
	(9, 8, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL),
	(11, 1, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 'citrina', 'pufas', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL),
	(11, 2, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 'citrina', 'pufas', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL),
	(13, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 'select  g\n\n\n f\n\n\n g', NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
/*!40000 ALTER TABLE `t#gttt` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gttw
CREATE TABLE IF NOT EXISTS `t#gttw` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `ses_id` bigint(20) unsigned NOT NULL COMMENT 'Sesijos identifikatorius',
  KEY `t#gttw_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Prisijungimo prie EMCOS sesijos informacija';

-- Dumping data for table emcor.t#gttw: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gttw` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gttw` ENABLE KEYS */;

-- Dumping structure for table emcor.t#gttx
CREATE TABLE IF NOT EXISTS `t#gttx` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `id0` bigint(20) unsigned DEFAULT NULL,
  KEY `t#gttx_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#gttx: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#gttx` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#gttx` ENABLE KEYS */;

-- Dumping structure for table emcor.t#ipty
CREATE TABLE IF NOT EXISTS `t#ipty` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `spty_id` mediumint(8) unsigned NOT NULL COMMENT 'Sistemos savybės identifikatorius',
  `spty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Sistemos savybės reikšmė',
  KEY `t#ipty_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Sesijai nustatytos sistemos savybės';

-- Dumping data for table emcor.t#ipty: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#ipty` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#ipty` ENABLE KEYS */;

-- Dumping structure for table emcor.t#ml_show
CREATE TABLE IF NOT EXISTS `t#ml_show` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `ml_id` mediumint(8) unsigned NOT NULL,
  KEY `t#ml_show_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#ml_show: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#ml_show` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#ml_show` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tg$grc
CREATE TABLE IF NOT EXISTS `t#tg$grc` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `cont_id` int(10) unsigned NOT NULL,
  `comp_id` int(10) unsigned NOT NULL,
  `grc_bt` datetime NOT NULL,
  `grc_et` datetime DEFAULT NULL,
  KEY `tg$grc_cont_i` (`cont_id`,`comp_id`),
  KEY `t#tg$grc_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tg$grc: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tg$grc` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tg$grc` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tg$grcj_comp
CREATE TABLE IF NOT EXISTS `t#tg$grcj_comp` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `gr_id` int(10) unsigned NOT NULL,
  KEY `t#tg$grcj_comp_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tg$grcj_comp: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tg$grcj_comp` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tg$grcj_comp` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tg$grcj_cont
CREATE TABLE IF NOT EXISTS `t#tg$grcj_cont` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `gr_id` int(10) unsigned NOT NULL,
  KEY `t#tg$grcj_cont_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tg$grcj_cont: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tg$grcj_cont` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tg$grcj_cont` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tg$grcj_data_comp
CREATE TABLE IF NOT EXISTS `t#tg$grcj_data_comp` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `gr_id` int(10) unsigned NOT NULL,
  KEY `t#tg$grcj_data_comp_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tg$grcj_data_comp: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tg$grcj_data_comp` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tg$grcj_data_comp` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tg$grcj_data_cont
CREATE TABLE IF NOT EXISTS `t#tg$grcj_data_cont` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `gr_id` int(10) unsigned NOT NULL,
  KEY `t#tg$grcj_data_cont_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tg$grcj_data_cont: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tg$grcj_data_cont` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tg$grcj_data_cont` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tg$grcj_data_p
CREATE TABLE IF NOT EXISTS `t#tg$grcj_data_p` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `point_id` int(10) unsigned NOT NULL,
  KEY `t#tg$grcj_data_p_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tg$grcj_data_p: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tg$grcj_data_p` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tg$grcj_data_p` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tg$grcj_p
CREATE TABLE IF NOT EXISTS `t#tg$grcj_p` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `point_id` int(10) unsigned NOT NULL,
  KEY `t#tg$grcj_p_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tg$grcj_p: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tg$grcj_p` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tg$grcj_p` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tg$grcj_r
CREATE TABLE IF NOT EXISTS `t#tg$grcj_r` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `gr_id` int(10) unsigned DEFAULT NULL,
  `point_id` int(10) unsigned DEFAULT NULL,
  `bt` datetime DEFAULT NULL,
  `et` datetime DEFAULT NULL,
  KEY `tg$grcj_r_grp_i` (`gr_id`,`point_id`),
  KEY `t#tg$grcj_r_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tg$grcj_r: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tg$grcj_r` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tg$grcj_r` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tg$grc_data
CREATE TABLE IF NOT EXISTS `t#tg$grc_data` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `cont_id` int(10) unsigned NOT NULL,
  `cont_ms_id` smallint(5) unsigned NOT NULL,
  `cont_dir_id` tinyint(4) NOT NULL,
  `cont_ec_id` mediumint(8) unsigned NOT NULL,
  `comp_id` int(10) unsigned NOT NULL,
  `comp_ms_id` smallint(5) unsigned NOT NULL,
  `comp_dir_id` tinyint(4) NOT NULL,
  `comp_ec_id` mediumint(8) unsigned NOT NULL,
  `grc_bt` datetime NOT NULL,
  `coef` double NOT NULL DEFAULT 1,
  KEY `tg$grc_data_cont_i` (`cont_id`,`comp_id`),
  KEY `t#tg$grc_data_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tg$grc_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tg$grc_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tg$grc_data` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tg$grpj_data_g
CREATE TABLE IF NOT EXISTS `t#tg$grpj_data_g` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `gr_id` int(10) unsigned NOT NULL,
  KEY `t#tg$grpj_data_g_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tg$grpj_data_g: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tg$grpj_data_g` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tg$grpj_data_g` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tg$grpj_data_p
CREATE TABLE IF NOT EXISTS `t#tg$grpj_data_p` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `point_id` int(10) unsigned NOT NULL,
  KEY `t#tg$grpj_data_p_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tg$grpj_data_p: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tg$grpj_data_p` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tg$grpj_data_p` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tg$grpj_g
CREATE TABLE IF NOT EXISTS `t#tg$grpj_g` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `gr_id` int(10) unsigned NOT NULL,
  KEY `t#tg$grpj_g_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tg$grpj_g: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tg$grpj_g` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tg$grpj_g` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tg$grpj_p
CREATE TABLE IF NOT EXISTS `t#tg$grpj_p` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `point_id` int(10) unsigned NOT NULL,
  KEY `t#tg$grpj_p_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tg$grpj_p: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tg$grpj_p` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tg$grpj_p` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tmpl$dids
CREATE TABLE IF NOT EXISTS `t#tmpl$dids` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `di_id` int(10) unsigned DEFAULT NULL,
  `ds_id` int(10) unsigned DEFAULT NULL,
  `point_id` int(10) unsigned DEFAULT NULL,
  `ds_type_id` int(10) unsigned DEFAULT NULL,
  `sbst_tmpl_id` int(10) unsigned DEFAULT NULL,
  `src_id` int(10) unsigned DEFAULT NULL,
  KEY `t#tmpl$dids_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tmpl$dids: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tmpl$dids` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tmpl$dids` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tmpl$pladv
CREATE TABLE IF NOT EXISTS `t#tmpl$pladv` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `pl_id` int(10) unsigned DEFAULT NULL,
  `point_id` int(10) unsigned DEFAULT NULL,
  `ml_id` int(10) unsigned DEFAULT NULL,
  `sbst_tmpl_id` int(10) unsigned DEFAULT NULL,
  `src_id` int(10) unsigned DEFAULT NULL,
  KEY `t#tmpl$pladv_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tmpl$pladv: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tmpl$pladv` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tmpl$pladv` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tmpl$seadv
CREATE TABLE IF NOT EXISTS `t#tmpl$seadv` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `se_id` int(10) unsigned DEFAULT NULL,
  `src_id` int(10) unsigned DEFAULT NULL,
  `point_id` int(10) unsigned DEFAULT NULL,
  `ml_id` int(10) unsigned DEFAULT NULL,
  `se_ab` tinyint(3) unsigned DEFAULT NULL,
  `se_a` double DEFAULT NULL,
  `se_b` double DEFAULT NULL,
  `se_h` tinyint(1) DEFAULT NULL,
  `se_h_per_id` tinyint(3) unsigned DEFAULT NULL,
  `se_h_depth` mediumint(8) unsigned DEFAULT NULL,
  `se_h_restore_depth` mediumint(8) unsigned DEFAULT NULL,
  `se_h_restore_per_id` tinyint(3) unsigned DEFAULT NULL,
  KEY `t#tmpl$seadv_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tmpl$seadv: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tmpl$seadv` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tmpl$seadv` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tmpl$sedsadv
CREATE TABLE IF NOT EXISTS `t#tmpl$sedsadv` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `se_id` int(10) unsigned DEFAULT NULL,
  `src_id` int(10) unsigned DEFAULT NULL,
  `point_id` int(10) unsigned DEFAULT NULL,
  `ds_id` int(10) unsigned DEFAULT NULL,
  `ds_type_id` int(10) unsigned DEFAULT NULL,
  `se_h` tinyint(1) DEFAULT NULL,
  `se_h_per_id` tinyint(3) unsigned DEFAULT NULL,
  `se_h_depth` mediumint(8) unsigned DEFAULT NULL,
  `se_h_restore_depth` mediumint(8) unsigned DEFAULT NULL,
  `se_h_restore_per_id` tinyint(3) unsigned DEFAULT NULL,
  KEY `t#tmpl$sedsadv_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tmpl$sedsadv: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tmpl$sedsadv` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tmpl$sedsadv` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tmpl$sep
CREATE TABLE IF NOT EXISTS `t#tmpl$sep` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `se_id` int(10) unsigned DEFAULT NULL,
  `sep_id` int(10) unsigned DEFAULT NULL,
  `sp_id` int(10) unsigned DEFAULT NULL,
  KEY `t#tmpl$sep_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tmpl$sep: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tmpl$sep` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tmpl$sep` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tmpl$seprc
CREATE TABLE IF NOT EXISTS `t#tmpl$seprc` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `sep_id` int(10) unsigned DEFAULT NULL,
  `rc_id` tinyint(3) unsigned DEFAULT NULL,
  `sch_id` mediumint(8) unsigned DEFAULT NULL,
  `per_id` tinyint(3) unsigned DEFAULT NULL,
  `sep_rc_lag` mediumint(8) unsigned DEFAULT NULL,
  `sep_rc_depth` mediumint(8) unsigned DEFAULT NULL,
  KEY `t#tmpl$seprc_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tmpl$seprc: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tmpl$seprc` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tmpl$seprc` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tmpl$srcm
CREATE TABLE IF NOT EXISTS `t#tmpl$srcm` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `src_id` int(10) unsigned DEFAULT NULL,
  `m` tinyint(1) DEFAULT NULL,
  KEY `t#tmpl$srcm_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tmpl$srcm: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tmpl$srcm` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tmpl$srcm` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tmpl$srcm3
CREATE TABLE IF NOT EXISTS `t#tmpl$srcm3` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `src_id` int(10) unsigned DEFAULT NULL,
  `m` tinyint(1) DEFAULT NULL,
  `dl_type_id` int(10) unsigned DEFAULT NULL,
  `tz_id` int(10) unsigned DEFAULT NULL,
  `src_tz_dst_used` int(10) unsigned DEFAULT NULL,
  `src_save_statistics` int(10) unsigned DEFAULT NULL,
  `point_id` int(10) unsigned DEFAULT NULL,
  `src_tmpl_id` int(10) unsigned DEFAULT NULL,
  `src_number` varchar(80) COLLATE utf8_bin DEFAULT NULL,
  `src_dir_inv` int(10) unsigned DEFAULT NULL,
  `tsrc_tmpl_id` int(10) unsigned DEFAULT NULL,
  `src_tmpl_multipoint` int(10) unsigned DEFAULT NULL,
  `tdl_type_id` int(10) unsigned DEFAULT NULL,
  `ttz_id` int(10) unsigned DEFAULT NULL,
  `tsrc_tz_dst_used` int(10) unsigned DEFAULT NULL,
  `tsrc_save_statistics` int(10) unsigned DEFAULT NULL,
  `tsrc_dir_inv` int(10) unsigned DEFAULT NULL,
  `tinherit_src_number` int(10) unsigned DEFAULT NULL,
  `error_number` int(10) unsigned DEFAULT NULL,
  `error_msg` varchar(1000) COLLATE utf8_bin DEFAULT NULL,
  KEY `t#tmpl$srcm3_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- Dumping data for table emcor.t#tmpl$srcm3: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tmpl$srcm3` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tmpl$srcm3` ENABLE KEYS */;

-- Dumping structure for table emcor.t#tmpl$src_point
CREATE TABLE IF NOT EXISTS `t#tmpl$src_point` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `src_id` int(10) unsigned DEFAULT NULL,
  `point_id` int(10) unsigned DEFAULT NULL,
  `sbst_tmpl_id` int(10) unsigned DEFAULT NULL,
  `coef_u_numerator` double DEFAULT NULL,
  `coef_u_denominator` double DEFAULT NULL,
  `coef_i_numerator` double DEFAULT NULL,
  `coef_i_denominator` double DEFAULT NULL,
  KEY `t#tmpl$src_point_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#tmpl$src_point: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#tmpl$src_point` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#tmpl$src_point` ENABLE KEYS */;

-- Dumping structure for table emcor.t#v_ar$period
CREATE TABLE IF NOT EXISTS `t#v_ar$period` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `point_id` int(10) unsigned NOT NULL,
  `bt` datetime NOT NULL,
  `et` datetime DEFAULT NULL,
  KEY `t#v_ar$period_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#v_ar$period: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#v_ar$period` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#v_ar$period` ENABLE KEYS */;

-- Dumping structure for table emcor.t#v_ar_map$gr
CREATE TABLE IF NOT EXISTS `t#v_ar_map$gr` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `ma_id` int(10) unsigned DEFAULT NULL,
  `ts_id` tinyint(1) DEFAULT NULL,
  `mt_id` int(10) unsigned DEFAULT NULL,
  `da` date DEFAULT NULL,
  `bt` datetime DEFAULT NULL,
  `et` datetime DEFAULT NULL,
  `map_id` int(10) unsigned DEFAULT NULL,
  `verge_id` smallint(5) unsigned DEFAULT NULL,
  `verge_code` varchar(40) COLLATE utf8_bin DEFAULT NULL,
  `verge_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `ma_report_exceeding` tinyint(1) DEFAULT NULL,
  `val` double DEFAULT NULL,
  `has_specific_dstatus` tinyint(1) DEFAULT NULL,
  `ml_id` mediumint(8) unsigned DEFAULT NULL,
  `ml_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `gr_id` int(10) unsigned DEFAULT NULL,
  `gmod_id` mediumint(8) unsigned DEFAULT NULL,
  `gmod_code` varchar(40) COLLATE utf8_bin DEFAULT NULL,
  `gmod_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `gprc` tinyint(3) unsigned DEFAULT NULL,
  `ec_id` mediumint(8) unsigned DEFAULT NULL,
  `ec_code` varchar(50) COLLATE utf8_bin DEFAULT NULL,
  `ec_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `ec_in` tinyint(1) DEFAULT NULL,
  `ds_id` int(10) unsigned DEFAULT NULL,
  KEY `t#v_ar_map$gr_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- Dumping data for table emcor.t#v_ar_map$gr: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#v_ar_map$gr` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#v_ar_map$gr` ENABLE KEYS */;

-- Dumping structure for table emcor.t#v_ar_map$point
CREATE TABLE IF NOT EXISTS `t#v_ar_map$point` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `ma_id` int(10) unsigned DEFAULT NULL,
  `ts_id` tinyint(1) DEFAULT NULL,
  `mt_id` int(10) unsigned DEFAULT NULL,
  `da` date DEFAULT NULL,
  `bt` datetime DEFAULT NULL,
  `et` datetime DEFAULT NULL,
  `map_id` int(10) unsigned DEFAULT NULL,
  `verge_id` smallint(5) unsigned DEFAULT NULL,
  `verge_code` varchar(40) COLLATE utf8_bin DEFAULT NULL,
  `verge_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `ma_report_exceeding` tinyint(1) DEFAULT NULL,
  `ma_auto_null_act` tinyint(3) unsigned DEFAULT NULL,
  `ma_auto_ccs` tinyint(1) DEFAULT NULL,
  `val` double DEFAULT NULL,
  `has_specific_dstatus` tinyint(1) DEFAULT NULL,
  `ml_id` mediumint(8) unsigned DEFAULT NULL,
  `ml_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `point_id` int(10) unsigned DEFAULT NULL,
  `ds_id` int(10) unsigned DEFAULT NULL,
  KEY `t#v_ar_map$point_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- Dumping data for table emcor.t#v_ar_map$point: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#v_ar_map$point` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#v_ar_map$point` ENABLE KEYS */;

-- Dumping structure for table emcor.t#v_ar_map$sam
CREATE TABLE IF NOT EXISTS `t#v_ar_map$sam` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `ma_id` int(10) unsigned DEFAULT NULL,
  `ts_id` tinyint(1) DEFAULT NULL,
  `mt_id` int(10) unsigned DEFAULT NULL,
  `da` date DEFAULT NULL,
  `bt` datetime DEFAULT NULL,
  `et` datetime DEFAULT NULL,
  `map_id` int(10) unsigned DEFAULT NULL,
  `verge_id` smallint(5) unsigned DEFAULT NULL,
  `verge_code` varchar(40) COLLATE utf8_bin DEFAULT NULL,
  `verge_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `ma_report_exceeding` tinyint(1) DEFAULT NULL,
  `val` double DEFAULT NULL,
  `has_specific_dstatus` tinyint(1) DEFAULT NULL,
  `sam_id` int(10) unsigned DEFAULT NULL,
  `sam_code` varchar(80) COLLATE utf8_bin DEFAULT NULL,
  `sam_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  KEY `t#v_ar_map$sam_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- Dumping data for table emcor.t#v_ar_map$sam: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#v_ar_map$sam` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#v_ar_map$sam` ENABLE KEYS */;

-- Dumping structure for table emcor.t#v_ar_map_gr$f
CREATE TABLE IF NOT EXISTS `t#v_ar_map_gr$f` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `ma_id` int(10) unsigned DEFAULT NULL,
  `ts_id` tinyint(1) DEFAULT NULL,
  `mt_id` int(10) unsigned DEFAULT NULL,
  `gr_id` int(10) unsigned DEFAULT NULL,
  `gmod_id` mediumint(8) unsigned DEFAULT NULL,
  `gprc` tinyint(3) unsigned DEFAULT NULL,
  `mt_ec_id` mediumint(8) unsigned DEFAULT NULL,
  `mt_ec_in` tinyint(1) DEFAULT NULL,
  `gmod_a` double DEFAULT NULL,
  `gmod_b` double DEFAULT NULL,
  `ml_id` mediumint(8) unsigned DEFAULT NULL,
  `da` date DEFAULT NULL,
  `coef` double DEFAULT NULL,
  `pl_id` int(10) unsigned DEFAULT NULL,
  `ec_id` mediumint(8) unsigned DEFAULT NULL,
  `ec_in` tinyint(1) DEFAULT NULL,
  `verge_id` smallint(5) unsigned DEFAULT NULL,
  `verge_code` varchar(40) COLLATE utf8_bin DEFAULT NULL,
  `verge_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `ma_ab` tinyint(1) DEFAULT NULL,
  `ma_a_nom` float DEFAULT NULL,
  `ma_a_denom` float DEFAULT NULL,
  `ma_b` float DEFAULT NULL,
  `ma_report_exceeding` tinyint(1) DEFAULT NULL,
  `ma_lag` double DEFAULT NULL,
  `ma_lag_per_id` tinyint(3) unsigned DEFAULT NULL,
  `map_id` int(10) unsigned DEFAULT NULL,
  `ml_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `gmod_code` varchar(40) COLLATE utf8_bin DEFAULT NULL,
  `gmod_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `ec_code` varchar(50) COLLATE utf8_bin DEFAULT NULL,
  `ec_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `orig` double DEFAULT NULL,
  `sbst_improvable` tinyint(1) DEFAULT NULL,
  `sbst_ab` tinyint(1) DEFAULT NULL,
  `sbst_a` double DEFAULT NULL,
  `sbst_b` double DEFAULT NULL,
  `sbst_lag` mediumint(8) unsigned DEFAULT NULL,
  `sbst_per_id` tinyint(1) DEFAULT NULL,
  `sam_id` int(10) unsigned DEFAULT NULL,
  `pl2` double DEFAULT NULL,
  `byp_state` double DEFAULT NULL,
  `bt` datetime DEFAULT NULL,
  `et` datetime DEFAULT NULL,
  `rbt` datetime DEFAULT NULL,
  `sam_v` double DEFAULT NULL,
  `imc_bias` double DEFAULT NULL,
  `aggs_type_id` double DEFAULT NULL,
  `ds_id` int(10) unsigned DEFAULT NULL,
  KEY `t#v_ar_map_gr$f_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- Dumping data for table emcor.t#v_ar_map_gr$f: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#v_ar_map_gr$f` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#v_ar_map_gr$f` ENABLE KEYS */;

-- Dumping structure for table emcor.t#v_ar_map_gr$v
CREATE TABLE IF NOT EXISTS `t#v_ar_map_gr$v` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `ma_id` int(10) unsigned DEFAULT NULL,
  `ts_id` tinyint(1) DEFAULT NULL,
  `mt_id` int(10) unsigned DEFAULT NULL,
  `gr_id` int(10) unsigned DEFAULT NULL,
  `gmod_id` mediumint(8) unsigned DEFAULT NULL,
  `gprc` tinyint(3) unsigned DEFAULT NULL,
  `mt_ec_id` mediumint(8) unsigned DEFAULT NULL,
  `mt_ec_in` tinyint(1) DEFAULT NULL,
  `gmod_a` double DEFAULT NULL,
  `gmod_b0` double DEFAULT NULL,
  `ml_id` mediumint(8) unsigned DEFAULT NULL,
  `aggs_id` tinyint(3) unsigned DEFAULT NULL,
  `aggf_id` tinyint(3) unsigned DEFAULT NULL,
  `md_id` smallint(5) unsigned DEFAULT NULL,
  `tff_id` tinyint(3) unsigned DEFAULT NULL,
  `dir_id` tinyint(4) DEFAULT NULL,
  `ms_id` smallint(5) unsigned DEFAULT NULL,
  `per_id` tinyint(3) unsigned DEFAULT NULL,
  `md_int_value` mediumint(8) unsigned DEFAULT NULL,
  `verge_id` smallint(5) unsigned DEFAULT NULL,
  `verge_code` varchar(40) COLLATE utf8_bin DEFAULT NULL,
  `verge_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `ma_ab` tinyint(1) DEFAULT NULL,
  `ma_a_nom` float DEFAULT NULL,
  `ma_a_denom` float DEFAULT NULL,
  `ma_b` float DEFAULT NULL,
  `ma_report_exceeding` tinyint(1) DEFAULT NULL,
  `ma_lag` double DEFAULT NULL,
  `ma_lag_per_id` tinyint(3) unsigned DEFAULT NULL,
  `map_id` int(10) unsigned DEFAULT NULL,
  `map_bt` datetime DEFAULT NULL,
  `map_et` datetime DEFAULT NULL,
  `map_h_bound` datetime DEFAULT NULL,
  `ml_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `gmod_code` varchar(40) COLLATE utf8_bin DEFAULT NULL,
  `gmod_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `gmod_b` double DEFAULT NULL,
  `da` date DEFAULT NULL,
  `mo` date DEFAULT NULL,
  `bt` datetime DEFAULT NULL,
  `et` datetime DEFAULT NULL,
  `i_nr` mediumint(8) unsigned DEFAULT NULL,
  `point_ms_id` smallint(5) unsigned DEFAULT NULL,
  `point_dir_id` tinyint(4) DEFAULT NULL,
  `coef` double DEFAULT NULL,
  `ec_id` mediumint(8) unsigned DEFAULT NULL,
  `ec_in` tinyint(1) DEFAULT NULL,
  `point_id` int(10) unsigned DEFAULT NULL,
  `ec_code` varchar(50) COLLATE utf8_bin DEFAULT NULL,
  `ec_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `ds_id` int(10) unsigned DEFAULT NULL,
  KEY `t#v_ar_map_gr$v_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- Dumping data for table emcor.t#v_ar_map_gr$v: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#v_ar_map_gr$v` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#v_ar_map_gr$v` ENABLE KEYS */;

-- Dumping structure for table emcor.t#v_ar_map_point$f
CREATE TABLE IF NOT EXISTS `t#v_ar_map_point$f` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `ma_id` int(10) unsigned DEFAULT NULL,
  `ts_id` tinyint(1) DEFAULT NULL,
  `mt_id` int(10) unsigned DEFAULT NULL,
  `ml_id` mediumint(8) unsigned DEFAULT NULL,
  `ml_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `point_id` int(10) unsigned DEFAULT NULL,
  `verge_id` smallint(5) unsigned DEFAULT NULL,
  `verge_code` varchar(40) COLLATE utf8_bin DEFAULT NULL,
  `verge_name` varchar(120) COLLATE utf8_bin DEFAULT NULL,
  `ma_ab` tinyint(1) DEFAULT NULL,
  `ma_a_nom` float DEFAULT NULL,
  `ma_a_denom` float DEFAULT NULL,
  `ma_b` float DEFAULT NULL,
  `ma_report_exceeding` tinyint(1) DEFAULT NULL,
  `ma_auto_null_act` tinyint(3) unsigned DEFAULT NULL,
  `ma_auto_ccs` tinyint(1) DEFAULT NULL,
  `map_id` int(10) unsigned DEFAULT NULL,
  `mo` date DEFAULT NULL,
  `da` date DEFAULT NULL,
  `per_id` tinyint(3) unsigned DEFAULT NULL,
  `md_int_value` mediumint(8) unsigned DEFAULT NULL,
  `pl2` int(10) unsigned DEFAULT NULL,
  `byp_state` tinyint(1) DEFAULT NULL,
  `bt` datetime DEFAULT NULL,
  `et` datetime DEFAULT NULL,
  `rbt0` datetime DEFAULT NULL,
  `ret0` datetime DEFAULT NULL,
  `aggs_type_id` tinyint(3) unsigned DEFAULT NULL,
  `aggs_id` tinyint(3) unsigned DEFAULT NULL,
  `bc` mediumint(8) unsigned DEFAULT NULL,
  `ma_lag` mediumint(8) unsigned DEFAULT NULL,
  `ma_lag_per_id` tinyint(3) unsigned DEFAULT NULL,
  `rbt` datetime DEFAULT NULL,
  `ret` datetime DEFAULT NULL,
  `ds_id` int(10) unsigned DEFAULT NULL,
  KEY `t#v_ar_map_point$f_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- Dumping data for table emcor.t#v_ar_map_point$f: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#v_ar_map_point$f` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#v_ar_map_point$f` ENABLE KEYS */;

-- Dumping structure for table emcor.t#v_plep_updated$f
CREATE TABLE IF NOT EXISTS `t#v_plep_updated$f` (
  `cid` bigint(4) NOT NULL DEFAULT connection_id(),
  `pl_id` int(10) unsigned NOT NULL,
  `plep_bt` datetime NOT NULL,
  `plep_et` datetime NOT NULL,
  `di_id` int(10) unsigned NOT NULL,
  `se_id` int(10) unsigned NOT NULL,
  `sep_id` int(10) unsigned NOT NULL,
  `point_id` int(10) unsigned NOT NULL,
  `pl_enabled` tinyint(1) NOT NULL,
  `point_enabled` tinyint(1) NOT NULL,
  `ow0` datetime DEFAULT NULL,
  `ow` datetime DEFAULT NULL,
  `tz_shift` double DEFAULT NULL,
  `aggs_id` tinyint(3) unsigned NOT NULL,
  `per_id` tinyint(3) unsigned DEFAULT NULL,
  `md_id` smallint(5) unsigned NOT NULL,
  `src_type_internal` tinyint(1) NOT NULL,
  `sep_h_lag` mediumint(8) unsigned DEFAULT NULL,
  `sep_h_depth` mediumint(8) unsigned DEFAULT NULL,
  `sep_h_per_id` tinyint(1) DEFAULT NULL,
  `sep_h_sch_id` mediumint(8) unsigned DEFAULT NULL,
  `se_h_depth` mediumint(8) unsigned DEFAULT NULL,
  `se_h_per_id` tinyint(3) unsigned DEFAULT NULL,
  `se_h_bound` datetime DEFAULT NULL,
  `se_h` tinyint(1) NOT NULL,
  `se_enabled` tinyint(1) NOT NULL,
  `di_enabled` tinyint(1) NOT NULL,
  `sep_enabled` tinyint(1) NOT NULL,
  `ph_enabled` tinyint(1) NOT NULL,
  `ph_deleted` tinyint(1) NOT NULL,
  `dp_deleted` tinyint(1) NOT NULL,
  `dp_enabled` tinyint(1) NOT NULL,
  `src_bt` datetime DEFAULT NULL,
  `src_et` datetime DEFAULT NULL,
  `src_enabled` tinyint(1) NOT NULL,
  `se_h_restore_depth` mediumint(8) unsigned DEFAULT NULL,
  `se_h_restore_per_id` tinyint(3) unsigned DEFAULT NULL,
  `bc` mediumint(8) unsigned NOT NULL,
  `sbc` double DEFAULT NULL,
  `aggs_type_id` tinyint(3) unsigned NOT NULL,
  `di_bt` datetime DEFAULT NULL,
  `di_et` datetime DEFAULT NULL,
  `cp_enabled` tinyint(1) DEFAULT NULL,
  KEY `t#v_plep_updated$f_cid_i` (`cid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.t#v_plep_updated$f: ~0 rows (approximately)
/*!40000 ALTER TABLE `t#v_plep_updated$f` DISABLE KEYS */;
/*!40000 ALTER TABLE `t#v_plep_updated$f` ENABLE KEYS */;

-- Dumping structure for table emcor.t2
CREATE TABLE IF NOT EXISTS `t2` (
  `i` int(11) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

-- Dumping data for table emcor.t2: ~1 rows (approximately)
/*!40000 ALTER TABLE `t2` DISABLE KEYS */;
/*!40000 ALTER TABLE `t2` ENABLE KEYS */;

-- Dumping structure for table emcor.tab
CREATE TABLE IF NOT EXISTS `tab` (
  `tab_id` mediumint(8) unsigned NOT NULL COMMENT 'Lentelės identifikatorius',
  `tab_type_id` smallint(5) unsigned NOT NULL COMMENT 'Lentelių tipo identifikatorius',
  `tab_name` varchar(30) COLLATE utf8_bin NOT NULL COMMENT 'Lentelės pavadinimas',
  PRIMARY KEY (`tab_id`),
  UNIQUE KEY `tab_name_u` (`tab_name`),
  KEY `tab_tab_type_fk` (`tab_type_id`),
  CONSTRAINT `tab_tab_type_fk` FOREIGN KEY (`tab_type_id`) REFERENCES `tab_type` (`tab_type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Lentelės';

-- Dumping data for table emcor.tab: ~257 rows (approximately)
/*!40000 ALTER TABLE `tab` DISABLE KEYS */;
INSERT INTO `tab` (`tab_id`, `tab_type_id`, `tab_name`) VALUES
	(1, 4, 'ACT'),
	(2, 4, 'ACT_DATA'),
	(3, 4, 'ACT_TYPE'),
	(4, 4, 'ACT_TYPE_80020'),
	(5, 4, 'BGA'),
	(6, 4, 'BGA_CLASS'),
	(7, 4, 'BGA_PARAM'),
	(8, 4, 'BGAQ'),
	(9, 4, 'BGA_TYPE'),
	(10, 4, 'BGA_TYPE_PARAM'),
	(11, 4, 'BGA_TYPE_UG'),
	(12, 1, 'BYP'),
	(13, 4, 'CAP_PARAM'),
	(14, 4, 'CAPTION'),
	(15, 3, 'DAS'),
	(16, 3, 'DEV'),
	(17, 3, 'DEVDP'),
	(18, 3, 'DEV_TYPE'),
	(19, 3, 'DEW'),
	(20, 1, 'DI'),
	(21, 3, 'DL_TYPE'),
	(22, 3, 'DP'),
	(23, 3, 'DP_DAS_FRC'),
	(24, 3, 'DP_LPTY'),
	(25, 5, 'DPR'),
	(26, 5, 'DPR_DATA'),
	(27, 3, 'DP_TYPE'),
	(28, 4, 'DS'),
	(29, 4, 'DS_DATA'),
	(30, 4, 'DS_DATA_VALID'),
	(31, 2, 'DS_GR'),
	(32, 4, 'DS_TYPE'),
	(33, 2, 'DS_TYPE_GR'),
	(34, 1, 'EC'),
	(35, 1, 'ECP'),
	(36, 1, 'ECP_DATA'),
	(37, 4, 'ENUM'),
	(38, 4, 'ENUM_DATA'),
	(39, 4, 'ENUM_TYPE'),
	(40, 4, 'EPTY'),
	(41, 4, 'EPTY_TYPE'),
	(42, 4, 'EVA'),
	(43, 4, 'EVA_ACK_UG'),
	(44, 4, 'EVA_ACK_USER'),
	(45, 3, 'EVABGAQF'),
	(46, 4, 'EVAC'),
	(47, 4, 'EVAQF'),
	(48, 4, 'EVA_TYPE'),
	(49, 3, 'EXC_SRC_TYPE_WITHE'),
	(50, 3, 'EXC_SRC_TMPL_GR'),
	(51, 4, 'FFP'),
	(52, 4, 'FFP_DATA'),
	(53, 4, 'FFP_UG'),
	(54, 4, 'FIB'),
	(55, 4, 'FP'),
	(56, 4, 'FP_DATA'),
	(57, 4, 'FP_SF'),
	(58, 3, 'GEW'),
	(59, 3, 'GMA_MA_TMPL'),
	(60, 3, 'GMA_TMPL'),
	(61, 4, 'GMOD'),
	(62, 4, 'GMOD_DATA'),
	(63, 2, 'GPTY'),
	(64, 2, 'GPTY_CNT_GRC'),
	(65, 2, 'GPTY_CNT_GRP'),
	(66, 4, 'GPTY_TYPE'),
	(67, 2, 'GR'),
	(68, 2, 'GRC'),
	(69, 2, 'GRC_DATA'),
	(70, 2, 'GRC_RULE'),
	(71, 3, 'GR_GMA_TMPL'),
	(72, 2, 'GR_GPTY'),
	(73, 2, 'GRP'),
	(74, 2, 'GRP_DATA'),
	(75, 2, 'GR_TYPE'),
	(76, 2, 'GR_TYPE_GPTY'),
	(77, 5, 'GTP'),
	(78, 5, 'HLD'),
	(79, 5, 'HLD_DATA'),
	(80, 5, 'HLD_SP_DATA'),
	(81, 3, 'LC'),
	(82, 4, 'LICENSE'),
	(83, 3, 'LP'),
	(84, 3, 'LP_DATA'),
	(85, 4, 'MA'),
	(86, 4, 'MAP'),
	(87, 1, 'MCC'),
	(88, 1, 'METER'),
	(89, 1, 'METER_MPTY'),
	(90, 1, 'METER_TYPE'),
	(91, 1, 'METER_TYPE_MPTY'),
	(92, 4, 'MY_ROOT'),
	(93, 4, 'MLSET'),
	(94, 4, 'MLSET_DATA'),
	(95, 3, 'MLSET_DS_DATA'),
	(96, 1, 'MOU'),
	(97, 1, 'MOU_TYPE'),
	(98, 1, 'MPTY'),
	(99, 4, 'MPTY_TYPE'),
	(100, 4, 'MS_TYPE'),
	(101, 4, 'MS_TYPE_UG'),
	(102, 4, 'MT'),
	(103, 4, 'MTA'),
	(104, 3, 'PH'),
	(105, 3, 'PH_COSTA'),
	(106, 3, 'PH_LPTY'),
	(107, 3, 'PH_TYPE'),
	(108, 3, 'PH_TYPE_LPTY'),
	(109, 1, 'PL'),
	(110, 3, 'PMA_MA_TMPL'),
	(111, 3, 'PMA_TMPL'),
	(112, 1, 'POINT'),
	(113, 1, 'POINT_FP'),
	(114, 3, 'POINT_PMA_TMPL'),
	(115, 1, 'POINT_PPTY'),
	(116, 3, 'POINT_RTP'),
	(117, 1, 'POINT_TYPE'),
	(118, 1, 'POINT_TYPE_PPTY'),
	(119, 1, 'POINT_VP'),
	(120, 1, 'PPTY'),
	(121, 4, 'PPTY_TYPE'),
	(122, 1, 'PTP'),
	(123, 3, 'PWW'),
	(124, 1, 'REL'),
	(125, 1, 'REL_EPTY'),
	(126, 1, 'REL_POS'),
	(127, 4, 'REL_TYPE'),
	(128, 4, 'REL_TYPE_EPTY'),
	(129, 4, 'REL_TYPE_POS'),
	(130, 4, 'RP'),
	(131, 4, 'RPA'),
	(132, 4, 'RPAPV'),
	(133, 4, 'RPA_RPTY'),
	(134, 4, 'RPAUG'),
	(135, 4, 'RPAUSER'),
	(136, 4, 'RP_DAS_FRC'),
	(137, 4, 'RP_FPTY'),
	(138, 4, 'RPQ'),
	(139, 4, 'RPQC'),
	(140, 4, 'RPQF'),
	(141, 4, 'RP_TYPE'),
	(142, 4, 'RP_UG'),
	(143, 3, 'RTP'),
	(144, 3, 'RTP_DATA'),
	(145, 4, 'SAM'),
	(146, 4, 'SAM_CONST_VAL_STATE'),
	(147, 4, 'SAMD'),
	(148, 4, 'SAM_DC'),
	(149, 4, 'SAMD_DATA'),
	(150, 4, 'SAMP'),
	(152, 4, 'SAM_TYPE'),
	(153, 4, 'SAM_TMPL'),
	(154, 4, 'SAM_TMPL_AI'),
	(155, 4, 'SAMU'),
	(156, 4, 'SAMW'),
	(157, 4, 'SAMW_DATA'),
	(158, 1, 'SBST'),
	(159, 3, 'SCH'),
	(160, 3, 'SCHI'),
	(161, 3, 'SCHI_DATA'),
	(162, 3, 'SE'),
	(163, 3, 'SE_LPTY'),
	(164, 3, 'SEP'),
	(165, 3, 'SEP_RC'),
	(166, 3, 'SEP_TMPL'),
	(167, 4, 'SEP_TMPL_DP_SHEAF'),
	(168, 4, 'SEP_TMPL_DP_SHEAF_RC'),
	(169, 3, 'SEP_TMPL_RC'),
	(170, 4, 'SEP_TMPL_SHEAF'),
	(171, 4, 'SEP_TMPL_SHEAF_RC'),
	(172, 3, 'SE_TMPL'),
	(173, 4, 'SE_TMPL_DP_SHEAF'),
	(174, 4, 'SE_TMPL_DP_SHEAF_LPTY'),
	(175, 4, 'SE_TMPL_LPTY'),
	(176, 4, 'SE_TMPL_SHEAF'),
	(177, 4, 'SE_TMPL_SHEAF_LPTY'),
	(178, 3, 'SP'),
	(179, 3, 'SP_LPTY'),
	(180, 4, 'SPTY'),
	(181, 3, 'SRC'),
	(182, 3, 'SRC_LPTY'),
	(183, 3, 'SRC_RULE'),
	(184, 4, 'SRC_TYPE_IMPORTANT_WITHE'),
	(185, 3, 'SRC_TMPL'),
	(186, 4, 'SRC_TMPL_LPTY'),
	(187, 4, 'SRC_TMPL_PH_TYPE_LPTY'),
	(188, 5, 'TFF_SELECTED'),
	(189, 5, 'TP'),
	(190, 5, 'TPP'),
	(191, 4, 'UG'),
	(192, 4, 'UG_DATA'),
	(193, 2, 'UGR'),
	(194, 4, 'UGROLE'),
	(195, 4, 'UG_ROOT'),
	(196, 4, 'USER_ROOT'),
	(197, 4, 'USERS'),
	(198, 4, 'VERGE'),
	(199, 4, 'VP'),
	(200, 4, 'VP_DATA'),
	(201, 4, 'VP_SCALAR'),
	(202, 4, 'WITHESET'),
	(203, 4, 'WITHESET_DATA'),
	(204, 5, 'WPR'),
	(205, 5, 'WPR_DATA'),
	(206, 4, 'XA'),
	(207, 4, 'XA_DAS_FRC'),
	(208, 4, 'XA_RPTY'),
	(209, 4, 'XF'),
	(210, 4, 'XFA'),
	(211, 4, 'XFAU'),
	(212, 4, 'XFE'),
	(213, 4, 'XF_RC'),
	(214, 4, 'XF_RPT'),
	(215, 4, 'XF_XPTY'),
	(216, 0, 'AGGF'),
	(217, 0, 'AGGS'),
	(218, 0, 'AGGS_TYPE'),
	(219, 0, 'ALGR'),
	(220, 0, 'DC'),
	(221, 0, 'DIR'),
	(222, 0, 'EVAC_TYPE'),
	(223, 0, 'FFP_VAL_TYPE'),
	(224, 0, 'FPTY'),
	(225, 0, 'LPTY'),
	(226, 0, 'LTC'),
	(227, 0, 'MD'),
	(228, 0, 'ML'),
	(229, 0, 'MS'),
	(230, 0, 'PER'),
	(231, 0, 'PH_LAYER'),
	(232, 0, 'RC'),
	(233, 0, 'RPF'),
	(234, 0, 'RPP'),
	(235, 0, 'RPQO'),
	(236, 0, 'RPQU'),
	(237, 0, 'RPTY'),
	(238, 0, 'SAMU_TYPE'),
	(239, 0, 'SAMW_TYPE'),
	(240, 0, 'SCH_INT'),
	(241, 0, 'SF'),
	(242, 0, 'SHEAF'),
	(243, 0, 'SPTY_TYPE'),
	(244, 0, 'SRC_TYPE'),
	(245, 0, 'TFF'),
	(246, 0, 'TS'),
	(247, 0, 'TZ'),
	(248, 0, 'WITHE'),
	(249, 0, 'WITHE_TYPE'),
	(250, 0, 'XE'),
	(251, 0, 'XFAU_TYPE'),
	(252, 0, 'XF_TYPE'),
	(253, 0, 'XPTY'),
	(254, 4, 'DIP'),
	(255, 3, 'SE_TMPL_DS_TYPE'),
	(256, 3, 'SE_TMPL_DS_TYPE_LPTY'),
	(257, 3, 'SEP_TMPL_DS_TYPE'),
	(258, 3, 'SEP_TMPL_DS_TYPE_RC');
/*!40000 ALTER TABLE `tab` ENABLE KEYS */;

-- Dumping structure for table emcor.tab_col
CREATE TABLE IF NOT EXISTS `tab_col` (
  `tab_id` mediumint(8) unsigned NOT NULL COMMENT 'Lentelės identifikatorius',
  `col_id` mediumint(8) unsigned NOT NULL COMMENT 'Lauko identifikatorius',
  `desc_nr` smallint(5) unsigned DEFAULT NULL COMMENT 'Lauko eilės numeris lentelės įrašo apibūdinime',
  `col_bp` tinyint(1) DEFAULT NULL COMMENT 'Lauko-identifikatoriaus pirmojo užpildymo požymis',
  PRIMARY KEY (`tab_id`,`col_id`),
  KEY `tab_col_col_i` (`col_id`,`col_bp`),
  CONSTRAINT `tab_col_col_fk` FOREIGN KEY (`col_id`) REFERENCES `col` (`col_id`),
  CONSTRAINT `tab_col_tab_fk` FOREIGN KEY (`tab_id`) REFERENCES `tab` (`tab_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Lentelių laukai';

-- Dumping data for table emcor.tab_col: ~1 343 rows (approximately)
/*!40000 ALTER TABLE `tab_col` DISABLE KEYS */;
INSERT INTO `tab_col` (`tab_id`, `col_id`, `desc_nr`, `col_bp`) VALUES
	(1, 1, NULL, NULL),
	(1, 2, NULL, NULL),
	(1, 3, NULL, 1),
	(1, 4, NULL, NULL),
	(1, 5, 1, NULL),
	(1, 6, NULL, NULL),
	(1, 102, NULL, NULL),
	(1, 309, NULL, NULL),
	(1, 442, NULL, NULL),
	(1, 684, NULL, NULL),
	(2, 3, 1, NULL),
	(2, 8, NULL, NULL),
	(2, 13, NULL, NULL),
	(2, 102, NULL, NULL),
	(2, 419, 2, NULL),
	(2, 421, 3, NULL),
	(3, 6, NULL, 1),
	(3, 7, 1, NULL),
	(4, 6, 1, NULL),
	(5, 27, NULL, NULL),
	(5, 28, NULL, 1),
	(5, 29, 1, NULL),
	(5, 36, NULL, NULL),
	(5, 41, NULL, NULL),
	(5, 266, NULL, NULL),
	(5, 582, NULL, NULL),
	(5, 767, NULL, NULL),
	(6, 24, NULL, NULL),
	(6, 25, NULL, 1),
	(6, 26, 1, NULL),
	(7, 28, 1, NULL),
	(7, 32, 2, NULL),
	(7, 33, NULL, NULL),
	(7, 34, NULL, NULL),
	(8, 35, NULL, NULL),
	(8, 36, NULL, 1),
	(8, 37, 1, NULL),
	(9, 25, NULL, NULL),
	(9, 38, NULL, NULL),
	(9, 39, NULL, NULL),
	(9, 40, NULL, NULL),
	(9, 41, NULL, 1),
	(9, 42, 1, NULL),
	(9, 47, NULL, NULL),
	(9, 48, NULL, NULL),
	(9, 49, NULL, NULL),
	(9, 50, NULL, NULL),
	(10, 31, NULL, NULL),
	(10, 41, 2, NULL),
	(10, 43, NULL, NULL),
	(10, 44, NULL, NULL),
	(10, 45, 1, NULL),
	(10, 46, NULL, NULL),
	(10, 172, NULL, NULL),
	(11, 41, 1, NULL),
	(11, 675, 2, NULL),
	(12, 52, NULL, NULL),
	(12, 53, NULL, NULL),
	(12, 54, NULL, NULL),
	(12, 55, NULL, NULL),
	(12, 56, 2, NULL),
	(12, 140, NULL, NULL),
	(12, 442, 1, NULL),
	(13, 62, 1, NULL),
	(13, 64, NULL, NULL),
	(13, 65, 2, NULL),
	(14, 61, NULL, NULL),
	(14, 62, NULL, 1),
	(14, 63, 1, NULL),
	(14, 66, NULL, NULL),
	(14, 67, NULL, NULL),
	(15, 98, NULL, NULL),
	(15, 99, NULL, 1),
	(15, 100, 1, NULL),
	(16, 111, NULL, 1),
	(16, 112, 1, NULL),
	(16, 113, 2, NULL),
	(16, 765, NULL, NULL),
	(17, 108, NULL, NULL),
	(17, 109, NULL, NULL),
	(17, 110, 1, 1),
	(17, 111, NULL, NULL),
	(17, 128, NULL, NULL),
	(18, 113, NULL, 1),
	(18, 114, 1, NULL),
	(19, 115, NULL, NULL),
	(19, 116, NULL, NULL),
	(19, 117, NULL, 1),
	(19, 118, 1, NULL),
	(19, 128, NULL, NULL),
	(19, 714, NULL, NULL),
	(19, 719, NULL, NULL),
	(20, 119, NULL, NULL),
	(20, 120, NULL, 1),
	(20, 128, 5, NULL),
	(20, 140, 2, NULL),
	(20, 319, NULL, NULL),
	(20, 419, 1, NULL),
	(20, 442, 4, NULL),
	(20, 614, 3, NULL),
	(20, 716, 6, NULL),
	(21, 123, NULL, 1),
	(21, 124, 1, NULL),
	(22, 125, NULL, NULL),
	(22, 126, NULL, NULL),
	(22, 127, NULL, NULL),
	(22, 128, NULL, 1),
	(22, 129, NULL, NULL),
	(22, 130, 1, NULL),
	(22, 133, NULL, NULL),
	(23, 99, 2, NULL),
	(23, 128, 1, NULL),
	(24, 128, 1, NULL),
	(24, 323, 2, NULL),
	(24, 324, NULL, NULL),
	(25, 131, NULL, 1),
	(25, 132, 1, NULL),
	(26, 51, 2, NULL),
	(26, 131, 1, NULL),
	(26, 167, 3, NULL),
	(26, 665, NULL, NULL),
	(27, 133, NULL, 1),
	(27, 134, 1, NULL),
	(28, 135, NULL, NULL),
	(28, 136, 1, NULL),
	(28, 138, NULL, NULL),
	(28, 139, NULL, NULL),
	(28, 140, NULL, 1),
	(28, 141, NULL, NULL),
	(28, 144, NULL, NULL),
	(28, 150, NULL, NULL),
	(28, 172, NULL, NULL),
	(28, 442, NULL, NULL),
	(29, 102, NULL, NULL),
	(29, 137, NULL, NULL),
	(29, 140, 1, NULL),
	(29, 143, NULL, NULL),
	(29, 145, 2, NULL),
	(29, 147, NULL, NULL),
	(29, 152, NULL, NULL),
	(29, 404, NULL, NULL),
	(29, 603, NULL, NULL),
	(29, 672, NULL, NULL),
	(31, 140, 1, NULL),
	(31, 142, NULL, NULL),
	(31, 266, 2, NULL),
	(32, 135, NULL, NULL),
	(32, 139, NULL, NULL),
	(32, 144, NULL, NULL),
	(32, 148, NULL, NULL),
	(32, 150, NULL, 1),
	(32, 151, 1, NULL),
	(32, 172, NULL, NULL),
	(33, 149, NULL, NULL),
	(33, 150, 1, NULL),
	(33, 160, NULL, NULL),
	(33, 161, NULL, NULL),
	(33, 244, NULL, NULL),
	(33, 246, NULL, NULL),
	(33, 266, 2, NULL),
	(33, 355, NULL, NULL),
	(33, 536, NULL, NULL),
	(33, 690, NULL, NULL),
	(33, 714, NULL, NULL),
	(34, 159, NULL, NULL),
	(34, 160, NULL, 1),
	(34, 161, NULL, NULL),
	(34, 162, 1, NULL),
	(35, 163, NULL, NULL),
	(35, 164, NULL, 1),
	(35, 165, 1, NULL),
	(36, 74, NULL, NULL),
	(36, 122, 3, NULL),
	(36, 160, 4, NULL),
	(36, 164, 1, NULL),
	(36, 264, 6, NULL),
	(36, 267, 5, NULL),
	(36, 274, 7, NULL),
	(36, 391, 2, NULL),
	(37, 170, NULL, NULL),
	(37, 172, NULL, 1),
	(37, 173, 1, NULL),
	(37, 175, NULL, NULL),
	(38, 171, NULL, NULL),
	(38, 172, 1, NULL),
	(38, 177, 2, NULL),
	(38, 178, NULL, NULL),
	(39, 174, NULL, NULL),
	(39, 175, NULL, 1),
	(39, 176, 1, NULL),
	(40, 172, NULL, NULL),
	(40, 179, NULL, NULL),
	(40, 180, NULL, 1),
	(40, 181, 1, NULL),
	(40, 183, NULL, NULL),
	(40, 185, NULL, NULL),
	(41, 184, NULL, NULL),
	(41, 185, NULL, 1),
	(41, 186, 1, NULL),
	(42, 28, NULL, NULL),
	(42, 30, NULL, NULL),
	(42, 68, NULL, NULL),
	(42, 69, NULL, NULL),
	(42, 70, NULL, NULL),
	(42, 71, NULL, NULL),
	(42, 72, NULL, NULL),
	(42, 73, NULL, NULL),
	(42, 153, NULL, NULL),
	(42, 154, NULL, NULL),
	(42, 155, NULL, NULL),
	(42, 156, NULL, NULL),
	(42, 157, NULL, NULL),
	(42, 158, NULL, NULL),
	(42, 189, NULL, NULL),
	(42, 190, NULL, NULL),
	(42, 191, NULL, NULL),
	(42, 192, NULL, NULL),
	(42, 195, NULL, NULL),
	(42, 198, NULL, NULL),
	(42, 199, NULL, 1),
	(42, 200, NULL, NULL),
	(42, 201, 1, NULL),
	(42, 202, NULL, NULL),
	(42, 311, NULL, NULL),
	(42, 398, NULL, NULL),
	(42, 399, NULL, NULL),
	(42, 400, NULL, NULL),
	(42, 401, NULL, NULL),
	(42, 402, NULL, NULL),
	(42, 480, NULL, NULL),
	(42, 615, NULL, NULL),
	(42, 616, NULL, NULL),
	(42, 617, NULL, NULL),
	(42, 618, NULL, NULL),
	(42, 619, NULL, NULL),
	(42, 655, NULL, NULL),
	(43, 22, NULL, NULL),
	(43, 199, 1, NULL),
	(43, 675, 2, NULL),
	(44, 22, NULL, NULL),
	(44, 199, 1, NULL),
	(44, 684, 2, NULL),
	(45, 32, 2, NULL),
	(45, 33, NULL, NULL),
	(45, 199, 1, NULL),
	(46, 96, NULL, NULL),
	(46, 105, NULL, NULL),
	(46, 193, NULL, NULL),
	(46, 194, 2, NULL),
	(46, 196, NULL, NULL),
	(46, 199, 1, NULL),
	(46, 396, NULL, NULL),
	(46, 397, NULL, NULL),
	(47, 199, 1, NULL),
	(47, 502, 2, NULL),
	(47, 505, NULL, NULL),
	(48, 202, NULL, 1),
	(48, 203, 1, NULL),
	(49, 314, 3, NULL),
	(49, 649, 1, NULL),
	(49, 714, 2, NULL),
	(50, 266, 2, NULL),
	(50, 580, NULL, NULL),
	(50, 581, NULL, NULL),
	(50, 651, 1, NULL),
	(51, 206, NULL, NULL),
	(51, 209, NULL, 1),
	(51, 210, 1, NULL),
	(51, 211, NULL, NULL),
	(52, 207, 1, 1),
	(52, 208, NULL, NULL),
	(52, 209, NULL, NULL),
	(52, 212, NULL, NULL),
	(52, 213, NULL, NULL),
	(52, 214, NULL, NULL),
	(52, 215, NULL, NULL),
	(52, 216, NULL, NULL),
	(52, 218, NULL, NULL),
	(53, 209, 1, NULL),
	(53, 675, 2, NULL),
	(54, 102, NULL, NULL),
	(54, 146, NULL, NULL),
	(54, 147, NULL, NULL),
	(54, 219, 1, 1),
	(54, 346, 4, NULL),
	(54, 350, 2, NULL),
	(54, 404, NULL, NULL),
	(54, 420, NULL, NULL),
	(54, 421, 5, NULL),
	(54, 422, NULL, NULL),
	(54, 656, 3, NULL),
	(55, 224, NULL, NULL),
	(55, 225, NULL, 1),
	(55, 226, 1, NULL),
	(56, 9, NULL, NULL),
	(56, 11, NULL, NULL),
	(56, 13, NULL, NULL),
	(56, 122, NULL, NULL),
	(56, 225, 1, NULL),
	(56, 227, 2, NULL),
	(56, 346, NULL, NULL),
	(56, 391, NULL, NULL),
	(56, 665, NULL, NULL),
	(57, 225, 1, NULL),
	(57, 610, NULL, NULL),
	(57, 612, 2, NULL),
	(58, 231, NULL, NULL),
	(58, 232, NULL, NULL),
	(58, 233, NULL, 1),
	(58, 234, 1, NULL),
	(58, 266, NULL, NULL),
	(58, 714, NULL, NULL),
	(58, 719, NULL, NULL),
	(59, 235, 1, 1),
	(59, 237, NULL, NULL),
	(59, 248, NULL, NULL),
	(59, 249, NULL, NULL),
	(59, 250, NULL, NULL),
	(59, 251, NULL, NULL),
	(59, 308, NULL, NULL),
	(59, 326, NULL, NULL),
	(59, 327, NULL, NULL),
	(59, 328, NULL, NULL),
	(59, 329, NULL, NULL),
	(59, 330, NULL, NULL),
	(59, 331, NULL, NULL),
	(59, 332, NULL, NULL),
	(59, 333, NULL, NULL),
	(59, 337, NULL, NULL),
	(59, 338, NULL, NULL),
	(59, 341, NULL, NULL),
	(59, 342, NULL, NULL),
	(59, 620, NULL, NULL),
	(59, 621, NULL, NULL),
	(59, 622, NULL, NULL),
	(59, 623, NULL, NULL),
	(59, 624, NULL, NULL),
	(59, 625, NULL, NULL),
	(59, 626, NULL, NULL),
	(59, 627, NULL, NULL),
	(59, 658, NULL, NULL),
	(59, 659, NULL, NULL),
	(59, 660, NULL, NULL),
	(59, 661, NULL, NULL),
	(59, 662, NULL, NULL),
	(59, 690, NULL, NULL),
	(60, 236, NULL, NULL),
	(60, 237, NULL, 1),
	(60, 238, 1, NULL),
	(61, 239, NULL, NULL),
	(61, 242, NULL, NULL),
	(61, 243, NULL, NULL),
	(61, 244, NULL, 1),
	(61, 245, 1, NULL),
	(61, 307, NULL, NULL),
	(62, 160, NULL, NULL),
	(62, 240, NULL, NULL),
	(62, 241, 2, NULL),
	(62, 244, 1, NULL),
	(62, 248, NULL, NULL),
	(62, 326, NULL, NULL),
	(62, 391, NULL, NULL),
	(62, 665, NULL, NULL),
	(63, 172, NULL, NULL),
	(63, 247, NULL, NULL),
	(63, 248, NULL, 1),
	(63, 252, 1, NULL),
	(63, 253, NULL, NULL),
	(63, 254, NULL, NULL),
	(63, 256, NULL, NULL),
	(64, 84, NULL, NULL),
	(64, 90, 1, NULL),
	(64, 248, 2, NULL),
	(65, 164, NULL, NULL),
	(65, 248, 2, NULL),
	(65, 274, 1, NULL),
	(65, 448, NULL, NULL),
	(66, 255, NULL, NULL),
	(66, 256, NULL, 1),
	(66, 257, 1, NULL),
	(67, 263, 1, NULL),
	(67, 266, NULL, 1),
	(67, 268, NULL, NULL),
	(67, 274, NULL, NULL),
	(67, 315, NULL, NULL),
	(67, 684, NULL, NULL),
	(68, 82, 2, NULL),
	(68, 88, 1, NULL),
	(68, 259, 3, NULL),
	(68, 260, NULL, NULL),
	(68, 261, NULL, NULL),
	(68, 262, NULL, NULL),
	(69, 74, NULL, NULL),
	(69, 80, 5, NULL),
	(69, 81, 6, NULL),
	(69, 82, 2, NULL),
	(69, 83, 4, NULL),
	(69, 86, 8, NULL),
	(69, 87, 9, NULL),
	(69, 88, 1, NULL),
	(69, 89, 7, NULL),
	(69, 259, 3, NULL),
	(70, 74, NULL, NULL),
	(70, 80, 6, NULL),
	(70, 81, 8, NULL),
	(70, 83, 4, NULL),
	(70, 84, 2, NULL),
	(70, 86, 5, NULL),
	(70, 87, 7, NULL),
	(70, 89, 3, NULL),
	(70, 90, 1, NULL),
	(70, 524, NULL, NULL),
	(71, 237, NULL, NULL),
	(71, 266, 1, NULL),
	(72, 248, 2, NULL),
	(72, 258, NULL, NULL),
	(72, 266, 1, NULL),
	(72, 536, NULL, NULL),
	(73, 266, 1, NULL),
	(73, 269, 3, NULL),
	(73, 270, NULL, NULL),
	(73, 271, NULL, NULL),
	(73, 272, NULL, NULL),
	(73, 442, 2, NULL),
	(74, 74, NULL, NULL),
	(74, 264, 7, NULL),
	(74, 265, 8, NULL),
	(74, 266, 1, NULL),
	(74, 267, 6, NULL),
	(74, 269, 3, NULL),
	(74, 440, 5, NULL),
	(74, 442, 2, NULL),
	(74, 445, 4, NULL),
	(75, 273, NULL, NULL),
	(75, 274, NULL, 1),
	(75, 275, 1, NULL),
	(76, 248, 2, NULL),
	(76, 274, 1, NULL),
	(77, 9, 3, NULL),
	(77, 266, 1, NULL),
	(77, 276, 4, NULL),
	(77, 277, 5, NULL),
	(77, 278, NULL, 1),
	(77, 391, 2, NULL),
	(77, 667, NULL, NULL),
	(78, 305, NULL, 1),
	(78, 306, 1, NULL),
	(79, 107, 3, NULL),
	(79, 305, 1, NULL),
	(79, 359, 2, NULL),
	(80, 97, NULL, NULL),
	(80, 279, 2, NULL),
	(80, 305, 1, NULL),
	(80, 702, NULL, NULL),
	(81, 266, 1, NULL),
	(81, 316, NULL, NULL),
	(82, 95, NULL, NULL),
	(82, 204, NULL, NULL),
	(82, 317, NULL, NULL),
	(82, 318, NULL, NULL),
	(82, 444, NULL, NULL),
	(83, 319, NULL, 1),
	(83, 320, 1, NULL),
	(84, 123, 1, NULL),
	(84, 133, 2, NULL),
	(84, 319, 4, NULL),
	(84, 321, NULL, NULL),
	(84, 415, 3, NULL),
	(85, 327, NULL, NULL),
	(85, 328, NULL, NULL),
	(85, 329, NULL, NULL),
	(85, 330, NULL, NULL),
	(85, 331, NULL, NULL),
	(85, 332, NULL, NULL),
	(85, 333, NULL, NULL),
	(85, 335, NULL, NULL),
	(85, 336, 1, 1),
	(85, 337, NULL, NULL),
	(85, 338, NULL, NULL),
	(85, 341, NULL, NULL),
	(85, 342, NULL, NULL),
	(85, 690, NULL, NULL),
	(86, 58, 2, NULL),
	(86, 188, NULL, NULL),
	(86, 336, 1, NULL),
	(86, 339, NULL, NULL),
	(86, 340, NULL, 1),
	(87, 75, NULL, NULL),
	(87, 76, NULL, NULL),
	(87, 77, NULL, NULL),
	(87, 78, NULL, NULL),
	(87, 102, NULL, NULL),
	(87, 343, 2, NULL),
	(87, 344, NULL, NULL),
	(87, 417, NULL, NULL),
	(87, 442, 1, NULL),
	(88, 205, NULL, NULL),
	(88, 334, NULL, NULL),
	(88, 348, NULL, NULL),
	(88, 349, NULL, 1),
	(88, 350, 1, NULL),
	(88, 351, 2, NULL),
	(89, 349, 1, NULL),
	(89, 383, 2, NULL),
	(89, 389, NULL, NULL),
	(90, 351, NULL, 1),
	(90, 352, 1, NULL),
	(90, 353, NULL, NULL),
	(91, 351, 1, NULL),
	(91, 383, 2, NULL),
	(92, 266, NULL, NULL),
	(92, 684, 1, NULL),
	(93, 356, NULL, NULL),
	(93, 357, NULL, 1),
	(93, 358, 1, NULL),
	(94, 355, 2, NULL),
	(94, 357, 1, NULL),
	(95, 150, 2, NULL),
	(95, 357, 1, NULL),
	(96, 349, NULL, NULL),
	(96, 361, NULL, NULL),
	(96, 362, NULL, NULL),
	(96, 363, NULL, NULL),
	(96, 364, NULL, NULL),
	(96, 365, NULL, NULL),
	(96, 366, NULL, NULL),
	(96, 367, 1, 1),
	(96, 368, NULL, NULL),
	(96, 442, NULL, NULL),
	(97, 368, NULL, 1),
	(97, 369, 1, NULL),
	(98, 172, NULL, NULL),
	(98, 382, NULL, NULL),
	(98, 383, NULL, 1),
	(98, 384, 1, NULL),
	(98, 385, NULL, NULL),
	(98, 387, NULL, NULL),
	(99, 386, NULL, NULL),
	(99, 387, NULL, 1),
	(99, 388, 1, NULL),
	(100, 392, NULL, 1),
	(100, 393, 1, NULL),
	(100, 692, NULL, NULL),
	(101, 392, 1, NULL),
	(101, 675, 2, NULL),
	(101, 692, NULL, NULL),
	(102, 160, 7, NULL),
	(102, 161, 8, NULL),
	(102, 244, 5, NULL),
	(102, 246, 6, NULL),
	(102, 266, 4, NULL),
	(102, 355, 2, NULL),
	(102, 394, NULL, 1),
	(102, 442, 1, NULL),
	(102, 536, 3, NULL),
	(103, 336, 1, NULL),
	(103, 394, NULL, NULL),
	(103, 670, 2, NULL),
	(104, 91, NULL, NULL),
	(104, 92, NULL, NULL),
	(104, 93, NULL, NULL),
	(104, 94, NULL, NULL),
	(104, 128, 1, NULL),
	(104, 407, NULL, NULL),
	(104, 408, NULL, NULL),
	(104, 409, NULL, NULL),
	(104, 410, NULL, 1),
	(104, 413, 2, NULL),
	(104, 414, NULL, NULL),
	(104, 415, NULL, NULL),
	(106, 323, 2, NULL),
	(106, 324, NULL, NULL),
	(106, 410, 1, NULL),
	(107, 412, NULL, NULL),
	(107, 415, NULL, 1),
	(107, 416, 1, NULL),
	(108, 323, 2, NULL),
	(108, 324, NULL, NULL),
	(108, 415, 1, NULL),
	(109, 355, 1, NULL),
	(109, 418, NULL, NULL),
	(109, 419, NULL, 1),
	(109, 442, 2, NULL),
	(110, 308, NULL, NULL),
	(110, 326, NULL, NULL),
	(110, 327, NULL, NULL),
	(110, 328, NULL, NULL),
	(110, 329, NULL, NULL),
	(110, 330, NULL, NULL),
	(110, 331, NULL, NULL),
	(110, 332, NULL, NULL),
	(110, 333, NULL, NULL),
	(110, 337, NULL, NULL),
	(110, 338, NULL, NULL),
	(110, 341, NULL, NULL),
	(110, 342, NULL, NULL),
	(110, 423, 1, 1),
	(110, 425, NULL, NULL),
	(110, 452, NULL, NULL),
	(110, 454, NULL, NULL),
	(110, 455, NULL, NULL),
	(110, 456, NULL, NULL),
	(110, 457, NULL, NULL),
	(110, 475, NULL, NULL),
	(110, 625, NULL, NULL),
	(110, 626, NULL, NULL),
	(110, 627, NULL, NULL),
	(110, 662, NULL, NULL),
	(110, 690, NULL, NULL),
	(111, 424, NULL, NULL),
	(111, 425, NULL, 1),
	(111, 426, 1, NULL),
	(112, 164, NULL, NULL),
	(112, 427, NULL, NULL),
	(112, 428, 1, NULL),
	(112, 429, NULL, NULL),
	(112, 430, NULL, NULL),
	(112, 431, NULL, NULL),
	(112, 432, NULL, NULL),
	(112, 433, NULL, NULL),
	(112, 434, NULL, NULL),
	(112, 435, NULL, NULL),
	(112, 436, NULL, NULL),
	(112, 437, NULL, NULL),
	(112, 438, NULL, NULL),
	(112, 439, NULL, NULL),
	(112, 441, NULL, NULL),
	(112, 442, NULL, 1),
	(112, 443, NULL, NULL),
	(112, 446, NULL, NULL),
	(112, 448, NULL, NULL),
	(112, 723, NULL, NULL),
	(113, 225, NULL, NULL),
	(113, 442, 1, NULL),
	(114, 425, NULL, NULL),
	(114, 442, 1, NULL),
	(115, 442, 1, NULL),
	(115, 454, 2, NULL),
	(115, 464, NULL, NULL),
	(116, 442, 1, NULL),
	(116, 520, NULL, NULL),
	(117, 447, NULL, NULL),
	(117, 448, NULL, 1),
	(117, 449, 1, NULL),
	(118, 448, 1, NULL),
	(118, 454, 2, NULL),
	(119, 442, 1, NULL),
	(119, 696, NULL, NULL),
	(120, 172, NULL, NULL),
	(120, 453, NULL, NULL),
	(120, 454, NULL, 1),
	(120, 458, 1, NULL),
	(120, 459, NULL, NULL),
	(120, 460, NULL, NULL),
	(120, 462, NULL, NULL),
	(121, 461, NULL, NULL),
	(121, 462, NULL, 1),
	(121, 463, 1, NULL),
	(122, 9, 2, NULL),
	(122, 442, 1, NULL),
	(122, 465, 3, NULL),
	(122, 466, 4, NULL),
	(122, 467, NULL, 1),
	(122, 667, NULL, NULL),
	(123, 266, NULL, NULL),
	(123, 468, NULL, NULL),
	(123, 469, 1, 1),
	(123, 649, NULL, NULL),
	(123, 675, NULL, NULL),
	(123, 716, NULL, NULL),
	(124, 472, NULL, NULL),
	(124, 473, 1, 1),
	(124, 475, NULL, NULL),
	(125, 180, 2, NULL),
	(125, 187, NULL, NULL),
	(125, 473, 1, NULL),
	(126, 442, NULL, NULL),
	(126, 452, 2, NULL),
	(126, 473, 1, NULL),
	(127, 474, NULL, NULL),
	(127, 475, NULL, 1),
	(127, 476, 1, NULL),
	(128, 172, NULL, NULL),
	(128, 180, 2, NULL),
	(128, 182, NULL, NULL),
	(128, 475, 1, NULL),
	(129, 450, 2, NULL),
	(129, 451, NULL, NULL),
	(129, 452, NULL, NULL),
	(129, 475, 1, NULL),
	(130, 484, NULL, NULL),
	(130, 486, NULL, NULL),
	(130, 487, NULL, NULL),
	(130, 488, NULL, 1),
	(130, 489, NULL, NULL),
	(130, 490, 1, NULL),
	(130, 493, NULL, NULL),
	(130, 516, NULL, NULL),
	(130, 684, NULL, NULL),
	(131, 221, NULL, NULL),
	(131, 223, NULL, NULL),
	(131, 478, NULL, NULL),
	(131, 479, NULL, NULL),
	(131, 480, NULL, 1),
	(131, 481, NULL, NULL),
	(131, 482, 1, NULL),
	(131, 488, NULL, NULL),
	(131, 492, NULL, NULL),
	(131, 582, NULL, NULL),
	(131, 684, NULL, NULL),
	(132, 480, NULL, NULL),
	(132, 483, 1, 1),
	(132, 500, NULL, NULL),
	(132, 502, NULL, NULL),
	(132, 505, NULL, NULL),
	(133, 480, 1, NULL),
	(133, 515, 2, NULL),
	(133, 518, NULL, NULL),
	(134, 480, 1, NULL),
	(134, 675, 2, NULL),
	(135, 480, 1, NULL),
	(135, 684, 2, NULL),
	(136, 99, 2, NULL),
	(136, 488, 1, NULL),
	(137, 229, 2, NULL),
	(137, 230, NULL, NULL),
	(137, 488, 1, NULL),
	(138, 488, 2, NULL),
	(138, 494, NULL, NULL),
	(138, 498, NULL, NULL),
	(138, 506, NULL, 1),
	(138, 507, NULL, NULL),
	(138, 508, 1, NULL),
	(138, 511, NULL, NULL),
	(138, 657, NULL, NULL),
	(139, 79, NULL, NULL),
	(139, 495, NULL, NULL),
	(139, 496, 1, 1),
	(139, 497, NULL, NULL),
	(139, 506, NULL, NULL),
	(139, 512, NULL, NULL),
	(140, 79, NULL, NULL),
	(140, 101, NULL, NULL),
	(140, 499, NULL, NULL),
	(140, 500, NULL, NULL),
	(140, 501, NULL, NULL),
	(140, 502, 1, 1),
	(140, 503, NULL, NULL),
	(140, 504, NULL, NULL),
	(140, 505, NULL, NULL),
	(140, 506, NULL, NULL),
	(140, 510, NULL, NULL),
	(141, 516, NULL, 1),
	(141, 517, 1, NULL),
	(142, 22, NULL, NULL),
	(142, 488, 1, NULL),
	(142, 675, 2, NULL),
	(143, 519, NULL, NULL),
	(143, 520, NULL, 1),
	(143, 523, 1, NULL),
	(144, 355, 2, NULL),
	(144, 406, NULL, NULL),
	(144, 520, 1, NULL),
	(144, 521, NULL, NULL),
	(144, 522, NULL, NULL),
	(145, 85, NULL, NULL),
	(145, 305, NULL, NULL),
	(145, 346, NULL, NULL),
	(145, 525, NULL, NULL),
	(145, 528, NULL, NULL),
	(145, 529, NULL, NULL),
	(145, 536, NULL, 1),
	(145, 537, 1, NULL),
	(145, 541, NULL, NULL),
	(145, 548, NULL, NULL),
	(145, 643, NULL, NULL),
	(145, 677, NULL, NULL),
	(146, 530, NULL, NULL),
	(146, 531, NULL, NULL),
	(146, 536, 1, NULL),
	(147, 346, NULL, NULL),
	(147, 533, NULL, NULL),
	(147, 534, NULL, 1),
	(147, 535, 1, NULL),
	(148, 104, NULL, NULL),
	(148, 394, NULL, NULL),
	(148, 406, NULL, NULL),
	(148, 536, 1, NULL),
	(148, 712, NULL, NULL),
	(149, 395, 2, NULL),
	(149, 534, 1, NULL),
	(149, 559, NULL, NULL),
	(150, 23, NULL, NULL),
	(150, 57, NULL, NULL),
	(150, 58, NULL, NULL),
	(150, 166, NULL, NULL),
	(150, 169, NULL, NULL),
	(150, 188, NULL, NULL),
	(150, 536, NULL, NULL),
	(150, 538, 1, 1),
	(150, 561, NULL, NULL),
	(152, 541, NULL, 1),
	(152, 542, 1, NULL),
	(153, 59, NULL, NULL),
	(153, 60, NULL, NULL),
	(153, 85, NULL, NULL),
	(153, 305, NULL, NULL),
	(153, 347, NULL, NULL),
	(153, 403, NULL, NULL),
	(153, 528, NULL, NULL),
	(153, 541, NULL, NULL),
	(153, 544, NULL, NULL),
	(153, 545, NULL, NULL),
	(153, 546, NULL, NULL),
	(153, 547, NULL, NULL),
	(153, 548, NULL, 1),
	(153, 549, 1, NULL),
	(153, 550, NULL, NULL),
	(153, 551, NULL, NULL),
	(153, 564, NULL, NULL),
	(153, 677, NULL, NULL),
	(154, 15, NULL, NULL),
	(154, 16, NULL, NULL),
	(154, 17, NULL, NULL),
	(154, 18, NULL, NULL),
	(154, 19, NULL, NULL),
	(154, 543, 2, NULL),
	(154, 548, 1, NULL),
	(155, 394, 1, NULL),
	(155, 536, NULL, NULL),
	(155, 539, NULL, NULL),
	(155, 540, NULL, NULL),
	(155, 552, NULL, NULL),
	(155, 553, NULL, NULL),
	(155, 554, NULL, NULL),
	(155, 555, NULL, NULL),
	(155, 556, NULL, NULL),
	(155, 558, 2, NULL),
	(155, 564, NULL, NULL),
	(155, 582, NULL, NULL),
	(156, 346, NULL, NULL),
	(156, 560, NULL, NULL),
	(156, 561, NULL, 1),
	(156, 562, 1, NULL),
	(157, 534, NULL, NULL),
	(157, 561, 1, NULL),
	(157, 702, 2, NULL),
	(158, 406, NULL, NULL),
	(158, 419, 1, NULL),
	(158, 536, NULL, NULL),
	(158, 565, NULL, NULL),
	(158, 566, NULL, NULL),
	(158, 567, NULL, NULL),
	(158, 568, NULL, NULL),
	(158, 569, NULL, NULL),
	(158, 570, NULL, NULL),
	(158, 571, NULL, NULL),
	(158, 572, NULL, NULL),
	(158, 573, NULL, NULL),
	(158, 574, NULL, NULL),
	(158, 575, NULL, NULL),
	(158, 576, NULL, NULL),
	(158, 577, NULL, NULL),
	(158, 578, NULL, NULL),
	(158, 579, NULL, NULL),
	(159, 582, NULL, 1),
	(159, 587, 1, NULL),
	(160, 280, NULL, NULL),
	(160, 281, NULL, NULL),
	(160, 282, NULL, NULL),
	(160, 283, NULL, NULL),
	(160, 284, NULL, NULL),
	(160, 285, NULL, NULL),
	(160, 286, NULL, NULL),
	(160, 287, NULL, NULL),
	(160, 288, NULL, NULL),
	(160, 289, NULL, NULL),
	(160, 290, NULL, NULL),
	(160, 291, NULL, NULL),
	(160, 292, NULL, NULL),
	(160, 293, NULL, NULL),
	(160, 294, NULL, NULL),
	(160, 295, NULL, NULL),
	(160, 296, NULL, NULL),
	(160, 297, NULL, NULL),
	(160, 298, NULL, NULL),
	(160, 299, NULL, NULL),
	(160, 300, NULL, NULL),
	(160, 301, NULL, NULL),
	(160, 302, NULL, NULL),
	(160, 303, NULL, NULL),
	(160, 304, NULL, NULL),
	(160, 305, NULL, NULL),
	(160, 360, NULL, NULL),
	(160, 370, NULL, NULL),
	(160, 371, NULL, NULL),
	(160, 372, NULL, NULL),
	(160, 373, NULL, NULL),
	(160, 374, NULL, NULL),
	(160, 375, NULL, NULL),
	(160, 376, NULL, NULL),
	(160, 377, NULL, NULL),
	(160, 378, NULL, NULL),
	(160, 379, NULL, NULL),
	(160, 380, NULL, NULL),
	(160, 381, NULL, NULL),
	(160, 582, 1, NULL),
	(160, 583, 2, NULL),
	(160, 588, NULL, NULL),
	(160, 589, NULL, NULL),
	(160, 703, NULL, NULL),
	(160, 704, NULL, NULL),
	(160, 705, NULL, NULL),
	(160, 706, NULL, NULL),
	(160, 707, NULL, NULL),
	(160, 708, NULL, NULL),
	(160, 709, NULL, NULL),
	(160, 710, NULL, NULL),
	(160, 711, NULL, NULL),
	(161, 406, NULL, NULL),
	(161, 582, 1, NULL),
	(161, 583, 2, NULL),
	(161, 584, 3, NULL),
	(161, 586, NULL, NULL),
	(162, 120, NULL, NULL),
	(162, 590, NULL, NULL),
	(162, 591, NULL, NULL),
	(162, 592, NULL, NULL),
	(162, 593, NULL, NULL),
	(162, 594, NULL, NULL),
	(162, 595, NULL, NULL),
	(162, 596, NULL, NULL),
	(162, 597, NULL, NULL),
	(162, 598, NULL, NULL),
	(162, 599, NULL, NULL),
	(162, 600, NULL, NULL),
	(162, 601, 1, 1),
	(162, 642, NULL, NULL),
	(163, 323, 2, NULL),
	(163, 324, NULL, NULL),
	(163, 601, 1, NULL),
	(164, 601, 2, NULL),
	(164, 602, NULL, NULL),
	(164, 603, NULL, 1),
	(164, 628, 1, NULL),
	(165, 406, NULL, NULL),
	(165, 471, 2, NULL),
	(165, 582, NULL, NULL),
	(165, 603, 1, NULL),
	(165, 604, NULL, NULL),
	(165, 605, NULL, NULL),
	(166, 415, 2, NULL),
	(166, 608, 1, NULL),
	(167, 415, 2, NULL),
	(167, 606, 1, NULL),
	(168, 406, NULL, NULL),
	(168, 415, 2, NULL),
	(168, 471, 3, NULL),
	(168, 582, NULL, NULL),
	(168, 604, NULL, NULL),
	(168, 605, NULL, NULL),
	(168, 606, 1, NULL),
	(169, 406, NULL, NULL),
	(169, 415, 2, NULL),
	(169, 471, 3, NULL),
	(169, 582, NULL, NULL),
	(169, 604, NULL, NULL),
	(169, 605, NULL, NULL),
	(169, 608, 1, NULL),
	(170, 415, 2, NULL),
	(170, 609, 1, NULL),
	(171, 406, NULL, NULL),
	(171, 415, 2, NULL),
	(171, 471, 3, NULL),
	(171, 582, NULL, NULL),
	(171, 604, NULL, NULL),
	(171, 605, NULL, NULL),
	(171, 609, 1, NULL),
	(172, 319, NULL, NULL),
	(172, 355, 1, NULL),
	(172, 590, NULL, NULL),
	(172, 591, NULL, NULL),
	(172, 592, NULL, NULL),
	(172, 595, NULL, NULL),
	(172, 597, NULL, NULL),
	(172, 598, NULL, NULL),
	(172, 599, NULL, NULL),
	(172, 600, NULL, NULL),
	(172, 607, NULL, NULL),
	(172, 608, NULL, 1),
	(172, 651, 2, NULL),
	(173, 319, NULL, NULL),
	(173, 595, NULL, NULL),
	(173, 597, NULL, NULL),
	(173, 598, NULL, NULL),
	(173, 599, NULL, NULL),
	(173, 600, NULL, NULL),
	(173, 606, 1, 1),
	(173, 614, NULL, NULL),
	(173, 651, NULL, NULL),
	(173, 716, NULL, NULL),
	(174, 323, 2, NULL),
	(174, 324, NULL, NULL),
	(174, 606, 1, NULL),
	(175, 323, 2, NULL),
	(175, 324, NULL, NULL),
	(175, 608, 1, NULL),
	(176, 319, NULL, NULL),
	(176, 595, NULL, NULL),
	(176, 597, NULL, NULL),
	(176, 598, NULL, NULL),
	(176, 599, NULL, NULL),
	(176, 600, NULL, NULL),
	(176, 609, 1, 1),
	(176, 614, NULL, NULL),
	(176, 651, NULL, NULL),
	(176, 716, NULL, NULL),
	(177, 323, 2, NULL),
	(177, 324, NULL, NULL),
	(177, 609, 1, NULL),
	(178, 410, 1, NULL),
	(178, 628, NULL, 1),
	(178, 642, 2, NULL),
	(179, 323, 2, NULL),
	(179, 324, NULL, NULL),
	(179, 628, 1, NULL),
	(180, 172, NULL, NULL),
	(180, 629, NULL, NULL),
	(180, 630, NULL, NULL),
	(180, 631, NULL, 1),
	(180, 632, 1, NULL),
	(180, 633, NULL, NULL),
	(180, 634, NULL, NULL),
	(180, 636, NULL, NULL),
	(180, 637, NULL, NULL),
	(180, 692, NULL, NULL),
	(181, 123, NULL, NULL),
	(181, 128, 1, NULL),
	(181, 442, NULL, NULL),
	(181, 638, 2, NULL),
	(181, 639, NULL, NULL),
	(181, 640, NULL, NULL),
	(181, 641, 3, NULL),
	(181, 642, NULL, 1),
	(181, 644, 4, NULL),
	(181, 645, NULL, NULL),
	(181, 647, NULL, NULL),
	(181, 649, NULL, NULL),
	(181, 651, NULL, NULL),
	(181, 654, NULL, NULL),
	(181, 674, NULL, NULL),
	(182, 323, 2, NULL),
	(182, 324, NULL, NULL),
	(182, 642, 1, NULL),
	(183, 113, NULL, NULL),
	(183, 133, NULL, NULL),
	(183, 164, NULL, NULL),
	(183, 351, NULL, NULL),
	(183, 368, NULL, NULL),
	(183, 448, NULL, NULL),
	(183, 454, NULL, NULL),
	(183, 464, NULL, NULL),
	(183, 524, NULL, NULL),
	(183, 646, 1, 1),
	(183, 651, NULL, NULL),
	(184, 314, 2, NULL),
	(184, 649, 1, NULL),
	(184, 714, 3, NULL),
	(185, 123, NULL, NULL),
	(185, 310, NULL, NULL),
	(185, 313, NULL, NULL),
	(185, 639, NULL, NULL),
	(185, 647, NULL, NULL),
	(185, 649, NULL, NULL),
	(185, 650, NULL, NULL),
	(185, 651, NULL, 1),
	(185, 652, NULL, NULL),
	(185, 653, 1, NULL),
	(185, 654, NULL, NULL),
	(185, 674, NULL, NULL),
	(186, 323, 2, NULL),
	(186, 324, NULL, NULL),
	(186, 651, 1, NULL),
	(187, 323, 3, NULL),
	(187, 324, NULL, NULL),
	(187, 415, 2, NULL),
	(187, 651, 1, NULL),
	(188, 663, NULL, NULL),
	(188, 664, NULL, NULL),
	(188, 665, 1, NULL),
	(188, 666, NULL, NULL),
	(189, 168, NULL, NULL),
	(189, 220, NULL, NULL),
	(189, 305, NULL, NULL),
	(189, 667, NULL, 1),
	(189, 668, 1, NULL),
	(190, 23, NULL, NULL),
	(190, 57, NULL, NULL),
	(190, 166, NULL, NULL),
	(190, 169, NULL, NULL),
	(190, 667, NULL, NULL),
	(190, 669, 1, 1),
	(190, 720, NULL, NULL),
	(191, 675, NULL, 1),
	(191, 676, 1, NULL),
	(192, 675, 1, NULL),
	(192, 684, 2, NULL),
	(193, 21, NULL, NULL),
	(193, 266, 2, NULL),
	(193, 675, 1, NULL),
	(194, 266, 2, NULL),
	(194, 477, 3, NULL),
	(194, 675, 1, NULL),
	(195, 266, NULL, NULL),
	(195, 675, 1, NULL),
	(196, 266, NULL, NULL),
	(196, 684, 1, NULL),
	(197, 103, NULL, NULL),
	(197, 678, NULL, NULL),
	(197, 679, NULL, NULL),
	(197, 680, NULL, NULL),
	(197, 681, NULL, NULL),
	(197, 682, NULL, NULL),
	(197, 683, NULL, NULL),
	(197, 684, NULL, 1),
	(197, 685, NULL, NULL),
	(197, 686, 1, NULL),
	(197, 687, NULL, NULL),
	(197, 688, NULL, NULL),
	(198, 689, NULL, NULL),
	(198, 690, NULL, 1),
	(198, 691, 1, NULL),
	(199, 694, NULL, NULL),
	(199, 695, NULL, NULL),
	(199, 696, NULL, 1),
	(199, 698, 1, NULL),
	(199, 700, NULL, NULL),
	(199, 701, NULL, NULL),
	(200, 9, NULL, NULL),
	(200, 13, NULL, NULL),
	(200, 122, NULL, NULL),
	(200, 391, NULL, NULL),
	(200, 665, NULL, NULL),
	(200, 696, 1, NULL),
	(200, 699, 2, NULL),
	(201, 13, 2, NULL),
	(201, 122, 4, NULL),
	(201, 391, 3, NULL),
	(201, 693, NULL, NULL),
	(201, 696, 1, NULL),
	(201, 697, NULL, NULL),
	(202, 649, NULL, NULL),
	(202, 715, 1, NULL),
	(202, 716, NULL, 1),
	(202, 717, NULL, NULL),
	(202, 766, NULL, NULL),
	(203, 714, 2, NULL),
	(203, 716, 1, NULL),
	(204, 720, NULL, 1),
	(204, 721, 1, NULL),
	(205, 131, NULL, NULL),
	(205, 702, 2, NULL),
	(205, 720, 1, NULL),
	(206, 722, NULL, NULL),
	(206, 723, NULL, 1),
	(206, 724, 1, NULL),
	(207, 99, 2, NULL),
	(207, 723, 1, NULL),
	(208, 515, 2, NULL),
	(208, 518, NULL, NULL),
	(208, 723, 1, NULL),
	(209, 488, NULL, NULL),
	(209, 492, NULL, NULL),
	(209, 723, 2, NULL),
	(209, 744, NULL, NULL),
	(209, 745, NULL, 1),
	(209, 746, NULL, NULL),
	(209, 747, 1, NULL),
	(209, 751, NULL, NULL),
	(210, 674, NULL, NULL),
	(210, 727, 2, NULL),
	(210, 728, NULL, NULL),
	(210, 729, NULL, 1),
	(210, 730, NULL, NULL),
	(210, 731, NULL, NULL),
	(210, 732, NULL, NULL),
	(210, 745, 1, NULL),
	(211, 140, NULL, NULL),
	(211, 266, NULL, NULL),
	(211, 312, NULL, NULL),
	(211, 442, NULL, NULL),
	(211, 729, NULL, NULL),
	(211, 733, NULL, NULL),
	(211, 734, NULL, NULL),
	(211, 735, NULL, NULL),
	(211, 736, 1, 1),
	(211, 737, NULL, NULL),
	(211, 738, NULL, NULL),
	(211, 739, NULL, NULL),
	(212, 355, 1, NULL),
	(212, 726, 3, NULL),
	(212, 736, 2, NULL),
	(212, 741, NULL, NULL),
	(212, 742, NULL, 1),
	(212, 743, NULL, NULL),
	(213, 406, NULL, NULL),
	(213, 471, 2, NULL),
	(213, 582, NULL, NULL),
	(213, 745, 1, NULL),
	(213, 748, NULL, NULL),
	(213, 749, NULL, NULL),
	(214, 222, NULL, NULL),
	(214, 745, 1, NULL),
	(214, 752, 2, NULL),
	(214, 753, 3, NULL),
	(215, 745, 1, NULL),
	(215, 755, 2, NULL),
	(215, 756, NULL, NULL),
	(216, 9, NULL, 1),
	(216, 10, 1, NULL),
	(217, 11, NULL, 1),
	(217, 12, 1, NULL),
	(217, 13, NULL, NULL),
	(217, 406, NULL, NULL),
	(218, 13, NULL, 1),
	(218, 14, 1, NULL),
	(219, 20, 1, NULL),
	(219, 21, NULL, 1),
	(220, 105, NULL, 1),
	(220, 106, 1, NULL),
	(221, 121, 1, NULL),
	(221, 122, NULL, 1),
	(222, 196, NULL, 1),
	(222, 197, 1, NULL),
	(223, 217, NULL, NULL),
	(223, 218, 1, 1),
	(224, 172, NULL, NULL),
	(224, 228, 1, NULL),
	(224, 229, NULL, 1),
	(225, 172, NULL, NULL),
	(225, 322, 1, NULL),
	(225, 323, NULL, 1),
	(226, 325, 1, NULL),
	(226, 326, NULL, 1),
	(227, 13, NULL, NULL),
	(227, 344, NULL, NULL),
	(227, 345, 1, NULL),
	(227, 346, NULL, 1),
	(227, 406, NULL, NULL),
	(228, 9, NULL, NULL),
	(228, 11, NULL, NULL),
	(228, 13, NULL, NULL),
	(228, 122, NULL, NULL),
	(228, 346, NULL, NULL),
	(228, 354, 1, NULL),
	(228, 355, NULL, 1),
	(228, 391, NULL, NULL),
	(228, 656, NULL, NULL),
	(228, 665, NULL, NULL),
	(229, 390, 1, NULL),
	(229, 391, NULL, 1),
	(229, 392, NULL, NULL),
	(230, 405, 1, NULL),
	(230, 406, NULL, 1),
	(231, 411, 1, NULL),
	(231, 412, NULL, 1),
	(232, 470, 1, NULL),
	(232, 471, NULL, 1),
	(233, 485, 1, NULL),
	(233, 486, NULL, 1),
	(234, 491, 1, NULL),
	(234, 492, NULL, 1),
	(235, 509, 1, NULL),
	(235, 510, NULL, 1),
	(236, 512, NULL, 1),
	(236, 513, 1, NULL),
	(237, 172, NULL, NULL),
	(237, 514, 1, NULL),
	(237, 515, NULL, 1),
	(238, 557, 1, NULL),
	(238, 558, NULL, 1),
	(239, 563, 1, NULL),
	(239, 564, NULL, 1),
	(240, 584, NULL, 1),
	(240, 585, 1, NULL),
	(241, 611, 1, NULL),
	(241, 612, NULL, 1),
	(242, 613, 1, NULL),
	(242, 614, NULL, 1),
	(242, 656, NULL, NULL),
	(243, 635, 1, NULL),
	(243, 636, NULL, 1),
	(244, 648, 1, NULL),
	(244, 649, NULL, 1),
	(245, 665, 1, 1),
	(245, 666, NULL, NULL),
	(246, 670, NULL, 1),
	(246, 671, 1, NULL),
	(247, 673, 1, NULL),
	(247, 674, NULL, 1),
	(248, 172, NULL, NULL),
	(248, 713, 1, NULL),
	(248, 714, NULL, 1),
	(248, 719, NULL, NULL),
	(249, 718, 1, NULL),
	(249, 719, NULL, 1),
	(250, 725, 1, NULL),
	(250, 726, NULL, 1),
	(251, 406, NULL, NULL),
	(251, 739, NULL, 1),
	(251, 740, 1, NULL),
	(252, 406, NULL, NULL),
	(252, 649, NULL, NULL),
	(252, 750, 1, NULL),
	(252, 751, NULL, 1),
	(253, 172, NULL, NULL),
	(253, 754, 1, NULL),
	(253, 755, NULL, 1),
	(254, 120, 1, NULL),
	(254, 763, 2, NULL),
	(254, 764, NULL, NULL),
	(255, 150, NULL, NULL),
	(255, 319, NULL, NULL),
	(255, 595, NULL, NULL),
	(255, 597, NULL, NULL),
	(255, 598, NULL, NULL),
	(255, 599, NULL, NULL),
	(255, 600, NULL, NULL),
	(255, 651, NULL, NULL),
	(255, 768, 1, 1),
	(255, 769, NULL, NULL),
	(256, 323, 2, NULL),
	(256, 324, NULL, NULL),
	(256, 768, 1, NULL),
	(257, 415, 2, NULL),
	(257, 768, 1, NULL),
	(258, 406, NULL, NULL),
	(258, 415, 2, NULL),
	(258, 471, 3, NULL),
	(258, 582, NULL, NULL),
	(258, 604, NULL, NULL),
	(258, 605, NULL, NULL),
	(258, 768, 1, NULL);
/*!40000 ALTER TABLE `tab_col` ENABLE KEYS */;

-- Dumping structure for table emcor.tab_type
CREATE TABLE IF NOT EXISTS `tab_type` (
  `tab_type_id` smallint(5) unsigned NOT NULL COMMENT 'Lentelių tipo identifikatorius',
  `tab_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Lentelių tipo pavadinimas',
  PRIMARY KEY (`tab_type_id`),
  UNIQUE KEY `tab_type_name_u` (`tab_type_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Lentelių tipai';

-- Dumping data for table emcor.tab_type: ~6 rows (approximately)
/*!40000 ALTER TABLE `tab_type` DISABLE KEYS */;
INSERT INTO `tab_type` (`tab_type_id`, `tab_type_name`) VALUES
	(2, 'Grupės'),
	(4, 'Kiti objektai'),
	(0, 'Sisteminė informacija'),
	(3, 'Surinkimo konfigūracija'),
	(5, 'Tarifai'),
	(1, 'Taškai');
/*!40000 ALTER TABLE `tab_type` ENABLE KEYS */;

-- Dumping structure for table emcor.tff
CREATE TABLE IF NOT EXISTS `tff` (
  `tff_id` tinyint(3) unsigned NOT NULL COMMENT 'Tarifo identifikatorius',
  `tff_name` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Tarifo pavadinimas',
  PRIMARY KEY (`tff_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Tarifų sąrašas';

-- Dumping data for table emcor.tff: ~100 rows (approximately)
/*!40000 ALTER TABLE `tff` DISABLE KEYS */;
INSERT INTO `tff` (`tff_id`, `tff_name`) VALUES
	(0, 'Netarifikuota'),
	(1, '1 tarifas'),
	(2, '2 tarifas'),
	(3, '3 tarifas'),
	(4, '4 tarifas'),
	(5, '5 tarifas'),
	(6, '6 tarifas'),
	(7, '7 tarifas'),
	(8, '8 tarifas'),
	(9, '9 tarifas'),
	(10, '10 tarifas'),
	(11, '11 tarifas'),
	(12, '12 tarifas'),
	(13, '13 tarifas'),
	(14, '14 tarifas'),
	(15, '15 tarifas'),
	(16, '16 tarifas'),
	(17, '17 tarifas'),
	(18, '18 tarifas'),
	(19, '19 tarifas'),
	(20, '20 tarifas'),
	(21, '21 tarifas'),
	(22, '22 tarifas'),
	(23, '23 tarifas'),
	(24, '24 tarifas'),
	(25, '25 tarifas'),
	(26, '26 tarifas'),
	(27, '27 tarifas'),
	(28, '28 tarifas'),
	(29, '29 tarifas'),
	(30, '30 tarifas'),
	(31, '31 tarifas'),
	(32, '32 tarifas'),
	(33, '33 tarifas'),
	(34, '34 tarifas'),
	(35, '35 tarifas'),
	(36, '36 tarifas'),
	(37, '37 tarifas'),
	(38, '38 tarifas'),
	(39, '39 tarifas'),
	(40, '40 tarifas'),
	(41, '41 tarifas'),
	(42, '42 tarifas'),
	(43, '43 tarifas'),
	(44, '44 tarifas'),
	(45, '45 tarifas'),
	(46, '46 tarifas'),
	(47, '47 tarifas'),
	(48, '48 tarifas'),
	(49, '49 tarifas'),
	(50, '50 tarifas'),
	(51, '51 tarifas'),
	(52, '52 tarifas'),
	(53, '53 tarifas'),
	(54, '54 tarifas'),
	(55, '55 tarifas'),
	(56, '56 tarifas'),
	(57, '57 tarifas'),
	(58, '58 tarifas'),
	(59, '59 tarifas'),
	(60, '60 tarifas'),
	(61, '61 tarifas'),
	(62, '62 tarifas'),
	(63, '63 tarifas'),
	(64, '64 tarifas'),
	(65, '65 tarifas'),
	(66, '66 tarifas'),
	(67, '67 tarifas'),
	(68, '68 tarifas'),
	(69, '69 tarifas'),
	(70, '70 tarifas'),
	(71, '71 tarifas'),
	(72, '72 tarifas'),
	(73, '73 tarifas'),
	(74, '74 tarifas'),
	(75, '75 tarifas'),
	(76, '76 tarifas'),
	(77, '77 tarifas'),
	(78, '78 tarifas'),
	(79, '79 tarifas'),
	(80, '80 tarifas'),
	(81, '81 tarifas'),
	(82, '82 tarifas'),
	(83, '83 tarifas'),
	(84, '84 tarifas'),
	(85, '85 tarifas'),
	(86, '86 tarifas'),
	(87, '87 tarifas'),
	(88, '88 tarifas'),
	(89, '89 tarifas'),
	(90, '90 tarifas'),
	(91, '91 tarifas'),
	(92, '92 tarifas'),
	(93, '93 tarifas'),
	(94, '94 tarifas'),
	(95, '95 tarifas'),
	(96, '96 tarifas'),
	(97, '97 tarifas'),
	(98, '98 tarifas'),
	(99, '99 tarifas');
/*!40000 ALTER TABLE `tff` ENABLE KEYS */;

-- Dumping structure for table emcor.tff_selected
CREATE TABLE IF NOT EXISTS `tff_selected` (
  `tff_id` tinyint(3) unsigned NOT NULL COMMENT 'Tarifo identifikatorius',
  `tff_name` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Tarifo pavadinimas',
  `tff_color` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Tarifo spalva',
  `tff_enabled` tinyint(1) NOT NULL COMMENT 'Tarifo naudojimo požymis',
  PRIMARY KEY (`tff_id`),
  CONSTRAINT `tff_selected_tff_fk` FOREIGN KEY (`tff_id`) REFERENCES `tff` (`tff_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Sistemoje naudojamų tarifų sąrašas';

-- Dumping data for table emcor.tff_selected: ~5 rows (approximately)
/*!40000 ALTER TABLE `tff_selected` DISABLE KEYS */;
INSERT INTO `tff_selected` (`tff_id`, `tff_name`, `tff_color`, `tff_enabled`) VALUES
	(0, NULL, '008000', 1),
	(1, 'Pikas (1 tarifas)', 'FF0000', 1),
	(2, 'Diena (2 tarifas)', '00FF00', 1),
	(3, 'Šventės (3 tarifas)', '8B4513', 1),
	(4, 'Naktis (4 tarifas)', '0000FF', 1);
/*!40000 ALTER TABLE `tff_selected` ENABLE KEYS */;

-- Dumping structure for table emcor.tmst
CREATE TABLE IF NOT EXISTS `tmst` (
  `tmst_code` varchar(80) COLLATE utf8_bin NOT NULL,
  `amp` datetime NOT NULL,
  `arg_1` int(10) unsigned DEFAULT NULL,
  PRIMARY KEY (`tmst_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Sistemos vykdomų foninių užduočių laiko žymės';

-- Dumping data for table emcor.tmst: ~26 rows (approximately)
/*!40000 ALTER TABLE `tmst` DISABLE KEYS */;
INSERT INTO `tmst` (`tmst_code`, `amp`, `arg_1`) VALUES
	('AUTO_ACT_INIT_GEN', '2017-04-02 21:00:00', NULL),
	('AUTO_DELETE_ALL_FROM_ATOM_DAS_LOG', '2016-12-23 21:30:00', NULL),
	('AUTO_DELETE_ALL_FROM_BGAO', '2017-03-03 21:30:00', NULL),
	('AUTO_DELETE_ALL_FROM_EV', '2017-01-02 21:30:00', NULL),
	('AUTO_DELETE_ALL_FROM_EVAH', '2017-01-02 00:00:00', NULL),
	('AUTO_DELETE_ALL_FROM_MAP_DATA', '2014-04-18 21:30:00', NULL),
	('AUTO_DELETE_ALL_FROM_RP_LOG', '2017-01-02 00:00:00', NULL),
	('AUTO_DELETE_ALL_FROM_SMS_LOG', '2016-12-03 21:30:00', NULL),
	('AUTO_DELETE_ALL_FROM_XO', '2016-11-03 21:30:00', NULL),
	('AUTO_DELETE_BGA_AUD_DATA', '2017-03-23 21:31:06', NULL),
	('AUTO_DELETE_FROM_EAPP_EDEV_PRQ_EE_LOG', '2017-03-03 21:30:00', NULL),
	('AUTO_DELETE_INVALID_FROM_DS_DATA', '2017-03-03 21:30:00', NULL),
	('AUTO_DELETE_INVALID_FROM_DW_DATA', '2017-02-01 21:30:00', NULL),
	('AUTO_DELETE_INVALID_FROM_PL_DATA', '2017-03-03 21:30:00', NULL),
	('AUTO_DELETE_INVALID_FROM_PW_DATA', '2017-02-01 21:30:00', NULL),
	('AUTO_DELETE_REPEATED_DS_DATA', '2017-01-22 21:00:00', NULL),
	('AUTO_PLUP_INIT_GEN', '2017-04-02 21:00:00', NULL),
	('AUTO_REL_INIT_GEN', '2017-04-02 21:00:00', NULL),
	('AUTO_UPDATE_SRC_FROM_TMPL', '2017-04-02 22:16:34', NULL),
	('AUTO_UPDATE_SRC_FROM_TMPL2', '2017-04-02 22:16:56', NULL),
	('CHECK_LOCKED_USERS', '2000-01-01 00:00:00', NULL),
	('INSERT_FORWARD_INTO_PLEP', '2017-04-03 00:00:00', NULL),
	('PLUP_DB_TIME_BOUND', '2017-04-02 22:00:22', NULL),
	('PL_DATA_SET_DB_TIME_TO_NULL', '2016-12-03 21:30:00', NULL),
	('PL_SE_POST_PROCESSING', '2016-03-03 09:11:14', NULL),
	('XF_SRC_UI', '2017-04-02 22:11:34', NULL);
/*!40000 ALTER TABLE `tmst` ENABLE KEYS */;

-- Dumping structure for table emcor.tp
CREATE TABLE IF NOT EXISTS `tp` (
  `tp_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Tarifų plano identifikatorius',
  `tp_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Tarifų plano pavadinimas',
  `fixed_tff_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Tarifų plano pastovaus tarifo identifikatorius',
  `else_tff_id` tinyint(3) unsigned NOT NULL COMMENT 'Tarifų plano neatitikimų tarifo identifikatorius',
  `hld_id` mediumint(8) unsigned NOT NULL COMMENT 'Šventinių dienų rinkinio identifikatorius',
  PRIMARY KEY (`tp_id`),
  UNIQUE KEY `tp_name_u` (`tp_name`),
  KEY `tp_else_tff_i` (`else_tff_id`),
  KEY `tp_fixed_tff_i` (`fixed_tff_id`),
  KEY `tp_hld_i` (`hld_id`),
  CONSTRAINT `tp_else_tff_fk` FOREIGN KEY (`else_tff_id`) REFERENCES `tff` (`tff_id`),
  CONSTRAINT `tp_fixed_tff_fk` FOREIGN KEY (`fixed_tff_id`) REFERENCES `tff` (`tff_id`),
  CONSTRAINT `tp_hld_fk` FOREIGN KEY (`hld_id`) REFERENCES `hld` (`hld_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Tarifų planai';

-- Dumping data for table emcor.tp: ~0 rows (approximately)
/*!40000 ALTER TABLE `tp` DISABLE KEYS */;
/*!40000 ALTER TABLE `tp` ENABLE KEYS */;

-- Dumping structure for table emcor.tpp
CREATE TABLE IF NOT EXISTS `tpp` (
  `tpp_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Tarifų plano periodo identifikatorius',
  `tp_id` mediumint(8) unsigned NOT NULL COMMENT 'Tarifų plano identifikatorius',
  `bmm` tinyint(3) unsigned NOT NULL COMMENT 'Periodo pradžios mėnuo',
  `bdd` tinyint(3) unsigned NOT NULL COMMENT 'Periodo pradžios diena',
  `emm` tinyint(3) unsigned NOT NULL COMMENT 'Pabaigos mėnuo',
  `edd` tinyint(3) unsigned NOT NULL COMMENT 'Pabaigos diena',
  `wpr_id` mediumint(8) unsigned NOT NULL COMMENT 'Tarifų plano savaitės programos identifikatorius',
  PRIMARY KEY (`tpp_id`),
  UNIQUE KEY `tpp_tp_u` (`tp_id`,`bmm`,`bdd`,`emm`,`edd`),
  KEY `tpp_wpr_i` (`wpr_id`),
  CONSTRAINT `tpp_tp_fk` FOREIGN KEY (`tp_id`) REFERENCES `tp` (`tp_id`) ON DELETE CASCADE,
  CONSTRAINT `tpp_wpr_fk` FOREIGN KEY (`wpr_id`) REFERENCES `wpr` (`wpr_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Tarifų plano periodai';

-- Dumping data for table emcor.tpp: ~0 rows (approximately)
/*!40000 ALTER TABLE `tpp` DISABLE KEYS */;
/*!40000 ALTER TABLE `tpp` ENABLE KEYS */;

-- Dumping structure for table emcor.ts
CREATE TABLE IF NOT EXISTS `ts` (
  `ts_id` tinyint(1) NOT NULL COMMENT 'Paskirties požymis',
  `ts_name` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Išeities paskirties požymio pavadinimas',
  PRIMARY KEY (`ts_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Išeities paskirties požymiai';

-- Dumping data for table emcor.ts: ~2 rows (approximately)
/*!40000 ALTER TABLE `ts` DISABLE KEYS */;
INSERT INTO `ts` (`ts_id`, `ts_name`) VALUES
	(0, 'Išeities rodiklis'),
	(1, 'Paskirties rodiklis');
/*!40000 ALTER TABLE `ts` ENABLE KEYS */;

-- Dumping structure for table emcor.tz
CREATE TABLE IF NOT EXISTS `tz` (
  `tz_id` smallint(5) unsigned NOT NULL COMMENT 'Laiko zonos identifikatorius',
  `tz_code` varchar(30) COLLATE utf8_bin NOT NULL COMMENT 'Laiko zonos kodas',
  `tz_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Laiko zonos pavadinimas',
  `tz_winter_offset` varchar(30) COLLATE utf8_bin NOT NULL COMMENT 'Atitraukimas iki zonos žiemos laiko',
  `tz_winter_tzd` varchar(10) COLLATE utf8_bin NOT NULL COMMENT 'Žiemos laiko papildomas kodas',
  `tz_summer_tzd` varchar(10) COLLATE utf8_bin NOT NULL COMMENT 'Vasaros laiko papildomas kodas',
  PRIMARY KEY (`tz_id`),
  UNIQUE KEY `tz_code_u` (`tz_code`),
  UNIQUE KEY `tz_name_u` (`tz_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Laiko zonos';

-- Dumping data for table emcor.tz: ~2 rows (approximately)
/*!40000 ALTER TABLE `tz` DISABLE KEYS */;
INSERT INTO `tz` (`tz_id`, `tz_code`, `tz_name`, `tz_winter_offset`, `tz_winter_tzd`, `tz_summer_tzd`) VALUES
	(1, 'Europe/Vilnius', 'Lietuvos laikas', '+02:00', 'EET', 'EEST'),
	(2, 'UTC', 'UTC', ' 00:00', 'GMT', 'GMT');
/*!40000 ALTER TABLE `tz` ENABLE KEYS */;

-- Dumping structure for table emcor.ug
CREATE TABLE IF NOT EXISTS `ug` (
  `ug_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Vartotojų grupės identifikatorius',
  `ug_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Vartotojų grupės pavadinimas',
  PRIMARY KEY (`ug_id`),
  UNIQUE KEY `ug_name_u` (`ug_name`)
) ENGINE=InnoDB AUTO_INCREMENT=62 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Vartotojų grupės';

-- Dumping data for table emcor.ug: ~2 rows (approximately)
/*!40000 ALTER TABLE `ug` DISABLE KEYS */;
INSERT INTO `ug` (`ug_id`, `ug_name`) VALUES
	(8, 'Administratoriai'),
	(61, 'Vartotojai be apribojimų pagal taškus');
/*!40000 ALTER TABLE `ug` ENABLE KEYS */;

-- Dumping structure for table emcor.ugr
CREATE TABLE IF NOT EXISTS `ugr` (
  `ug_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojų grupės identifikatorius',
  `gr_id` int(10) unsigned DEFAULT NULL COMMENT 'Grupės identifikatorius',
  `algr_id` tinyint(3) unsigned NOT NULL COMMENT 'Grupių prieigos lygio identifikatorius',
  UNIQUE KEY `ugr_ug_i` (`ug_id`,`gr_id`),
  KEY `ugr_algr_i` (`algr_id`),
  KEY `ugr_gr_i` (`gr_id`),
  CONSTRAINT `ugr_algr_fk` FOREIGN KEY (`algr_id`) REFERENCES `algr` (`algr_id`) ON DELETE CASCADE,
  CONSTRAINT `ugr_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE,
  CONSTRAINT `ugr_ug_fk` FOREIGN KEY (`ug_id`) REFERENCES `ug` (`ug_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Vartotojų grupėms pasiekiamos taškų grupės';

-- Dumping data for table emcor.ugr: ~2 rows (approximately)
/*!40000 ALTER TABLE `ugr` DISABLE KEYS */;
INSERT INTO `ugr` (`ug_id`, `gr_id`, `algr_id`) VALUES
	(8, NULL, 3),
	(61, NULL, 2);
/*!40000 ALTER TABLE `ugr` ENABLE KEYS */;

-- Dumping structure for table emcor.ugrole
CREATE TABLE IF NOT EXISTS `ugrole` (
  `ug_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojų grupės identifikatorius',
  `gr_id` int(10) unsigned DEFAULT NULL COMMENT 'Grupės identifikatorius',
  `role` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Redagavimo rolė',
  UNIQUE KEY `ugrole_u` (`ug_id`,`gr_id`,`role`),
  KEY `ugrole_gr_fk` (`gr_id`),
  CONSTRAINT `ugrole_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE,
  CONSTRAINT `ugrole_ug_fk` FOREIGN KEY (`ug_id`) REFERENCES `ug` (`ug_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Vartotojų grupėms pasiekiamų taškų grupių redagavimo rolės';

-- Dumping data for table emcor.ugrole: ~2 rows (approximately)
/*!40000 ALTER TABLE `ugrole` DISABLE KEYS */;
INSERT INTO `ugrole` (`ug_id`, `gr_id`, `role`) VALUES
	(8, NULL, NULL),
	(61, NULL, NULL);
/*!40000 ALTER TABLE `ugrole` ENABLE KEYS */;

-- Dumping structure for table emcor.ug_data
CREATE TABLE IF NOT EXISTS `ug_data` (
  `ug_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojų grupės identifikatorius',
  `user_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojo identifikatorius',
  PRIMARY KEY (`ug_id`,`user_id`),
  KEY `ug_data_user_i` (`user_id`,`ug_id`),
  CONSTRAINT `ug_data_ug_fk` FOREIGN KEY (`ug_id`) REFERENCES `ug` (`ug_id`) ON DELETE CASCADE,
  CONSTRAINT `ug_data_user_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Vartotojų grupių sudėtis';

-- Dumping data for table emcor.ug_data: ~2 rows (approximately)
/*!40000 ALTER TABLE `ug_data` DISABLE KEYS */;
INSERT INTO `ug_data` (`ug_id`, `user_id`) VALUES
	(8, 0),
	(8, 1);
/*!40000 ALTER TABLE `ug_data` ENABLE KEYS */;

-- Dumping structure for table emcor.ug_root
CREATE TABLE IF NOT EXISTS `ug_root` (
  `ug_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojų grupės identifikatorius',
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  PRIMARY KEY (`ug_id`),
  KEY `ug_root_gr_i` (`gr_id`),
  CONSTRAINT `ug_root_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE,
  CONSTRAINT `ug_root_ug_fk` FOREIGN KEY (`ug_id`) REFERENCES `ug` (`ug_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Vartotojų grupių šakninės grupės';

-- Dumping data for table emcor.ug_root: ~0 rows (approximately)
/*!40000 ALTER TABLE `ug_root` DISABLE KEYS */;
/*!40000 ALTER TABLE `ug_root` ENABLE KEYS */;

-- Dumping structure for table emcor.users
CREATE TABLE IF NOT EXISTS `users` (
  `user_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojo identifikatorius',
  `dbu` varchar(30) COLLATE utf8_bin NOT NULL COMMENT 'Sistemos vartotojo DB vartotojo vardas',
  `user_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Sistemos vartotojo vardas, pavardė',
  `user_email` varchar(50) COLLATE utf8_bin DEFAULT NULL COMMENT 'Sistemos vartotojo elektroninio pašto adresas',
  `user_phone` varchar(50) COLLATE utf8_bin DEFAULT NULL COMMENT 'Sistemos vartotojo telefono numeris',
  `user_location` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Sistemos vartotojo vieta',
  `user_gsm` varchar(50) COLLATE utf8_bin DEFAULT NULL COMMENT 'Sistemos vartotojo mobilaus telefono numeris',
  `user_company` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Sistemos vartotojo organizacija',
  `user_department` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Sistemos vartotojo skyrius',
  `user_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Vartotojo galiojimo požymis',
  `user_sms_limit` mediumint(8) unsigned DEFAULT NULL COMMENT 'Mėnesinis SMS pranešimų limitas sistemos vartotojui',
  `user_deleted` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Vartotojo egzistavimo požymis',
  PRIMARY KEY (`user_id`),
  UNIQUE KEY `users_dbu_u` (`dbu`),
  UNIQUE KEY `users_name_u` (`user_name`),
  KEY `users_user_gsm_i` (`user_gsm`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Sistemos vartotojai';

-- Dumping data for table emcor.users: ~2 rows (approximately)
/*!40000 ALTER TABLE `users` DISABLE KEYS */;
INSERT INTO `users` (`user_id`, `dbu`, `user_name`, `user_email`, `user_phone`, `user_location`, `user_gsm`, `user_company`, `user_department`, `user_enabled`, `user_sms_limit`, `user_deleted`) VALUES
	(0, 'EMCOS', 'System user EMCOS', NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0),
	(1, 'SUPERVISOR', 'Supervisor', NULL, NULL, NULL, NULL, NULL, NULL, 1, NULL, 0);
/*!40000 ALTER TABLE `users` ENABLE KEYS */;

-- Dumping structure for table emcor.user_root
CREATE TABLE IF NOT EXISTS `user_root` (
  `user_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojo identifikatorius',
  `gr_id` int(10) unsigned NOT NULL COMMENT 'Grupės identifikatorius',
  PRIMARY KEY (`user_id`),
  KEY `user_root_gr_i` (`gr_id`),
  CONSTRAINT `user_root_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE,
  CONSTRAINT `user_root_user_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Vartotojų šakninės grupės';

-- Dumping data for table emcor.user_root: ~0 rows (approximately)
/*!40000 ALTER TABLE `user_root` DISABLE KEYS */;
/*!40000 ALTER TABLE `user_root` ENABLE KEYS */;

-- Dumping structure for table emcor.utl
CREATE TABLE IF NOT EXISTS `utl` (
  `req_type_code` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Užklausų tipo kodas',
  `rodo_id` int(10) unsigned NOT NULL COMMENT 'Užsakymo ID',
  PRIMARY KEY (`rodo_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Skubių ryšio užduočių eilė';

-- Dumping data for table emcor.utl: ~0 rows (approximately)
/*!40000 ALTER TABLE `utl` DISABLE KEYS */;
/*!40000 ALTER TABLE `utl` ENABLE KEYS */;

-- Dumping structure for table emcor.utl_das
CREATE TABLE IF NOT EXISTS `utl_das` (
  `rodo_id` int(10) unsigned NOT NULL COMMENT 'Užsakymo ID',
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  `db_time` datetime DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  PRIMARY KEY (`rodo_id`,`das_id`),
  KEY `utl_das_das_fk` (`das_id`),
  CONSTRAINT `utl_das_das_fk` FOREIGN KEY (`das_id`) REFERENCES `das` (`das_id`) ON DELETE CASCADE,
  CONSTRAINT `utl_das_utl_fk` FOREIGN KEY (`rodo_id`) REFERENCES `utl` (`rodo_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų surinkimo serverių nuskaitytos skubių ryšio užduočių eilės užduotys';

-- Dumping data for table emcor.utl_das: ~0 rows (approximately)
/*!40000 ALTER TABLE `utl_das` DISABLE KEYS */;
/*!40000 ALTER TABLE `utl_das` ENABLE KEYS */;

-- Dumping structure for table emcor.uv
CREATE TABLE IF NOT EXISTS `uv` (
  `uv_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Sistemos vartotojų pasirinkimų rinkinio identifikatorius',
  `user_id` mediumint(8) unsigned NOT NULL COMMENT 'Vartotojo identifikatorius',
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `uv_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Sistemos vartotojų pasirinkimų rinkinio pavadinimas',
  `uv_public` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Viešo sistemos vartotojų pasirinkimų rinkinio požymis',
  `uv_module` varchar(80) COLLATE utf8_bin NOT NULL COMMENT 'Modulio pavadinimas',
  `uv_type` varchar(80) COLLATE utf8_bin NOT NULL COMMENT 'Sistemos vartotojų pasirinkimų rinkinių tipas',
  `uv_tech_info` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Sistemos vartotojų pasirinkimų rinkinio technologinė informacija',
  `uv_data` longtext COLLATE utf8_bin DEFAULT NULL COMMENT 'Sistemos vartotojų pasirinkimų rinkinio duomenys',
  `uv_subtype` varchar(80) COLLATE utf8_bin DEFAULT NULL COMMENT 'Sistemos vartotojų pasirinkimų rinkinių potipis',
  PRIMARY KEY (`uv_id`),
  KEY `uv_user_i` (`user_id`,`uv_type`,`uv_module`,`uv_subtype`),
  CONSTRAINT `uv_user_fk` FOREIGN KEY (`user_id`) REFERENCES `users` (`user_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Sistemos vartotojų pasirinkimų rinkiniai';

-- Dumping data for table emcor.uv: ~0 rows (approximately)
/*!40000 ALTER TABLE `uv` DISABLE KEYS */;
/*!40000 ALTER TABLE `uv` ENABLE KEYS */;

-- Dumping structure for table emcor.vapp
CREATE TABLE IF NOT EXISTS `vapp` (
  `vapp_time` datetime NOT NULL COMMENT 'Aplikacijos voko sukūrimo laikas',
  `vapp_nr` mediumint(8) unsigned NOT NULL COMMENT 'Aplikacijos voko numeris',
  `vapp_otime` datetime NOT NULL COMMENT 'Aplikacijos voko operacijos laikas',
  `vs_id` tinyint(3) unsigned NOT NULL COMMENT 'Voko būsenos identifikatorius',
  `sch_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Tvarkaraščio ID',
  `rodo_id` int(10) unsigned DEFAULT NULL COMMENT 'Užsakymo ID',
  PRIMARY KEY (`vapp_time`,`vapp_nr`),
  KEY `vapp_otime_i` (`vapp_otime`),
  KEY `vapp_rodo_i` (`rodo_id`),
  KEY `vapp_sch_i` (`sch_id`),
  KEY `vapp_vs_i` (`vs_id`),
  CONSTRAINT `vapp_sch_fk` FOREIGN KEY (`sch_id`) REFERENCES `sch` (`sch_id`) ON DELETE SET NULL,
  CONSTRAINT `vapp_vs_fk` FOREIGN KEY (`vs_id`) REFERENCES `vs` (`vs_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Aplikacijos vokai';

-- Dumping data for table emcor.vapp: ~0 rows (approximately)
/*!40000 ALTER TABLE `vapp` DISABLE KEYS */;
/*!40000 ALTER TABLE `vapp` ENABLE KEYS */;

-- Dumping structure for table emcor.vapp_log
CREATE TABLE IF NOT EXISTS `vapp_log` (
  `vapp_time` datetime NOT NULL COMMENT 'Aplikacijos voko sukūrimo laikas',
  `vapp_nr` mediumint(8) unsigned NOT NULL COMMENT 'Aplikacijos voko numeris',
  `vapp_otime` datetime NOT NULL COMMENT 'Aplikacijos voko operacijos laikas',
  `vs_id` tinyint(3) unsigned NOT NULL COMMENT 'Voko būsenos identifikatorius',
  PRIMARY KEY (`vapp_time`,`vapp_nr`,`vapp_otime`,`vs_id`),
  KEY `vapp_log_vs_fk` (`vs_id`),
  CONSTRAINT `vapp_log_vs_fk` FOREIGN KEY (`vs_id`) REFERENCES `vs` (`vs_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Aplikacijos vokų būsenų pasikeitimų istorija';

-- Dumping data for table emcor.vapp_log: ~0 rows (approximately)
/*!40000 ALTER TABLE `vapp_log` DISABLE KEYS */;
/*!40000 ALTER TABLE `vapp_log` ENABLE KEYS */;

-- Dumping structure for table emcor.vapp_reason
CREATE TABLE IF NOT EXISTS `vapp_reason` (
  `vapp_reason_id` mediumint(8) unsigned NOT NULL COMMENT 'Aplikacijos vokų priežasties identifikatorius',
  `vapp_reason_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Aplikacijos vokų priežasties kodas(SCH_ID, RODO_ID ...)',
  `vapp_reason_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Aplikacijos vokų priežasties pavadinimas',
  PRIMARY KEY (`vapp_reason_id`),
  UNIQUE KEY `vapp_reason_code_u` (`vapp_reason_code`),
  UNIQUE KEY `vapp_reason_name_u` (`vapp_reason_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Aplikacijos vokų priežastys';

-- Dumping data for table emcor.vapp_reason: ~2 rows (approximately)
/*!40000 ALTER TABLE `vapp_reason` DISABLE KEYS */;
INSERT INTO `vapp_reason` (`vapp_reason_id`, `vapp_reason_code`, `vapp_reason_name`) VALUES
	(1, 'RODO', 'Nuskaitymų pagal pareikalavimą užsakymai'),
	(2, 'SCH', 'Tvarkaraščiai');
/*!40000 ALTER TABLE `vapp_reason` ENABLE KEYS */;

-- Dumping structure for table emcor.vdev
CREATE TABLE IF NOT EXISTS `vdev` (
  `vdev_time` datetime NOT NULL COMMENT 'Prietaiso voko sukūrimo laikas',
  `vdev_nr` mediumint(8) unsigned NOT NULL COMMENT 'Prietaiso voko numeris',
  `vdp_time` datetime NOT NULL COMMENT 'Nuskaitymo taško voko sukūrimo laikas',
  `vdp_nr` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymo taško voko numeris',
  `vdp_vdev_nr` mediumint(8) unsigned NOT NULL COMMENT 'Prietaiso voko eilės numeris nuskaitymo taško voke',
  `vdev_otime` datetime NOT NULL COMMENT 'Prietaiso voko būsenos operacijos laikas',
  `vs_id` tinyint(3) unsigned NOT NULL COMMENT 'Voko būsenos identifikatorius',
  PRIMARY KEY (`vdev_time`,`vdev_nr`),
  KEY `vdev_otime_i` (`vdev_otime`),
  KEY `vdev_vdp_i` (`vdp_time`,`vdp_nr`),
  KEY `vdev_vdp_vdev_nr_i` (`vdp_vdev_nr`),
  KEY `vdev_vs_i` (`vs_id`),
  CONSTRAINT `vdev_vs_fk` FOREIGN KEY (`vs_id`) REFERENCES `vs` (`vs_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Prietaisų vokai';

-- Dumping data for table emcor.vdev: ~0 rows (approximately)
/*!40000 ALTER TABLE `vdev` DISABLE KEYS */;
/*!40000 ALTER TABLE `vdev` ENABLE KEYS */;

-- Dumping structure for table emcor.vdev_data
CREATE TABLE IF NOT EXISTS `vdev_data` (
  `vdev_time` datetime NOT NULL COMMENT 'Prietaiso voko sukūrimo laikas',
  `vdev_nr` mediumint(8) unsigned NOT NULL COMMENT 'Prietaiso voko numeris',
  `prq_time` datetime NOT NULL COMMENT 'Pirminės užklausos draiveriui laikas',
  `prq_nr` mediumint(8) unsigned NOT NULL COMMENT 'Pirminės užklausos draiveriui numeris',
  `prqs_id` smallint(5) unsigned NOT NULL COMMENT 'Pirminės užklausos būsenos identifikatorius',
  `sep_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
  `bt` datetime DEFAULT NULL COMMENT 'Periodo pradžia',
  `et` datetime DEFAULT NULL COMMENT 'Periodo pabaiga',
  `withe_id` mediumint(8) DEFAULT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `ind1` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
  `ind2` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
  `ind3` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
  `enr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus elemento numeris',
  `write2device` varchar(4000) COLLATE utf8_bin DEFAULT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo reikšmė',
  PRIMARY KEY (`vdev_time`,`vdev_nr`,`prq_time`,`prq_nr`),
  KEY `vdev_data_prqs_i` (`prqs_id`),
  KEY `vdev_data_sep_i` (`sep_id`),
  KEY `vdev_data_withe_i` (`withe_id`),
  CONSTRAINT `vdev_data_prqs_fk` FOREIGN KEY (`prqs_id`) REFERENCES `prqs` (`prqs_id`) ON DELETE CASCADE,
  CONSTRAINT `vdev_data_sep_fk` FOREIGN KEY (`sep_id`) REFERENCES `sep` (`sep_id`) ON DELETE CASCADE,
  CONSTRAINT `vdev_data_withe_fk` FOREIGN KEY (`withe_id`) REFERENCES `withe` (`withe_id`) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Prietaiso voko nuskaitoma pirminių užduočių informacija';

-- Dumping data for table emcor.vdev_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `vdev_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `vdev_data` ENABLE KEYS */;

-- Dumping structure for table emcor.vdev_dump
CREATE TABLE IF NOT EXISTS `vdev_dump` (
  `vdev_time` datetime NOT NULL COMMENT 'Prietaiso voko sukūrimo laikas',
  `vdev_nr` mediumint(8) unsigned NOT NULL COMMENT 'Prietaiso voko numeris',
  `vdev_step_nr` mediumint(8) unsigned NOT NULL COMMENT 'Prietaiso voko žingsnio numeris',
  `data` longtext COLLATE utf8_bin NOT NULL COMMENT 'Prietaiso voko detali informacija',
  PRIMARY KEY (`vdev_time`,`vdev_nr`),
  KEY `vdev_dump_vdev_step_nr_i` (`vdev_step_nr`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Prietaiso vokų detali informacija';

-- Dumping data for table emcor.vdev_dump: ~0 rows (approximately)
/*!40000 ALTER TABLE `vdev_dump` DISABLE KEYS */;
/*!40000 ALTER TABLE `vdev_dump` ENABLE KEYS */;

-- Dumping structure for table emcor.vdev_log
CREATE TABLE IF NOT EXISTS `vdev_log` (
  `vdev_time` datetime NOT NULL COMMENT 'Prietaiso voko sukūrimo laikas',
  `vdev_nr` mediumint(8) unsigned NOT NULL COMMENT 'Prietaiso voko numeris',
  `vdev_otime` datetime NOT NULL COMMENT 'Prietaiso voko būsenos operacijos laikas',
  `vs_id` tinyint(3) unsigned NOT NULL COMMENT 'Voko būsenos identifikatorius',
  PRIMARY KEY (`vdev_time`,`vdev_nr`,`vdev_otime`),
  KEY `vdev_log_vs_fk` (`vs_id`),
  CONSTRAINT `vdev_log_vs_fk` FOREIGN KEY (`vs_id`) REFERENCES `vs` (`vs_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Prietaisų vokų būsenų pasikeitimų istorija';

-- Dumping data for table emcor.vdev_log: ~0 rows (approximately)
/*!40000 ALTER TABLE `vdev_log` DISABLE KEYS */;
/*!40000 ALTER TABLE `vdev_log` ENABLE KEYS */;

-- Dumping structure for table emcor.vdev_step
CREATE TABLE IF NOT EXISTS `vdev_step` (
  `vdev_time` datetime NOT NULL COMMENT 'Prietaiso voko sukūrimo laikas',
  `vdev_nr` mediumint(8) unsigned NOT NULL COMMENT 'Prietaiso voko numeris',
  `vdev_step_nr` mediumint(8) unsigned NOT NULL COMMENT 'Prietaiso voko žingsnio numeris',
  `vdev_stime` datetime NOT NULL COMMENT 'Prietaiso voko žingsnio laikas',
  `vdev_step_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Prietaiso voko žingsnio tipo identifikatorius',
  `src_id` int(10) unsigned NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
  `ph_id` int(10) unsigned NOT NULL COMMENT 'Ryšio kanalo identifikatorius',
  `vdev_step_msg` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Prietaiso voko žingsnio pranešimas',
  PRIMARY KEY (`vdev_time`,`vdev_nr`,`vdev_step_nr`),
  KEY `vdev_step_ph_i` (`ph_id`),
  KEY `vdev_step_src_i` (`src_id`),
  KEY `vdev_step_vdev_step_type_i` (`vdev_step_type_id`),
  KEY `vdev_step_vdev_stime_i` (`vdev_stime`),
  CONSTRAINT `vdev_step_ph_fk` FOREIGN KEY (`ph_id`) REFERENCES `ph` (`ph_id`) ON DELETE CASCADE,
  CONSTRAINT `vdev_step_src_fk` FOREIGN KEY (`src_id`) REFERENCES `src` (`src_id`) ON DELETE CASCADE,
  CONSTRAINT `vdev_step_type_fk` FOREIGN KEY (`vdev_step_type_id`) REFERENCES `vdev_step_type` (`vdev_step_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Prietaiso voko vykdymo žingsniai';

-- Dumping data for table emcor.vdev_step: ~0 rows (approximately)
/*!40000 ALTER TABLE `vdev_step` DISABLE KEYS */;
/*!40000 ALTER TABLE `vdev_step` ENABLE KEYS */;

-- Dumping structure for table emcor.vdev_step_type
CREATE TABLE IF NOT EXISTS `vdev_step_type` (
  `vdev_step_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Prietaiso voko žingsnio tipo identifikatorius',
  `vdev_step_type_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Prietaiso voko žingsnio tipo kodas',
  `vdev_step_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Prietaiso voko žingsnio tipo pavadinimas',
  PRIMARY KEY (`vdev_step_type_id`),
  UNIQUE KEY `vdev_step_type_code_u` (`vdev_step_type_code`),
  UNIQUE KEY `vdev_step_type_name_u` (`vdev_step_type_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Prietaiso vokų žingsnių tipai';

-- Dumping data for table emcor.vdev_step_type: ~0 rows (approximately)
/*!40000 ALTER TABLE `vdev_step_type` DISABLE KEYS */;
/*!40000 ALTER TABLE `vdev_step_type` ENABLE KEYS */;

-- Dumping structure for table emcor.vdp
CREATE TABLE IF NOT EXISTS `vdp` (
  `vdp_time` datetime NOT NULL COMMENT 'Nuskaitymo taško voko sukūrimo laikas',
  `vdp_nr` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymo taško voko numeris',
  `dp_id` int(10) unsigned NOT NULL COMMENT 'Duomenų nuskaitymo taško identifikatorius',
  `vapp_time` datetime NOT NULL COMMENT 'Aplikacijos voko sukūrimo laikas',
  `vapp_nr` mediumint(8) unsigned NOT NULL COMMENT 'Aplikacijos voko numeris',
  `vdp_otime` datetime NOT NULL COMMENT 'Nuskaitymo taško voko būsenos operacijos laikas',
  `vs_id` tinyint(3) unsigned NOT NULL COMMENT 'Voko būsenos identifikatorius',
  PRIMARY KEY (`vdp_time`,`vdp_nr`),
  KEY `vdp_dp_i` (`dp_id`),
  KEY `vdp_otime_i` (`vdp_otime`),
  KEY `vdp_vapp_i` (`vapp_time`,`vapp_nr`),
  KEY `vdp_vs_i` (`vs_id`),
  CONSTRAINT `vdp_dp_fk` FOREIGN KEY (`dp_id`) REFERENCES `dp` (`dp_id`) ON DELETE CASCADE,
  CONSTRAINT `vdp_vs_fk` FOREIGN KEY (`vs_id`) REFERENCES `vs` (`vs_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitymo taškų vokai';

-- Dumping data for table emcor.vdp: ~0 rows (approximately)
/*!40000 ALTER TABLE `vdp` DISABLE KEYS */;
/*!40000 ALTER TABLE `vdp` ENABLE KEYS */;

-- Dumping structure for table emcor.vdp_log
CREATE TABLE IF NOT EXISTS `vdp_log` (
  `vdp_time` datetime NOT NULL COMMENT 'Nuskaitymo taško voko sukūrimo laikas',
  `vdp_nr` mediumint(8) unsigned NOT NULL COMMENT 'Nuskaitymo taško voko numeris',
  `vdp_otime` datetime NOT NULL COMMENT 'Nuskaitymo taško voko būsenos operacijos laikas',
  `vs_id` tinyint(3) unsigned NOT NULL COMMENT 'Voko būsenos identifikatorius',
  PRIMARY KEY (`vdp_time`,`vdp_nr`,`vdp_otime`),
  KEY `vdp_log_vs_fk` (`vs_id`),
  CONSTRAINT `vdp_log_vs_fk` FOREIGN KEY (`vs_id`) REFERENCES `vs` (`vs_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Nuskaitymo taškų vokų būsenų pasikeitimų istorija';

-- Dumping data for table emcor.vdp_log: ~0 rows (approximately)
/*!40000 ALTER TABLE `vdp_log` DISABLE KEYS */;
/*!40000 ALTER TABLE `vdp_log` ENABLE KEYS */;

-- Dumping structure for table emcor.verge
CREATE TABLE IF NOT EXISTS `verge` (
  `verge_id` smallint(5) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Kraštinės ID',
  `verge_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Kraštinės kodas',
  `verge_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Kraštinės pavadinimas',
  PRIMARY KEY (`verge_id`),
  UNIQUE KEY `verge_code_u` (`verge_code`),
  UNIQUE KEY `verge_name_u` (`verge_name`)
) ENGINE=InnoDB AUTO_INCREMENT=10 DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Kraštinės';

-- Dumping data for table emcor.verge: ~4 rows (approximately)
/*!40000 ALTER TABLE `verge` DISABLE KEYS */;
INSERT INTO `verge` (`verge_id`, `verge_code`, `verge_name`) VALUES
	(6, 'HIHI', 'Viršutinė avarinė riba'),
	(7, 'HI', 'Viršutinė įspėjamoji riba'),
	(8, 'LOLO', 'Apatinė avarinė riba'),
	(9, 'LO', 'Apatinė įspėjamoji riba');
/*!40000 ALTER TABLE `verge` ENABLE KEYS */;

-- Dumping structure for table emcor.version
CREATE TABLE IF NOT EXISTS `version` (
  `version_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Versijos kodas',
  `release_date` datetime DEFAULT NULL COMMENT 'Laidos data',
  `release_number` mediumint(8) unsigned DEFAULT NULL COMMENT 'Laidos numeris',
  UNIQUE KEY `version_code_u` (`version_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Programinės įrangos versija';

-- Dumping data for table emcor.version: ~0 rows (approximately)
/*!40000 ALTER TABLE `version` DISABLE KEYS */;
INSERT INTO `version` (`version_code`, `release_date`, `release_number`) VALUES
	('Emcos Corporate 2.1', '2017-02-12 00:00:00', 458);
/*!40000 ALTER TABLE `version` ENABLE KEYS */;

-- Dumping structure for table emcor.vp
CREATE TABLE IF NOT EXISTS `vp` (
  `vp_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Verifikacijos profilio identifikatorius',
  `vp_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Verifikacijos profilio kodas',
  `vp_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Verifikacijos profilio pavadinimas',
  `vp_bias` double NOT NULL DEFAULT 0.5 COMMENT 'Verifikacijos profilio maksimali leistinoji procentinė paklaida',
  `vp_separate_tff` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Verifikacijos profilio atskirų pagal tarifus tikrinimų požymis',
  `vp_smallest_interval` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Verifikacijos profilio tikrinimų taikymas tik smulkiausiems agregavimo segmento tipo intervalams',
  PRIMARY KEY (`vp_id`),
  UNIQUE KEY `vp_code_u` (`vp_code`),
  UNIQUE KEY `vp_name_u` (`vp_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Verifikacijos profiliai';

-- Dumping data for table emcor.vp: ~0 rows (approximately)
/*!40000 ALTER TABLE `vp` DISABLE KEYS */;
/*!40000 ALTER TABLE `vp` ENABLE KEYS */;

-- Dumping structure for table emcor.vp_data
CREATE TABLE IF NOT EXISTS `vp_data` (
  `vp_id` int(10) unsigned NOT NULL COMMENT 'Verifikacijos profilio identifikatorius',
  `vp_nr` mediumint(8) unsigned NOT NULL COMMENT 'Verifikacijos profilio sąlygos numeris',
  `aggs_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  `ms_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Matavimo identifikatorius',
  `dir_id` tinyint(4) DEFAULT NULL COMMENT 'Krypties identifikatorius',
  `aggf_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Agregavimo funkcijos identifikatorius',
  `tff_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Tarifo identifikatorius',
  PRIMARY KEY (`vp_id`,`vp_nr`),
  KEY `vp_data_aggf_fk` (`aggf_id`),
  KEY `vp_data_aggs_type_fk` (`aggs_type_id`),
  KEY `vp_data_dir_fk` (`dir_id`),
  KEY `vp_data_ms_fk` (`ms_id`),
  KEY `vp_data_tff_fk` (`tff_id`),
  CONSTRAINT `vp_data_aggf_fk` FOREIGN KEY (`aggf_id`) REFERENCES `aggf` (`aggf_id`) ON DELETE CASCADE,
  CONSTRAINT `vp_data_aggs_type_fk` FOREIGN KEY (`aggs_type_id`) REFERENCES `aggs_type` (`aggs_type_id`) ON DELETE CASCADE,
  CONSTRAINT `vp_data_dir_fk` FOREIGN KEY (`dir_id`) REFERENCES `dir` (`dir_id`) ON DELETE CASCADE,
  CONSTRAINT `vp_data_ms_fk` FOREIGN KEY (`ms_id`) REFERENCES `ms` (`ms_id`) ON DELETE CASCADE,
  CONSTRAINT `vp_data_tff_fk` FOREIGN KEY (`tff_id`) REFERENCES `tff` (`tff_id`) ON DELETE CASCADE,
  CONSTRAINT `vp_data_vp_fk` FOREIGN KEY (`vp_id`) REFERENCES `vp` (`vp_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Verifikacijos profilių duomenys';

-- Dumping data for table emcor.vp_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `vp_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `vp_data` ENABLE KEYS */;

-- Dumping structure for table emcor.vp_scalar
CREATE TABLE IF NOT EXISTS `vp_scalar` (
  `vp_id` int(10) unsigned NOT NULL COMMENT 'Verifikacijos profilio identifikatorius',
  `aggs_type_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
  `ms_id` smallint(5) unsigned NOT NULL COMMENT 'Matavimo identifikatorius',
  `dir_id` tinyint(4) NOT NULL COMMENT 'Krypties identifikatorius',
  `vp_allowed_scalar_error` double DEFAULT NULL COMMENT 'Maksimali leistina skaliarinė paklaida, kai viršijama procentinė paklaida',
  `vp_max_scalar_error` double DEFAULT NULL COMMENT 'Maksimali leistina skaliarinė paklaida, kai neviršijama procentinė paklaida',
  PRIMARY KEY (`vp_id`,`aggs_type_id`,`ms_id`,`dir_id`),
  CONSTRAINT `vp_scalar_vp_fk` FOREIGN KEY (`vp_id`) REFERENCES `vp` (`vp_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Verifikacijos profilių skaliarinių paklaidų informacija';

-- Dumping data for table emcor.vp_scalar: ~0 rows (approximately)
/*!40000 ALTER TABLE `vp_scalar` DISABLE KEYS */;
/*!40000 ALTER TABLE `vp_scalar` ENABLE KEYS */;

-- Dumping structure for table emcor.vs
CREATE TABLE IF NOT EXISTS `vs` (
  `vs_id` tinyint(3) unsigned NOT NULL COMMENT 'Voko būsenos identifikatorius',
  `vs_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Voko būsenos kodas',
  `vs_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Voko būsenos pavadinimas',
  PRIMARY KEY (`vs_id`),
  UNIQUE KEY `vs_code_u` (`vs_code`),
  UNIQUE KEY `vs_name_u` (`vs_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Vokų būsenos';

-- Dumping data for table emcor.vs: ~7 rows (approximately)
/*!40000 ALTER TABLE `vs` DISABLE KEYS */;
INSERT INTO `vs` (`vs_id`, `vs_code`, `vs_name`) VALUES
	(1, 'CREATED', 'Sukurta'),
	(2, 'DELAYED', 'Atidėta'),
	(3, 'RUNNING', 'Vykdoma'),
	(4, 'CONTINUED', 'Pratęsta'),
	(5, 'CANCELLED', 'Atšaukta'),
	(6, 'REJECTED', 'Atmesta'),
	(7, 'DONE', 'Baigta');
/*!40000 ALTER TABLE `vs` ENABLE KEYS */;

-- Dumping structure for table emcor.withe
CREATE TABLE IF NOT EXISTS `withe` (
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  `withe_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų vytelės kodas',
  `withe_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų vytelės pavadinimas',
  `withe_type_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų vytelių tipo identifikatorius',
  `withe_normal_state` tinyint(1) DEFAULT NULL COMMENT 'Normali duomenų vytelės būsena',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  `withe_dtype_id` tinyint(3) unsigned NOT NULL COMMENT 'Duomenų vytelių duomenų tipo identifikatorius',
  `eu_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Matavimo vienetų identifikatorius',
  PRIMARY KEY (`withe_id`),
  UNIQUE KEY `withe_code_u` (`withe_code`),
  UNIQUE KEY `withe_name_u` (`withe_name`),
  KEY `withe_enum_i` (`enum_id`),
  KEY `withe_withe_dtype_i` (`withe_dtype_id`),
  KEY `withe_withe_type_i` (`withe_type_id`),
  CONSTRAINT `withe_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`),
  CONSTRAINT `withe_withe_dtype_fk` FOREIGN KEY (`withe_dtype_id`) REFERENCES `withe_dtype` (`withe_dtype_id`),
  CONSTRAINT `withe_withe_type_fk` FOREIGN KEY (`withe_type_id`) REFERENCES `withe_type` (`withe_type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų vytelės';

-- Dumping data for table emcor.withe: ~2 150 rows (approximately)
/*!40000 ALTER TABLE `withe` DISABLE KEYS */;
INSERT INTO `withe` (`withe_id`, `withe_code`, `withe_name`, `withe_type_id`, `withe_normal_state`, `enum_id`, `withe_dtype_id`, `eu_id`) VALUES
	(-50950, 'ACFaultFixTime_ms ', 'Maitinimo dingimo trukmė (msek)', 15, NULL, NULL, 5, 81),
	(-50949, 'ACFaultServer3 ', 'Serverio (Nr.3) IP adresas, į kurį siunčiami maitinimo dingimo pranešimai', 22, NULL, NULL, 5, NULL),
	(-50948, 'ACFaultServer2 ', 'Serverio (Nr.2) IP adresas, į kurį siunčiami maitinimo dingimo pranešimai', 22, NULL, NULL, 5, NULL),
	(-50946, 'CLOut1107InitPortBaudRate ', 'Skaitiklio sąsajos (CL out) IEC1107 protokolo srovinės kilpos pradinis greitis', 22, NULL, NULL, 5, NULL),
	(-50945, 'SetTariffsResult', 'Tarifų patikros/įrašymo rezultatas', 17, NULL, NULL, 5, NULL),
	(-50944, 'SetTariffsDate', 'Tarifų patikros/įrašymo data', 17, NULL, NULL, 5, NULL),
	(-50943, 'RelaysState', 'Relės būsena', 18, NULL, NULL, 5, NULL),
	(-50942, 'RecalculationKf', 'Perskaičiavimo koeficientas', 19, NULL, NULL, 5, NULL),
	(-50941, 'HolidayTariffing', 'Išeiginių dienų tarifikacija', 17, NULL, NULL, 5, NULL),
	(-50940, 'HolidayTariffWrite', 'Išeiginių dienų tarifikacijos įrašymas', 17, NULL, NULL, 5, NULL),
	(-50939, 'TariffWriteNr', 'Tarifų tvarkaraščio numeris', 17, NULL, NULL, 5, NULL),
	(-50938, 'TariffWrite', 'Tarifo įrašymas', 17, NULL, NULL, 5, NULL),
	(-50937, 'TariffTest', 'Tarifo patikra', 17, NULL, NULL, 5, NULL),
	(-50936, 'PassiveTariffNr', 'Tarifo numeris priskirtas rezerviniam tarifiniam tvarkaraščiui', 17, NULL, NULL, 5, NULL),
	(-50935, 'ActiveTariffNr', 'Tarifo numeris priskirtas esamam tarifiniam tvarkaraščiui', 17, NULL, NULL, 5, NULL),
	(-50934, 'TariffMode_Time_Am', 'Tarifikacijos režimas. Pagal generuojamos aktyvinės energijos laikines zonas', 17, NULL, 82, 5, NULL),
	(-50933, 'TariffMode_External_Am', 'Tarifikacijos režimas. Išorinis generuojamai aktyvinei energijai', 17, NULL, 82, 5, NULL),
	(-50932, 'TariffMode_Event_Am', 'Tarifikacijos režimas. Pagal aktyvinės generuojamos energijos įvykius', 17, NULL, 82, 5, NULL),
	(-50931, 'TariffMode_Time_Ap', 'Tarifikacijos režimas. Pagal vartojamos aktyvinės energijos laikines zonas', 17, NULL, 82, 5, NULL),
	(-50930, 'TariffMode_External_Ap', 'Tarifikacijos režimas. Išorinis aktyvinei vartojamai energijai', 17, NULL, 82, 5, NULL),
	(-50929, 'TariffMode_Event_Ap', 'Tarifikacijos režimas. Pagal aktyvinės vartojamos energijos įvykius', 17, NULL, 82, 5, NULL),
	(-50928, 'GroupSeasonNr', 'Sezonų grupių numeris', 17, NULL, NULL, 5, NULL),
	(-50927, 'GroupSeasonChangeDate', 'Sezonų grupių keitimo data', 17, NULL, NULL, 5, NULL),
	(-50926, 'GroupSeasonChangeStatus', 'Leidžiamas sezonų grupės keitimas', 17, NULL, 82, 5, NULL),
	(-50925, 'MWDI_CurrentStatus', 'Skaitmeninio skaitiklio dabartinė būklė', 7, NULL, NULL, 5, NULL),
	(-50924, 'MWDI_Version', 'Skaitmeninio skaitiklio versija', 7, NULL, NULL, 5, NULL),
	(-50923, 'Serial_Number_Primary_Meter', 'Pirminio matuoklio serijinis numeris', 24, NULL, NULL, 5, NULL),
	(-50922, 'Serial_Number_Secondary_Calculator', 'Antrinio skaitiklio serijinis numeris', 24, NULL, NULL, 5, NULL),
	(-50921, 'PC_DataIndex', 'Profilio kanalo indeksas', 16, NULL, NULL, 5, NULL),
	(-50920, 'PC_Attribute', 'Profilio kanalo atributo numeris', 16, NULL, NULL, 5, NULL),
	(-50919, 'PC_Class_ID', 'Profilio kanalo klasės tipas', 16, NULL, NULL, 5, NULL),
	(-50918, 'PC_OBIS', 'Profilio kanalo OBIS kodas', 16, NULL, NULL, 5, NULL),
	(-50917, 'BetweenPackPause', 'IEC1142 pauzė tarp paketų', 22, NULL, NULL, 5, NULL),
	(-50916, 'BetweenBytePause', 'IEC1142 pauzė tarp baitų', 22, NULL, NULL, 5, NULL),
	(-50915, 'BetweenPackFactor_M', 'IEC1142 pauzės tarp paketų daugiklis M', 22, NULL, NULL, 5, NULL),
	(-50914, 'BetweenByteFactor_M', 'IEC1142 pauzės tarp baitų daugiklis M', 22, NULL, NULL, 5, NULL),
	(-50913, 'TypeUart4', 'UART4 modulio tipas', 22, NULL, 966, 5, NULL),
	(-50912, 'LimitAbnormalMode', 'Riba pagal avarinį TP režimą', 7, NULL, NULL, 5, 1),
	(-50911, 'LimitByContract', 'Riba pagal sutartį', 7, NULL, NULL, 5, 1),
	(-50910, 'RelayMode_Power_On', '"Pagal galią" įjungimo variantas', 7, NULL, 956, 5, NULL),
	(-50909, 'RelayMode_Power_Off', '"Pagal galią" atjungimo variantas', 7, NULL, 955, 5, NULL),
	(-50908, 'RellayOnLimitLow_U', 'Įjungimo riba pasibaigus įtampos kritimui', 7, NULL, NULL, 5, 6),
	(-50907, 'RellayOffLimitLow_U', 'Atjungimo nukritus įtampai riba', 7, NULL, NULL, 5, 6),
	(-50906, 'RellayOnLimitHi_U', 'Įjungimo riba pagal įtampos viršijimo pabaigą', 7, NULL, NULL, 5, 6),
	(-50905, 'RellayOffLimitHi_U', 'Viršijus įtampą atjungimo riba', 7, NULL, NULL, 5, 6),
	(-50904, 'MoneyCoefficient_T4', 'Svorio koeficientas 4 tarifui 0,01 kWh valiutoje, kapeikos', 7, NULL, NULL, 5, NULL),
	(-50903, 'MoneyCoefficient_T3', 'Svorio koeficientas 3 tarifui 0,01 kWh valiutoje, kapeikos', 7, NULL, NULL, 5, NULL),
	(-50902, 'MoneyCoefficient_T2', 'Svorio koeficientas 2 tarifui 0,01 kWh valiutoje, kapeikos', 7, NULL, NULL, 5, NULL),
	(-50901, 'MoneyCoefficient_T1', 'Svorio koeficientas 1 tarifui 0,01 kWh valiutoje, kapeikos', 7, NULL, NULL, 5, NULL),
	(-50900, 'MoneyBalanceAlert', 'Veikimo aprašymas pasiekus kritinį pinigų kiekį vartotojo balanse', 7, NULL, 954, 5, NULL),
	(-50899, 'CriticalMoneyBalance', 'Kritinis pinigų kiekis vartotojo balanse, kapeikos', 7, NULL, NULL, 5, NULL),
	(-50898, 'MoneyBalance', 'Einamasis vartotojo balansas, kapeikos', 7, NULL, NULL, 5, NULL),
	(-50897, 'HzDeviationHiLimit_vnt', 'Viršutinė riba pagal dažnį', 7, NULL, NULL, 5, 8),
	(-50896, 'VoltDeviationLowLimit_vnt', 'Apatinė riba pagal įtampą', 7, NULL, NULL, 5, 6),
	(-50895, 'VoltDeviationHiLimit_vnt', 'Viršutinė riba pagal įtampą', 7, NULL, NULL, 5, 6),
	(-50894, 'RelayDayScheduler', 'Relės valdymo paros grafikas - įjungtas', 7, NULL, 953, 5, NULL),
	(-50893, 'InterfaceUnlockTime', 'Interfeiso atblokavimo mygtuku laikas', 7, NULL, NULL, 5, 10),
	(-50892, 'InterfaceConnectionTime', 'Interfeiso sujungimo laikas', 7, NULL, NULL, 5, 10),
	(-50891, 'RetranslationWaitTimeOut', 'Laukimo  prieš retransliaciją laikas, ms', 7, NULL, NULL, 5, NULL),
	(-50890, 'FactoryCalibration', 'Gamintojo dariusio kalibravimą, pavadinimas', 7, NULL, NULL, 5, NULL),
	(-50889, 'BillingID', 'Bilingo identifikatorius', 7, NULL, NULL, 5, NULL),
	(-50888, 'Abonent', 'Abonento VP', 7, NULL, NULL, 5, NULL),
	(-50887, 'Apartment', 'Butas', 7, NULL, NULL, 5, NULL),
	(-50886, 'House', 'Namas', 7, NULL, NULL, 5, NULL),
	(-50885, 'Street', 'Gatvė', 7, NULL, NULL, 5, NULL),
	(-50884, 'PersonalAccount', 'Vartotojo sąskaita', 7, NULL, NULL, 5, NULL),
	(-50883, 'StreetLight', 'Skaitiklis su gatvės apšvietimu', 7, NULL, 952, 5, NULL),
	(-50882, 'TypeUart3', 'UART3 modulio tipas', 7, NULL, 951, 5, NULL),
	(-50881, 'TypeUart2', 'UART2 modulio tipas', 7, NULL, 951, 5, NULL),
	(-50880, 'TypeUart1', 'UART1 modulio tipas', 7, NULL, 951, 5, NULL),
	(-50879, 'Meter_100A', 'Skaitiklis 100A', 7, NULL, 950, 5, NULL),
	(-50878, 'PassiveCL_On_Off', 'Pasyvinė srovinė kilpa', 21, NULL, 932, 5, NULL),
	(-50877, 'ActiveCL_On_Off', 'Aktyvinė srovinė kilpa', 21, NULL, 931, 5, NULL),
	(-50876, 'StartBaud', 'IEC1107 pradinis greitis', 22, NULL, NULL, 5, NULL),
	(-50875, 'AEC3RET', 'Laikas po kurio sugrįžtama į skaidrų režimą', 15, NULL, NULL, 5, 10),
	(-50874, 'SaveSettings', 'Nustatymų išsaugojimas', 21, NULL, NULL, 6, NULL),
	(-50873, 'ResetDevice', 'Prietaiso perkrovimas', 21, NULL, NULL, 6, NULL),
	(-50872, 'ACFaultMessagingNumberTries', 'Bandymų išsiųsti pranešimą kiekis', 21, NULL, NULL, 5, NULL),
	(-50871, 'BTS_CellID', 'BTS Cell ID', 21, NULL, NULL, 5, NULL),
	(-50870, 'BTS_LocalAreaCode', 'BTS lokalinis kodas', 21, NULL, NULL, 5, NULL),
	(-50869, 'Modem_IPAddress', 'Buvęs modemo IP adresas', 22, NULL, NULL, 5, NULL),
	(-50868, 'GSM_IMEI', 'GSM IMEI', 22, NULL, NULL, 5, NULL),
	(-50867, 'GPRS_Port', 'GPRS kontrolės portas', 22, NULL, NULL, 5, NULL),
	(-50866, 'GPRS_IPAddress', 'GPRS kontrolės serverio IP adresas', 22, NULL, NULL, 5, NULL),
	(-50865, 'GPRS_ControlInterval', 'GPRS kontrolės intervalas', 15, NULL, NULL, 5, 10),
	(-50864, 'NTP_IPAddress', 'NTP serverio IP adresas', 22, NULL, NULL, 5, NULL),
	(-50863, 'RTC_Period', 'RTC sinchronizacija', 15, NULL, 930, 5, NULL),
	(-50862, 'ResetPeriod', 'Neaktyvios būsenos perkrovimo periodas', 21, NULL, NULL, 5, 10),
	(-50861, 'ResetCLIPPhone', 'Nuotolinio CLIP aparatūrinis perkrovimas', 21, NULL, NULL, 5, NULL),
	(-50860, 'ResetHardwareTime', 'Aparatūros perkrovimo pagal tvarkaraštį laikas', 21, NULL, NULL, 5, NULL),
	(-50859, 'ResetTime', 'Perkrovimo pagal tvarkaraštį laikas', 21, NULL, NULL, 5, NULL),
	(-50858, 'ConfigurationPort', 'Konfiguracinis IP portas', 22, NULL, NULL, 5, NULL),
	(-50857, 'CSD_SMS_Phone', 'Leistino CSD/SMS telefono numeris', 22, NULL, NULL, 5, NULL),
	(-50856, 'TCP_TimeOut', 'TCP sesijos neaktyvumo TimeOut', 15, NULL, NULL, 5, 10),
	(-50855, 'InterfacePort', 'Nuoseklaus prievado IP portas', 22, NULL, NULL, 5, NULL),
	(-50854, 'ReadOutMode', 'Nuoseklaus porto nuskaitymo būdas', 24, NULL, 929, 5, NULL),
	(-50853, 'PassSpecialDayProgId', 'Profilio specialios dienos identifikatorius naudojamas pasyviniam kalendoriui', 7, NULL, NULL, 5, NULL),
	(-50852, 'PassSpecialDayDate', 'Specialios dienos data pasyviniam kalendoriui', 7, NULL, NULL, 5, NULL),
	(-50851, 'SoftwareCRC', 'PĮ kontrolinė suma', 7, NULL, NULL, 5, NULL),
	(-50850, 'SoftwareCRCMetrology', 'PĮ kontrolinė suma, metrologinė dalis', 7, NULL, NULL, 5, NULL),
	(-50849, 'SoftwareVersionMetrology', 'PĮ versija, metrologinė dalis', 7, NULL, NULL, 5, NULL),
	(-50848, 'GazStartHour', 'Dujų dienos pradžia', 7, NULL, NULL, 5, 29),
	(-50847, 'OperateMagistral', 'Aptarnaujamų vartotojų aprašymas', 7, NULL, NULL, 5, NULL),
	(-50846, 'OperateHeatLine', 'Aptarnaujamų vamzdynų aprašymas', 7, NULL, NULL, 5, NULL),
	(-50845, 'MagistralType', 'Magistralės tipas', 7, NULL, 908, 5, NULL),
	(-50844, 'HeatConnectionScheme', 'Šilumos tiekimo schema', 7, NULL, 907, 5, NULL),
	(-50843, 'HeatQntt_exponent', 'Šilumos energijos parodymų diskretiškumas', 7, NULL, NULL, 5, NULL),
	(-50842, 'VolQntt_exponent', 'Šilumos nešėjo masės parodymų diskretiškumas', 7, NULL, NULL, 5, NULL),
	(-50841, 'MeasSupp_DayEnergy', 'Skaitiklio tipo aprašymas: skaitiklis 3-čios kartos', 7, NULL, NULL, 5, NULL),
	(-50840, 'MeasSupp_MonthFixTime', 'Skaitiklio tipo aprašymas: mėnesio rodmenų fiksacijos laikas', 7, NULL, NULL, 5, NULL),
	(-50839, 'MeasSupp_DayFixTime', 'Skaitiklio tipo aprašymas: paros rodmenų fiksacijos laikas', 7, NULL, NULL, 5, NULL),
	(-50838, 'MeasSupp_ErrFlag_LastMonth', 'Skaitiklio tipo aprašymas: klaidos požymis (praėjusis mėnuo)', 7, NULL, NULL, 5, NULL),
	(-50837, 'MeasSupp_ErrFlag_Yesterday', 'Skaitiklio tipo aprašymas: klaidos požymis (praėjusi para)', 7, NULL, NULL, 5, NULL),
	(-50836, 'MeasSupp_ErrFlag_Today', 'Skaitiklio tipo aprašymas: klaidos požymis (šiandien)', 7, NULL, NULL, 5, NULL),
	(-50835, 'MeasSupp_Mon_Relay', 'Mėnesinių rodmenų fiksavimo klasės: relės būsena', 7, NULL, NULL, 5, NULL),
	(-50834, 'MeasSupp_Mon_Retrans', 'Mėnesinių rodmenų fiksavimo klasės: retransliacijos statusas', 7, NULL, NULL, 5, NULL),
	(-50833, 'MeasSupp_Mon_P', 'Mėnesinių rodmenų fiksavimo klasės: aktyvinė galia', 7, NULL, NULL, 5, NULL),
	(-50832, 'MeasSupp_Mon_Current', 'Mėnesinių rodmenų fiksavimo klasės: srovė pagal 3 fazes', 7, NULL, NULL, 5, NULL),
	(-50831, 'MeasSupp_Mon_Voltage', 'Mėnesinių rodmenų fiksavimo klasės: įtampa pagal 3 fazes', 7, NULL, NULL, 5, NULL),
	(-50830, 'MeasSupp_Mon_Events', 'Mėnesinių rodmenų fiksavimo klasės: įvykių žurnalai', 7, NULL, NULL, 5, NULL),
	(-50829, 'MeasSupp_Mon_R', 'Mėnesinių rodmenų fiksavimo klasės: reaktyvinė energija (suminė ir pagal tarifus)', 7, NULL, NULL, 5, NULL),
	(-50828, 'MeasSupp_Mon_A', 'Mėnesinių rodmenų fiksavimo klasės: aktyvinė energija (suminė ir pagal tarifus)', 7, NULL, NULL, 5, NULL),
	(-50827, 'MeasSupp_Daily_Relay', 'Paros rodmenų fiksavimo klasės: relės būsena', 7, NULL, NULL, 5, NULL),
	(-50826, 'MeasSupp_Daily_Retrans', 'Paros rodmenų fiksavimo klasės: retransliacijos statusas', 7, NULL, NULL, 5, NULL),
	(-50825, 'MeasSupp_Daily_P', 'Paros rodmenų fiksavimo klasės: aktyvinė galia', 7, NULL, NULL, 5, NULL),
	(-50824, 'MeasSupp_Daily_Current', 'Paros rodmenų fiksavimo klasės: srovė pagal 3 fazes', 7, NULL, NULL, 5, NULL),
	(-50823, 'MeasSupp_Daily_Voltage', 'Paros rodmenų fiksavimo klasės: įtampa pagal 3 fazes', 7, NULL, NULL, 5, NULL),
	(-50822, 'MeasSupp_Daily_Events', 'Paros rodmenų fiksavimo klasės: įvykių žurnalai', 7, NULL, NULL, 5, NULL),
	(-50821, 'MeasSupp_Daily_R', 'Paros rodmenų fiksavimo klasės: reaktyvinė energija (suminė ir pagal tarifus)', 7, NULL, NULL, 5, NULL),
	(-50820, 'MeasSupp_Daily_A', 'Paros rodmenų fiksavimo klasės: aktyvinė energija (suminė ir pagal tarifus)', 7, NULL, NULL, 5, NULL),
	(-50819, 'MeasSupp_Hourly_Relay', 'Valandinių rodmenų fiksavimo klasės: relės būsena', 7, NULL, NULL, 5, NULL),
	(-50818, 'MeasSupp_Hourly_Retrans', 'Valandinių rodmenų fiksavimo klasės: retransliacijos statusas', 7, NULL, NULL, 5, NULL),
	(-50817, 'MeasSupp_Hourly_P', 'Valandinių rodmenų fiksavimo klasės: aktyvinė galia', 7, NULL, NULL, 5, NULL),
	(-50816, 'MeasSupp_Hourly_Current', 'Valandinių rodmenų fiksavimo klasės: srovė pagal 3 fazes', 7, NULL, NULL, 5, NULL),
	(-50815, 'MeasSupp_Hourly_Voltage', 'Valandinių rodmenų fiksavimo klasės: įtampa pagal 3 fazes', 7, NULL, NULL, 5, NULL),
	(-50814, 'MeasSupp_Hourly_Events', 'Valandinių rodmenų fiksavimo klasės: įvykių žurnalai', 7, NULL, NULL, 5, NULL),
	(-50813, 'MeasSupp_Hourly_R', 'Valandinių rodmenų fiksavimo klasės: reaktyvinė energija (suminė ir pagal tarifus)', 7, NULL, NULL, 5, NULL),
	(-50812, 'MeasSupp_Hourly_A', 'Valandinių rodmenų fiksavimo klasės: aktyvinė energija (suminė ir pagal tarifus)', 7, NULL, NULL, 5, NULL),
	(-50811, 'ProfileMAXChannelsCount', 'Kanalų kiekis (maksimumas)', 7, NULL, NULL, 5, NULL),
	(-50810, 'Profile_MAX_NBR_BLK_INTS', 'Bloko intervalų kiekis (maksimumas)', 7, NULL, NULL, 5, NULL),
	(-50809, 'Profile_MAX_NBR_BLKS', 'Blokų kiekis (maksimumas)', 7, NULL, NULL, 5, NULL),
	(-50808, 'Profile_MAX_MEMORY_LEN', 'Apkrovos profilių atminties kiekis (maksimumas)', 7, NULL, NULL, 5, NULL),
	(-50807, 'NORMAL_MODE_INTERVAL', 'Normalaus režimo intervalas', 7, NULL, NULL, 5, NULL),
	(-50806, 'Profile_NBR_BLK_INTS', 'Bloko intervalų kiekis', 7, NULL, NULL, 5, NULL),
	(-50805, 'Profile_NBR_BLKS', 'Blokų kiekis', 7, NULL, NULL, 5, NULL),
	(-50804, 'Profile_MEMORY_LEN', 'Apkrovos profilių atminties kiekis', 7, NULL, NULL, 5, NULL),
	(-50803, 'TIER_DAY_SCH_NUM', 'Dieninių tvarkaraščių kiekis', 7, NULL, NULL, 5, NULL),
	(-50802, 'TIER_SWITCH_MIN', 'Perjungimo minutė', 7, NULL, NULL, 5, 11),
	(-50801, 'TIER_SWITCH_HOUR', 'Perjungimo valanda', 7, NULL, NULL, 5, 29),
	(-50800, 'TIER_DEMANDS_SWITCH_FLAG', 'Galios perjungimo požymis', 7, NULL, NULL, 5, NULL),
	(-50799, 'TIER_SUMMATION_SWITCH_FLAG', 'Sukauptų duomenų perjungimo požymis', 7, NULL, NULL, 5, NULL),
	(-50798, 'TIER_Nr', 'Naujas lygis', 7, NULL, NULL, 5, NULL),
	(-50797, 'RECURR_DATES_SELF_READ_FLAG', 'Autonuskaitymų požymis (pasikartojančios datos)', 7, NULL, NULL, 5, NULL),
	(-50796, 'RECURR_DATES_DEMAND_RESET_FLAG', 'Galios numetimo požymis (pasikartojančios datos)', 7, NULL, NULL, 5, NULL),
	(-50795, 'RECURR_DATES_ACTION', 'Vykdoma funkcija (pasikartojančios datos)', 7, NULL, 927, 5, NULL),
	(-50794, 'RECURR_DATES_SELECTDATE', 'Pasikartojančių datų tipas', 7, NULL, 928, 5, NULL),
	(-50793, 'NON_RECURR_DATES_SELF_READ_FLAG', 'Autonuskaitymo požymis (nepasikartojančios datos)', 7, NULL, NULL, 5, NULL),
	(-50792, 'NON_RECURR_DATES_DEMAND_RESET_FLAG', 'Galios numetimo požymis (nepasikartojančios datos)', 7, NULL, NULL, 5, NULL),
	(-50791, 'NON_RECURR_DATES_ACTION', 'Vykdoma funkcija (nepasikartojančios datos)', 7, NULL, 927, 5, NULL),
	(-50790, 'NON_RECURR_DATES_Date', 'Nepasikartojančių datų masyvas', 7, NULL, NULL, 5, NULL),
	(-50789, 'RECURR_DATES_ANCHOR_DATE', 'Pririšimo data', 7, NULL, NULL, 5, NULL),
	(-50788, 'CALENDAR_SIZE', 'Kalendoriaus dydis', 7, NULL, NULL, 5, NULL),
	(-50787, 'NBR_TIER_SWITCHES', 'Persijungimo lygių kiekis', 7, NULL, NULL, 5, NULL),
	(-50786, 'NBR_RECURR_DATES', 'Pasikartojančių datų kiekis', 7, NULL, NULL, 5, NULL),
	(-50785, 'NBR_NON_RECURR_DATES', 'Nepasikartojančių datų kiekis', 7, NULL, NULL, 5, NULL),
	(-50784, 'NBR_SPECIAL_SCHED', 'Specialių tvarkaraščių kiekis', 7, NULL, NULL, 5, NULL),
	(-50783, 'NBR_SEASONS', 'Sezonų kiekis', 7, NULL, NULL, 5, NULL),
	(-50782, 'CAP_TM_ZN_OFFSET_FLAG', 'Laiko juostos postūmio galimybė', 7, NULL, NULL, 5, NULL),
	(-50781, 'SORT_TIER_SWITCHES_FLAG', 'Perjungimo lygių rūšiavimas', 7, NULL, NULL, 5, NULL),
	(-50780, 'SEPARATE_SUM_DEMANDS_FLAG', 'Atskiros sukauptos galios', 7, NULL, NULL, 5, NULL),
	(-50779, 'SEPARATE_WEEKDAYS_FLAG', 'Atskiros darbo dienos', 7, NULL, NULL, 5, NULL),
	(-50778, 'CAP_DST_AUTO_FLAG', 'Galimybė perėjimo į vasaros laiką', 7, NULL, NULL, 5, NULL),
	(-50777, 'ANCHOR_DATE_FLAG', 'Pririšimo data', 7, NULL, NULL, 5, NULL),
	(-50776, 'SORT_DATES_FLAG', 'Datų rūšiavimas', 7, NULL, NULL, 5, NULL),
	(-50775, 'SEASON_CHNG_ARMED_FLAG', 'Rankinis sezono pakeitimas', 7, NULL, NULL, 5, NULL),
	(-50774, 'SEASON_DEMAND_RESET_FLAG', 'Galios numetimo sezonas', 7, NULL, NULL, 5, NULL),
	(-50773, 'SEASON_SELF_READ_FLAG', 'Autonuskaitymų sezonas', 7, NULL, NULL, 5, NULL),
	(-50772, 'TOU_SELF_READ_FLAG', 'Autonuskaitymų panaudojimo lentelė', 7, NULL, NULL, 5, NULL),
	(-50771, 'PRESENT_VALUE_SELECT', 'Einamojo tinklo parametro kodas', 7, NULL, 926, 5, NULL),
	(-50770, 'PRESENT_DEMAND_SELECT', 'Einamosios galios kodas', 7, NULL, 926, 5, NULL),
	(-50769, 'COIN_DEMAND_ASSOC', 'Galios sutapimo asociacija', 7, NULL, 926, 5, NULL),
	(-50768, 'COINCIDENT_SELECT', 'Sutapimo kodas', 7, NULL, 926, 5, NULL),
	(-50767, 'DEMAND_MAX_FLAGS', 'Minimumo arba maksimumo požymis', 7, NULL, NULL, 5, NULL),
	(-50766, 'DEMAND_SELECT', 'Galios kodas', 7, NULL, 926, 5, NULL),
	(-50765, 'SUMMATION_SELECT', 'Sumuojančių registrų masyvas.', 7, NULL, 926, 5, NULL),
	(-50764, 'SELF_READ_DEMAND_RESET', 'Galios numetimas autonuskaitant', 7, NULL, 925, 5, NULL),
	(-50763, 'WEEKLY_SELF_READ_FLAG', 'Būtinųjų kas savaitinų autoskaitymų palaikymo požymis', 7, NULL, NULL, 5, NULL),
	(-50762, 'DAILY_SELF_READ_FLAG', 'Būtinųjų kasdieninių autoskaitymų palaikymo požymis', 7, NULL, NULL, 5, NULL),
	(-50761, 'SELF_READ_SEQ_NBR_FLAG', 'Autoskaitymų nuoseklusis numeris', 7, NULL, NULL, 5, NULL),
	(-50760, 'SELF_READ_INHIBIT_OVERFLOW_FLAG', 'Uždraudimas autoskaitymo esant perpildymui', 7, NULL, NULL, 5, NULL),
	(-50759, 'TIME_REMAINING_FLAG', 'Skaitiklis fiksuoja laiką likusį iki  galios pabaigos pointervalo. ', 7, NULL, NULL, 5, NULL),
	(-50758, 'CONT_CUM_DEMAND_FLAG', 'Skaitiklis palaiko nenutrūkstamos kumuliatyvinės galios skaičiavimą ', 7, NULL, NULL, 5, NULL),
	(-50757, 'CUM_DEMAND_FLAG', 'skaitiklis palaiko kumuliatyvinės galios skaičiavimą  ', 7, NULL, NULL, 5, NULL),
	(-50756, 'DEMAND_RESET_LOCK_FLAG', 'Skaitlis palaiko galios numetimo blokavimą', 7, NULL, NULL, 5, NULL),
	(-50755, 'DEMAND_RESET_CTR_FLAG', 'Skaitiklis saugo bendrą galios numetimų kiekį', 7, NULL, NULL, 5, NULL),
	(-50754, 'DATE_TIME_FIELD_FLAG', 'Data ir laikas yra skaitiklio rodmenų lentelėse', 7, NULL, NULL, 5, NULL),
	(-50753, 'SEASON_INFO_FIELD_FLAG', 'Skaitiklio rodmenų sezonų informacija esanti lentelėse ', 7, NULL, NULL, 5, NULL),
	(-50752, 'NBR_PRESENT_VALUES', 'Esančių reikšmių kiekis', 7, NULL, NULL, 5, NULL),
	(-50751, 'NBR_PRESENT_DEMANDS', 'Esančių galių kiekis', 7, NULL, NULL, 5, NULL),
	(-50750, 'NBR_TIERS', 'Eilių kiekis', 7, NULL, NULL, 5, NULL),
	(-50749, 'NBR_OCCUR', 'Įvykių kiekis', 7, NULL, NULL, 5, NULL),
	(-50748, 'NBR_COIN_VALUES', 'Sutampančių reikšmių kiekis', 7, NULL, NULL, 5, NULL),
	(-50747, 'NBR_DEMANDS', 'Galių kiekis', 7, NULL, NULL, 5, NULL),
	(-50746, 'NBR_SUMMATIONS', 'Sumuojamų registrų kiekis', 7, NULL, NULL, 5, NULL),
	(-50745, 'NBR_SELF_READS', 'Autoskaitymų kiekis', 7, NULL, NULL, 5, NULL),
	(-50744, 'TEST_MODE_INTERVAL', 'Sekundžių kiekis testinio režimo intervale', 7, NULL, NULL, 5, 10),
	(-50743, 'COLD_LOAD_PICKUP', 'Šalto užkrovimo suveikimo laikas', 7, NULL, NULL, 5, 11),
	(-50742, 'P_FAIL_EXCLUSION', 'Maitinimo dingimų panaikinimas', 7, NULL, NULL, 5, 11),
	(-50741, 'P_FAIL_RECOGNTN_TM', 'Maitinimo dingimo atpažinimo laikas', 7, NULL, NULL, 5, 10),
	(-50740, 'RESET_EXCLUSION', 'Numetimo panaikinimas', 7, NULL, NULL, 5, 11),
	(-50739, 'MISC_ID', 'Įvairūs identifikatoriai', 7, NULL, NULL, 5, NULL),
	(-50738, 'PROGRAMMER_NAME', 'Programuotojo vardas', 7, NULL, NULL, 5, NULL),
	(-50737, 'EX_SW_VERSION', 'EX programos versijos numeris', 7, NULL, NULL, 5, NULL),
	(-50736, 'EX_SW_VENDOR', 'EX programos pardavėjas', 7, NULL, NULL, 5, NULL),
	(-50735, 'TARIFF_ID', 'Tarifo identifikatorius', 7, NULL, NULL, 5, NULL),
	(-50734, 'COORDINATE_3', '3 kordinatė', 7, NULL, NULL, 5, NULL),
	(-50733, 'COORDINATE_2', '2 kordinatė', 7, NULL, NULL, 5, NULL),
	(-50732, 'COORDINATE_1', '1 kordinatė', 7, NULL, NULL, 5, NULL),
	(-50731, 'CUSTOMER_ID', 'Vartotojo identifikatorius', 7, NULL, NULL, 5, NULL),
	(-50730, 'UTIL_SER_NO', 'Tarnybinis serijinis numeris', 7, NULL, NULL, 5, NULL),
	(-50729, 'DEVICE_ID', 'Prietaiso identifikatorius', 7, NULL, NULL, 5, NULL),
	(-50728, 'ELEC_ADDR', 'Elektromontažinis adresas', 7, NULL, NULL, 5, NULL),
	(-50727, 'SERVICE_POINT_ID', 'Servisinio centro identifikatorius', 7, NULL, NULL, 5, NULL),
	(-50726, 'UTILITY_DIV', 'Tarnybinis Div', 7, NULL, NULL, 5, NULL),
	(-50725, 'OWNER_NAME', 'Šeimininko vardas', 7, NULL, NULL, 5, NULL),
	(-50724, 'ExternalSupplyVoltage', 'Išorinio maitinimo įtampa', 7, NULL, NULL, 5, NULL),
	(-50723, 'ElementVoltage', 'Baterijos įtampa', 7, NULL, NULL, 5, NULL),
	(-50722, 'BASE_TYPE', 'Bazinio skaitiklio tipas', 7, NULL, 924, 5, NULL),
	(-50721, 'NO_OF_ELEMENTS', 'Matuojamų elemenų kiekis ', 7, NULL, NULL, 5, NULL),
	(-50720, 'INPUT_SCALAR', 'Įėjimo daugiklis', 7, NULL, NULL, 5, NULL),
	(-50719, 'METER_KT', 'Naudoja skaitiklio Kt koeficientą ', 7, NULL, NULL, 5, NULL),
	(-50718, 'METER_KH', 'Naudoja skaitiklio Kh koeficientą ', 7, NULL, NULL, 5, NULL),
	(-50717, 'Use_TrKf', 'Skaitiklis įvertina transformacijos koeficientą', 7, NULL, NULL, 5, NULL),
	(-50716, 'KEAdj', 'Pirminis Ke', 7, NULL, NULL, 5, NULL),
	(-50715, 'KH_Kf', 'Kh', 7, NULL, NULL, 5, NULL),
	(-50714, 'KE_Kf', 'Ke', 7, NULL, NULL, 5, NULL),
	(-50713, 'ScaleFactor', 'Dešimtainio kablelio vieta energijai', 7, NULL, NULL, 5, NULL),
	(-50712, 'EXTERNAL_MULTIPLIER', 'Išorinis daugiklis', 7, NULL, NULL, 5, NULL),
	(-50711, 'ScaleFactor_Instrumental', 'Dešimtainio kablelio vieta tinklo parametrams', 7, NULL, NULL, 5, NULL),
	(-50710, 'UseLossCompensation', 'Leistina nuostolių kompensacija', 7, NULL, NULL, 5, NULL),
	(-50709, 'UseTariff', 'Leistinas tarifikavimas', 7, NULL, NULL, 5, NULL),
	(-50708, 'UseTimekeeping', 'Leistinas laikrodis', 7, NULL, NULL, 5, NULL),
	(-50707, 'UseAdvanceMetering', 'Leistini papildomi matavimai', 7, NULL, NULL, 5, NULL),
	(-50706, 'UsePQM', 'Leistinas PQM', 7, NULL, NULL, 5, NULL),
	(-50705, 'UseInstrumentalProfile', 'Leistini tinklo parametrų grafikai', 7, NULL, NULL, 5, NULL),
	(-50704, 'UseProfile', 'Leistinas bazinis apkrovos grafikas', 7, NULL, NULL, 5, NULL),
	(-50703, 'ServiceVer', 'Serviso versija', 7, NULL, NULL, 5, NULL),
	(-50702, 'PQMVer', 'PQM versija', 7, NULL, NULL, 5, NULL),
	(-50701, 'SMVer', 'SM versija', 7, NULL, NULL, 5, NULL),
	(-50700, 'DSPVer', 'DSP versija', 7, NULL, NULL, 5, NULL),
	(-50699, 'FirmwareSSpec', 'S-Spec vidinės PĮ', 7, NULL, NULL, 5, NULL),
	(-50698, 'StyleNumber', 'Stail', 7, NULL, NULL, 5, NULL),
	(-50697, 'UnitOfMeasure_Strm', 'Galios matavimo vienetai', 7, NULL, 885, 5, NULL),
	(-50696, 'UnitOfMeasure_Qntt', 'Energijos matavimo vienetai', 7, NULL, 884, 5, NULL),
	(-50695, 'UnitOfMeasure_Press', 'Slėgio matavimo vienetai', 7, NULL, 883, 5, NULL),
	(-50694, 'ResetIntervalOnIdle', '"Watchdogo" timeoutas', 7, NULL, NULL, 5, 10),
	(-50693, 'DirectionCount', 'Krypčių kiekis', 7, NULL, NULL, 5, NULL),
	(-50692, 'PhaseCount', 'Fazių kiekis', 7, NULL, NULL, 5, NULL),
	(-50691, 'PLCTimeRWMethod', 'Laiko nuskaitymo būdas', 7, NULL, 821, 5, NULL),
	(-50690, 'FridayProgrammTariff', 'Penktadienio programa - tarifas', 7, NULL, NULL, 5, NULL),
	(-50689, 'FridayProgrammBegin', 'Penktadienio programa - laikas', 7, NULL, NULL, 5, NULL),
	(-50688, 'ThursdayProgrammTariff', 'Ketvirtadienio programa - tarifas', 7, NULL, NULL, 5, NULL),
	(-50687, 'ThursdayProgrammBegin', 'Ketvirtadienio programa - laikas', 7, NULL, NULL, 5, NULL),
	(-50686, 'WednesdayProgrammTariff', 'Trečiadienio programa - tarifas', 7, NULL, NULL, 5, NULL),
	(-50685, 'WednesdayProgrammBegin', 'Trečiadienio programa - laikas', 7, NULL, NULL, 5, NULL),
	(-50684, 'TuesdayProgrammTariff', 'Antradienio programa - tarifas', 7, NULL, NULL, 5, NULL),
	(-50683, 'TuesdayProgrammBegin', 'Antradienio programa - laikas', 7, NULL, NULL, 5, NULL),
	(-50682, 'MondayProgrammTariff', 'Pirmadienio programa - tarifas', 7, NULL, NULL, 5, NULL),
	(-50681, 'MondayProgrammBegin', 'Pirmadienio programa - laikas', 7, NULL, NULL, 5, NULL),
	(-50680, 'DisplayIndicate_Ap_4', 'Indikacija displėjuje - 4 tarifas', 7, NULL, NULL, 5, NULL),
	(-50679, 'DisplayIndicate_Ap_3', 'Indikacija displėjuje - 3 tarifas', 7, NULL, NULL, 5, NULL),
	(-50678, 'DisplayIndicate_Ap_2', 'Indikacija displėjuje - 2 tarifas', 7, NULL, NULL, 5, NULL),
	(-50677, 'DisplayIndicate_Ap_1', 'Indikacija displėjuje - 1 tarifas', 7, NULL, NULL, 5, NULL),
	(-50676, 'DisplayIndicate_SummA', 'Indikacija displėjuje - Tarifų suma', 7, NULL, NULL, 5, NULL),
	(-50675, 'DisplayIndicate_Addr', 'Indikacija displėjuje - Tinklinis adresas', 7, NULL, NULL, 5, NULL),
	(-50674, 'DisplayIndicate_Time', 'Indikacija displėjuje - Laikas', 7, NULL, NULL, 5, NULL),
	(-50673, 'DisplayIndicate_Date', 'Indikacija displėjuje - Data', 7, NULL, NULL, 5, NULL),
	(-50672, 'MonthPeriodFirstDay', 'Mėnesinio periodo pirmoji diena', 7, NULL, NULL, 5, NULL),
	(-50670, 'VoltageCode', 'Įtampos kodas  - reikšmės', 7, NULL, 814, 5, NULL),
	(-50669, 'CurrentCode', 'Srovės kodas - reikšmės', 7, NULL, 813, 5, NULL),
	(-50668, 'AccuracyClassForReactEnergy', 'Reaktyvinės energijos matavimo tikslumo klasė', 7, NULL, 812, 5, NULL),
	(-50667, 'NewTariffsStartDate', 'Naujo tarifinio tvarkaraščio pritaikymo data', 7, NULL, NULL, 5, NULL),
	(-50666, 'relay5capable', 'Relė 5 yra', 7, NULL, 82, 5, NULL),
	(-50665, 'relay4capable', 'Relė 4 yra', 7, NULL, 82, 5, NULL),
	(-50664, 'relay3capable', 'Relė 3 yra', 7, NULL, 82, 5, NULL),
	(-50663, 'relay2capable', 'Relė 2 yra', 7, NULL, 82, 5, NULL),
	(-50655, 'MeterRole', 'Prietaiso rolė', 7, NULL, NULL, 5, NULL),
	(-50654, 'FirmwareVer', 'Programinės įrangos versija', 7, NULL, NULL, 5, NULL),
	(-50653, 'ProtokolVer', 'Protokolo versija', 7, NULL, NULL, 5, NULL),
	(-50652, 'SendPeriodBRK', 'Periodinis duomenų paketų siuntimas iš prietaisų į serverį, kuriame instaliuota TBN broker tarnyba', 7, NULL, NULL, 5, 10),
	(-50651, 'Kf_Loss', 'Nuostolių koeficientas, imp/kWh', 7, NULL, NULL, 5, NULL),
	(-50650, 'Kf_ImpToIntEnergy_3Min', 'Impulsų transformacijos koeficientas 3 min. duomenims, imp/kWh', 7, NULL, NULL, 5, NULL),
	(-50649, 'Kf_ImpToIntEnergy_30Min', 'Impulsų transformacijos koeficientas 30 min. duomenims, imp/kWh', 7, NULL, NULL, 5, NULL),
	(-50648, 'Kf_ImpToSumEnergy', 'Impulsų transformacijos koeficientas skaitikliams, imp/kWh', 7, NULL, NULL, 5, NULL),
	(-50647, 'Kf_ImpToIntEnergy', 'Impulsų transformacijos koeficientas energijai, imp/kWh', 7, NULL, NULL, 5, NULL),
	(-50637, 'VariantHeatCalculation', 'Šilumos apskaičiavimo varijantas', 7, NULL, NULL, 5, NULL),
	(-50636, 'PLCPowerUpperLimit', 'Galios ribojimo viršutinė reikšmė, impulsai per minutę', 7, NULL, NULL, 5, 72),
	(-50635, 'Meter_Kf_for_React', 'Skaitiklio konstanta reaktyvinei energijai - imp/kWh', 7, NULL, NULL, 5, 71),
	(-50629, 'MeterFeaturesFlags_Bidirectional', 'Abiejų krypčių', 7, NULL, NULL, 5, NULL),
	(-50628, 'MeterFeaturesFlags_TheftProtection', 'Apsauga nuo grobstymo', 7, NULL, NULL, 5, NULL),
	(-50627, 'MeterFeaturesFlags_OpticalPort', 'Optinis portas', 7, NULL, NULL, 5, NULL),
	(-50626, 'MeterFeaturesFlags_IRDAPort', 'IrDA ', 7, NULL, NULL, 5, NULL),
	(-50625, 'MeterFeaturesFlags_SerialCommModule', 'RS', 7, NULL, NULL, 5, NULL),
	(-50624, 'MeterFeaturesFlags_PLCModule', 'PLC', 7, NULL, NULL, 5, NULL),
	(-50623, 'MeterFeaturesFlags_CardModule', 'Kortelinis', 7, NULL, NULL, 5, NULL),
	(-50622, 'MeterFeaturesFlags_ExtraMemory', 'Papildoma  atmintis', 7, NULL, NULL, 5, NULL),
	(-50620, 'MeterFeaturesFlags_RMRadioModule', 'Radio modulis', 7, NULL, NULL, 5, NULL),
	(-50619, 'MeterFeaturesFlags_TXMultiTariffMode', 'TX (daugiatarifinis)', 7, NULL, NULL, 5, NULL),
	(-50618, 'MeterFeaturesFlags_T1SingleTariffMode', 'T1 (vieno tarifo)', 7, NULL, NULL, 5, NULL),
	(-50617, 'SecurityPolicy', 'Saugumo politika', 7, NULL, NULL, 5, NULL),
	(-50616, 'CryptKey', 'Šifravimo raktas', 7, NULL, NULL, 5, NULL),
	(-50615, 'AuthKey', 'Autentifikavimo raktas', 7, NULL, NULL, 5, NULL),
	(-50614, 'PasswMngmLocal', 'Kliento slaptažodis valdymui (per lokalų portą)', 7, NULL, NULL, 5, NULL),
	(-50613, 'PasswMngm', 'Kliento slaptažodis valdymui', 7, NULL, NULL, 5, NULL),
	(-50612, 'PasswReadLocal', 'Kliento slaptažodis skaitymui (per lokalų portą)', 7, NULL, NULL, 5, NULL),
	(-50611, 'PasswRead', 'Kliento slaptažodis skaitymui', 7, NULL, NULL, 5, NULL),
	(-50610, 'MeterCountsDaysWOPowerSupplyMon', 'Skaitiklis skaičiuoja dienų kiekį be elektros energijos padavimo už praėjusį mėnesį', 7, NULL, NULL, 5, NULL),
	(-50600, 'Modem_ByteWaitTimeOut_ms', 'Modemo tarpbaitinis laukimo laikas, ms', 7, NULL, NULL, 5, NULL),
	(-50599, 'ByteWaitTimeOut_ms', 'PC sąsajos (RS232) tarpbaitinis laukimo laikas, ms', 7, NULL, NULL, 5, NULL),
	(-50598, 'RetranslationRoute', 'Automatinės retransliacijos maršrutas', 7, NULL, NULL, 5, NULL),
	(-50597, 'RetranslationMode', 'Retransliacijos režimas', 7, NULL, NULL, 5, NULL),
	(-50596, 'HostAnswerToReceivedPacketProg', 'Kompiuterio veikla gavus heartbeat paketą siunčiamą pagal paros tvarkaraštį', 7, NULL, NULL, 5, 11),
	(-50595, 'DataSendToHostTimeProg', 'Duomenų perdavimo pagal paros tvarkaraštį laikas', 7, NULL, NULL, 5, NULL),
	(-50594, 'Gateway', 'Koncentratoriaus vartai pagal nutylėjimą', 7, NULL, NULL, 5, NULL),
	(-50593, 'SubnetMask', 'Koncentratoriaus potinklio kaukė', 7, NULL, NULL, 5, NULL),
	(-50592, 'ModeLANConnect', 'Duomenų perdavimo režimas - Ethernet (LAN)', 7, NULL, NULL, 5, NULL),
	(-50591, 'ConnectConfirmPacketSendInterval', 'Intervalas tarp paketų patvirtinančių sujungimą', 7, NULL, NULL, 5, 11),
	(-50590, 'ReconnectToHostAfter', 'Intervalas pakartotinam bandymui pasijungti dingus sujungimui', 7, NULL, NULL, 5, 11),
	(-50589, 'HostAnswerToReceivedPacket', 'Kompiuterio veikla gavus heartbeat paketą', 7, NULL, NULL, 5, NULL),
	(-50588, 'MonDataSendToHostTime', 'Mėnesio duomenų perdavimo laikas', 7, NULL, NULL, 5, NULL),
	(-50587, 'DayDataSendToHostTime', 'Paros duomenų perdavimo laikas', 7, NULL, NULL, 5, NULL),
	(-50586, 'APN_Password', 'APN slaptažodis', 7, NULL, NULL, 5, NULL),
	(-50585, 'APN_UserID', 'APN vartotojas', 7, NULL, NULL, 5, NULL),
	(-50584, 'HostPort', 'Kompiuterio portas', 7, NULL, NULL, 5, NULL),
	(-50583, 'HostIP', 'Kompiuterio IP - adresas', 7, NULL, NULL, 5, NULL),
	(-50582, 'MeasSupp_Am_All_Tariff_Mon', 'Palaikomas matavimas: aktyvinė grįžtama energija (suminė pagal tarifus) už praėjusį mėnesį', 7, NULL, NULL, 5, NULL),
	(-50581, 'MeasSupp_R_All_Mon', 'Palaikomas matavimas: suminė reaktyvinė energija už praėjusį mėnesį', 7, NULL, NULL, 5, NULL),
	(-50580, 'SaveErr', 'Slopina klaidų rašymą', 7, NULL, NULL, 5, NULL),
	(-50579, 'MeasSupp_Am_All_Tariff_Day', 'Palaikomas matavimas: aktyvinė grįžtama energija (suminė pagal tarifus) už praėjusią parą', 7, NULL, NULL, 5, NULL),
	(-50578, 'MeasSupp_R_All_Day', 'Palaikomas matavimas:  suminė reaktyvinė energija už prėjusią parą', 7, NULL, NULL, 5, NULL),
	(-50577, 'DayCountWOPowerSupplyMon', 'Dienų kiekis be elektros energijos padavimo už praėjusį mėnesį', 7, NULL, NULL, 5, 12),
	(-50576, 'MeasSupp_P_Mom', 'Palaikomas matavimas:  momentinė galia', 7, NULL, NULL, 5, NULL),
	(-50575, 'MeterNrIsRetrans', 'Skaitiklio-retransliatoriaus naudojamo duomenų apsikeitimui, pozicija', 7, NULL, NULL, 5, NULL),
	(-50574, 'TariffCount', 'Tarifų kiekis', 7, NULL, NULL, 5, NULL),
	(-50573, 'SaveMaxPowerPerPeriod', 'Skaitiklis išsaugo maksimalios galios už periodą reikšmę', 7, NULL, NULL, 5, NULL),
	(-50572, 'MeterSaveDataAtDayEnd', 'Skaitiklis išsaugo duomenis praeitos dienos pabaigai', 7, NULL, NULL, 5, NULL),
	(-50571, 'MeterCountsEnergyBalance', 'Skaitiklis skaičiuoja likutį (kW*h)', 7, NULL, NULL, 5, NULL),
	(-50570, 'MeterCountsCreditBalance', 'Skaitiklis skaičiuoja elektros energijos kredito likutį', 7, NULL, NULL, 5, NULL),
	(-50569, 'MeterIsLead', 'Skaitiklis yra vedantysis', 7, NULL, NULL, 5, NULL),
	(-50568, 'BlockNrJoinMeters', 'Bloko numeris, loginis mazgas, apjungiantis skaitiklius', 7, NULL, NULL, 5, NULL),
	(-50567, 'PhaseMeterConnect', 'Pajungimo fazė, naudojama duomenų automatinei retransliacijai', 7, NULL, NULL, 5, NULL),
	(-50566, 'ConnectToHostToSendDayData', 'Susijungimas su kompiuterių paros duomenų perdavimui', 7, NULL, NULL, 5, NULL),
	(-50565, 'CollectDayData', 'Paros duomenų fiksacijos poreikio požymis', 7, NULL, NULL, 5, NULL),
	(-50564, 'CollectDayCurrDataTime', 'Parodymų fiksavimo paros pradžiai laikas', 7, NULL, NULL, 5, NULL),
	(-50563, 'TXToRX_Delay', 'Tx į Rx uždelsimas, ms', 7, NULL, NULL, 5, NULL),
	(-50562, 'HookTimeout', 'Maksimalus modemo neaktyvumo laikas, s', 7, NULL, NULL, 5, NULL),
	(-50561, 'reverseflowhandling', 'Grįžtamo srauto apdorojimas', 7, NULL, NULL, 5, NULL),
	(-50560, 'relaycapable', 'Yra apkrovos atjungimo relė', 7, NULL, NULL, 5, NULL),
	(-50559, 'readrequest', 'Galimas rankinis skaitymas per optoportą', 7, NULL, NULL, 5, NULL),
	(-50558, 'outagereport', 'Kritimų registravimas', 7, NULL, NULL, 5, NULL),
	(-50557, 'manufactureddate', 'Pagaminimo data', 7, NULL, NULL, 5, NULL),
	(-50556, 'lotnumber', 'Atkrovimo partijos numeris', 7, NULL, NULL, 5, NULL),
	(-50555, 'loadcontrol', 'Palaikoma apkrovos valdymo funkcija', 7, NULL, NULL, 5, NULL),
	(-50554, 'installationdate', 'Instaliavimo data/laikas', 7, NULL, NULL, 5, NULL),
	(-50553, 'METER_NUMBER', 'Galinio įrenginio serijinis numeris', 7, NULL, NULL, 5, NULL),
	(-50552, 'POINT_NAME', 'Laisvo stiliaus tekstinis aprašymas', 7, NULL, NULL, 5, NULL),
	(-50551, 'POINT_CODE', 'Galinio įrenginio unikalus identifikatorius', 7, NULL, NULL, 5, NULL),
	(-50550, 'ForwardingBlockSize', 'Persiunčiamo bloko dydis', 7, NULL, NULL, 5, NULL),
	(-50549, 'DelayBeforeForwarding', 'Uždelsimas prieš persiuntimą', 7, NULL, NULL, 5, NULL),
	(-50548, 'GPRS_Mode', 'GPRS režimas', 7, NULL, NULL, 5, NULL),
	(-50547, 'Flags', 'Vėliavos', 7, NULL, NULL, 5, NULL),
	(-50546, 'MenuPassword', 'Meniu slaptažodis', 7, NULL, NULL, 5, NULL),
	(-50545, 'PIN', 'PIN', 7, NULL, NULL, 5, NULL),
	(-50544, 'CLIPPhoneNr', 'CLIP telefono numeris', 7, NULL, NULL, 5, NULL),
	(-50543, 'ACFaultMessagingListenPort', 'IP portas, kuriuo siunčiami pranešimai apie maitinimo dingimus', 7, NULL, NULL, 5, NULL),
	(-50542, 'ACFaultMessagingServerIP', 'Serverio IP adresas, į kurį siunčiami maitinimo dingimo pranešimai', 7, NULL, NULL, 5, NULL),
	(-50541, 'IPListenPort', 'TCP/IP klausymosi portas', 7, NULL, NULL, 5, NULL),
	(-50540, 'APN', 'APN', 7, NULL, NULL, 5, NULL),
	(-50539, 'ISP', 'ISP', 7, NULL, NULL, 5, NULL),
	(-50538, 'Network_Password', 'Tinklo slaptažodis', 7, NULL, NULL, 5, NULL),
	(-50537, 'Network_User', 'Tinklo vartotojo vardas', 7, NULL, NULL, 5, NULL),
	(-50536, 'Modem_Mode', 'Modemo režimas', 7, NULL, NULL, 5, NULL),
	(-50535, 'Modem_Protocol', 'Modemo protokolas', 7, NULL, NULL, 5, NULL),
	(-50534, 'Modem_DataWaitTimeOut_ms', 'Modemo duomenų laukimo taimautas', 7, NULL, NULL, 5, NULL),
	(-50533, 'Modem_ByteWaitTimeOut', 'Modemo tarpbaitinis laukimo laikas, baitais', 7, NULL, NULL, 5, NULL),
	(-50532, 'Modem_Speed', 'Modemo porto ryšio greitis', 7, NULL, NULL, 5, NULL),
	(-50531, 'CL_OutNexDataWaitTimeOut', 'Skaitiklio sąsajos (CL out) sekančių duomenų laukimo laikas', 7, NULL, NULL, 5, NULL),
	(-50530, 'CL_OutDataWaitTimeOut', 'Skaitiklio sąsajos (CL out) duomenų laukimo laikas', 7, NULL, NULL, 5, NULL),
	(-50529, 'CL_OutByteWaitTimeOut', 'Skaitiklio sąsajos (CL out) tarpbaitinis laukimo laikas, baitais', 7, NULL, NULL, 5, NULL),
	(-50528, 'CL_OutSpeed', 'Skaitiklio sąsajos (CL out) srovinės kilpos greitis', 7, NULL, NULL, 5, NULL),
	(-50527, 'CL_InByteWaitTimeOut', 'Vartotojo sąsajos (CL in) tarpbaitinis laukimo laikas, baitais', 7, NULL, NULL, 5, NULL),
	(-50526, 'CL_InSpeed', 'Vartotojo sąsajos (CL in) srovinės kilpos greitis', 7, NULL, NULL, 5, NULL),
	(-50525, 'ByteWaitTimeOut', 'PC sąsajos (RS232) tarpbaitinis laukimo laikas, baitais', 7, NULL, NULL, 5, NULL),
	(-50524, 'ACFaultMessagingTimeout', 'Matinimo dingimo pranešimo timeout', 7, NULL, NULL, 5, NULL),
	(-50523, 'ACFaultMessagingRetryTimes', 'Maitinimo dingimo pranešimo pakartojimo laikas', 7, NULL, NULL, 5, NULL),
	(-50522, 'ACFaultFixTime', 'Maitinimo dingimo trukmė', 7, NULL, NULL, 5, 10),
	(-50521, 'RebootTime', 'Perkrovimo laikas', 7, NULL, NULL, 5, NULL),
	(-50520, 'RequestWaitTimeOut', 'Užklausos pratęsimo taimautas', 7, NULL, NULL, 5, NULL),
	(-50519, 'DevicePassword', 'Prietaiso slaptažodis', 7, NULL, NULL, 5, NULL),
	(-50518, 'ParametrsDataLength', 'Duomenų parametrų ilgis', 7, NULL, NULL, 5, NULL),
	(-50517, 'SimplePowerEnergyTariff', 'Paprastos tarifų programos laiko žymės tarifo numeris', 7, NULL, NULL, 5, NULL),
	(-50516, 'SimpleDayProgrammBegin', 'Paprastos tarifų programos tarifų perjungimo laiko žymės', 7, NULL, NULL, 5, NULL),
	(-50515, 'SimpleLcdDisplayPeriod', 'Paprastos tarifų programos atvaizdavimo trukmė per LCD', 7, NULL, NULL, 5, NULL),
	(-50514, 'SimpleCE303LCDList1', 'Paprastos tarifų programos parametrų sąrašas per LCD', 7, NULL, NULL, 5, NULL),
	(-50513, 'SimpleActiveTouCalendarName', 'Paprastos tarifų programos pavadinimas', 7, NULL, NULL, 5, NULL),
	(-50512, 'HolidayDayProgNr', 'Šventinių dienų dienos programos numeris', 7, NULL, NULL, 5, NULL),
	(-50511, 'BillingProfilePeriod', 'Apskaitos profilio periodiškumas', 7, NULL, NULL, 5, NULL),
	(-50510, 'TimeZoneName', 'Laiko juosta', 7, NULL, NULL, 5, NULL),
	(-50509, 'TimeCorrectionLimitPerYear', 'Metinis laiko korekcijos limitas', 7, NULL, NULL, 5, NULL),
	(-50508, 'ClockAccuracy', 'Laikrodžio tikslumas', 7, NULL, NULL, 5, NULL),
	(-50507, 'RelayCoil', 'Relės ritė', 7, NULL, NULL, 5, NULL),
	(-50506, 'MoreLimitPowerControl', 'Maksimalios galios limito kontrolė', 7, NULL, NULL, 5, NULL),
	(-50505, 'EobMode', 'Apskaitos periodo uždarymas', 7, NULL, 780, 5, NULL),
	(-50504, 'LEDResetByButton', 'Įjungta/išjungta funkcija LED išjungimo mygtuko paspaudimu', 7, NULL, 779, 5, NULL),
	(-50503, 'IsPasswordProtected', 'Skaitiklis reikalauja slaptažodžio', 7, NULL, NULL, 5, NULL),
	(-50502, 'IsLicenseIDProtected', 'Skaitiklio PĮ versija, reikalaujanti licenzijos', 7, NULL, NULL, 5, NULL),
	(-50501, 'HasLoadProfile', 'Skaitiklis turi galios profilį', 7, NULL, NULL, 5, NULL),
	(-50500, 'BPC_DataIndex', 'Apskaitos profilio kanalų duomenų indeksai', 7, NULL, NULL, 5, NULL),
	(-50499, 'BPC_Attribute', 'Apskaitos profilio kanalų atributai', 7, NULL, NULL, 5, NULL),
	(-50498, 'BPC_Class_ID', 'Apskaitos profilio kanalų klasės', 7, NULL, NULL, 5, NULL),
	(-50497, 'BPC_OBIS', 'Apskaitos profilio kanalų OBIS kodai', 7, NULL, NULL, 5, NULL),
	(-50496, 'LPC_DataIndex', 'Galios profilio kanalų duomenų indeksai', 7, NULL, NULL, 5, NULL),
	(-50495, 'LPC_Attribute', 'Galios profilio kanalų atributai', 7, NULL, NULL, 5, NULL),
	(-50494, 'LPC_Class_ID', 'Galios profilio kanalų klasės', 7, NULL, NULL, 5, NULL),
	(-50493, 'LPC_OBIS', 'Galios profilio kanalų OBIS kodai', 7, NULL, NULL, 5, NULL),
	(-50492, 'SL_Dlms_Obis', 'OBIS kodų masyvas atitinkantis scaler masyvą', 7, NULL, NULL, 5, NULL),
	(-50491, 'SL_Scaler', 'Scaler (daugiklis) masyvas', 7, NULL, NULL, 5, NULL),
	(-50490, 'AL_ShortName', 'ShortName sąrašas iš Asociacijos sąrašo', 7, NULL, NULL, 5, NULL),
	(-50489, 'AL_Class_ID', 'Class ID sąrašas iš Asociacijos sąrašo', 7, NULL, NULL, 5, NULL),
	(-50488, 'AL_Dlms_Obis', 'OBIS kodų sąrašas iš Asociacijos sąrašo', 7, NULL, NULL, 5, NULL),
	(-50487, 'MACAddress', 'MAC adresas', 7, NULL, NULL, 5, NULL),
	(-50486, 'IPAddress', 'IP adresas', 7, NULL, NULL, 5, NULL),
	(-50485, 'ThermalSystem_NumberPipelines', 'Šilumos sistemos aptarnaujamų vamzdynų bendras kiekis', 7, NULL, NULL, 5, NULL),
	(-50484, 'ThermalSystem_Scheme', 'Šilumos sistemos konfigūracijos schema', 7, NULL, NULL, 5, NULL),
	(-50483, 'DemandRegisterMode', 'Demand registro rėžimas', 7, NULL, NULL, 5, NULL),
	(-50482, 'DemandRegisterPeriod', 'Demand registro periodas', 7, NULL, NULL, 5, NULL),
	(-50481, 'DemandCaptureIndex', 'Demand registro stebimo objekto Index', 7, NULL, NULL, 5, NULL),
	(-50480, 'DemandCaptureAttribute', 'Demand registro stebimo objekto Attribute', 7, NULL, NULL, 5, NULL),
	(-50479, 'DemandCaptureObisName', 'Demand registro stebimo objekto ObisName', 7, NULL, NULL, 5, NULL),
	(-50478, 'DemandCaptureClassId', 'Demand registro stebimo objekto ClassId', 7, NULL, NULL, 5, NULL),
	(-50477, 'CommunicationSuccessPercent', 'Skaitiklio ryšio sėkmės procentas per paskutines 24 valandas', 7, NULL, NULL, 5, NULL),
	(-50476, 'LastMeterResponseDate', 'Paskutinė skaitiklio atsako data', 7, NULL, NULL, 5, NULL),
	(-50475, 'AlarmRegister', 'Signalo registras', 7, NULL, NULL, 5, NULL),
	(-50474, 'MeterInfo', 'Skaitiklio informacija', 7, NULL, NULL, 5, NULL),
	(-50473, 'UniqMeterSystemTitle', 'Skaitiklio unikalus sistemos pavadinimas', 7, NULL, NULL, 5, NULL),
	(-50472, 'EnableP3_2gzip', 'Aktyvuoti P3.2 gzip kompresiją', 7, NULL, NULL, 5, NULL),
	(-50471, 'EnableP3_2Interface', 'Aktyvuoti P3.2 interfeisą', 7, NULL, NULL, 5, NULL),
	(-50470, 'DCMeterCount', 'Prie kontrolerio pajungtu skaitiklių skaičius', 7, NULL, NULL, 5, NULL),
	(-50469, 'DCUSoftVer', 'DCU programinės įrangos versija', 7, NULL, NULL, 5, NULL),
	(-50468, 'DevHardRevision', 'Kontrolerio techninės įrangos versija', 7, NULL, NULL, 5, NULL),
	(-50467, 'DevUniqSystemTitle', 'Kontrolerio unikalus sistemos pavadinimas', 7, NULL, NULL, 5, NULL),
	(-50466, 'P_C_data_index', 'Profilio kanalų sąrašo indeksai', 7, NULL, NULL, 5, NULL),
	(-50465, 'P_C_attribute_id', 'Profilio kanalų sąrašo atributų ID', 7, NULL, NULL, 5, NULL),
	(-50464, 'P_C_logical_name', 'Profilio kanalų sąrašo Obis kodai', 7, NULL, NULL, 5, NULL),
	(-50463, 'P_C_class_id', 'Profilio kanalų sąrašo klasių ID', 7, NULL, NULL, 5, NULL),
	(-50462, 'AcceptedEnergy', 'Leidžiama energija', 7, NULL, NULL, 5, NULL),
	(-50461, 'CE303LCDList6', '6-os grupės parametrų sąrašas per LCD', 7, NULL, NULL, 5, NULL),
	(-50460, 'CE303LCDList5', '5-os grupės parametrų sąrašas per LCD', 7, NULL, NULL, 5, NULL),
	(-50459, 'CE303LCDList4', '4-os grupės parametrų sąrašas per LCD', 7, NULL, NULL, 5, NULL),
	(-50458, 'CE303LCDList3', '3-os grupės parametrų sąrašas per LCD', 7, NULL, NULL, 5, NULL),
	(-50457, 'CE303LCDList2', '2-os grupės parametrų sąrašas per LCD', 7, NULL, NULL, 5, NULL),
	(-50456, 'CE303LCDList1', '1-os grupės parametrų sąrašas per LCD', 7, NULL, NULL, 5, NULL),
	(-50455, 'CE303WriteListData', 'Parametrų sąrašas, leidžiamų vartotojui programuoti', 7, NULL, NULL, 5, NULL),
	(-50454, 'CE303ReadListData', 'Parametrų sąrašas, leidžiamų vartotojui skaityti', 7, NULL, NULL, 5, NULL),
	(-50453, 'CE303AllListData', 'Parametrų sąrašas, rodomas per sąsają bendru skaitymu', 7, NULL, NULL, 5, NULL),
	(-50452, 'StInterfaceTimeOut_active', 'Sąsajos atsakymo laikas lygus sąsajos aktyvios veiklos reakcijos laikui', 7, NULL, 715, 5, NULL),
	(-50451, 'StLCDDataByList', 'Parametrų pagal sąrašą peržiūra rankiniu režimu per LCD', 7, NULL, 714, 5, NULL),
	(-50450, 'StNoClearEnergyParams', 'Energijos parametrų numetimo draudimas', 7, NULL, 713, 5, NULL),
	(-50449, 'StGotoStartCadre', 'Perjungti į pradinį kadrą', 7, NULL, 712, 5, NULL),
	(-50448, 'StLCDDayMonthData', 'Sukauptų dienos ir mėnesio energijų išvestis per LCD', 7, NULL, 711, 5, NULL),
	(-50447, 'StWriteWithoutDSTP', 'Programavimas leidžiamas be mygtuko «DSTP» paspausdimo', 7, NULL, 710, 5, NULL),
	(-50446, 'StNoAutomaticLcdData', 'Parametrų automatinės peržiūros per LCD draudimas', 7, NULL, 709, 5, NULL),
	(-50445, 'StTimeOutGreaterThen20', 'Sąsajos atsakymo laikas ne mažiau 20 ms', 7, NULL, 708, 5, NULL),
	(-50444, 'StProfileWithAdditionalData', 'Rodyti apkrovos profilių papildomą informaciją', 7, NULL, 707, 5, NULL),
	(-50443, 'StLimits_DayContol', 'Energijos limito kontrolė - paros', 7, NULL, NULL, 5, NULL),
	(-50442, 'StReadoutNoName', 'Sekančių to paties pavadinimo parametrų be pavadinimo išvestis', 7, NULL, 706, 5, NULL),
	(-50441, 'StAllReadbyList', 'Bendro skaitymo pagal sąrašą išvestis', 7, NULL, 705, 5, NULL),
	(-50440, 'StCustomReadWithPassword', 'Sąrašo atrankinis skaitymas vartotojo su slaptažodžiu', 7, NULL, 704, 5, NULL),
	(-50439, 'T_Condition_Param', 'Skaitiklio dabartinio temperatūros režimo parametras', 7, NULL, NULL, 5, NULL),
	(-50438, 'ZeroPointCorrection_Calibration', 'Nulio korekcijos kalibravimo koeficientas fazėse A, B, C', 7, NULL, NULL, 5, NULL),
	(-50437, 'ZeroPointCorrection3_Calibration', 'Nulio korekcijos kalibravimo koeficientas fazėje C', 7, NULL, NULL, 5, NULL),
	(-50436, 'ZeroPointCorrection2_Calibration', 'Nulio korekcijos kalibravimo koeficientas fazėje B', 7, NULL, NULL, 5, NULL),
	(-50435, 'ZeroPointCorrection1_Calibration', 'Nulio korekcijos kalibravimo koeficientas fazėje A', 7, NULL, NULL, 5, NULL),
	(-50434, 'PhaseDisplacement3_Calibration', 'Kampinės paklaidos korekcijos kalibravimo koeficientas fazėje C', 7, NULL, NULL, 5, NULL),
	(-50433, 'PhaseDisplacement2_Calibration', 'Kampinės paklaidos korekcijos kalibravimo koeficientas fazėje B', 7, NULL, NULL, 5, NULL),
	(-50432, 'PhaseDisplacement1_Calibration', 'Kampinės paklaidos korekcijos kalibravimo koeficientas fazėje A', 7, NULL, NULL, 5, NULL),
	(-50431, 'I3_Calibration', 'Srovės matavimo kanalų kalibravimo koeficientas fazėje C', 7, NULL, NULL, 5, NULL),
	(-50430, 'I2_Calibration', 'Srovės matavimo kanalų kalibravimo koeficientas fazėje B', 7, NULL, NULL, 5, NULL),
	(-50429, 'I1_Calibration', 'Srovės matavimo kanalų kalibravimo koeficientas fazėje A', 7, NULL, NULL, 5, NULL),
	(-50428, 'U3_Calibration', 'Įtampos matavimo kanalų kalibravimo koeficientas fazėje C', 7, NULL, NULL, 5, NULL),
	(-50427, 'U2_Calibration', 'Įtampos matavimo kanalų kalibravimo koeficientas fazėje B', 7, NULL, NULL, 5, NULL),
	(-50426, 'U1_Calibration', 'Įtampos matavimo kanalų kalibravimo koeficientas fazėje A', 7, NULL, NULL, 5, NULL),
	(-50425, 'GeneralID', 'Bendras identifikatorius', 7, NULL, NULL, 5, NULL),
	(-50424, 'FunctionLocation', 'Prietaiso funkcinė vieta', 7, NULL, NULL, 5, NULL),
	(-50423, 'StateHoliday', 'Požymis: išeiginė diena', 7, NULL, NULL, 5, NULL),
	(-50422, 'LcdListFormat', 'LCD parametrų sąrašo formatai', 7, NULL, NULL, 5, NULL),
	(-50421, 'LcdListAttrId', 'LCD parametrų sąrašo atributų ID', 7, NULL, NULL, 5, NULL),
	(-50420, 'LcdListObisName', 'LCD parametrų sąrašo Obis kodai', 7, NULL, NULL, 5, NULL),
	(-50419, 'LcdListClassId', 'LCD parametrų sąrašo klasių ID', 7, NULL, NULL, 5, NULL),
	(-50418, 'LcdOffPeriod', 'Laikas iki LCD išjungimo', 7, NULL, NULL, 5, NULL),
	(-50417, 'LcdDisplayPeriod', 'LCD atvaizdavimo trukmė', 7, NULL, NULL, 5, NULL),
	(-50416, 'InterframeTimeout', 'Paketo priėmimo timeout', 7, NULL, NULL, 5, NULL),
	(-50415, 'NeutralUndercurrentLowLimit', 'Srovės neutralėje pažemėjimo apatinė riba', 7, NULL, NULL, 5, NULL),
	(-50414, 'NeutralUndercurrentHighLimit', 'Srovės neutralėje pažemėjimo viršutinė riba', 7, NULL, NULL, 5, NULL),
	(-50413, 'NeutralOvercurrentLowLimit', 'Srovės neutralėje viršijimo apatinė riba', 7, NULL, NULL, 5, NULL),
	(-50412, 'NeutralOvercurrentHighLimit', 'Srovės neutralėje viršijimo viršutinė riba', 7, NULL, NULL, 5, NULL),
	(-50411, 'UndercurrentLowLimit', 'Srovės pažemėjimo apatinė riba', 7, NULL, NULL, 5, NULL),
	(-50410, 'UndercurrentHighLimit', 'Srovės pažemėjimo viršutinė riba', 7, NULL, NULL, 5, NULL),
	(-50409, 'OvercurrentLowLimit', 'Srovės viršijimo apatinė riba', 7, NULL, NULL, 5, NULL),
	(-50408, 'OvercurrentHighLimit', 'Srovės viršijimo viršutinė riba', 7, NULL, NULL, 5, NULL),
	(-50407, 'UndervoltageLowLimit', 'Žemaįtampio apatinė riba', 7, NULL, NULL, 5, NULL),
	(-50406, 'UndervoltageHighLimit', 'Žemaįtampio viršutinė riba', 7, NULL, NULL, 5, NULL),
	(-50405, 'OvervoltageLowLimit', 'Viršįtampio apatinė riba', 7, NULL, NULL, 5, NULL),
	(-50404, 'OvervoltageHighLimit', 'Viršįtampio viršutinė riba', 7, NULL, NULL, 5, NULL),
	(-50403, 'UndervoltageDurationForRelay', 'Žemaįtampio trukmė, kad būtų atjungta rėlė, s', 7, NULL, NULL, 5, NULL),
	(-50402, 'OvervoltageDurationForRelay', 'Viršįtampio trukmė, kad būtų atjungta rėlė, s', 7, NULL, NULL, 5, NULL),
	(-50401, 'DisplayIndication', 'Indikacijos režimas', 7, NULL, 700, 5, NULL),
	(-50400, 'SpecProgrammTariff', 'Speciali tarifų programa - tarifas', 7, NULL, NULL, 5, NULL),
	(-50399, 'SpecProgrammBegin', 'Speciali tarifų programa - laikas', 7, NULL, NULL, 5, NULL),
	(-50398, 'SundayProgrammTariff', 'Sekmadienio dienos programa  - tarifas', 7, NULL, NULL, 5, NULL),
	(-50397, 'SundayProgrammBegin', 'Sekmadienio dienos programa  - laikas', 7, NULL, NULL, 5, NULL),
	(-50396, 'SaturdayProgrammTariff', 'Šeštadienio dienos programa  - tarifas', 7, NULL, NULL, 5, NULL),
	(-50395, 'SaturdayProgrammBegin', 'Šeštadienio dienos programa  - laikas', 7, NULL, NULL, 5, NULL),
	(-50394, 'WorkDayProgrammTariff', 'Darbo dienos programa - tarifas', 7, NULL, NULL, 5, NULL),
	(-50393, 'WorkDayProgrammBegin', 'Darbo dienos programa - laikas', 7, NULL, NULL, 5, NULL),
	(-50392, 'SumEnergyLimit', 'Suminės energijos riba', 7, NULL, NULL, 5, NULL),
	(-50391, 'PowerLimUnderMinDuration', 'Uždelsimas iki galios grįžimo į normą fiksavimo', 7, NULL, NULL, 5, NULL),
	(-50390, 'PowerLimOverMinDuration', 'Uždelsimas iki galios limito peržengimo fiksavimo', 7, NULL, NULL, 5, NULL),
	(-50389, 'ExternalTariffStatus', 'Įjungta išorinė tarifikacija', 7, NULL, NULL, 5, NULL),
	(-50388, 'PowerLimitStatus', 'Galios limitai išjungia apkrovą', 7, NULL, NULL, 5, NULL),
	(-50387, 'EnergySumLimitStatus', 'Suminės energijos limitas išjungia apkrovą', 7, NULL, NULL, 5, NULL),
	(-50386, 'EnergyLimitStatus', 'Energijos limitai išjungia apkrovą', 7, NULL, NULL, 5, NULL),
	(-50385, 'MaxWorkTariffNr', 'Didžiausio galiojančio tarifo numeris', 7, NULL, NULL, 5, NULL),
	(-50384, 'DstStartHour', 'Vasaros laiko pervedimo valanda', 7, NULL, NULL, 5, NULL),
	(-50383, 'ControlModeDTStatus', 'Laikrodžio kontrolės įjungimas/išjungimas', 7, NULL, NULL, 5, NULL),
	(-50382, 'AccuracyClass', 'Tikslumo klasė', 7, NULL, NULL, 5, NULL),
	(-50381, 'ConnectionScheme', 'Įjungimo schema', 7, NULL, 697, 5, NULL),
	(-50380, 'DemandControlInterval', 'Automatinio apkrovos įjungimo intervalas', 7, NULL, NULL, 5, NULL),
	(-50379, 'DemandControlStatus', 'Automatinio apkrovos įjungimo leidimas', 7, NULL, NULL, 5, NULL),
	(-50378, 'AbonentNr', 'Abonento numeris', 7, NULL, NULL, 5, NULL),
	(-50377, 'TimeCorrectionKf', 'Laikrodžio korekcijos koeficientas', 7, NULL, NULL, 5, NULL),
	(-50376, 'InterfaceTimeOutStatus', 'Sąsajos užlaikymo įjungimas/išjungimas', 7, NULL, NULL, 5, NULL),
	(-50375, 'MeterBlockingStatus', 'Sąsajos užblokavimo konfigūracija įvedant 3 neteisingus slaptažodžius', 7, NULL, NULL, 5, NULL),
	(-50374, 'TariffsChangeStatus', 'Šventinių ir išeiginių dienų tarifų konfigūracija', 7, NULL, NULL, 5, NULL),
	(-50373, 'MeterAddress', 'Skaitiklio ryšio adresas', 7, NULL, NULL, 5, NULL),
	(-50372, 'DstEndMonth', 'Vasaros laiko pabaigos mėnuo', 7, NULL, NULL, 5, NULL),
	(-50371, 'DstStartMonth', 'Vasaros laiko pradžios mėnuo', 7, NULL, NULL, 5, NULL),
	(-50370, 'VoltDeviationLowLimit', 'Apatinė leistina riba įtampos nuokrypiui, %', 7, NULL, NULL, 5, NULL),
	(-50369, 'VoltDeviationHiLimit', 'Viršutinė leistina riba įtampos nuokrypiui, %', 7, NULL, NULL, 5, NULL),
	(-50367, 'IntBatteryVoltage', 'Vidinio akumuliatoriaus įtampa', 7, NULL, NULL, 5, NULL),
	(-50366, 'DirectAccessTimeOut', 'Nustatytas tiesioginės prieigos kanalo neaktyvumo laikas iki automatinio uždarymo, s', 7, NULL, NULL, 5, NULL),
	(-50365, 'DirectAccessIntfSlave', 'Tiesioginės prieigos slave sąsaja', 7, NULL, NULL, 5, NULL),
	(-50364, 'DirectAccessIntfMaster', 'Tiesioginės prieigos master sąsaja', 7, NULL, NULL, 5, NULL),
	(-50363, 'DDMNrInBB', 'Nuotolinio galios daviklio numeris baziniame bloke', 7, NULL, NULL, 5, NULL),
	(-50362, 'DDMType', 'Nuotolinio galios daviklio tipas', 7, NULL, NULL, 5, NULL),
	(-50361, 'DDMNr', 'Nuotolinio galios daviklio numeris', 7, NULL, NULL, 5, NULL),
	(-50360, 'RemoteControlNr', 'Valdymo pulto numeris', 7, NULL, NULL, 5, NULL),
	(-50359, 'SpecialDayProgId', 'Specialiai dienai taikomo dienos profilio identifikatorius', 7, NULL, NULL, 5, NULL),
	(-50358, 'SpecialDayDate', 'Specialios dienos data', 7, NULL, NULL, 5, NULL),
	(-50357, 'ActivateCalendarTime', 'Pasyvaus kalendoriaus aktyvavimo laikas', 7, NULL, NULL, 5, NULL),
	(-50356, 'PassiveDayProgScriptId', 'Pasyvaus kalendoriaus dienų profilio skripto selektorius', 7, NULL, NULL, 5, NULL),
	(-50355, 'ActiveDayProgScriptId', 'Aktyvaus kalendoriaus dienų profilio skripto selektorius', 7, NULL, NULL, 5, NULL),
	(-50354, 'PassiveDayProgScriptTable', 'Pasyvaus kalendoriaus dienų profilio skripto OBIS pavadinimas', 7, NULL, NULL, 5, NULL),
	(-50353, 'ActiveDayProgScriptTable', 'Aktyvaus kalendoriaus dienų profilio skripto OBIS pavadinimas', 7, NULL, NULL, 5, NULL),
	(-50352, 'PassiveDayProgStart', 'Pasyvaus kalendoriaus dienų profilio tarifo pradžios laikas', 7, NULL, NULL, 5, NULL),
	(-50351, 'ActiveDayProgStart', 'Aktyvaus kalendoriaus dienų profilio tarifo pradžios laikas', 7, NULL, NULL, 5, NULL),
	(-50350, 'PassiveDayProgId', 'Pasyvaus kalendoriaus dienų profilio dienos identifikatorius', 7, NULL, NULL, 5, NULL),
	(-50349, 'ActiveDayProgId', 'Aktyvaus kalendoriaus dienų profilio dienos identifikatorius', 7, NULL, NULL, 5, NULL),
	(-50348, 'PassiveWeekProgDays', 'Pasyvaus kalendoriaus savaitės profilio dienos', 7, NULL, NULL, 5, NULL),
	(-50347, 'ActiveWeekProgDays', 'Aktyvaus kalendoriaus savaitės profilio dienos', 7, NULL, NULL, 5, NULL),
	(-50346, 'PassiveWeekProgId', 'Pasyvaus kalendoriaus savaitės profilio pavadinimas', 7, NULL, NULL, 5, NULL),
	(-50345, 'ActiveWeekProgId', 'Aktyvaus kalendoriaus savaitės profilio pavadinimas', 7, NULL, NULL, 5, NULL),
	(-50344, 'PassiveSeasonProgWeek', 'Pasyvaus kalendoriaus sezono savaitės pavadinimas', 7, NULL, NULL, 5, NULL),
	(-50343, 'ActiveSeasonProgWeek', 'Aktyvaus kalendoriaus sezono savaitės pavadinimas', 7, NULL, NULL, 5, NULL),
	(-50342, 'PassiveSeasonProgStart', 'Pasyvaus kalendoriaus sezono pradžia', 7, NULL, NULL, 5, NULL),
	(-50341, 'ActiveSeasonProgStart', 'Aktyvaus kalendoriaus sezono pradžia', 7, NULL, NULL, 5, NULL),
	(-50340, 'PassiveSeasonProgName', 'Pasyvaus kalendoriaus sezono profilio pavadinimas', 7, NULL, NULL, 5, NULL),
	(-50339, 'ActiveSeasonProgName', 'Aktyvaus kalendoriaus sezono profilio pavadinimas', 7, NULL, NULL, 5, NULL),
	(-50338, 'PassiveTouCalendarName', 'Pasyvaus kalendoriaus pavadinimas', 7, NULL, NULL, 5, NULL),
	(-50337, 'ActiveTouCalendarName', 'Aktyvaus kalendoriaus pavadinimas', 7, NULL, NULL, 5, NULL),
	(-50336, 'S0_Output_Const', 'SO išėjimo konstanta', 7, NULL, NULL, 5, NULL),
	(-50335, 'LicenseID', 'Licenzijos identifikatorius', 7, NULL, NULL, 5, NULL),
	(-50334, 'DespoticDataCollectionChannelNr', 'Duomenų surinkimo pagal užklausimą einamieji apskaitos kanalai', 7, NULL, NULL, 5, NULL),
	(-50333, 'DespoticDataCollectionProfileNr', 'Duomenų surinkimo pagal užklausimą profilio indeksas', 7, NULL, NULL, 5, NULL),
	(-50332, 'MWDI_RelayControl', 'Skaitm. sąsajos skaitiklio relės kontrolės požymis', 7, NULL, NULL, 5, NULL),
	(-50331, 'MWDI_GroupNr', 'Skaitm. sąsajos skaitiklio apskaitos grupė', 7, NULL, NULL, 5, NULL),
	(-50330, 'IC_GroupNr', 'Apskaitos grupė IC', 7, NULL, NULL, 5, NULL),
	(-50329, 'TimeOut_CE832C5', 'Uždelsimo laikas per CE832C5, s', 7, NULL, NULL, 5, NULL),
	(-50328, 'TimeOut_CE834', 'Uždelsimo laikas per CE834, s', 7, NULL, NULL, 5, NULL),
	(-50327, 'TimeOut_CE833', 'Uždelsimo laikas per CE833, s', 7, NULL, NULL, 5, NULL),
	(-50326, 'TimeOut_CE832C4', 'Uždelsimo laikas per CE832C4, s', 7, NULL, NULL, 5, NULL),
	(-50325, 'TimeOut_CE831', 'Uždelsimo laikas per CE831, s', 7, NULL, NULL, 5, NULL),
	(-50324, 'TimeOutDirectConnection', 'Tiesioginio jungimo uždelsimo laikas, s', 7, NULL, NULL, 5, NULL),
	(-50323, 'CHANNELS_GroupNr', 'Ryšio kanalo apskaitos grupė', 7, NULL, NULL, 5, NULL),
	(-50322, 'PasswordTypeForMeterWrite', 'Skaitiklio įrašymo slaptažodio tipas', 7, NULL, NULL, 5, NULL),
	(-50321, 'PasswordForMeterWrite', 'Skaitiklio įrašymo slaptažodis', 7, NULL, NULL, 5, NULL),
	(-50320, 'EnergyLimit', 'Energijos limitas', 7, NULL, NULL, 5, NULL),
	(-50319, 'PowerLimit', 'Galios limitas', 7, NULL, NULL, 5, NULL),
	(-50318, 'MeterMeasurableChannelsInfo', 'Skaitiklio matavimo dydis', 7, NULL, NULL, 5, NULL),
	(-50317, 'MeterMeasurableChannelsNr', 'Skaitiklio apskaitos kanalo numeris', 7, NULL, NULL, 5, NULL),
	(-50316, 'TaskRunLimit', 'Vykdymo limitas', 7, NULL, NULL, 5, NULL),
	(-50315, 'TaskDelay', 'Paleidimo užlaikimas', 7, NULL, NULL, 5, NULL),
	(-50314, 'TaskReferenceTimeCnt', 'Užduoties laiko vienetų kiekis', 7, NULL, NULL, 5, NULL),
	(-50313, 'TaskDiskret', 'Laiko vienetai', 7, NULL, NULL, 5, NULL),
	(-50312, 'TaskParam2', 'Parametras 2 (profilio surinkimo gylis)', 7, NULL, NULL, 5, NULL),
	(-50311, 'TaskParam1', 'Parametras 1 (profilio numeris)', 7, NULL, NULL, 5, NULL),
	(-50310, 'TaskPriority', 'Užduoties prioritetas', 7, NULL, 648, 5, NULL),
	(-50309, 'TaskType', 'Užduoties tipas', 7, NULL, 631, 5, NULL),
	(-50308, 'ProfileDataStatus', 'Duomenų apskaitos gairė', 7, NULL, 630, 5, NULL),
	(-50307, 'ProfileChannelNr', 'Profilio apskaitos kanalo numeris', 7, NULL, NULL, 5, NULL),
	(-50306, 'ProfileDataSource', 'Apskaitos duomenų profilis-šaltinis', 7, NULL, NULL, 5, NULL),
	(-50305, 'ProfileDataType', 'Profilio dydžio tipas', 7, NULL, 629, 5, NULL),
	(-50304, 'ProfilePeriodDiscret', 'Profilio periodų laikai', 7, NULL, NULL, 5, NULL),
	(-50303, 'ProfileLengthInPercent', 'Profilio duomenų saugojimo vieta', 7, NULL, NULL, 5, NULL),
	(-50302, 'ProfileChannelsCount', 'Profilio apskaitos kanalų kiekis', 7, NULL, NULL, 5, NULL),
	(-50301, 'ProfileTarifsCount', 'Profilio tarifų kiekis', 7, NULL, NULL, 5, NULL),
	(-50300, 'ProfileName', 'Profilio aprašymas', 7, NULL, NULL, 5, NULL),
	(-50299, 'PointChannels', 'Apskaitos taško parametrai', 7, NULL, NULL, 5, NULL),
	(-50298, 'ChannelMSRKINDS', 'Matavimo dydžio kodas', 7, NULL, 628, 5, NULL),
	(-50297, 'ChannelDataSourceNr', 'Apskaitos kanalų duomenų šaltinio eilės numeris', 7, NULL, NULL, 5, NULL),
	(-50296, 'ChannelDataSourceType', 'Apskaitos kanalų duomenų šaltinio tipas', 7, NULL, 627, 5, NULL),
	(-50295, 'UserType', 'Vartotojo tipas', 7, NULL, 626, 5, NULL),
	(-50294, 'AUTOCONF_PROFILES', 'Autokonfigūravimo profiliai', 7, NULL, NULL, 5, NULL),
	(-50293, 'AUTOCONF_MSRKINDS', 'Autokonfigūravimo matavimo dydžiai', 7, NULL, NULL, 5, NULL),
	(-50292, 'CDLCHANGE_NOTIF', 'Prietaisų sąrašo pasikeitimo pranešimas', 7, NULL, NULL, 5, NULL),
	(-50291, 'AUTOCONF_CONFIRM', 'Autokonfigūravimo patvirtinimas', 7, NULL, NULL, 5, NULL),
	(-50290, 'NET_SCAN_SYSPASS', 'Pajungtų prietaisų tinklo sisteminis slaptažodis', 7, NULL, NULL, 5, NULL),
	(-50289, 'CDSLIST_READ_N', 'Pajungtų prietaisų sąrašo nuskaitymų kiekis', 7, NULL, NULL, 5, NULL),
	(-50288, 'Device_Identifier', 'Prietaiso identifikatorius', 7, NULL, NULL, 5, NULL),
	(-50287, 'NETSCANPERIODCnt', 'Laiko vienetų kiekis', 7, NULL, NULL, 5, NULL),
	(-50286, 'NETSCANPERIOD', 'Pajungtų prietaisų tinklo skenavimo periodas', 7, NULL, 625, 5, NULL),
	(-50285, 'NETSCAN', 'Pajungtų prietaisų tinklo automatinis skenavimas', 7, NULL, NULL, 5, NULL),
	(-50284, 'CHANNELS_intfType', 'Ryšio kanalo pajungimo tipas', 7, NULL, 624, 5, NULL),
	(-50283, 'CHANNELS_intfSpeed', 'Ryšio kanalo apsikeitimo greitis', 7, NULL, NULL, 5, NULL),
	(-50282, 'CHANNELS_intfNr', 'Ryšio kanalo sąsajos numeris', 7, NULL, NULL, 5, NULL),
	(-50281, 'EVENTS_COLL_DEPTH', 'Skaitiklio žurnalo surinkimo maksimalus gylis', 7, NULL, NULL, 5, NULL),
	(-50280, 'ADDRORIGIN_CONTROL', 'Skaitiklių adresų unikalumo kontrolė', 7, NULL, NULL, 5, NULL),
	(-50279, 'MAXPACKET_S', 'Duomenų surinkimo paketo maksimalus ilgis', 7, NULL, NULL, 5, NULL),
	(-50278, 'GROUPREADSt', 'Duomenų surinkimo sugrupuoto skaitymo naudojimas', 7, NULL, NULL, 5, NULL),
	(-50277, 'DATAFORMAT', 'Duomenų saugojimo ir perdavimo formatas', 7, NULL, 623, 5, NULL),
	(-50276, 'Alarm_SignalID', 'Signalizacijos kanalo identifikatorius', 7, NULL, NULL, 5, NULL),
	(-50275, 'Alarm_NotifStatus', 'Pranešimas', 7, NULL, NULL, 5, NULL),
	(-50274, 'Alarm_ChannelNr', 'Kanalo numeris šaltinyje', 7, NULL, NULL, 5, NULL),
	(-50273, 'Alarm_ChannelType', 'Signalizacijos kanalo tipas', 7, NULL, 622, 5, NULL),
	(-50272, 'Alarm_Phone_Sec', 'Papildomas telefono numeris', 7, NULL, NULL, 5, NULL),
	(-50271, 'Alarm_Phone_Prim', 'Telesignalizacijos pagrindinis telefono numeris', 7, NULL, NULL, 5, NULL),
	(-50270, 'Alarm_DialMode', 'Telesignalizacijos numerio rinkimo režimas', 7, NULL, 621, 5, NULL),
	(-50269, 'Alarm_NotifInterval', 'Pranešimo intervalas', 7, NULL, NULL, 5, NULL),
	(-50268, 'Alarm_Connection', 'Telesignalizacijos jungimo tipas', 7, NULL, 620, 5, NULL),
	(-50267, 'MWDI_MaxTime_Diff', 'Skaitm. sąsajos skaitiklio leistinas didžiausiasis nuokrypis', 7, NULL, NULL, 5, NULL),
	(-50266, 'MWDI_Extra_TimeOut_Ex', 'Skaitm. sąsajos skaitiklio atsakymo laukimo išplėstinis papildomas uždelsimo laikas', 7, NULL, NULL, 5, NULL),
	(-50265, 'MWDI_Extra_TimeOut', 'Skaitm. sąsajos skaitiklio atsakymo laukimo papildomas uždelsimo laikas', 7, NULL, NULL, 5, NULL),
	(-50264, 'MWDI_Route_CE832_transponder_Ex', 'Skaitm. sąsajos skaitiklio duomenų surinkimo per CE832 išplėstinis maršrutas. Retransliatoriaus adresas', 7, NULL, NULL, 5, NULL),
	(-50263, 'MWDI_Route_CE832_HostAddr_Ex', 'Skaitm. sąsajos skaitiklio duomenų surinkimo per CE832 išplėstinis maršrutas. Hosto adresas', 7, NULL, NULL, 5, NULL),
	(-50262, 'MWDI_Route_CE832_SubNetNNL_Ex', 'Skaitm. sąsajos skaitiklio duomenų surinkimo per CE832 išplėstinis maršrutas. NNL potinklis', 7, NULL, NULL, 5, NULL),
	(-50261, 'MWDI_Route_CE832_SubNetNr_Ex', 'Skaitm. sąsajos skaitiklio duomenų surinkimo per CE832 išplėstinis maršrutas. Loginis potinklis', 7, NULL, NULL, 5, NULL),
	(-50260, 'MWDI_Route_CE832_transponder', 'Skaitm. sąsajos skaitiklio duomenų surinkimo per CE832 maršrutas. Retransliatoriaus adresas', 7, NULL, NULL, 5, NULL),
	(-50259, 'MWDI_Route_CE832_HostAddr', 'Skaitm. sąsajos skaitiklio duomenų surinkimo per CE832 maršrutas. Hosto adresas', 7, NULL, NULL, 5, NULL),
	(-50258, 'MWDI_Route_CE832_SubNetNr', 'Skaitm. sąsajos skaitiklio duomenų surinkimo per CE832 maršrutas. Loginis potinklis', 7, NULL, NULL, 5, NULL),
	(-50257, 'MWDI_Route_CE831_transponder', 'Skaitm. sąsajos skaitiklio duomenų surinkimo per CE831 maršrutas. Retransliatoriaus adresas ', 7, NULL, NULL, 5, NULL),
	(-50256, 'MWDI_Route_CE831_receiver', 'Skaitm. sąsajos skaitiklio duomenų surinkimo per CE831 maršrutas. Imtuvo adresas ', 7, NULL, NULL, 5, NULL),
	(-50255, 'MWDI_CE832_SubNet_Ex', 'Skaitm. sąsajos skaitiklio duomenų surinkimo per CE832 išplėstinis loginis potinklis', 7, NULL, NULL, 5, NULL),
	(-50254, 'MWDI_CE832_SubNet', 'Skaitm. sąsajos skaitiklio duomenų surinkimo per CE832 loginis potinklis', 7, NULL, NULL, 5, NULL),
	(-50253, 'MWDI_Speed', 'Skaitm. sąsajos skaitiklio apsiketimo greitis', 7, NULL, NULL, 5, NULL),
	(-50252, 'MWDI_Interface', 'Skaitm. sąsajos skaitiklio sąsaja', 7, NULL, NULL, 5, NULL),
	(-50251, 'MWDI_UsePassword', 'Slaptažodis nustatytas/nenustatytas', 7, NULL, NULL, 5, NULL),
	(-50250, 'MWDI_PasswordType', 'Slaptažodžio tipas', 7, NULL, 619, 5, NULL),
	(-50249, 'MWDI_Password', 'Skaitm. sąsajos skaitiklio prieigos slaptažodis', 7, NULL, NULL, 5, NULL),
	(-50248, 'MWDI_ZigBee', 'Skaitm. sąsajos skaitiklio ZigBee modulis', 7, NULL, NULL, 5, NULL),
	(-50247, 'MWDI_Addr', 'Skaitm. sąsajos skaitiklio adresas', 7, NULL, NULL, 5, NULL),
	(-50246, 'MWDI_ID', 'Skaitm. sąsajos skaitiklio adresas-identifikatorius', 7, NULL, NULL, 5, NULL),
	(-50245, 'MWDI_ConnectType', 'Sujungimo tipas', 7, NULL, 618, 5, NULL),
	(-50244, 'MWDI_LogEvents', 'Skaitiklio žurnalo surinkimo kontrolės gairė', 7, NULL, NULL, 5, NULL),
	(-50243, 'MWDI_NrMonitoring', 'Gamyklinio skaitiklio numerio kontrolės gairė', 7, NULL, NULL, 5, NULL),
	(-50242, 'MWDI_Type', 'Skait. skaitiklio tipas', 7, NULL, 617, 5, NULL),
	(-50241, 'IC_StartValue', 'Impulsų skaitiklio pradiniai rodmenys', 7, NULL, NULL, 5, NULL),
	(-50240, 'IC_TR_EX_NoElektra', 'Vandens/dujų/šilumos skaitiklio perskaičiavimo koeficientas', 7, NULL, NULL, 5, NULL),
	(-50239, 'IC_TR_EX_I', 'Impulsų skaitiklio srovės transformatoriaus transformacijos koeficientas. Išplėstinė parinktis', 7, NULL, NULL, 5, NULL),
	(-50238, 'IC_TR_EX_U', 'Impulsų skaitiklio įtampos transformatoriaus transformacijos koeficientas. Išplėstinė parinktis', 7, NULL, NULL, 5, NULL),
	(-50237, 'IC_TR_I', 'Impulsų skaitiklio srovės transformatoriaus transformacijos koeficientas', 7, NULL, NULL, 5, NULL),
	(-50236, 'IC_TR_U', 'Impulsų skaitiklio įtampos transformatoriaus transformacijos koeficientas', 7, NULL, NULL, 5, NULL),
	(-50235, 'IC_Digit_FracPart', 'Impulsų skaitiklio apskaitos įrenginio skaitmenų skaičius po kablelio', 7, NULL, NULL, 5, NULL),
	(-50234, 'IC_Digit_IntPart', 'Impulsų skaitiklio apskaitos įrenginio skaitmenų skaičius iki kablelio', 7, NULL, NULL, 5, NULL),
	(-50233, 'IC_Ratio', 'Impulsų skaitiklio pastovioji', 7, NULL, NULL, 5, NULL),
	(-50232, 'IDC_Logging', 'Registavimas IDC būsenų pasikeitimų žurnale', 7, NULL, 616, 5, NULL),
	(-50231, 'IDC_Mode', 'IDC darbo režimas', 7, NULL, 615, 5, NULL),
	(-50230, 'CollectMonthDays', 'Duomenų surinkimo mėnesio dienos', 7, NULL, NULL, 5, NULL),
	(-50229, 'CollectWeekDays', 'Duomenų surinkimo savaitės dienos', 7, NULL, NULL, 5, NULL),
	(-50228, 'CollectModeMonths', 'Režimas rinkti duomenis per nustatytą mėnesio dieną', 7, NULL, NULL, 5, NULL),
	(-50227, 'CollectModeDays', 'Režimas rinkti duomenis per nustatytą savaitės dieną', 7, NULL, NULL, 5, NULL),
	(-50226, 'CollectIntervalsEnd', 'Duomenų surinkimo laiko intervalo pabaiga', 7, NULL, NULL, 5, NULL),
	(-50225, 'CollectIntervalsBegin', 'Duomenų surinkimo laiko intervalo pradžia', 7, NULL, NULL, 5, NULL),
	(-50224, 'ConcurrentCollection', 'Sinchroninis surinkimas per kelias sąsajas', 7, NULL, NULL, 5, NULL),
	(-50223, 'DirectAccess', 'Tiesioginė prieiga prie sąsajos', 7, NULL, 614, 5, NULL),
	(-50222, 'SessionTimeOut', 'Laikas iki ryšio seanso uždarymo', 7, NULL, NULL, 5, NULL),
	(-50221, 'InterfaceDataBit', 'Duomenų bitų kiekis', 7, NULL, NULL, 5, NULL),
	(-50220, 'InterfaceParity', 'Pariteto kontrolė', 7, NULL, 613, 5, NULL),
	(-50219, 'InterfaceStopBit', 'Sustojimo bitų kiekis', 7, NULL, NULL, 5, NULL),
	(-50218, 'InterfaceProtocol', 'Apsikeitimo protokolas', 7, NULL, 612, 5, NULL),
	(-50217, 'InterfaceSpeed', 'Sąsajos apsikeitimo greitis', 7, NULL, NULL, 5, NULL),
	(-50216, 'InterfaceTypeConnect', 'Pasijungimo tipas', 7, NULL, 611, 5, NULL),
	(-50215, 'InterfaceNr', 'Sąsajos numeris', 7, NULL, NULL, 5, NULL),
	(-50214, 'TSTOutput_Hz', 'Meandro dažnis testinio generatoriaus išejime', 7, NULL, NULL, 5, NULL),
	(-50213, 'USPDAddr', 'Koncentratoriaus tinklo adresas', 7, NULL, NULL, 5, NULL),
	(-50212, 'USPDId', 'Koncentratoriaus identifikatorius', 7, NULL, NULL, 5, NULL),
	(-50211, 'ObjectAddr', 'Objekto tinklo adresas', 7, NULL, NULL, 5, NULL),
	(-50210, 'ObjectId', 'Objekto identifikatorius', 7, NULL, NULL, 5, NULL),
	(-50209, 'TimeCorrAddr', 'Laiko korekcijos komandų šaltinio adresas', 7, NULL, NULL, 5, NULL),
	(-50208, 'TimeCorrInterface', 'Laiko korekcijos komandų sąsaja-šaltinis', 7, NULL, 610, 5, NULL),
	(-50207, 'AutoCorrectionTimeInDay', 'Automatinė laiko korekcija, s', 7, NULL, NULL, 5, NULL),
	(-50206, 'RouteNr', 'Maršruto numeris', 7, NULL, NULL, 5, NULL),
	(-50205, 'RouteId', 'Maršruto identifikatorius', 7, NULL, NULL, 5, NULL),
	(-50204, 'SetDefaultConfig', 'Įrašyti gamyklinę konfigūraciją', 7, NULL, NULL, 5, NULL),
	(-50203, 'WeekDayNr', 'Dienos numeris', 7, NULL, NULL, 5, NULL),
	(-50202, 'SetTariffsInMeterDeltaTime', 'Tarifų tvarkaraščio įrašymo į skaitiklius paskuba', 7, NULL, NULL, 5, NULL),
	(-50201, 'SetTariffsInMeterPriority', 'Tarifų tvarkaraščio įrašymo į skaitiklius prioritetas', 7, NULL, 648, 5, NULL),
	(-50200, 'SetTariffsInMeter', 'Artimiausio pagal laiką tarifų tvarkaraščio įrašymas į skaitiklius', 7, NULL, NULL, 5, NULL),
	(-50199, 'PrgBuildDT', 'Įdiegtų programų surinkimo data ir laikas', 7, NULL, NULL, 5, NULL),
	(-50198, 'IndGTMTime', 'Laiko juostos kodas', 7, NULL, NULL, 5, NULL),
	(-50197, 'PasswordParamF', 'Slaptažodis parametravimui(Gamyklinis)', 7, NULL, NULL, 5, NULL),
	(-50196, 'PasswordParamO', 'Slaptažodis parametravimui(Operatoriaus)', 7, NULL, NULL, 5, NULL),
	(-50195, 'Relay_Duration', 'Relės impulso trukmė', 7, NULL, NULL, 5, NULL),
	(-50194, 'Relay_PowerTariff', 'Relės galios tarifas', 7, NULL, NULL, 5, NULL),
	(-50193, 'Relay_EnergyTariff', 'Relės energijos tarifas', 7, NULL, NULL, 5, NULL),
	(-50192, 'Relay_EventE_Code', 'Įvykio arba būsenos OBIS kodo E grupė', 7, NULL, NULL, 5, NULL),
	(-50191, 'Relay_EventD_Code', 'Įvykio arba būsenos OBIS kodo D grupė', 7, NULL, NULL, 5, NULL),
	(-50190, 'Relay_EventC_Code', 'Įvykio arba būsenos OBIS kodo C grupė', 7, NULL, NULL, 5, NULL),
	(-50189, 'Relay_Border', 'Riba procentais', 7, NULL, NULL, 5, NULL),
	(-50188, 'Relay_StartTime', 'Sekundes N nuo integravimo periodo pradžios', 7, NULL, NULL, 5, NULL),
	(-50187, 'Relay_Power', 'Galios rūšis', 7, NULL, 595, 5, NULL),
	(-50186, 'Relay_Quadrant4', '4 kvadrantas', 7, NULL, NULL, 5, NULL),
	(-50185, 'Relay_Quadrant3', '3 kvadrantas', 7, NULL, NULL, 5, NULL),
	(-50184, 'Relay_Quadrant2', '2 kvadrantas', 7, NULL, NULL, 5, NULL),
	(-50183, 'Relay_Quadrant1', '1 kvadrantas', 7, NULL, NULL, 5, NULL),
	(-50182, 'RelayMode', 'Relinio išvado funkcija', 7, NULL, 594, 5, NULL),
	(-50181, 'PasswordParam', 'Slaptažodis parametravimui', 7, NULL, NULL, 5, NULL),
	(-50180, 'MeterNrInBuffer', 'Skaitiklio numeris buferyje', 7, NULL, NULL, 5, NULL),
	(-50179, 'BuffParam3', 'Buferavimo parametras 3', 7, NULL, NULL, 5, NULL),
	(-50178, 'BuffParam2', 'Buferavimo parametras 2', 7, NULL, NULL, 5, NULL),
	(-50177, 'BuffParam1', 'Buferavimo parametras 1', 7, NULL, NULL, 5, NULL),
	(-50176, 'BufferingPeriod', 'Buferavimo periodas (minutėmis)', 7, NULL, NULL, 5, NULL),
	(-50175, 'Cl_Protocol', 'Srovinių kilpų (cl) protokolo numeris', 7, NULL, NULL, 5, NULL),
	(-50174, 'CL_RepeatTimeOut', 'Srovinių kilpų (cl) perklausimo užlaikymas (sekundėmis)', 7, NULL, NULL, 5, NULL),
	(-50173, 'CL_TimeOut', 'Srovinių kilpų (cl) numatytas laukimo laikas (timeout) (sekundėmis)', 7, NULL, NULL, 5, NULL),
	(-50172, 'CL_LinkSpeed', 'Srovinės kilpos (cl) ryšio greitis (bodais)', 7, NULL, NULL, 5, NULL),
	(-50171, 'LinkWatchDog', 'Užlaikymas persikrovimui po paskutinio išduoto paketo', 7, NULL, NULL, 5, NULL),
	(-50170, 'LinkRepeatCount', 'Ryšio pakartojimų skaičius', 7, NULL, NULL, 5, NULL),
	(-50169, 'RS232_Speed', 'Ryšio greitis (RS-232)', 7, NULL, NULL, 5, NULL),
	(-50168, 'GPRS_Speed', 'Ryšio greitis (GPRS)', 7, NULL, NULL, 5, NULL),
	(-50167, 'Lan_Spead', 'Ryšio greitis (LAN)', 7, NULL, NULL, 5, NULL),
	(-50166, 'MeterType', 'Skaitiklio tipas', 7, NULL, NULL, 5, NULL),
	(-50165, 'GroupNr', 'Grupės numeris', 7, NULL, NULL, 5, NULL),
	(-50164, 'CurrentLoopNr', 'Srovinės kilpos (CL) numeris', 7, NULL, NULL, 5, NULL),
	(-50163, 'MeterNrInMeterList', 'Skaitiklio numeris skaitiklių sąraše', 7, NULL, NULL, 5, NULL),
	(-50162, 'PrgChannelsObisCode', 'Laisvai programuojamo kanalo OBIS kodas', 7, NULL, NULL, 5, NULL),
	(-50161, 'CyclicDispleyName', 'Ciklinės indikacijos sekos pavadinimas', 7, NULL, NULL, 5, NULL),
	(-50160, 'CyclicDispleyObisCode', 'Ciklinės indikacijos sekos OBIS kodas', 7, NULL, NULL, 5, NULL),
	(-50159, 'StaticDispleyName', 'Statinės indikacijos sekos pavadinimas', 7, NULL, NULL, 5, NULL),
	(-50158, 'StaticDispleyObisCode', 'Statinės indikacijos sekos OBIS kodas', 7, NULL, NULL, 5, NULL),
	(-50157, 'PassiveWeekProgNr', 'Pasyvaus sezono savaitės programos numeris', 7, NULL, NULL, 5, NULL),
	(-50156, 'ChannelsIntPeriod', 'Laisvai programuojamų kanalų integravimo periodas', 7, NULL, NULL, 5, NULL),
	(-50155, 'TMOut_S_Quadrants', 'Pilnoji energija - telemetrinis kvardanto išejimas', 7, NULL, NULL, 5, NULL),
	(-50154, 'TMOut_R_Quadrants', 'Reaktyvinė energija - telemetrinis kvardanto išejimas', 7, NULL, NULL, 5, NULL),
	(-50153, 'TMOut_A_Quadrants', 'Aktyvinė energija - telemetrinis kvardanto išejimas', 7, NULL, NULL, 5, NULL),
	(-50152, 'TMOut_S', 'Pilnoji energija - telemetrinis išejimas', 7, NULL, NULL, 5, NULL),
	(-50151, 'TMOut_R', 'Reaktyvinė energija - telemetrinis išejimas', 7, NULL, NULL, 5, NULL),
	(-50150, 'TMOut_A', 'Aktyvinė energija - telemetrinis išejimas', 7, NULL, NULL, 5, NULL),
	(-50149, 'Percent_Display_FracPart', 'Procentų trupmeninės dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50148, 'Percent_Display_IntPart', 'Procentų sveikosios dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50147, 'Cos_Display_FracPart', 'Galios faktoriaus trupmeninės dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50146, 'Cos_Display_IntPart', 'Galios faktoriaus sveikosios dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50145, 'Hz_Display_FracPart', 'Dažnio trupmeninės dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50144, 'Hz_Display_IntPart', 'Dažnio sveikosios dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50143, 'U_Display_FracPart', 'Įtampos trupmeninės dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50142, 'U_Display_IntPart', 'Įtampos sveikosios dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50141, 'I_Display_FracPart', 'Srovės trupmeninės dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50140, 'I_Display_IntPart', 'Srovės sveikosios dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50139, 'Power_Inst_Display_FracPart', 'Momentinės galios trupmeninės dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50138, 'Power_Inst_Display_IntPart', 'Momentinės galios sveikosios dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50137, 'Power_Com_Display_FracPart', 'Kumuliacinės galios trupmeninės dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50136, 'Power_Com_Display_IntPart', 'Kumuliacinės galios sveikosios dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50135, 'Power_Max_Display_FracPart', 'Maksimalios galios trupmeninės dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50134, 'Power_Max_Display_IntPart', 'Maksimalios galios sveikosios dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50133, 'Power_Display_FracPart', 'Galios trupmeninės dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50132, 'Power_Display_IntPart', 'Galios sveikosios dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50131, 'Energy_Day_Display_FracPart', 'Paros energijos trupmeninės dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50130, 'Energy_Day_Display_IntPart', 'Paros energijos sveikosios dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50129, 'Energy_Mon_Display_FracPart', 'Menėsio energijos trupmeninės dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50128, 'Energy_Mon_Display_IntPart', 'Menėsio energijos sveikosios dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50127, 'Energy_Total_Display_FracPart', 'Suminės energijos trupmeninės dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50126, 'Energy_Total_Display_IntPart', 'Suminės energijos sveikosios dalies atvaizdavimas', 7, NULL, NULL, 5, NULL),
	(-50125, 'OpticParametrizationSealing', 'Optinio porto plombavimas parametravimui', 7, NULL, NULL, 5, NULL),
	(-50124, 'MaxPowerKey', 'Maksimalios galios numetimo mygtukas', 7, NULL, NULL, 5, NULL),
	(-50123, 'SMom_Accepted', 'Pilnos momentinės galios matavimas leistas', 7, NULL, NULL, 5, NULL),
	(-50122, 'UnrestrainedBadPassword', 'Blogo slaptažodžio skaitliukas neapribotas', 7, NULL, NULL, 5, NULL),
	(-50121, 'UnrestrainedTimeCorrection', 'Laiko korekcija neapribota', 7, NULL, NULL, 5, NULL),
	(-50120, 'R_Accepted', 'Reaktyvios energijos matavimas leistas', 7, NULL, NULL, 5, NULL),
	(-50119, 'S_Accepted', 'Pilnos energijos matavimas leistas', 7, NULL, NULL, 5, NULL),
	(-50118, 'S_CalckMetod', 'Pilnos energijos apskaičiavimo metodas', 7, NULL, NULL, 5, NULL),
	(-50117, 'Three_wire', 'Trijų laidų skaitiklis', 7, NULL, NULL, 5, NULL),
	(-50116, 'DisplayLighting', 'Displejaus pašviesinimas', 7, NULL, NULL, 5, NULL),
	(-50115, 'OpticSealing', 'Optinio porto plombavimas', 7, NULL, NULL, 5, NULL),
	(-50114, 'MagneticFieldCheck', 'Magnetinio poveikio patikrinimas leistas', 7, NULL, NULL, 5, NULL),
	(-50113, 'A_Monitoring', 'Energijos kokybės monitoringas lestas', 7, NULL, NULL, 5, NULL),
	(-50112, 'CaseOpenCheck', 'Korpuso atidarymo patikrinimas leistas', 7, NULL, NULL, 5, NULL),
	(-50111, 'Cannels_11007_Form', 'Laisvai programuojamų kanalų nuskaitymo protokolu IEC1107 forma', 7, NULL, NULL, 5, NULL),
	(-50110, 'BatteryCheck', 'Maitinimo elemento įtampos patikrinimas leistas', 7, NULL, NULL, 5, NULL),
	(-50109, 'TemperatureTimeCorrection', 'Temperatūrinė laiko korekcija leista', 7, NULL, NULL, 5, NULL),
	(-50108, 'PassiveSeasonsStart', 'Pasyvaus sezono aktyvavimo laikas', 7, NULL, NULL, 5, NULL),
	(-50107, 'Maximal_T', 'Maksimali temperatūra', 7, NULL, NULL, 5, NULL),
	(-50106, 'Minimal_T', 'Minimali temperatūra', 7, NULL, NULL, 5, NULL),
	(-50105, 'MonitoringBegin', 'Energijos monitoringo pradžia', 7, NULL, NULL, 5, NULL),
	(-50104, 'EmergencyEnergyTariff', 'Avarinis energijos tarifas', 7, NULL, NULL, 5, NULL),
	(-50103, 'EmergencyMaxPowerTariff', 'Avarinis maksimalios galios tarifas', 7, NULL, NULL, 5, NULL),
	(-50102, 'BillingDay', 'Apskaito periodo pradžios laikas', 7, NULL, NULL, 5, NULL),
	(-50101, 'IntPeriodCount', 'Integravimo periodų skaičius', 7, NULL, NULL, 5, NULL),
	(-50100, 'StaticDispleyDuration', 'Statistinės indikacijos trukmė', 7, NULL, NULL, 5, NULL),
	(-50099, 'CyclicDispleyDuration', 'Ciklinės indikacijos trukmė', 7, NULL, NULL, 5, NULL),
	(-50098, 'Shift_Time', 'Poslinkis nuo GMT', 7, NULL, NULL, 5, NULL),
	(-50097, 'DST_Time', 'Laiko pervedimo delta ', 7, NULL, NULL, 5, NULL),
	(-50096, 'Maximal_Hz', 'Maksimalus dažnis', 7, NULL, NULL, 5, NULL),
	(-50095, 'Minimal_Hz', 'Minimalus dažnis', 7, NULL, NULL, 5, NULL),
	(-50094, 'Maximal_U', 'Maksimali įtampa', 7, NULL, NULL, 5, NULL),
	(-50093, 'Minimal_U', 'Minimali įtampa', 7, NULL, NULL, 5, NULL),
	(-50092, 'Maximal_I', 'Maksimali srovė', 7, NULL, NULL, 5, NULL),
	(-50091, 'Nominal_Hz', 'Nominalus dažnis', 7, NULL, NULL, 5, NULL),
	(-50090, 'Nominal_I', 'Nominali srovė', 7, NULL, NULL, 5, NULL),
	(-50089, 'Nominal_U', 'Nominali įtampa', 7, NULL, NULL, 5, NULL),
	(-50088, 'MeterLanguage', 'Prietaiso kalba', 7, NULL, NULL, 5, NULL),
	(-50087, 'CL_Speed', 'Ryšio greitis', 7, NULL, NULL, 5, NULL),
	(-50086, 'BetweenPackFactor', 'Pauzė tarp paketų', 7, NULL, NULL, 5, NULL),
	(-50085, 'BetweenByteFactor', 'Pauzė tarp baitų', 7, NULL, NULL, 5, NULL),
	(-50084, 'MetrFunctionLED_Hz', 'LED dažnis', 7, NULL, NULL, 5, NULL),
	(-50083, 'MetrFunctionLED_S', 'LED pilnoji galia', 7, NULL, NULL, 5, NULL),
	(-50082, 'MetrFunctionLED_Q', 'LED reaktyvinė galia', 7, NULL, NULL, 5, NULL),
	(-50081, 'MetrFunctionLED_P', 'LED aktyvinė galia', 7, NULL, NULL, 5, NULL),
	(-50080, 'IndicationWithKoef', 'Indikacija atsižvelgiant į transformacijos koeficientus', 7, NULL, NULL, 5, NULL),
	(-50079, 'SeasonChangeStatus', 'Sezoninis laiko pervedimas leistas', 7, NULL, 947, 5, NULL),
	(-50078, 'Location', 'Vietovė', 7, NULL, NULL, 5, NULL),
	(-50077, 'Model', 'Modelis', 7, NULL, NULL, 5, NULL),
	(-50076, 'Manufacturer', 'Gamintojas', 7, NULL, NULL, 5, NULL),
	(-50075, 'Meter_Pause', 'Minimalios pauzės trukmė', 7, NULL, NULL, 5, NULL),
	(-50074, 'Meter_ImpulsDuration', 'Impulso trukmė', 7, NULL, NULL, 5, NULL),
	(-50073, 'Meter_Kf', 'Skaitiklio konstanta - imp/kWh', 7, NULL, NULL, 5, NULL),
	(-50072, 'Hilbert_TrKf', 'Hilberto transformacijos koeficientas', 7, NULL, NULL, 5, NULL),
	(-50071, 'R_Offset', 'Reaktyvinės energijos poslinkis', 7, NULL, NULL, 5, NULL),
	(-50070, 'A_Offset', 'Aktyvinės energijos poslinkis', 7, NULL, NULL, 5, NULL),
	(-50069, 'Phase_Calibration', 'Fazių poslinkio kalibravimas', 7, NULL, NULL, 5, NULL),
	(-50068, 'I_Calibration', 'Srovės kalibravimas', 7, NULL, NULL, 5, NULL),
	(-50067, 'U_Calibration', 'Įtampos kalibravimas', 7, NULL, NULL, 5, NULL),
	(-50066, 'T_Calibration', 'Temperatūros kalibravimas', 7, NULL, NULL, 5, NULL),
	(-50065, 'Starting_I', 'Pradinė srovė', 7, NULL, NULL, 5, NULL),
	(-50064, 'Nominal_T', 'Nominali temperatūra', 7, NULL, NULL, 5, NULL),
	(-50063, 'ClockCalibration', 'Laikrodžio kalibravimas', 7, NULL, NULL, 5, NULL),
	(-50062, 'Kf_Ki_denominator', 'Koeficiento I vardiklis ', 7, NULL, NULL, 5, NULL),
	(-50061, 'Kf_Ki_numerator', 'Koeficiento I skaitiklis ', 7, NULL, NULL, 5, NULL),
	(-50060, 'Kf_Ku_denominator', 'Koeficiento U vardiklis ', 7, NULL, NULL, 5, NULL),
	(-50059, 'Kf_Ku_numerator', 'Koeficiento U skaitiklis ', 7, NULL, NULL, 5, NULL),
	(-50058, 'KF_I_NoExponent', 'Koeficientas I neatsižvelgiant į dešimties laipsnio rodiklį', 7, NULL, NULL, 5, NULL),
	(-50057, 'KF_U_NoExponent', 'Koeficientas U neatsižvelgiant į dešimties laipsnio rodiklį', 7, NULL, NULL, 5, NULL),
	(-50056, 'PowerTariff', 'Galios tarifas', 7, NULL, NULL, 5, NULL),
	(-50055, 'DayProgrammEnd', 'Savaitės programos pabaigos laikas', 7, NULL, NULL, 5, NULL),
	(-50054, 'ActiveSeasonsEnd', 'Sezono pabaigos laikas', 7, NULL, NULL, 5, NULL),
	(-50053, 'TM_OutPause', 'Pauzė tarp impulsų TM_OUT', 7, NULL, NULL, 5, NULL),
	(-50052, 'TM_OutImpulsDuration', 'Impulso trukmė TM_OUT', 7, NULL, NULL, 5, NULL),
	(-50051, 'TM_InPause', 'Pauzė tarp impulsų TM_IN', 7, NULL, NULL, 5, NULL),
	(-50050, 'TM_InImpulsDuration', 'Impulso trukmė TM_IN', 7, NULL, NULL, 5, NULL),
	(-50049, 'TM_KF', 'Q+ Q- išėjimo koeficientas TM', 7, NULL, NULL, 5, NULL),
	(-50048, 'TM_OutKf', 'P+ P- išėjimo koeficientas TM', 7, NULL, NULL, 5, NULL),
	(-50047, 'MetrologyTM_Out_Kf', 'Metrologinio išėjimo koeficientas TM', 7, NULL, NULL, 5, NULL),
	(-50046, 'TM_IN_Kf_exponent', 'Koeficiento TM_IN dešimties laipsnio rodiklis', 7, NULL, NULL, 5, NULL),
	(-50045, 'TM_IN_Kf', 'Koeficientas TM_IN', 7, NULL, NULL, 5, NULL),
	(-50044, 'MonthEnd', 'Mėnesio pabaiga', 7, NULL, NULL, 5, NULL),
	(-50043, 'MetrologyStatus', 'Metrologijos požymis', 7, NULL, NULL, 5, NULL),
	(-50042, 'TarifExitStatus', 'Tarifinių išėjimų požymis', 7, NULL, NULL, 5, NULL),
	(-50041, 'Time_CorrectionStatus', 'Laiko korekcijos požymis', 7, NULL, NULL, 5, NULL),
	(-50040, ' Kf_exponent', 'Transformacijos koeficientų dešimties laipsnio rodiklis', 7, NULL, NULL, 5, NULL),
	(-50038, 'Kf_Ku_exponent', 'Koeficiento U dešimties laipsnio rodiklis', 7, NULL, NULL, 5, NULL),
	(-50037, 'Kf_Ku_FracPart', 'Koeficiento U trupmeninė dalis', 7, NULL, NULL, 5, NULL),
	(-50036, 'Kf_Ku_IntPart', 'Koeficiento U sveikoji dalis', 7, NULL, NULL, 5, NULL),
	(-50035, 'Kf_Ki_exponent', 'Koeficiento I dešimties laipsnio rodiklis', 7, NULL, NULL, 5, NULL),
	(-50034, 'Kf_Ki_FracPart', 'Koeficiento I trupmeninė dalis', 7, NULL, NULL, 5, NULL),
	(-50033, 'Kf_Ki_IntPart', 'Koeficiento I sveikoji dalis', 7, NULL, NULL, 5, NULL),
	(-50032, 'Kf_Ki', 'Momentinių konvertavimo koeficientas Ki', 7, NULL, NULL, 5, NULL),
	(-50031, 'Kf_Ku', 'Momentinių konvertavimo koeficientas Ku', 7, NULL, NULL, 5, NULL),
	(-50030, 'Kf_Km', 'Momentinių konvertavimo koeficientas Km', 7, NULL, NULL, 5, NULL),
	(-50029, 'Kf_Kd', 'Momentinių konvertavimo koeficientas Kd', 7, NULL, NULL, 5, NULL),
	(-50028, 'ParamBitMask', 'Parametravimo leidimo kaukė', 7, NULL, NULL, 5, NULL),
	(-50027, 'WrongPasswordCount', 'Neteisingo slaptažodžio skaitliukas', 7, NULL, NULL, 5, NULL),
	(-50026, 'EnergyTariffsNum', 'Energijos tarifų skaičius', 7, NULL, NULL, 5, NULL),
	(-50025, 'MaxPowerTariffsNum', 'Galios tarifų skaičius', 7, NULL, NULL, 5, NULL),
	(-50024, 'MaxPower_length', 'Maksimumų saugojimo dienų skaičius', 7, NULL, NULL, 5, NULL),
	(-50023, 'MinNonRecTime', 'Minimali nefiksuojama maitinimo dingimo trukmė', 7, NULL, NULL, 5, NULL),
	(-50022, 'UserName', 'Vartotojo vardas', 7, NULL, NULL, 5, NULL),
	(-50021, 'EnergyTariff', 'Energijos tarifas', 7, NULL, NULL, 5, NULL),
	(-50020, 'PowerEnergyTariff', 'Galios ir energijos tarifas', 7, NULL, NULL, 5, NULL),
	(-50019, 'DayProgrammBegin', 'Dienos programos pradinis laikas', 7, NULL, NULL, 5, NULL),
	(-50018, 'WeekProgHoliday', 'Savaitės profilis - šventės', 7, NULL, NULL, 5, NULL),
	(-50017, 'WeekProgSunday', 'Savaitės profilis - sekmadienis', 7, NULL, NULL, 5, NULL),
	(-50016, 'WeekProgSaturday', 'Savaitės profilis - šeštadienis', 7, NULL, NULL, 5, NULL),
	(-50015, 'WeekProgFriday', 'Savaitės profilis - penktadienis', 7, NULL, NULL, 5, NULL),
	(-50014, 'WeekProgThursday', 'Savaitės profilis - ketvirtadienis', 7, NULL, NULL, 5, NULL),
	(-50013, 'WeekProgWednesday', 'Savaitės profilis - trečiadienis', 7, NULL, NULL, 5, NULL),
	(-50012, 'WeekProgTuesday', 'Savaitės profilis - antradienis', 7, NULL, NULL, 5, NULL),
	(-50011, 'WeekProgMonday', 'Savaitės profilis - pirmadienis', 7, NULL, NULL, 5, NULL),
	(-50010, 'ActiveWeekProgNr', 'Savaitės programos numeris', 7, NULL, NULL, 5, NULL),
	(-50009, 'PassiveSeasonsBegin', 'Pasyvaus sezono pradinis laikas', 7, NULL, NULL, 5, NULL),
	(-50008, 'ActiveSeasonsBegin', 'Aktyvaus sezono pradinis laikas', 7, NULL, NULL, 5, NULL),
	(-50007, 'DayProgNr', 'Dienos programos numeris', 7, NULL, NULL, 5, NULL),
	(-50006, 'SpecialDays', 'Specialios dienos', 7, NULL, NULL, 5, NULL),
	(-50005, 'Holiday', 'Šventinių dienų kalendorius', 7, NULL, NULL, 5, NULL),
	(-50004, 'CustomerCode', 'Kliento kodas', 7, NULL, NULL, 5, NULL),
	(-50003, 'WinterTime', 'Laiko pervedimas - žiema', 7, NULL, NULL, 5, NULL),
	(-50002, 'SummerTime', 'Laiko pervedimas - vasara', 7, NULL, NULL, 5, NULL),
	(-50001, 'RelayInfoEnd', 'Relės suveikimo galutinis laikas', 7, NULL, NULL, 5, NULL),
	(-50000, 'RelayInfoBegin', 'Relės suveikimo pradinis laikas', 7, NULL, NULL, 5, NULL),
	(-31, 'Device_Implementation', 'Prietaiso implementacija', 7, NULL, NULL, 5, NULL),
	(-18, 'Full_Consts', 'Prietaisų konfigūracijos parametrai - konstantos ', 7, NULL, NULL, 5, NULL),
	(-17, 'Full_Tariffications', 'Prietaisų konfigūracijos parametrai - tarifai ', 7, NULL, NULL, 5, NULL),
	(-16, 'Full_Configuration', 'Visi prietaisų konfigūracijos parametrai', 7, NULL, NULL, 5, NULL),
	(-15, 'Kf_WhMask', 'WhMask koeficientas', 7, NULL, NULL, 5, NULL),
	(-13, 'Profile_length', 'Profilio saugojimo dienų skaičius', 7, NULL, NULL, 5, NULL),
	(-12, 'Direct_Connection', 'Tiesiogino įjungimo skaitiklis', 7, NULL, NULL, 5, NULL),
	(-11, 'PQ_Resolution', 'Slenkstinė energija A, R', 7, NULL, NULL, 5, NULL),
	(-10, 'KF_I', 'Srovės transformacijos koeficientas', 7, NULL, NULL, 5, NULL),
	(-9, 'KF_U', 'Įtampos transformacijos koeficientas', 7, NULL, NULL, 5, NULL),
	(-8, 'Int_Period', 'Integravimo periodas', 7, NULL, NULL, 5, NULL),
	(-7, 'TypeCode', 'Prietaiso tipas', 7, NULL, NULL, 5, NULL),
	(-5, 'Device_Nr', 'Prietaiso numeris', 7, NULL, NULL, 5, NULL),
	(-4, 'BatteryLife', 'Likęs baterijos laikas sekundėmis', 15, NULL, NULL, 4, 10),
	(-3, 'Device_Version', 'Prietaiso versija', 7, NULL, NULL, 5, NULL),
	(-1, 'Time_Read', 'Laikas', 10, NULL, NULL, 7, NULL),
	(1115, 'Gas_ContentN2', 'Azoto dalis dujose', 7, NULL, NULL, 5, 9),
	(1116, 'Gas_ContentCO2', 'CO2 dalis dujose', 7, NULL, NULL, 5, 9),
	(1170, 'Gas_CalorificValue', 'Viršutinis dujų šilumingumas', 7, NULL, NULL, 5, 82),
	(1172, 'Gas_RelativeDensity', 'Santykinis dujų tankis', 7, NULL, NULL, 5, 0),
	(3101, 'ErrorCode', 'Klaidos kodas', 9, NULL, NULL, 1, NULL),
	(4001, 'DevTemp', 'Prietaiso vidinė temperatūra', 5, NULL, NULL, 1, 27),
	(4002, 'GSMSignalQuality_1_31', 'Gauto signalo kokybė', 11, NULL, NULL, 1, NULL),
	(4011, 'ChargingStatus', 'Krovimo būklė', 5, NULL, 1028, 1, NULL),
	(4012, 'GSMSignalStrength_dBm', 'GSM signalo stiprumas', 11, NULL, NULL, 1, 58),
	(4013, 'CLInStatus', 'Vartotojo sąsajos (Cl in) būklė', 5, NULL, 1029, 1, NULL),
	(4014, 'CLOutStatus', 'Skaitiklio sąsajos (Cl out) būklė', 5, NULL, 1030, 1, NULL),
	(4015, 'ACStatus', 'Maitinimo (AC) būklė', 6, NULL, 1031, 1, NULL),
	(4017, 'ACFaultCount', 'Maitinimo (AC) dingimų kiekis', 6, NULL, NULL, 3, NULL),
	(4019, 'IntBatteryVoltageMeasured', 'Vidinio akumuliatoriaus įtampa (išmatuota)', 21, NULL, NULL, 3, 6),
	(4020, 'ExtBatteryVoltageMeasured', 'Išorinio akumuliatoriaus įtampa (išmatuota)', 21, NULL, NULL, 3, 6),
	(9999, 'UnknownEvent', 'Nežinomas įvykis', 9, NULL, 416, 1, NULL),
	(10000, 'Phase_1', 'Fazė L1', 2, 1, 149, 1, NULL),
	(10001, 'Phase_2', 'Fazė L2', 2, 1, 150, 1, NULL),
	(10002, 'Phase_3', 'Fazė L3', 2, 1, 151, 1, NULL),
	(10003, 'Magnetic_Field', 'Magnetinio lauko poveikis skaitikliui', 1, 0, 153, 1, NULL),
	(10004, 'Bad_Temperature', 'Netinkama temperatura', 1, 0, 154, 1, NULL),
	(10005, 'Link_Blocked', 'Ryšio blokavimas', 9, 0, 155, 1, NULL),
	(10006, 'Manufacturer_Access', 'Leidimas gamykliniam parametravimui', 7, 1, 156, 1, NULL),
	(10007, 'Wrong_Phase_Sequence', 'Fazių seka korektiška', 9, 1, 148, 1, NULL),
	(10008, 'Clock_Confusion', 'Laikrodžio sutrikimas', 9, 0, 157, 1, NULL),
	(10009, 'Fatal_Error', 'Fatalinė klaida', 9, 0, 147, 1, NULL),
	(10010, 'Relay_1', 'Relės nr.1 jungimas', 8, 0, 158, 1, NULL),
	(10011, 'Relay_2', 'Relės nr.2 jungimas', 8, 0, 159, 1, NULL),
	(10012, 'Low_Baterry', 'Maitinimo elemento pakrovimas', 9, 1, 146, 1, NULL),
	(10013, 'Summer_Time', 'Vasaros laikas', 4, 0, 160, 1, NULL),
	(10014, 'Case_Open', 'Korpuso atidarymas', 1, NULL, 792, 1, NULL),
	(10015, 'Timer_Setting', 'Laiko nustatymas', 12, NULL, 416, 1, NULL),
	(10016, 'Cumulative_Power_Reset', 'Sukauptų duomenų anuliavimas', 7, NULL, 416, 1, NULL),
	(10017, 'Remote_Parametrization', 'Skaitiklio paskutinio parametravimo data per kilpą', 7, NULL, 416, 1, NULL),
	(10018, 'Local_Parametrization', 'Vietinis parametravimas', 7, NULL, 774, 1, NULL),
	(10019, 'Day_Max_Demand_Reset', 'Paros maksimalios galios anuliavimas', 7, NULL, 416, 1, NULL),
	(10020, 'Month_Max_Demand_Reset', 'Mėnesių maksimalios galios anuliavimas', 7, NULL, 416, 1, NULL),
	(10021, 'Day_Energy_Reset', 'Paros energijos anuliavimas', 7, NULL, 416, 1, NULL),
	(10022, 'Month_Energy_Reset', 'Mėnesių energijos anuliavimas', 7, NULL, 416, 1, NULL),
	(10023, 'Timer_Adjust_Forward', 'Laiko korekcija į priekį', 4, NULL, 416, 1, NULL),
	(10024, 'Error_Without_Reset', 'Klaida, nereikalaujanti perkrovimo', 9, NULL, 416, 1, NULL),
	(10025, 'Error_Need_Reset', 'Klaida, reikalaujanti perkrovimo', 9, NULL, 416, 1, NULL),
	(10026, 'Watchdog_Reset', 'Perkrovimas dėl WatchDog', 9, NULL, 416, 1, NULL),
	(10027, 'Illegal_Operation', 'Neleistina operacija', 9, NULL, 416, 1, NULL),
	(10028, 'Timer_Adjust_Back', 'Laiko korekcija atgal', 4, NULL, 416, 1, NULL),
	(10029, 'PowerOn', 'Maitinimas', 6, 1, 152, 1, NULL),
	(10030, 'PowerReserveOn', 'Skaitiklis rezerviniame maitinime', 6, 0, 161, 1, NULL),
	(10031, 'UnauthorizedAccess', 'Nesankcionuota prieiga prie skaitiklio', 1, NULL, 416, 1, NULL),
	(10032, 'Parametrization', 'Skaitiklio perprogramavimas', 7, NULL, 416, 1, NULL),
	(10033, 'ProfileInit', 'Galios profilio pirmo masyvo inicializacija', 7, NULL, 416, 1, NULL),
	(10034, 'Profile2Init', 'Galios profilio antro masyvo inicializacija', 7, NULL, 416, 1, NULL),
	(10035, 'StatusWordChange', 'Statuso žodžio pakeitimas', 7, NULL, 416, 1, NULL),
	(10036, 'Link1Configuration', 'Interfeiso 1 parametrų keitimas', 7, NULL, 416, 1, NULL),
	(10037, 'Link2Configuration', 'Interfeiso 2 parametrų keitimas', 7, NULL, 416, 1, NULL),
	(10038, 'SettingChange', 'Programuojamų vėliavų keitimas, nurodančių skaitiklio darbo režimą', 7, NULL, 416, 1, NULL),
	(10039, 'SummerTimeBeginChange', 'Perėjimo į vasaros laiką laiko keitimas', 7, NULL, 416, 1, NULL),
	(10040, 'SummerTimeEndChange', 'Perėjimo į žiemos laiką laiko keitimas', 7, NULL, 416, 1, NULL),
	(10041, 'TransfCoefChange', 'Transformacijos koeficientų keitimas', 7, NULL, 416, 1, NULL),
	(10042, 'SerialNumbChange', 'Skaitiklio serijinio numerio ir gamybos datos keitimas', 7, NULL, 416, 1, NULL),
	(10043, 'Reboot', 'Perkrovimas', 3, NULL, 416, 1, NULL),
	(10044, 'EventLogReset', 'Įvykių žurnalo anuliavimas', 7, NULL, 416, 1, NULL),
	(10045, 'Timer_Adjust', 'Laiko korekcija', 4, NULL, NULL, 1, NULL),
	(10046, 'SelfTestOk', 'Sėkminga savidiagnostika', 9, NULL, 416, 1, NULL),
	(10047, 'SelfTestErr', 'Nesėkminga savidiagnostika', 9, NULL, 416, 1, NULL),
	(10048, 'ProfileReset', 'Galios profilio anuliavimas', 7, NULL, 416, 1, NULL),
	(10049, 'MeterChange', 'Skaitiklio keitimas', 7, NULL, 416, 1, NULL),
	(10050, 'UserAccessOk', 'Sėkminga vartotojo prieiga prie duomenų', 1, NULL, 416, 1, NULL),
	(10051, 'UserAccessErr', 'Vartotojo prieigos apsaugos klaida', 9, NULL, 416, 1, NULL),
	(10052, 'UserGetDataErr', 'Vartotojo duomenų gavimo klaida', 9, NULL, 416, 1, NULL),
	(10053, 'TurnedOn', 'Prietaiso jungimas', 3, 1, 169, 1, NULL),
	(10054, 'SwitchToMeteringScheme', 'Perjungimas į matavimų schemą', 8, NULL, 416, 1, NULL),
	(10055, 'ProtectionBreak', 'Apsaugos pažeidimas', 9, NULL, 416, 1, NULL),
	(10056, 'MeterAccessErr', 'Prieigos prie skaitiklio nėra', 8, 0, 170, 1, NULL),
	(10057, 'NoData', 'Duomenų nėra', 9, NULL, 416, 1, NULL),
	(10058, 'DataRecovered', 'Duomenų atstatymas', 9, NULL, 416, 1, NULL),
	(10059, 'GroupsConfigChange', 'Matavimų kanalų grupių įvėdimas/keitimas', 7, NULL, 416, 1, NULL),
	(10060, 'ConfigAndDataChange', 'Konfiguracijos ir duomenų keitimas', 7, NULL, 416, 1, NULL),
	(10061, 'MeteringObjStatusChange', 'Matavimo objekto būsenos keitimas', 8, NULL, 416, 1, NULL),
	(10062, 'COM_Open', 'Atidarytas COM-tunelis', 8, 0, 171, 1, NULL),
	(10063, 'TestOff', 'Testo išjungimas', 8, 1, 172, 1, NULL),
	(10064, 'Bloc_Refusal', 'Bloko atsisakymas', 9, 0, 173, 1, NULL),
	(10065, 'SpecialSignalOn', 'Specialus signalas', 9, 0, 174, 1, NULL),
	(10066, 'Sensing_Break', 'Jutiklio gedimas', 9, 0, 175, 1, NULL),
	(10067, 'Sensing_MoreMax', 'Jutiklis - išėjimas už MAX', 5, 0, 176, 1, NULL),
	(10068, 'Sensing_SmallerMin', 'Jutiklis - išėjimas už MIN', 5, 0, 177, 1, NULL),
	(10069, 'ArchivesInit', 'Archyvų inicializacija', 7, NULL, 416, 1, NULL),
	(10070, 'BadArchives', 'Archyvų trūkumas nustatytai konfiguracijai', 9, NULL, 416, 1, NULL),
	(10071, 'ShortArchivesError', 'Trumpų archyvų įrašymo klaida', 9, NULL, 416, 1, NULL),
	(10072, 'MainArchivesError', 'Pagrindinių archyvų įrašymo klaida', 9, NULL, 416, 1, NULL),
	(10073, 'DayArchivesError', 'Paros archyvų įrašymo klaida', 9, NULL, 416, 1, NULL),
	(10074, 'MonthArchivesError', 'Mėnesio archyvų įrašymo klaida', 9, NULL, 416, 1, NULL),
	(10075, 'YearArchivesError', 'Mėtų archyvų įrašymo klaida', 9, NULL, 416, 1, NULL),
	(10076, 'Repair_TurnedOff', 'Avarinis išjungimas', 3, NULL, 416, 1, NULL),
	(10077, 'Protection', 'Apsaugos panaudojimas', 1, NULL, 416, 1, NULL),
	(10078, 'Start', 'Paleidimas', 3, 1, 178, 1, NULL),
	(10079, 'High_Power', 'Apkrovos viršijimas', 5, 0, 179, 1, NULL),
	(10080, 'Timer_Adjust_Blocked', 'Laiko korekcija blokuota', 9, 0, 180, 1, NULL),
	(10081, 'Timer_Adjust_GPS', 'Laiko korekcija pagal GPS', 4, NULL, NULL, 1, NULL),
	(10082, 'Timer_Adjust_Before_GPS', 'Laiko korekcija pagal GPS/prieš', 4, NULL, 416, 1, NULL),
	(10083, 'Timer_Adjust_After_GPS', 'Laiko korekcija pagal GPS/po', 4, NULL, 416, 1, NULL),
	(10084, 'MoreLimit', 'Limito viršijimas', 5, 0, 181, 1, NULL),
	(10085, 'Reset', 'Anuliavimas', 7, NULL, 416, 1, NULL),
	(10086, 'Profile2Reset', '2-o profilio anuliavimas', 7, NULL, 416, 1, NULL),
	(10087, 'ProfilsReset', 'Profilių anuliavimas', 7, NULL, 416, 1, NULL),
	(10088, 'Max_Demand_Reset', 'Galios maksimumų anuliavimas', 7, NULL, 416, 1, NULL),
	(10089, 'Refusal_Reset', 'Atsisakymų anuliavimas', 7, NULL, 416, 1, NULL),
	(10090, 'PowerLimitChange', 'Galios ribos keitimas', 7, NULL, 416, 1, NULL),
	(10091, 'EnergyLimitChange', 'Energijos ribos keitimas', 7, NULL, 416, 1, NULL),
	(10092, 'MoreLimitEnergy_T1', 'Energijos ribos peržengimas pagal 1 tarifą', 5, NULL, 416, 1, NULL),
	(10093, 'MoreLimitEnergy_T2', 'Energijos ribos peržengimas pagal 2 tarifą', 5, NULL, 416, 1, NULL),
	(10094, 'MoreLimitEnergy_T3', 'Energijos ribos peržengimas pagal 3 tarifą', 5, NULL, 416, 1, NULL),
	(10095, 'MoreLimitEnergy_T4', 'Energijos ribos peržengimas pagal 4 tarifą', 5, NULL, 416, 1, NULL),
	(10096, 'MoreLimitPower', 'Galios ribos peržengimas', 5, 0, 182, 1, NULL),
	(10097, 'MoreLimitKU', 'Įtampos iškraipymų koeficiento ribos peržengimas', 5, 0, 183, 1, NULL),
	(10098, 'HiLimitHz', 'Dažnio viršutinės ribos peržengimas', 5, 0, 184, 1, NULL),
	(10099, 'LoLimitHz', 'Dažnio apatinės ribos peržengimas', 5, 0, 185, 1, NULL),
	(10100, 'HiLimitUl', 'Tiesioginės sekos įtampos U1(1) viršutinės ribos peržengimas', 5, 0, 186, 1, NULL),
	(10101, 'LoLimitUl', 'Tiesioginės sekos įtampos U1(1) apatinės ribos peržengimas', 5, 0, 187, 1, NULL),
	(10102, 'HiLimitU1', '1 fazės įtampos viršutinės ribos peržengimas', 5, 0, 188, 1, NULL),
	(10103, 'LoLimitU1', '1 fazės įtampos apatinės ribos peržengimas', 5, 0, 189, 1, NULL),
	(10104, 'HiLimitU2', '2 fazės įtampos viršutinės ribos peržengimas', 5, 0, 190, 1, NULL),
	(10105, 'LoLimitU2', '2 fazės įtampos apatinės ribos peržengimas', 5, 0, 191, 1, NULL),
	(10106, 'HiLimitU3', '3 fazės įtampos viršutinės ribos peržengimas', 5, 0, 192, 1, NULL),
	(10107, 'LoLimitU3', '3 fazės įtampos apatinės ribos peržengimas', 5, 0, 193, 1, NULL),
	(10108, 'HolidaysChange', 'Švenčių tvarkaraščio keitimas', 7, NULL, 416, 1, NULL),
	(10109, 'TariffsChange', 'Tarifų tvarkaraščio keitimas', 7, NULL, 416, 1, NULL),
	(10110, 'ListCarryChange', 'Perkeltų dienų sąrašo keitimas', 7, NULL, 416, 1, NULL),
	(10111, 'PowerMaxChange', 'Galios maksimumų tvarkaraščio keitimas', 7, NULL, 416, 1, NULL),
	(10112, 'Show_Reset', 'Parodymų anuliavimas', 7, NULL, 416, 1, NULL),
	(10113, 'Profile1_Max_Demand_Reset', '1 profilio galios maksimumų anuliavimas', 7, NULL, 416, 1, NULL),
	(10114, 'Profile2_Max_Demand_Reset', '2 profilio galios maksimumų anuliavimas', 7, NULL, 416, 1, NULL),
	(10115, 'MoreLimitPP', 'Aktyvinės tiekimo krypties galios ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10116, 'MoreLimitPM', 'Aktyvinės grįžtamos krypties galios ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10117, 'MoreLimitQP', 'Reaktyvinės tiekimo krypties galios ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10118, 'MoreLimitQM', 'Reaktyvinės grįžtamos krypties galios ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10119, 'HiLimitValue_Hz', 'Dažnio viršutinės ALVR peržengimas', 5, 0, 194, 1, NULL),
	(10120, 'HiNormalValue_Hz', 'Dažnio viršutinės NLVR peržengimas', 5, 0, 195, 1, NULL),
	(10121, 'LoLimitValue_Hz', 'Dažnio apatinės ALVR peržengimas', 5, 0, 196, 1, NULL),
	(10122, 'LoNormalValue_Hz', 'Dažnio apatinės NLVR peržengimas', 5, 0, 197, 1, NULL),
	(10123, 'HiLimitValue_Ul', 'Tiesioginės sekos įtampos U1(1) viršutinės ALVR peržengimas', 5, 0, 198, 1, NULL),
	(10124, 'HiNormalValue_Ul', 'Tiesioginės sekos įtampos U1(1) viršutinės NLVR peržengimas', 5, 0, 199, 1, NULL),
	(10125, 'LoLimitValue_Ul', 'Tiesioginės sekos įtampos U1(1) apatinės ALVR peržengimas', 5, 0, 200, 1, NULL),
	(10126, 'LoNormalValue_Ul', 'Tiesioginės sekos įtampos U1(1) apatinės NLVR peržengimas', 5, 0, 201, 1, NULL),
	(10127, 'HiLimitValue_U1', '1 fazės įtampos viršutinės ALVR peržengimas', 5, 0, 202, 1, NULL),
	(10128, 'HiNormalValue_U1', '1 fazės įtampos viršutinės NLVR peržengimas', 5, 0, 203, 1, NULL),
	(10129, 'LoLimitValue_U1', '1 fazės įtampos apatinės ALVR peržengimas', 5, 0, 204, 1, NULL),
	(10130, 'LoNormalValue_U1', '1 fazės įtampos apatinės NLVR peržengimas', 5, 0, 205, 1, NULL),
	(10131, 'HiLimitValue_U2', '2 fazės įtampos viršutinės ALVR peržengimas', 5, 0, 206, 1, NULL),
	(10132, 'HiNormalValue_U2', '2 fazės įtampos viršutinės NLVR peržengimas', 5, 0, 207, 1, NULL),
	(10133, 'LoLimitValue_U2', '2 fazės įtampos apatinės ALVR peržengimas', 5, 0, 208, 1, NULL),
	(10134, 'LoNormalValue_U2', '2 fazės įtampos apatinės NLVR peržengimas', 5, 0, 209, 1, NULL),
	(10135, 'HiLimitValue_U3', '3 fazės įtampos viršutinės ALVR peržengimas', 5, 0, 210, 1, NULL),
	(10136, 'HiNormalValue_U3', '3 fazės įtampos viršutinės NLVR peržengimas', 5, 0, 211, 1, NULL),
	(10137, 'LoLimitValue_U3', '3 fazės įtampos apatinės ALVR peržengimas', 5, 0, 212, 1, NULL),
	(10138, 'LoNormalValue_U3', '3 fazės įtampos apatinės NLVR peržengimas', 5, 0, 213, 1, NULL),
	(10139, 'HiLimitValue_U12', 'Įtampos tarp fazių 12 viršutinės ALVR peržengimas', 5, 0, 214, 1, NULL),
	(10140, 'HiNormalValue_U12', 'Įtampos tarp fazių 12 viršutinės NLVR peržengimas', 5, 0, 215, 1, NULL),
	(10141, 'LoLimitValue_U12', 'Įtampos tarp fazių 12 apatinės ALVR peržengimas', 5, 0, 216, 1, NULL),
	(10142, 'LoNormalValue_U12', 'Įtampos tarp fazių 12 apatinės NLVR peržengimas', 5, 0, 217, 1, NULL),
	(10143, 'HiLimitValue_U23', 'Įtampos tarp fazių 23 viršutinės ALVR peržengimas', 5, 0, 218, 1, NULL),
	(10144, 'HiNormalValue_U23', 'Įtampos tarp fazių 23 viršutinės NLVR peržengimas', 5, 0, 219, 1, NULL),
	(10145, 'LoLimitValue_U23', 'Įtampos tarp fazių 23 apatinės ALVR peržengimas', 5, 0, 220, 1, NULL),
	(10146, 'LoNormalValue_U23', 'Įtampos tarp fazių 23 apatinės NLVR peržengimas', 5, 0, 221, 1, NULL),
	(10147, 'HiLimitValue_U31', 'Įtampos tarp fazių 31 viršutinės ALVR peržengimas', 5, 0, 222, 1, NULL),
	(10148, 'HiNormalValue_U31', 'Įtampos tarp fazių 31 viršutinės NLVR peržengimas', 5, 0, 223, 1, NULL),
	(10149, 'LoLimitValue_U31', 'Įtampos tarp fazių 31 apatinės ALVR peržengimas', 5, 0, 224, 1, NULL),
	(10150, 'LoNormalValue_U31', 'Įtampos tarp fazių 31 apatinės NLVR peržengimas', 5, 0, 225, 1, NULL),
	(10151, 'MoreLimitValue_U1', '1 fazės įtampos iškraipymų koeficiento ALVR peržengimas', 5, 0, 226, 1, NULL),
	(10152, 'MoreNormalValue_U1', '1 fazės įtampos iškraipymų koeficiento NLVR peržengimas', 5, 0, 227, 1, NULL),
	(10153, 'MoreLimitValue_U2', '2 fazės įtampos iškraipymų koeficiento ALVR peržengimas', 5, 0, 228, 1, NULL),
	(10154, 'MoreNormalValue_U2', '2 fazės įtampos iškraipymų koeficiento NLVR peržengimas', 5, 0, 229, 1, NULL),
	(10155, 'MoreLimitValue_U3', '3 fazės įtampos iškraipymų koeficiento ALVR peržengimas', 5, 0, 230, 1, NULL),
	(10156, 'MoreNormalValue_U3', '3 fazės įtampos iškraipymų koeficiento NLVR peržengimas', 5, 0, 231, 1, NULL),
	(10157, 'MoreLimitValue_U12', 'Įtampos iškraipymų koeficiento tarp fazių 12 ALVR peržengimas', 5, 0, 232, 1, NULL),
	(10158, 'MoreNormalValue_U12', 'Įtampos iškraipymų koeficiento tarp fazių 12 NLVR peržengimas', 5, 0, 233, 1, NULL),
	(10159, 'MoreLimitValue_U23', 'Įtampos iškraipymų koeficiento tarp fazių 23 ALVR peržengimas', 5, 0, 234, 1, NULL),
	(10160, 'MoreNormalValue_U23', 'Įtampos iškraipymų koeficiento tarp fazių 23 NLVR peržengimas', 5, 0, 235, 1, NULL),
	(10161, 'MoreLimitValue_U31', 'Įtampos iškraipymų koeficiento tarp fazių 31 ALVR peržengimas', 5, 0, 236, 1, NULL),
	(10162, 'MoreNormalValue_U31', 'Įtampos iškraipymų koeficiento tarp fazių 31 NLVR peržengimas', 5, 0, 237, 1, NULL),
	(10163, 'MoreLimitValue_K0U', 'Nulinės sekos nesimetrinės įtampos koeficiento ALVR peržengimas', 5, 0, 238, 1, NULL),
	(10164, 'MoreNormalValue_K0U', 'Nulinės sekos nesimetrinės įtampos koeficiento NLVR peržengimas', 5, 0, 239, 1, NULL),
	(10165, 'MoreLimitValue_K2U', 'Atvirkštinės sekos nesimetrinės įtampos koeficiento ALVR peržengimas', 5, 0, 240, 1, NULL),
	(10166, 'MoreNormalValue_K2U', 'Atvirkštinės sekos nesimetrinės įtampos koeficiento NLVR peržengimas', 5, 0, 241, 1, NULL),
	(10167, 'Power1minLimitHigh', '1 min. galios viršutinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10168, 'Power1minLimitLow', '1 min. galios apatinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10169, 'Power2minLimitHigh', '2 min. galios viršutinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10170, 'Power2minLimitLow', '2 min. galios apatinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10171, 'Power3minLimitHigh', '3 min. galios viršutinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10172, 'Power3minLimitLow', '3 min. galios apatinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10173, 'Power4minLimitHigh', '4 min. galios viršutinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10174, 'Power4minLimitLow', '4 min. galios apatinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10175, 'Power5minLimitHigh', '5 min. galios viršutinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10176, 'Power5minLimitLow', '5 min. galios apatinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10177, 'Power6minLimitHigh', '6 min. galios viršutinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10178, 'Power6minLimitLow', '6 min. galios apatinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10179, 'Power10minLimitHigh', '10 min. galios viršutinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10180, 'Power10minLimitLow', '10 min. galios apatinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10181, 'Power15minLimitHigh', '15 min. galios viršutinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10182, 'Power15minLimitLow', '15 min. galios apatinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10183, 'Power30minLimitHigh', '30 min. galios viršutinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10184, 'Power30minLimitLow', '30 min. galios apatinės ribos peržengimas', 5, NULL, 416, 1, NULL),
	(10185, 'PowerTooHigh', 'Galios reikšmė peržengė viršutinę leistiną ribą', 5, NULL, 416, 1, NULL),
	(10186, 'PowerTooLow', 'Galios reikšmė peržengė apatinę leistiną ribą', 5, NULL, 416, 1, NULL),
	(10187, 'XmlDocumentToSend', 'Įvestas dokumentas siuntimui', 8, NULL, 416, 1, NULL),
	(10188, 'XmlSyntaxErrInDoc', 'Dokumente rasta sintaksės klaida', 9, NULL, 416, 1, NULL),
	(10189, 'XmlNumberAssigned', 'Dokumentui priskirtas numeris', 8, NULL, 416, 1, NULL),
	(10190, 'XmlSentPrimChan', 'Dokumentas siunčiamas pagrindiniu kanalu', 8, NULL, 416, 1, NULL),
	(10191, 'XmlAckReceived', 'Gautas dokumento patirtinimas', 8, NULL, 416, 1, NULL),
	(10192, 'XmlAckSignError', 'Skaitmeninio parašo patikrinimo klaida patvirtinime', 9, NULL, 416, 1, NULL),
	(10193, 'XmlDocRefused', 'Dokumentas nepriimtas', 9, NULL, 416, 1, NULL),
	(10194, 'XmlFullyReceived', 'Dokumentas priimtas pilnai', 9, NULL, 416, 1, NULL),
	(10195, 'XmlPartiallyReceived', 'Dokumentas priimtas dalinai (pagal ne visus subjektus)', 9, NULL, 416, 1, NULL),
	(10196, 'XmlReceivedWNotes', 'Dokumentas priimtas su pastabomis', 9, NULL, 416, 1, NULL),
	(10197, 'XmlAckTimeout', 'Patvirtinimo laukimo laikas baigėsi', 9, NULL, 416, 1, NULL),
	(10198, 'XmlReserveChanErr', 'Nepavyko nustatyti papildomą kanalą', 8, NULL, 416, 1, NULL),
	(10199, 'XmlSentReserveChan', 'Dokumentas siunčiamas papildomu kanalu', 8, NULL, 416, 1, NULL),
	(10200, 'XmlUknRespFileFormat', 'Gauta nežinomo formato byla iš atsakomojo adreso(spam)', 9, NULL, 416, 1, NULL),
	(10201, 'XmlSendRetryEnd', 'Baigėsi dokumento siuntimo bandymai', 9, NULL, 416, 1, NULL),
	(10202, 'XmlErrInSettings', 'Klaida nustatymuose', 9, NULL, 416, 1, NULL),
	(10203, 'XmlNoSoftModule', 'Programinio komponento trukumas', 9, NULL, 416, 1, NULL),
	(10204, 'XmlDeliveryBlocked', 'Užblokuota pristatymo užduotis', 9, NULL, 416, 1, NULL),
	(10205, 'XmlReqReceived', 'Gauta užklausa', 8, NULL, 416, 1, NULL),
	(10206, 'XmlReportCreated', 'Ataskaita suformuota', 8, NULL, 416, 1, NULL),
	(10207, 'XmlReportWNotes', 'Ataskaita suformuota su pastabomis', 9, NULL, 416, 1, NULL),
	(10208, 'XmlReportNotCreated', 'Ataskaita nesuformuota', 9, NULL, 416, 1, NULL),
	(10209, 'SynchroNotNeeded', 'Gautas pavaldaus prietaiso laikas, sinchronizacija nereikalinga', 8, NULL, 416, 1, NULL),
	(10210, 'SynchroNeeded', 'Gautas pavaldaus prietaiso laikas, sinchronizacija reikalinga', 8, NULL, 416, 1, NULL),
	(10211, 'SynchroImpossibleBig', 'Gautas pavaldaus prietaiso laikas, sinchronizacija negalima (perdidelis skirtumas)', 9, NULL, 416, 1, NULL),
	(10212, 'TimeReadErr', 'Nepavyko gauti pavaldaus prietaiso laiko', 9, NULL, 416, 1, NULL),
	(10213, 'TimeSetToDevice', 'Nustatytas naujas laikas pavaldaus prietaise', 12, NULL, 416, 1, NULL),
	(10214, 'SmoothCorrectionSet', 'Pavaldžiam prietaisui nustatyta tolygi laiko korekcija', 8, NULL, 416, 1, NULL),
	(10215, 'SynchroImpossibleITV', 'Gautas pavaldaus prietaiso laikas, sinchronizacija negalima (nėra sinchronizacijos su ITV)', 9, NULL, 416, 1, NULL),
	(10216, 'SynchroImpossibleLag', 'Gautas pavaldaus prietaiso laikas, sinchronizacija negalima (viršitas atsakymo gavimo laikas)', 9, NULL, 416, 1, NULL),
	(10217, 'UnableToSetTime', 'Nepavyko nustatyti pavaldaus prietaiso laiko', 12, NULL, 416, 1, NULL),
	(10218, 'UnableToSmoothCor', 'Nepavyko nustatyti pavaldaus prietaiso tolydžios laiko korekcijos', 12, NULL, 416, 1, NULL),
	(10219, 'PtsCorNotNeeded', 'Laiko korekcijos seansas iš ITV - nereikalingas', 4, NULL, 416, 1, NULL),
	(10220, 'PtsCorrectionOk', 'Laiko korekcijos seansas iš ITV - sėkmingas laiko nustatymas', 4, NULL, NULL, 1, NULL),
	(10221, 'PtsTimeUnreliable', 'Laiko korekcijos seansas iš ITV - nesėkmingas (gautas laikas su napatikimumo statusu)', 4, NULL, 416, 1, NULL),
	(10222, 'PtsCorTooBig', 'Laiko korekcijos seansas iš ITV - nesėkmingas (viršita maksimalaus neatitikimo riba)', 4, NULL, 416, 1, NULL),
	(10223, 'PtsCorRecvErr', 'Laiko korekcijos seansas iš ITV - nesėkmingas (duomenų gavimo klaida)', 4, NULL, 416, 1, NULL),
	(10224, 'PtsTimeSet', 'Sėkmingas laiko nustatymas ITV', 12, NULL, 416, 1, NULL),
	(10225, 'PtsTimeNotSet', 'Nustatyti laiką ITV nepavyko', 12, NULL, 416, 1, NULL),
	(10226, 'Unbalance1MinLimit', 'Leistino nebalanso už 1 minutę viršijimas', 5, NULL, 416, 1, NULL),
	(10227, 'Unbalance2MinLimit', 'Leistino nebalanso už 2 minutes viršijimas', 5, NULL, 416, 1, NULL),
	(10228, 'Unbalance3MinLimit', 'Leistino nebalanso už 3 minutes viršijimas', 5, NULL, 416, 1, NULL),
	(10229, 'Unbalance4MinLimit', 'Leistino nebalanso už 4 minutes viršijimas', 5, NULL, 416, 1, NULL),
	(10230, 'Unbalance5MinLimit', 'Leistino nebalanso už 5 minutes viršijimas', 5, NULL, 416, 1, NULL),
	(10231, 'Unbalance6MinLimit', 'Leistino nebalanso už 6 minutes viršijimas', 5, NULL, 416, 1, NULL),
	(10232, 'Unbalance10MinLimit', 'Leistino nebalanso už 10 minučių viršijimas', 5, NULL, 416, 1, NULL),
	(10233, 'Unbalance15MinLimit', 'Leistino nebalanso už 15 minučių viršijimas', 5, NULL, 416, 1, NULL),
	(10234, 'Unbalance30MinLimit', 'Leistino nebalanso už 30 minučių viršijimas', 5, NULL, 416, 1, NULL),
	(10235, 'Unbalance1hLimit', 'Leistino energijos nebalanso už valandą viršijimas', 5, NULL, 416, 1, NULL),
	(10236, 'Unbalance1dayLimit', 'Leistino energijos nebalanso už parą viršijimas', 5, NULL, 416, 1, NULL),
	(10237, 'Unbalance1monLimit', 'Leistino energijos nebalanso už mėnesį viršijimas', 5, NULL, 416, 1, NULL),
	(10238, 'Unbalance1yearLimit', 'Leistino energijos nebalanso už metus viršijimas', 5, NULL, 416, 1, NULL),
	(10239, 'UnbalanceCurDayLimit', 'Leistino energijos nebalanso už einamąją parą viršijimas', 5, NULL, 416, 1, NULL),
	(10240, 'UnbalanceCurMonLimit', 'Leistino energijos nebalanso už einamąjį mėnesį viršijimas', 5, NULL, 416, 1, NULL),
	(10241, 'UnbalanceCurYearLimit', 'Leistino energijos nebalanso už einamuosius metus viršijimas', 5, NULL, 416, 1, NULL),
	(10242, 'DevBadLink', 'Blogas ryšys su prietaisu', 8, 0, 242, 1, NULL),
	(10243, 'DevNoResponse', 'Prietaisas neatsako', 8, 0, 243, 1, NULL),
	(10244, 'DevPasswordErr', 'Neteisingas prietaiso priėjimo slaptažodis', 9, 0, 244, 1, NULL),
	(10245, 'DevDescriptionErr', 'Netinkamas prietaiso aprašymas', 9, 0, 245, 1, NULL),
	(10246, 'DevSettingsErr', 'Neteisingai sukonfiguruotas prietaisas', 9, 0, 246, 1, NULL),
	(10247, 'DevParameterErr', 'Netinkamas parametro aprašymas', 9, 0, 247, 1, NULL),
	(10248, 'DevErrReceived', 'Prietaiso atsakymas su klaidos kodu', 9, 0, 248, 1, NULL),
	(10249, 'DevUnknownErr', 'Nežinoma klaida', 9, 0, 249, 1, NULL),
	(10252, 'DevConnectConfChange', 'Ryšio prietaiso konfiguracijos keitimas', 7, NULL, 416, 1, NULL),
	(10253, 'DevRS485ConfChange', 'Skaitiklio RS485 konfiguracijos keitimas', 7, NULL, 416, 1, NULL),
	(10254, 'ChannelConfChange', 'Apskaitos kanalo keitimas', 7, NULL, 416, 1, NULL),
	(10255, 'USPDConfChange', 'Išorinių DPP konfiguracijos keitimas', 7, NULL, 416, 1, NULL),
	(10256, 'GPSConfChange', 'GPS konfiguracijos keitimas', 7, NULL, 416, 1, NULL),
	(10257, 'TSChannelConfChange', 'TS įėjimo keitimas', 7, NULL, 416, 1, NULL),
	(10258, 'BadAnswerCE6850', 'Neteisingas atsakymas CE6850', 9, NULL, 416, 1, NULL),
	(10259, 'ConfigDBChange', 'Parametrų duomenų bazės keitimas', 7, NULL, 416, 1, NULL),
	(10260, 'HighIntPowerLimit', 'Dabartinės intervalinės galios limito viršijimas', 5, NULL, 416, 1, NULL),
	(10261, 'OpenSession', 'Sesijos atidarymas', 11, 0, 162, 1, NULL),
	(10262, 'Timer_Adjust_USO', 'Modulio USO laiko korekcijos komanda', 4, NULL, 416, 1, NULL),
	(10263, 'Dialing', 'Numerio rinkimas', 8, NULL, 416, 1, NULL),
	(10264, 'Connected', 'Sujungimo nustatymas', 8, 0, 163, 1, NULL),
	(10265, 'NoConnect', 'Sujungimas nenustatytas', 8, NULL, 416, 1, NULL),
	(10266, 'ModuleConnected', 'Ryšys su moduliu', 8, 1, 164, 1, NULL),
	(10267, 'ModuleGroupConnected', 'Ryšys su modulių grupe', 8, 1, 165, 1, NULL),
	(10268, 'ErrorConfig', 'Konfiguracijos klaida', 7, 0, 166, 1, NULL),
	(10269, 'ErrorCalculate', 'Skaičiavimo klaida', 7, 0, 167, 1, NULL),
	(10270, 'LimitExit', 'Diapazono viršijimas', 5, 0, 168, 1, NULL),
	(10271, 'Start_Event', 'Paledimas', 3, NULL, 416, 1, NULL),
	(10272, 'Time_Before_Adjust', 'Laikas prieš korekciją', 4, NULL, 416, 1, NULL),
	(10273, 'Time_After_Adjust', 'Laikas po korekcijos', 4, NULL, 416, 1, NULL),
	(10274, 'Timer_Adjust_KeyBoard', 'Laiko korekciją per klaviatūrą', 4, NULL, 416, 1, NULL),
	(10275, 'Timer_Adjust_IsRun', 'Laiko korekciją jau paleista', 4, NULL, 416, 1, NULL),
	(10276, 'BadUserName_Or_Password', 'Neteisingas vartotojo vardas arba slaptažodis', 9, NULL, 416, 1, NULL),
	(10280, 'GeneralAlarm', 'Bendros avarinės signalizacijos', 21, NULL, 829, 1, NULL),
	(10281, 'IsLeak', 'Nuotėkis šiuo metu', 5, NULL, 830, 1, NULL),
	(10282, 'WasLeak', 'Nuotėkis praeityje', 5, NULL, 831, 1, NULL),
	(10283, 'MeterBlocked', 'Skaitiklis užblokuotas/neužblokuotas', 11, NULL, 819, 1, NULL),
	(10284, 'ReverseFlow', 'Atvirkštinės krypties tėkmė', 5, NULL, 646, 1, NULL),
	(10285, 'UnderFlow', 'Pastovus perpildymas', 5, NULL, 832, 1, NULL),
	(10286, 'ExcessFlow', 'Perteklinis srautas', 5, NULL, 833, 1, NULL),
	(10287, 'IsMagneticFraud', 'Magnetinio lauko poveikis šiuo metu', 1, NULL, 834, 1, NULL),
	(10288, 'WasMagneticFraud', 'Magnetinio lauko poveikis praeityje', 1, NULL, 835, 1, NULL),
	(10289, 'IsMechanicalFraud', 'Mechaninis poveikis šiuo metu', 1, NULL, 836, 1, NULL),
	(10290, 'WasMechanicalFraud', 'Mechaninis poveikis praeityje', 1, NULL, 837, 1, NULL),
	(10291, 'ChangeMode', 'Režimo keitimas', 8, NULL, 416, 1, NULL),
	(10292, 'Restart', 'Paleisti iš naujo', 3, NULL, 416, 1, NULL),
	(10293, 'Off_discharging', 'Išsijungimas dėl NMŠ iškrovos', 6, NULL, 416, 1, NULL),
	(10294, 'Bad_Battery', 'Maitinimo elementas neveikia', 6, NULL, 416, 1, NULL),
	(10295, 'WorkBattery_ChangeU', 'Maitinimas iš elemento dėl greito įtampos ketimo', 6, NULL, 416, 1, NULL),
	(10296, 'WorkBattery_HighU', 'Maitinimas iš elemento dėl aukštos įtampos', 6, NULL, 416, 1, NULL),
	(10297, 'WorkBattery_LowU', 'Maitinimas iš elemento dėl žemos įtampos', 6, NULL, 416, 1, NULL),
	(10298, 'WorkBattery_ImpulseU', 'Maitinimas iš elemento dėl įtampos impulso', 6, NULL, 416, 1, NULL),
	(10299, 'LockConfig', 'Konfiguravimas uždraustas', 7, 0, 252, 1, NULL),
	(10300, 'Connect_MEK101', 'Ryšys IEC 870-5-101 yra', 8, 0, 253, 1, NULL),
	(10301, 'Connect_MEK104', 'Ryšys IEC 870-5-104 yra', 8, 0, 254, 1, NULL),
	(10302, 'Work_Battery', 'Maitinimas iš elemento', 6, 0, 255, 1, NULL),
	(10303, 'MoreMax_U', 'Įtampa - išėjimas už MAX', 5, 0, 256, 1, NULL),
	(10304, 'SmallerMin_U', 'Įtampa - išėjimas už MIN', 5, 0, 257, 1, NULL),
	(10305, 'SmallerMin_I', 'Srovė - išėjimas už MIN', 5, 0, 258, 1, NULL),
	(10306, 'MoreNorm', 'Ribos peržengimas', 5, 0, 259, 1, NULL),
	(10307, 'MoreLimit_KfP', 'Galios koeficiento ribos peržengimas', 5, 0, 260, 1, NULL),
	(10308, 'MoreLimit_I2', '2 harmoninės srovės ribos peržengimas', 5, 0, 261, 1, NULL),
	(10309, 'MoreLimit_I_noSin', 'Nesinusoidinės srovės ribos peržengimas', 5, 0, 262, 1, NULL),
	(10310, 'MoreLimit_UF', 'Fazių įtampų atitikimo ribos peržengimas', 5, 0, 263, 1, NULL),
	(10311, 'MoreLimit_IF', 'Fazių srovių atitikimo ribos peržengimas', 5, 0, 264, 1, NULL),
	(10312, 'MoreLimit_Voltage', 'Apkrovos iškreipimo ribos peržengimas', 5, 0, 265, 1, NULL),
	(10313, 'MoreLimit_dP', 'dP ribos peržengimas', 5, 0, 266, 1, NULL),
	(10314, 'LoLimit_dP', 'dP apatinės ribos peržengimas', 5, 0, 267, 1, NULL),
	(10315, 'HiLimit_dP', 'dP viršutinės ribos peržengimas', 5, 0, 268, 1, NULL),
	(10316, 'MoreCutOff_dP', 'dP išėjimas po atkirtą', 5, 0, 269, 1, NULL),
	(10317, 'HiLimit_Hz_1', 'Dažnio viršutinės ribos peržengimas, kanalas 1', 5, 0, 270, 1, NULL),
	(10318, 'HiLimit_Hz_2', 'Dažnio viršutinės ribos peržengimas, kanalas 2', 5, 0, 271, 1, NULL),
	(10319, 'HiLimit_Hz_3', 'Dažnio viršutinės ribos peržengimas, kanalas 3', 5, 0, 272, 1, NULL),
	(10320, 'HiLimit_Hz_4', 'Dažnio viršutinės ribos peržengimas, kanalas 4', 5, 0, 273, 1, NULL),
	(10321, 'HiLimit_Qn', 'Suvartojimo viršutinės ribos peržengimas', 5, 0, 274, 1, NULL),
	(10322, 'LoLimit_Qn', 'Suvartojimo apatinės ribos peržengimas', 5, 0, 275, 1, NULL),
	(10323, 'HiLimit_Qn_1', 'Suvartojimo viršutinės ribos peržengimas, kanalas 1', 5, 0, 276, 1, NULL),
	(10324, 'LoLimit_Qn_1', 'Suvartojimo apatinės ribos peržengimas, kanalas 1', 5, 0, 277, 1, NULL),
	(10325, 'HiLimit_Qn_2', 'Suvartojimo viršutinės ribos peržengimas, kanalas 2', 5, 0, 278, 1, NULL),
	(10326, 'LoLimit_Qn_2', 'Suvartojimo apatinės ribos peržengimas, kanalas 2', 5, 0, 279, 1, NULL),
	(10327, 'HiLimit_Qn_3', 'Suvartojimo viršutinės ribos peržengimas, kanalas 3', 5, 0, 280, 1, NULL),
	(10328, 'LoLimit_Qn_3', 'Suvartojimo apatinės ribos peržengimas, kanalas 3', 5, 0, 281, 1, NULL),
	(10329, 'HiLimit_Qn_4', 'Suvartojimo viršutinės ribos peržengimas, kanalas 4', 5, 0, 282, 1, NULL),
	(10330, 'LoLimit_Qn_4', 'Suvartojimo apatinės ribos peržengimas, kanalas 4', 5, 0, 283, 1, NULL),
	(10331, 'HiThreshold_Qn', 'Suvartojimo viršutinio slenksčio peržengimas', 5, 0, 284, 1, NULL),
	(10332, 'LoThreshold_Qn', 'Suvartojimo apatinio slenksčio peržengimas', 5, 0, 285, 1, NULL),
	(10333, 'HiThreshold_Qn_1', 'Suvartojimo viršutinio slenksčio peržengimas, kanalas 1', 5, 0, 286, 1, NULL),
	(10334, 'LoThreshold_Qn_1', 'Suvartojimo apatinio slenksčio peržengimas, kanalas 1', 5, 0, 287, 1, NULL),
	(10335, 'HiThreshold_Qn_2', 'Suvartojimo viršutinio slenksčio peržengimas, kanalas 2', 5, 0, 288, 1, NULL),
	(10336, 'LoThreshold_Qn_2', 'Suvartojimo apatinio slenksčio peržengimas, kanalas 2', 5, 0, 289, 1, NULL),
	(10337, 'HiThreshold_Qn_3', 'Suvartojimo viršutinio slenksčio peržengimas, kanalas 3', 5, 0, 290, 1, NULL),
	(10338, 'LoThreshold_Qn_3', 'Suvartojimo apatinio slenksčio peržengimas, kanalas 3', 5, 0, 291, 1, NULL),
	(10339, 'HiThreshold_Qn_4', 'Suvartojimo viršutinio slenksčio peržengimas, kanalas 4', 5, 0, 292, 1, NULL),
	(10340, 'LoThreshold_Qn_4', 'Suvartojimo apatinio slenksčio peržengimas, kanalas 4', 5, 0, 293, 1, NULL),
	(10341, 'HiBound_Qn', 'Suvartojimo viršutinio apribojimo peržengimas', 5, 0, 294, 1, NULL),
	(10342, 'LoBound_Qn', 'Suvartojimo apatinio apribojimo peržengimas', 5, 0, 295, 1, NULL),
	(10343, 'HiBound_Qn_1', 'Suvartojimo viršutinio apribojimo peržengimas, kanalas 1', 5, 0, 296, 1, NULL),
	(10344, 'LoBound_Qn_1', 'Suvartojimo apatinio apribojimo peržengimas, kanalas 1', 5, 0, 297, 1, NULL),
	(10345, 'HiBound_Qn_2', 'Suvartojimo viršutinio apribojimo peržengimas, kanalas 2', 5, 0, 298, 1, NULL),
	(10346, 'LoBound_Qn_2', 'Suvartojimo apatinio apribojimo peržengimas, kanalas 2', 5, 0, 299, 1, NULL),
	(10347, 'HiBound_Qn_3', 'Suvartojimo viršutinio apribojimo peržengimas, kanalas 3', 5, 0, 300, 1, NULL),
	(10348, 'LoBound_Qn_3', 'Suvartojimo apatinio apribojimo peržengimas, kanalas 3', 5, 0, 301, 1, NULL),
	(10349, 'HiBound_Qn_4', 'Suvartojimo viršutinio apribojimo peržengimas, kanalas 4', 5, 0, 302, 1, NULL),
	(10350, 'LoBound_Qn_4', 'Suvartojimo apatinio apribojimo peržengimas, kanalas 4', 5, 0, 303, 1, NULL),
	(10351, 'LastMeterInit', 'Paskutinio inicalizavimo data', 8, 0, 416, 1, NULL),
	(10400, 'AnalogInputLoLimit', 'Analoginio įėjimo apatinės ribos peržengimas', 5, 0, 304, 1, NULL),
	(10401, 'AnalogInputHiLimit', 'Analoginio įėjimo viršutinės ribos peržengimas', 5, 0, 305, 1, NULL),
	(10402, 'HiLimit_T', 'T viršutinės ribos peržengimas', 5, 0, 306, 1, NULL),
	(10403, 'LoLimit_T', 'T apatinės ribos peržengimas', 5, 0, 307, 1, NULL),
	(10404, 'HiLimit_P', 'P viršutinės ribos peržengimas', 5, 0, 308, 1, NULL),
	(10405, 'LoLimit_P', 'P apatinės ribos peržengimas', 5, 0, 309, 1, NULL),
	(10406, 'ConstChange', 'Konstantų keitimas', 7, NULL, 416, 1, NULL),
	(10407, 'TelemetrySetting', 'Telemetrijos parametrų keitimas', 7, NULL, 416, 1, NULL),
	(10408, 'MetrologySetting', 'Metrologijos parametrų keitimas', 7, NULL, NULL, 1, NULL),
	(10409, 'ManualUpdateArch', 'Archyvo rankinė korekcija', 7, NULL, 416, 1, NULL),
	(10410, 'WriteDevice', 'Duomenų įrašymas į prietaisą', 7, NULL, 416, 1, NULL),
	(10411, 'UnSyncDevDT', 'Serverio ir išorinio prietaiso laiko nesutapimas', 9, NULL, 416, 1, NULL),
	(10412, 'ImportEvent', 'Importuotas iš pajungtų apskaitos prietaisų, kontrolerių ir pan. įvykis', 8, NULL, 416, 1, NULL),
	(10413, 'ChangeStateChannel', 'Ryšio kanalo būsenos keitimas', 8, NULL, 416, 1, NULL),
	(10414, 'BadFileCalibration', 'Kalibravimo failas sugadintas', 9, NULL, 416, 1, NULL),
	(10415, 'Distortion', 'Tinklo trukdžiai', 9, NULL, 416, 1, NULL),
	(10416, 'ErrorExchangeDPS', 'Apsikeitimo su DPS klaida', 9, NULL, 416, 1, NULL),
	(10417, 'ErrorDPS', 'Klaida DPS', 9, NULL, 416, 1, NULL),
	(10418, 'ErrorEEPROM', 'Sugedęs kalibravimo EEPROM', 9, NULL, 416, 1, NULL),
	(10419, 'ErrorEEPROM1', 'Sugedęs EEPROM 1', 9, NULL, 416, 1, NULL),
	(10420, 'ErrorEEPROM2', 'Sugedęs EEPROM 2', 9, NULL, 416, 1, NULL),
	(10421, 'ErrorEEPROM3', 'Sugedęs EEPROM 3', 9, NULL, 416, 1, NULL),
	(10422, 'ErrorROM', 'Sugedęs  ROM', 9, NULL, 416, 1, NULL),
	(10423, 'ErrorRAM', 'Sugedęs  RAM', 9, NULL, 416, 1, NULL),
	(10424, 'TariffsChangeWorkdays', 'Darbo dienų tarifinio tvarkaraščio keitimas', 7, NULL, 416, 1, NULL),
	(10425, 'TariffsChangeHolidays', 'Šventinių dienų tarifinio tvarkaraščio keitimas', 7, NULL, 416, 1, NULL),
	(10426, 'AddressChange', 'Tinklo adreso keitimas', 7, NULL, 416, 1, NULL),
	(10427, 'PortChange', 'Porto parametrų keitimas', 7, NULL, 416, 1, NULL),
	(10428, 'MaskChange', 'Atvaizdavimo šablono keitimas', 7, NULL, 416, 1, NULL),
	(10429, 'NormalMode', 'Normalus režimas', 8, NULL, 416, 1, NULL),
	(10430, 'CalibrationMode', 'Kalibravimo režimas', 8, NULL, 416, 1, NULL),
	(10431, 'CheckMode', 'Patikrinimo režimas', 8, NULL, 793, 1, NULL),
	(10432, 'PasswordChange', 'Slaptažodžio keitimas', 7, NULL, 416, 1, NULL),
	(10433, 'Year_Energy_Reset', 'Metinės energijos anuliavimas', 7, NULL, 416, 1, NULL),
	(10434, 'Total_Energy_Reset', 'Sukauptos energijos anuliavimas', 7, NULL, 416, 1, NULL),
	(10435, 'AdminChange', 'Administratoriaus keitimas', 7, NULL, 416, 1, NULL),
	(10436, 'ScanPassword', 'Slaptažodžio skenavimas', 1, NULL, 416, 1, NULL),
	(10437, 'EvLogWinApplication', 'Windows įvykių žurnalas - Application', 9, NULL, 416, 1, NULL),
	(10438, 'EvLogWinSecurity', 'Windows įvykių žurnalas - Security', 9, NULL, 416, 1, NULL),
	(10439, 'EvLogWinSystem', 'Windows įvykių žurnalas - System', 9, NULL, 416, 1, NULL),
	(10440, 'EvLogSTUSPDService', 'Windows įvykių žurnalas - STUSPDService', 9, NULL, 416, 1, NULL),
	(10441, 'EvLogUSPDConfigurator', 'Windows įvykių žurnalas - USPDConfigurator', 9, NULL, 416, 1, NULL),
	(10442, 'EvLogUSPDDrvService', 'Windows įvykių žurnalas - USPDDrvService', 9, NULL, 416, 1, NULL),
	(10443, 'EvLogUSPDMonitor', 'Windows įvykių žurnalas - USPDMonitor', 9, NULL, 416, 1, NULL),
	(10444, 'EvLogUSPDService', 'Windows įvykių žurnalas - USPDService', 9, NULL, 416, 1, NULL),
	(10445, 'EvLogUSPD_Logger', 'Windows įvykių žurnalas - Uspd_Logger', 9, NULL, 416, 1, NULL),
	(10446, 'GPSTimeOn', 'GPS laikas atstatytas', 8, 1, 310, 1, NULL),
	(10447, 'DemandOn', 'Apkrovos įjungimas', 8, 0, 311, 1, NULL),
	(10448, 'PermissionDemandOn', 'Apkrovos įjungimo leidimas', 8, NULL, 416, 1, NULL),
	(10449, 'EnrolmentPay', '1 apmokėjimo registracija', 8, NULL, 416, 1, NULL),
	(10450, 'VoltageLossFase1', '1 fazės srovė be įtampos', 2, 0, 312, 1, NULL),
	(10451, 'VoltageLossFase2', '2 fazės srovė be įtampos', 2, 0, 313, 1, NULL),
	(10452, 'VoltageLossFase3', '3 fazės srovė be įtampos', 2, 0, 314, 1, NULL),
	(10453, 'WorkBegin', 'Darbo pradžia', 8, NULL, 416, 1, NULL),
	(10454, 'TestIM1Ok', 'Testas IM1 - sėkmingai', 8, 1, 315, 1, NULL),
	(10455, 'TestIM2Ok', 'Testas IM2 - sėkmingai', 8, 1, 316, 1, NULL),
	(10456, 'TestIM3Ok', 'Testas IM3 - sėkmingai', 8, 1, 317, 1, NULL),
	(10457, 'TestIM4Ok', 'Testas IM4 - sėkmingai', 8, 1, 318, 1, NULL),
	(10458, 'KeyIM1On', 'Apsaugos jungiklis IM1 įjungtas', 8, 1, 319, 1, NULL),
	(10459, 'KeyIM2On', 'Apsaugos jungiklis IM2 įjungtas', 8, 1, 320, 1, NULL),
	(10460, 'KeyIM3On', 'Apsaugos jungiklis IM3 įjungtas', 8, 1, 321, 1, NULL),
	(10461, 'KeyIM4On', 'Apsaugos jungiklis IM4 įjungtas', 8, 1, 322, 1, NULL),
	(10462, 'ModeSummer1', 'Režimas "Vasara 1"', 8, NULL, 416, 1, NULL),
	(10463, 'ModeSummer2', 'Režimas "Vasara 2"', 8, NULL, 416, 1, NULL),
	(10464, 'ModeSummer3', 'Režimas "Vasara 3"', 8, NULL, 416, 1, NULL),
	(10465, 'ModeAbNormal', 'Režimas "Neetatinis"', 8, 0, 323, 1, NULL),
	(10466, 'DemandOnCommand', 'Įjungimo leidimas pagal komandą', 8, 1, 324, 1, NULL),
	(10467, 'FaseOn', 'Fazės atsistatymas', 2, 1, 325, 1, NULL),
	(10468, 'TickDemandOn', 'Įjungimo leidimas pagal kredito nustatymą', 8, 1, 326, 1, NULL),
	(10469, 'ScalingOn', 'Skaičiavimo atnaujinimas', 8, 1, 327, 1, NULL),
	(10470, 'TestRAMOkIM1', 'Testas RAM IM1 - sėkmingai', 8, 1, 328, 1, NULL),
	(10471, 'TestRAMOkIM2', 'Testas RAM IM2 - sėkmingai', 8, 1, 329, 1, NULL),
	(10472, 'TestRAMOkIM3', 'Testas RAM IM3 - sėkmingai', 8, 1, 330, 1, NULL),
	(10473, 'TestRAMOkIM4', 'Testas RAM IM4 - sėkmingai', 8, 1, 331, 1, NULL),
	(10474, 'RestartCNVSTR', 'Perkrovimas nuo įėjimo CNVSTR', 3, NULL, 416, 1, NULL),
	(10475, 'DemandOnHiLimit', 'Apkrovos išjungimas dėl limito viršijimo', 8, NULL, 416, 1, NULL),
	(10476, 'StartDayBegin', 'Įjungimo leidimas paros pradžioje', 8, NULL, 416, 1, NULL),
	(10477, 'ErrorReadRTC', 'RTC skaitymo klaida', 9, 0, 332, 1, NULL),
	(10478, 'DemandOnByT', 'Įjungimo leidimas dėl temperatūros sumažėjimo', 8, 1, 333, 1, NULL),
	(10479, 'RebootProgram', 'Programinis perkrovimas', 3, NULL, 416, 1, NULL),
	(10480, 'Off_ResetProfile', 'Maitinimo išjungimas su sumų per valandą praradimu', 6, NULL, 416, 1, NULL),
	(10481, 'ErrorWriteRTC', 'RTC įrašymo klaida', 9, 0, 334, 1, NULL),
	(10482, 'ErrorReadEEPROM', 'EEPROM skaitymo klaida', 9, 0, 335, 1, NULL),
	(10483, 'ErrorWriteEEPROM', 'EEPROM įrašymo klaida', 9, 0, 336, 1, NULL),
	(10484, 'WorkLimit', 'Suveikė apribojimas', 5, 0, 337, 1, NULL),
	(10485, 'SystemError', 'Skaitiklio sisteminė klaida', 9, 0, 338, 1, NULL),
	(10486, 'ErrorRWEEPROM_IM1', 'EEPROM IM1 parametrų skatymo/rašymo klaida', 9, 0, 339, 1, NULL),
	(10487, 'ErrorRWEEPROM_IM2', 'EEPROM IM2 parametrų skatymo/rašymo klaida', 9, 0, 340, 1, NULL),
	(10488, 'ErrorRWEEPROM_IM3', 'EEPROM IM3 parametrų skatymo/rašymo klaida', 9, 0, 341, 1, NULL),
	(10489, 'ErrorRWEEPROM_IM4', 'EEPROM IM4 parametrų skatymo/rašymo klaida', 9, 0, 342, 1, NULL),
	(10490, 'Connection_IM1', 'Ryšys su IM1 atstatytas', 9, 1, 343, 1, NULL),
	(10491, 'Connection_IM2', 'Ryšys su IM2 atstatytas', 9, 1, 344, 1, NULL),
	(10492, 'Connection_IM3', 'Ryšys su IM3 atstatytas', 9, 1, 345, 1, NULL),
	(10493, 'Connection_IM4', 'Ryšys su IM4 atstatytas', 9, 1, 346, 1, NULL),
	(10494, 'ErrorSend_IM1', 'Perdavimo į IM1 klaida', 9, NULL, 416, 1, NULL),
	(10495, 'ErrorSend_IM2', 'Perdavimo į IM2 klaida', 9, NULL, 416, 1, NULL),
	(10496, 'ErrorSend_IM3', 'Perdavimo į IM3 klaida', 9, NULL, 416, 1, NULL),
	(10497, 'ErrorSend_IM4', 'Perdavimo į IM4 klaida', 9, NULL, 416, 1, NULL),
	(10498, 'ErrorReceiving_IM1', 'Priėmimo iš IM1 klaida', 9, NULL, 416, 1, NULL),
	(10499, 'ErrorReceiving_IM2', 'Priėmimo iš IM2 klaida', 9, NULL, 416, 1, NULL),
	(10500, 'ErrorReceiving_IM3', 'Priėmimo iš IM3 klaida', 9, NULL, 416, 1, NULL),
	(10501, 'ErrorReceiving_IM4', 'Priėmimo iš IM4 klaida', 9, NULL, 416, 1, NULL),
	(10502, 'HiPulseRate', 'Impulsų dažnis grandinėje aukštesnis už leistą', 5, NULL, 416, 1, NULL),
	(10503, 'ErrorRS485', 'Gedimas RS-485', 9, 0, 347, 1, NULL),
	(10504, 'ErrorPIC', 'Gedimas PIC', 9, 0, 348, 1, NULL),
	(10505, 'ErrorWriteFlash_IM1', 'IM1 parametrų rašymo į FLASH klaida', 9, NULL, 416, 1, NULL),
	(10506, 'ErrorWriteFlash_IM2', 'IM2 parametrų rašymo į FLASH klaida', 9, NULL, 416, 1, NULL),
	(10507, 'ErrorWriteFlash_IM3', 'IM3 parametrų rašymo į FLASH klaida', 9, NULL, 416, 1, NULL),
	(10508, 'ErrorWriteFlash_IM4', 'IM4 parametrų rašymo į FLASH klaida', 9, NULL, 416, 1, NULL),
	(10509, 'ErrorProcessor', 'Procesoriaus gedimas', 9, 0, 349, 1, NULL),
	(10510, 'ErrorTimer', 'Taimerio gedimas', 9, 0, 350, 1, NULL),
	(10511, 'ErrorFlash', 'Flash atminties gedimas', 9, 0, 351, 1, NULL),
	(10512, 'MoreMax_I', 'I ritės MAX peržengimas', 5, 0, 352, 1, NULL),
	(10513, 'ErrorABB', 'ABB gedimas', 9, 0, 353, 1, NULL),
	(10514, 'ErrorCircuitABB', 'ABB grandinės klaida', 9, 0, 354, 1, NULL),
	(10515, 'ErrorI_ABB', 'ABB srovės įėjimo kanale klaida', 9, 0, 355, 1, NULL),
	(10516, 'ErrorR_ABB', 'ABB varžos įėjimo kanale klaida', 9, 0, 356, 1, NULL),
	(10517, 'ErrorTimeRead', 'Laiko nuskatymo klaida', 9, NULL, 416, 1, NULL),
	(10518, 'BadTime', 'Netinkamas laikas', 9, NULL, 794, 1, NULL),
	(10519, 'AdminAccess', 'Priegos lygis - administratorius', 8, NULL, 416, 1, NULL),
	(10520, 'MeteringModeStart', 'Matavimų režimo įjungimas', 3, NULL, 416, 1, NULL),
	(10521, 'PowerOnWMeteringOn', 'Įjungimas su matavimų tęsimu', 3, NULL, 416, 1, NULL),
	(10522, 'MeteringModeStop', 'Matavimų režimo išjungimas', 3, NULL, 416, 1, NULL),
	(10523, 'PowerOffWMeteringOn', 'Išjungimas su matavimų pertraukimu', 3, NULL, 416, 1, NULL),
	(10524, 'ConfigGUI', 'Vartotojo sąsajos nustatymo keitimas', 7, NULL, 416, 1, NULL),
	(10525, 'ConfigUsers', 'Slaptažodžių dumenų bazės keitimas', 7, NULL, 416, 1, NULL),
	(10526, 'SystInfo', 'Sisteminė informacija', 8, NULL, 416, 1, NULL),
	(10527, 'VoltagePulse1', '1 kanalo impulas', 5, NULL, 416, 1, NULL),
	(10528, 'VoltagePulse2', '2 kanalo impulas', 5, NULL, 416, 1, NULL),
	(10529, 'VoltagePulse3', '3 kanalo impulas', 5, NULL, 416, 1, NULL),
	(10530, 'OverVoltage1', '1 kanalo viršįtampis', 5, NULL, 416, 1, NULL),
	(10531, 'OverVoltage2', '2 kanalo viršįtampis', 5, NULL, 416, 1, NULL),
	(10532, 'OverVoltage3', '3 kanalo viršįtampis', 5, NULL, 416, 1, NULL),
	(10533, 'UnderVoltage1', '1 kanalo įtampos sumažėjimas', 5, NULL, 416, 1, NULL),
	(10534, 'UnderVoltage2', '2 kanalo įtampos sumažėjimas', 5, NULL, 416, 1, NULL),
	(10535, 'UnderVoltage3', '3 kanalo įtampos sumažėjimas', 5, NULL, 416, 1, NULL),
	(10536, 'MeteringStart', 'Matavimų paleidimas', 3, NULL, 416, 1, NULL),
	(10537, 'PlannedMeteringStop', 'Matavimų numatytas sustabdymas', 3, NULL, 416, 1, NULL),
	(10538, 'MeteringDelayedNoPower', 'Matavimų paleidimas atidėtas dėl matinimo stokos', 3, NULL, 416, 1, NULL),
	(10539, 'MeteringContinues', 'Matavimų tęsimas', 3, NULL, 416, 1, NULL),
	(10540, 'MeteringStopOutOfMemory', 'Sustabdymas dėl atminties stokos', 3, NULL, 416, 1, NULL),
	(10541, 'MeteringStopSwitchOff', 'Sustabdymas dėl prietaiso išjungimo', 3, NULL, 416, 1, NULL),
	(10542, 'MeteringStopFreqTooLow', 'Sustabdymas dėl dažnio ribos kritimo žemiau 40Hz', 3, NULL, 416, 1, NULL),
	(10543, 'MeteringStopFreqTooHigh', 'Sustabdymas dėl dažnio ribos viršijimo 60Hz', 3, NULL, 416, 1, NULL),
	(10544, 'MeteringStopVoltageTooLow', 'Sustabdymas dėl žemesnės už 70% nominalo įtampos', 3, NULL, 416, 1, NULL),
	(10545, 'MeteringStopVoltageTooHigh', 'Sustabdymas dėl didėsnės už 70% nominalo viršįtampos', 3, NULL, 416, 1, NULL),
	(10546, 'MeteringStopRestart', 'Prietaiso paleidimas iš naujo', 3, NULL, 416, 1, NULL),
	(10547, 'MeteringPeriodReset', 'Matavimo periodo numetimas', 9, NULL, 416, 1, NULL),
	(10548, 'ReverseEnergyFlow', 'Atvirkštinės krypties energijos tėkmė', 2, 0, 421, 1, NULL),
	(10549, 'ReverseEnergyFlow1', 'Atvirkštinės krypties energijos tėkmė 1-je fazėje', 2, 0, 422, 1, NULL),
	(10550, 'ReverseEnergyFlow2', 'Atvirkštinės krypties energijos tėkmė 2-je fazėje', 2, 0, 423, 1, NULL),
	(10551, 'ReverseEnergyFlow3', 'Atvirkštinės krypties energijos tėkmė 3-je fazėje', 2, 0, 424, 1, NULL),
	(10552, 'WatchDog', 'Suveikė WatchDog', 9, NULL, 416, 1, NULL),
	(10553, 'CableCoverOpen', 'Skaitiklio kleminio dangčio atidarymas ', 1, NULL, 647, 1, NULL),
	(10554, 'ByPassCurrent', 'Srovės dingimas', 6, 0, 795, 1, NULL),
	(10555, 'ByPassCurrent1', 'Srovės dingimas 1-je fazėje', 2, NULL, 416, 1, NULL),
	(10556, 'ByPassCurrent2', 'Srovės dingimas 2-je fazėje', 2, NULL, 416, 1, NULL),
	(10557, 'ByPassCurrent3', 'Srovės dingimas 3-je fazėje', 2, NULL, 416, 1, NULL),
	(10558, 'ByPassCurrent12', 'Srovės dingimas 1-je ir 2-je fazėse', 2, NULL, 416, 1, NULL),
	(10559, 'ByPassCurrent23', 'Srovės dingimas 2-je ir 3-je fazėse', 2, NULL, 416, 1, NULL),
	(10560, 'ByPassCurrent13', 'Srovės dingimas 1-je ir 3-je fazėse', 2, NULL, 416, 1, NULL),
	(10561, 'ByPassCurrent123', 'Srovės dingimas 1-je, 2-je ir 3-je fazėse', 2, NULL, 416, 1, NULL),
	(10562, 'VoltageLoss', 'Įtampos dingimas', 6, 0, 796, 1, NULL),
	(10563, 'VoltageLoss1', 'Įtampos dingimas 1-je fazėje', 2, NULL, 416, 1, NULL),
	(10564, 'VoltageLoss2', 'Įtampos dingimas 2-je fazėje', 2, NULL, 416, 1, NULL),
	(10565, 'VoltageLoss3', 'Įtampos dingimas 3-je fazėje', 2, NULL, 416, 1, NULL),
	(10566, 'VoltageLoss12', 'Įtampos dingimas 1-je ir 2-je fazėse', 2, NULL, 416, 1, NULL),
	(10567, 'VoltageLoss23', 'Įtampos dingimas 2-je ir 3-je fazėse', 2, NULL, 416, 1, NULL),
	(10568, 'VoltageLoss13', 'Įtampos dingimas 1-je ir 3-je fazėse', 2, NULL, 416, 1, NULL),
	(10569, 'VoltageLoss123', 'Įtampos dingimas 1-je, 2-je ir 3-je fazėse', 2, NULL, 416, 1, NULL),
	(10570, 'CriticalError', 'Kritinė klaida', 9, NULL, 416, 1, NULL),
	(10571, 'ClockReservationError', 'Prietaiso laikrodžio rezervavimo klaida', 9, NULL, 416, 1, NULL),
	(10572, 'ResultDestruction', 'Matavimo rezultato sunaikinimas', 9, NULL, 416, 1, NULL),
	(10573, 'ClockAdvanceChange', 'Laiko pervedimo sąlygos pasikeitimas', 4, NULL, 416, 1, NULL),
	(10574, 'StatusSetOfTimeSet', 'Laiko nustatymo statuso nustatymas', 12, NULL, 416, 1, NULL),
	(10575, 'InterruptRequest', 'Nutraukimo užklausimas', 8, NULL, 416, 1, NULL),
	(10576, 'RequestCanceled', 'Užklausimo atšaukimas', 8, NULL, 416, 1, NULL),
	(10577, 'PowerOnOffRequest', 'Užklausimas ĮJUNGTI/IŠJUNGTI', 3, NULL, 416, 1, NULL),
	(10578, 'InterruptError', 'Nutraukimo klaida', 9, NULL, 416, 1, NULL),
	(10579, 'ReportRestart', 'Ataskaitų perkrovimas', 3, NULL, NULL, 1, NULL),
	(10580, 'VariableSetting', 'Kintamojo nustatymas', 7, NULL, NULL, 1, NULL),
	(10581, 'UnreliableExtControl', 'Nepatikimas išorinis valdymas', 1, 0, 456, 1, NULL),
	(10582, 'VoltageNormal', 'Įtampa normalizavosi (po nukrypimo)', 5, NULL, NULL, 1, NULL),
	(10583, 'VoltageNormal1', 'Įtampa normalizavosi (po nukrypimo 1)', 5, NULL, NULL, 1, NULL),
	(10584, 'VoltageNormal2', 'Įtampa normalizavosi (po nukrypimo 2)', 5, NULL, NULL, 1, NULL),
	(10585, 'VoltageNormal3', 'Įtampa normalizavosi (po nukrypimo 3)', 5, NULL, NULL, 1, NULL),
	(10586, 'Other_Event', 'Kitas įvykis', 11, 0, 416, 1, NULL),
	(10587, 'Magnetic_Field_Count', 'Magnetinio lauko poveikių kiekis', 1, NULL, NULL, 3, NULL),
	(10588, 'Magnetic_Field_Duration', 'Magnetinio lauko poveikio trukmė', 1, NULL, NULL, 4, NULL),
	(10589, 'SeasonChange', 'Pasikeitė sezonas', 8, 0, 416, 1, NULL),
	(10590, 'TariffSeasonChange', 'Pasikeitė tarifo sezonas', 8, 0, 416, 1, NULL),
	(10591, 'Measurement_1', '1 fazės matavimo požymis', 2, 0, 491, 1, NULL),
	(10592, 'Measurement_2', '2 fazės matavimo požymis', 2, 0, 492, 1, NULL),
	(10593, 'Measurement_3', '3 fazės matavimo požymis', 2, 0, 493, 1, NULL),
	(10594, 'Direction_1', '1 fazės srovės kryptis', 2, 0, 494, 1, NULL),
	(10595, 'Direction_2', '2 fazės srovės kryptis', 2, 0, 495, 1, NULL),
	(10596, 'Direction_3', '3 fazės srovės kryptis', 2, 0, 496, 1, NULL),
	(10597, 'InternalErrors', 'Klaidos', 9, 0, 416, 1, NULL),
	(10598, 'ProcessingProfil', 'Profilio rodyklių apdorojimas', 8, 0, 497, 1, NULL),
	(10599, 'ProcessingDays', 'Dienų rodyklių apdorojimas', 8, 0, 498, 1, NULL),
	(10600, 'ProcessingMonths', 'Mėnesių rodyklių apdorojimas', 8, 0, 499, 1, NULL),
	(10601, 'OddClockSec', 'Laikrodžio sekundė', 15, NULL, 838, 1, NULL),
	(10602, 'OppositeDirectEnergy', 'Registruota energija priešinga kryptimi', 9, NULL, NULL, 4, NULL),
	(10603, 'PowerBlackoutsCount', 'Įrenginių atjungimų kiekis', 3, NULL, NULL, 3, NULL),
	(10604, 'PhaseChangesCount', 'Fazių keitimų kiekis', 2, NULL, NULL, 3, NULL),
	(10605, 'LocalPrgCount', 'Lokalių parametravimų kiekis', 7, NULL, NULL, 3, NULL),
	(10606, 'ParamCF', 'Parametras CF', 7, 0, 416, 1, NULL),
	(10607, 'PeriodicalEoi', 'Periodinė intervalo pabaiga', 8, NULL, NULL, 1, NULL),
	(10608, 'AsynchronousEoi', 'Asinchroninė intervalo pabaiga', 8, NULL, NULL, 1, NULL),
	(10609, 'AsynchronousEoiProcPowerUp', 'Proceso įjungimo asinchroninė intervalo pabaiga', 8, NULL, NULL, 1, NULL),
	(10610, 'PeriodicalEob', 'Periodinė apskaitos pabaiga', 8, NULL, NULL, 1, NULL),
	(10611, 'ProgrammedEob', 'Programinė apskaitos pabaiga', 8, NULL, NULL, 1, NULL),
	(10612, 'AsynchronousEobComms', 'Ryšio asinchroninė apskaitos pabaiga', 8, NULL, NULL, 1, NULL),
	(10613, 'AsynchronousEobDisplay', 'Ekrano asinchroninė apskaitos pabaiga', 8, NULL, NULL, 1, NULL),
	(10614, 'AsynchronousEobInternal', 'Vidinė asinchroninė apskaitos pabaiga', 8, NULL, NULL, 1, NULL),
	(10615, 'IndexDpm', 'Dienos profilio pakeitimas', 7, NULL, NULL, 3, NULL),
	(10616, 'RestoreInternalIndex', 'Atkurtas vidinis indeksas', 7, NULL, NULL, 1, NULL),
	(10617, 'DayProfileCL', 'CL dienos profilis', 7, NULL, NULL, 1, NULL),
	(10618, 'RestoreInternalDayProfile', 'Atkurti vidinį dienos profilį', 7, NULL, NULL, 1, NULL),
	(10619, 'SeasonSm', 'SM sezonas', 7, NULL, NULL, 3, NULL),
	(10620, 'RestoreInternalSeason', 'Atkurti vidinį sezoną', 7, NULL, NULL, 1, NULL),
	(10621, 'DstWithSeason', 'Sezonas su vasaros/žiemos laiku', 7, NULL, NULL, 3, NULL),
	(10622, 'EnterDownloadMode', 'Parsisiuntimo būsena', 8, NULL, NULL, 1, NULL),
	(10623, 'SaveManufacturerParameters', 'Išsaugoti gamintojo parametrus', 7, NULL, NULL, 1, NULL),
	(10624, 'AssociationLnProgramming', 'DLMS COSEM asociacijos programavimas', 7, NULL, NULL, 3, NULL),
	(10625, 'IndexParameter', 'Indekso parametras', 7, NULL, NULL, 3, NULL),
	(10626, 'Eor', 'EOR', 8, NULL, NULL, 1, NULL),
	(10627, 'ParametersSaving', 'Skaitiklio parametrai išsaugoti atmintyje', 7, NULL, NULL, 1, NULL),
	(10628, 'ClearNonFatalAlarmsComms', 'Nesvarbūs ryšio aliarmai ištrinti', 8, NULL, NULL, 1, NULL),
	(10629, 'ClearNonFatalAlarmsDisplay', 'Nesvarbūs ekrano aliarmai ištrinti', 8, NULL, NULL, 1, NULL),
	(10630, 'ClearFatalAlarms', 'Svarbūs aliarmai ištrinti', 8, NULL, NULL, 1, NULL),
	(10631, 'InternalClockSynchro', 'Realaus laiko laikrodis sinchronizuotas iš vidaus', 7, NULL, NULL, 1, NULL),
	(10632, 'DstWithoutSeason', 'Sezonas be vasaros/žiemos laiko', 7, NULL, NULL, 1, NULL),
	(10633, 'AcFailAppearanceThreshold', 'Limitų sutrikimai', 5, NULL, NULL, 1, NULL),
	(10634, 'AcFailAppearancePhasescut', 'Fazių sutrikimai', 2, NULL, NULL, 1, NULL),
	(10635, 'AcFailDisappearanceThreshold', 'Limitų sutrikimai pašalinti', 5, NULL, NULL, 1, NULL),
	(10636, 'AcFailDisappearancePresencephase', 'Fazių sutrikimai pašalinti', 2, NULL, NULL, 1, NULL),
	(10637, 'ProgrammingCm', 'Programavimas CM', 7, NULL, NULL, 3, NULL),
	(10638, 'ProgrammingDi', 'Programavimas DI', 7, NULL, NULL, 3, NULL),
	(10639, 'CancelProgrammingDi', 'Atšaukti programavimą DI', 7, NULL, NULL, 3, NULL),
	(10640, 'ResetMeasurementData', 'Numesti skaitiklio duomenis', 7, NULL, NULL, 1, NULL),
	(10641, 'StartMeasurement', 'Matavimo pradžia', 7, NULL, NULL, 1, NULL),
	(10642, 'StopMeasurement', 'Matavimo pabaiga', 7, NULL, NULL, 1, NULL),
	(10643, 'StartTriggeredTests', 'Trigerinių testų pradžia', 8, NULL, NULL, 1, NULL),
	(10644, 'StartTriggeredTestsOutput', 'Išvedimo trigeriinių testų pradžia', 8, NULL, NULL, 1, NULL),
	(10645, 'StopTriggeredTests', 'Trigerinių testų pabaiga', 8, NULL, NULL, 1, NULL),
	(10646, 'EndOfCurrentDataSaving24h', 'Registro duomenys išsaugoti (kas 24 val.)', 8, NULL, NULL, 1, NULL),
	(10647, 'EndOfCurrentDataSavingPowerUp', 'Registro duomenys išsaugoti po įjugimo', 8, NULL, NULL, 1, NULL),
	(10648, 'EndOfCurrentDataSavingPowerFail', 'Registro duomenys išsaugoti po maitinimo dingimo', 8, NULL, NULL, 1, NULL),
	(10649, 'PasswordRestoration', 'Skaitiklių slaptažodžiai pagal nutylėjimą atsatyti', 7, NULL, NULL, 1, NULL),
	(10650, 'IndexClockLoss', 'Indekso laikrodžio praradimai', 9, NULL, NULL, 3, NULL),
	(10651, 'SuccessfulCommunicationUtility', 'Pagalbinis sujungimas sėkmingas', 8, NULL, NULL, 1, NULL),
	(10652, 'SuccessfulCommunicationCustom', 'Specifinis sujungimas sėkmingas', 8, NULL, NULL, 1, NULL),
	(10653, 'ManufacturerAlarmAppearance', 'Gamintojo aliarmas', 9, NULL, NULL, 1, NULL),
	(10654, 'ClearManufacturerAlarms', 'Išvalyti gamintojo aliarmai', 8, NULL, NULL, 1, NULL),
	(10655, 'ResetTer', 'Perkrauti TER', 3, NULL, NULL, 1, NULL),
	(10656, 'InternalRamError', 'Vidinė RAM klaida', 9, NULL, NULL, 1, NULL),
	(10657, 'ExternalRamError', 'Išorinė RAM klaida', 9, NULL, NULL, 1, NULL),
	(10658, 'InternalProgramMemoryError', 'Vidinė programos atminties klaida', 9, NULL, NULL, 1, NULL),
	(10659, 'ExternalProgramMemoryError', 'Išorinė programos atminties klaida', 9, NULL, NULL, 1, NULL),
	(10660, 'WatchdogActivity', 'Watchdog veikla', 8, NULL, NULL, 1, NULL),
	(10661, 'ExternalClockIncoherence', 'Išorinio laikrodžio nesuderinamumas', 9, NULL, NULL, 1, NULL),
	(10662, 'ConfigurationIncoherence', 'Konfigūracijos nesuderinamumas', 9, NULL, NULL, 1, NULL),
	(10663, 'NonVolatileMemoryNonFatalError', '"Flash" atminties priėjimo klaida', 9, NULL, NULL, 1, NULL),
	(10664, 'ProgrammingIncoherence', 'Programavimo nesuderinamumas', 9, NULL, NULL, 1, NULL),
	(10665, 'NoInternalConsumption', 'Energijos vartojimo nebuvimas', 9, NULL, NULL, 1, NULL),
	(10668, 'ClockLoss', 'Realaus laiko laikrodžio praradimai', 9, NULL, NULL, 1, NULL),
	(10669, 'ExternalAlarm', 'Išorinis aliarmas', 9, NULL, NULL, 1, NULL),
	(10674, 'VoltageSagPhase1', 'Įtampos kritimas 1 fazėje', 2, NULL, NULL, 1, NULL),
	(10675, 'VoltageSagPhase2', 'Įtampos kritimas 2 fazėje', 2, NULL, NULL, 1, NULL),
	(10676, 'VoltageSagPhase3', 'Įtampos kritimas 3 fazėje', 2, NULL, NULL, 1, NULL),
	(10677, 'VoltageSwellPhase1', 'Įtampos bangavimas 1 fazėje', 2, NULL, NULL, 1, NULL),
	(10678, 'VoltageSwellPhase2', 'Įtampos bangavimas 2 fazėje', 2, NULL, NULL, 1, NULL),
	(10679, 'VoltageSwellPhase3', 'Įtampos bangavimas 3 fazėje', 2, NULL, NULL, 1, NULL),
	(10680, 'ExternalBatteryInstallTime', 'Išorinės baterijos pajungimo laikas', 8, NULL, 416, 1, NULL),
	(10682, 'BatteryMissing', 'Baterijos nėra', 6, NULL, NULL, 1, NULL),
	(10684, 'MeterWorkTime', 'Skaitiklio darbo laikas', 15, NULL, NULL, 4, 10),
	(10685, 'BadTemperature_Duration', 'Prastos temperatūros poveikio trukmė', 9, NULL, NULL, 4, NULL),
	(10686, 'Timer_Adjust_Duration', 'Laiko korekcijos trukmė', 4, NULL, NULL, 4, NULL),
	(10687, 'ResetCount', 'Numetimų kiekis', 3, NULL, NULL, 3, NULL),
	(10688, 'EvState_Three_wire', 'Skaitiklio pajungimo schema', 24, NULL, 839, 1, NULL),
	(10689, 'EvState_12V', 'Maitinimas 12 V', 8, 0, 500, 1, NULL),
	(10690, 'NewPowerValue', 'Įvykių būklė maitinimo dingimų žurnale ', 6, 0, 501, 1, NULL),
	(10691, 'NewPhazeValue', 'Įvykių būklė fazių perjungimų žurnale ', 2, 0, 502, 1, NULL),
	(10692, 'NewOtherValue', 'Įvykių būklė žurnale ', 8, 0, 503, 1, NULL),
	(10693, 'OptConnectParam', 'Ryšys parametravimui per optinę galvutę', 8, 0, 504, 1, NULL),
	(10694, 'OptConnectRead', 'Ryšys skaitymui per optinę galvutę', 8, 0, 505, 1, NULL),
	(10695, 'EndIntPeriod', 'Integravimo periodo būklė', 8, 0, 506, 1, NULL),
	(10696, 'EndDay', 'Dienos būklė', 8, 0, 507, 1, NULL),
	(10697, 'EndMonth', 'Mėnesio būklė', 8, 0, 508, 1, NULL),
	(10698, 'EndYear', 'Metų būklė', 8, 0, 509, 1, NULL),
	(10699, 'Timer_Adjust_Limit', 'Laiko korekcijos ribos būklė', 4, 0, 510, 7, NULL),
	(10700, 'BadVKM', 'Blogas VKM', 8, 0, 511, 1, NULL),
	(10701, 'RemotPrgCount', 'Nuotolinių parametravimų kiekis', 7, NULL, NULL, 3, NULL),
	(10702, 'PowerOutagesCount', 'Įtampos nestabilumų kiekis', 6, NULL, NULL, 3, NULL),
	(10703, 'BadTemperatureCount', 'Prastos temperatūros poveikių kiekis', 9, NULL, NULL, 3, NULL),
	(10704, 'BillingCount', 'Suformuotų ataskaitų kiekis', 11, NULL, NULL, 3, NULL),
	(10705, 'Case_Open_Count', 'Dangtelio atidarymų kiekis', 1, NULL, NULL, 3, NULL),
	(10706, 'Block_Connect_Count', 'Ryšio blokavimų kiekis', 9, NULL, NULL, 3, NULL),
	(10707, 'SetTime_Count', 'Laiko nustatymų kiekis', 12, NULL, NULL, 3, NULL),
	(10708, 'Comulation_Reset_Count', 'Kumuliacinės galios numetimų kiekis', 9, NULL, NULL, 3, NULL),
	(10709, 'Watchdog_Reset_Count', 'Watchdog numetimų kiekis', 9, NULL, NULL, 3, NULL),
	(10710, 'Illegal_Operation_Count', 'Neleistinų operacijų kiekis', 9, NULL, NULL, 3, NULL),
	(10711, 'Error_Need_Reset_Count', 'Klaidų skaičius su perkrovimu', 9, NULL, NULL, 3, NULL),
	(10712, 'Error_Without_Reset_Count', 'Klaidų skaičius be perkrovimų', 9, NULL, NULL, 3, NULL),
	(10713, 'SpecialDayChange', 'Pasikeitė speciali diena', 9, 0, 416, 1, NULL),
	(10714, 'TariffsMaxChange', 'Pasikeitė maksimalios galios tarifas', 9, 0, 416, 1, NULL),
	(10715, 'DeviceAccessedforRead', 'Prietaisas pasiekiamas skaityti', 8, 0, 416, 1, NULL),
	(10716, 'DeviceAccessedforWrite', 'Prietaisas pasiekiamas rašyti', 8, 0, 416, 1, NULL),
	(10717, 'ProcedureInvoked', 'Procedūra iškviesta', 8, 0, 416, 1, NULL),
	(10718, 'TableWrittenTo', 'Lentelė įrašyta', 8, 0, 416, 1, NULL),
	(10719, 'CommunicationTerminatedNormally', 'Perdavimas pasibaigė normaliai', 8, 0, 416, 1, NULL),
	(10720, 'CommunicationTerminatedAbnormally', 'Perdavimas pasibaigė neteisingai', 8, 0, 416, 1, NULL),
	(10721, 'ResetListPointers', 'Numetimų sąrašo rodyklės', 8, 0, 416, 1, NULL),
	(10722, 'UpdateListPointers', 'Atnaujinimų sąrašo rodyklės', 8, 0, 416, 1, NULL),
	(10723, 'HistoryLogPointersUpdated', 'Rodykles žurnalas istorijų buvo atnaujintos', 8, 0, 416, 1, NULL),
	(10724, 'EventLogPointersUpdated', 'Rodykles įvykių žurnale atnaujinta', 8, 0, 416, 1, NULL),
	(10725, 'SelfReadOccurred', 'Nusiskaitymas', 8, 0, 416, 1, NULL),
	(10726, 'DaylightSavingsTimeOn', 'Vasaros laiko režimas', 8, 0, 512, 1, NULL),
	(10727, 'RateChange', 'Lygio keitimas', 8, 0, 416, 1, NULL),
	(10728, 'PendingTableActivation', 'Lentelės aktyvaciją laukimo režime', 8, 0, 416, 1, NULL),
	(10729, 'PendingTableClear', 'Lentelės išvalymas laukimo režime', 8, 0, 416, 1, NULL),
	(10730, 'Metershopmode', 'Parduotuvės režimas skaitiklyje', 8, 0, 513, 1, NULL),
	(10731, 'MemoryError', 'Atminties klaida', 9, 0, 416, 1, NULL),
	(10732, 'LowLossPotential', 'Žemas nuostolių potencialas', 9, 0, 416, 1, NULL),
	(10733, 'DemandOverload', 'Perkrovos reikalavimas', 9, 0, 416, 1, NULL),
	(10734, 'TamperAttempt', 'Bandymas trenkti', 8, 0, 416, 1, NULL),
	(10735, 'ControlPointChanged', 'Kontrolinis taškas pasikeitė', 8, 0, 416, 1, NULL),
	(10736, 'DeviceSealed', 'Įrenginio izoliacijos būklė', 8, 0, 514, 1, NULL),
	(10737, 'ReadSecuredTable', 'Saugomos lentelės skaitymas', 8, 0, 416, 1, NULL),
	(10738, 'ReadSecuredRegister', 'Saugomo registro skaitymas', 8, 0, 416, 1, NULL),
	(10739, 'AddedToRemainingCredit', 'Pridėtas prie kredito likučio', 8, 0, 416, 1, NULL),
	(10740, 'SubtractedToRemainingCredit', 'Išskaičiuotas iš kredito likučio', 8, 0, 416, 1, NULL),
	(10741, 'AdjustedTheRemainingCredit', 'Pakoreguotas kredito likutis', 8, 0, 416, 1, NULL),
	(10742, 'RS485Access', 'Prieigos per RS485 mėginimas', 1, NULL, 416, 1, NULL),
	(10743, 'PanelAccess', 'Prieigos per mygtukus mėginimas', 1, NULL, 416, 1, NULL),
	(10744, 'OverCurrent', 'Srovės perkrovos visose fazėse', 2, 0, 589, 1, NULL),
	(10745, 'OverCurrent1', 'Srovės perkrovos 1 fazėje', 2, 0, 590, 1, NULL),
	(10746, 'OverCurrent2', 'Srovės perkrovos 2 fazėje', 2, 0, 591, 1, NULL),
	(10747, 'OverCurrent3', 'Srovės perkrovos 3 fazėje', 2, 0, 592, 1, NULL),
	(10748, 'BadLinkParams', 'Sąsajos apsikeitimų problemos(apsikeitimo parametrai nepatikimi)', 9, NULL, 416, 1, NULL),
	(10749, 'ElectronicSealWork', 'Elektroninės plombos suveikimas', 1, 0, 593, 1, NULL),
	(10750, 'MainDataErr', 'Pagrindinių sukauptų duomenų problemos', 9, NULL, 416, 1, NULL),
	(10751, 'AdditionalDataErr', 'Papildomų sukauptų duomenų problemos', 9, NULL, 416, 1, NULL),
	(10752, 'Total_Energy_Err', 'Augančios energijos įrašymo klaida', 9, NULL, 416, 1, NULL),
	(10753, 'ProfileData_Err', 'Profilio duomenų kaupiklio problemos', 9, NULL, 416, 1, NULL),
	(10754, 'LastSunday', 'Paskutinis mėnesio sekmadienis', 11, NULL, 416, 1, NULL),
	(10755, 'TariffsProblem', 'Tarifikavimo problemos (nėra apskaitos pagal tarifus)', 9, NULL, 416, 1, NULL),
	(10756, 'DaysGraphArrayErr', '"Dienų grafikų" masyvo klaida', 9, NULL, 416, 1, NULL),
	(10757, 'SeassonArrayErr', '"Sezonų grafikų" masyvo klaida', 9, NULL, 416, 1, NULL),
	(10758, 'SpecialDaysArrayErr', '"Specialių dienų" masyvo klaida', 9, NULL, 416, 1, NULL),
	(10759, 'PasswordReset', 'Slaptažodžių numetimas', 7, NULL, 416, 1, NULL),
	(10760, 'LimitChange', 'Limitų keitimas', 5, NULL, 416, 1, NULL),
	(10761, 'NegativeAngle', 'Kampo tarp įtampos vektorių neigama reikšmė (kai yra visos 3 fazės)', 2, NULL, 416, 1, NULL),
	(10762, 'KFCRCError', 'Kalibravimo koeficientų kontrolinės sumos klaida', 9, NULL, 416, 1, NULL),
	(10763, 'TechnologicParamsChange', 'Technologinių parametrų keitimai', 7, NULL, 416, 1, NULL),
	(10764, 'TechnologicParamsErr', 'Technologinės dalies problemos (nėra energijos apskaitos)', 9, NULL, 416, 1, NULL),
	(10765, 'MeasuringParamsErr', 'Matuoklio parametrų problemos (nėra energijos apskaitos)', 9, NULL, 416, 1, NULL),
	(10766, 'EventsErr', 'Žurnalų problemos (nepatikima informacija žurnaluose)', 9, NULL, 416, 1, NULL),
	(10767, 'AveragingTime', 'Priartinimo prie vidurkio laikas', 11, NULL, 416, 1, NULL),
	(10768, 'ResistanceChange', 'Fazių laidų varžos pasikeitimas', 2, NULL, 416, 1, NULL),
	(10769, 'CorrectionTime_Count', 'Laiko korekcijų kiekis', 11, NULL, NULL, 4, NULL),
	(10770, 'NotAuthorizedAccess_Count', 'Neautorizuotos prieigos bandymų skaičius', 11, NULL, NULL, 3, NULL),
	(10771, 'DstChange', 'Perėjimas į žiemos/vasaros laiką ', 8, 0, 416, 1, NULL),
	(10772, 'PhaseFailure', 'Fazės įtampos dingimas', 2, 0, 553, 1, NULL),
	(10773, 'PhaseFailureInPeriod', 'Apkrovos profilio intervale registruotas įtampos dingimas vienoje ir daugiau fazėse ', 2, 0, 416, 1, NULL),
	(10774, 'ReverseEnergyFlowInPeriod', 'Apkrovos profilio intervale registruotas energijos atvirkštinis srautas', 2, 0, 416, 1, NULL),
	(10775, 'VoltageTest', 'Įtampos testavimas', 8, 0, 554, 1, NULL),
	(10776, 'UnderVoltage', 'Įtampa normos ribose', 5, 0, 555, 1, NULL),
	(10777, 'OverVoltage', 'Įtampa normos ribose', 5, 0, 556, 1, NULL),
	(10778, 'PowerCoefOrReverse', 'Įtampos reverso koeficiento testavimas', 5, 0, 557, 1, NULL),
	(10779, 'LowCurrent', 'Srovė yra normos ribose', 5, 0, 558, 1, NULL),
	(10780, 'PowerFactorTh', 'Įtampos koeficiento testavimas', 5, 0, 559, 1, NULL),
	(10781, 'SecondHarmonicCurrTh', 'Antra harmoninė srovė yra normos ribose', 5, 0, 560, 1, NULL),
	(10782, 'SinCurrCoefTh', 'Nesinusoidinės srovės koeficientas yra normos ribose', 5, 0, 561, 1, NULL),
	(10783, 'SinVoltCoefTh', 'Nesinusoidinės įtampos koeficientas yra normos ribose', 5, 0, 562, 1, NULL),
	(10784, 'PhaseVoltageCoefTh', 'Fazinių įtampų atitikties koeficientas normos ribose', 5, 0, 563, 1, NULL),
	(10785, 'PhaseCurrentCoefTh', 'Fazinių srovių atitikties koeficientas normos ribose', 5, 0, 564, 1, NULL),
	(10786, 'TotalDemandCoefTh', 'Bendras įtampos iškraipymų koeficientas normos ribose', 5, 0, 565, 1, NULL),
	(10787, 'PointAccessErr', 'Ryšio su apklausos tašku dingimas', 9, 0, 566, 1, NULL),
	(10788, 'AutoSwitchPoint', 'Automatinis perjungimas į apklausos tašką', 8, 0, 416, 1, NULL),
	(10789, 'StartAutoAcq', 'Automatinės apklausos pradžia', 8, 0, 567, 1, NULL),
	(10790, 'UnSyncControllerDt', 'Laikų skirtumo su žemesnio lygio koncentratoriumi ribos peržengimas', 5, 0, 416, 1, NULL),
	(10791, 'ControllerAccessErr', 'Ryšio su žemesnio lygio koncentratoriumi dingimas', 9, 0, 568, 1, NULL),
	(10792, 'TimeAdjustForController', 'Žemesnio lygio koncentratoriaus laiko korekcijos komanda', 4, 0, 416, 1, NULL),
	(10793, 'TimeAdjustForMeter', 'Skaitiklio laiko korekcijos komanda', 4, 0, 416, 1, NULL),
	(10794, 'MeterConfigChange', 'Skaitiklio konfiguracijos keitimas', 7, 0, 416, 1, NULL),
	(10795, 'SystemErrorEv', 'Sisteminė klaida skaitiklyje', 9, 0, 416, 1, NULL),
	(10796, 'MeterProfRegisterOverf', 'Skaitiklio registrų perpildymo intervalo registravimas', 9, 0, 416, 1, NULL),
	(10797, 'MeterTimeDiffStopAcq', 'Laiko skirtumo su skaitikliu ribos peržengimas, duomenų surinkimas sustabdytas', 9, 0, 416, 1, NULL),
	(10798, 'MeterDescrErrStopAcq', 'Surinkimo sustabdymas dėl parametravimo klaidos', 9, 0, 569, 1, NULL),
	(10799, 'PhaseOpposition', 'Srovės ir įtampos priešingoji fazė', 2, 0, 582, 1, NULL),
	(10800, 'OverloadCurrent', 'Srovės perkrova', 5, 0, 583, 1, NULL),
	(10801, 'OverloadVoltage', 'Įtampos perkrova', 5, 0, 584, 1, NULL),
	(10802, 'SettingDevice', 'Prietaiso nustatymas', 8, 0, 416, 1, NULL),
	(10803, 'PasswordChange_1', 'Vartotojo slaptažodžio keitimas (1 lygis)', 8, 0, 416, 1, NULL),
	(10804, 'PasswordChange_2', 'Vartotojo slaptažodžio keitimas (2 lygis)', 8, 0, 416, 1, NULL),
	(10805, 'SettingMenu', 'Meniu nustatymas', 8, 0, 416, 1, NULL),
	(10806, 'SettingTariffing', 'Tarifikavimo nustatymas', 8, 0, 416, 1, NULL),
	(10807, 'SettingExternalDevices', 'Išorinių įrenginių nustatymas', 8, 0, 416, 1, NULL),
	(10808, 'ResetImpulsesExternalDevices', 'Impulsų nuo išorinių įrenginių apskaitos numetimas', 8, 0, 416, 1, NULL),
	(10809, 'SettingProfileChannel', 'Profilio kanalo nustatymas', 8, 0, 416, 1, NULL),
	(10810, 'SettingExternalDevicesAuto', 'Išorinių įrenginių nustatymas, automatinė programa', 8, 0, 416, 1, NULL),
	(10811, 'ClearInterface', 'Sąsajos numetimas', 7, 0, 416, 1, NULL),
	(10812, 'OverflowMemory', 'Aparatinės atminties perpildymas', 9, 0, 416, 1, NULL),
	(10813, 'FailureMemory', 'Aparatinės atminties sutrikimas', 9, 0, 416, 1, NULL),
	(10814, '?xceptionDevice', 'Išimtis', 9, 0, 416, 1, NULL),
	(10815, 'ChangeUserName', 'Vartotojo vardas pakeistas', 7, 0, 416, 1, NULL),
	(10816, 'TimeOutChange', 'Ryšio taimautas pakeistas', 7, 0, 416, 1, NULL),
	(10817, 'ObjAddressChange', 'Objekto tinklo adresas pakeistas', 7, 0, 416, 1, NULL),
	(10818, 'InterfaceChange_232', 'Sąsajos RS232 parametrai pakeisti', 7, 0, 416, 1, NULL),
	(10819, 'InterfaceChange_485', 'Sąsajos RS485 parametrai pakeisti', 7, 0, 416, 1, NULL),
	(10820, 'InterfaceChange_CAN', 'Sąsajos CAN parametrai pakeisti', 7, 0, 416, 1, NULL),
	(10821, 'TestGeneratorChange', 'Testinio generatoriaus parametrai pakeisti', 7, 0, 416, 1, NULL),
	(10822, 'DirectAccesChange', 'Tiesioginės prieigos prie sąsajų parametrai pakeisti', 7, 0, 416, 1, NULL),
	(10823, 'AdditionalTimeOutChange', 'Atsakymo laukimo papildomo taimauto reikšmė pakeista', 7, 0, 416, 1, NULL),
	(10824, 'TimeDeltaChange', 'Maksimalaus laiko nuokrypio reikšmė pakeista', 7, 0, 416, 1, NULL),
	(10825, 'AccumulationSeveralInterfChange', 'Vienalaikio surinkimo keliose sąsajose požymis pakeistas', 7, 0, 416, 1, NULL),
	(10826, 'DataSaveFormatChange', 'Duomenų saugojimo ir perdavimo formatas pakeistas', 7, 0, 416, 1, NULL),
	(10827, 'ScanParamsChange', 'Tinklo skenavimo ir pajungtų prietaisų automatinio konfiguravimo parametrai pakeisti', 7, 0, 416, 1, NULL),
	(10828, 'DataIntervalChange', 'Duomenų surinkimo laiko intervalai pakeisti', 7, 0, 416, 1, NULL),
	(10829, 'NewMeterInit', 'Skaitiklio įvedimas', 7, 0, 416, 1, NULL),
	(10830, 'ChangeProfileDefinition', 'Profilių aprašymas pakeistas', 7, 0, 416, 1, NULL),
	(10831, 'ChangeProfileType', 'Profilių reikšmės tipas pakeistas', 7, 0, 416, 1, NULL),
	(10832, 'ChangeProfileMemory', 'Profilių duomenų saugojimo vieta pakeista', 7, 0, 416, 1, NULL),
	(10833, 'ChangeProfilePeriod', 'Profilių laiko periodas pakeistas', 7, 0, 416, 1, NULL),
	(10834, 'ChangeProfileTariffsCount', 'Profilių tarifų kiekis pakeistas', 7, 0, 416, 1, NULL),
	(10835, 'ChangeProfileSource', 'Profilių profilis-šaltinis pakeistas', 7, 0, 416, 1, NULL),
	(10836, 'ChangeProfileChannelsCount', 'Profilių kanalų kiekis pakeistas', 7, 0, 416, 1, NULL),
	(10837, 'RelayLimit', 'Relės įjungimas pagal limitus', 5, 0, 596, 1, NULL),
	(10838, 'PowerReserveDischarge', 'Rezervinio maitinimo elemento išlydis', 11, NULL, 416, 1, NULL),
	(10839, 'ChangeMetersList', 'Prietaisų sąrašo pakeitimai', 7, NULL, 416, 1, NULL),
	(10840, 'ElectronicSealOpen', 'Elektronės plombos atidarymas', 1, NULL, 416, 1, NULL),
	(10841, 'DemandForMeter', 'Apkrovos valdymas', 7, NULL, 597, 6, NULL),
	(10842, 'TariffWritingInMeter', 'Tarifų tvarkaraščių įrašymo užduočių būsenos', 8, NULL, 598, 7, NULL),
	(10843, 'ConnectedMeterInfo', 'Pajungtų prietaisų informacija', 8, NULL, 599, 5, NULL),
	(10844, 'ExchangeMeterData', 'Apsikeitimo su skaitikliu rezultatas', 8, NULL, 600, 5, NULL),
	(10845, 'TestRamOk', 'RAM testavimo rezultatai', 8, NULL, 602, 5, NULL),
	(10846, 'TestMemoryOk', 'Atminties testavimo rezultatai', 8, NULL, 603, 5, NULL),
	(10847, 'FailureInterface_CAN', 'CAN sąsajos klaida', 8, NULL, 604, 5, NULL),
	(10848, 'SupernumerarySituation', 'Nenumatyta situacija', 8, NULL, 605, 5, NULL),
	(10849, 'OverCurrentN', 'Srovės perkrova neutralėje', 5, 0, 601, 1, NULL),
	(10850, 'MeteringParamChange', 'Skaitiklio duomenų parametrų keitimas', 7, NULL, 416, 1, NULL),
	(10851, 'CommandExecution', 'Komandos vykdymas', 11, NULL, 416, 1, NULL),
	(10852, 'IdentificationParamChange', 'Identifikacijos parametrų keitimas', 7, NULL, 416, 1, NULL),
	(10853, 'ClockParamChange', 'Laiko parametrų keitimas', 12, NULL, 416, 1, NULL),
	(10854, 'RelayForMeter', 'Relės valdymas', 7, NULL, 606, 6, NULL),
	(10855, 'ChangeGroupRead', 'Duomenų surinkime pakeistas sugrupuoto nuskaitymo požymis', 7, NULL, 416, 1, NULL),
	(10856, 'ChangeMAXPACKET', 'Duomenų surinkime pakeistas maksimalus paketo ilgis', 7, NULL, 416, 1, NULL),
	(10857, 'ChangeADDRORIGIN_CONTROL', 'Pakeistas skaitm. sąsajos skaitiklių dubliavimo kontrolės požymis', 7, NULL, 416, 1, NULL),
	(10858, 'MWDI_TypeChange', 'Pakeistas skaitm. sąsajos skaitiklių tipas', 7, NULL, 416, 1, NULL),
	(10859, 'MWDI_InterfaceChange', 'Pakeista skaitm. sąsajos skaitiklių sąsaja', 7, NULL, 416, 1, NULL),
	(10860, 'MWDI_IDChange', 'Pakeistas skaitm. sąsajos skaitiklių identifikatorius', 7, NULL, 416, 1, NULL),
	(10861, 'MWDI_PasswordChange', 'Pakeistas skaitm. sąsajos skaitiklių slaptažodis', 7, NULL, 416, 1, NULL),
	(10862, 'MWDI_AddrChange', 'Pakeistas skaitm. sąsajos skaitiklių adresas', 7, NULL, 416, 1, NULL),
	(10863, 'MWDI_Route831Change', 'Pakeistas skaitm. sąsajos skaitiklių apsikeitimo per SE831 maršrutas', 7, NULL, 416, 1, NULL),
	(10864, 'MWDI_SubNetChange', 'Pakeistas skaitm. sąsajos skaitiklių apsikeitimo per SE831 loginis potinklis', 7, NULL, 416, 1, NULL),
	(10865, 'MWDI_Route832Change', 'Pakeistas skaitm. sąsajos skaitiklių apsikeitimo per SE831 maršruto šablonas', 7, NULL, 416, 1, NULL),
	(10866, 'MWDI_ModemIdChange', 'Pakeistas skaitm. sąsajos skaitiklių modemo identifikatorius', 7, NULL, 416, 1, NULL),
	(10867, 'MWDI_GroupChange', 'Pakeista apskaitos grupė', 7, NULL, 416, 1, NULL),
	(10868, 'MWDI_ModemTypeChange', 'Pakeistas modemo tipas', 7, NULL, 416, 1, NULL),
	(10869, 'MWDI_StatusChange', 'Pakeista keitimo kontolė', 7, NULL, 416, 1, NULL),
	(10870, 'MWDI_RelayChange', 'Pakeistas relės būsenos skaitymas', 7, NULL, 416, 1, NULL),
	(10871, 'MWDI_LogEventsChange', 'Pakeistas žurnalų surinkimas', 7, NULL, 416, 1, NULL),
	(10872, 'MWDI_BaudChange', 'Pakeistas apsikeitimo greitis', 7, NULL, 416, 1, NULL),
	(10873, 'Relay2Limit', '2 relės įjungimas pagal limitus/2 relės išjungimas pagal limitus', 7, NULL, 416, 1, NULL),
	(10874, 'WriteLimitStop', 'Limitų įrašymas į skaitm. sąsajos skaitiklį baigtas', 7, NULL, 416, 1, NULL),
	(10875, 'LimitsForMeterP', 'Galios limitų įrašymas į skaitiklius', 7, NULL, 607, 1, NULL),
	(10876, 'PasswodrsForMeters', 'Slaptažodžių įrašymas į skaitiklius', 7, NULL, 608, 1, NULL),
	(10877, 'Clock_Invalid', 'Laikrodis gali būti negaliojantis', 9, NULL, NULL, 7, NULL),
	(10878, 'Replace_Battery', 'Baterija turi būti keičiama dėl pasibaigusio tarnavimo laiko', 8, NULL, NULL, 1, NULL),
	(10879, 'TOU_Activated', 'Pasyvus TOU buvo aktyvuotas', 8, NULL, NULL, 1, NULL),
	(10880, 'Error_Register_Cleared', 'Klaidų registras buvo išvalytas', 8, NULL, NULL, 1, NULL),
	(10881, 'Alarm_Register_Cleared', 'Signalizacijos registras buvo išvalytas', 8, NULL, NULL, 1, NULL),
	(10882, 'Measurement_System_Error', 'Loginės arba fizinės klaidos matavimo sistemoje', 9, NULL, NULL, 1, NULL),
	(10883, 'Firmware_Ready_For_Activation', 'Nauja programinė įranga buvo sėkmingai parsisiųsta ir patikrinta, parengta aktyvavimui', 8, NULL, NULL, 1, NULL),
	(10884, 'Firmware_Activated', 'Nauja programinė įranga buvo aktyvuota', 8, NULL, NULL, 1, NULL),
	(10885, 'Uart_Optic_Active', 'Optinis UART buvo aktyvuotas', 8, NULL, NULL, 1, NULL),
	(10886, 'FirmwareUpdated', 'Buvo pakeista programinė įranga', 8, NULL, NULL, 1, NULL),
	(10887, 'LimitsForMeterE', 'Energijos limitų įrašymas į skaitiklius', 7, NULL, 607, 1, NULL),
	(10888, 'LimitsForMeterCancel', 'Limitų įrašymo atšaukimas', 7, NULL, 607, 1, NULL),
	(10889, 'DespoticDataCollection', 'Duomenų surinkimas pagal užklausą', 8, NULL, 609, 1, NULL),
	(10890, 'FraudLogReset', 'Pažeidimų aptikimų įvykių žurnalas išvalytas', 8, NULL, NULL, 1, NULL),
	(10891, 'DisconnectorLogReset', 'Skyriklio kontrolės įvykių žurnalas išvalytas', 8, NULL, NULL, 1, NULL),
	(10892, 'ExtraLogReset', 'Papildomas įvykių žurnalas išvalytas', 8, NULL, NULL, 1, NULL),
	(10893, 'CreditOut', 'Kreditas pasiekė 0', 8, NULL, 656, 1, NULL),
	(10894, 'UnbalancePower', 'Aptiktas galios disbalansas (3 fazėse)', 5, NULL, 657, 1, NULL),
	(10895, 'UnbalanceVoltage', 'Aptiktas įtampos disbalansas', 5, NULL, 658, 1, NULL),
	(10896, 'TemperatureHigh', 'Aptiktas temperatūros viršijimas', 5, NULL, 659, 1, NULL),
	(10897, 'TemperatureLow', 'Aptiktas temperatūros sumažėjimas', 5, NULL, 660, 1, NULL),
	(10898, 'HighActivePower', 'Aptiktas aktyvios galios viršijimas', 5, NULL, 661, 1, NULL),
	(10899, 'HighActivePowerL1', 'Fazėje A aptiktas aktyvios galios viršijimas', 5, NULL, 662, 1, NULL),
	(10900, 'HighActivePowerL2', 'Fazėje B aptiktas aktyvios galios viršijimas', 5, NULL, 663, 1, NULL),
	(10901, 'HighActivePowerL3', 'Fazėje C aptiktas aktyvios galios viršijimas', 5, NULL, 664, 1, NULL),
	(10902, 'HighReactivePower', 'Aptiktas reaktyvios galios viršijimas', 5, NULL, 665, 1, NULL),
	(10903, 'HighReactivePowerL1', 'Fazėje A aptiktas reaktyvios galios viršijimas', 5, NULL, 666, 1, NULL),
	(10904, 'HighReactivePowerL2', 'Fazėje B aptiktas reaktyvios galios viršijimas', 5, NULL, 667, 1, NULL),
	(10905, 'HighReactivePowerL3', 'Fazėje C aptiktas aktyreaktyviosvios galios viršijimas', 5, NULL, 668, 1, NULL),
	(10906, 'PowerFactorImpDrop', 'Aptiktas galios koeficiento (imp) sumažėjimas', 5, NULL, 669, 1, NULL),
	(10907, 'PowerFactorImpDropL1', 'Fazėje A aptiktas galios koeficiento (imp) sumažėjimas', 5, NULL, 670, 1, NULL),
	(10908, 'PowerFactorImpDropL2', 'Fazėje B aptiktas galios koeficiento (imp) sumažėjimas', 5, NULL, 671, 1, NULL),
	(10909, 'PowerFactorImpDropL3', 'Fazėje C aptiktas galios koeficiento (imp) sumažėjimas', 5, NULL, 672, 1, NULL),
	(10910, 'STSModeActive', 'STS režimas įjungtas', 8, NULL, 673, 1, NULL),
	(10911, 'UangleABHigh', 'Aptiktas AB kampo reikšmės viršijimas', 5, NULL, 674, 1, NULL),
	(10912, 'UangleABLow', 'Aptiktas AB kampo reikšmės sumažejimas', 5, NULL, 675, 1, NULL),
	(10913, 'UangleACHigh', 'Aptiktas AC kampo reikšmės viršijimas', 5, NULL, 676, 1, NULL),
	(10914, 'UangleACLow', 'Aptiktas AC kampo reikšmės sumažejimas', 5, NULL, 677, 1, NULL),
	(10915, 'PowerFactorExpDrop', 'Aptiktas galios koeficiento (exp) sumažėjimas', 5, NULL, 678, 1, NULL),
	(10916, 'PowerFactorExpDropL1', 'Fazėje A aptiktas galios koeficiento (exp) sumažėjimas', 5, NULL, 679, 1, NULL),
	(10917, 'PowerFactorExpDropL2', 'Fazėje B aptiktas galios koeficiento (exp) sumažėjimas', 5, NULL, 680, 1, NULL),
	(10918, 'PowerFactorExpDropL3', 'Fazėje C aptiktas galios koeficiento (exp) sumažėjimas', 5, NULL, 681, 1, NULL),
	(10919, 'LVModemError', 'LV modemas nerastas', 8, NULL, 682, 1, NULL),
	(10920, 'LVNoConnection', 'LV ryšys nerastas', 8, NULL, 683, 1, NULL),
	(10921, 'GPRSModemError', 'GPRS modemas nerastas', 8, NULL, 684, 1, NULL),
	(10922, 'GPRSNoConnection', 'GPRS ryšys nerastas', 8, NULL, 685, 1, NULL),
	(10923, 'ModeLoaderWait', 'Režimas "įkrovimas-laukimas"', 8, NULL, 416, 1, NULL),
	(10924, 'ModeLoaderRenewal', 'Režimas "įkrovimas-atnaujinimas"', 8, NULL, 416, 1, NULL),
	(10925, 'ModeDiagnostics', 'Režimas "MKS-diagnostika"', 8, NULL, 416, 1, NULL),
	(10926, 'ModeCallSound', 'Režimas "iškvietimas-balsas"', 8, NULL, 416, 1, NULL),
	(10927, 'ModeCallData', 'Režimas "iškvietimas-duomenys"', 8, NULL, 416, 1, NULL),
	(10928, 'ModeRadioConnect', 'Režimas "radijo ryšys"', 8, NULL, 416, 1, NULL),
	(10929, 'ModeGSMConnect', 'Režimas "GSM-jungimas"', 8, NULL, 416, 1, NULL),
	(10930, 'ModeGPRSConnect', 'Režimas "GPRS-jungimas"', 8, NULL, 416, 1, NULL),
	(10931, 'ChangeCalculatingDay', 'Atsiskaitymo diena pasikeitė', 8, NULL, 416, 1, NULL),
	(10932, 'ChangeRF2', 'Pasikeitė RF2', 8, NULL, 416, 1, NULL),
	(10933, 'ChangePLC', 'Pasikeitė PLC', 8, NULL, 416, 1, NULL),
	(10934, 'Voltage12V_Norma', '12 V įtampa', 5, NULL, 638, 1, NULL),
	(10935, 'VoltageDepression1', 'Įtampos dingimo viršutinė riba fazėje A', 5, NULL, 639, 1, NULL),
	(10936, 'VoltageDepression2', 'Įtampos dingimo viršutinė riba fazėje B', 5, NULL, 640, 1, NULL),
	(10937, 'VoltageDepression3', 'Įtampos dingimo viršutinė riba fazėje C', 5, NULL, 641, 1, NULL),
	(10938, 'MoreLimit_Tg1', 'tg(fi) viršutinė riba fazėje ?', 5, NULL, 642, 1, NULL),
	(10939, 'MoreLimit_Tg2', 'tg(fi) viršutinė riba fazėje B', 5, NULL, 643, 1, NULL),
	(10940, 'MoreLimit_Tg3', 'tg(fi) viršutinė riba fazėje C', 5, NULL, 644, 1, NULL),
	(10941, 'CTRatioCumulative', 'CT santykis', 8, NULL, 416, 1, NULL),
	(10942, 'BillingCumulative', 'Apskaita', 8, NULL, 416, 1, NULL),
	(10943, 'TransientResetCumulative', 'Laikinas perkrovimas', 3, NULL, 416, 1, NULL),
	(10944, 'InternalBatteryCumulative', 'Vidinis maitinimo elementas', 8, NULL, 416, 1, NULL),
	(10945, 'ExternalBatteryCumulative', 'Išorinis maitinimo elementas', 8, NULL, 416, 1, NULL),
	(10946, 'DDM5_Status', 'Nuotolinio galios daviklio 5 statusas', 3, NULL, 650, 1, NULL),
	(10947, 'DDM_A_Status', 'Nuotolinio galios daviklio statusas fazėje A', 2, NULL, 651, 1, NULL),
	(10948, 'DDM_B_Status', 'Nuotolinio galios daviklio statusas fazėje B', 2, NULL, 651, 1, NULL),
	(10949, 'DDM_C_Status', 'Nuotolinio galios daviklio statusas fazėje C', 2, NULL, 651, 1, NULL),
	(10950, 'OpenDirectAccess', 'Tiesioginės prieigos teikimas', 7, NULL, 654, 1, NULL),
	(10951, 'Relay_3', 'Relės nr.3 jungimas', 8, NULL, 653, 1, NULL),
	(10952, 'RelaySettingChange', 'Relės valdymo parametrų keitimas', 7, NULL, NULL, 1, NULL),
	(10953, 'Failure_IC2', 'Klaida IC4', 9, NULL, NULL, 1, NULL),
	(10954, 'ClearEEPROM', 'Pilnas valymas EEPROM', 8, NULL, NULL, 1, NULL),
	(10955, 'ClearTariffs', 'Tarifų saugyklos anuliavimas', 8, NULL, NULL, 1, NULL),
	(10956, 'Relay1_permission', 'Apkrovos valdymo relės įjungimo leidimas', 7, NULL, NULL, 1, NULL),
	(10957, 'MoreLimitEnergyTariff', 'Energijos pagal tarifus ribos viršijimas', 5, NULL, NULL, 1, NULL),
	(10958, 'MoreLimitEnergySum', 'Suminės energijos ribos viršijimas', 5, NULL, NULL, 1, NULL),
	(10959, 'Synchronization', 'Sinchronizacija įvykdyta', 8, NULL, NULL, 1, NULL),
	(10960, 'RequestSynchronization', 'Laiko sinchronizacijos užklausa', 8, NULL, NULL, 1, NULL),
	(10961, 'SumEnergyLimitChange', 'Suminės energijos ribos pakeitimas', 5, NULL, NULL, 1, NULL),
	(10962, 'FixData', 'Tvirtinimo duomenų transliacinį komanda', 8, NULL, NULL, 1, NULL),
	(10963, 'CurrentTariffChange', 'Dabartinio tarifo pakeitimas', 7, NULL, NULL, 1, NULL),
	(10964, 'AbonentNumbChange', 'Abonentinio numerio pakeitimas', 7, NULL, NULL, 1, NULL),
	(10965, 'Lighting', 'Pašviesinimo buvimo/nebuvimo konfiguravimas', 7, NULL, NULL, 1, NULL),
	(10966, 'AdjustKfChange', 'Laiko korekcijos koeficiento pakeitimas', 7, NULL, NULL, 1, NULL),
	(10967, 'KodeWrite', 'Kodo įrašymas, kuris apibūdina skaitiklio veikla', 7, NULL, NULL, 1, NULL),
	(10968, 'DisplayTimeChange', 'Laiko indikacijos pakeitimas', 7, NULL, NULL, 1, NULL),
	(10969, 'TariffProgramOn', 'Tarifų programos tarifikavimo įjungimas', 7, NULL, NULL, 1, NULL),
	(10970, 'ExternalTariffOn', 'Išorinio tarifikavimo įjungimas', 7, NULL, NULL, 1, NULL),
	(10971, 'StateTarffsOn', 'Savaitgalių tarifikavimo įjungimas', 7, NULL, 691, 1, NULL),
	(10972, 'StateDstOn', 'Automatinio vasaros/žiemos laiko pervedimo įjungimas', 7, NULL, 692, 1, NULL),
	(10973, 'StateRelayEnergyOn', 'Relės suveikimo įjungimas viršijant energijos ribą', 5, NULL, 693, 1, NULL),
	(10974, 'StateRelayPowerOn', 'Relės suveikimo įjungimas viršijant galios ribą', 5, NULL, 694, 1, NULL),
	(10975, 'StateRelaySumEnergyOn', 'Relės suveikimo įjungimas viršijant suminės energijos ribą', 5, NULL, 695, 1, NULL),
	(10976, 'StateMeterBlockingOn', 'Sąsajos užblokavimo įjungimas įvedant 3 neteisingus slaptažodžius', 8, NULL, 696, 1, NULL),
	(10977, 'OptionalInterfaceChange', 'Papildomos sąsajos parametrų keitimas', 7, NULL, NULL, 1, NULL),
	(10978, 'RelayParamsChange', 'Signalizacijos relės ir apkrovos valdymo relės parametrų keitimas', 7, NULL, NULL, 1, NULL),
	(10979, 'PowerModeChange', 'Apkrovos įšjungimo/išjungimo režimo parametrų keitimas', 7, NULL, NULL, 1, NULL),
	(10980, 'KF_I_Change', 'Srovės koeficiento pakeitimas', 7, NULL, NULL, 1, NULL),
	(10981, 'BatteryRes', 'Maitinimo elemento dabartinė būsena procentais', 8, NULL, NULL, 3, NULL),
	(10982, 'LoCutoff_Qn_1', 'Suvartojimas yra mažesnis už atkirtą 1-me vamzdyne', 5, NULL, NULL, 1, NULL),
	(10983, 'LoCutoff_Qn_2', 'Suvartojimas yra mažesnis už atkirtą 2-me vamzdyne', 5, NULL, NULL, 1, NULL),
	(10984, 'LoCutoff_Qn_3', 'Suvartojimas yra mažesnis už atkirtą 3-me vamzdyne', 5, NULL, NULL, 1, NULL),
	(10985, 'LoCutoff_Qn_4', 'Suvartojimas yra mažesnis už atkirtą 4-me vamzdyne', 5, NULL, NULL, 1, NULL),
	(10986, 'TransformerConsumptionFailure_1', 'Klaida tūrio impulso linijoje 1-me vamzdyne (suvartojimo keitiklio gedimas)', 9, NULL, NULL, 1, NULL),
	(10987, 'TransformerConsumptionFailure_2', 'Klaida tūrio impulso linijoje 2-me vamzdyne (suvartojimo keitiklio gedimas)', 9, NULL, NULL, 1, NULL),
	(10988, 'TransformerConsumptionFailure_3', 'Klaida tūrio impulso linijoje 3-me vamzdyne (suvartojimo keitiklio gedimas)', 9, NULL, NULL, 1, NULL),
	(10989, 'TransformerConsumptionFailure_4', 'Klaida tūrio impulso linijoje 4-me vamzdyne (suvartojimo keitiklio gedimas)', 9, NULL, NULL, 1, NULL),
	(10990, 'Temperature_SensorPowerFailure_1', 'Temperatūros jutiklio klaida 1-me vamzdyne', 9, NULL, NULL, 1, NULL),
	(10991, 'Temperature_SensorPowerFailure_2', 'Temperatūros jutiklio klaida 2-me vamzdyne', 9, NULL, NULL, 1, NULL),
	(10992, 'Temperature_SensorPowerFailure_3', 'Temperatūros jutiklio klaida 3-me vamzdyne', 9, NULL, NULL, 1, NULL),
	(10993, 'Temperature_SensorPowerFailure_4', 'Temperatūros jutiklio klaida 4-me vamzdyne', 9, NULL, NULL, 1, NULL),
	(10994, 'Pressure_SensorPowerFailure_1', 'Slėgio jutiklio klaida 1-me vamzdyne', 9, NULL, NULL, 1, NULL),
	(10995, 'Pressure_SensorPowerFailure_2', 'Slėgio jutiklio klaida 2-me vamzdyne', 9, NULL, NULL, 1, NULL),
	(10996, 'Pressure_SensorPowerFailure_3', 'Slėgio jutiklio klaida 3-me vamzdyne', 9, NULL, NULL, 1, NULL),
	(10997, 'Pressure_SensorPowerFailure_4', 'Slėgio jutiklio klaida 4-me vamzdyne', 9, NULL, NULL, 1, NULL),
	(10998, 'SS_G2_gt_KprG1', 'Avarinė situacija: G2> Kpr*G1', 9, NULL, NULL, 1, NULL),
	(10999, 'SS_t1_minus_t2_lt_Delta_trc', 'Avarinė situacija: t1-t2 <delta tts', 9, NULL, NULL, 1, NULL),
	(11000, 'SS_G1_lt_G2_lt_KprG1', 'Avarinė situacija: G1 <G2 <Kpr*G1', 9, NULL, NULL, 1, NULL),
	(11001, 'SS_G4_gt_KprG3', 'Avarinė situacija: G4> Kpr*G3', 9, NULL, NULL, 1, NULL),
	(11002, 'SS_t3_minus_t4_lt_Delta_trc', 'Avarinė situacija: t3-t4 <delta tts', 9, NULL, NULL, 1, NULL),
	(11003, 'SS_G3_lt_G3_lt_KprG3', 'Avarinė situacija: G3 <G4 <Kpr*G3', 9, NULL, NULL, 1, NULL),
	(11004, 'Failure_FRAM', 'FRAM klaida', 9, NULL, NULL, 1, NULL),
	(11005, 'Failure_FLASH', 'FLASH klaida', 9, NULL, NULL, 1, NULL),
	(11006, 'Failure_DB_Service', 'DB serviso klaida', 9, NULL, NULL, 1, NULL),
	(11007, 'Failure_DB_Check', 'DB patikrinimo klaida', 9, NULL, NULL, 1, NULL),
	(11008, 'Failure_ADC1', 'ADC1 klaida', 9, NULL, NULL, 1, NULL),
	(11009, 'Failure_ADC2', 'ADC2 klaida', 9, NULL, NULL, 1, NULL),
	(11010, 'Failure_SemaphoreEvents', 'Įvykių semaforo klaida', 9, NULL, NULL, 1, NULL),
	(11011, 'Failure_ClockCopy', 'Laikrodžio kopijos klaida', 9, NULL, NULL, 1, NULL),
	(11012, 'NoTemporaryEvent', 'Nėra laikino įvykio', 9, NULL, NULL, 1, NULL),
	(11013, 'SetupMode', 'Režimas "konfigūravimas"', 8, NULL, NULL, 1, NULL),
	(11014, 'TemperatureHigh_1', '1 vamzdyno temperatūros maksimumas', 5, NULL, 725, 1, NULL),
	(11015, 'TemperatureHigh_2', '2 vamzdyno temperatūros maksimumas', 5, NULL, 726, 1, NULL),
	(11016, 'TemperatureHigh_3', '3 vamzdyno temperatūros maksimumas', 5, NULL, 727, 1, NULL),
	(11017, 'TemperatureHigh_4', '4 vamzdyno temperatūros maksimumas', 5, NULL, 728, 1, NULL),
	(11018, 'TemperatureLow_1', '1 vamzdyno temperatūros minimali riba', 5, NULL, 729, 1, NULL),
	(11019, 'TemperatureLow_2', '2 vamzdyno temperatūros minimali riba', 5, NULL, 730, 1, NULL),
	(11020, 'TemperatureLow_3', '3 vamzdyno temperatūros minimali riba', 5, NULL, 731, 1, NULL),
	(11021, 'TemperatureLow_4', '4 vamzdyno temperatūros minimali riba', 5, NULL, 732, 1, NULL),
	(11022, 'HiCutoff_Qn_1', '1 vamzdyno sunaudojimas', 5, NULL, 733, 1, NULL),
	(11023, 'HiCutoff_Qn_2', '2 vamzdyno sunaudojimas', 5, NULL, 734, 1, NULL),
	(11024, 'HiCutoff_Qn_3', '3 vamzdyno sunaudojimas', 5, NULL, 735, 1, NULL),
	(11025, 'HiCutoff_Qn_4', '4 vamzdyno sunaudojimas', 5, NULL, 736, 1, NULL),
	(11026, 'ChannelHigh', 'Kanalo reikšmės maksimumas', 5, NULL, 737, 1, NULL),
	(11027, 'ChannelLow', 'Kanalo reikšmės minimali riba', 5, NULL, 738, 1, NULL),
	(11028, 'refusal_Change', 'Atmetimų  keitimas', 7, NULL, NULL, 1, NULL),
	(11029, 'Param_WriteChannel', 'Paprasto parametro įrašymas per kanalą', 7, NULL, NULL, 1, NULL),
	(11030, 'Param_correction', 'Paprasto parametro koregavimas per meniu', 7, NULL, NULL, 1, NULL),
	(11031, 'Param_Clear', 'Parametro valymas ', 7, NULL, NULL, 1, NULL),
	(11032, 'Param_FixCanBus', 'Indeksinio parametro CAN BUS fiksavimas', 7, NULL, NULL, 1, NULL),
	(11033, 'IndexParam_Write', 'Indeksinio parametro įrašymas', 7, NULL, NULL, 1, NULL),
	(11034, 'unknown_Param', 'Užduoties kreipimas į nežinomą parametrą', 7, NULL, NULL, 1, NULL),
	(11035, 'FoneTaskWrite', 'Foninės užduoties įrašymo į PNSĮ bandymas', 7, NULL, NULL, 1, NULL),
	(11036, 't4_gt_t4Max', 'Avarinė situacija: t4 > t4max', 5, NULL, 745, 1, NULL),
	(11037, 't4_lt_t4Min', 'Avarinė situacija: t4 < t4min', 5, NULL, 746, 1, NULL),
	(11038, 'ModeFundamental', 'Režimas «Pagrindinis (Žiema)»', 7, NULL, NULL, 1, NULL),
	(11039, 'ModeNoStream', 'Režimas «Nėra srovės»', 7, NULL, NULL, 1, NULL),
	(11040, 'Gv2_gt_1_04XGv2', 'Avarinė situacija:Gv2 > 1.04*Gv2', 5, NULL, 747, 1, NULL),
	(11041, 'tx_gt_txMax', 'Avarinė situacija: tx > tx max', 5, NULL, 748, 1, NULL),
	(11042, 'tx_lt_txMin', 'Avarinė situacija: tx < tx max', 5, NULL, 749, 1, NULL),
	(11043, 't2_gt_t2Max', 'Avarinė situacija: t2 > t2max', 5, NULL, 750, 1, NULL),
	(11044, 't2_lt_t2Min', 'Avarinė situacija: t2 < t2min', 5, NULL, 751, 1, NULL),
	(11045, 't1_gt_t1Max', 'Avarinė situacija: t1 > t1max', 5, NULL, 752, 1, NULL),
	(11046, 't1_lt_t1Min', 'Avarinė situacija: t1 < t1min', 5, NULL, 753, 1, NULL),
	(11047, 't1_Minus_t2_gt_Delta_tmax', 'Avarinė situacija: t1 - t2 > delta_tmax', 5, NULL, 754, 1, NULL),
	(11048, 'W_gt_0', 'Avarinė situacija: W < 0', 5, NULL, 755, 1, NULL),
	(11049, 'P1_gt_P1Max', 'Avarinė situacija: P1 > P1max', 5, NULL, 756, 1, NULL),
	(11050, 'P1_lt_P1Min', 'Avarinė situacija: P1 < P1min', 5, NULL, 757, 1, NULL),
	(11051, 'P2_gt_P2Max', 'Avarinė situacija: P2 > P2max', 5, NULL, 758, 1, NULL),
	(11052, 'P2_lt_P2Min', 'Avarinė situacija: P2 < P2min', 5, NULL, 759, 1, NULL),
	(11053, 'ErrorsCnt_gt_Max', 'Klaidų kiekis per parą > maksimumą', 5, NULL, 760, 1, NULL),
	(11054, 'LinkError_PPC', 'Apsikeitimo su PPC klaida', 9, NULL, 761, 1, NULL),
	(11055, 'PPC_Failure', 'PPC termometrų gedimas grandyje', 9, NULL, 762, 1, NULL),
	(11056, 'KM_5_Failure', 'KM-5 termometrų gedimas grandyje', 9, NULL, 763, 1, NULL),
	(11057, 'Flag_Empty_KM_5', 'KM-5 tuščio vamzdžio daviklio galutinis požymis', 9, NULL, 764, 1, NULL),
	(11058, 'Flag_Empty_PPC', 'PPC tuščio vamzdžio daviklio galutinis požymis', 9, NULL, 765, 1, NULL),
	(11059, 'Flag_Nulling_G1', 'Numetimo požymis G1', 7, NULL, NULL, 1, NULL),
	(11060, 'Flag_Nulling_G2', 'Numetimo požymis G2', 7, NULL, NULL, 1, NULL),
	(11061, 'Flag_Reverse_G1', 'Reverso požymis G1', 7, NULL, NULL, 1, NULL),
	(11062, 'Flag_Reverse_G2', 'Reverso požymis G2', 7, NULL, NULL, 1, NULL),
	(11063, 'InternalWarning', 'Vidinis įspėjimas', 9, NULL, 767, 1, NULL),
	(11064, 'ConnectErrorCount', 'Nepavykusių sujungimų su skaitikliu ne iš pirmo karto skaičius', 9, NULL, NULL, 3, NULL),
	(11065, 'CommunicationError', 'Ryšio seanso klaidos kodas', 9, NULL, NULL, 1, NULL),
	(11066, 'CmosTimeChanged', 'CMOS laiko keitimas', 12, NULL, NULL, 1, NULL),
	(11067, 'UpsEvent', 'UPS sugeneruotas įvykis', 6, NULL, NULL, 1, NULL),
	(11068, 'ConfigWarning', 'Konfigūravimo įspėjimas', 7, NULL, NULL, 1, NULL),
	(11069, 'ArchiveSizeExceeded', 'Viršitas leistinas archyvų dydis', 5, NULL, NULL, 1, NULL),
	(11070, 'BillingParamConfig', 'Komercinės konfigūracijos keitimas', 7, NULL, NULL, 1, NULL),
	(11071, 'TechParamConfig', 'Techninės konfigūracijos keitimas', 7, NULL, NULL, 1, NULL),
	(11072, 'ArchiveWriteError', 'Archyvo įrašo klaida', 9, NULL, NULL, 1, NULL),
	(11073, 'GPSNoConnection', 'GPS sujungimas', 9, NULL, 768, 1, NULL),
	(11074, 'MoreLimitPowerCount', 'Maksimalios (sutartinės) galios peržengimų skaičius', 5, NULL, NULL, 3, NULL),
	(11075, 'ReverseFlow_Count', 'Energijos reversų skaičius', 11, NULL, NULL, 3, NULL),
	(11076, 'PhaseFailure_Count', 'Įtampos pertraukų fazėse skaičius', 2, NULL, NULL, 3, NULL),
	(11077, 'SettingChange_Count', 'Programavimo skaitmatis', 7, NULL, NULL, 3, NULL),
	(11078, 'CTRatioCumulative_Count', 'Transformacijos koeficiento programavimo skaitmatis', 7, NULL, NULL, 3, NULL),
	(11079, 'Fatal_Error_Count', 'Skaitiklio klaidų skaitmatis', 9, NULL, NULL, 3, NULL),
	(11080, 'CableCoverOpen_Count', 'Skaitiklio gnybtų atidarymų skaičius ', 1, NULL, NULL, 3, NULL),
	(11081, 'InternalBatteryCumulative_Count', 'Vidinės baterijos įvykių skaičius', 6, NULL, NULL, 3, NULL),
	(11082, 'ExternalBatteryCumulative_Count', 'Išorinės baterijos įvykių skaičius', 6, NULL, NULL, 3, NULL),
	(11083, 'PowerDown_Len', 'Maitinimo atjungimų suminė trukmė', 6, NULL, NULL, 4, NULL),
	(11084, 'ModemPowerOff', 'Nėra modemo maitinimo', 6, NULL, NULL, 1, NULL),
	(11085, 'ManufacturerConfig', 'Gamyklinis derinimas', 7, NULL, NULL, 1, NULL),
	(11086, 'ModePowerEconomy', 'Energijos taupymo režimas', 7, NULL, NULL, 1, NULL),
	(11087, 'ActiveAntiCreep', 'Savaeigė aktyvioji energija', 11, NULL, NULL, 1, NULL),
	(11088, 'ReactiveAntiCreep', 'Savaeigė reaktyvioji energija', 11, NULL, NULL, 1, NULL),
	(11089, 'UnregisteredMeter', 'Naujo skaitiklio registracija', 3, 0, 775, 1, NULL),
	(11090, 'RestartFromNMI', 'Perkrovimas per NMI', 3, NULL, NULL, 1, NULL),
	(11091, 'RestartFromNMIAndReset', 'Perkrovimas per NMI + RESET', 3, NULL, NULL, 1, NULL),
	(11092, 'RestartFromButton', 'Perkrovimas mygtuku', 3, NULL, NULL, 1, NULL),
	(11093, 'WarmRestartFromUser', 'Vartotojo inicijuotas "karštas" perkrovimas', 3, NULL, NULL, 1, NULL),
	(11094, 'FirstStart', 'Pirmas įjungimas arba "šaltas" perkrovimas', 3, NULL, NULL, 1, NULL),
	(11095, 'RestartFromSoftWatchdog', 'Apsauginis laikamatis. Programinis kontrolerio perkrovimas', 3, NULL, NULL, 1, NULL),
	(11096, 'RestartFromNetwork', 'Programinis perkrovimas nuo tinklo', 3, NULL, NULL, 1, NULL),
	(11097, 'RestartAfterClearDB', 'Perkrovimas po duomenų bazės išvalymo', 3, NULL, NULL, 1, NULL),
	(11098, 'TimeSet_SyncLimit', 'Laiko nustatymas dėl perdidelio nesutapimo', 12, NULL, NULL, 1, NULL),
	(11099, 'TimeSetByUser', 'Vartotojo inicijuotas laiko nustatymas', 12, NULL, NULL, 1, NULL),
	(11100, 'TimeSetByUser_Network', 'Vartotojo inicijuotas kontrolerio laiko nustatymas tinkle', 12, NULL, NULL, 1, NULL),
	(11101, 'CopyOfDSTRules', 'Sezonų perjungimų taisyklių kopijavimas iš pagrindinio kontrolerio', 7, NULL, NULL, 1, NULL),
	(11102, 'DSTRulesSetByUser', 'Vartotojo inicijuotas sezonų perjungimų taisyklių nustatymas', 7, NULL, NULL, 1, NULL),
	(11103, 'DSTRulesSetByUser_Network', 'Vartotojo inicijuotas kontrolerio sezonų perjungimų taisyklių nustatymas tinkle', 7, NULL, NULL, 1, NULL),
	(11104, 'CopyOfSyncPlan', 'Korekcijos plano kopijavimas iš pagrindinio kontrolerio', 7, NULL, NULL, 1, NULL),
	(11105, 'SyncPlanSetByUser', 'Vartotojo inicijuotas korekcijos plano nustatymas', 7, NULL, NULL, 1, NULL),
	(11106, 'SyncPlanSetByUser_Network', 'Vartotojo inicijuotas kontrolerio korekcijos plano nustatymas tinkle', 7, NULL, NULL, 1, NULL),
	(11107, 'SyncTimeFromRadio', 'Laiko sinchronizavimas per radijo kanalą', 12, NULL, NULL, 1, NULL),
	(11108, 'SyncTimeFromPTS', 'Laiko sinchronizavimas su TLP', 12, NULL, NULL, 1, NULL),
	(11109, 'PTSSyncEnabled', 'Įėjimas į TLP pavaldumo režimą', 7, NULL, NULL, 1, NULL),
	(11110, 'NetworkTimeMaster', 'Kontroleris yra "master" tinkle', 7, NULL, NULL, 1, NULL),
	(11111, 'WeekChange', 'Savaitė pasikeitė', 7, NULL, NULL, 1, NULL),
	(11112, 'DayChange', 'Diena pasikeitė', 7, NULL, NULL, 1, NULL),
	(11113, 'Magnetic_Field_EnergyUsed', 'Magnetinio lauko poveikio trukmės suskaičiuota energija', 7, NULL, NULL, 1, NULL),
	(11114, 'TimeCorrectionSumPerYear', 'Išnaudota laikrodžio korekcijos dalis', 7, NULL, NULL, 1, NULL),
	(11115, 'LimitExit_P', 'Slėgio limito viršijimas', 5, NULL, NULL, 1, NULL),
	(11116, 'LimitExit_T', 'Temperatūros limito viršijimas', 5, NULL, NULL, 1, NULL),
	(11117, 'MoreCutOff_Qn', 'Tūrio suvartojimo atkirtos viršijimas', 5, NULL, NULL, 1, NULL),
	(11118, 'dP_div_P_lt_025', 'dP/P santykis viršija 0,25 ', 5, NULL, NULL, 1, NULL),
	(11119, 'LimitExit_Rejnolds', 'Reinoldso skaičiaus limito viršijimas', 5, NULL, NULL, 1, NULL),
	(11120, 'InCorrectFazeMode', 'Nekorektiška šilumnešio fazinė būsena ', 9, NULL, NULL, 1, NULL),
	(11121, 'BadChannel_dP1', 'Slėgio slenksčio dP1 matavimo kanalo gedimas', 9, NULL, NULL, 1, NULL),
	(11122, 'BadChannel_dP2', 'Slėgio slenksčio dP2 matavimo kanalo gedimas', 9, NULL, NULL, 1, NULL),
	(11123, 'BadChannel_dP3', 'Slėgio slenksčio dP3 matavimo kanalo gedimas', 9, NULL, NULL, 1, NULL),
	(11124, 'BadChannel_P', 'Slėgio matavimo kanalo gedimas', 9, NULL, NULL, 1, NULL),
	(11125, 'BadChannel_T', 'Temperatūros matavimo kanalo gedimas', 9, NULL, NULL, 1, NULL),
	(11126, 'BadCalculationAccuracy', 'Dujų skaičiavimų tikslumas nepasiektas', 9, NULL, NULL, 1, NULL),
	(11127, 'ReduceVoltage1', 'Maitinimo kritimas L1 fazėje', 5, NULL, NULL, 1, NULL),
	(11128, 'ReduceVoltage2', 'Maitinimo kritimas L2 fazėje', 5, NULL, NULL, 1, NULL),
	(11129, 'ReduceVoltage3', 'Maitinimo kritimas L3 fazėje', 5, NULL, NULL, 1, NULL),
	(11130, 'ChangeValueModeSet', 'Kintamasis pakeistas režimu SET', 7, NULL, NULL, 1, NULL),
	(11131, 'Intervention_MCO', 'Poveikis- MCO', 1, NULL, NULL, 1, NULL),
	(11132, 'Intervention_TCO', 'Poveikis- TCO', 1, NULL, NULL, 1, NULL),
	(11133, 'AlarmRequest', 'Signalizacijos užklausa', 1, NULL, NULL, 1, NULL),
	(11134, 'SendAlarm', 'Signalizacijos nusiuntimas', 1, NULL, NULL, 1, NULL),
	(11135, 'AlarmError', 'Signalizacijos klaida', 1, NULL, NULL, 1, NULL),
	(11136, 'Violation', 'Pažeidimo', 9, NULL, 911, 1, NULL),
	(11137, 'TerminalCase_Open', 'Skaitiklio dangtelis ', 9, NULL, 909, 1, NULL),
	(11138, 'KeyChange', 'Pakeistas asmeninis raktas', 7, NULL, NULL, 1, NULL),
	(11139, 'LocalConnectionBegin', 'Lokalaus sujungimo', 8, NULL, 912, 1, NULL),
	(11140, 'RemoutConnectionBegin', 'Nuotolinio sujungimo', 8, NULL, 913, 1, NULL),
	(11141, 'CommunicationBegin', 'Sujungimo pradžia', 8, NULL, NULL, 1, NULL),
	(11142, 'CorruptedSMS', 'SMS neteisingas', 9, NULL, NULL, 1, NULL),
	(11143, 'IncorrectCreditCode', 'Neteisingas kredito kodas', 9, NULL, NULL, 1, NULL),
	(11144, 'KeypadLocked', 'Klaviatūros blokiravimas', 9, NULL, NULL, 1, NULL),
	(11145, 'GSMNetworkFailure', 'GSM tinklo klaida', 9, NULL, NULL, 1, NULL),
	(11146, 'ProgrammingFailed', 'Programavimo klaida', 9, NULL, NULL, 1, NULL),
	(11147, 'Invalid_SMS_Source', 'Neteisingas SMS šaltinis', 9, NULL, NULL, 1, NULL),
	(11148, 'AllCodesEntered', 'Visi kodai įvesti', 11, NULL, NULL, 1, NULL),
	(11149, 'PurchaseCreditEntered', 'Reguliaraus pirkimo kodas įvestas', 11, NULL, NULL, 1, NULL),
	(11150, 'CustomerPurchaseRequest', 'Vartotojo pirkimo užklausa', 11, NULL, NULL, 1, NULL),
	(11151, 'MeterSnapshot', 'Skaitiklio rodmenys', 8, NULL, NULL, 1, NULL),
	(11152, 'EtechFull', 'Pilnas Etech', 11, NULL, NULL, 1, NULL),
	(11153, 'UnableSend_SMS', 'Nėra galimybės išsiųsti avarinio signalo per SMS', 9, NULL, NULL, 1, NULL),
	(11154, 'IntrusionReset', 'Atidarymų numetimas', 7, NULL, NULL, 1, NULL),
	(11155, 'COM_InsertedBad', 'COM modulis įstatytas', 11, NULL, 914, 1, NULL),
	(11156, 'IO_InsertedBad', 'IO modulis įstatytas', 11, NULL, 915, 1, NULL),
	(11157, 'COM_ModuleOut', 'COM modulio išėjimas', 11, NULL, NULL, 1, NULL),
	(11158, 'IO_ModuleOut', 'IO modulio įėjimas', 11, NULL, NULL, 1, NULL),
	(11159, 'UnbalancedByCurrent', 'Nebalanso pagal srovę ', 9, NULL, 910, 1, NULL),
	(11160, 'PowerFailure1', 'Energijos dingimas fazėje L1', 9, NULL, NULL, 1, NULL),
	(11161, 'PowerFailure2', 'Energijos dingimas fazėje L2', 9, NULL, NULL, 1, NULL),
	(11162, 'PowerFailure3', 'Energijos dingimas fazėje L3', 9, NULL, NULL, 1, NULL),
	(11163, 'ConnectionTimeout', 'Sujungimo nebuvimo delsa', 9, NULL, NULL, 1, NULL),
	(11164, 'PrepayTokenEnterOk', 'Išankstinio apmokėjimo simbolis įvestas', 11, NULL, 916, 1, NULL),
	(11165, 'PrepayCreditExpired', 'Išankstinis apmokėjimas', 11, NULL, 917, 1, NULL),
	(11166, 'Prepay_EM_CreditExpired', 'Išankstinis EM apmokėjimas', 11, NULL, 918, 1, NULL),
	(11167, 'RemoteReadyToConnect', 'Pasiruošimas nuotoliniam pasijungimui', 8, NULL, NULL, 1, NULL),
	(11168, 'FunctionDisconnect', 'Atsijungimo funkcija', 8, NULL, NULL, 1, NULL),
	(11169, 'UserConnect', 'Vartotojas', 8, NULL, 919, 1, NULL),
	(11170, 'AlarmOutputSet', 'Signalizacijos išėjimo nustatymas', 7, NULL, NULL, 1, NULL),
	(11171, 'DisconnectPowerLimit', 'Galios limito atsijungimo funkcija', 5, NULL, NULL, 1, NULL),
	(11172, 'DisconnectEnergyLimit', 'Energijos limito atsijungimo funkcija', 5, NULL, NULL, 1, NULL),
	(11173, 'DisconnectPrepayment', 'Atsijungimo pagal išankstinį apmokėjimą funkcija', 5, NULL, NULL, 1, NULL),
	(11187, 'RelayOffByTempLimit', 'Atjungimas viršijus leistiną temperatūrą', 13, NULL, NULL, 1, NULL),
	(11193, 'IncorrectInstallation', 'Neteisingas pajungimas', 9, NULL, NULL, 1, NULL),
	(11196, 'DataReadError', 'Paskutinio nepavykusio skaitiklio nuskaitymo laikas', 9, NULL, NULL, 1, NULL),
	(11197, 'ConcentrReadData', 'Koncentratorius yra neužbaigtoje skaitymo būsenoje', 9, NULL, NULL, 1, NULL),
	(11198, 'DataReadErrorCount', 'Klaidingų nuskaitymų kiekis', 9, NULL, NULL, 3, NULL),
	(11199, 'MoreNormalTreshold_U1', 'Įtampos nukrypimas ties normaliai leistinu slenksčiu fazėje L1', 5, NULL, 798, 1, NULL),
	(11200, 'MoreLimitTreshold_U1', 'Įtampos nukrypimas ties ribiniu leistinu slenksčiu fazėje L1', 5, NULL, 798, 1, NULL),
	(11201, 'MoreNormalTreshold_U2', 'Įtampos nukrypimas ties normaliai leistinu slenksčiu fazėje L2', 5, NULL, 798, 1, NULL),
	(11202, 'MoreLimitTreshold_U2', 'Įtampos nukrypimas ties ribiniu leistinu slenksčiu fazėje L2', 5, NULL, 798, 1, NULL),
	(11203, 'MoreNormalTreshold_U3', 'Įtampos nukrypimas ties normaliai leistinu slenksčiu fazėje L3', 5, NULL, 798, 1, NULL),
	(11204, 'MoreLimitTreshold_U3', 'Įtampos nukrypimas ties ribiniu leistinu slenksčiu fazėje L3', 5, NULL, 798, 1, NULL),
	(11205, 'LoTreshold_I1', 'Srovės nukrypimas ties apatiniu slenksčiu fazėje L1', 5, NULL, 798, 1, NULL),
	(11206, 'HiTreshold_I1', 'Srovės nukrypimas ties viršutiniu slenksčiu fazėje L1', 5, NULL, 798, 1, NULL),
	(11207, 'LoTreshold_I2', 'Srovės nukrypimas ties apatiniu slenksčiu fazėje L2', 5, NULL, 798, 1, NULL),
	(11208, 'HiTreshold_I2', 'Srovės nukrypimas ties viršutiniu slenksčiu fazėje L2', 5, NULL, 798, 1, NULL),
	(11209, 'LoTreshold_I3', 'Srovės nukrypimas ties apatiniu slenksčiu fazėje L3', 5, NULL, 798, 1, NULL),
	(11210, 'HiTreshold_I4', 'Srovės nukrypimas ties viršutiniu slenksčiu fazėje L3', 5, NULL, 798, 1, NULL),
	(11211, 'LoTreshold_Pmom', 'Aktyvinės momentinės galios nukrypimas ties apatiniu slenksčiu', 5, NULL, 798, 1, NULL),
	(11212, 'HiTreshold_Pmom', 'Aktyvinės momentinės galios nukrypimas ties viršutiniu slenksčiu', 5, NULL, 798, 1, NULL),
	(11213, 'LoTreshold_Qmom', 'Reaktyvinės momentinės galios nukrypimas ties apatiniu slenksčiu', 5, NULL, 798, 1, NULL),
	(11214, 'HiTreshold_Qmom', 'Reaktyvinės momentinės galios nukrypimas ties viršutiniu slenksčiu', 5, NULL, 798, 1, NULL),
	(11215, 'LoTreshold_Hz', 'Dažnio nukrypimas ties apatiniu slenksčiu', 5, NULL, 798, 1, NULL),
	(11216, 'HiTreshold_Hz', 'Dažnio nukrypimas ties viršutiniu slenksčiu', 5, NULL, 798, 1, NULL),
	(11217, 'DemandOnHiLimitEnergy', 'Apkrovos valdymas viršijus energijos suvartojimo limitą', 5, NULL, 799, 1, NULL),
	(11218, 'DemandOnHiMaxPower', 'Apkrovos valdymas viršijus maksimalią galią', 5, NULL, 799, 1, NULL),
	(11219, 'DemandOnInterface', 'Apkrovos valdymas per interfeisinį kanalą', 3, NULL, 799, 1, NULL),
	(11220, 'ChangeSoftVersion', 'Skaitiklio programinės versijos pakeitimas', 7, NULL, NULL, 1, NULL),
	(11221, 'TUComConfChange', 'Nuotolinio valdymo komandos pasikeitimas', 7, NULL, NULL, 1, NULL),
	(11222, 'MoreTreshold_I0', 'Nulinės sekos srovės slenksčio peržengimas', 5, NULL, 798, 1, NULL),
	(11223, 'MoreTreshold_U0', 'Nulinės sekos įtampos slenksčio peržengimas', 5, NULL, 798, 1, NULL),
	(11224, 'MoreTreshold_Kf', 'Nulinės sekos nesimetrijos koeficiento slenksčio peržengimas', 5, NULL, 798, 1, NULL),
	(11225, 'MoreLimitValue_Hz', 'Ribinio leistino dažnio reikšmes nukrypimo', 5, NULL, 798, 1, NULL),
	(11226, 'MoreNormalValue_Hz', 'Normaliai leistino dažnio reikšmes nukrypimo', 5, NULL, 798, 1, NULL),
	(11227, 'MoreNormal_U1', 'Įtampos nukrypimas fazėje L1 ( virš normaliai leistino slenksčio )', 5, NULL, 798, 1, NULL),
	(11228, 'MoreLimit_U1', 'Įtampos nukrypimas fazėje L1 ( virš ribinio leistino slenksčio )', 5, NULL, 798, 1, NULL),
	(11229, 'MoreNormal_U2', 'Įtampos nukrypimas fazėje L2 ( virš normaliai leistino slenksčio )', 5, NULL, 798, 1, NULL),
	(11230, 'MoreLimit_U2', 'Įtampos nukrypimas fazėje L2 ( virš ribinio leistino slenksčio )', 5, NULL, 798, 1, NULL),
	(11231, 'MoreNormal_U3', 'Įtampos nukrypimas fazėje L3 ( virš normaliai leistino slenksčio )', 5, NULL, 798, 1, NULL),
	(11232, 'MoreLimit_U3', 'Įtampos nukrypimas fazėje L3 ( virš ribinio leistino slenksčio )', 5, NULL, 798, 1, NULL),
	(11233, 'MoreNormal_Ul', 'Tiesioginės sekos įtampos slenksčio nukrypimas ( virš normaliai leistino slenksčio )', 5, NULL, 798, 1, NULL),
	(11234, 'MoreLimit_Ul', 'Tiesioginės sekos įtampos slenksčio nukrypimas ( virš ribinio leistino slenksčio )', 5, NULL, 798, 1, NULL),
	(11235, 'Profile3Init', 'Galios profilio trečio masyvo inicializacija', 11, NULL, NULL, 1, NULL),
	(11236, 'Profile3_Max_Demand_Reset', '3-čio profilio galios maksimumų anuliavimas', 11, NULL, NULL, 1, NULL),
	(11237, 'ChangeLossParams', 'Nuostolių parametrų keitimo žurnalas', 11, NULL, NULL, 1, NULL),
	(11238, 'ChangePowerQuality', 'Elektos kokybės matuoklio parametrų keitimo žurnalas', 11, NULL, NULL, 1, NULL),
	(11239, 'ChangeRF1', 'Pakeistas RF1 režimas ', 7, NULL, NULL, 1, NULL),
	(11240, 'ChangeGPRS', 'Pakeistas GPRS tvarkaraštis', 7, NULL, NULL, 1, NULL),
	(11241, 'ChangeSMSList', 'Pakeistas SMS pranešimų sąrašas', 7, NULL, NULL, 1, NULL),
	(11242, 'AutoConfigStart', 'Auto konfigūracijos', 7, NULL, NULL, 1, NULL),
	(11243, 'AutoConfigFinish', 'Auto konfigūracija pasibaigė', 7, NULL, NULL, 1, NULL),
	(11244, 'ChangeGPRSServer', 'Pakeistas GPRS serverio režimas', 7, NULL, NULL, 1, NULL),
	(11245, 'U_090_220V', 'U<(0,9*220V)', 5, NULL, NULL, 1, NULL),
	(11246, '_090_220_U_095_220', '(0,9*220V)<U<(0,95*220V)', 5, NULL, NULL, 1, NULL),
	(11247, '_105_220_U_110_220', '(1,05*220V)<U<(1,1*220V)', 5, NULL, NULL, 1, NULL),
	(11248, '_110_220_U', '(1,1*220V)<U', 5, NULL, NULL, 1, NULL),
	(11249, 'Hz_090_50', 'F<(0,9*50Hz)', 5, NULL, NULL, 1, NULL),
	(11250, '_090_50_Hz_095_50', '(0,9*50Hz)<F<(0,95*50Hz)', 5, NULL, NULL, 1, NULL),
	(11251, '_105_50_Hz_110_50', '(1,05*50Hz)<F<(1,1*50Hz)', 5, NULL, NULL, 1, NULL),
	(11252, '_110_50_Hz', '(1,1*50Hz)<F', 5, NULL, NULL, 1, NULL),
	(11253, 'PowerLimitKfChange', 'Pakeistas galios limito koeficientas ', 7, NULL, NULL, 1, NULL),
	(11254, 'IndikationModeChange', 'Pakeistas indikacijos režimas', 7, NULL, NULL, 1, NULL),
	(11255, 'TgTresholdChange', 'Pakeistas tg slenkstis', 7, NULL, NULL, 1, NULL),
	(11256, 'LossResistanceChange', 'Pakeista linijos nuostolių varža', 7, NULL, NULL, 1, NULL),
	(11257, 'IntPeriodPenaltyChange', 'Pakeistas perėjimo į baudos tarifą  galios vidurkinimo periodas', 7, NULL, NULL, 1, NULL),
	(11258, 'AddrRFPLCChange', 'Pakeistas tinklo RFPLC adresas ir grupė', 7, NULL, NULL, 1, NULL),
	(11259, 'TranslatorRFPLCChange', 'Pakeista RFPLC tinklo retransliacijos lentelė', 7, NULL, NULL, 1, NULL),
	(11260, 'FlagsReset', 'Požymių numetimas', 7, NULL, NULL, 1, NULL),
	(11261, 'TresholdChange', 'Pakeisti  įtampų kritimų/viršįtampių slenksčiai', 7, NULL, NULL, 1, NULL),
	(11262, 'IncorrectEnergyParamsChange', 'Pakeisti nekokybiškos energijos perskaičiavimo parametrai', 7, NULL, NULL, 1, NULL),
	(11263, 'RadioChannelChange', 'Pakeista radijo kanalo galia ir Nr ', 7, NULL, NULL, 1, NULL),
	(11264, 'CalibrationElement1', 'Daviklio Nr 1 kalibravimas', 7, NULL, NULL, 1, NULL),
	(11265, 'CalibrationElement2', 'Daviklio Nr 2 kalibravimas', 7, NULL, NULL, 1, NULL),
	(11266, 'CalibrationElement3', 'Daviklio Nr 3 kalibravimas', 7, NULL, NULL, 1, NULL),
	(11267, 'SetupElement1', 'Daviklio Nr 1 pradinis nustatymas', 7, NULL, NULL, 1, NULL),
	(11268, 'SetupElement2', 'Daviklio Nr 2 pradinis nustatymas', 7, NULL, NULL, 1, NULL),
	(11269, 'SetupElement3', 'Daviklio Nr 3 pradinis nustatymas', 7, NULL, NULL, 1, NULL),
	(11270, 'PLCStatusByteOfMeter', 'Skaitiklio būsenos kontrolinis baitas', 11, NULL, NULL, 1, NULL),
	(11271, 'PLCStatusByteOfNetwork', 'Tinklo būsenos kontrolinis baitas', 11, NULL, NULL, 1, NULL),
	(11272, 'PLCErrorCodeControlByte', 'Klaidos kontrolinis baitas', 11, NULL, NULL, 1, NULL),
	(11273, 'PLCWorkInTime', 'Visas dirbtas laikas', 11, NULL, NULL, 4, 29),
	(11274, 'FailureI2C', 'I2C sutrikimas', 9, NULL, 416, 1, NULL),
	(11275, 'ManufacturerConfigUnblock', 'Atblokuota gamyklinių nustatymų apsauga', 9, NULL, 416, 1, NULL),
	(11276, 'LinkBlockedByPassword', 'Interfeisas blokuotas, slaptažodis buvo įvestas neteisingai ', 9, NULL, 416, 1, NULL),
	(11277, 'DemandOffByContract', 'Apkrovos atjungimas viršijus vartojimą pagal sutartį', 5, NULL, 416, 1, NULL),
	(11278, 'DemandOffByFailure', 'Apkrovos atjungimas avarinio režimo metu', 9, NULL, 416, 1, NULL),
	(11279, 'DivisionKfChange', 'Dalinimo koeficiento pakeitimas', 7, NULL, 416, 1, NULL),
	(11280, 'CaliberUKfChange', 'Tinklo įtampos kalibracinių koeficientų pakeitimas', 7, NULL, 416, 1, NULL),
	(11281, 'TimeDurationChange', 'Laikinių veikimo intervalų pakeitimas', 7, NULL, 416, 1, NULL),
	(11282, 'FieldDescriptionChange', 'Aprašymo laukų pakeitimas', 7, NULL, 416, 1, NULL),
	(11283, 'SetNewTariffsDate', 'Naujo tvarkaraščio įvedimo datos nustatymas', 7, NULL, 416, 1, NULL),
	(11284, 'SetNewTariffs', 'Įvestas naujas tarifų tvarkaraštis', 7, NULL, 416, 1, NULL),
	(11285, 'ResetByDataStorageFailure', 'Skaitiklio perkrovimas sutrikus kaupikliams', 9, NULL, 416, 1, NULL),
	(11286, 'DataStorageResetByEPROM', 'Energijos kaupiklių perkrovimas sutrikus EPROM', 9, NULL, 416, 1, NULL),
	(11287, 'DataStorageResetByRAM', 'Energijos kaupiklių perkrovimas sutrikus RAM', 9, NULL, 416, 1, NULL),
	(11288, 'ConfigResetByAddrFailure', 'Perkrovimas konfigūracijos sutrikus prietaiso adresui', 9, NULL, 416, 1, NULL),
	(11289, 'RestoringEnergyFromMainDataStorageErr', 'Įvyko klaida atstatant energiją iš pagrindinio kaupiklio', 9, NULL, 416, 1, NULL),
	(11290, 'RestoringEnergyFromOtherDataStorageErr', 'Įvyko klaida atstatant energiją iš papildomo kaupiklio', 9, NULL, 416, 1, NULL),
	(11291, 'TrKfUErr', 'Įtampos transformacijos koeficiento klaida', 9, NULL, 416, 1, NULL),
	(11292, 'TrKfIErr', 'Srovės transformacijos koeficiento klaida', 9, NULL, 416, 1, NULL),
	(11293, 'Relay_4', 'Relės nr.4 jungimas', 8, 0, 935, 1, NULL),
	(11294, 'Relay_5', 'Relės nr.5 jungimas', 8, 0, 936, 1, NULL),
	(11295, 'RelayOffErr', 'Relės atjungimo klaida', 9, NULL, 416, 1, NULL),
	(11296, 'RelayOnErr', 'Relės įjungimo klaida', 9, NULL, 416, 1, NULL),
	(11297, 'DemandOnHiU', 'Apkrova viršijus įtampą', 8, 0, 937, 1, NULL),
	(11298, 'DemandOnHiPowerUsage', 'Apkrova viršijus vartojimą', 8, 0, 938, 1, NULL),
	(11299, 'DemandOnButtonAccepted', 'Duotas operatoriaus leidimas įjungti mygtuku apkrovą', 8, NULL, 416, 1, NULL),
	(11300, 'DemandOnButton', 'Apkrovos įjungimas mygtuku', 8, NULL, 416, 1, NULL),
	(11301, 'DemandOnOperator', 'Operatorius apkrovą', 8, NULL, 939, 1, NULL),
	(11302, 'DemandOnAutomatic', 'Apkrovos įjungimas automatiškai', 8, NULL, 416, 1, NULL),
	(11303, 'AveragingIntChange', 'Galios paros profilio vidurkinimo intervalų pakeitimas', 7, NULL, 416, 1, NULL),
	(11304, 'ClearMetersDataTable', 'Vandens/dujų skaitiklių visos beadresinės lentelės išvalymas', 14, NULL, 416, 1, NULL),
	(11305, 'FixAddress', 'Vandens/dujų skaitiklio adreso pririšimas', 7, NULL, 416, 1, NULL),
	(11306, 'SystemUnitOpen', 'Keičiamo modulio skyrius', 25, NULL, 940, 1, NULL),
	(11307, 'ResetSeal', 'Plombų būsenos numetimas', 25, NULL, 416, 1, NULL),
	(11308, 'HiTreshold1_U', 'Viršutinis įtampos slenkstis Nr.1', 26, NULL, 941, 1, NULL),
	(11309, 'HiTreshold2_U', 'Viršutinis įtampos slenkstis Nr.2', 26, NULL, 942, 1, NULL),
	(11310, 'VoltageFall_Treshold1', 'Apatinis įtampos slenkstis Nr.1', 26, NULL, 943, 1, NULL),
	(11311, 'VoltageFall_Treshold2', 'Apatinis įtampos slenkstis Nr.2', 26, NULL, 944, 1, NULL),
	(11312, 'ComeUpToHi_U', 'Pasiekta viršutinė įtampos reikšmė', 26, NULL, 416, 1, NULL),
	(11313, 'ComeUpToLo_U', 'Pasiekta apatinė įtampos reikšmė', 26, NULL, 416, 1, NULL),
	(11314, 'ComeUpToHi_Hz', 'Pasiekta viršutinė dažnio slenksčio reikšmė', 26, NULL, 416, 1, NULL),
	(11315, 'ComeUpToLo_Hz', 'Pasiekta apatinė dažnio slenksčio reikšmė', 26, NULL, 416, 1, NULL),
	(11316, 'CustomerBalanceAppending', 'Vartotojo balanso papildymas', 26, NULL, 416, 1, NULL),
	(11317, 'CustomerBalanceZero', 'Vartotojo balansas pasiekė nulį', 26, NULL, 416, 1, NULL),
	(11318, 'CustomerBalanceAttainingThreshold', 'Vartotojo balansas pasiekė kritinę reikšmę', 26, NULL, 416, 1, NULL),
	(11319, 'CustomerBalanceSetThreshold', 'Vartotojo balanso kritinė reikšmė', 26, NULL, 945, 1, NULL),
	(11320, 'CustomerBalanceKfChange', 'Vartotojo balanso svorinių reikšmių pakeitimas', 7, NULL, 416, 1, NULL),
	(11321, 'RelayControlFailure', 'Relės valdymo sutrikimas, einamoji būsena neatitinka išsaugotosios', 9, 0, 803, 1, NULL),
	(11322, 'ElectricityTheftDetected', 'Užregistruotas el. energijos grobstymas arba atvirkštinė energijos kryptis', 1, 0, 804, 1, NULL),
	(11323, 'CurrentTariffsChange', 'Veikiančios programos tarifinių tvarkaraščių pakeitimas', 7, NULL, 416, 1, NULL),
	(11324, 'NewTariffsChange', 'Naujo tarifinio tvarkaraščio pakeitimas', 7, NULL, 416, 1, NULL),
	(11325, 'TemperatureSensoFailure', 'Temperatūros daviklio gedimas - matavimas pagal fazę nepatikimas', 9, NULL, NULL, 1, NULL),
	(11326, 'MonitoringLogReset', 'Monitoringo žurnalo išvalymas', 14, NULL, NULL, 1, NULL),
	(11327, 'MonthlyProfileReset', 'Mėnesio profilio parodymų numetimas visose fazėse', 14, NULL, NULL, 1, NULL),
	(11328, 'DailyProfileReset', 'Paros profilio parodymų numetimas visose fazėse', 14, NULL, NULL, 1, NULL),
	(11329, 'ProfileResetL1', 'Profilio parodymų numetimas fazėje A', 14, NULL, NULL, 1, NULL),
	(11330, 'MonthlyProfileResetL1', 'Mėnesio profilio parodymų numetimas fazėje A', 14, NULL, NULL, 1, NULL),
	(11331, 'DailyProfileResetL1', 'Paros profilio parodymų numetimas fazėje A', 14, NULL, NULL, 1, NULL),
	(11332, 'ProfileResetL2', 'Profilio parodymų numetimas fazėje B', 14, NULL, NULL, 1, NULL),
	(11333, 'MonthlyProfileResetL2', 'Mėnesio profilio parodymų numetimas fazėje B', 14, NULL, NULL, 1, NULL),
	(11334, 'DailyProfileResetL2', 'Paros profilio parodymų numetimas fazėje B', 14, NULL, NULL, 1, NULL),
	(11335, 'ProfileResetL3', 'Profilio parodymų numetimas fazėje C', 14, NULL, NULL, 1, NULL),
	(11336, 'MonthlyProfileResetL3', 'Mėnesio profilio parodymų numetimas fazėje C', 14, NULL, NULL, 1, NULL),
	(11337, 'DailyProfileResetL3', 'Paros profilio parodymų numetimas fazėje C', 14, NULL, NULL, 1, NULL),
	(11338, 'ClockBatteryLow', 'Laikrodžio baterija', 9, NULL, 958, 1, NULL),
	(11339, 'PLCModuleFirmwareUpdate', 'PLC modulio PĮ atnaujinimas', 28, NULL, NULL, 1, NULL),
	(11340, 'RFModuleFirmwareUpdate', 'RF modulio PĮ atnaujinimas', 28, NULL, NULL, 1, NULL),
	(11341, 'ZigBeeModuleFirmwareUpdate', 'ZigBee modulio PĮ atnaujinimas', 28, NULL, NULL, 1, NULL),
	(11342, 'VoltageAfterRelayDisconnection', 'Atjungus relę', 13, NULL, 959, 1, NULL),
	(11343, 'VoltageAfterRelayDisconnection_L1', 'Atjungus relę fazėje A', 13, NULL, 960, 1, NULL),
	(11344, 'VoltageAfterRelayDisconnection_L2', 'Atjungus relę fazėje B', 13, NULL, 961, 1, NULL),
	(11345, 'VoltageAfterRelayDisconnection_L3', 'Atjungus relę fazėje C', 13, NULL, 962, 1, NULL),
	(11346, 'RegisterMonitor_Threshold1_CrossUp', 'Registras-monitorius, slenksčio 1 kirtimas iš apačios į viršų', 5, NULL, NULL, 1, NULL),
	(11347, 'RegisterMonitor_Threshold1_CrossDown', 'Registras-monitorius, slenksčio 1 kirtimas iš viršaus į apačią', 5, NULL, NULL, 1, NULL),
	(11348, 'RegisterMonitor_Threshold2_CrossUp', 'Registras-monitorius, slenksčio 2 kirtimas iš apačios į viršų', 5, NULL, NULL, 1, NULL),
	(11349, 'RegisterMonitor_Threshold2_CrossDown', 'Registras-monitorius, slenksčio 2 kirtimas iš viršaus į apačią', 5, NULL, NULL, 1, NULL),
	(11350, 'RelayOffByTempLimit_L1', 'Pagal temperatūrą relė fazėje A', 13, NULL, 963, 1, NULL),
	(11351, 'RelayOffByTempLimit_L2', 'Pagal temperatūrą relė fazėje B', 13, NULL, 964, 1, NULL),
	(11352, 'RelayOffByTempLimit_L3', 'Pagal temperatūrą relė fazėje C', 13, NULL, 965, 1, NULL),
	(11353, 'PLCNetworkSearch', 'Pasijungimas prie PLC tinklo, tinklo paieška', 8, NULL, NULL, 1, NULL),
	(11354, 'PLCConnAsBaseStation', 'Pajungtas prie PLC tinklo kaip bazinė stotis', 8, NULL, NULL, 1, NULL),
	(11355, 'PLCConnAsRemoteStation', 'Pajungtas prie PLC tinklo kaip nutolusi stotis', 8, NULL, NULL, 1, NULL),
	(11356, 'PLCDisconn_ParentUnstable', 'PLC klaida, atjungtas, nestabilus prietaisas-tėvas', 1, NULL, NULL, 1, NULL),
	(11357, 'PLCDisconn_NoBaseAck', 'PLC klaida, atjungtas, nėra patvirtinimo  iš bazinės stoties', 1, NULL, NULL, 1, NULL),
	(11358, 'PLCDisconn_RepeatLimit', 'PLC klaida, atjungtas, viršytas retranliacijų limitas', 1, NULL, NULL, 1, NULL),
	(11359, 'PLCDisconn_StackReset', 'PLC klaida, atjungtas, steko perkrovimas', 1, NULL, NULL, 1, NULL),
	(11360, 'PLCDisconn_TimerFailure', 'PLC klaida, atjungtas, negalima paleisti tinklinio protokolo taimerio', 1, NULL, NULL, 1, NULL),
	(11361, 'PLCDisconn_NoConnToBase', 'PLC klaida, atjungtas, ryšio tikrinimas su bazine stotimi atmestas', 1, NULL, NULL, 1, NULL),
	(11362, 'PLCDisconn_TestTaskListOvfl', 'PLC klaida, atjungtas, tikrinant ryšį bazine stotimi perpildytas užduočių sąrašas', 1, NULL, NULL, 1, NULL),
	(11363, 'PLCDisconn_VoidAddress', 'PLC klaida, atjungtas, nenaudojamas adresas', 1, NULL, NULL, 1, NULL),
	(11364, 'PLCDisconn_AppRequest', 'PLC klaida, atjungtas, vykdat užduotį', 1, NULL, NULL, 1, NULL),
	(11365, 'PLCNetworkLeftByCmd', 'Įvykdyta komanda išeiti iš tinklo', 8, NULL, NULL, 1, NULL),
	(11366, 'PLCRefused_IDListFull', 'PLC klaida, pajungimas atmestas dėl perpildymo bazėje ID bazinėje stotyje', 1, NULL, NULL, 1, NULL),
	(11367, 'PLCRefused_BaseStationApp', 'PLC klaida, pajungimas atmestas bazinės stoties užduotimi', 1, NULL, NULL, 1, NULL),
	(11368, 'PLCRefused_NoReason', 'PLC klaida, pajungimas atmestas be priežasties', 1, NULL, NULL, 1, NULL),
	(11369, 'PLCRefused_SerialNumber', 'PLC klaida, pajungimas atmestas, serijinis numeris neleistino diapazono', 1, NULL, NULL, 1, NULL),
	(11370, 'PLCRefused_DuplicateAddress', 'PLC klaida, pajungimas atmestas, dubliuojantis adresas', 1, NULL, NULL, 1, NULL),
	(11371, 'PLCRefused_WrongAddress', 'PLC klaida, pajungimas atmestas, neteisingas adresas', 1, NULL, NULL, 1, NULL),
	(11372, 'PLCRefused_WrongKey', 'PLC klaida, pajungimas atmestas, neteisingas tinklo raktas', 1, NULL, NULL, 1, NULL),
	(11373, 'AutoChangeChanToPhase', 'Automatinis energijos apskaitos kanalo pakeitimas į apskaitos pagal fazę kanalą', 8, NULL, NULL, 1, NULL),
	(11374, 'AutoChangeChanToNeutral', 'Automatinis energijos apskaitos kanalo pakeitimas į apskaitos pagal neutralę kanalą', 8, NULL, NULL, 1, NULL),
	(11384, 'HiLimit_FQ', 'FQ signalo dažnis', 9, NULL, 822, 1, NULL),
	(11385, 'WaterInSensor_Q', 'Vanduo Q daviklyje', 9, NULL, 823, 1, NULL),
	(11386, 'SensorFailure_Q', 'Q daviklio stovis', 9, NULL, 824, 1, NULL),
	(11387, 'NoFlow_Q', 'Suvartojimas', 9, NULL, 825, 1, NULL),
	(11388, 'BadSignal_Q', 'Q signalo busena', 9, NULL, 826, 1, NULL),
	(11389, 'SignalTest_Q', 'Suvartojimo pulsacija', 9, NULL, 827, 1, NULL),
	(11390, 'BadSignalMetering', 'Dujų apskaita esant blogam signalui', 9, NULL, 828, 1, NULL),
	(11391, 'LimitFaultedQn', 'Darbinio suvartojimo ribos', 5, NULL, 840, 1, NULL),
	(11392, 'ImpossibleCalckAdjustKf', 'Korekcijos koeficiento išskaičiavimas', 9, NULL, 841, 1, NULL),
	(11393, 'LimitFaultedT', 'Aliarmo temperatūrai ribos', 5, NULL, 842, 1, NULL),
	(11394, 'LimitFaultedP', 'Aliarmo slėgiui ribos', 5, NULL, 843, 1, NULL),
	(11395, 'ImpossibleCalckGazCompressKf', 'Dujų suspaudimo koeficiento išskaičiavimas', 9, NULL, 844, 1, NULL),
	(11396, 'ImpossibleCalckGazKf', 'Realių dujų koeficiento išskaičiavimas', 9, NULL, 845, 1, NULL),
	(11397, 'ErrorInput1', 'Klaida 1 įėjime', 9, NULL, 846, 1, NULL),
	(11398, 'ErrorInput2', 'Klaida 2 įėjime', 9, NULL, 847, 1, NULL),
	(11399, 'ErrorOutput1', 'Klaida 1 išėjime', 9, NULL, 848, 1, NULL),
	(11400, 'ErrorOutput2', 'Klaida 2 išėjime', 9, NULL, 849, 1, NULL),
	(11401, 'ErrorOutput3', 'Klaida 3 išėjime', 9, NULL, 850, 1, NULL),
	(11402, 'ErrorOutput4', 'Klaida 4 išėjime', 9, NULL, 851, 1, NULL),
	(11403, 'AlertLimitW', 'Perspėjimo riba pagal W', 5, NULL, 852, 1, NULL),
	(11404, 'AlertLimitFaultedQnCorr', 'Standartinio kiekio suvartojimo ribos', 5, NULL, 853, 1, NULL),
	(11405, 'AlertLimitFaultedQn', 'Darbinio kiekio suvartojimo ribos', 5, NULL, 854, 1, NULL),
	(11406, 'AlertLimitFaultedT', 'Temperatūros perspėjimo ribos', 5, NULL, 855, 1, NULL),
	(11407, 'AlertLimitFaultedP', 'Slėgio perspėjimo ribos', 5, NULL, 856, 1, NULL),
	(11408, 'ProgrammError', 'Programinės įrangos klaida', 9, NULL, 857, 1, NULL),
	(11409, 'HiDayLimitQn', 'Dujų suvartojimas per parą viršijo limitą', 5, NULL, 858, 1, NULL),
	(11410, 'SettingError', 'Nustatymų klaida', 9, NULL, 859, 1, NULL),
	(11411, 'HiMonthLimitQn', 'Nustatyta dujų suvartojimo riba per mėnesį', 5, NULL, 860, 1, NULL),
	(11412, 'AlarmInput3', 'Perspėjimo signalas Įėjime 3', 9, NULL, 861, 1, NULL),
	(11413, 'LoLimitBattery', 'Maitinimo elementų likutinio veikimo laiko žemutinės riba', 5, NULL, 862, 1, NULL),
	(11414, 'RepairMode', 'Remonto rėžimas', 9, NULL, 863, 1, NULL),
	(11415, 'ReportInput2', 'Ataskaitos signalas Įėjime 2', 9, NULL, 864, 1, NULL),
	(11416, 'ReportInput3', 'Ataskaitos signalas Įėjime 3', 9, NULL, 865, 1, NULL),
	(11417, 'KeyCalibration', 'Kalibravimo spyna', 9, NULL, 866, 1, NULL),
	(11418, 'KeyProvider', 'Tiekėjo spyna', 9, NULL, 867, 1, NULL),
	(11419, 'KeyCustomer', 'Vartotojo spyna', 9, NULL, 868, 1, NULL),
	(11420, 'Interval1Active', 'Duomenų  užklausimo patvirtinimo 1 laikinis intervalas', 9, NULL, 869, 1, NULL),
	(11421, 'Interval2Active', 'Duomenų  užklausimo patvirtinimo 2 laikinis intervalas', 9, NULL, 870, 1, NULL),
	(11422, 'Interval3Active', 'Duomenų  užklausimo patvirtinimo 3 laikinis intervalas', 9, NULL, 871, 1, NULL),
	(11423, 'Interval4Active', 'Duomenų  užklausimo patvirtinimo 4 laikinis intervalas', 9, NULL, 872, 1, NULL),
	(11424, 'ProperValueAfter', 'Tinkama reikšmė archyvui pasikeitė - reikšmė po pakeitimo', 8, NULL, NULL, 1, NULL),
	(11425, 'ProperValueBefore', 'Tinkama reikšmė archyvui pasikeitė - reikšmė prieš pakeitimą', 8, NULL, NULL, 1, NULL),
	(11426, 'FreezeUp', 'Komanda "Užšaldyti"', 8, NULL, NULL, 1, NULL),
	(11427, 'CableCoverOpen_Duration', 'Atidarytos kontaktų kaladėlės trukmė', 9, NULL, NULL, 4, 10),
	(11428, 'CaseOpen_Duration', 'Atidaryto korpuso trukmė', 9, NULL, NULL, 4, 10),
	(11429, 'DeletionOfSignaling', 'Sensorių suveikimo pranešimų trynimas', 7, NULL, NULL, 1, NULL),
	(11430, 'DeletionOfSignaling_COO', 'Korpuso atidarymo sensoriaus pranešimų trynimas', 7, NULL, NULL, 1, NULL),
	(11431, 'DeletionOfSignaling_CZM', 'Kontaktų kaladėlės atidarymo sensoriaus pranešimų trynimas', 7, NULL, NULL, 1, NULL),
	(11432, 'DeletionOfSignaling_RPM', 'Magnetinio lauko poveikio sensoriaus pranešimų trynimas', 7, NULL, NULL, 1, NULL),
	(11433, 'DeletionOfSignaling_Remote', 'Sensorių suveikimo pranešimų trynimas nuotoliniu būdu', 7, NULL, NULL, 1, NULL),
	(11434, 'SettingChange_ByButton', 'Nustatymų keitimas naudojantis skaitiklio mygtuku', 7, NULL, NULL, 1, NULL),
	(11435, 'CalendarChange_ByButton', 'Aktyvaus kalendoriaus keitimas naudojantis skaitiklio mygtuku', 7, NULL, NULL, 1, NULL),
	(11436, 'LastRechargeRecords', 'Paskutinių papildymų įrašai', 11, NULL, NULL, 1, NULL),
	(11437, 'TamperAtemptsCount', 'Bendras neleistino poveikio kiekis', 11, NULL, NULL, 3, NULL),
	(11438, 'ClearCredit', 'Kredito registro numetimas', 14, NULL, NULL, 1, NULL),
	(11439, 'ClearTamper', 'Skaitiklio poveikio registro numetimas', 14, NULL, NULL, 1, NULL),
	(11440, 'Timing', 'Laiko skaičiavimas', 17, NULL, NULL, 1, NULL),
	(11441, 'CreditIs0', 'Kreditas lygus 0', 17, NULL, NULL, 1, NULL),
	(11442, 'DownloadTariff', 'Tarifo užkrovimas', 17, NULL, NULL, 1, NULL),
	(11443, 'EnterTechnicalTOKEN', 'TOKENo įvedimas', 11, NULL, NULL, 1, NULL),
	(11444, 'PostPre_PaymentShift', 'Pakeitimas paprasto/išankstinio apmokėjimo tipo', 17, NULL, NULL, 1, NULL),
	(11445, 'LowVoltageMalfunction', 'Per žema įtampa normaliam darbui', 9, NULL, NULL, 1, NULL),
	(11446, 'RechargeTimesCount', 'Bendras papildymų kiekis', 11, NULL, NULL, 3, NULL),
	(11447, 'TotalEeventsCount', 'Bendras įvykių kiekis', 11, NULL, NULL, 3, NULL),
	(11448, 'Contract1PassiveCleared', 'Pasyvus  1 kontrakto išvalymas ', 11, NULL, NULL, 1, NULL),
	(11449, 'Contract1AutoBillEndPassChange', 'Pasyvus automatinio bilingo 1 kontrakto pabaigos pakeitimas', 11, NULL, NULL, 1, NULL),
	(11450, 'Contract1ActivationPassChange', 'Pasyvus 1 kontrakto aktyvizacijos datos pakeitimas', 11, NULL, NULL, 1, NULL),
	(11451, 'ActivityCalendarConfigErr', 'Aktyvusis kalendorius yra neteisingos konfigūracijos', 11, NULL, NULL, 1, NULL),
	(11452, 'ThresholdVoltSagSwellChanged', 'Trumpalaikių įtampos dingimų ir viršiimų  slenkstis pakeistas', 11, NULL, NULL, 1, NULL),
	(11453, 'ThresholdLongPowerFailChanged', 'Ilgalaikių įtampos dingimų slenkstis pakeistas', 11, NULL, NULL, 1, NULL),
	(11454, 'ConsumerMsgObjChanged', 'Vartotojų pranešimų objektas pakeistas', 11, NULL, NULL, 1, NULL),
	(11455, 'DemandConfigChanged', 'Pakeista galios konfigūracija', 11, NULL, NULL, 1, NULL),
	(11456, 'DeviceIDChanged', 'Pakeistas prietaiso ID', 11, NULL, NULL, 1, NULL),
	(11457, 'LoadProfileP1Changed', 'Pakeistas 1 apkrovos profilis', 11, NULL, NULL, 1, NULL),
	(11458, 'LoadProfileP2Changed', 'Pakeistas 2 apkrovos profilis', 11, NULL, NULL, 1, NULL),
	(11459, 'LocalDisplayConfigChanged', 'Pakeista lokalaus displėjaus konfigūracija', 11, NULL, NULL, 1, NULL),
	(11460, 'SecuritySetupConfigChanged', 'Pakeista saugumo nustatymų konfigūracija', 11, NULL, NULL, 1, NULL),
	(11461, 'StandardEventLogChanged', 'Pakeistas standartinių įvykių įrašas', 11, NULL, NULL, 1, NULL),
	(11462, 'FirmwareEventLogChanged', 'Pakeistas vidinės programinės įrangos įrašas', 11, NULL, NULL, 1, NULL),
	(11463, 'SyncEventLogChanged', 'Pakeistas sinchronizacijos įrašas', 11, NULL, NULL, 1, NULL),
	(11464, 'DisconnectorLogChanged', 'Pakeistas atjungimų kontrolės įrašas', 11, NULL, NULL, 1, NULL),
	(11465, 'PowerQualityLogChanged', 'Pakeistas galios kokybės įvykių įrašas', 11, NULL, NULL, 1, NULL),
	(11466, 'FinishedQualityLogChanged', 'Pakeistas jau baigtas kokybės įvykių įrašas', 11, NULL, NULL, 1, NULL),
	(11467, 'FraudLogChanged', 'Pakeistas nesankcionuoto poveikio įrašas', 11, NULL, NULL, 1, NULL),
	(11468, 'DemandMngmLogChanged', 'Pakeistas galios valdymo įrašas', 11, NULL, NULL, 1, NULL),
	(11469, 'CommonLogChanged', 'Pakeistas įeinančių parametrų įrašas.', 11, NULL, NULL, 1, NULL),
	(11470, 'HANControllerPasswChange', 'Pakeistas kontrolerio HAN slaptažodis', 11, NULL, NULL, 1, NULL),
	(11471, 'SafeParamMsgActivated', 'Aktyvuotas saugaus parametravimo pranešimas', 11, NULL, NULL, 1, NULL),
	(11472, 'CreditModeActivated', 'Aktyvuotas kreditinis modulis', 11, NULL, NULL, 1, NULL),
	(11473, 'AssocReadCliError', 'Klaida asocijuoto kliento skaitymui', 11, NULL, NULL, 1, NULL),
	(11474, 'AssocMngmCliError', 'Klaida asocijuoto kliento valdymui', 11, NULL, NULL, 1, NULL),
	(11475, 'AssocHanCliError', 'Klaida asocijuoto kliento HAN kontroleriui', 11, NULL, NULL, 1, NULL),
	(11476, 'AssocReadCliLock', 'Blokavimas asocijuoto kliento skaitymui', 11, NULL, NULL, 1, NULL),
	(11477, 'AssocMngmCliLock', 'Blokavimas asocijuoto kliento valdymui', 11, NULL, NULL, 1, NULL),
	(11478, 'AssocHanCliLock', 'Blokavimas asocijuoto kliento HAN kontroleriui', 11, NULL, NULL, 1, NULL),
	(11479, 'AssocReadCliUnlock', 'Atblokavimas asocijuoto kliento skaitymui', 11, NULL, NULL, 1, NULL),
	(11480, 'AssocMngmCliUnlock', 'Atblokavimas asocijuoto kliento valdymui', 11, NULL, NULL, 1, NULL),
	(11481, 'AssocHanCliUnlock', 'Atblokavimas asocijuoto kliento HAN kontroleriui', 11, NULL, NULL, 1, NULL),
	(11482, 'TotalActivePowerError', 'Suminė aktyvinė energija', 11, NULL, 900, 1, NULL),
	(11483, 'ActiveDemandError', 'Aktyvinė galia', 11, NULL, 900, 1, NULL),
	(11484, 'FirmwBlockTransfInit', 'Inicijuotas blokinis vidinės programinės įrangos atvaizdo perdavimas', 11, NULL, NULL, 1, NULL),
	(11485, 'FirmwBlockTransfFinish', 'Pabaigtas blokinis vidinės programinės įrangos atvaizdo perdavimas', 11, NULL, NULL, 1, NULL),
	(11486, 'FirmwVerificationInit', 'Inicijuotas vidinės programinės įrangos atvaizdo patikrinimas', 11, NULL, NULL, 1, NULL),
	(11487, 'FirmwVerificationSucc', 'Vidinės programinės įrangos atvaizdo patikrinimas pavyko', 11, NULL, NULL, 1, NULL),
	(11488, 'FirmwVerificationFail', 'Vidinės programinės įrangos atvaizdo patikrinimas nepavyko', 11, NULL, NULL, 1, NULL),
	(11489, 'FirmwActivationInit', 'Vidinės programinės įrangos atvaizdo patikrinimo aktyvavimo inicializacija', 11, NULL, NULL, 1, NULL),
	(11490, 'FirmwActivationFail', 'Vidinės programinės įrangos atvaizdo patikrinimo aktyvavimas nepavyko', 11, NULL, NULL, 1, NULL),
	(11491, 'FirmwBlockWriteError', 'Blokinio vidinės programinės įrangos atvaizdo įrašymo klaida', 11, NULL, NULL, 1, NULL),
	(11492, 'UnderVoltage1Sag1', 'Įtampa fazėje L1 žemiau slenksčio (1 kritimas)', 11, NULL, NULL, 1, NULL),
	(11493, 'UnderVoltage2Sag1', 'Įtampa fazėje L2 žemiau slenksčio (1 kritimas)', 11, NULL, NULL, 1, NULL),
	(11494, 'UnderVoltage3Sag1', 'Įtampa fazėje L3 žemiau slenksčio (1 kritimas)', 11, NULL, NULL, 1, NULL),
	(11495, 'OverVoltage1Swell', 'Įtampa fazėje L1 aukščiau slenksčio ', 11, NULL, NULL, 1, NULL),
	(11496, 'OverVoltage2Swell', 'Įtampa fazėje L2 aukščiau slenksčio ', 11, NULL, NULL, 1, NULL),
	(11497, 'OverVoltage3Swell', 'Įtampa fazėje L3 aukščiau slenksčio ', 11, NULL, NULL, 1, NULL),
	(11498, 'PowerFailure', 'Įtampos dingimas visose fazėse', 11, NULL, NULL, 1, NULL),
	(11499, 'UnderVoltage1Sag2', 'Įtampa fazėje L1 žemiau slenksčio (2 kritimas)', 11, NULL, NULL, 1, NULL),
	(11500, 'UnderVoltage2Sag2', 'Įtampa fazėje L2 žemiau slenksčio (2 kritimas)', 11, NULL, NULL, 1, NULL),
	(11501, 'UnderVoltage3Sag2', 'Įtampa fazėje L3 žemiau slenksčio (2 kritimas)', 11, NULL, NULL, 1, NULL),
	(11502, 'UnderVoltage1Sag3', 'Įtampa fazėje L1 žemiau slenksčio (3 kritimas)', 11, NULL, NULL, 1, NULL),
	(11503, 'UnderVoltage2Sag3', 'Įtampa fazėje L2 žemiau slenksčio (3 kritimas)', 11, NULL, NULL, 1, NULL),
	(11504, 'UnderVoltage3Sag3', 'Įtampa fazėje L3 žemiau slenksčio (3 kritimas)', 11, NULL, NULL, 1, NULL),
	(11505, 'PLCCommunication', 'Ryšio per PLC portą', 11, NULL, 901, 1, NULL),
	(11506, 'OpticalCommunication', 'Ryšio per optinį portą', 11, NULL, NULL, 1, NULL),
	(11507, 'OFDMCommFail', 'Susijungimas su OFDM modemu', 11, NULL, 902, 1, NULL),
	(11508, 'OFDMRestart', 'Persikrovė OFDM modemas', 11, NULL, NULL, 1, NULL),
	(11509, 'PasswordErrKeyBoard', 'Slaptažodžio įvedimas klaviatūros pagalba', 11, NULL, 904, 1, NULL),
	(11510, 'PLISError', 'PLIS darbo klaida', 11, NULL, NULL, 1, NULL),
	(11511, 'PromConfigErr', 'Prom-kontrolerio klaidingas nustatymas', 11, NULL, NULL, 1, NULL),
	(11512, 'PromConfigChange', 'Pakeista konfigūracija prom-kontrolerio tipo', 11, NULL, NULL, 1, NULL),
	(11513, 'FlashDiskOverload', 'Flash diske vietos', 11, NULL, 905, 1, NULL),
	(11514, 'RAMDiskOverload', 'RAM diske vietos', 11, NULL, 905, 1, NULL),
	(11515, 'RAMOverload', 'RAM atmintyje vietos', 11, NULL, 905, 1, NULL),
	(11516, 'TempDel', 'Laikinų failų naikinimas', 11, NULL, NULL, 1, NULL),
	(11517, 'DBSettingChange', 'DB nustatymų pakeitimas', 11, NULL, NULL, 1, NULL),
	(11518, 'TSPowerOn', 'Vidinių MP-4 maitinimas', 11, NULL, 906, 1, NULL),
	(11519, 'StartProcessArchives', 'Proceso "Archyvas" paleidimas', 11, NULL, NULL, 1, NULL),
	(11520, 'StartProcessQueue', 'Proceso "Eilė" paleidimas', 11, NULL, NULL, 1, NULL),
	(11521, 'Timer_Adjust_IntervalTooLong', 'Laiko koregavimas viršijo užduotą intervalą', 11, NULL, NULL, 1, NULL),
	(11522, 'ProgrammChange', 'Skaitiklio programos modifikacija', 11, NULL, NULL, 1, NULL),
	(11523, 'LastEvent', 'Įvykių sąrašo paskutinis įvykis', 11, NULL, NULL, 1, NULL),
	(11524, 'RebootWithLoss', 'Perkrovimas su duomenų praradimu', 11, NULL, NULL, 1, NULL),
	(11525, 'RebootWithoutLoss', 'Perkrovimas be duomenų praradimo', 11, NULL, NULL, 1, NULL),
	(11526, 'RegisterParamChange', 'Pakeisti registrų parametrai ', 11, NULL, NULL, 1, NULL),
	(11528, 'ReadingPasswChange', 'Pakeistas skaitymo slaptažodis', 11, NULL, NULL, 1, NULL),
	(11529, 'ConfigPasswChange', 'Pakeistas parametrizacijos slaptažodis', 11, NULL, NULL, 1, NULL),
	(11530, 'FirmwarePasswChange', 'Pakeistas vidinės programinės įrangos slaptažodis', 11, NULL, NULL, 1, NULL),
	(11531, 'BatteryCleared', 'Bateriją išsikrovusi', 11, NULL, NULL, 1, NULL),
	(11532, 'Contract1ClosureCmdPrompt', 'Iškvietimo komandos 1 kontrakto uždarymas', 11, NULL, NULL, 1, NULL),
	(11533, 'Contract1ParametersChanged', 'Pakeisti 1 kontrakto parametrai', 11, NULL, NULL, 1, NULL),
	(11534, 'Contract1SpecDaysPassChange', 'Pasyvus specialių dienų  lentelės 1 kontrakto pakeitimas', 11, NULL, NULL, 1, NULL),
	(11535, 'Contract1SeasonPassChange', 'Pasyvus sezonų lentelės 1 kontrakto pakeitimas', 11, NULL, NULL, 1, NULL),
	(11536, 'Wrong_Phase_Sequence_U', 'Atvirkštinė įtampos fazių seka', 11, NULL, NULL, 1, NULL),
	(11537, 'Wrong_Phase_Sequence_I', 'Atvirkštinė srovės fazių seka', 11, NULL, NULL, 1, NULL),
	(11538, 'CurrentLossPhase1', 'Nuostolių srovė fazėje L1', 11, NULL, NULL, 1, NULL),
	(11539, 'CurrentLossPhase2', 'Nuostolių srovė fazėje L2', 11, NULL, NULL, 1, NULL),
	(11540, 'CurrentLossPhase3', 'Nuostolių srovė fazėje L3', 11, NULL, NULL, 1, NULL),
	(11541, 'OverLoadPhase1', 'Perkrova fazėje L1', 3, NULL, NULL, 1, NULL),
	(11542, 'OverLoadPhase2', 'Perkrova fazėje L2', 3, NULL, NULL, 1, NULL),
	(11543, 'OverLoadPhase3', 'Perkrova fazėje L3', 3, NULL, NULL, 1, NULL),
	(11544, 'MoreLimitQ1', 'Reaktyvinės galios limito viršijimas kvandrante Q1', 5, NULL, NULL, 1, NULL),
	(11545, 'MoreLimitQ2', 'Reaktyvinės galios limito viršijimas kvandrante Q2', 5, NULL, NULL, 1, NULL),
	(11546, 'MoreLimitQ3', 'Reaktyvinės galios limito viršijimas kvandrante Q3', 5, NULL, NULL, 1, NULL),
	(11547, 'MoreLimitQ4', 'Reaktyvinės galios limito viršijimas kvandrante Q4', 5, NULL, NULL, 1, NULL),
	(11548, 'DayOffChange', 'Poilsio ir šventinių dienų programavimas', 7, NULL, NULL, 1, NULL),
	(11549, 'CombinationChange_A', 'Aktyvinės kombinacijos programavimas', 7, NULL, NULL, 1, NULL),
	(11550, 'CombinationChange_R1', 'Reaktyvinės 1-os kombinacijos programavimas', 7, NULL, NULL, 1, NULL),
	(11551, 'CombinationChange_R2', 'Reaktyvinės 2-os kombinacijos programavimas', 7, NULL, NULL, 1, NULL),
	(11552, 'MeterAccessBlockedToday', 'Prieiga prie skaitiklio viršijus blogų slaptažodžių limitą', 8, NULL, 948, 1, NULL),
	(11553, 'MeterSleepTime', 'Miego trukmė', 12, NULL, NULL, 1, 10),
	(11554, 'MagneticSeal_DCfield', 'Magnetinės pastovios įtampos plombos pažeidimas', 9, NULL, NULL, 1, NULL),
	(11555, 'MagneticSeal_ACfield', 'Magnetinės kintamos įtampos plombos pažeidimas', 9, NULL, NULL, 1, NULL),
	(11556, 'Relay_1_Count', '1-osios relės padarytų atjungimų kiekis', 13, NULL, NULL, 3, NULL),
	(11557, 'Relay_2_Count', '2-osios relės padarytų atjungimų kiekis', 13, NULL, NULL, 3, NULL),
	(11558, 'Relay_3_Count', '3-osios relės padarytų atjungimų kiekis', 13, NULL, NULL, 3, NULL),
	(11559, 'Relay_4_Count', '4-osios relės padarytų atjungimų kiekis', 13, NULL, NULL, 3, NULL),
	(11560, 'Relay_5_Count', '5-osios relės padarytų atjungimų kiekis', 13, NULL, NULL, 3, NULL),
	(11561, 'Power_Error', 'Maitinimo', 9, NULL, 988, 1, NULL),
	(11562, 'Error_Clock_MC ', 'MK taktavimo', 9, NULL, 989, 1, NULL),
	(11563, 'Error_?emory_Chip_1', 'Atminties"1" mikroschemos', 9, NULL, 990, 1, NULL),
	(11564, 'Error_?emory_Chip_2', 'Atminties"2" mikroschemos', 9, NULL, 991, 1, NULL),
	(11565, 'Error_Program_Checksum ', 'Programos kontrolinės sumos', 9, NULL, 992, 1, NULL),
	(11566, 'Triggering_Radio_Sensor', 'Radijo daviklio suveikimas', 8, NULL, 993, 1, NULL),
	(11567, '?mergency_Tariff ', 'Avarinis tarifas', 8, NULL, 994, 1, NULL),
	(11568, 'Energy_Registers_Damaged ', 'Energijos registrai ', 9, NULL, 995, 1, NULL),
	(11569, 'Calibration_Metrology_Damaged', 'Metrologinė kalibruotė', 9, NULL, 996, 1, NULL),
	(11570, 'Parameterization_Damaged ', 'Parametravimas', 9, NULL, 997, 1, NULL),
	(11571, 'Load_Control_Relay_Open                ', 'Apkrovos valdymo relė', 13, NULL, 1027, 1, NULL),
	(11573, 'Shows_Indication_RADIO ', 'Indikacija "Radijo"', 8, NULL, 998, 1, NULL),
	(11574, 'Shows_Indication_MAGN', 'Indikacija "Magn"', 8, NULL, 999, 1, NULL),
	(11575, 'Shows_Indication_BORG', 'Indikacija "Borg"', 8, NULL, 1000, 1, NULL),
	(11576, 'Voltage_Below_Normal_L1', 'Įtampa žemiau normos fazėje L1', 5, NULL, 1001, 1, NULL),
	(11577, 'Voltage_Below_Normal_L2', 'Įtampa žemiau normos fazėje L2', 5, NULL, 1002, 1, NULL),
	(11578, 'Voltage_Below_Normal_L3', 'Įtampa žemiau normos fazėje L3', 5, NULL, 1003, 1, NULL),
	(11579, 'Voltage_Above_Normal_L1', 'Įtampa aukščiau normos fazėje L1', 5, NULL, 1004, 1, NULL),
	(11580, 'Voltage_Above_Normal_L2', 'Įtampa aukščiau normos fazėje L2', 5, NULL, 1005, 1, NULL),
	(11581, 'Voltage_Above_Normal_L3', 'Įtampa aukščiau normos fazėje L3', 5, NULL, 1006, 1, NULL),
	(11582, 'Current_Above_Normal_L1', 'Srovė viršija normą fazėje L1', 5, NULL, 1007, 1, NULL),
	(11583, 'Current_Above_Normal_L2', 'Srovė viršija normą fazėje L2', 5, NULL, 1008, 1, NULL),
	(11584, 'Current_Above_Normal_L3', 'Srovė viršija normą fazėje L3', 5, NULL, 1009, 1, NULL),
	(11585, 'OptPort_Active_Authoriz_User ', 'Optoportas, vartotojo autorizacija aktyvi', 8, NULL, 1010, 1, NULL),
	(11586, 'OptPort_Active_Authoriz_Operator ', 'Optoportas, operatoriaus autorizacija aktyvi', 8, NULL, 1011, 1, NULL),
	(11587, 'OptPort_Locked_Authoriz_User ', 'Optoportas, vartotojo autorizacija užblokuota', 8, NULL, 1012, 1, NULL),
	(11588, 'OptPort_Locked_Authoriz_Operator ', 'Optoportas, operatoriaus autorizacija užblokuota', 8, NULL, 1013, 1, NULL),
	(11589, 'Interface_1_Active_Authoriz_User ', 'Interfeisas 1, vartotojo autorizacija aktyvi', 8, NULL, 1014, 1, NULL),
	(11590, 'Interface_1_Active_Authoriz_Operator ', 'Interfeisas 1, operatoriaus autorizacija aktyvi', 8, NULL, 1015, 1, NULL),
	(11591, 'Interface_1_Locked_Authoriz_User ', 'Interfeisas 1, vartotojo autorizacija užblokuota', 8, NULL, 1016, 1, NULL),
	(11592, 'Interface_1_Locked_Authoriz_Operator ', 'Interfeisas 1, operatoriaus autorizacija užblokuota', 8, NULL, 1017, 1, NULL),
	(11593, 'Interface_2_Active_Authoriz_User ', 'Interfeisas 2, vartotojo autorizacija aktyvi', 8, NULL, 1018, 1, NULL),
	(11594, 'Interface_2_Active_Authoriz_Operator ', 'Interfeisas 2, operatoriaus autorizacija aktyvi', 8, NULL, 1019, 1, NULL),
	(11595, 'Interface_2_Locked_Authoriz_User ', 'Interfeisas 2, vartotojo autorizacija užblokuota', 8, NULL, 1020, 1, NULL),
	(11596, 'Interface_2_Locked_Authoriz_Operator ', 'Interfeisas 2, operatoriaus autorizacija užblokuota', 8, NULL, 1021, 1, NULL),
	(11597, 'Interface_3_Active_Authoriz_User ', 'Interfeisas 3, vartotojo autorizacija aktyvi', 8, NULL, 1022, 1, NULL),
	(11598, 'Interface_3_Active_Authoriz_Operator ', 'Interfeisas 3, operatoriaus autorizacija aktyvi', 8, NULL, 1023, 1, NULL),
	(11599, 'Interface_3_Locked_Authoriz_User ', 'Interfeisas 3, vartotojo autorizacija užblokuota', 8, NULL, 1024, 1, NULL),
	(11600, 'Interface_3_Locked_Authoriz_Operator ', 'Interfeisas 3, operatoriaus autorizacija užblokuota', 8, NULL, 1025, 1, NULL),
	(11601, 'Power_On_Count ', 'Skaitiklio įjungimų kiekis', 8, NULL, NULL, 3, NULL),
	(11602, 'CableCover_Close_Count ', 'Pajungimo kaladėlės uždarymų kiekis', 8, NULL, NULL, 3, NULL),
	(11603, 'Case_Close_Count ', 'Korpuso uždarymo kiekis', 8, NULL, NULL, 3, NULL),
	(11604, 'Events_Before_TimeSet_Count', '"Laikas iki pasikeitimo" nustatymų kiekis', 8, NULL, NULL, 3, NULL),
	(11605, 'Events_After_TimeSet_Count ', '"Laikas po pasikeitimo" nustatymų kiekis ', 8, NULL, NULL, 3, NULL),
	(11606, 'Start_RF_Exposure_Count', '"Poveikiu radijo lauku pradžia " kiekis', 8, NULL, NULL, 3, NULL),
	(11607, 'Stop_RF_Exposure_Count ', '"Poveikiu radijo lauku pabaiga" kiekis ', 8, NULL, NULL, 3, NULL),
	(11608, 'Reset_Indication_RF_Exposure_Count ', 'Indikacijos veikimo radijo lauku numetimų kiekis', 8, NULL, NULL, 3, NULL),
	(11609, 'Start_Magnet_Exposure_Count', '"Poveikiu magnetu pradžia" kiekis ', 8, NULL, NULL, 3, NULL),
	(11610, 'Stop_Magnet_Exposure_Count ', '"Poveikiu magnetu pabaIga" kiekis ', 8, NULL, NULL, 3, NULL),
	(11611, 'Reset_Indication_Magnet_Exposure_Count ', 'Indikacijos poveikiu magnetu numetimų kiekis', 8, NULL, NULL, 3, NULL),
	(11612, 'Loss_Voltage_L1_Count', 'Įtampos dingimų kiekis fazėje L1 ', 8, NULL, NULL, 3, NULL),
	(11613, 'Loss_Voltage_L2_Count', 'Įtampos dingimų kiekis fazėje L2 ', 8, NULL, NULL, 3, NULL),
	(11614, 'Loss_Voltage_L3_Count', 'Įtampos dingimų kiekis fazėje L3', 8, NULL, NULL, 3, NULL),
	(11615, 'Undervoltage_L1_Count', 'Įtampos kritimų kiekis fazėje L1', 8, NULL, NULL, 3, NULL),
	(11616, 'Undervoltage_L2_Count', 'Įtampos kritimų kiekis fazėje L2', 8, NULL, NULL, 3, NULL),
	(11617, 'Undervoltage_L3_Count', 'Įtampos kritimų kiekis fazėje L3', 8, NULL, NULL, 3, NULL),
	(11618, 'Increasing_Voltage_L1_Count', 'įtampos pakilimų kiekis fazėje L1', 8, NULL, NULL, 3, NULL),
	(11619, 'Increasing_Voltage_L2_Count', 'Įtampos pakilimų kiekis fazėje L2', 8, NULL, NULL, 3, NULL),
	(11620, 'Increasing_Voltage_L3_Count', 'Įtampos pakilimų kiekis fazėje L3', 8, NULL, NULL, 3, NULL),
	(11621, 'Voltage_Recovery_L1_Count', 'Įtampos atsistatymo kiekis fazėje L1', 8, NULL, NULL, 3, NULL),
	(11622, 'Voltage_Recovery_L2_Count', 'Įtampos atsistatymo kiekis fazėje L2', 8, NULL, NULL, 3, NULL),
	(11623, 'Voltage_Recovery_L3_Count', 'Įtampos atsistatymo kiekis fazėje L3', 8, NULL, NULL, 3, NULL),
	(11626, 'Status_Backup_Battery_Count', 'Rezervinio maitinimo baterijos būsenos įvykių kiekis ', 8, NULL, NULL, 3, NULL),
	(11627, 'Reset_Load_Profile_Count ', 'Apkrovos profilio numetimas', 8, NULL, NULL, 3, NULL),
	(11628, 'Tariff_Scale_Change_Count', 'Tarifinio tinklelio pakeitimų kiekis', 8, NULL, NULL, 3, NULL),
	(11629, 'Time_Before_Set', 'Laikas iki pasikeitimo', 8, NULL, NULL, 1, NULL),
	(11630, 'Time_After_Set ', 'Laikas po pasikeitimo', 8, NULL, NULL, 1, NULL),
	(11631, 'RF_Exposure', 'Poveikio radijo lauku', 8, NULL, 1026, 1, NULL),
	(11632, 'Reset_Indication_RF_Exposure ', 'Poveikio radijo lauku indikacijos numetimas', 8, NULL, NULL, 1, NULL),
	(11633, 'Reset_Indication_Magnet_Exposure ', 'Poveikio magnetinio lauku indikacijos numetimas', 8, NULL, NULL, 1, NULL),
	(11634, 'State_Backup_Battery ', 'Rezervinio maitinimo baterijos būsena ', 8, NULL, NULL, 1, NULL),
	(11635, 'AlgorithmOutOfR', 'Reikšmės Z ir Zb intervalą', 26, NULL, 1037, 1, NULL),
	(11636, 'LimitExit_P1', 'Parametras p1 limitus I p1 arba u p1', 26, NULL, 1038, 1, NULL),
	(11637, 'LimitExit_P2', 'Parametras p2 limitus I p2 arba u p2', 26, NULL, 1039, 1, NULL),
	(11638, 'QbOutOfL', 'Parametras Qb limitus I Qb arba u Qb', 26, NULL, 1040, 1, NULL),
	(11639, 'QmOutOfL', 'Parametras Qm limitus I Qm arba u Qm', 26, NULL, 1041, 1, NULL),
	(11640, 'dVbhOutOfL3', 'Parametras dVbh limitą Vbh 3 ', 26, NULL, 1042, 1, NULL),
	(11641, 'dVbhOutOfL2', 'Parametras dVbh limitą Vbh 2', 26, NULL, 1043, 1, NULL),
	(11642, 'dVbhOutOfL1', 'Parametras dVbh limitą Vbh 1', 26, NULL, 1044, 1, NULL),
	(11643, 'Vm_V2OutOfL', 'Skirtumas Vm-V2 toleranciją', 26, NULL, 1045, 1, NULL),
	(11644, 'LFfreqOutOfR', 'Dažnis LF limitą 2,5 kHz', 26, NULL, 1046, 1, NULL),
	(11645, 'p1OutOfR', 'Parametras p1 intervalą nuo p1 min iki p1 max', 26, NULL, 1047, 1, NULL),
	(11646, 'p2OutOfR', 'Parametras p2 intervalą nuo p2 min iki p2 max', 26, NULL, 1048, 1, NULL),
	(11647, 'tOutOfR', 'Temperatūra intervalą nuo t min iki t max', 26, NULL, 1049, 1, NULL),
	(11648, 'QmOutOfR', 'Parametras Qb intervalą nuo Qm min iki Qm max', 26, NULL, 1050, 1, NULL),
	(11649, 'HF_LF_error', 'Santykis HF / LF toleranciją', 26, NULL, 1051, 1, NULL),
	(11650, 'Legalization', 'Įteisinimas', 27, NULL, 1052, 1, NULL),
	(11651, 'ChangeVm', 'Pakeistas Vm', 7, NULL, 1053, 1, NULL),
	(11652, 'ChangeDtau', 'Registravimo periodas pakeistas', 7, NULL, 1054, 1, NULL),
	(11653, 'ChangeConf', 'Impulsinių įėjimų konfigūracija pakeista', 7, NULL, 1055, 1, NULL),
	(11654, 'ChangeValue', 'DP reišmė pakeista', 7, NULL, 1056, 1, NULL),
	(11655, 'ChangeText', 'DP tekstas pakeistas', 7, NULL, 1057, 1, NULL),
	(11656, 'ChangeGasParam', 'Pakeistas dūjų parametras', 7, NULL, 1058, 1, NULL),
	(11657, 'MemoryErased', 'Duomenys prietaise ištrinti', 14, NULL, 1059, 1, NULL),
	(11658, 'DigitalInputS1', 'Pasikeitė iėjimo S1 būsena', 11, NULL, 1060, 1, NULL),
	(11659, 'DigitalInputS2', 'Pasikeitė iėjimo S2 būsena', 11, NULL, 1061, 1, NULL),
	(11660, 'DigitalInputS3', 'Pasikeitė iėjimo S3 būsena', 11, NULL, 1062, 1, NULL),
	(11661, 'SolarBatteryMode', 'Saulės baterijos veikimo', 8, NULL, 1063, 1, NULL),
	(11662, 'BatteryDisconnection', 'Baterijos atsijungimo', 9, NULL, 1064, 1, NULL),
	(11663, 'KeyboardError', 'Klaviatūros gedimų', 9, NULL, 1065, 1, NULL),
	(11664, 'CounterOverrun', 'Indikatoriaus perpildymo', 9, NULL, 1066, 1, NULL),
	(11665, 'ReedContactAlarm', 'Kontrolinis kontaktas ', 11, NULL, 1067, 1, NULL),
	(11666, 'LockCFGOff', 'Prietaiso užrakinimas uždraustas', 7, NULL, 1068, 1, NULL),
	(11667, 'R1OutOfL', 'Iėjimo R1 reikšmė išėjo už ribų', 26, NULL, 1069, 1, NULL),
	(11668, 'R2OutOfL', 'Iėjimo R2 reikšmė išėjo už ribų', 26, NULL, 1070, 1, NULL),
	(11669, 'R3OutOfL', 'Iėjimo R3 reikšmė išėjo už ribų', 26, NULL, 1071, 1, NULL),
	(11670, 'R4OutOfL', 'Iėjimo R4 reikšmė išėjo už ribų', 26, NULL, 1072, 1, NULL),
	(11671, 'R1Disconn', 'Atsijungė R1', 11, NULL, 1073, 1, NULL),
	(11672, 'R2Disconn', 'Atsijungė R2', 11, NULL, 1074, 1, NULL),
	(11673, 'R3Disconn', 'Atsijungė R3', 11, NULL, 1075, 1, NULL),
	(11674, 'CollectiveAlarm_B', 'Pasikeitė statusas B aliarmo grupėje', 11, NULL, 1076, 1, NULL),
	(11675, 'CollectiveAlarm_A', 'Pasikeitė statusas A aliarmo grupėje', 11, NULL, 1077, 1, NULL),
	(11676, 'DigitalInputS4', 'Pasikeitė iėjimo S4 būsena', 11, NULL, 1078, 1, NULL),
	(11677, 'DigitalInputS5', 'Pasikeitė iėjimo S5 būsena', 11, NULL, 1079, 1, NULL),
	(11678, 'DigitalInputS6', 'Pasikeitė iėjimo S6 būsena', 11, NULL, 1080, 1, NULL),
	(11679, 'DigitalInputS7', 'Pasikeitė iėjimo S7 būsena', 11, NULL, 1081, 1, NULL),
	(11680, 'DigitalInputS8', 'Pasikeitė iėjimo S8 būsena', 11, NULL, 1082, 1, NULL),
	(11681, 'dEhOutOfL1', 'Parametras dEh limitą l dEh 1', 26, NULL, 1083, 1, NULL),
	(11682, 'dEhOutOfL2', 'Parametras dEh limitą l dEh 2', 26, NULL, 1084, 1, NULL),
	(11683, 'dEhOutOfL3', 'Parametras dEh limitą l dEh 3', 26, NULL, 1085, 1, NULL),
	(11684, 'SystemTest', 'Sistemos įvykis', 11, NULL, 1086, 1, NULL),
	(11685, 'ephOutOfL1', 'Parametras eph limitą l eph1', 26, NULL, 1087, 1, NULL),
	(11686, 'ephOutOfL2', 'Parametras eph limitą l eph2', 26, NULL, 1088, 1, NULL),
	(11687, 'AlarmsBlockade', 'Signalizacijos atminies užimtumas viršija 90%. ', 26, NULL, 1089, 1, NULL),
	(11688, 'AlarmsClear', 'Signalizacijos atminies užimtumas viršija 50%. ', 26, NULL, 1090, 1, NULL),
	(11689, 'tambOutOfR', 'Aplinkos temperatūra intervalo ribas nuo tamb min iki tamb max', 26, NULL, 1091, 1, NULL),
	(11690, 'dp_p_exceeded', 'Primtinas dp/p santykis', 26, NULL, 1092, 1, NULL),
	(11691, 'dp_exceeded', 'Parametras dp diapazoną  3.95 ÷ 20.2 mA', 26, NULL, 1093, 1, NULL),
	(11692, 'p_Exceeded', 'Signalizacija suveiks kai p viršys diapazoną  3.95 ÷ 20.2 mA', 26, NULL, 1094, 1, NULL),
	(11693, 't_Exceeded', 'Signalizacija suveiks kai t viršys diapazoną  3.95 ÷ 20.2 mA', 26, NULL, 1095, 1, NULL),
	(11694, 'rez1_Exceeded', 'Signalizacija suveiks kai rez1  viršys diapazoną 3.95 ÷ 20.2 mA', 26, NULL, 1096, 1, NULL),
	(11695, 'rez2_Exceeded', 'Signalizacija suveiks kai rez2 viršys diapazoną  3.95 ÷ 20.2 mA', 26, NULL, 1097, 1, NULL),
	(11696, 'dp_LimitExceeded', 'Slėgio skirtumo dp reikšmė limitą', 26, NULL, 1098, 1, NULL),
	(11697, 'rez1_LimitExceeded', 'Parametras rez1 limitą', 26, NULL, 1099, 1, NULL),
	(11698, 'rez2_LimitExceeded', 'Parametras rez2 limitą', 26, NULL, 1100, 1, NULL),
	(11699, 'Re_Exceedance', 'Reinoldso skaičius', 26, NULL, 1101, 1, NULL),
	(11700, 'Error_dp_diff', 'Keitiklių poros slėgio skirtumas  limitus e dpL arba e dpH', 26, NULL, 1102, 1, NULL),
	(11701, 'GrossError_dp', 'Keitiklių poros slėgio skirtumas 5%', 26, NULL, 1103, 1, NULL),
	(11702, 'Error_HF2_HF3', 'Impulsų įėjimai HF2 ir HF3 impulsų skaičius toleranciją', 26, NULL, 1104, 1, NULL),
	(11703, 'ManualDeactivation', 'Kompiūteris išjungtas klaviatūros pagalba', 7, NULL, 1105, 1, NULL),
	(11704, 'MeasurementCheck', 'Algoritmas ar matavimo kanalų tikrinimo moda', 8, NULL, 1106, 1, NULL),
	(11705, 'Exceed_fmax_OfOdorizer', 'Maksimalus dažnis leistino', 26, NULL, 1107, 1, NULL),
	(11706, 'SubstGasValues', 'Pakaitinis dujų sudėties skaičiavimas', 8, NULL, 1108, 1, NULL),
	(11707, 'BatteryTest', 'Atliekamas baterijos testas', 8, NULL, 1109, 1, NULL),
	(11708, 'BatteryCharging', 'Baterija kraunama iš srauto kompjūterio', 8, NULL, 1110, 1, NULL),
	(11709, 'UPS_Discharged', 'UPS išsikrovęs', 26, NULL, 1111, 1, NULL),
	(11710, 'T_BatteryExceedsRange', 'Lauko temperatūra priimtino įkrovimo diapazono', 26, NULL, 1112, 1, NULL),
	(11711, 'ChargerDamaged', 'Ryšys su baterijos  moduliu', 9, NULL, 1113, 1, NULL),
	(11712, 'BatteryConditioning', 'Baterijos patikra atlikta', 8, NULL, 1114, 1, NULL),
	(11713, 'S6_1_Signalling', 'S6-1 signalo aktyvumo', 11, NULL, 1115, 1, NULL),
	(11714, 'S6_2_Signalling', 'S6-2 signalo aktyvumo', 11, NULL, 1116, 1, NULL),
	(11715, 'S6_3_Signalling', 'S6-3 signalo aktyvumo', 11, NULL, 1117, 1, NULL),
	(11716, 'S6_4_Signalling', 'S6-4 signalo aktyvumo', 11, NULL, 1118, 1, NULL),
	(11717, 'S6_5_Signalling', 'S6-5 signalo aktyvumo', 11, NULL, 1119, 1, NULL),
	(11718, 'S6_6_Signalling', 'S6-6 signalo aktyvumo', 11, NULL, 1120, 1, NULL),
	(11719, 'SN4_1_Signalling', 'SN4-1 signalo aktyvumo', 11, NULL, 1121, 1, NULL),
	(11720, 'SN4_2_Signalling', 'SN4-2 signalo aktyvumo', 11, NULL, 1122, 1, NULL),
	(11721, 'SN4_3_Signalling', 'SN4-3 signalo aktyvumo', 11, NULL, 1123, 1, NULL),
	(11722, 'SN4_4_Signalling', 'SN4-4 signalo aktyvumo', 11, NULL, 1124, 1, NULL),
	(11723, 'SN4_N_Signalling', 'SN4-N signalo aktyvumo', 11, NULL, 1125, 1, NULL),
	(11724, 'Signalling', 'Signalų aktyvumo', 11, NULL, 1126, 1, NULL),
	(11725, 'SN6_1_Signalling', 'SN6-1 signalo aktyvumo', 11, NULL, 1127, 1, NULL),
	(11726, 'SN6_2_Signalling', 'SN6-2 signalo aktyvumo', 11, NULL, 1128, 1, NULL),
	(11727, 'SN6_3_Signalling', 'SN6-3 signalo aktyvumo', 11, NULL, 1129, 1, NULL),
	(11728, 'SN6_4_Signalling', 'SN6-4 signalo aktyvumo', 11, NULL, 1130, 1, NULL),
	(11729, 'SN6_5_Signalling', 'SN6-5 signalo aktyvumo', 11, NULL, 1131, 1, NULL),
	(11730, 'SN6_6_Signalling', 'SN6-6 signalo aktyvumo', 11, NULL, 1132, 1, NULL),
	(11731, 'SO_1_Signalling', 'SO-1 signalo aktyvumo', 11, NULL, 1133, 1, NULL),
	(11732, 'SO_2_Signalling', 'SO-2 signalo aktyvumo', 11, NULL, 1134, 1, NULL),
	(11733, 'SO_3_Signalling', 'SO-3 signalo aktyvumo', 11, NULL, 1135, 1, NULL),
	(11734, 'SO_4_Signalling', 'SO-4 signalo aktyvumo', 11, NULL, 1136, 1, NULL),
	(11735, 'SO_5_Signalling', 'SO-5 signalo aktyvumo', 11, NULL, 1137, 1, NULL),
	(11736, 'SO_6_Signalling', 'SO-6 signalo aktyvumo', 11, NULL, 1138, 1, NULL),
	(11737, 'Board_1_Damaged', 'Ryšys su modulių nr 1', 9, NULL, 1139, 1, NULL),
	(11738, 'Board_2_Damaged', 'Ryšys su modulių nr 2', 9, NULL, 1140, 1, NULL),
	(11739, 'Board_3_Damaged', 'Ryšys su modulių nr 3', 9, NULL, 1141, 1, NULL),
	(11740, 'Board_4_Damaged', 'Ryšys su modulių nr 4', 9, NULL, 1142, 1, NULL),
	(11741, 'Board_5_Damaged', 'Ryšys su modulių nr 5', 9, NULL, 1143, 1, NULL),
	(11742, 'Totalizer_Cycled', 'Sumatoriaus reikšmė maksimalią reikšmę', 26, NULL, 1144, 1, NULL),
	(11743, 'Correction', 'Korekcijos klaida', 9, NULL, 1145, 1, NULL),
	(11744, 't_otoc_Exceeded', 'Vidaus temperatūra pasiekė primtiną reikšmę', 26, NULL, 1146, 1, NULL),
	(11745, 'CollectiveAlarm1', 'Aliarmas 1 ', 11, NULL, 1147, 1, NULL),
	(11746, 'CollectiveAlarm2', 'Aliarmas 2', 11, NULL, 1148, 1, NULL),
	(11747, 'CollectiveAlarm3', 'Aliarmas 3', 11, NULL, 1149, 1, NULL),
	(11748, 'CollectiveAlarm4', 'Aliarmas 4 ', 11, NULL, 1150, 1, NULL),
	(11749, 'rez3_Exceeded', 'Patrametras rez3 intervalą 3.95 ÷ 20.2 mA', 26, NULL, 1151, 1, NULL),
	(11750, 'rez3_LimitExceed', 'Parametras rez3 limitą', 26, NULL, 1152, 1, NULL),
	(11751, 'rezU1_Exceeded', 'Įtampa rezU1 intervalą  -1 ÷ 0 V arba -2 ÷ 0 V', 26, NULL, 1153, 1, NULL),
	(11752, 'rezU1_LimitExceeded', 'Parametras rezU1 limitą', 26, NULL, 1154, 1, NULL),
	(11753, 'p1w_Exceeded', 'Parametras p1w limitą ', 26, NULL, 1155, 1, NULL),
	(11754, 'AliarmConfirmation', 'Aliarmų patvirtinimas', 7, NULL, 1156, 1, NULL),
	(11755, 'DivisionByZero', 'Dalybos iš nulio', 9, NULL, 1157, 1, NULL),
	(11756, 'LossInternalCommunication', 'Ryšio tarp procesoriaus ir analoginės dalies', 9, NULL, 1158, 1, NULL);
/*!40000 ALTER TABLE `withe` ENABLE KEYS */;

-- Dumping structure for table emcor.witheset
CREATE TABLE IF NOT EXISTS `witheset` (
  `witheset_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Duomenų vytelių rinkinio identifikatorius',
  `witheset_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų vytelių rinkinio kodas',
  `witheset_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų vytelių rinkinio pavadinimas',
  `src_type_id` int(10) DEFAULT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `witheset_journal` tinyint(1) NOT NULL COMMENT 'Duomenu vyteliu rinkinis yra žurnalas',
  PRIMARY KEY (`witheset_id`),
  UNIQUE KEY `witheset_code_u` (`witheset_code`),
  KEY `witheset_src_type_i` (`src_type_id`),
  CONSTRAINT `witheset_src_type_fk` FOREIGN KEY (`src_type_id`) REFERENCES `src_type` (`src_type_id`) ON DELETE CASCADE,
  CONSTRAINT `WITHESET_JOURNAL_01` CHECK (`witheset_journal` in (0,1))
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų vytelių rinkiniai';

-- Dumping data for table emcor.witheset: ~0 rows (approximately)
/*!40000 ALTER TABLE `witheset` DISABLE KEYS */;
/*!40000 ALTER TABLE `witheset` ENABLE KEYS */;

-- Dumping structure for table emcor.witheset_data
CREATE TABLE IF NOT EXISTS `witheset_data` (
  `witheset_id` int(10) unsigned NOT NULL COMMENT 'Duomenų vytelių rinkinio identifikatorius',
  `withe_id` mediumint(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
  PRIMARY KEY (`witheset_id`,`withe_id`),
  KEY `witheset_data_withe_fk` (`withe_id`),
  CONSTRAINT `witheset_data_withe_fk` FOREIGN KEY (`withe_id`) REFERENCES `withe` (`withe_id`) ON DELETE CASCADE,
  CONSTRAINT `witheset_data_witheset_fk` FOREIGN KEY (`witheset_id`) REFERENCES `witheset` (`witheset_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Duomenų vytelių rinkinių sudėtis';

-- Dumping data for table emcor.witheset_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `witheset_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `witheset_data` ENABLE KEYS */;

-- Dumping structure for table emcor.withe_class
CREATE TABLE IF NOT EXISTS `withe_class` (
  `withe_class_id` tinyint(3) unsigned NOT NULL COMMENT 'Duomenų vytelių klasės identifikatorius',
  `withe_class_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų vytelių klasės kodas',
  `withe_class_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų vytelių klasės pavadinimas',
  PRIMARY KEY (`withe_class_id`),
  UNIQUE KEY `withe_class_code_u` (`withe_class_code`),
  UNIQUE KEY `withe_class_name_u` (`withe_class_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų vytelių klasės';

-- Dumping data for table emcor.withe_class: ~3 rows (approximately)
/*!40000 ALTER TABLE `withe_class` DISABLE KEYS */;
INSERT INTO `withe_class` (`withe_class_id`, `withe_class_code`, `withe_class_name`) VALUES
	(1, 'EVENT_LOG', 'Įvykiai ir būsenos'),
	(2, 'COUNTERS', 'Skaitmačiai ir laikmačiai'),
	(3, 'CONFIGURATION', 'Konfigūracija');
/*!40000 ALTER TABLE `withe_class` ENABLE KEYS */;

-- Dumping structure for table emcor.withe_dtype
CREATE TABLE IF NOT EXISTS `withe_dtype` (
  `withe_dtype_id` tinyint(3) unsigned NOT NULL COMMENT 'Duomenų vytelių duomenų tipo identifikatorius',
  `withe_dtype_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų vytelių duomenų tipo kodas',
  `withe_dtype_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų vytelių duomenų tipo pavadinimas',
  PRIMARY KEY (`withe_dtype_id`),
  UNIQUE KEY `withe_dtype_code_u` (`withe_dtype_code`),
  UNIQUE KEY `withe_dtype_name_u` (`withe_dtype_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų vytelių duomenų tipai';

-- Dumping data for table emcor.withe_dtype: ~6 rows (approximately)
/*!40000 ALTER TABLE `withe_dtype` DISABLE KEYS */;
INSERT INTO `withe_dtype` (`withe_dtype_id`, `withe_dtype_code`, `withe_dtype_name`) VALUES
	(1, 'EVENT', 'Įvykiai'),
	(3, 'COUNTER', 'Skaitmačiai'),
	(4, 'DURATION_COUNTER', 'Laikmačiai'),
	(5, 'SETTING', 'Parametrai'),
	(6, 'COMMAND', 'Komandos'),
	(7, 'TIME', 'Laikas');
/*!40000 ALTER TABLE `withe_dtype` ENABLE KEYS */;

-- Dumping structure for table emcor.withe_type
CREATE TABLE IF NOT EXISTS `withe_type` (
  `withe_type_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų vytelių tipo identifikatorius',
  `withe_type_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų vytelių tipo kodas',
  `withe_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Duomenų vytelių tipo pavadinimas',
  `withe_class_id` tinyint(3) unsigned NOT NULL COMMENT 'Duomenų vytelių klasės identifikatorius',
  PRIMARY KEY (`withe_type_id`),
  UNIQUE KEY `withe_type_code_u` (`withe_type_code`),
  UNIQUE KEY `withe_type_name_u` (`withe_type_name`),
  KEY `withe_type_withe_class_i` (`withe_class_id`),
  CONSTRAINT `withe_type_withe_class_fk` FOREIGN KEY (`withe_class_id`) REFERENCES `withe_class` (`withe_class_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Duomenų vytelių tipai';

-- Dumping data for table emcor.withe_type: ~28 rows (approximately)
/*!40000 ALTER TABLE `withe_type` DISABLE KEYS */;
INSERT INTO `withe_type` (`withe_type_id`, `withe_type_code`, `withe_type_name`, `withe_class_id`) VALUES
	(1, 'EXTERNAL_IMPACT', 'Aptiktas išorinis poveikis', 1),
	(2, 'PHASE_LOSS', 'Fazių pasikeitimai', 1),
	(3, 'ON_OFF', 'Įjungimai, išjungimai, perkrovimai', 1),
	(4, 'TIME_ADJUSTMENT', 'Laiko korekcija', 1),
	(5, 'EXCEEDING_LIMITS', 'Limitų viršijimas', 1),
	(6, 'POWER_CUT', 'Maitinimo dingimai', 1),
	(7, 'CONFIGURATION_CHANGE', 'Nustatymų keitimas', 1),
	(8, 'DEVICE_OPERATION', 'Äåéńņāč˙, āūļīėķ˙åģūå óńņšīéńņāīģ ąāņīģąņč÷åńźč', 1),
	(9, 'FAULT', 'Sutrikimai', 1),
	(10, 'TIME_READ', 'Nuskaitytas laikas', 3),
	(11, 'MINOR', 'Antraeiliai įvykiai', 1),
	(12, 'TIME_SET', 'Nustatytas laikas', 1),
	(13, 'RELAY', 'Šåėå', 1),
	(14, 'RESET', 'Ńįšīń', 1),
	(15, 'TIME', 'Ļąšąģåņšū ÷ąńīā č āšåģåķč', 3),
	(16, 'BILLING', 'Ļąšąģåņšū ļåščīäą ó÷åņą', 3),
	(17, 'TARIFF', 'Ļąšąģåņšū ńčńņåģū ņąščōčźąöčč', 3),
	(18, 'RELAY_PARAM', 'Ļąšąģåņšū šåėå', 3),
	(19, 'COEF', 'Źīżōōčöčåķņū', 3),
	(20, 'LCD', 'Ļąšąģåņšū żźšąķą', 3),
	(21, 'SERVICE', 'Ļąšąģåņšū ńåšāčńķīćī šåęčģą', 3),
	(22, 'COMMUNICATION', 'Ļąšąģåņšū č šåęčģū źīģģóķčźąöčč', 3),
	(23, 'CALCULATION', 'Ļąšąģåņšū šąń÷øņīā ā óńņšīéńņāå', 3),
	(24, 'GENERAL_PARAMETER', 'Ļąšąģåņšū óńņšīéńņāą č ļīäźėž÷åķč˙', 3),
	(25, 'SECURITY', 'Ļąšąģåņšū įåēīļąńķīńņč', 3),
	(26, 'LIMITS', 'Ėčģčņū', 3),
	(27, 'UNCLASSIFIED', 'Ķå źėąńńčōčöčšīāąķķūå ļąšąģåņšū', 3),
	(28, 'FIRMWARE_UPDATE', 'Vidinės PĮ (firmware) naujinimas', 1);
/*!40000 ALTER TABLE `withe_type` ENABLE KEYS */;

-- Dumping structure for table emcor.wpr
CREATE TABLE IF NOT EXISTS `wpr` (
  `wpr_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Tarifų plano savaitės programos identifikatorius',
  `wpr_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Tarifų plano savaitės programos pavadinimas',
  PRIMARY KEY (`wpr_id`),
  UNIQUE KEY `wpr_name_u` (`wpr_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Tarifų plano savaitės programos';

-- Dumping data for table emcor.wpr: ~0 rows (approximately)
/*!40000 ALTER TABLE `wpr` DISABLE KEYS */;
/*!40000 ALTER TABLE `wpr` ENABLE KEYS */;

-- Dumping structure for table emcor.wpr_data
CREATE TABLE IF NOT EXISTS `wpr_data` (
  `wpr_id` mediumint(8) unsigned NOT NULL COMMENT 'Tarifų plano savaitės programos identifikatorius',
  `wd` tinyint(3) unsigned NOT NULL COMMENT 'Savaitės dienos numeris',
  `dpr_id` mediumint(8) unsigned NOT NULL COMMENT 'Tarifų plano dienų programos identifikatorius',
  PRIMARY KEY (`wpr_id`,`wd`),
  KEY `wpr_dpr_i` (`dpr_id`),
  CONSTRAINT `wpr_data_dpr_fk` FOREIGN KEY (`dpr_id`) REFERENCES `dpr` (`dpr_id`),
  CONSTRAINT `wpr_data_wpr_fk` FOREIGN KEY (`wpr_id`) REFERENCES `wpr` (`wpr_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Tarifų plano savaitės programos duomenys';

-- Dumping data for table emcor.wpr_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `wpr_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `wpr_data` ENABLE KEYS */;

-- Dumping structure for table emcor.xa
CREATE TABLE IF NOT EXISTS `xa` (
  `xa_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Apsikeitimo duomenimis adresato identifikatorius',
  `xa_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Apsikeitimo duomenimis adresato pavadinimas',
  `xa_enabled` tinyint(1) NOT NULL COMMENT 'Apsikeitimo duomenimis adresato naudojimo požymis',
  PRIMARY KEY (`xa_id`),
  UNIQUE KEY `xa_name_u` (`xa_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apsikeitimo duomenimis adresatai';

-- Dumping data for table emcor.xa: ~0 rows (approximately)
/*!40000 ALTER TABLE `xa` DISABLE KEYS */;
/*!40000 ALTER TABLE `xa` ENABLE KEYS */;

-- Dumping structure for table emcor.xa_das
CREATE TABLE IF NOT EXISTS `xa_das` (
  `xa_id` int(10) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis adresato identifikatorius',
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  `atom_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Atomo naudojimo požymis',
  `atom_activated` datetime NOT NULL DEFAULT '1899-12-30 00:00:00' COMMENT 'Atomo paskutinio aktyvavimo data',
  PRIMARY KEY (`xa_id`),
  KEY `xa_das_das_fk` (`das_id`),
  CONSTRAINT `xa_das_das_fk` FOREIGN KEY (`das_id`) REFERENCES `das` (`das_id`) ON DELETE CASCADE,
  CONSTRAINT `xa_das_xa_fk` FOREIGN KEY (`xa_id`) REFERENCES `xa` (`xa_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apsikeitimo duomenimis adresatų automatinis priskyrimas duomenų surinkimo serveriams';

-- Dumping data for table emcor.xa_das: ~0 rows (approximately)
/*!40000 ALTER TABLE `xa_das` DISABLE KEYS */;
/*!40000 ALTER TABLE `xa_das` ENABLE KEYS */;

-- Dumping structure for table emcor.xa_das_frc
CREATE TABLE IF NOT EXISTS `xa_das_frc` (
  `xa_id` int(10) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis adresato identifikatorius',
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  PRIMARY KEY (`xa_id`,`das_id`),
  KEY `xa_das_frc_das_fk` (`das_id`),
  CONSTRAINT `xa_das_frc_das_fk` FOREIGN KEY (`das_id`) REFERENCES `das` (`das_id`) ON DELETE CASCADE,
  CONSTRAINT `xa_das_frc_xa_fk` FOREIGN KEY (`xa_id`) REFERENCES `xa` (`xa_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apsikeitimo duomenimis adresatų priverstinis priskyrimas duomenų surinkimo serveriams';

-- Dumping data for table emcor.xa_das_frc: ~0 rows (approximately)
/*!40000 ALTER TABLE `xa_das_frc` DISABLE KEYS */;
/*!40000 ALTER TABLE `xa_das_frc` ENABLE KEYS */;

-- Dumping structure for table emcor.xa_das_log
CREATE TABLE IF NOT EXISTS `xa_das_log` (
  `db_time` datetime NOT NULL DEFAULT current_timestamp() COMMENT 'Registravimo duomenų bazėje laikas',
  `atom_log_id` mediumint(8) unsigned NOT NULL COMMENT 'Atomų priskyrimo duomenų surinkimo serveriams istorijos įrašo ID',
  `xa_id` int(10) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis adresato identifikatorius',
  `das_id` smallint(5) unsigned NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  `atom_enabled` tinyint(1) NOT NULL COMMENT 'Atomo naudojimo požymis',
  `atom_activated` datetime NOT NULL COMMENT 'Atomo paskutinio aktyvavimo data',
  PRIMARY KEY (`db_time`,`atom_log_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apsikeitimo duomenimis adresatų automatinio priskyrimo duomenų surinkimo serveriams istorija';

-- Dumping data for table emcor.xa_das_log: ~0 rows (approximately)
/*!40000 ALTER TABLE `xa_das_log` DISABLE KEYS */;
/*!40000 ALTER TABLE `xa_das_log` ENABLE KEYS */;

-- Dumping structure for table emcor.xa_rpty
CREATE TABLE IF NOT EXISTS `xa_rpty` (
  `xa_id` int(10) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis adresato identifikatorius',
  `rpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo savybės identifikatorius',
  `rpty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Automatizuotos ataskaitos savybės reikšmė',
  PRIMARY KEY (`xa_id`,`rpty_id`),
  KEY `xa_rpty_rpty_i` (`rpty_id`),
  CONSTRAINT `xa_rpty_rpty_fk` FOREIGN KEY (`rpty_id`) REFERENCES `rpty` (`rpty_id`),
  CONSTRAINT `xa_rpty_xa_fk` FOREIGN KEY (`xa_id`) REFERENCES `xa` (`xa_id`) ON DELETE CASCADE,
  CONSTRAINT `XA_RPTY_SYMBOL_CHECK` CHECK (nullif(regexp_replace(`rpty_value`,'([[:print:]])+',''),'') is null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apsikeitimo duomenimis adresato protokolų savybės';

-- Dumping data for table emcor.xa_rpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `xa_rpty` DISABLE KEYS */;
/*!40000 ALTER TABLE `xa_rpty` ENABLE KEYS */;

-- Dumping structure for table emcor.xdata
CREATE TABLE IF NOT EXISTS `xdata` (
  `id1` bigint(20) unsigned DEFAULT NULL,
  `id2` bigint(20) unsigned DEFAULT NULL,
  `id3` bigint(20) unsigned DEFAULT NULL,
  `id4` bigint(20) unsigned DEFAULT NULL,
  `id5` bigint(20) unsigned DEFAULT NULL,
  `id6` bigint(20) unsigned DEFAULT NULL,
  `id7` bigint(20) unsigned DEFAULT NULL,
  `id8` bigint(20) unsigned DEFAULT NULL,
  `id9` bigint(20) unsigned DEFAULT NULL,
  `id0` bigint(20) unsigned DEFAULT NULL,
  `v1` double DEFAULT NULL,
  `v2` double DEFAULT NULL,
  `v3` double DEFAULT NULL,
  `v4` double DEFAULT NULL,
  `v5` double DEFAULT NULL,
  `v6` double DEFAULT NULL,
  `v7` double DEFAULT NULL,
  `v8` double DEFAULT NULL,
  `v9` double DEFAULT NULL,
  `v0` double DEFAULT NULL,
  `d1` datetime DEFAULT NULL,
  `d2` datetime DEFAULT NULL,
  `d3` datetime DEFAULT NULL,
  `d4` datetime DEFAULT NULL,
  `d5` datetime DEFAULT NULL,
  `d6` datetime DEFAULT NULL,
  `d7` datetime DEFAULT NULL,
  `d8` datetime DEFAULT NULL,
  `d9` datetime DEFAULT NULL,
  `d0` datetime DEFAULT NULL,
  `c1` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c2` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c3` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c4` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c5` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c6` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c7` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c8` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c9` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c0` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c10` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c11` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c12` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c13` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c14` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c15` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c16` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c17` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c18` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c19` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `c20` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `xo_id` bigint(20) unsigned DEFAULT NULL,
  `db_time` datetime DEFAULT NULL COMMENT 'Registravimo duomenų bazėje laikas',
  `t1` datetime(3) DEFAULT NULL,
  `t2` datetime(3) DEFAULT NULL,
  `t3` datetime(3) DEFAULT NULL,
  `cbig` varchar(2000) COLLATE utf8_bin DEFAULT NULL,
  KEY `xdata_xo_i` (`xo_id`),
  CONSTRAINT `xdata_xo_fk` FOREIGN KEY (`xo_id`) REFERENCES `xo` (`xo_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Tarpinė eksporto formų duomenų informacija';

-- Dumping data for table emcor.xdata: ~0 rows (approximately)
/*!40000 ALTER TABLE `xdata` DISABLE KEYS */;
/*!40000 ALTER TABLE `xdata` ENABLE KEYS */;

-- Dumping structure for table emcor.xe
CREATE TABLE IF NOT EXISTS `xe` (
  `xe_id` int(10) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis elemento identifikatorius',
  `xe_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Apsikeitimo duomenimis elemento kodas',
  `xe_name` varchar(250) COLLATE utf8_bin NOT NULL COMMENT 'Apsikeitimo duomenimis elemento pavadinimas',
  `xe_code2` varchar(40) COLLATE utf8_bin DEFAULT NULL COMMENT 'Apsikeitimo duomenimis elemento antras kodas',
  `xe_name2` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Apsikeitimo duomenimis elemento antras pavadinimas',
  PRIMARY KEY (`xe_id`),
  UNIQUE KEY `xe_name_u` (`xe_name`),
  KEY `xe_code_i` (`xe_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apsikeitimo duomenimis elementai';

-- Dumping data for table emcor.xe: ~178 rows (approximately)
/*!40000 ALTER TABLE `xe` DISABLE KEYS */;
INSERT INTO `xe` (`xe_id`, `xe_code`, `xe_name`, `xe_code2`, `xe_name2`) VALUES
	(1, '01', 'A+ akt.gauta', '01', 'A+ akt.gauta'),
	(2, '02', 'A- akt.atiduota', '02', 'A- akt.atiduota'),
	(3, '03', 'R+ reakt.gauta', '03', 'R+ reakt.gauta'),
	(4, '04', 'R- reakt.atiduota', '04', 'R- reakt.atiduota'),
	(11, '11', 'A+ akt.gauta(11)', '11', 'A+ akt.gauta'),
	(12, '12', 'A- akt.atiduota(12)', '12', 'A- akt.atiduota'),
	(13, '13', 'R+ reakt.gauta(13)', '13', 'R+ reakt.gauta'),
	(14, '14', 'R- reakt.atiduota(14)', '14', 'R- reakt.atiduota'),
	(15, '01', 'Slodzes profils A+', '01', 'Slodzes profils A+'),
	(16, '02', 'Slodzes profils A-', '02', 'Slodzes profils A-'),
	(17, '03', 'Slodzes profils R+', '03', 'Slodzes profils R+'),
	(18, '04', 'Slodzes profils R-', '04', 'Slodzes profils R-'),
	(19, '050', 'ARGE_K_050', NULL, NULL),
	(20, '051', 'ARGE_K_051', NULL, NULL),
	(21, '052', 'ARGE_K_052', NULL, NULL),
	(22, '053', 'ARGE_K_053', NULL, NULL),
	(23, '054', 'ARGE_K_054', NULL, NULL),
	(24, '055', 'ARGE_K_055', NULL, NULL),
	(25, '056', 'ARGE_K_056', NULL, NULL),
	(26, '057', 'ARGE_K_057', NULL, NULL),
	(27, '058', 'ARGE_K_058', NULL, NULL),
	(28, '059', 'ARGE_K_059', NULL, NULL),
	(29, '060', 'ARGE_K_060', NULL, NULL),
	(30, '061', 'ARGE_K_061', NULL, NULL),
	(31, '062', 'ARGE_K_062', NULL, NULL),
	(32, '063', 'ARGE_K_063', NULL, NULL),
	(33, '064', 'ARGE_K_064', NULL, NULL),
	(34, '065', 'ARGE_K_065', NULL, NULL),
	(35, '066', 'ARGE_K_066', NULL, NULL),
	(36, '067', 'ARGE_K_067', NULL, NULL),
	(37, '068', 'ARGE_K_068', NULL, NULL),
	(38, '069', 'ARGE_K_069', NULL, NULL),
	(39, '070', 'ARGE_K_070', NULL, NULL),
	(40, '200', 'ARGE_K_200', NULL, NULL),
	(41, '201', 'ARGE_K_201', NULL, NULL),
	(42, '202', 'ARGE_K_202', NULL, NULL),
	(43, '203', 'ARGE_K_203', NULL, NULL),
	(44, '220', 'ARGE_K_220', NULL, NULL),
	(45, '221', 'ARGE_K_221', NULL, NULL),
	(46, '222', 'ARGE_K_222', NULL, NULL),
	(47, '223', 'ARGE_K_223', NULL, NULL),
	(48, '224', 'ARGE_K_224', NULL, NULL),
	(49, '225', 'ARGE_K_225', NULL, NULL),
	(50, '226', 'ARGE_K_226', NULL, NULL),
	(51, '227', 'ARGE_K_227', NULL, NULL),
	(52, '228', 'ARGE_K_228', NULL, NULL),
	(53, '229', 'ARGE_K_229', NULL, NULL),
	(54, '230', 'ARGE_K_230', NULL, NULL),
	(55, '231', 'ARGE_K_231', NULL, NULL),
	(56, '232', 'ARGE_K_232', NULL, NULL),
	(57, '233', 'ARGE_K_233', NULL, NULL),
	(58, '234', 'ARGE_K_234', NULL, NULL),
	(59, '235', 'ARGE_K_235', NULL, NULL),
	(60, '236', 'ARGE_K_236', NULL, NULL),
	(61, '237', 'ARGE_K_237', NULL, NULL),
	(62, '238', 'ARGE_K_238', NULL, NULL),
	(63, '239', 'ARGE_K_239', NULL, NULL),
	(64, '240', 'ARGE_K_240', NULL, NULL),
	(65, '241', 'ARGE_K_241', NULL, NULL),
	(66, '242', 'ARGE_K_242', NULL, NULL),
	(67, '243', 'ARGE_K_243', NULL, NULL),
	(68, '244', 'ARGE_K_244', NULL, NULL),
	(69, '250', 'ARGE_K_250', NULL, NULL),
	(70, '251', 'ARGE_K_251', NULL, NULL),
	(71, '252', 'ARGE_K_252', NULL, NULL),
	(72, '253', 'ARGE_K_253', NULL, NULL),
	(73, '254', 'ARGE_K_254', NULL, NULL),
	(74, '255', 'ARGE_K_255', NULL, NULL),
	(75, '256', 'ARGE_K_256', NULL, NULL),
	(76, '257', 'ARGE_K_257', NULL, NULL),
	(77, '258', 'ARGE_K_258', NULL, NULL),
	(78, '259', 'ARGE_K_259', NULL, NULL),
	(79, '260', 'ARGE_K_260', NULL, NULL),
	(80, '300', 'ARGE_K_300', NULL, NULL),
	(81, '301', 'ARGE_K_301', NULL, NULL),
	(82, '302', 'ARGE_K_302', NULL, NULL),
	(83, '303', 'ARGE_K_303', NULL, NULL),
	(84, '304', 'ARGE_K_304', NULL, NULL),
	(85, '1', 'Aktiiv + h', NULL, NULL),
	(86, '2', 'Reaktiiv + h', NULL, NULL),
	(87, '3', 'Reaktiiv - h', NULL, NULL),
	(90, '128', 'A+ delta 60', NULL, NULL),
	(91, '126', 'R+ delta 60', NULL, NULL),
	(92, '125', 'R- delta 60', NULL, NULL),
	(93, 'W1', 'Šilumos sistemos energija W1', 'W1', 'Šilumos sistemos energija W1'),
	(94, 'W2', 'Šilumos sistemos energija W2', 'W2', 'Šilumos sistemos energija W2'),
	(95, 'W3', 'Šilumos sistemos energija W3', 'W3', 'Šilumos sistemos energija W3'),
	(96, 'W4', 'Šilumos sistemos energija W4', 'W4', 'Šilumos sistemos energija W4'),
	(97, 'W5', 'Šilumos sistemos energija W5', 'W5', 'Šilumos sistemos energija W5'),
	(98, 'W6', 'Šilumos sistemos energija W6', 'W6', 'Šilumos sistemos energija W6'),
	(99, 'W7', 'Šilumos sistemos energija W7', 'W7', 'Šilumos sistemos energija W7'),
	(100, 'W8', 'Šilumos sistemos energija W8', 'W8', 'Šilumos sistemos energija W8'),
	(101, 'W9', 'Šilumos sistemos energija W9', 'W9', 'Šilumos sistemos energija W9'),
	(102, 'W10', 'Šilumos sistemos energija W10', 'W10', 'Šilumos sistemos energija W10'),
	(103, 'W11', 'Šilumos sistemos energija W11', 'W11', 'Šilumos sistemos energija W11'),
	(104, 'W12', 'Šilumos sistemos energija W12', 'W12', 'Šilumos sistemos energija W12'),
	(105, 'T1', 'Šilumnešio temperatūra T1', 'T1', 'Šilumnešio temperatūra T1'),
	(106, 'T2', 'Šilumnešio temperatūra T2', 'T2', 'Šilumnešio temperatūra T2'),
	(107, 'T3', 'Šilumnešio temperatūra T3', 'T3', 'Šilumnešio temperatūra T3'),
	(108, 'T4', 'Šilumnešio temperatūra T4', 'T4', 'Šilumnešio temperatūra T4'),
	(109, 'T5', 'Šilumnešio temperatūra T5', 'T5', 'Šilumnešio temperatūra T5'),
	(110, 'T6', 'Šilumnešio temperatūra T6', 'T6', 'Šilumnešio temperatūra T6'),
	(111, 'T7', 'Šilumnešio temperatūra T7', 'T7', 'Šilumnešio temperatūra T7'),
	(112, 'T8', 'Šilumnešio temperatūra T8', 'T8', 'Šilumnešio temperatūra T8'),
	(113, 'T9', 'Šilumnešio temperatūra T9', 'T9', 'Šilumnešio temperatūra T9'),
	(114, 'T10', 'Šilumnešio temperatūra T10', 'T10', 'Šilumnešio temperatūra T10'),
	(115, 'T11', 'Šilumnešio temperatūra T11', 'T11', 'Šilumnešio temperatūra T11'),
	(116, 'T12', 'Šilumnešio temperatūra T12', 'T12', 'Šilumnešio temperatūra T12'),
	(117, 'M1', 'Šilumnešio masė M1', 'M1', 'Šilumnešio masė M1'),
	(118, 'M2', 'Šilumnešio masė M2', 'M2', 'Šilumnešio masė M2'),
	(119, 'M3', 'Šilumnešio masė M3', 'M3', 'Šilumnešio masė M3'),
	(120, 'M4', 'Šilumnešio masė M4', 'M4', 'Šilumnešio masė M4'),
	(121, 'M5', 'Šilumnešio masė M5', 'M5', 'Šilumnešio masė M5'),
	(122, 'M6', 'Šilumnešio masė M6', 'M6', 'Šilumnešio masė M6'),
	(123, 'M7', 'Šilumnešio masė M7', 'M7', 'Šilumnešio masė M7'),
	(124, 'M8', 'Šilumnešio masė M8', 'M8', 'Šilumnešio masė M8'),
	(125, 'M9', 'Šilumnešio masė M9', 'M9', 'Šilumnešio masė M9'),
	(126, 'M10', 'Šilumnešio masė M10', 'M10', 'Šilumnešio masė M10'),
	(127, 'M11', 'Šilumnešio masė M11', 'M11', 'Šilumnešio masė M11'),
	(128, 'M12', 'Šilumnešio masė M12', 'M12', 'Šilumnešio masė M12'),
	(129, 'V1', 'Šilumnešio tūris V1', 'V1', 'Šilumnešio tūris V1'),
	(130, 'V2', 'Šilumnešio tūris V2', 'V2', 'Šilumnešio tūris V2'),
	(131, 'V3', 'Šilumnešio tūris V3', 'V3', 'Šilumnešio tūris V3'),
	(132, 'V4', 'Šilumnešio tūris V4', 'V4', 'Šilumnešio tūris V4'),
	(133, 'V5', 'Šilumnešio tūris V5', 'V5', 'Šilumnešio tūris V5'),
	(134, 'V6', 'Šilumnešio tūris V6', 'V6', 'Šilumnešio tūris V6'),
	(135, 'V7', 'Šilumnešio tūris V7', 'V7', 'Šilumnešio tūris V7'),
	(136, 'V8', 'Šilumnešio tūris V8', 'V8', 'Šilumnešio tūris V8'),
	(137, 'V9', 'Šilumnešio tūris V9', 'V9', 'Šilumnešio tūris V9'),
	(138, 'V10', 'Šilumnešio tūris V10', 'V10', 'Šilumnešio tūris V10'),
	(139, 'V11', 'Šilumnešio tūris V11', 'V11', 'Šilumnešio tūris V11'),
	(140, 'V12', 'Šilumnešio tūris V12', 'V12', 'Šilumnešio tūris V12'),
	(141, 'P1', 'Slėgis sistemoje P1', 'P1', 'Slėgis sistemoje P1'),
	(142, 'P2', 'Slėgis sistemoje P2', 'P2', 'Slėgis sistemoje P2'),
	(143, 'P3', 'Slėgis sistemoje P3', 'P3', 'Slėgis sistemoje P3'),
	(144, 'P4', 'Slėgis sistemoje P4', 'P4', 'Slėgis sistemoje P4'),
	(145, 'P5', 'Slėgis sistemoje P5', 'P5', 'Slėgis sistemoje P5'),
	(146, 'P6', 'Slėgis sistemoje P6', 'P6', 'Slėgis sistemoje P6'),
	(147, 'P7', 'Slėgis sistemoje P7', 'P7', 'Slėgis sistemoje P7'),
	(148, 'P8', 'Slėgis sistemoje P8', 'P8', 'Slėgis sistemoje P8'),
	(149, 'P9', 'Slėgis sistemoje P9', 'P9', 'Slėgis sistemoje P9'),
	(150, 'P10', 'Slėgis sistemoje P10', 'P10', 'Slėgis sistemoje P10'),
	(151, 'P11', 'Slėgis sistemoje P11', 'P11', 'Slėgis sistemoje P11'),
	(152, 'P12', 'Slėgis sistemoje P12', 'P12', 'Slėgis sistemoje P12'),
	(153, 'WT1', 'Darbo laikas WT1', 'WT1', 'Darbo laikas WT1'),
	(154, 'WT2', 'Darbo laikas WT2', 'WT2', 'Darbo laikas WT2'),
	(155, 'WT3', 'Darbo laikas WT3', 'WT3', 'Darbo laikas WT3'),
	(156, 'WT4', 'Darbo laikas WT4', 'WT4', 'Darbo laikas WT4'),
	(157, 'WT5', 'Darbo laikas WT5', 'WT5', 'Darbo laikas WT5'),
	(158, 'WT6', 'Darbo laikas WT6', 'WT6', 'Darbo laikas WT6'),
	(159, 'WT7', 'Darbo laikas WT7', 'WT7', 'Darbo laikas WT7'),
	(160, 'WT8', 'Darbo laikas WT8', 'WT8', 'Darbo laikas WT8'),
	(161, 'WT9', 'Darbo laikas WT9', 'WT9', 'Darbo laikas WT9'),
	(162, 'WT10', 'Darbo laikas WT10', 'WT10', 'Darbo laikas WT10'),
	(163, 'WT11', 'Darbo laikas WT11', 'WT11', 'Darbo laikas WT11'),
	(164, 'WT12', 'Darbo laikas WT12', 'WT12', 'Darbo laikas WT12'),
	(165, 'ER1', 'Klaidos kodas ER1', 'ER1', 'Klaidos kodas ER1'),
	(166, 'ER2', 'Klaidos kodas ER2', 'ER2', 'Klaidos kodas ER2'),
	(167, 'ER3', 'Klaidos kodas ER3', 'ER3', 'Klaidos kodas ER3'),
	(168, 'ER4', 'Klaidos kodas ER4', 'ER4', 'Klaidos kodas ER4'),
	(169, 'ER5', 'Klaidos kodas ER5', 'ER5', 'Klaidos kodas ER5'),
	(170, 'ER6', 'Klaidos kodas ER6', 'ER6', 'Klaidos kodas ER6'),
	(171, 'ER7', 'Klaidos kodas ER7', 'ER7', 'Klaidos kodas ER7'),
	(172, 'ER8', 'Klaidos kodas ER8', 'ER8', 'Klaidos kodas ER8'),
	(173, 'ER9', 'Klaidos kodas ER9', 'ER9', 'Klaidos kodas ER9'),
	(174, 'ER10', 'Klaidos kodas ER10', 'ER10', 'Klaidos kodas ER10'),
	(175, 'ER11', 'Klaidos kodas ER11', 'ER11', 'Klaidos kodas ER11'),
	(176, 'ER12', 'Klaidos kodas ER12', 'ER12', 'Klaidos kodas ER12'),
	(177, '1', 'A+', NULL, NULL),
	(178, '2', 'A-', NULL, NULL),
	(179, '3', 'R1', NULL, NULL),
	(180, '4', 'R2', NULL, NULL),
	(181, '5', 'R3', NULL, NULL),
	(182, '6', 'R4', NULL, NULL),
	(183, '7', 'R1+4', NULL, NULL),
	(184, '8', 'R2+3', NULL, NULL),
	(185, '0', 'Tiekimas į tinklą', NULL, NULL),
	(186, '1', 'Priėmimas iš tinklo', NULL, NULL);
/*!40000 ALTER TABLE `xe` ENABLE KEYS */;

-- Dumping structure for table emcor.xf
CREATE TABLE IF NOT EXISTS `xf` (
  `xf_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Apsikeitimo duomenimis formos identifikatorius',
  `xf_type_id` smallint(5) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
  `xa_id` int(10) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis adresato identifikatorius',
  `rpp_id` mediumint(8) unsigned NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo identifikatorius',
  `xf_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Apsikeitimo duomenimis formos pavadinimas',
  `xf_enabled` tinyint(1) NOT NULL COMMENT 'Apsikeitimo duomenimis formos naudojimo požymis',
  `xf_import` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Importo/eksporto formos požymis',
  `rp_id` int(10) unsigned DEFAULT NULL COMMENT 'Ataskaitos identifikatorius',
  PRIMARY KEY (`xf_id`),
  UNIQUE KEY `xf_name_u` (`xf_name`,`xa_id`),
  KEY `xf_rp_i` (`rp_id`),
  KEY `xf_rpp_i` (`rpp_id`),
  KEY `xf_xa_i` (`xa_id`),
  KEY `xf_xf_type_i` (`xf_type_id`),
  CONSTRAINT `xf_rp_fk` FOREIGN KEY (`rp_id`) REFERENCES `rp` (`rp_id`),
  CONSTRAINT `xf_rpp_fk` FOREIGN KEY (`rpp_id`) REFERENCES `rpp` (`rpp_id`) ON DELETE CASCADE,
  CONSTRAINT `xf_xa_fk` FOREIGN KEY (`xa_id`) REFERENCES `xa` (`xa_id`) ON DELETE CASCADE,
  CONSTRAINT `xf_xf_type_fk` FOREIGN KEY (`xf_type_id`) REFERENCES `xf_type` (`xf_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apsikeitimo duomenimis formos';

-- Dumping data for table emcor.xf: ~0 rows (approximately)
/*!40000 ALTER TABLE `xf` DISABLE KEYS */;
/*!40000 ALTER TABLE `xf` ENABLE KEYS */;

-- Dumping structure for table emcor.xfa
CREATE TABLE IF NOT EXISTS `xfa` (
  `xfa_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Apsikeitimo duomenimis formos sekcijos identifikatorius',
  `xf_id` mediumint(8) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formos identifikatorius',
  `xfa_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Apsikeitimo duomenimis formos sekcijos kodas',
  `xfa_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Apsikeitimo duomenimis formos sekcijos pavadinimas',
  `tz_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Laiko zonos identifikatorius',
  `xfa_enabled` tinyint(1) NOT NULL COMMENT 'Apsikeitimo duomenimis formos sekcijos naudojimo požymis',
  `xfa_tz` varchar(5) COLLATE utf8_bin DEFAULT NULL COMMENT 'Apsikeitimo duomenimis formos sekcijos laiko zona',
  `xfa_tz_dst_used` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Apsikeitimo duomenimis formos sekcijos vasaros laiko naudojimo požymis',
  PRIMARY KEY (`xfa_id`),
  UNIQUE KEY `xfa_xf_code_u` (`xf_id`,`xfa_code`),
  KEY `xfa_tz_i` (`tz_id`),
  CONSTRAINT `xfa_tz_fk` FOREIGN KEY (`tz_id`) REFERENCES `tz` (`tz_id`),
  CONSTRAINT `xfa_xf_fk` FOREIGN KEY (`xf_id`) REFERENCES `xf` (`xf_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apsikeitimo duomenimis formos sekcijos';

-- Dumping data for table emcor.xfa: ~0 rows (approximately)
/*!40000 ALTER TABLE `xfa` DISABLE KEYS */;
/*!40000 ALTER TABLE `xfa` ENABLE KEYS */;

-- Dumping structure for table emcor.xfau
CREATE TABLE IF NOT EXISTS `xfau` (
  `xfau_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Apsikeitimo duomenimis formos mazgo identifikatorius',
  `xfau_type_id` smallint(5) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formų mazgų tipo identifikatorius',
  `xfau_enabled` tinyint(1) NOT NULL COMMENT 'Apsikeitimo duomenimis formos mazgo naudojimo požymis',
  `inherit_cn` tinyint(1) NOT NULL COMMENT 'Kodo ir pavadinimo paveldėjimo požymis',
  `xfau_code` varchar(80) COLLATE utf8_bin DEFAULT NULL COMMENT 'Apsikeitimo duomenimis formos mazgo kodas',
  `xfau_name` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Apsikeitimo duomenimis formos mazgo pavadinimas',
  `xfau_code2` varchar(80) COLLATE utf8_bin DEFAULT NULL COMMENT 'Apsikeitimo duomenimis formos mazgo antras kodas',
  `xfau_name2` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Apsikeitimo duomenimis formos mazgo antras pavadinimas',
  `point_id` int(10) unsigned DEFAULT NULL COMMENT 'Matavimo taško identifikatorius',
  `ds_id` int(10) unsigned DEFAULT NULL COMMENT 'Apskaitos būsenos signalo identifikatorius',
  `gr_id` int(10) unsigned DEFAULT NULL COMMENT 'Grupės identifikatorius',
  `xfa_id` int(10) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formos sekcijos identifikatorius',
  PRIMARY KEY (`xfau_id`),
  KEY `xfau_code_i` (`xfau_code`),
  KEY `xfau_ds_i` (`ds_id`),
  KEY `xfau_gr_i` (`gr_id`),
  KEY `xfau_point_i` (`point_id`),
  KEY `xfau_xfa_i` (`xfa_id`),
  KEY `xfau_xfau_type_i` (`xfau_type_id`),
  CONSTRAINT `xfau_ds_fk` FOREIGN KEY (`ds_id`) REFERENCES `ds` (`ds_id`) ON DELETE CASCADE,
  CONSTRAINT `xfau_gr_fk` FOREIGN KEY (`gr_id`) REFERENCES `gr` (`gr_id`) ON DELETE CASCADE,
  CONSTRAINT `xfau_point_fk` FOREIGN KEY (`point_id`) REFERENCES `point` (`point_id`) ON DELETE CASCADE,
  CONSTRAINT `xfau_xfa_fk` FOREIGN KEY (`xfa_id`) REFERENCES `xfa` (`xfa_id`) ON DELETE CASCADE,
  CONSTRAINT `xfau_xfau_type_fk` FOREIGN KEY (`xfau_type_id`) REFERENCES `xfau_type` (`xfau_type_id`) ON DELETE CASCADE,
  CONSTRAINT `XFAU_NOT_IN_3_CHK` CHECK (if(`point_id` is null,0,1) + if(`gr_id` is null,0,1) + if(`ds_id` is null,0,1) = 1),
  CONSTRAINT `XFAU_EMPTY_CN_CHK` CHECK (`inherit_cn` = 1 or `xfau_code` is not null or `xfau_name` is not null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apsikeitimo duomenimis formos mazgai';

-- Dumping data for table emcor.xfau: ~0 rows (approximately)
/*!40000 ALTER TABLE `xfau` DISABLE KEYS */;
/*!40000 ALTER TABLE `xfau` ENABLE KEYS */;

-- Dumping structure for table emcor.xfau_data
CREATE TABLE IF NOT EXISTS `xfau_data` (
  `xfau_id` int(10) unsigned NOT NULL,
  `xfau_bt` datetime NOT NULL,
  `xfau_et` datetime NOT NULL,
  PRIMARY KEY (`xfau_id`),
  CONSTRAINT `xfau_data_xfau_fk` FOREIGN KEY (`xfau_id`) REFERENCES `xfau` (`xfau_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.xfau_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `xfau_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `xfau_data` ENABLE KEYS */;

-- Dumping structure for table emcor.xfau_type
CREATE TABLE IF NOT EXISTS `xfau_type` (
  `xfau_type_id` smallint(5) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formų mazgų tipo identifikatorius',
  `xfau_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Apsikeitimo duomenimis formų mazgų tipo pavadinimas',
  `per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Periodo identifikatorius',
  `cb_point` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar tokio tipo mazgu gali būti apskaitos taškas',
  `cb_gr` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar tokio tipo mazgu gali būti apskaitos taškų grupė',
  `cb_ds` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar tokio tipo mazgu gali būti apskaitos būsenos signalas',
  PRIMARY KEY (`xfau_type_id`),
  UNIQUE KEY `xfau_type_name_u` (`xfau_type_name`),
  KEY `xfau_type_per_i` (`per_id`),
  CONSTRAINT `xfau_type_per_fk` FOREIGN KEY (`per_id`) REFERENCES `per` (`per_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apsikeitimo duomenimis formų mazgų tipai';

-- Dumping data for table emcor.xfau_type: ~7 rows (approximately)
/*!40000 ALTER TABLE `xfau_type` DISABLE KEYS */;
INSERT INTO `xfau_type` (`xfau_type_id`, `xfau_type_name`, `per_id`, `cb_point`, `cb_gr`, `cb_ds`) VALUES
	(1, 'Matavimo taškas', 2, 1, 1, 0),
	(3, 'Tiekimo taškas', 3, 1, 1, 0),
	(4, 'Tiekimo grupė', 3, 0, 1, 0),
	(5, 'Pertaka', 3, 0, 1, 0),
	(7, 'Matavimo priemonė', 2, 1, 1, 0),
	(8, 'Telesignalas', 2, 0, 0, 1),
	(9, 'Matavimo taškas (valandiniai duomenys)', 3, 1, 0, 0);
/*!40000 ALTER TABLE `xfau_type` ENABLE KEYS */;

-- Dumping structure for table emcor.xfe
CREATE TABLE IF NOT EXISTS `xfe` (
  `xfe_id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Apsikeitimo duomenimis formos elemento identifikatorius',
  `xfau_id` int(10) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formos mazgo identifikatorius',
  `ml_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Matavimo linijos identifikatorius',
  `xe_id` int(10) unsigned DEFAULT NULL COMMENT 'Apsikeitimo duomenimis elemento identifikatorius',
  `xfe_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Apsikeitimo duomenimis formos elemento naudojimo požymis',
  `xfe_info` varchar(250) COLLATE utf8_bin DEFAULT NULL COMMENT 'Apsikeitimo duomenimis formos elemento informacija',
  PRIMARY KEY (`xfe_id`),
  UNIQUE KEY `xfe_ml_u` (`ml_id`,`xfau_id`,`xe_id`),
  KEY `xfe_xe_i` (`xe_id`),
  KEY `xfe_xfau_i` (`xfau_id`),
  CONSTRAINT `xfe_ml_fk` FOREIGN KEY (`ml_id`) REFERENCES `ml` (`ml_id`) ON DELETE CASCADE,
  CONSTRAINT `xfe_xe_fk` FOREIGN KEY (`xe_id`) REFERENCES `xe` (`xe_id`) ON DELETE CASCADE,
  CONSTRAINT `xfe_xfau_fk` FOREIGN KEY (`xfau_id`) REFERENCES `xfau` (`xfau_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apsikeitimo duomenimis formos elementai';

-- Dumping data for table emcor.xfe: ~0 rows (approximately)
/*!40000 ALTER TABLE `xfe` DISABLE KEYS */;
/*!40000 ALTER TABLE `xfe` ENABLE KEYS */;

-- Dumping structure for table emcor.xfe_ds_data
CREATE TABLE IF NOT EXISTS `xfe_ds_data` (
  `xfe_id` int(10) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formos elemento identifikatorius',
  `xo_id` bigint(20) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis operacijos identifikatorius',
  `xs_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Apsikeitimo duomenų statuso identifikatorius',
  `xfe_t` datetime(3) NOT NULL COMMENT 'Apsikeitimo duomenimis formos elemento duomenų laikas',
  `xfe_v` tinyint(3) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formos elemento reikšmė',
  PRIMARY KEY (`xfe_id`,`xfe_t`,`xo_id`),
  KEY `xfe_ds_data_xo_i` (`xo_id`),
  KEY `xfe_ds_data_xs_i` (`xs_id`),
  CONSTRAINT `xfe_ds_data_xfe_fk` FOREIGN KEY (`xfe_id`) REFERENCES `xfe` (`xfe_id`) ON DELETE CASCADE,
  CONSTRAINT `xfe_ds_data_xo_fk` FOREIGN KEY (`xo_id`) REFERENCES `xo` (`xo_id`) ON DELETE CASCADE,
  CONSTRAINT `xfe_ds_data_xs_fk` FOREIGN KEY (`xs_id`) REFERENCES `xs` (`xs_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apsikeitimo duomenimis formos elementų-būsenų duomenys';

-- Dumping data for table emcor.xfe_ds_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `xfe_ds_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `xfe_ds_data` ENABLE KEYS */;

-- Dumping structure for table emcor.xfe_pl_data
CREATE TABLE IF NOT EXISTS `xfe_pl_data` (
  `xfe_id` int(10) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formos elemento identifikatorius',
  `xo_id` bigint(20) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis operacijos identifikatorius',
  `xs_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Apsikeitimo duomenų statuso identifikatorius',
  `xfe_t` datetime NOT NULL COMMENT 'Apsikeitimo duomenimis formos elemento duomenų laikas',
  `xfe_v` tinyint(3) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formos elemento reikšmė',
  `improvable` tinyint(1) NOT NULL COMMENT 'Požymis, ar galimi geresni duomenys',
  `xfe_rt` datetime DEFAULT NULL COMMENT 'Apsikeitimo duomenimis formos elemento duomenų nuskaitymo laikas',
  PRIMARY KEY (`xfe_id`,`xfe_t`,`xo_id`),
  KEY `xfe_pl_data_xo_i` (`xo_id`),
  KEY `xfe_pl_data_xs_fk` (`xs_id`),
  CONSTRAINT `xfe_pl_data_xfe_fk` FOREIGN KEY (`xfe_id`) REFERENCES `xfe` (`xfe_id`) ON DELETE CASCADE,
  CONSTRAINT `xfe_pl_data_xo_fk` FOREIGN KEY (`xo_id`) REFERENCES `xo` (`xo_id`) ON DELETE CASCADE,
  CONSTRAINT `xfe_pl_data_xs_fk` FOREIGN KEY (`xs_id`) REFERENCES `xs` (`xs_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apsikeitimo duomenimis formos elementų-matavimų duomenys';

-- Dumping data for table emcor.xfe_pl_data: ~0 rows (approximately)
/*!40000 ALTER TABLE `xfe_pl_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `xfe_pl_data` ENABLE KEYS */;

-- Dumping structure for table emcor.xfu
CREATE TABLE IF NOT EXISTS `xfu` (
  `xf_id` mediumint(8) unsigned NOT NULL,
  PRIMARY KEY (`xf_id`),
  CONSTRAINT `xfu_xf_fk` FOREIGN KEY (`xf_id`) REFERENCES `xf` (`xf_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.xfu: ~0 rows (approximately)
/*!40000 ALTER TABLE `xfu` DISABLE KEYS */;
/*!40000 ALTER TABLE `xfu` ENABLE KEYS */;

-- Dumping structure for table emcor.xf_rc
CREATE TABLE IF NOT EXISTS `xf_rc` (
  `xf_id` mediumint(8) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formos identifikatorius',
  `rc_id` tinyint(3) unsigned NOT NULL COMMENT 'Užklausų priežasties identifikatorius',
  `sch_id` mediumint(8) unsigned NOT NULL COMMENT 'Tvarkaraščio identifikatorius',
  `per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Periodo identifikatorius',
  `xf_rc_lag` mediumint(8) unsigned DEFAULT NULL COMMENT 'Periodų kiekis, apibrėžiantis išsiuntimo poslinkį',
  `xf_rc_depth` mediumint(8) unsigned DEFAULT NULL COMMENT 'Periodų kiekis, apibrėžiantis išsiuntimo gylį',
  PRIMARY KEY (`xf_id`,`rc_id`),
  KEY `xf_rc_per_i` (`per_id`),
  KEY `xf_rc_rc_i` (`rc_id`),
  KEY `xf_rc_sch_i` (`sch_id`),
  CONSTRAINT `xf_rc_per_fk` FOREIGN KEY (`per_id`) REFERENCES `per` (`per_id`) ON DELETE CASCADE,
  CONSTRAINT `xf_rc_rc_fk` FOREIGN KEY (`rc_id`) REFERENCES `rc` (`rc_id`) ON DELETE CASCADE,
  CONSTRAINT `xf_rc_sch_fk` FOREIGN KEY (`sch_id`) REFERENCES `sch` (`sch_id`),
  CONSTRAINT `xf_rc_xf_fk` FOREIGN KEY (`xf_id`) REFERENCES `xf` (`xf_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apsikeitimo duomenimis formų konfigūracija pagal nuskaitymo priežastį';

-- Dumping data for table emcor.xf_rc: ~0 rows (approximately)
/*!40000 ALTER TABLE `xf_rc` DISABLE KEYS */;
/*!40000 ALTER TABLE `xf_rc` ENABLE KEYS */;

-- Dumping structure for table emcor.xf_rpt
CREATE TABLE IF NOT EXISTS `xf_rpt` (
  `xf_id` mediumint(8) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formos identifikatorius',
  `xo_bt` datetime NOT NULL COMMENT 'Duomenų periodo pradžia',
  `xo_et` datetime NOT NULL COMMENT 'Duomenų periodo pabaiga',
  `forced` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Forsavimo požymis',
  PRIMARY KEY (`xf_id`,`xo_bt`,`xo_et`),
  CONSTRAINT `xf_rpt_xf_fk` FOREIGN KEY (`xf_id`) REFERENCES `xf` (`xf_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apsikeitimo duomenimis formų pakartotinio siuntimo periodai';

-- Dumping data for table emcor.xf_rpt: ~0 rows (approximately)
/*!40000 ALTER TABLE `xf_rpt` DISABLE KEYS */;
/*!40000 ALTER TABLE `xf_rpt` ENABLE KEYS */;

-- Dumping structure for table emcor.xf_type
CREATE TABLE IF NOT EXISTS `xf_type` (
  `xf_type_id` smallint(5) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
  `xf_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo pavadinimas',
  `xf_type_code` varchar(20) COLLATE utf8_bin NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo kodas',
  `xf_type_delivery` varchar(20) COLLATE utf8_bin NOT NULL DEFAULT 'ELEMENT',
  `per_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Periodo identifikatorius',
  `src_type_id` int(10) DEFAULT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
  `rc_filter` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Nuskaitymo priežasčių parametrų filtro naudojimo požymis apsikeitimo duomenimis formų tipui',
  `ml_filter` tinyint(1) NOT NULL DEFAULT 0 COMMENT 'Matavimo linijų filtro naudojimo požymis apsikeitimo duomenimis formų tipui',
  `xfe_usage` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Požymis, ar galimi mazgų elementai formoje',
  PRIMARY KEY (`xf_type_id`),
  UNIQUE KEY `xf_type_code_u` (`xf_type_code`),
  UNIQUE KEY `xf_type_name_u` (`xf_type_name`),
  KEY `xf_type_per_i` (`per_id`),
  KEY `xf_type_src_type_i` (`src_type_id`),
  CONSTRAINT `xf_type_per_fk` FOREIGN KEY (`per_id`) REFERENCES `per` (`per_id`),
  CONSTRAINT `xf_type_src_type_fk` FOREIGN KEY (`src_type_id`) REFERENCES `src_type` (`src_type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apsikeitimo duomenimis formų tipai';

-- Dumping data for table emcor.xf_type: ~34 rows (approximately)
/*!40000 ALTER TABLE `xf_type` DISABLE KEYS */;
INSERT INTO `xf_type` (`xf_type_id`, `xf_type_name`, `xf_type_code`, `xf_type_delivery`, `per_id`, `src_type_id`, `rc_filter`, `ml_filter`, `xfe_usage`) VALUES
	(1, 'XML(80020)', '80020', 'FORM', 4, 107, 0, 0, 1),
	(2, 'XML(51070)', '51070', 'FORM', 5, NULL, 0, 0, 1),
	(3, 'XML(80030)', '80030', 'FORM', 4, 109, 0, 0, 0),
	(4, 'ASKP', 'ASKP', 'FORM', 4, 110, 0, 0, 1),
	(5, 'EMCOS(EEML)', 'EEML', 'ELEMENT', NULL, 111, 0, 0, 1),
	(6, 'XML(80040)', '80040', 'FORM', 4, 112, 0, 0, 1),
	(7, 'XML(80050)', '80050', 'FORM', 5, NULL, 0, 0, 1),
	(8, 'SPD', 'SPD', 'FORM', 4, NULL, 0, 0, 1),
	(9, 'MND', 'MND', 'FORM', 4, NULL, 0, 0, 1),
	(10, 'PCCI', 'PCCI', 'ELEMENT', 4, 193, 0, 1, 1),
	(14, 'ARGE', 'ARGE', 'FORM', 5, NULL, 0, 0, 1),
	(15, 'KIO-3(3MIN AVG)', 'KIO3_3MIN_AVG', 'FORM', 2, NULL, 0, 0, 1),
	(16, 'KIO-3(3MIN TOTAL)', 'KIO3_3MIN_TOTAL', 'FORM', 2, NULL, 0, 0, 1),
	(17, 'KIO-3(DAY TOTAL)', 'KIO3_DAY_TOTAL', 'FORM', 4, NULL, 0, 0, 1),
	(18, 'KIO-3(MONTH TOTAL)', 'KIO3_MONTH_TOTAL', 'FORM', 5, NULL, 0, 0, 1),
	(19, 'SNG(1517)', 'SNG_1517', 'FORM', 4, 305, 0, 0, 1),
	(20, 'UkrEnergo(30818)', 'UkrEnergo_30818', 'FORM', 4, 169, 0, 1, 1),
	(21, 'UkrEnergo(30917)', 'UkrEnergo_30917', 'FORM', 4, 170, 0, 1, 1),
	(22, 'UkrEnergo(30817)', 'UkrEnergo_30817', 'FORM', 4, 171, 0, 1, 1),
	(23, 'UkrUPPD(LP)', 'UkrUPPD_LP', 'FORM', 4, NULL, 0, 1, 1),
	(24, 'UkrUPPD(ENERGY)', 'UkrUPPD_ENERGY', 'FORM', 4, NULL, 0, 1, 1),
	(25, 'DneprOblEnergo(DB)', 'DneprOblEnergo_DB', 'FORM', 4, 289, 0, 1, 1),
	(28, 'BelEnergoSbyt(DBF)', 'BelEnergoSbyt_DBF', 'FORM', 4, NULL, 0, 1, 1),
	(29, '61968', '61968', 'ELEMENT', NULL, 245, 0, 0, 1),
	(30, 'EestiEnergia(CSV)', 'Eesti_Energia_CSV', 'FORM', 4, 213, 0, 0, 1),
	(31, 'EnergoKrug(DB)', 'ENERGOKRUG_DB', 'FORM', 4, 231, 0, 0, 1),
	(32, 'Globos(CSV)', 'Globos_CSV', 'FORM', 4, 233, 0, 0, 1),
	(33, 'Free form CMR', 'FREE_FORM_CMR', 'FORM', 5, NULL, 0, 0, 1),
	(34, 'KANS', 'KANS', 'FORM', 5, NULL, 0, 0, 1),
	(35, 'PromEnergo(XML)', 'PromEnergo_XML', 'FORM', 4, NULL, 0, 0, 1),
	(36, 'EMCOS(EEDS)', 'EEDS', 'ELEMENT', NULL, NULL, 0, 0, 1),
	(37, 'SMARTTECH', 'SMARTTECH', 'FORM', 4, NULL, 0, 0, 1),
	(38, 'CATEK_AREK(DBF)', 'CATEK_AREK_DBF', 'ELEMENT', NULL, NULL, 0, 0, 1),
	(39, 'KaunoVandenys(XML)', 'KaunoVandenys_XML', 'FORM', 5, NULL, 0, 1, 1);
/*!40000 ALTER TABLE `xf_type` ENABLE KEYS */;

-- Dumping structure for table emcor.xf_type_aggf
CREATE TABLE IF NOT EXISTS `xf_type_aggf` (
  `xf_type_id` smallint(5) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
  `aggf_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo funkcijos identifikatorius įėjime',
  `x_aggf_id` tinyint(3) unsigned NOT NULL COMMENT 'Agregavimo funkcijos identifikatorius išėjime',
  PRIMARY KEY (`xf_type_id`,`aggf_id`),
  KEY `xf_type_aggf_x_aggf_i` (`x_aggf_id`),
  KEY `xf_type_aggf_aggf_fk` (`aggf_id`),
  CONSTRAINT `xf_type_aggf_aggf_fk` FOREIGN KEY (`aggf_id`) REFERENCES `aggf` (`aggf_id`) ON DELETE CASCADE,
  CONSTRAINT `xf_type_aggf_x_aggf_fk` FOREIGN KEY (`x_aggf_id`) REFERENCES `aggf` (`aggf_id`) ON DELETE CASCADE,
  CONSTRAINT `xf_type_aggf_xf_type_fk` FOREIGN KEY (`xf_type_id`) REFERENCES `xf_type` (`xf_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apsikeitimo duomenimis formų tipų agregavimo funkcijų lentelė';

-- Dumping data for table emcor.xf_type_aggf: ~6 rows (approximately)
/*!40000 ALTER TABLE `xf_type_aggf` DISABLE KEYS */;
INSERT INTO `xf_type_aggf` (`xf_type_id`, `aggf_id`, `x_aggf_id`) VALUES
	(1, 3, 2),
	(2, 3, 2),
	(6, 3, 2),
	(7, 3, 2),
	(8, 3, 2),
	(10, 3, 2);
/*!40000 ALTER TABLE `xf_type_aggf` ENABLE KEYS */;

-- Dumping structure for table emcor.xf_type_eu_map
CREATE TABLE IF NOT EXISTS `xf_type_eu_map` (
  `xf_type_id` smallint(5) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
  `in_eu_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo vienetų identifikatorius įėjime',
  `out_eu_id` mediumint(8) unsigned NOT NULL COMMENT 'Matavimo vienetų identifikatorius išėjime',
  PRIMARY KEY (`xf_type_id`,`in_eu_id`),
  KEY `xf_type_eu_map_out_eu_i` (`out_eu_id`),
  KEY `xf_type_eu_map_in_eu_fk` (`in_eu_id`),
  CONSTRAINT `xf_type_eu_map_in_eu_fk` FOREIGN KEY (`in_eu_id`) REFERENCES `eu` (`eu_id`) ON DELETE CASCADE,
  CONSTRAINT `xf_type_eu_map_out_eu_fk` FOREIGN KEY (`out_eu_id`) REFERENCES `eu` (`eu_id`) ON DELETE CASCADE,
  CONSTRAINT `xf_type_eu_map_xf_type_fk` FOREIGN KEY (`xf_type_id`) REFERENCES `xf_type` (`xf_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apsikeitimo duomenimis formų tipų matavimo vienetų lentelė';

-- Dumping data for table emcor.xf_type_eu_map: ~0 rows (approximately)
/*!40000 ALTER TABLE `xf_type_eu_map` DISABLE KEYS */;
/*!40000 ALTER TABLE `xf_type_eu_map` ENABLE KEYS */;

-- Dumping structure for table emcor.xf_type_ml_filter
CREATE TABLE IF NOT EXISTS `xf_type_ml_filter` (
  `xf_type_id` smallint(5) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
  `ms_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Matavimo identifikatorius',
  `dir_id` tinyint(4) DEFAULT NULL COMMENT 'Krypties identifikatorius',
  `aggs_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Agregavimo segmento identifikatorius',
  `aggf_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Agregavimo funkcijos identifikatorius',
  `tff_id` tinyint(3) unsigned DEFAULT NULL COMMENT 'Tarifo identifikatorius',
  `md_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Matavimo diskretiškumo identifikatorius',
  UNIQUE KEY `xf_type_ml_filter_u` (`xf_type_id`,`ms_id`,`dir_id`,`aggs_id`,`aggf_id`,`tff_id`,`md_id`),
  KEY `xf_type_ml_filter_aggf_fk` (`aggf_id`),
  KEY `xf_type_ml_filter_aggs_fk` (`aggs_id`),
  KEY `xf_type_ml_filter_dir_fk` (`dir_id`),
  KEY `xf_type_ml_filter_md_fk` (`md_id`),
  KEY `xf_type_ml_filter_ms_fk` (`ms_id`),
  KEY `xf_type_ml_filter_tff_fk` (`tff_id`),
  CONSTRAINT `xf_type_ml_filter_aggf_fk` FOREIGN KEY (`aggf_id`) REFERENCES `aggf` (`aggf_id`) ON DELETE CASCADE,
  CONSTRAINT `xf_type_ml_filter_aggs_fk` FOREIGN KEY (`aggs_id`) REFERENCES `aggs` (`aggs_id`) ON DELETE CASCADE,
  CONSTRAINT `xf_type_ml_filter_dir_fk` FOREIGN KEY (`dir_id`) REFERENCES `dir` (`dir_id`) ON DELETE CASCADE,
  CONSTRAINT `xf_type_ml_filter_md_fk` FOREIGN KEY (`md_id`) REFERENCES `md` (`md_id`) ON DELETE CASCADE,
  CONSTRAINT `xf_type_ml_filter_ms_fk` FOREIGN KEY (`ms_id`) REFERENCES `ms` (`ms_id`) ON DELETE CASCADE,
  CONSTRAINT `xf_type_ml_filter_tff_fk` FOREIGN KEY (`tff_id`) REFERENCES `tff` (`tff_id`) ON DELETE CASCADE,
  CONSTRAINT `xf_type_ml_filter_xf_type_fk` FOREIGN KEY (`xf_type_id`) REFERENCES `xf_type` (`xf_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.xf_type_ml_filter: ~386 rows (approximately)
/*!40000 ALTER TABLE `xf_type_ml_filter` DISABLE KEYS */;
INSERT INTO `xf_type_ml_filter` (`xf_type_id`, `ms_id`, `dir_id`, `aggs_id`, `aggf_id`, `tff_id`, `md_id`) VALUES
	(10, 1, 1, 13, 2, 0, 12),
	(10, 1, 1, 13, 3, 0, 12),
	(10, 1, 2, 13, 2, 0, 12),
	(10, 1, 2, 13, 3, 0, 12),
	(10, 3, -3, 13, 2, 0, 12),
	(10, 3, -3, 13, 3, 0, 12),
	(10, 3, -2, 13, 2, 0, 12),
	(10, 3, -2, 13, 3, 0, 12),
	(10, 3, 1, 13, 2, 0, 12),
	(10, 3, 1, 13, 3, 0, 12),
	(10, 3, 2, 13, 2, 0, 12),
	(10, 3, 2, 13, 3, 0, 12),
	(10, 3, 5, 13, 2, 0, 12),
	(10, 3, 5, 13, 3, 0, 12),
	(10, 3, 6, 13, 2, 0, 12),
	(10, 3, 6, 13, 3, 0, 12),
	(10, 3, 7, 13, 2, 0, 12),
	(10, 3, 7, 13, 3, 0, 12),
	(10, 3, 8, 13, 2, 0, 12),
	(10, 3, 8, 13, 3, 0, 12),
	(23, 1, 0, 1, 3, 0, 1),
	(23, 1, 0, 3, 3, 0, 3),
	(23, 1, 0, 4, 3, 0, 4),
	(23, 1, 0, 9, 3, 0, 8),
	(23, 1, 0, 11, 3, 0, 10),
	(23, 1, 0, 12, 3, 0, 11),
	(23, 1, 0, 13, 3, 0, 12),
	(23, 1, 1, 1, 3, 0, 1),
	(23, 1, 1, 3, 3, 0, 3),
	(23, 1, 1, 4, 3, 0, 4),
	(23, 1, 1, 9, 3, 0, 8),
	(23, 1, 1, 11, 3, 0, 10),
	(23, 1, 1, 12, 3, 0, 11),
	(23, 1, 1, 13, 3, 0, 12),
	(23, 1, 2, 1, 3, 0, 1),
	(23, 1, 2, 3, 3, 0, 3),
	(23, 1, 2, 4, 3, 0, 4),
	(23, 1, 2, 9, 3, 0, 8),
	(23, 1, 2, 11, 3, 0, 10),
	(23, 1, 2, 12, 3, 0, 11),
	(23, 1, 2, 13, 3, 0, 12),
	(23, 3, 0, 1, 3, 0, 1),
	(23, 3, 0, 3, 3, 0, 3),
	(23, 3, 0, 4, 3, 0, 4),
	(23, 3, 0, 9, 3, 0, 8),
	(23, 3, 0, 11, 3, 0, 10),
	(23, 3, 0, 12, 3, 0, 11),
	(23, 3, 0, 13, 3, 0, 12),
	(23, 3, 1, 1, 3, 0, 1),
	(23, 3, 1, 3, 3, 0, 3),
	(23, 3, 1, 4, 3, 0, 4),
	(23, 3, 1, 9, 3, 0, 8),
	(23, 3, 1, 11, 3, 0, 10),
	(23, 3, 1, 12, 3, 0, 11),
	(23, 3, 1, 13, 3, 0, 12),
	(23, 3, 2, 1, 3, 0, 1),
	(23, 3, 2, 3, 3, 0, 3),
	(23, 3, 2, 4, 3, 0, 4),
	(23, 3, 2, 9, 3, 0, 8),
	(23, 3, 2, 11, 3, 0, 10),
	(23, 3, 2, 12, 3, 0, 11),
	(23, 3, 2, 13, 3, 0, 12),
	(23, 3, 5, 1, 3, 0, 1),
	(23, 3, 5, 3, 3, 0, 3),
	(23, 3, 5, 4, 3, 0, 4),
	(23, 3, 5, 9, 3, 0, 8),
	(23, 3, 5, 11, 3, 0, 10),
	(23, 3, 5, 12, 3, 0, 11),
	(23, 3, 5, 13, 3, 0, 12),
	(23, 3, 6, 1, 3, 0, 1),
	(23, 3, 6, 3, 3, 0, 3),
	(23, 3, 6, 4, 3, 0, 4),
	(23, 3, 6, 9, 3, 0, 8),
	(23, 3, 6, 11, 3, 0, 10),
	(23, 3, 6, 12, 3, 0, 11),
	(23, 3, 6, 13, 3, 0, 12),
	(23, 3, 7, 1, 3, 0, 1),
	(23, 3, 7, 3, 3, 0, 3),
	(23, 3, 7, 4, 3, 0, 4),
	(23, 3, 7, 9, 3, 0, 8),
	(23, 3, 7, 11, 3, 0, 10),
	(23, 3, 7, 12, 3, 0, 11),
	(23, 3, 7, 13, 3, 0, 12),
	(23, 3, 8, 1, 3, 0, 1),
	(23, 3, 8, 3, 3, 0, 3),
	(23, 3, 8, 4, 3, 0, 4),
	(23, 3, 8, 9, 3, 0, 8),
	(23, 3, 8, 11, 3, 0, 10),
	(23, 3, 8, 12, 3, 0, 11),
	(23, 3, 8, 13, 3, 0, 12),
	(24, 1, 0, 1, 2, 0, 1),
	(24, 1, 0, 3, 2, 0, 3),
	(24, 1, 0, 4, 2, 0, 4),
	(24, 1, 0, 5, 2, 0, 5),
	(24, 1, 0, 5, 2, 1, 5),
	(24, 1, 0, 5, 2, 2, 5),
	(24, 1, 0, 5, 2, 3, 5),
	(24, 1, 0, 5, 2, 4, 5),
	(24, 1, 0, 5, 2, 5, 5),
	(24, 1, 0, 5, 2, 6, 5),
	(24, 1, 0, 5, 2, 7, 5),
	(24, 1, 0, 5, 2, 8, 5),
	(24, 1, 0, 6, 2, 0, 6),
	(24, 1, 0, 6, 2, 1, 6),
	(24, 1, 0, 6, 2, 2, 6),
	(24, 1, 0, 6, 2, 3, 6),
	(24, 1, 0, 6, 2, 4, 6),
	(24, 1, 0, 6, 2, 5, 6),
	(24, 1, 0, 6, 2, 6, 6),
	(24, 1, 0, 6, 2, 7, 6),
	(24, 1, 0, 6, 2, 8, 6),
	(24, 1, 0, 9, 2, 0, 8),
	(24, 1, 0, 11, 2, 0, 10),
	(24, 1, 0, 12, 2, 0, 11),
	(24, 1, 0, 13, 2, 0, 12),
	(24, 1, 1, 1, 2, 0, 1),
	(24, 1, 1, 3, 2, 0, 3),
	(24, 1, 1, 4, 2, 0, 4),
	(24, 1, 1, 5, 2, 0, 5),
	(24, 1, 1, 5, 2, 1, 5),
	(24, 1, 1, 5, 2, 2, 5),
	(24, 1, 1, 5, 2, 3, 5),
	(24, 1, 1, 5, 2, 4, 5),
	(24, 1, 1, 5, 2, 5, 5),
	(24, 1, 1, 5, 2, 6, 5),
	(24, 1, 1, 5, 2, 7, 5),
	(24, 1, 1, 5, 2, 8, 5),
	(24, 1, 1, 6, 2, 0, 6),
	(24, 1, 1, 6, 2, 1, 6),
	(24, 1, 1, 6, 2, 2, 6),
	(24, 1, 1, 6, 2, 3, 6),
	(24, 1, 1, 6, 2, 4, 6),
	(24, 1, 1, 6, 2, 5, 6),
	(24, 1, 1, 6, 2, 6, 6),
	(24, 1, 1, 6, 2, 7, 6),
	(24, 1, 1, 6, 2, 8, 6),
	(24, 1, 1, 9, 2, 0, 8),
	(24, 1, 1, 11, 2, 0, 10),
	(24, 1, 1, 12, 2, 0, 11),
	(24, 1, 1, 13, 2, 0, 12),
	(24, 1, 2, 1, 2, 0, 1),
	(24, 1, 2, 3, 2, 0, 3),
	(24, 1, 2, 4, 2, 0, 4),
	(24, 1, 2, 5, 2, 0, 5),
	(24, 1, 2, 5, 2, 1, 5),
	(24, 1, 2, 5, 2, 2, 5),
	(24, 1, 2, 5, 2, 3, 5),
	(24, 1, 2, 5, 2, 4, 5),
	(24, 1, 2, 5, 2, 5, 5),
	(24, 1, 2, 5, 2, 6, 5),
	(24, 1, 2, 5, 2, 7, 5),
	(24, 1, 2, 5, 2, 8, 5),
	(24, 1, 2, 6, 2, 0, 6),
	(24, 1, 2, 6, 2, 1, 6),
	(24, 1, 2, 6, 2, 2, 6),
	(24, 1, 2, 6, 2, 3, 6),
	(24, 1, 2, 6, 2, 4, 6),
	(24, 1, 2, 6, 2, 5, 6),
	(24, 1, 2, 6, 2, 6, 6),
	(24, 1, 2, 6, 2, 7, 6),
	(24, 1, 2, 6, 2, 8, 6),
	(24, 1, 2, 9, 2, 0, 8),
	(24, 1, 2, 11, 2, 0, 10),
	(24, 1, 2, 12, 2, 0, 11),
	(24, 1, 2, 13, 2, 0, 12),
	(24, 3, 0, 1, 2, 0, 1),
	(24, 3, 0, 3, 2, 0, 3),
	(24, 3, 0, 4, 2, 0, 4),
	(24, 3, 0, 5, 2, 0, 5),
	(24, 3, 0, 5, 2, 1, 5),
	(24, 3, 0, 5, 2, 2, 5),
	(24, 3, 0, 5, 2, 3, 5),
	(24, 3, 0, 5, 2, 4, 5),
	(24, 3, 0, 5, 2, 5, 5),
	(24, 3, 0, 5, 2, 6, 5),
	(24, 3, 0, 5, 2, 7, 5),
	(24, 3, 0, 5, 2, 8, 5),
	(24, 3, 0, 6, 2, 0, 6),
	(24, 3, 0, 6, 2, 1, 6),
	(24, 3, 0, 6, 2, 2, 6),
	(24, 3, 0, 6, 2, 3, 6),
	(24, 3, 0, 6, 2, 4, 6),
	(24, 3, 0, 6, 2, 5, 6),
	(24, 3, 0, 6, 2, 6, 6),
	(24, 3, 0, 6, 2, 7, 6),
	(24, 3, 0, 6, 2, 8, 6),
	(24, 3, 0, 9, 2, 0, 8),
	(24, 3, 0, 11, 2, 0, 10),
	(24, 3, 0, 12, 2, 0, 11),
	(24, 3, 0, 13, 2, 0, 12),
	(24, 3, 1, 1, 2, 0, 1),
	(24, 3, 1, 3, 2, 0, 3),
	(24, 3, 1, 4, 2, 0, 4),
	(24, 3, 1, 5, 2, 0, 5),
	(24, 3, 1, 5, 2, 1, 5),
	(24, 3, 1, 5, 2, 2, 5),
	(24, 3, 1, 5, 2, 3, 5),
	(24, 3, 1, 5, 2, 4, 5),
	(24, 3, 1, 5, 2, 5, 5),
	(24, 3, 1, 5, 2, 6, 5),
	(24, 3, 1, 5, 2, 7, 5),
	(24, 3, 1, 5, 2, 8, 5),
	(24, 3, 1, 6, 2, 0, 6),
	(24, 3, 1, 6, 2, 1, 6),
	(24, 3, 1, 6, 2, 2, 6),
	(24, 3, 1, 6, 2, 3, 6),
	(24, 3, 1, 6, 2, 4, 6),
	(24, 3, 1, 6, 2, 5, 6),
	(24, 3, 1, 6, 2, 6, 6),
	(24, 3, 1, 6, 2, 7, 6),
	(24, 3, 1, 6, 2, 8, 6),
	(24, 3, 1, 9, 2, 0, 8),
	(24, 3, 1, 11, 2, 0, 10),
	(24, 3, 1, 12, 2, 0, 11),
	(24, 3, 1, 13, 2, 0, 12),
	(24, 3, 2, 1, 2, 0, 1),
	(24, 3, 2, 3, 2, 0, 3),
	(24, 3, 2, 4, 2, 0, 4),
	(24, 3, 2, 5, 2, 0, 5),
	(24, 3, 2, 5, 2, 1, 5),
	(24, 3, 2, 5, 2, 2, 5),
	(24, 3, 2, 5, 2, 3, 5),
	(24, 3, 2, 5, 2, 4, 5),
	(24, 3, 2, 5, 2, 5, 5),
	(24, 3, 2, 5, 2, 6, 5),
	(24, 3, 2, 5, 2, 7, 5),
	(24, 3, 2, 5, 2, 8, 5),
	(24, 3, 2, 6, 2, 0, 6),
	(24, 3, 2, 6, 2, 1, 6),
	(24, 3, 2, 6, 2, 2, 6),
	(24, 3, 2, 6, 2, 3, 6),
	(24, 3, 2, 6, 2, 4, 6),
	(24, 3, 2, 6, 2, 5, 6),
	(24, 3, 2, 6, 2, 6, 6),
	(24, 3, 2, 6, 2, 7, 6),
	(24, 3, 2, 6, 2, 8, 6),
	(24, 3, 2, 9, 2, 0, 8),
	(24, 3, 2, 11, 2, 0, 10),
	(24, 3, 2, 12, 2, 0, 11),
	(24, 3, 2, 13, 2, 0, 12),
	(24, 3, 5, 1, 2, 0, 1),
	(24, 3, 5, 3, 2, 0, 3),
	(24, 3, 5, 4, 2, 0, 4),
	(24, 3, 5, 5, 2, 0, 5),
	(24, 3, 5, 5, 2, 1, 5),
	(24, 3, 5, 5, 2, 2, 5),
	(24, 3, 5, 5, 2, 3, 5),
	(24, 3, 5, 5, 2, 4, 5),
	(24, 3, 5, 5, 2, 5, 5),
	(24, 3, 5, 5, 2, 6, 5),
	(24, 3, 5, 5, 2, 7, 5),
	(24, 3, 5, 5, 2, 8, 5),
	(24, 3, 5, 6, 2, 0, 6),
	(24, 3, 5, 6, 2, 1, 6),
	(24, 3, 5, 6, 2, 2, 6),
	(24, 3, 5, 6, 2, 3, 6),
	(24, 3, 5, 6, 2, 4, 6),
	(24, 3, 5, 6, 2, 5, 6),
	(24, 3, 5, 6, 2, 6, 6),
	(24, 3, 5, 6, 2, 7, 6),
	(24, 3, 5, 6, 2, 8, 6),
	(24, 3, 5, 9, 2, 0, 8),
	(24, 3, 5, 11, 2, 0, 10),
	(24, 3, 5, 12, 2, 0, 11),
	(24, 3, 5, 13, 2, 0, 12),
	(24, 3, 6, 1, 2, 0, 1),
	(24, 3, 6, 3, 2, 0, 3),
	(24, 3, 6, 4, 2, 0, 4),
	(24, 3, 6, 5, 2, 0, 5),
	(24, 3, 6, 5, 2, 1, 5),
	(24, 3, 6, 5, 2, 2, 5),
	(24, 3, 6, 5, 2, 3, 5),
	(24, 3, 6, 5, 2, 4, 5),
	(24, 3, 6, 5, 2, 5, 5),
	(24, 3, 6, 5, 2, 6, 5),
	(24, 3, 6, 5, 2, 7, 5),
	(24, 3, 6, 5, 2, 8, 5),
	(24, 3, 6, 6, 2, 0, 6),
	(24, 3, 6, 6, 2, 1, 6),
	(24, 3, 6, 6, 2, 2, 6),
	(24, 3, 6, 6, 2, 3, 6),
	(24, 3, 6, 6, 2, 4, 6),
	(24, 3, 6, 6, 2, 5, 6),
	(24, 3, 6, 6, 2, 6, 6),
	(24, 3, 6, 6, 2, 7, 6),
	(24, 3, 6, 6, 2, 8, 6),
	(24, 3, 6, 9, 2, 0, 8),
	(24, 3, 6, 11, 2, 0, 10),
	(24, 3, 6, 12, 2, 0, 11),
	(24, 3, 6, 13, 2, 0, 12),
	(24, 3, 7, 1, 2, 0, 1),
	(24, 3, 7, 3, 2, 0, 3),
	(24, 3, 7, 4, 2, 0, 4),
	(24, 3, 7, 5, 2, 0, 5),
	(24, 3, 7, 5, 2, 1, 5),
	(24, 3, 7, 5, 2, 2, 5),
	(24, 3, 7, 5, 2, 3, 5),
	(24, 3, 7, 5, 2, 4, 5),
	(24, 3, 7, 5, 2, 5, 5),
	(24, 3, 7, 5, 2, 6, 5),
	(24, 3, 7, 5, 2, 7, 5),
	(24, 3, 7, 5, 2, 8, 5),
	(24, 3, 7, 6, 2, 0, 6),
	(24, 3, 7, 6, 2, 1, 6),
	(24, 3, 7, 6, 2, 2, 6),
	(24, 3, 7, 6, 2, 3, 6),
	(24, 3, 7, 6, 2, 4, 6),
	(24, 3, 7, 6, 2, 5, 6),
	(24, 3, 7, 6, 2, 6, 6),
	(24, 3, 7, 6, 2, 7, 6),
	(24, 3, 7, 6, 2, 8, 6),
	(24, 3, 7, 9, 2, 0, 8),
	(24, 3, 7, 11, 2, 0, 10),
	(24, 3, 7, 12, 2, 0, 11),
	(24, 3, 7, 13, 2, 0, 12),
	(24, 3, 8, 1, 2, 0, 1),
	(24, 3, 8, 3, 2, 0, 3),
	(24, 3, 8, 4, 2, 0, 4),
	(24, 3, 8, 5, 2, 0, 5),
	(24, 3, 8, 5, 2, 1, 5),
	(24, 3, 8, 5, 2, 2, 5),
	(24, 3, 8, 5, 2, 3, 5),
	(24, 3, 8, 5, 2, 4, 5),
	(24, 3, 8, 5, 2, 5, 5),
	(24, 3, 8, 5, 2, 6, 5),
	(24, 3, 8, 5, 2, 7, 5),
	(24, 3, 8, 5, 2, 8, 5),
	(24, 3, 8, 6, 2, 0, 6),
	(24, 3, 8, 6, 2, 1, 6),
	(24, 3, 8, 6, 2, 2, 6),
	(24, 3, 8, 6, 2, 3, 6),
	(24, 3, 8, 6, 2, 4, 6),
	(24, 3, 8, 6, 2, 5, 6),
	(24, 3, 8, 6, 2, 6, 6),
	(24, 3, 8, 6, 2, 7, 6),
	(24, 3, 8, 6, 2, 8, 6),
	(24, 3, 8, 9, 2, 0, 8),
	(24, 3, 8, 11, 2, 0, 10),
	(24, 3, 8, 12, 2, 0, 11),
	(24, 3, 8, 13, 2, 0, 12),
	(25, 1, 1, 3, 3, 0, 3),
	(25, 1, 1, 8, 2, 0, 5),
	(25, 1, 1, 8, 2, 0, 7),
	(25, 1, 1, 8, 2, 1, 7),
	(25, 1, 1, 8, 2, 2, 7),
	(25, 1, 1, 8, 2, 3, 7),
	(25, 1, 2, 3, 3, 0, 3),
	(25, 1, 2, 8, 2, 0, 5),
	(25, 1, 2, 8, 2, 0, 7),
	(25, 1, 2, 8, 2, 1, 7),
	(25, 1, 2, 8, 2, 2, 7),
	(25, 1, 2, 8, 2, 3, 7),
	(25, 3, 1, 3, 3, 0, 3),
	(25, 3, 1, 8, 2, 0, 5),
	(25, 3, 1, 8, 2, 0, 7),
	(25, 3, 1, 8, 2, 1, 7),
	(25, 3, 1, 8, 2, 2, 7),
	(25, 3, 1, 8, 2, 3, 7),
	(25, 3, 2, 3, 3, 0, 3),
	(25, 3, 2, 8, 2, 0, 5),
	(25, 3, 2, 8, 2, 0, 7),
	(25, 3, 2, 8, 2, 1, 7),
	(25, 3, 2, 8, 2, 2, 7),
	(25, 3, 2, 8, 2, 3, 7),
	(25, 3, 5, 8, 2, 0, 5),
	(25, 3, 5, 8, 2, 0, 7),
	(25, 3, 5, 8, 2, 1, 7),
	(25, 3, 5, 8, 2, 2, 7),
	(25, 3, 5, 8, 2, 3, 7),
	(25, 3, 6, 8, 2, 0, 5),
	(25, 3, 6, 8, 2, 0, 7),
	(25, 3, 6, 8, 2, 1, 7),
	(25, 3, 6, 8, 2, 2, 7),
	(25, 3, 6, 8, 2, 3, 7),
	(25, 3, 7, 8, 2, 0, 5),
	(25, 3, 7, 8, 2, 0, 7),
	(25, 3, 7, 8, 2, 1, 7),
	(25, 3, 7, 8, 2, 2, 7),
	(25, 3, 7, 8, 2, 3, 7),
	(25, 3, 8, 8, 2, 0, 5),
	(25, 3, 8, 8, 2, 0, 7),
	(25, 3, 8, 8, 2, 1, 7),
	(25, 3, 8, 8, 2, 2, 7),
	(25, 3, 8, 8, 2, 3, 7),
	(39, 58, NULL, 8, NULL, 0, NULL),
	(39, 61, NULL, 8, NULL, 0, NULL);
/*!40000 ALTER TABLE `xf_type_ml_filter` ENABLE KEYS */;

-- Dumping structure for table emcor.xf_type_rc_filter
CREATE TABLE IF NOT EXISTS `xf_type_rc_filter` (
  `xf_type_id` smallint(5) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
  `rc_id` tinyint(3) unsigned NOT NULL COMMENT 'Užklausų priežasties identifikatorius',
  `depth_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Gylio atvaizdavimo požymis',
  `lag_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Poslinkio atvaizdavimo požymis',
  `per_enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT 'Laiko periodų, atitinkančių formos diskretiškumą, atvaizdavimo požymis',
  PRIMARY KEY (`xf_type_id`,`rc_id`),
  CONSTRAINT `xf_type_rc_filter_xf_type_fk` FOREIGN KEY (`xf_type_id`) REFERENCES `xf_type` (`xf_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.xf_type_rc_filter: ~0 rows (approximately)
/*!40000 ALTER TABLE `xf_type_rc_filter` DISABLE KEYS */;
/*!40000 ALTER TABLE `xf_type_rc_filter` ENABLE KEYS */;

-- Dumping structure for table emcor.xf_type_rpp
CREATE TABLE IF NOT EXISTS `xf_type_rpp` (
  `xf_type_id` smallint(5) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
  `rpp_id` mediumint(8) unsigned NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo identifikatorius',
  PRIMARY KEY (`xf_type_id`,`rpp_id`),
  KEY `xf_type_rpp_rpp_i` (`rpp_id`),
  CONSTRAINT `xf_type_rpp_rpp_fk` FOREIGN KEY (`rpp_id`) REFERENCES `rpp` (`rpp_id`) ON DELETE CASCADE,
  CONSTRAINT `xf_type_rpp_xf_type_fk` FOREIGN KEY (`xf_type_id`) REFERENCES `xf_type` (`xf_type_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apsikeitimo duomenimis formų tipų ir protokolų priklausomybė';

-- Dumping data for table emcor.xf_type_rpp: ~73 rows (approximately)
/*!40000 ALTER TABLE `xf_type_rpp` DISABLE KEYS */;
INSERT INTO `xf_type_rpp` (`xf_type_id`, `rpp_id`) VALUES
	(1, 1),
	(1, 7),
	(2, 1),
	(2, 7),
	(3, 1),
	(3, 7),
	(4, 1),
	(5, 3),
	(6, 1),
	(6, 7),
	(7, 1),
	(7, 7),
	(8, 4),
	(8, 5),
	(9, 4),
	(9, 5),
	(10, 1),
	(10, 4),
	(10, 8),
	(14, 1),
	(14, 8),
	(15, 1),
	(15, 4),
	(15, 5),
	(15, 7),
	(15, 8),
	(16, 1),
	(16, 4),
	(16, 5),
	(16, 7),
	(16, 8),
	(17, 1),
	(17, 4),
	(17, 5),
	(17, 7),
	(17, 8),
	(18, 1),
	(18, 4),
	(18, 5),
	(18, 7),
	(18, 8),
	(19, 1),
	(19, 4),
	(19, 5),
	(19, 8),
	(20, 1),
	(21, 1),
	(22, 1),
	(23, 9),
	(24, 9),
	(25, 1),
	(28, 8),
	(29, 3),
	(30, 1),
	(31, 11),
	(32, 1),
	(32, 12),
	(33, 1),
	(33, 13),
	(34, 4),
	(34, 5),
	(35, 1),
	(35, 4),
	(36, 3),
	(37, 1),
	(37, 4),
	(37, 8),
	(37, 15),
	(38, 1),
	(39, 1),
	(39, 4),
	(39, 5),
	(39, 8);
/*!40000 ALTER TABLE `xf_type_rpp` ENABLE KEYS */;

-- Dumping structure for table emcor.xf_type_xe
CREATE TABLE IF NOT EXISTS `xf_type_xe` (
  `xf_type_id` smallint(5) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
  `xe_id` int(10) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis elemento identifikatorius',
  PRIMARY KEY (`xf_type_id`,`xe_id`),
  KEY `xf_type_xe_xe_i` (`xe_id`),
  CONSTRAINT `xf_type_xe_xe_fk` FOREIGN KEY (`xe_id`) REFERENCES `xe` (`xe_id`),
  CONSTRAINT `xf_type_xe_xf_type_fk` FOREIGN KEY (`xf_type_id`) REFERENCES `xf_type` (`xf_type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apsikeitimo duomenimis elementai pagal formų tipus';

-- Dumping data for table emcor.xf_type_xe: ~214 rows (approximately)
/*!40000 ALTER TABLE `xf_type_xe` DISABLE KEYS */;
INSERT INTO `xf_type_xe` (`xf_type_id`, `xe_id`) VALUES
	(1, 1),
	(1, 2),
	(1, 3),
	(1, 4),
	(1, 11),
	(1, 12),
	(1, 13),
	(1, 14),
	(2, 1),
	(2, 2),
	(2, 3),
	(2, 4),
	(2, 11),
	(2, 12),
	(2, 13),
	(2, 14),
	(4, 1),
	(4, 2),
	(4, 3),
	(4, 4),
	(6, 1),
	(6, 2),
	(6, 3),
	(6, 4),
	(6, 11),
	(6, 12),
	(6, 13),
	(6, 14),
	(7, 1),
	(7, 2),
	(7, 3),
	(7, 4),
	(7, 11),
	(7, 12),
	(7, 13),
	(7, 14),
	(8, 15),
	(8, 16),
	(8, 17),
	(8, 18),
	(10, 177),
	(10, 178),
	(10, 179),
	(10, 180),
	(10, 181),
	(10, 182),
	(10, 183),
	(10, 184),
	(14, 19),
	(14, 20),
	(14, 21),
	(14, 22),
	(14, 23),
	(14, 24),
	(14, 25),
	(14, 26),
	(14, 27),
	(14, 28),
	(14, 29),
	(14, 30),
	(14, 31),
	(14, 32),
	(14, 33),
	(14, 34),
	(14, 35),
	(14, 36),
	(14, 37),
	(14, 38),
	(14, 39),
	(14, 40),
	(14, 41),
	(14, 42),
	(14, 43),
	(14, 44),
	(14, 45),
	(14, 46),
	(14, 47),
	(14, 48),
	(14, 49),
	(14, 50),
	(14, 51),
	(14, 52),
	(14, 53),
	(14, 54),
	(14, 55),
	(14, 56),
	(14, 57),
	(14, 58),
	(14, 59),
	(14, 60),
	(14, 61),
	(14, 62),
	(14, 63),
	(14, 64),
	(14, 65),
	(14, 66),
	(14, 67),
	(14, 68),
	(14, 69),
	(14, 70),
	(14, 71),
	(14, 72),
	(14, 73),
	(14, 74),
	(14, 75),
	(14, 76),
	(14, 77),
	(14, 78),
	(14, 79),
	(14, 80),
	(14, 81),
	(14, 82),
	(14, 83),
	(14, 84),
	(25, 1),
	(25, 2),
	(25, 3),
	(25, 4),
	(30, 85),
	(30, 86),
	(30, 87),
	(30, 90),
	(30, 91),
	(30, 92),
	(32, 93),
	(32, 94),
	(32, 95),
	(32, 96),
	(32, 97),
	(32, 98),
	(32, 99),
	(32, 100),
	(32, 101),
	(32, 102),
	(32, 103),
	(32, 104),
	(32, 105),
	(32, 106),
	(32, 107),
	(32, 108),
	(32, 109),
	(32, 110),
	(32, 111),
	(32, 112),
	(32, 113),
	(32, 114),
	(32, 115),
	(32, 116),
	(32, 117),
	(32, 118),
	(32, 119),
	(32, 120),
	(32, 121),
	(32, 122),
	(32, 123),
	(32, 124),
	(32, 125),
	(32, 126),
	(32, 127),
	(32, 128),
	(32, 129),
	(32, 130),
	(32, 131),
	(32, 132),
	(32, 133),
	(32, 134),
	(32, 135),
	(32, 136),
	(32, 137),
	(32, 138),
	(32, 139),
	(32, 140),
	(32, 141),
	(32, 142),
	(32, 143),
	(32, 144),
	(32, 145),
	(32, 146),
	(32, 147),
	(32, 148),
	(32, 149),
	(32, 150),
	(32, 151),
	(32, 152),
	(32, 153),
	(32, 154),
	(32, 155),
	(32, 156),
	(32, 157),
	(32, 158),
	(32, 159),
	(32, 160),
	(32, 161),
	(32, 162),
	(32, 163),
	(32, 164),
	(32, 165),
	(32, 166),
	(32, 167),
	(32, 168),
	(32, 169),
	(32, 170),
	(32, 171),
	(32, 172),
	(32, 173),
	(32, 174),
	(32, 175),
	(32, 176),
	(35, 1),
	(35, 2),
	(35, 3),
	(35, 4),
	(37, 185),
	(37, 186);
/*!40000 ALTER TABLE `xf_type_xe` ENABLE KEYS */;

-- Dumping structure for table emcor.xf_type_xfau_type
CREATE TABLE IF NOT EXISTS `xf_type_xfau_type` (
  `xf_type_id` smallint(5) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
  `xfau_type_id` smallint(5) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formų mazgų tipo identifikatorius',
  PRIMARY KEY (`xf_type_id`,`xfau_type_id`),
  KEY `xf_type_xfau_type_xfau_type_i` (`xfau_type_id`),
  CONSTRAINT `xf_type_xfau_type_xf_type_fk` FOREIGN KEY (`xf_type_id`) REFERENCES `xf_type` (`xf_type_id`),
  CONSTRAINT `xf_type_xfau_type_xfau_type_fk` FOREIGN KEY (`xfau_type_id`) REFERENCES `xfau_type` (`xfau_type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Apsikeitimo duomenimis formų mazgų tipai pagal formų tipus';

-- Dumping data for table emcor.xf_type_xfau_type: ~51 rows (approximately)
/*!40000 ALTER TABLE `xf_type_xfau_type` DISABLE KEYS */;
INSERT INTO `xf_type_xfau_type` (`xf_type_id`, `xfau_type_id`) VALUES
	(1, 1),
	(1, 3),
	(1, 4),
	(1, 5),
	(2, 1),
	(2, 3),
	(2, 4),
	(2, 5),
	(3, 7),
	(3, 8),
	(4, 1),
	(4, 3),
	(4, 4),
	(4, 5),
	(5, 1),
	(6, 1),
	(6, 3),
	(6, 4),
	(6, 5),
	(7, 1),
	(7, 9),
	(8, 1),
	(9, 1),
	(10, 1),
	(14, 4),
	(15, 1),
	(16, 1),
	(17, 1),
	(18, 1),
	(19, 1),
	(20, 1),
	(21, 1),
	(22, 1),
	(22, 4),
	(23, 1),
	(23, 4),
	(24, 1),
	(24, 4),
	(25, 1),
	(28, 1),
	(29, 1),
	(30, 1),
	(31, 1),
	(32, 1),
	(33, 1),
	(34, 1),
	(35, 1),
	(36, 8),
	(37, 1),
	(38, 1),
	(39, 1);
/*!40000 ALTER TABLE `xf_type_xfau_type` ENABLE KEYS */;

-- Dumping structure for table emcor.xf_type_xpty
CREATE TABLE IF NOT EXISTS `xf_type_xpty` (
  `xf_type_id` smallint(5) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
  `xpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formų savybės identifikatorius',
  `xf_import` tinyint(1) DEFAULT NULL COMMENT 'Importo/eksporto formos požymis',
  `xpty_default_value` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Apsikeitimo duomenimis formos savybės reikšmė pagal nutylėjimą',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  `xpty_nr` mediumint(8) unsigned DEFAULT NULL COMMENT 'Apsikeitimo duomenimis formos savybės eilės numeris rušiavimui',
  PRIMARY KEY (`xf_type_id`,`xpty_id`),
  KEY `xf_type_xpty_enum_i` (`enum_id`),
  KEY `xf_type_xpty_xpty_i` (`xpty_id`),
  CONSTRAINT `xf_type_xpty_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`) ON DELETE SET NULL,
  CONSTRAINT `xf_type_xpty_xf_type_fk` FOREIGN KEY (`xf_type_id`) REFERENCES `xf_type` (`xf_type_id`),
  CONSTRAINT `xf_type_xpty_xpty_fk` FOREIGN KEY (`xpty_id`) REFERENCES `xpty` (`xpty_id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apsikeitimo duomenimis formų galimos savybės pagal formų tipus';

-- Dumping data for table emcor.xf_type_xpty: ~171 rows (approximately)
/*!40000 ALTER TABLE `xf_type_xpty` DISABLE KEYS */;
INSERT INTO `xf_type_xpty` (`xf_type_id`, `xpty_id`, `xf_import`, `xpty_default_value`, `enum_id`, `xpty_nr`) VALUES
	(1, 8, NULL, NULL, NULL, NULL),
	(1, 9, NULL, NULL, NULL, NULL),
	(1, 10, NULL, NULL, NULL, NULL),
	(1, 11, NULL, NULL, NULL, NULL),
	(1, 12, 1, NULL, NULL, NULL),
	(1, 13, NULL, NULL, NULL, NULL),
	(1, 53, 0, NULL, NULL, NULL),
	(1, 54, 0, NULL, NULL, NULL),
	(1, 55, 0, NULL, NULL, NULL),
	(1, 56, 0, NULL, NULL, NULL),
	(1, 57, 0, NULL, NULL, NULL),
	(1, 58, 0, NULL, NULL, NULL),
	(1, 68, 0, NULL, 880, NULL),
	(1, 69, 0, NULL, 881, NULL),
	(1, 70, 1, NULL, 82, NULL),
	(2, 8, NULL, NULL, NULL, NULL),
	(2, 9, NULL, NULL, NULL, NULL),
	(2, 10, NULL, NULL, NULL, NULL),
	(2, 11, NULL, NULL, NULL, NULL),
	(2, 12, 1, NULL, NULL, NULL),
	(2, 14, NULL, NULL, NULL, NULL),
	(3, 8, NULL, NULL, NULL, NULL),
	(3, 9, NULL, NULL, NULL, NULL),
	(3, 10, NULL, NULL, NULL, NULL),
	(3, 11, NULL, NULL, NULL, NULL),
	(3, 13, NULL, NULL, NULL, NULL),
	(4, 9, NULL, NULL, NULL, NULL),
	(4, 13, 0, NULL, NULL, NULL),
	(4, 17, NULL, NULL, NULL, NULL),
	(4, 18, NULL, NULL, NULL, NULL),
	(4, 19, NULL, NULL, NULL, NULL),
	(4, 20, NULL, NULL, NULL, NULL),
	(4, 21, 0, NULL, NULL, NULL),
	(4, 22, 0, NULL, NULL, NULL),
	(4, 33, NULL, NULL, NULL, NULL),
	(4, 34, NULL, NULL, NULL, NULL),
	(4, 35, NULL, NULL, NULL, NULL),
	(4, 36, NULL, NULL, NULL, NULL),
	(4, 37, NULL, NULL, NULL, NULL),
	(4, 44, NULL, NULL, NULL, NULL),
	(4, 51, 0, NULL, NULL, NULL),
	(4, 52, 0, NULL, NULL, NULL),
	(5, 1, NULL, NULL, NULL, NULL),
	(5, 2, NULL, NULL, NULL, NULL),
	(5, 3, NULL, NULL, NULL, NULL),
	(5, 4, NULL, NULL, NULL, NULL),
	(5, 5, NULL, NULL, NULL, NULL),
	(5, 24, NULL, NULL, NULL, NULL),
	(5, 25, NULL, NULL, NULL, NULL),
	(5, 26, NULL, NULL, NULL, NULL),
	(5, 32, NULL, NULL, NULL, NULL),
	(5, 43, 0, NULL, NULL, NULL),
	(5, 49, NULL, NULL, NULL, NULL),
	(5, 50, NULL, NULL, NULL, NULL),
	(6, 8, NULL, NULL, NULL, NULL),
	(6, 9, NULL, NULL, NULL, NULL),
	(6, 10, NULL, NULL, NULL, NULL),
	(6, 11, NULL, NULL, NULL, NULL),
	(6, 12, 1, NULL, NULL, NULL),
	(6, 13, NULL, NULL, NULL, NULL),
	(6, 53, 0, NULL, NULL, NULL),
	(6, 54, 0, NULL, NULL, NULL),
	(6, 55, 0, NULL, NULL, NULL),
	(6, 56, 0, NULL, NULL, NULL),
	(6, 57, 0, NULL, NULL, NULL),
	(6, 58, 0, NULL, NULL, NULL),
	(7, 8, NULL, NULL, NULL, NULL),
	(7, 9, NULL, NULL, NULL, NULL),
	(7, 10, NULL, NULL, NULL, NULL),
	(7, 11, NULL, NULL, NULL, NULL),
	(7, 12, NULL, NULL, NULL, NULL),
	(7, 15, NULL, NULL, NULL, NULL),
	(8, 9, 0, NULL, NULL, NULL),
	(9, 9, 0, NULL, NULL, NULL),
	(9, 16, 0, NULL, NULL, NULL),
	(10, 10, 0, NULL, NULL, NULL),
	(10, 35, 0, NULL, 481, NULL),
	(10, 45, 1, NULL, NULL, NULL),
	(10, 65, 0, '1', 82, NULL),
	(10, 66, 0, '0', 82, NULL),
	(10, 72, 1, NULL, NULL, NULL),
	(14, 23, 0, NULL, NULL, NULL),
	(15, 27, 0, NULL, NULL, NULL),
	(15, 28, 0, NULL, NULL, NULL),
	(15, 29, 0, NULL, NULL, NULL),
	(15, 30, 0, NULL, NULL, NULL),
	(15, 31, 0, NULL, NULL, NULL),
	(16, 27, 0, NULL, NULL, NULL),
	(16, 28, 0, NULL, NULL, NULL),
	(16, 29, 0, NULL, NULL, NULL),
	(16, 30, 0, NULL, NULL, NULL),
	(16, 31, 0, NULL, NULL, NULL),
	(17, 27, 0, NULL, NULL, NULL),
	(17, 28, 0, NULL, NULL, NULL),
	(17, 29, 0, NULL, NULL, NULL),
	(17, 30, 0, NULL, NULL, NULL),
	(17, 31, 0, NULL, NULL, NULL),
	(18, 27, 0, NULL, NULL, NULL),
	(18, 28, 0, NULL, NULL, NULL),
	(18, 29, 0, NULL, NULL, NULL),
	(18, 30, 0, NULL, NULL, NULL),
	(18, 31, 0, NULL, NULL, NULL),
	(19, 9, NULL, NULL, NULL, NULL),
	(19, 45, NULL, NULL, NULL, NULL),
	(19, 66, NULL, NULL, NULL, NULL),
	(19, 67, NULL, NULL, 879, NULL),
	(20, 9, NULL, NULL, NULL, NULL),
	(20, 10, NULL, NULL, NULL, NULL),
	(20, 38, NULL, NULL, NULL, NULL),
	(20, 39, NULL, NULL, NULL, NULL),
	(20, 40, NULL, NULL, NULL, NULL),
	(20, 41, NULL, NULL, NULL, NULL),
	(20, 42, NULL, NULL, NULL, NULL),
	(20, 46, NULL, NULL, NULL, NULL),
	(21, 9, NULL, NULL, NULL, NULL),
	(21, 10, NULL, NULL, NULL, NULL),
	(21, 38, NULL, NULL, NULL, NULL),
	(21, 39, NULL, NULL, NULL, NULL),
	(21, 40, NULL, NULL, NULL, NULL),
	(21, 41, NULL, NULL, NULL, NULL),
	(21, 42, NULL, NULL, NULL, NULL),
	(21, 46, NULL, NULL, NULL, NULL),
	(22, 9, NULL, NULL, NULL, NULL),
	(22, 10, NULL, NULL, NULL, NULL),
	(22, 38, NULL, NULL, NULL, NULL),
	(22, 39, NULL, NULL, NULL, NULL),
	(22, 40, NULL, NULL, NULL, NULL),
	(22, 41, NULL, NULL, NULL, NULL),
	(22, 42, NULL, NULL, NULL, NULL),
	(22, 44, NULL, NULL, NULL, NULL),
	(22, 46, NULL, NULL, NULL, NULL),
	(23, 10, NULL, NULL, NULL, NULL),
	(24, 10, NULL, NULL, NULL, NULL),
	(25, 10, NULL, NULL, NULL, NULL),
	(25, 38, NULL, NULL, NULL, NULL),
	(25, 39, NULL, NULL, NULL, NULL),
	(25, 64, 1, NULL, 82, NULL),
	(28, 9, NULL, NULL, NULL, NULL),
	(28, 38, NULL, NULL, NULL, NULL),
	(28, 39, NULL, NULL, NULL, NULL),
	(29, 24, NULL, NULL, NULL, NULL),
	(29, 25, NULL, NULL, NULL, NULL),
	(29, 32, NULL, NULL, NULL, NULL),
	(29, 47, NULL, NULL, NULL, NULL),
	(29, 48, NULL, NULL, NULL, NULL),
	(29, 49, NULL, NULL, NULL, NULL),
	(29, 50, NULL, NULL, NULL, NULL),
	(29, 59, 1, '3', 784, NULL),
	(30, 9, NULL, NULL, NULL, NULL),
	(30, 25, NULL, NULL, NULL, NULL),
	(30, 45, NULL, NULL, NULL, NULL),
	(33, 6, NULL, NULL, NULL, NULL),
	(33, 38, NULL, NULL, NULL, NULL),
	(33, 39, NULL, NULL, NULL, NULL),
	(33, 60, 0, NULL, 785, NULL),
	(33, 61, 0, NULL, 82, NULL),
	(34, 9, NULL, NULL, NULL, NULL),
	(34, 71, 0, '2', 891, NULL),
	(35, 9, NULL, NULL, NULL, NULL),
	(35, 38, NULL, NULL, NULL, NULL),
	(35, 39, NULL, NULL, NULL, NULL),
	(35, 62, NULL, NULL, NULL, NULL),
	(35, 63, NULL, NULL, NULL, NULL),
	(37, 38, 0, NULL, NULL, NULL),
	(37, 39, 0, '$$', NULL, NULL),
	(37, 45, NULL, NULL, NULL, NULL),
	(37, 65, 0, '1', 82, NULL),
	(38, 38, 0, '$$Sender_Code$$$$DataDate:YYYYMMDD$$.dbf', NULL, NULL),
	(38, 39, 0, '$$', NULL, NULL),
	(38, 45, NULL, NULL, NULL, NULL),
	(39, 9, 0, NULL, NULL, NULL);
/*!40000 ALTER TABLE `xf_type_xpty` ENABLE KEYS */;

-- Dumping structure for table emcor.xf_xpty
CREATE TABLE IF NOT EXISTS `xf_xpty` (
  `xf_id` mediumint(8) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formos identifikatorius',
  `xpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formų savybės identifikatorius',
  `xpty_value` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Apsikeitimo duomenimis formos savybės reikšmė',
  PRIMARY KEY (`xf_id`,`xpty_id`),
  KEY `xf_xpty_xpty_i` (`xpty_id`),
  CONSTRAINT `xf_xpty_xf_fk` FOREIGN KEY (`xf_id`) REFERENCES `xf` (`xf_id`) ON DELETE CASCADE,
  CONSTRAINT `xf_xpty_xpty_fk` FOREIGN KEY (`xpty_id`) REFERENCES `xpty` (`xpty_id`),
  CONSTRAINT `XF_XPTY_SYMBOL_CHECK` CHECK (nullif(regexp_replace(`xpty_value`,'([[:print:]])+',''),'') is null)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apsikeitimo duomenimis formų savybės';

-- Dumping data for table emcor.xf_xpty: ~0 rows (approximately)
/*!40000 ALTER TABLE `xf_xpty` DISABLE KEYS */;
/*!40000 ALTER TABLE `xf_xpty` ENABLE KEYS */;

-- Dumping structure for table emcor.xo
CREATE TABLE IF NOT EXISTS `xo` (
  `xo_id` bigint(20) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis operacijos identifikatorius',
  `xo_time` datetime NOT NULL COMMENT 'Apsikeitimo duomenimis operacijos laikas',
  `xf_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Apsikeitimo duomenimis formos identifikatorius',
  `xo_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis operacijų tipo identifikatorius',
  `xo_bt` datetime NOT NULL COMMENT 'Duomenų periodo pradžia',
  `xo_et` datetime DEFAULT NULL COMMENT 'Duomenų periodo pabaiga',
  `xo_info` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Apsikeitimo duomenimis operacijos papildoma informacija',
  `xo_tech_info` varchar(120) COLLATE utf8_bin DEFAULT NULL COMMENT 'Apsikeitimo duomenimis operacijos papildoma techninė informacija',
  `xo_info2` varchar(250) COLLATE utf8_bin DEFAULT NULL,
  `doc_nr` varchar(50) COLLATE utf8_bin DEFAULT NULL COMMENT 'Dokumento numeris',
  `das_id` smallint(5) unsigned DEFAULT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius',
  PRIMARY KEY (`xo_id`),
  KEY `xo_bt_xf_i` (`xo_bt`,`xf_id`,`xo_time`),
  KEY `xo_xf_i` (`xf_id`,`xo_time`),
  KEY `xo_xo_type_i` (`xo_type_id`),
  CONSTRAINT `xo_xf_fk` FOREIGN KEY (`xf_id`) REFERENCES `xf` (`xf_id`) ON DELETE CASCADE,
  CONSTRAINT `xo_xo_type_fk` FOREIGN KEY (`xo_type_id`) REFERENCES `xo_type` (`xo_type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apsikeitimo duomenimis operacijos';

-- Dumping data for table emcor.xo: ~0 rows (approximately)
/*!40000 ALTER TABLE `xo` DISABLE KEYS */;
/*!40000 ALTER TABLE `xo` ENABLE KEYS */;

-- Dumping structure for table emcor.xou
CREATE TABLE IF NOT EXISTS `xou` (
  `xo_id` int(10) unsigned NOT NULL,
  PRIMARY KEY (`xo_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Dumping data for table emcor.xou: ~0 rows (approximately)
/*!40000 ALTER TABLE `xou` DISABLE KEYS */;
/*!40000 ALTER TABLE `xou` ENABLE KEYS */;

-- Dumping structure for table emcor.xo_type
CREATE TABLE IF NOT EXISTS `xo_type` (
  `xo_type_id` mediumint(8) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis operacijų tipo identifikatorius',
  `xo_type_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Apsikeitimo duomenimis operacijų tipo pavadinimas',
  PRIMARY KEY (`xo_type_id`),
  UNIQUE KEY `xo_type_name_u` (`xo_type_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apsikeitimo duomenimis operacijų tipai';

-- Dumping data for table emcor.xo_type: ~18 rows (approximately)
/*!40000 ALTER TABLE `xo_type` DISABLE KEYS */;
INSERT INTO `xo_type` (`xo_type_id`, `xo_type_name`) VALUES
	(14, 'Dokumentas gautas, dalinai priimti duomenys'),
	(13, 'Dokumentas gautas, dokumentas nepriimtas'),
	(12, 'Dokumentas gautas, dokumentas priimtas'),
	(16, 'Dokumentas suformuotas tolimesniam apdorojimui'),
	(11, 'Dokumentas suformuotas, gavėjui nebuvo siunčiamas'),
	(5, 'Duomenys perduoti'),
	(7, 'Gautas dokumentas'),
	(3, 'Gautas pranešimas, kad dokumentas nepriimtas'),
	(2, 'Gautas pranešimas, kad dokumentas priimtas'),
	(4, 'Gautas pranešimas, kad kai kurie dokumento duomenys nepriimti'),
	(1, 'Išsiųstas dokumentas'),
	(0, 'Išsiųstas nepilnas dokumentas'),
	(9, 'Išsiųstas pranešimas, kad dokumentas nepriimtas'),
	(8, 'Išsiųstas pranešimas, kad dokumentas priimtas'),
	(10, 'Išsiųstas pranešimas, kad kai kurie dokumento duomenys nepriimti'),
	(6, 'Klaida'),
	(15, 'Nėra pirminių duomenų'),
	(17, 'Nėra pirminių duomenų "pagal skyles"');
/*!40000 ALTER TABLE `xo_type` ENABLE KEYS */;

-- Dumping structure for table emcor.xpty
CREATE TABLE IF NOT EXISTS `xpty` (
  `xpty_id` mediumint(8) unsigned NOT NULL COMMENT 'Apsikeitimo duomenimis formų savybės identifikatorius',
  `xpty_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Apsikeitimo duomenimis formų savybės kodas',
  `xpty_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Apsikeitimo duomenimis formų savybės pavadinimas',
  `enum_id` mediumint(8) unsigned DEFAULT NULL COMMENT 'Išvardinimo identifikatorius',
  PRIMARY KEY (`xpty_id`),
  UNIQUE KEY `xpty_code_u` (`xpty_code`),
  UNIQUE KEY `xpty_name_u` (`xpty_name`),
  KEY `xpty_enum_i` (`enum_id`),
  CONSTRAINT `xpty_enum_fk` FOREIGN KEY (`enum_id`) REFERENCES `enum` (`enum_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apsikeitimo duomenimis formų savybės';

-- Dumping data for table emcor.xpty: ~72 rows (approximately)
/*!40000 ALTER TABLE `xpty` DISABLE KEYS */;
INSERT INTO `xpty` (`xpty_id`, `xpty_code`, `xpty_name`, `enum_id`) VALUES
	(1, 'USE_SPLIT', 'Ar skaidyti formos duomenis pagal dydį', 82),
	(2, 'SPLIT_ON', 'Skaidyti pasiekus nurodytą įrašų ribą', NULL),
	(3, 'CONNECT_TIMEOUT', 'Susijungimo taimautas, sek', NULL),
	(4, 'SEND_TIMEOUT', 'Paketo siuntimo taimautas, sek', NULL),
	(5, 'GET_TIMEOUT', 'Atsakymo laukimo taimautas, sek', NULL),
	(6, 'ACK', 'Su gavimo patvirtinimu', 82),
	(7, 'SAVE_COPY', 'Saugoti kopijas', 82),
	(8, 'SIGNATURE', 'Naudoti elektroninį parašą', 82),
	(9, 'SENDER_NAME', 'Siuntėjo pavadinimas', NULL),
	(10, 'SENDER_INN', 'Siuntėjo INN', NULL),
	(11, 'AIIS_CODE', 'Automatizuotos apskaitos sistemos kodas', NULL),
	(12, 'REPLY_FROM', 'Adresas, iš kurio turi ateiti gavimo patvirtinimas', NULL),
	(13, 'DAY_OLD', 'Maksimalus apdorojamos informacijos gylis, dienomis', NULL),
	(14, 'KPOKOD', 'KPO organizacijos kodas', NULL),
	(15, 'DAYTYPE', 'Dienos tipas', 141),
	(16, 'MONTH_BACK_COUNT', 'Mėnesių atgal kiekis', NULL),
	(17, 'ASKP_PREFIX', 'ASKP failo prefiksas', NULL),
	(18, 'ASKP_EXTENTION', 'ASKP failo pabaiga', NULL),
	(19, 'ASKP_DATE_USE', 'Datos naudojimas ASKP dokumento pavadinime', 361),
	(20, 'ASKP_NUMBER_USE', 'Dokumento numerio naudojimas ASKP dokumento pavadinime', 82),
	(21, 'ASKP_POST_COMMA', 'Ženklų po kablelio skaičius ASKP dokumente', NULL),
	(22, 'ASKP_VERSION', 'ASKP failo versija', 362),
	(23, 'ARGE_Version', 'ARGE Version', NULL),
	(24, 'USE_ACT_DATA', 'Naudoti aktų informaciją', 82),
	(25, 'SEND_METER_NUMBER', 'Perduoti skaitiklio numerį', 82),
	(26, 'KEEP_SENDING_ON_CFG_MISMATCH', 'Kartoti siuntimą, aptikus konfigūracijos neatitikimo klaidas', 82),
	(27, 'FILENAME_DATA', 'Duomenų failo pavadinimas', NULL),
	(28, 'FILENAME_DATE', 'Datos failo pavadinimas', NULL),
	(29, 'FILENAME_TIME', 'Laiko failo pavadinimas', NULL),
	(30, 'FILENAME_DESC', 'Elementų failo pavadinimas', NULL),
	(31, 'FILENAME_LD', 'Kablelio vietos failo pavadinimas', NULL),
	(32, 'WHAT_TIME', 'Siųsti papildomai laiką', 467),
	(33, 'CODEPAGE', 'Koduotė', 476),
	(34, 'ASKP_UNIT', 'ASKP formos matavimo vienetai', 477),
	(35, 'EXPORT_TIMEZONE', 'Eksportuoti duomenis:', 481),
	(36, 'ASKP_DATE_MASK', 'Datos kaukė ASKP bylos varde', NULL),
	(37, 'ASKP_EMPTY_LINES_COUNT', 'Tuščių eilučių skaičius tarp techninės informacijos ir informacijos bloku ASKP byloje', NULL),
	(38, 'FILENAME_FORMAT', 'Bylos pavadinimo formatas', NULL),
	(39, 'FILENAME_FORMAT_DELIMITER', 'Skyriklis bylos pavadinimo formate', NULL),
	(40, 'HEADER_FORM_NAME', 'Formos pavadinimas pirmoje bylos eilutėje', NULL),
	(41, 'HEADER_DATE_FORMAT', 'Datos atvaizdavimas pirmoje bylos eilutėje', NULL),
	(42, 'FOOTER_SEPARATE_LINE', 'Specialių simbolių ==)) naudojimas paskutinėje bylos eilutėje', 82),
	(43, 'WS_Type', 'Web serviso tipas', 527),
	(44, 'SINGLE_MEASURE_MODE', 'Formos su vienetinio matavimo apskaitos mazgais požymis', 82),
	(45, 'SENDER_CODE', 'Siuntėjo kodas', NULL),
	(46, 'DATADATE_BEGIN_END', 'Duomenų datos atvaizdavimas išeities dokumente', 652),
	(47, 'SOURCE', 'Šaltinio identifikatorius', NULL),
	(48, 'USERID', 'Vartotojo identifikatorius', NULL),
	(49, 'SEND_RAW_VALUE', 'Siųsti originalią šaltinio reikšmę', 82),
	(50, 'USE_GENERATED_DATA', 'Naudoti generuojamus DB duomenis', 82),
	(51, 'ASKP_FORCED_TIME', 'Priverstinė TIME reikšmė', NULL),
	(52, 'ASKP_FORCED_LTIME', 'Priverstinė LTIME reikšmė', NULL),
	(53, 'av_peretok', 'Saldo parametrų skaičiavimo algoritmo versijos numeris', NULL),
	(54, 'av_deliverypoint_01', '01 kanalo tiekimo taško parametrų skaičiavimo algoritmo versijos numeris', NULL),
	(55, 'av_deliverypoint_02', '02 kanalo tiekimo taško parametrų skaičiavimo algoritmo versijos numeris', NULL),
	(56, 'av_deliverypoint_03', '03 kanalo tiekimo taško parametrų skaičiavimo algoritmo versijos numeris', NULL),
	(57, 'av_deliverypoint_04', '04 kanalo tiekimo taško parametrų skaičiavimo algoritmo versijos numeris', NULL),
	(58, 'av_deliverygroup', 'Tiekimo grupės parametrų skaičiavimo algoritmo versijos numeris', NULL),
	(59, 'ACTION', 'Importo procedūros duomenų įrašymo variantai', NULL),
	(60, 'FORCE_PERIOD', 'Priverstinis analizės gylis', NULL),
	(61, 'ONLY_MARGINAL_TOTALS', 'Ribinių suminių duomenų išdavimas', NULL),
	(62, 'Data_DateFormat', 'Dokumento datos formatas', NULL),
	(63, 'Data_DecimalSeparator', 'Dokumento duomenų skyriklis', NULL),
	(64, 'CHECKING_EMAIL_SENDER_ADDRESS', 'Siuntėjo pašto adreso tikrinimas', NULL),
	(65, 'EXPORT_IMPROVABLE', 'Eksportuoti pagerinamus rodmenis', 82),
	(66, 'ZERO_FILL_MISSING_VALUES', 'Eksportuoti nulius trūkstamiems eilutės matavimams', 82),
	(67, 'PROFILE_PERIOD', 'Duomenų profilio periodas, min', NULL),
	(68, 'ATS_PRECISION', 'Reikšmių formavimo variantas', NULL),
	(69, 'ATS_SEPARATOR', 'Trupmenų skyrybos ženklas', NULL),
	(70, 'Accept_Real_Data', 'Priimti nesveikus duomenis', NULL),
	(71, 'KANS_PRECISION', 'Reikšmių formavimo variantas', NULL),
	(72, 'FTP_REMOTEDIR', 'FTP REMOTE DIR', NULL);
/*!40000 ALTER TABLE `xpty` ENABLE KEYS */;

-- Dumping structure for table emcor.xs
CREATE TABLE IF NOT EXISTS `xs` (
  `xs_id` tinyint(3) unsigned NOT NULL COMMENT 'Apsikeitimo duomenų statuso identifikatorius',
  `xs_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT 'Apsikeitimo duomenų statuso kodas',
  `xs_name` varchar(120) COLLATE utf8_bin NOT NULL COMMENT 'Apsikeitimo duomenų statuso pavadinimas',
  PRIMARY KEY (`xs_id`),
  UNIQUE KEY `xs_code_u` (`xs_code`),
  UNIQUE KEY `xs_name_u` (`xs_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='Apsikeitimo duomenų statusai';

-- Dumping data for table emcor.xs: ~9 rows (approximately)
/*!40000 ALTER TABLE `xs` DISABLE KEYS */;
INSERT INTO `xs` (`xs_id`, `xs_code`, `xs_name`) VALUES
	(0, 'NO_ATTEMPT', 'Duomenys nebuvo perduodami'),
	(1, 'SENT', 'Duomenys perduoti'),
	(2, 'EXECUTION_ERROR', 'Duomenys neperduoti dėl vykdymo klaidos'),
	(3, 'UNKNOWN_UNIT', 'Duomenys neperduoti dėl nežinomo mazgo'),
	(4, 'UNKNOWN_ELEMENT', 'Duomenys neperduoti dėl nežinomo elemento'),
	(5, 'FORBIDDEN', 'Duomenys neperduoti dėl draudžiamo įrašymo'),
	(6, 'ALREADY_THERE', 'Tokie duomenys jau yra'),
	(7, 'CLOSED_PERIOD', 'Periodas uždarytas'),
	(8, 'METER_MISMATCH', 'Duomenys neperduoti dėl neatitinkančio skaitiklio numerio');
/*!40000 ALTER TABLE `xs` ENABLE KEYS */;

-- Dumping structure for view emcor.act_360$point
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `act_360$point` (
	`point_id` INT(10) UNSIGNED NULL,
	`cp_t` DATETIME NULL,
	`fp_id` INT(10) UNSIGNED NULL,
	`status` TINYINT(3) UNSIGNED NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.bgao_gttla
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `bgao_gttla` (
	`bgao_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'DB aplikacijos foninių užduočių vykdymo užsakymo ID'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.curr_das
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `curr_das` (
	`das_id` SMALLINT(5) UNSIGNED NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.curr_rodo_das
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `curr_rodo_das` (
	`rodo_id` INT(10) UNSIGNED NOT NULL,
	`das_id` SMALLINT(5) UNSIGNED NOT NULL COMMENT 'Duomenų surinkimo serverio identifikatorius'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.dqp$pldi
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `dqp$pldi` (
	`point_id` INT(10) UNSIGNED NULL,
	`pl_id` INT(10) UNSIGNED NULL,
	`pl_enabled` TINYINT(1) NULL,
	`ml_id` MEDIUMINT(8) UNSIGNED NULL,
	`md_id` SMALLINT(5) UNSIGNED NULL,
	`aggs_id` TINYINT(3) UNSIGNED NULL,
	`md_per_id` TINYINT(3) UNSIGNED NULL,
	`md_int_value` MEDIUMINT(8) UNSIGNED NULL,
	`aggs_type_id` TINYINT(3) UNSIGNED NULL,
	`di_id` INT(10) UNSIGNED NULL,
	`di_enabled` TINYINT(1) NULL,
	`bc` MEDIUMINT(8) UNSIGNED NULL,
	`src_type_internal` TINYINT(1) NULL,
	`mow_shift` FLOAT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.dqp$sesep
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `dqp$sesep` (
	`point_id` INT(10) UNSIGNED NULL,
	`pl_id` INT(10) UNSIGNED NULL,
	`se_enabled` TINYINT(1) NULL,
	`se_h` TINYINT(1) NULL,
	`se_h_per_id` TINYINT(3) UNSIGNED NULL,
	`se_h_depth` MEDIUMINT(8) UNSIGNED NULL,
	`se_h_bound` DATETIME NULL,
	`se_h_restore_depth` MEDIUMINT(8) UNSIGNED NULL,
	`se_h_restore_per_id` TINYINT(3) UNSIGNED NULL,
	`src_bt` DATETIME NULL,
	`src_et` DATETIME NULL,
	`src_enabled` TINYINT(1) NULL,
	`tz_id` SMALLINT(5) UNSIGNED NULL,
	`src_tz_dst_used` TINYINT(1) NULL,
	`src_type_id` INT(10) NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
	`src_type_internal` TINYINT(1) NULL,
	`dp_enabled` TINYINT(1) NULL,
	`dp_deleted` TINYINT(1) NULL,
	`sep_id` INT(10) UNSIGNED NULL,
	`sep_enabled` TINYINT(1) NULL,
	`sep_h_lag` MEDIUMINT(8) UNSIGNED NULL,
	`sep_h_depth` MEDIUMINT(8) UNSIGNED NULL,
	`sep_h_per_id` TINYINT(1) NULL,
	`sep_h_sch_id` MEDIUMINT(8) UNSIGNED NULL,
	`ph_enabled` TINYINT(1) NULL,
	`ph_deleted` TINYINT(1) NULL,
	`tzh_shift` TINYINT(3) UNSIGNED NULL,
	`ow_shift` FLOAT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.evla
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `evla` (
	`ev_time` DATETIME NULL,
	`ev_id` MEDIUMINT(8) UNSIGNED NOT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gen_adj$f0
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gen_adj$f0` (
	`da` DATE NULL COMMENT 'Diena',
	`bga_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'DB aplikacijos foninės užduoties ID',
	`src_name` VARCHAR(120) NULL COMMENT 'Šaltinio pavadinimas' COLLATE 'utf8_bin',
	`ml_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Matavimo linijos identifikatorius',
	`tpl_id` INT(10) UNSIGNED NULL,
	`sep_id` INT(10) UNSIGNED NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
	`point_id` INT(10) UNSIGNED NULL COMMENT 'Matavimo taško identifikatorius',
	`mou_id` INT(10) UNSIGNED NULL COMMENT 'Montažo identifikatorius',
	`mou_bt` DATETIME NULL COMMENT 'Montavimo data',
	`mou_et` DATETIME NULL COMMENT 'Išmontavimo data',
	`meter_id` INT(10) UNSIGNED NULL COMMENT 'Matavimo priemonės identifikatorius',
	`ms_id` SMALLINT(5) UNSIGNED NULL COMMENT 'Matavimo identifikatorius',
	`dir_id` TINYINT(4) NULL COMMENT 'Krypties identifikatorius',
	`tff_id` TINYINT(3) UNSIGNED NULL COMMENT 'Tarifo identifikatorius',
	`pl_id` INT(10) UNSIGNED NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
	`aggs_type_id` TINYINT(3) UNSIGNED NULL COMMENT 'Agregavimo segmento tipo identifikatorius'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gen_adj$f1
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gen_adj$f1` (
	`pl_t1` DATETIME NULL,
	`da` DATE NULL COMMENT 'Diena',
	`bga_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'DB aplikacijos foninės užduoties ID',
	`src_name` VARCHAR(120) NULL COMMENT 'Šaltinio pavadinimas' COLLATE 'utf8_bin',
	`ml_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Matavimo linijos identifikatorius',
	`tpl_id` INT(10) UNSIGNED NULL,
	`sep_id` INT(10) UNSIGNED NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
	`point_id` INT(10) UNSIGNED NULL COMMENT 'Matavimo taško identifikatorius',
	`mou_id` INT(10) UNSIGNED NULL COMMENT 'Montažo identifikatorius',
	`mou_bt` DATETIME NULL COMMENT 'Montavimo data',
	`mou_et` DATETIME NULL COMMENT 'Išmontavimo data',
	`meter_id` INT(10) UNSIGNED NULL COMMENT 'Matavimo priemonės identifikatorius',
	`ms_id` SMALLINT(5) UNSIGNED NULL COMMENT 'Matavimo identifikatorius',
	`dir_id` TINYINT(4) NULL COMMENT 'Krypties identifikatorius',
	`tff_id` TINYINT(3) UNSIGNED NULL COMMENT 'Tarifo identifikatorius',
	`pl_id` INT(10) UNSIGNED NULL COMMENT 'Matavimo linijos matavimo taške identifikatorius',
	`aggs_type_id` TINYINT(3) UNSIGNED NULL COMMENT 'Agregavimo segmento tipo identifikatorius'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gr_filter
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gr_filter` (
	`gr_filter_visibility` TINYINT(1) NOT NULL COMMENT 'Grupių sujungimo matomumo požymis',
	`gr_filter_oper` TINYINT(1) NOT NULL COMMENT 'Grupių sujungimo požymis (1 - sąjunga, 0 - sankirta)'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gr_filter_data
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gr_filter_data` (
	`gr_id` INT(10) UNSIGNED NOT NULL COMMENT 'Grupės identifikatorius',
	`visibility` TINYINT(1) NOT NULL COMMENT 'Grupės matomumo požymis'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gtree_ds
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gtree_ds` (
	`ds_id` INT(10) UNSIGNED NULL COMMENT 'Apskaitos būsenos signalo identifikatorius'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gtree_gr
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gtree_gr` (
	`gr_id` INT(10) UNSIGNED NULL COMMENT 'Grupės identifikatorius'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gtree_m
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gtree_m` (
	`ms_type_id` SMALLINT(5) UNSIGNED NULL COMMENT 'Matavimų tipo identifikatorius',
	`aggs_type_id` TINYINT(3) UNSIGNED NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
	`msf_id` SMALLINT(5) UNSIGNED NULL,
	`md_id` SMALLINT(5) UNSIGNED NULL,
	`dir_id` TINYINT(4) NULL,
	`ml_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Matavimo linijos identifikatorius',
	`sheaf_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Duomenų pluošto identifikatorius'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gtree_point
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gtree_point` (
	`point_id` INT(10) UNSIGNED NULL COMMENT 'Matavimo taško identifikatorius'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gtt5
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gtt5` (
	`point_id` INT(10) UNSIGNED NOT NULL,
	`withe_id` MEDIUMINT(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
	`sep_id` INT(10) UNSIGNED NOT NULL,
	`src_type_id` INT(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
	`di_id` INT(10) UNSIGNED NOT NULL,
	`dp_id` INT(10) UNSIGNED NOT NULL,
	`is_point` TINYINT(1) NOT NULL,
	`ind1` MEDIUMINT(8) UNSIGNED NULL,
	`ind2` MEDIUMINT(8) UNSIGNED NULL,
	`ind3` MEDIUMINT(8) UNSIGNED NULL,
	`enr` MEDIUMINT(8) UNSIGNED NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gtta
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gtta` (
	`show` TINYINT(1) NOT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gttd
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gttd` (
	`d1` DATETIME NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gttf
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gttf` (
	`show_generated` TINYINT(1) NULL,
	`show_instant` TINYINT(1) NULL,
	`mlset_id` INT(10) UNSIGNED NULL,
	`show_ml_selected` TINYINT(1) NULL,
	`show_di_enabled` TINYINT(1) NULL,
	`ignore_mcc` TINYINT(1) NULL,
	`ignore_icc` TINYINT(1) NULL,
	`ignore_act` TINYINT(1) NULL,
	`show_point_anyway` TINYINT(1) NULL,
	`include_monthly` TINYINT(1) NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gttn
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gttn` (
	`id1` BIGINT(20) UNSIGNED NULL,
	`id2` BIGINT(20) UNSIGNED NULL,
	`id3` BIGINT(20) UNSIGNED NULL,
	`id4` BIGINT(20) UNSIGNED NULL,
	`id5` BIGINT(20) UNSIGNED NULL,
	`id6` BIGINT(20) UNSIGNED NULL,
	`id7` BIGINT(20) UNSIGNED NULL,
	`id8` BIGINT(20) UNSIGNED NULL,
	`id9` BIGINT(20) UNSIGNED NULL,
	`id0` BIGINT(20) UNSIGNED NULL,
	`v1` DOUBLE NULL,
	`v2` DOUBLE NULL,
	`v3` DOUBLE NULL,
	`v4` DOUBLE NULL,
	`v5` DOUBLE NULL,
	`v6` DOUBLE NULL,
	`v7` DOUBLE NULL,
	`v8` DOUBLE NULL,
	`v9` DOUBLE NULL,
	`v0` DOUBLE NULL,
	`d1` DATETIME NULL,
	`d2` DATETIME NULL,
	`d3` DATETIME NULL,
	`d4` DATETIME NULL,
	`d5` DATETIME NULL,
	`d6` DATETIME NULL,
	`d7` DATETIME NULL,
	`d8` DATETIME NULL,
	`d9` DATETIME NULL,
	`d0` DATETIME NULL,
	`c1` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c2` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c3` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c4` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c5` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c6` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c7` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c8` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c9` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c0` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`cbig` VARCHAR(4000) NULL COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gttn2
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gttn2` (
	`id1` BIGINT(20) UNSIGNED NULL,
	`id2` BIGINT(20) UNSIGNED NULL,
	`id3` BIGINT(20) UNSIGNED NULL,
	`id4` BIGINT(20) UNSIGNED NULL,
	`id5` BIGINT(20) UNSIGNED NULL,
	`id6` BIGINT(20) UNSIGNED NULL,
	`id7` BIGINT(20) UNSIGNED NULL,
	`id8` BIGINT(20) UNSIGNED NULL,
	`id9` BIGINT(20) UNSIGNED NULL,
	`id0` BIGINT(20) UNSIGNED NULL,
	`v1` DOUBLE NULL,
	`v2` DOUBLE NULL,
	`v3` DOUBLE NULL,
	`v4` DOUBLE NULL,
	`v5` DOUBLE NULL,
	`v6` DOUBLE NULL,
	`v7` DOUBLE NULL,
	`v8` DOUBLE NULL,
	`v9` DOUBLE NULL,
	`v0` DOUBLE NULL,
	`d1` DATETIME NULL,
	`d2` DATETIME NULL,
	`d3` DATETIME NULL,
	`d4` DATETIME NULL,
	`d5` DATETIME NULL,
	`d6` DATETIME NULL,
	`d7` DATETIME NULL,
	`d8` DATETIME NULL,
	`d9` DATETIME NULL,
	`d0` DATETIME NULL,
	`c1` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c2` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c3` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c4` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c5` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c6` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c7` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c8` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c9` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c0` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`cbig` VARCHAR(4000) NULL COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gttq
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gttq` (
	`id1` BIGINT(20) UNSIGNED NULL,
	`id2` BIGINT(20) UNSIGNED NULL,
	`id3` BIGINT(20) UNSIGNED NULL,
	`id4` BIGINT(20) UNSIGNED NULL,
	`id5` BIGINT(20) UNSIGNED NULL,
	`id6` BIGINT(20) UNSIGNED NULL,
	`id7` BIGINT(20) UNSIGNED NULL,
	`id8` BIGINT(20) UNSIGNED NULL,
	`id9` BIGINT(20) UNSIGNED NULL,
	`id0` BIGINT(20) UNSIGNED NULL,
	`v1` DOUBLE NULL,
	`v2` DOUBLE NULL,
	`v3` DOUBLE NULL,
	`v4` DOUBLE NULL,
	`v5` DOUBLE NULL,
	`v6` DOUBLE NULL,
	`v7` DOUBLE NULL,
	`v8` DOUBLE NULL,
	`v9` DOUBLE NULL,
	`v0` DOUBLE NULL,
	`d1` DATETIME NULL,
	`d2` DATETIME NULL,
	`d3` DATETIME NULL,
	`d4` DATETIME NULL,
	`d5` DATETIME NULL,
	`d6` DATETIME NULL,
	`d7` DATETIME NULL,
	`d8` DATETIME NULL,
	`d9` DATETIME NULL,
	`d0` DATETIME NULL,
	`c1` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c2` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c3` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c4` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c5` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c6` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c7` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c8` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c9` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c0` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`cbig` VARCHAR(4000) NULL COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gttr
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gttr` (
	`point_id` INT(10) UNSIGNED NOT NULL,
	`sheaf_id` MEDIUMINT(8) UNSIGNED NOT NULL,
	`sep_id` INT(10) UNSIGNED NOT NULL,
	`src_type_id` INT(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
	`di_id` INT(10) UNSIGNED NOT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gtts
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gtts` (
	`id1` BIGINT(20) UNSIGNED NULL,
	`id2` BIGINT(20) UNSIGNED NULL,
	`id3` BIGINT(20) UNSIGNED NULL,
	`id4` BIGINT(20) UNSIGNED NULL,
	`id5` BIGINT(20) UNSIGNED NULL,
	`id6` BIGINT(20) UNSIGNED NULL,
	`id7` BIGINT(20) UNSIGNED NULL,
	`id8` BIGINT(20) UNSIGNED NULL,
	`id9` BIGINT(20) UNSIGNED NULL,
	`id0` BIGINT(20) UNSIGNED NULL,
	`v1` DOUBLE NULL,
	`v2` DOUBLE NULL,
	`v3` DOUBLE NULL,
	`v4` DOUBLE NULL,
	`v5` DOUBLE NULL,
	`v6` DOUBLE NULL,
	`v7` DOUBLE NULL,
	`v8` DOUBLE NULL,
	`v9` DOUBLE NULL,
	`v0` DOUBLE NULL,
	`d1` DATETIME NULL,
	`d2` DATETIME NULL,
	`d3` DATETIME NULL,
	`d4` DATETIME NULL,
	`d5` DATETIME NULL,
	`d6` DATETIME NULL,
	`d7` DATETIME NULL,
	`d8` DATETIME NULL,
	`d9` DATETIME NULL,
	`d0` DATETIME NULL,
	`c1` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c2` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c3` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c4` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c5` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c6` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c7` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c8` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c9` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c0` VARCHAR(250) NULL COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gttt
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gttt` (
	`id1` BIGINT(20) UNSIGNED NULL,
	`id2` BIGINT(20) UNSIGNED NULL,
	`id3` BIGINT(20) UNSIGNED NULL,
	`id4` BIGINT(20) UNSIGNED NULL,
	`id5` BIGINT(20) UNSIGNED NULL,
	`id6` BIGINT(20) UNSIGNED NULL,
	`id7` BIGINT(20) UNSIGNED NULL,
	`id8` BIGINT(20) UNSIGNED NULL,
	`id9` BIGINT(20) UNSIGNED NULL,
	`id0` BIGINT(20) UNSIGNED NULL,
	`v1` DOUBLE NULL,
	`v2` DOUBLE NULL,
	`v3` DOUBLE NULL,
	`v4` DOUBLE NULL,
	`v5` DOUBLE NULL,
	`v6` DOUBLE NULL,
	`v7` DOUBLE NULL,
	`v8` DOUBLE NULL,
	`v9` DOUBLE NULL,
	`v0` DOUBLE NULL,
	`d1` DATETIME NULL,
	`d2` DATETIME NULL,
	`d3` DATETIME NULL,
	`d4` DATETIME NULL,
	`d5` DATETIME NULL,
	`d6` DATETIME NULL,
	`d7` DATETIME NULL,
	`d8` DATETIME NULL,
	`d9` DATETIME NULL,
	`d0` DATETIME NULL,
	`c1` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c2` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c3` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c4` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c5` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c6` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c7` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c8` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c9` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`c0` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`cbig` VARCHAR(4000) NULL COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gttw
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gttw` (
	`ses_id` BIGINT(20) UNSIGNED NOT NULL COMMENT 'Sesijos identifikatorius'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.gttx
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `gttx` (
	`id0` BIGINT(20) UNSIGNED NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.ipty
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `ipty` (
	`spty_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Sistemos savybės identifikatorius',
	`spty_value` VARCHAR(120) NOT NULL COMMENT 'Sistemos savybės reikšmė' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.ml_show
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `ml_show` (
	`ml_id` MEDIUMINT(8) UNSIGNED NOT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_act_360_result
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_act_360_result` (
	`point_id` INT(10) UNSIGNED NULL,
	`cp_t` DATETIME NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_act_type
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_act_type` (
	`ACT_TYPE_ID` MEDIUMINT(9) NOT NULL COMMENT 'Aktų tipo identifikatorius',
	`ACT_TYPE_NAME` VARCHAR(120) NOT NULL COMMENT 'Aktų tipo pavadinimas' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_curr_user
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_curr_user` (
	`USER_ID` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Vartotojo identifikatorius',
	`ses_id` BIGINT(20) UNSIGNED NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_server_tz
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_server_tz` (
	`tz_id` SMALLINT(5) UNSIGNED NOT NULL COMMENT 'Laiko zonos identifikatorius',
	`server_tz_dst_used` TINYINT(1) NOT NULL COMMENT 'Vasaros laiko naudojimo požymis',
	`tz_code` VARCHAR(30) NOT NULL COMMENT 'Laiko zonos kodas' COLLATE 'utf8_bin',
	`tz_name` VARCHAR(120) NOT NULL COMMENT 'Laiko zonos pavadinimas' COLLATE 'utf8_bin',
	`tz_winter_offset` VARCHAR(30) NOT NULL COMMENT 'Atitraukimas iki zonos žiemos laiko' COLLATE 'utf8_bin',
	`tz_winter_tzd` VARCHAR(10) NOT NULL COMMENT 'Žiemos laiko papildomas kodas' COLLATE 'utf8_bin',
	`tz_summer_tzd` VARCHAR(10) NOT NULL COMMENT 'Vasaros laiko papildomas kodas' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_src_type_mod_withe#opty
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_src_type_mod_withe#opty` (
	`src_type_id` INT(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
	`src_type_mod_nr` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
	`is_point` TINYINT(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
	`withe_id` MEDIUMINT(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
	`ind1` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
	`ind2` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
	`ind3` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
	`opty_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
	`opty_value` VARCHAR(120) NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė' COLLATE 'utf8_bin',
	`lpty_type_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Ryšio modulių savybių tipo identifikatorius',
	`enum_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Išvardinimo identifikatorius',
	`opty_code` VARCHAR(40) NOT NULL COMMENT 'Parametro kodas' COLLATE 'utf8_bin',
	`opty_name` VARCHAR(120) NOT NULL COMMENT 'Parametro pavadinimas' COLLATE 'utf8_bin',
	`opty_tm` TINYINT(1) NOT NULL COMMENT 'TM parametro požymis',
	`opty_default` VARCHAR(120) NULL COMMENT 'Parametro reikšmė pagal nutylėjimą' COLLATE 'utf8_bin',
	`opty_nr` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Parametro eilės numeris rušiavimui',
	`enum_code` VARCHAR(40) NULL COMMENT 'Išvardinimo kodas' COLLATE 'utf8_bin',
	`enum_name` VARCHAR(120) NULL COMMENT 'Išvardinimo pavadinimas' COLLATE 'utf8_bin',
	`enum_type_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Išvardinimų naudojimo tipo ID',
	`lpty_type_code` VARCHAR(40) NOT NULL COMMENT 'Ryšio modulių savybių tipo kodas' COLLATE 'utf8_bin',
	`lpty_type_name` VARCHAR(120) NOT NULL COMMENT 'Ryšio modulių savybių tipo pavadinimas' COLLATE 'utf8_bin',
	`dt_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Duomenų tipo identifikatorius',
	`ind1_cnt` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmo indekso dimensija',
	`ind1_code` VARCHAR(40) NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmo indekso kodas' COLLATE 'utf8_bin',
	`ind2_cnt` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antro indekso dimensija',
	`ind2_code` VARCHAR(40) NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antro indekso kodas' COLLATE 'utf8_bin',
	`ind3_cnt` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečio indekso dimensija',
	`ind3_code` VARCHAR(40) NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečio indekso kodas' COLLATE 'utf8_bin',
	`enr_cnt` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus dimensija',
	`readable` TINYINT(1) NULL COMMENT 'Požymis, ar galimas nuskaitymas',
	`writable` TINYINT(1) NULL COMMENT 'Požymis, ar galimas įrašymas',
	`omit_value` TINYINT(1) NULL COMMENT 'Požymis, ar neįtraukti <Value>',
	`dt_code` VARCHAR(20) NOT NULL COMMENT 'Duomenų tipo kodas' COLLATE 'utf8_bin',
	`version_dependent` TINYINT(1) NOT NULL COMMENT 'Priklausomybė nuo versijos',
	`typecode_dependent` TINYINT(1) NOT NULL COMMENT 'Priklausomybė nuo tipo kodo',
	`src_type_mod_desc` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`src_type_code` VARCHAR(40) NOT NULL COMMENT 'Duomenų šaltinių tipo kodas' COLLATE 'utf8_bin',
	`src_type_name` VARCHAR(120) NOT NULL COMMENT 'Duomenų šaltinių tipo pavadinimas' COLLATE 'utf8_bin',
	`guid` VARCHAR(50) NULL COMMENT 'Ryšio draiverio GUID' COLLATE 'utf8_bin',
	`src_type_internal` TINYINT(1) NOT NULL COMMENT 'Sistemos apklausiamų duomenų arba importuojamų išorinių duomenų požymis',
	`tm_guid` VARCHAR(50) NULL COMMENT 'Transporto menedžerio GUID' COLLATE 'utf8_bin',
	`devicetype` INT(10) NOT NULL COMMENT 'Susijęs duomenų šaltinių tipo identifikatorius',
	`horizontal_read_mode` TINYINT(1) NOT NULL COMMENT 'Horizontalaus archyvų nuskaitymo požymis'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_src_type_mod_withe_opty
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_src_type_mod_withe_opty` (
	`src_type_id` INT(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
	`src_type_mod_nr` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
	`is_point` TINYINT(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
	`withe_id` MEDIUMINT(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
	`opty_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
	`rc_in` TINYINT(1) NULL COMMENT 'Nuskaitymo užklausų požymis',
	`opty_value` VARCHAR(120) NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė' COLLATE 'utf8_bin',
	`lpty_type_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Ryšio modulių savybių tipo identifikatorius',
	`enum_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Išvardinimo identifikatorius',
	`opty_code` VARCHAR(40) NOT NULL COMMENT 'Parametro kodas' COLLATE 'utf8_bin',
	`opty_name` VARCHAR(120) NOT NULL COMMENT 'Parametro pavadinimas' COLLATE 'utf8_bin',
	`opty_tm` TINYINT(1) NOT NULL COMMENT 'TM parametro požymis',
	`opty_default` VARCHAR(120) NULL COMMENT 'Parametro reikšmė pagal nutylėjimą' COLLATE 'utf8_bin',
	`opty_nr` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Parametro eilės numeris rušiavimui',
	`enum_code` VARCHAR(40) NULL COMMENT 'Išvardinimo kodas' COLLATE 'utf8_bin',
	`enum_name` VARCHAR(120) NULL COMMENT 'Išvardinimo pavadinimas' COLLATE 'utf8_bin',
	`enum_type_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Išvardinimų naudojimo tipo ID',
	`lpty_type_code` VARCHAR(40) NOT NULL COMMENT 'Ryšio modulių savybių tipo kodas' COLLATE 'utf8_bin',
	`lpty_type_name` VARCHAR(120) NOT NULL COMMENT 'Ryšio modulių savybių tipo pavadinimas' COLLATE 'utf8_bin',
	`dt_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Duomenų tipo identifikatorius',
	`ind1_cnt` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmo indekso dimensija',
	`ind1_code` VARCHAR(40) NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmo indekso kodas' COLLATE 'utf8_bin',
	`ind2_cnt` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antro indekso dimensija',
	`ind2_code` VARCHAR(40) NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antro indekso kodas' COLLATE 'utf8_bin',
	`ind3_cnt` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečio indekso dimensija',
	`ind3_code` VARCHAR(40) NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečio indekso kodas' COLLATE 'utf8_bin',
	`enr_cnt` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus dimensija',
	`readable` TINYINT(1) NULL COMMENT 'Požymis, ar galimas nuskaitymas',
	`writable` TINYINT(1) NULL COMMENT 'Požymis, ar galimas įrašymas',
	`omit_value` TINYINT(1) NULL COMMENT 'Požymis, ar neįtraukti <Value>',
	`dt_code` VARCHAR(20) NOT NULL COMMENT 'Duomenų tipo kodas' COLLATE 'utf8_bin',
	`version_dependent` TINYINT(1) NOT NULL COMMENT 'Priklausomybė nuo versijos',
	`typecode_dependent` TINYINT(1) NOT NULL COMMENT 'Priklausomybė nuo tipo kodo',
	`src_type_mod_desc` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`src_type_code` VARCHAR(40) NOT NULL COMMENT 'Duomenų šaltinių tipo kodas' COLLATE 'utf8_bin',
	`src_type_name` VARCHAR(120) NOT NULL COMMENT 'Duomenų šaltinių tipo pavadinimas' COLLATE 'utf8_bin',
	`guid` VARCHAR(50) NULL COMMENT 'Ryšio draiverio GUID' COLLATE 'utf8_bin',
	`src_type_internal` TINYINT(1) NOT NULL COMMENT 'Sistemos apklausiamų duomenų arba importuojamų išorinių duomenų požymis',
	`tm_guid` VARCHAR(50) NULL COMMENT 'Transporto menedžerio GUID' COLLATE 'utf8_bin',
	`devicetype` INT(10) NOT NULL COMMENT 'Susijęs duomenų šaltinių tipo identifikatorius',
	`horizontal_read_mode` TINYINT(1) NOT NULL COMMENT 'Horizontalaus archyvų nuskaitymo požymis'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_src_type_mod_withe_rc#opty
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_src_type_mod_withe_rc#opty` (
	`src_type_id` INT(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
	`src_type_mod_nr` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
	`is_point` TINYINT(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
	`withe_id` MEDIUMINT(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
	`ind1` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmas indeksas',
	`ind2` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antras indeksas',
	`ind3` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečias indeksas',
	`rc_in` TINYINT(1) NOT NULL COMMENT 'Nuskaitymo užklausų požymis',
	`opty_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
	`opty_value` VARCHAR(120) NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė' COLLATE 'utf8_bin',
	`lpty_type_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Ryšio modulių savybių tipo identifikatorius',
	`enum_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Išvardinimo identifikatorius',
	`opty_code` VARCHAR(40) NOT NULL COMMENT 'Parametro kodas' COLLATE 'utf8_bin',
	`opty_name` VARCHAR(120) NOT NULL COMMENT 'Parametro pavadinimas' COLLATE 'utf8_bin',
	`opty_tm` TINYINT(1) NOT NULL COMMENT 'TM parametro požymis',
	`opty_default` VARCHAR(120) NULL COMMENT 'Parametro reikšmė pagal nutylėjimą' COLLATE 'utf8_bin',
	`opty_nr` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Parametro eilės numeris rušiavimui',
	`enum_code` VARCHAR(40) NULL COMMENT 'Išvardinimo kodas' COLLATE 'utf8_bin',
	`enum_name` VARCHAR(120) NULL COMMENT 'Išvardinimo pavadinimas' COLLATE 'utf8_bin',
	`enum_type_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Išvardinimų naudojimo tipo ID',
	`lpty_type_code` VARCHAR(40) NOT NULL COMMENT 'Ryšio modulių savybių tipo kodas' COLLATE 'utf8_bin',
	`lpty_type_name` VARCHAR(120) NOT NULL COMMENT 'Ryšio modulių savybių tipo pavadinimas' COLLATE 'utf8_bin',
	`dt_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Duomenų tipo identifikatorius',
	`ind1_cnt` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmo indekso dimensija',
	`ind1_code` VARCHAR(40) NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmo indekso kodas' COLLATE 'utf8_bin',
	`ind2_cnt` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antro indekso dimensija',
	`ind2_code` VARCHAR(40) NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antro indekso kodas' COLLATE 'utf8_bin',
	`ind3_cnt` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečio indekso dimensija',
	`ind3_code` VARCHAR(40) NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečio indekso kodas' COLLATE 'utf8_bin',
	`enr_cnt` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus dimensija',
	`readable` TINYINT(1) NULL COMMENT 'Požymis, ar galimas nuskaitymas',
	`writable` TINYINT(1) NULL COMMENT 'Požymis, ar galimas įrašymas',
	`omit_value` TINYINT(1) NULL COMMENT 'Požymis, ar neįtraukti <Value>',
	`dt_code` VARCHAR(20) NOT NULL COMMENT 'Duomenų tipo kodas' COLLATE 'utf8_bin',
	`version_dependent` TINYINT(1) NOT NULL COMMENT 'Priklausomybė nuo versijos',
	`typecode_dependent` TINYINT(1) NOT NULL COMMENT 'Priklausomybė nuo tipo kodo',
	`src_type_mod_desc` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`src_type_code` VARCHAR(40) NOT NULL COMMENT 'Duomenų šaltinių tipo kodas' COLLATE 'utf8_bin',
	`src_type_name` VARCHAR(120) NOT NULL COMMENT 'Duomenų šaltinių tipo pavadinimas' COLLATE 'utf8_bin',
	`guid` VARCHAR(50) NULL COMMENT 'Ryšio draiverio GUID' COLLATE 'utf8_bin',
	`src_type_internal` TINYINT(1) NOT NULL COMMENT 'Sistemos apklausiamų duomenų arba importuojamų išorinių duomenų požymis',
	`tm_guid` VARCHAR(50) NULL COMMENT 'Transporto menedžerio GUID' COLLATE 'utf8_bin',
	`devicetype` INT(10) NOT NULL COMMENT 'Susijęs duomenų šaltinių tipo identifikatorius',
	`horizontal_read_mode` TINYINT(1) NOT NULL COMMENT 'Horizontalaus archyvų nuskaitymo požymis'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_src_type_mod_withe_rc_opty
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_src_type_mod_withe_rc_opty` (
	`src_type_id` INT(10) NOT NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
	`src_type_mod_nr` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų šaltinių tipų modifikacijos numeris',
	`is_point` TINYINT(1) NOT NULL COMMENT 'Požymis, ar susiję su matavimo tašku',
	`withe_id` MEDIUMINT(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
	`rc_in` TINYINT(1) NOT NULL COMMENT 'Nuskaitymo užklausų požymis',
	`opty_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro ID',
	`opty_value` VARCHAR(120) NOT NULL COMMENT 'Nuskaitymų pagal pareikalavimą užsakymo parametro reikšmė' COLLATE 'utf8_bin',
	`lpty_type_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Ryšio modulių savybių tipo identifikatorius',
	`enum_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Išvardinimo identifikatorius',
	`opty_code` VARCHAR(40) NOT NULL COMMENT 'Parametro kodas' COLLATE 'utf8_bin',
	`opty_name` VARCHAR(120) NOT NULL COMMENT 'Parametro pavadinimas' COLLATE 'utf8_bin',
	`opty_tm` TINYINT(1) NOT NULL COMMENT 'TM parametro požymis',
	`opty_default` VARCHAR(120) NULL COMMENT 'Parametro reikšmė pagal nutylėjimą' COLLATE 'utf8_bin',
	`opty_nr` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Parametro eilės numeris rušiavimui',
	`enum_code` VARCHAR(40) NULL COMMENT 'Išvardinimo kodas' COLLATE 'utf8_bin',
	`enum_name` VARCHAR(120) NULL COMMENT 'Išvardinimo pavadinimas' COLLATE 'utf8_bin',
	`enum_type_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Išvardinimų naudojimo tipo ID',
	`lpty_type_code` VARCHAR(40) NOT NULL COMMENT 'Ryšio modulių savybių tipo kodas' COLLATE 'utf8_bin',
	`lpty_type_name` VARCHAR(120) NOT NULL COMMENT 'Ryšio modulių savybių tipo pavadinimas' COLLATE 'utf8_bin',
	`dt_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Duomenų tipo identifikatorius',
	`ind1_cnt` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmo indekso dimensija',
	`ind1_code` VARCHAR(40) NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro pirmo indekso kodas' COLLATE 'utf8_bin',
	`ind2_cnt` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antro indekso dimensija',
	`ind2_code` VARCHAR(40) NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro antro indekso kodas' COLLATE 'utf8_bin',
	`ind3_cnt` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečio indekso dimensija',
	`ind3_code` VARCHAR(40) NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro trečio indekso kodas' COLLATE 'utf8_bin',
	`enr_cnt` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Masyvinio prietaiso konfigūracinio parametro vektoriaus dimensija',
	`readable` TINYINT(1) NULL COMMENT 'Požymis, ar galimas nuskaitymas',
	`writable` TINYINT(1) NULL COMMENT 'Požymis, ar galimas įrašymas',
	`omit_value` TINYINT(1) NULL COMMENT 'Požymis, ar neįtraukti <Value>',
	`dt_code` VARCHAR(20) NOT NULL COMMENT 'Duomenų tipo kodas' COLLATE 'utf8_bin',
	`version_dependent` TINYINT(1) NOT NULL COMMENT 'Priklausomybė nuo versijos',
	`typecode_dependent` TINYINT(1) NOT NULL COMMENT 'Priklausomybė nuo tipo kodo',
	`src_type_mod_desc` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`src_type_code` VARCHAR(40) NOT NULL COMMENT 'Duomenų šaltinių tipo kodas' COLLATE 'utf8_bin',
	`src_type_name` VARCHAR(120) NOT NULL COMMENT 'Duomenų šaltinių tipo pavadinimas' COLLATE 'utf8_bin',
	`guid` VARCHAR(50) NULL COMMENT 'Ryšio draiverio GUID' COLLATE 'utf8_bin',
	`src_type_internal` TINYINT(1) NOT NULL COMMENT 'Sistemos apklausiamų duomenų arba importuojamų išorinių duomenų požymis',
	`tm_guid` VARCHAR(50) NULL COMMENT 'Transporto menedžerio GUID' COLLATE 'utf8_bin',
	`devicetype` INT(10) NOT NULL COMMENT 'Susijęs duomenų šaltinių tipo identifikatorius',
	`horizontal_read_mode` TINYINT(1) NOT NULL COMMENT 'Horizontalaus archyvų nuskaitymo požymis'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_vp
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_vp` (
	`vp_id` INT(10) UNSIGNED NOT NULL COMMENT 'Verifikacijos profilio identifikatorius',
	`vp_code` VARCHAR(40) NOT NULL COMMENT 'Verifikacijos profilio kodas' COLLATE 'utf8_bin',
	`vp_name` VARCHAR(120) NOT NULL COMMENT 'Verifikacijos profilio pavadinimas' COLLATE 'utf8_bin',
	`vp_bias` DOUBLE NOT NULL COMMENT 'Verifikacijos profilio maksimali leistinoji procentinė paklaida',
	`vp_separate_tff` TINYINT(1) NOT NULL COMMENT 'Verifikacijos profilio atskirų pagal tarifus tikrinimų požymis',
	`vp_smallest_interval` TINYINT(1) NOT NULL COMMENT 'Verifikacijos profilio tikrinimų taikymas tik smulkiausiems agregavimo segmento tipo intervalams'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_vp_data
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_vp_data` (
	`vp_id` INT(10) UNSIGNED NOT NULL COMMENT 'Verifikacijos profilio identifikatorius',
	`vp_nr` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Verifikacijos profilio sąlygos numeris',
	`aggs_type_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Agregavimo segmento tipo identifikatorius',
	`ms_id` SMALLINT(5) UNSIGNED NULL COMMENT 'Matavimo identifikatorius',
	`dir_id` TINYINT(4) NULL COMMENT 'Krypties identifikatorius',
	`aggf_id` TINYINT(3) UNSIGNED NULL COMMENT 'Agregavimo funkcijos identifikatorius',
	`tff_id` TINYINT(3) UNSIGNED NULL COMMENT 'Tarifo identifikatorius',
	`aggf_name` VARCHAR(120) NULL COMMENT 'Agregavimo funkcijos pavadinimas' COLLATE 'utf8_bin',
	`aggs_type_name` VARCHAR(120) NOT NULL COMMENT 'Agregavimo segmento tipo pavadinimas' COLLATE 'utf8_bin',
	`dir_code` VARCHAR(20) NULL COMMENT 'Krypties kodas' COLLATE 'utf8_bin',
	`dir_name` VARCHAR(120) NULL COMMENT 'Krypties pavadinimas' COLLATE 'utf8_bin',
	`ms_code` VARCHAR(40) NULL COMMENT 'Matavimo kodas' COLLATE 'utf8_bin',
	`ms_name` VARCHAR(120) NULL COMMENT 'Matavimo pavadinimas' COLLATE 'utf8_bin',
	`ms_type_id` SMALLINT(5) UNSIGNED NULL COMMENT 'Matavimų tipo identifikatorius',
	`ms_type_name` VARCHAR(120) NULL COMMENT 'Matavimų tipo pavadinimas' COLLATE 'utf8_bin',
	`tff_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`vp_code` VARCHAR(40) NOT NULL COMMENT 'Verifikacijos profilio kodas' COLLATE 'utf8_bin',
	`vp_name` VARCHAR(120) NOT NULL COMMENT 'Verifikacijos profilio pavadinimas' COLLATE 'utf8_bin',
	`vp_bias` DOUBLE NOT NULL COMMENT 'Verifikacijos profilio maksimali leistinoji procentinė paklaida',
	`vp_separate_tff` TINYINT(1) NOT NULL COMMENT 'Verifikacijos profilio atskirų pagal tarifus tikrinimų požymis',
	`vp_smallest_interval` TINYINT(1) NOT NULL COMMENT 'Verifikacijos profilio tikrinimų taikymas tik smulkiausiems agregavimo segmento tipo intervalams'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_vs
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_vs` (
	`vs_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Voko būsenos identifikatorius',
	`vs_code` VARCHAR(40) NOT NULL COMMENT 'Voko būsenos kodas' COLLATE 'utf8_bin',
	`vs_name` VARCHAR(120) NOT NULL COMMENT 'Voko būsenos pavadinimas' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_withe
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_withe` (
	`withe_id` MEDIUMINT(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
	`withe_code` VARCHAR(40) NOT NULL COMMENT 'Duomenų vytelės kodas' COLLATE 'utf8_bin',
	`withe_name` VARCHAR(120) NOT NULL COMMENT 'Duomenų vytelės pavadinimas' COLLATE 'utf8_bin',
	`withe_type_id` SMALLINT(5) UNSIGNED NOT NULL COMMENT 'Duomenų vytelių tipo identifikatorius',
	`withe_normal_state` TINYINT(1) NULL COMMENT 'Normali duomenų vytelės būsena',
	`enum_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Išvardinimo identifikatorius',
	`withe_dtype_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Duomenų vytelių duomenų tipo identifikatorius',
	`enum_code` VARCHAR(40) NULL COMMENT 'Išvardinimo kodas' COLLATE 'utf8_bin',
	`enum_name` VARCHAR(120) NULL COMMENT 'Išvardinimo pavadinimas' COLLATE 'utf8_bin',
	`withe_dtype_code` VARCHAR(40) NOT NULL COMMENT 'Duomenų vytelių duomenų tipo kodas' COLLATE 'utf8_bin',
	`withe_dtype_name` VARCHAR(120) NOT NULL COMMENT 'Duomenų vytelių duomenų tipo pavadinimas' COLLATE 'utf8_bin',
	`withe_type_code` VARCHAR(40) NOT NULL COMMENT 'Duomenų vytelių tipo kodas' COLLATE 'utf8_bin',
	`withe_type_name` VARCHAR(120) NOT NULL COMMENT 'Duomenų vytelių tipo pavadinimas' COLLATE 'utf8_bin',
	`withe_class_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Duomenų vytelių klasės identifikatorius',
	`withe_class_code` VARCHAR(40) NOT NULL COMMENT 'Duomenų vytelių klasės kodas' COLLATE 'utf8_bin',
	`withe_class_name` VARCHAR(120) NOT NULL COMMENT 'Duomenų vytelių klasės pavadinimas' COLLATE 'utf8_bin',
	`eu_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Matavimo vienetų identifikatorius',
	`eu_code` VARCHAR(10) NULL COMMENT 'Matavimo vieneto kodas' COLLATE 'utf8_bin',
	`eu_name` VARCHAR(120) NULL COMMENT 'Matavimo vieneto pavadinimas' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_witheset
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_witheset` (
	`witheset_id` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų vytelių rinkinio identifikatorius',
	`witheset_code` VARCHAR(40) NOT NULL COMMENT 'Duomenų vytelių rinkinio kodas' COLLATE 'utf8_bin',
	`witheset_name` VARCHAR(120) NOT NULL COMMENT 'Duomenų vytelių rinkinio pavadinimas' COLLATE 'utf8_bin',
	`src_type_id` INT(10) NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
	`witheset_journal` TINYINT(1) NOT NULL COMMENT 'Duomenu vyteliu rinkinis yra žurnalas',
	`src_type_code` VARCHAR(40) NULL COMMENT 'Duomenų šaltinių tipo kodas' COLLATE 'utf8_bin',
	`src_type_name` VARCHAR(120) NULL COMMENT 'Duomenų šaltinių tipo pavadinimas' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_witheset_data
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_witheset_data` (
	`witheset_id` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų vytelių rinkinio identifikatorius',
	`withe_id` MEDIUMINT(8) NOT NULL COMMENT 'Duomenų vytelės identifikatorius',
	`withe_code` VARCHAR(40) NOT NULL COMMENT 'Duomenų vytelės kodas' COLLATE 'utf8_bin',
	`withe_name` VARCHAR(120) NOT NULL COMMENT 'Duomenų vytelės pavadinimas' COLLATE 'utf8_bin',
	`withe_type_id` SMALLINT(5) UNSIGNED NOT NULL COMMENT 'Duomenų vytelių tipo identifikatorius',
	`withe_normal_state` TINYINT(1) NULL COMMENT 'Normali duomenų vytelės būsena',
	`enum_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Išvardinimo identifikatorius',
	`withe_dtype_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Duomenų vytelių duomenų tipo identifikatorius',
	`withe_dtype_code` VARCHAR(40) NOT NULL COMMENT 'Duomenų vytelių duomenų tipo kodas' COLLATE 'utf8_bin',
	`withe_dtype_name` VARCHAR(120) NOT NULL COMMENT 'Duomenų vytelių duomenų tipo pavadinimas' COLLATE 'utf8_bin',
	`withe_type_code` VARCHAR(40) NOT NULL COMMENT 'Duomenų vytelių tipo kodas' COLLATE 'utf8_bin',
	`withe_type_name` VARCHAR(120) NOT NULL COMMENT 'Duomenų vytelių tipo pavadinimas' COLLATE 'utf8_bin',
	`withe_class_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Duomenų vytelių klasės identifikatorius',
	`witheset_code` VARCHAR(40) NOT NULL COMMENT 'Duomenų vytelių rinkinio kodas' COLLATE 'utf8_bin',
	`witheset_name` VARCHAR(120) NOT NULL COMMENT 'Duomenų vytelių rinkinio pavadinimas' COLLATE 'utf8_bin',
	`witheset_journal` TINYINT(1) NOT NULL COMMENT 'Duomenu vyteliu rinkinis yra žurnalas',
	`src_type_id` INT(10) NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
	`src_type_code` VARCHAR(40) NULL COMMENT 'Duomenų šaltinių tipo kodas' COLLATE 'utf8_bin',
	`src_type_name` VARCHAR(120) NULL COMMENT 'Duomenų šaltinių tipo pavadinimas' COLLATE 'utf8_bin',
	`eu_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Matavimo vienetų identifikatorius',
	`eu_code` VARCHAR(10) NULL COMMENT 'Matavimo vieneto kodas' COLLATE 'utf8_bin',
	`eu_name` VARCHAR(120) NULL COMMENT 'Matavimo vieneto pavadinimas' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_withe_class
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_withe_class` (
	`withe_class_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Duomenų vytelių klasės identifikatorius',
	`withe_class_code` VARCHAR(40) NOT NULL COMMENT 'Duomenų vytelių klasės kodas' COLLATE 'utf8_bin',
	`withe_class_name` VARCHAR(120) NOT NULL COMMENT 'Duomenų vytelių klasės pavadinimas' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_withe_dtype
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_withe_dtype` (
	`withe_dtype_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Duomenų vytelių duomenų tipo identifikatorius',
	`withe_dtype_code` VARCHAR(40) NOT NULL COMMENT 'Duomenų vytelių duomenų tipo kodas' COLLATE 'utf8_bin',
	`withe_dtype_name` VARCHAR(120) NOT NULL COMMENT 'Duomenų vytelių duomenų tipo pavadinimas' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_withe_type
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_withe_type` (
	`withe_type_id` SMALLINT(5) UNSIGNED NOT NULL COMMENT 'Duomenų vytelių tipo identifikatorius',
	`withe_type_code` VARCHAR(40) NOT NULL COMMENT 'Duomenų vytelių tipo kodas' COLLATE 'utf8_bin',
	`withe_type_name` VARCHAR(120) NOT NULL COMMENT 'Duomenų vytelių tipo pavadinimas' COLLATE 'utf8_bin',
	`withe_class_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Duomenų vytelių klasės identifikatorius',
	`withe_class_code` VARCHAR(40) NOT NULL COMMENT 'Duomenų vytelių klasės kodas' COLLATE 'utf8_bin',
	`withe_class_name` VARCHAR(120) NOT NULL COMMENT 'Duomenų vytelių klasės pavadinimas' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_xfau_type
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_xfau_type` (
	`xfau_type_id` SMALLINT(5) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis formų mazgų tipo identifikatorius',
	`xfau_type_name` VARCHAR(120) NOT NULL COMMENT 'Apsikeitimo duomenimis formų mazgų tipo pavadinimas' COLLATE 'utf8_bin',
	`per_id` TINYINT(3) UNSIGNED NULL COMMENT 'Periodo identifikatorius',
	`cb_point` TINYINT(1) NOT NULL COMMENT 'Požymis, ar tokio tipo mazgu gali būti apskaitos taškas',
	`cb_gr` TINYINT(1) NOT NULL COMMENT 'Požymis, ar tokio tipo mazgu gali būti apskaitos taškų grupė',
	`cb_ds` TINYINT(1) NOT NULL COMMENT 'Požymis, ar tokio tipo mazgu gali būti apskaitos būsenos signalas',
	`per_code` VARCHAR(10) NULL COMMENT 'Periodo kodas' COLLATE 'utf8_bin',
	`per_name` VARCHAR(50) NULL COMMENT 'Periodo pavadinimas' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_xf_type
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_xf_type` (
	`xf_type_id` SMALLINT(5) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
	`xf_type_code` VARCHAR(20) NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo kodas' COLLATE 'utf8_bin',
	`xf_type_name` VARCHAR(120) NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo pavadinimas' COLLATE 'utf8_bin',
	`src_type_id` INT(10) NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
	`xf_type_delivery` VARCHAR(20) NOT NULL COLLATE 'utf8_bin',
	`per_id` TINYINT(3) UNSIGNED NULL COMMENT 'Periodo identifikatorius',
	`rc_filter` TINYINT(1) NOT NULL COMMENT 'Nuskaitymo priežasčių parametrų filtro naudojimo požymis apsikeitimo duomenimis formų tipui',
	`ml_filter` TINYINT(1) NOT NULL COMMENT 'Matavimo linijų filtro naudojimo požymis apsikeitimo duomenimis formų tipui',
	`per_code` VARCHAR(10) NULL COMMENT 'Periodo kodas' COLLATE 'utf8_bin',
	`per_name` VARCHAR(50) NULL COMMENT 'Periodo pavadinimas' COLLATE 'utf8_bin',
	`xfe_usage` TINYINT(1) NOT NULL COMMENT 'Požymis, ar galimi mazgų elementai formoje',
	`aggf_id` TINYINT(3) UNSIGNED NULL COMMENT 'Agregavimo funkcijos identifikatorius įėjime',
	`aggf_name` VARCHAR(120) NULL COMMENT 'Agregavimo funkcijos pavadinimas' COLLATE 'utf8_bin',
	`x_aggf_id` TINYINT(3) UNSIGNED NULL COMMENT 'Agregavimo funkcijos identifikatorius išėjime',
	`x_aggf_name` VARCHAR(120) NULL COMMENT 'Agregavimo funkcijos pavadinimas' COLLATE 'utf8_bin',
	`in_eu_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Matavimo vienetų identifikatorius įėjime',
	`in_eu_code` VARCHAR(10) NULL COMMENT 'Matavimo vieneto kodas' COLLATE 'utf8_bin',
	`in_eu_name` VARCHAR(120) NULL COMMENT 'Matavimo vieneto pavadinimas' COLLATE 'utf8_bin',
	`out_eu_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Matavimo vienetų identifikatorius išėjime',
	`out_eu_code` VARCHAR(10) NULL COMMENT 'Matavimo vieneto kodas' COLLATE 'utf8_bin',
	`out_eu_name` VARCHAR(120) NULL COMMENT 'Matavimo vieneto pavadinimas' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_xf_type_aggf
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_xf_type_aggf` (
	`xf_type_id` SMALLINT(5) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
	`aggf_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Agregavimo funkcijos identifikatorius įėjime',
	`x_aggf_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Agregavimo funkcijos identifikatorius išėjime',
	`aggf_name` VARCHAR(120) NOT NULL COMMENT 'Agregavimo funkcijos pavadinimas' COLLATE 'utf8_bin',
	`x_aggf_name` VARCHAR(120) NOT NULL COMMENT 'Agregavimo funkcijos pavadinimas' COLLATE 'utf8_bin',
	`xf_type_code` VARCHAR(20) NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo kodas' COLLATE 'utf8_bin',
	`xf_type_name` VARCHAR(120) NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo pavadinimas' COLLATE 'utf8_bin',
	`src_type_id` INT(10) NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
	`xf_type_delivery` VARCHAR(20) NOT NULL COLLATE 'utf8_bin',
	`per_id` TINYINT(3) UNSIGNED NULL COMMENT 'Periodo identifikatorius',
	`rc_filter` TINYINT(1) NOT NULL COMMENT 'Nuskaitymo priežasčių parametrų filtro naudojimo požymis apsikeitimo duomenimis formų tipui',
	`ml_filter` TINYINT(1) NOT NULL COMMENT 'Matavimo linijų filtro naudojimo požymis apsikeitimo duomenimis formų tipui',
	`per_code` VARCHAR(10) NULL COMMENT 'Periodo kodas' COLLATE 'utf8_bin',
	`per_name` VARCHAR(50) NULL COMMENT 'Periodo pavadinimas' COLLATE 'utf8_bin',
	`xfe_usage` TINYINT(1) NOT NULL COMMENT 'Požymis, ar galimi mazgų elementai formoje'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_xf_type_eu_map
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_xf_type_eu_map` (
	`xf_type_id` SMALLINT(5) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
	`in_eu_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Matavimo vienetų identifikatorius įėjime',
	`out_eu_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Matavimo vienetų identifikatorius išėjime',
	`in_eu_code` VARCHAR(10) NULL COMMENT 'Matavimo vieneto kodas' COLLATE 'utf8_bin',
	`in_eu_name` VARCHAR(120) NULL COMMENT 'Matavimo vieneto pavadinimas' COLLATE 'utf8_bin',
	`out_eu_code` VARCHAR(10) NULL COMMENT 'Matavimo vieneto kodas' COLLATE 'utf8_bin',
	`out_eu_name` VARCHAR(120) NULL COMMENT 'Matavimo vieneto pavadinimas' COLLATE 'utf8_bin',
	`xf_type_code` VARCHAR(20) NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo kodas' COLLATE 'utf8_bin',
	`xf_type_name` VARCHAR(120) NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo pavadinimas' COLLATE 'utf8_bin',
	`src_type_id` INT(10) NULL COMMENT 'Duomenų šaltinių tipo identifikatorius',
	`xf_type_delivery` VARCHAR(20) NOT NULL COLLATE 'utf8_bin',
	`per_id` TINYINT(3) UNSIGNED NULL COMMENT 'Periodo identifikatorius',
	`rc_filter` TINYINT(1) NOT NULL COMMENT 'Nuskaitymo priežasčių parametrų filtro naudojimo požymis apsikeitimo duomenimis formų tipui',
	`ml_filter` TINYINT(1) NOT NULL COMMENT 'Matavimo linijų filtro naudojimo požymis apsikeitimo duomenimis formų tipui',
	`per_code` VARCHAR(10) NULL COMMENT 'Periodo kodas' COLLATE 'utf8_bin',
	`per_name` VARCHAR(50) NULL COMMENT 'Periodo pavadinimas' COLLATE 'utf8_bin',
	`xfe_usage` TINYINT(1) NOT NULL COMMENT 'Požymis, ar galimi mazgų elementai formoje'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_xf_type_rpp
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_xf_type_rpp` (
	`xf_type_id` SMALLINT(5) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
	`rpp_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo identifikatorius',
	`rpp_code` VARCHAR(20) NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo kodas' COLLATE 'utf8_bin',
	`rpp_name` VARCHAR(120) NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo pavadinimas' COLLATE 'utf8_bin',
	`rpp_enabled` TINYINT(1) NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo galiojimas',
	`xf_type_code` VARCHAR(20) NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo kodas' COLLATE 'utf8_bin',
	`xf_type_name` VARCHAR(120) NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo pavadinimas' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_xf_type_xe
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_xf_type_xe` (
	`xf_type_id` SMALLINT(5) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
	`xe_id` INT(10) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis elemento identifikatorius',
	`xe_code` VARCHAR(40) NOT NULL COMMENT 'Apsikeitimo duomenimis elemento kodas' COLLATE 'utf8_bin',
	`xe_name` VARCHAR(250) NOT NULL COMMENT 'Apsikeitimo duomenimis elemento pavadinimas' COLLATE 'utf8_bin',
	`xe_code2` VARCHAR(40) NULL COMMENT 'Apsikeitimo duomenimis elemento antras kodas' COLLATE 'utf8_bin',
	`xe_name2` VARCHAR(250) NULL COMMENT 'Apsikeitimo duomenimis elemento antras pavadinimas' COLLATE 'utf8_bin',
	`xf_type_code` VARCHAR(20) NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo kodas' COLLATE 'utf8_bin',
	`xf_type_name` VARCHAR(120) NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo pavadinimas' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_xf_type_xfau_type
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_xf_type_xfau_type` (
	`xf_type_id` SMALLINT(5) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
	`xfau_type_id` SMALLINT(5) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis formų mazgų tipo identifikatorius',
	`xfau_type_name` VARCHAR(120) NOT NULL COMMENT 'Apsikeitimo duomenimis formų mazgų tipo pavadinimas' COLLATE 'utf8_bin',
	`per_id` TINYINT(3) UNSIGNED NULL COMMENT 'Periodo identifikatorius',
	`cb_point` TINYINT(1) NOT NULL COMMENT 'Požymis, ar tokio tipo mazgu gali būti apskaitos taškas',
	`cb_gr` TINYINT(1) NOT NULL COMMENT 'Požymis, ar tokio tipo mazgu gali būti apskaitos taškų grupė',
	`cb_ds` TINYINT(1) NOT NULL COMMENT 'Požymis, ar tokio tipo mazgu gali būti apskaitos būsenos signalas',
	`per_code` VARCHAR(10) NULL COMMENT 'Periodo kodas' COLLATE 'utf8_bin',
	`per_name` VARCHAR(50) NULL COMMENT 'Periodo pavadinimas' COLLATE 'utf8_bin',
	`xf_type_code` VARCHAR(20) NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo kodas' COLLATE 'utf8_bin',
	`xf_type_name` VARCHAR(120) NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo pavadinimas' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_xf_type_xpty
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_xf_type_xpty` (
	`xf_type_id` SMALLINT(5) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
	`xpty_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis formų savybės identifikatorius',
	`xf_import` TINYINT(1) NULL COMMENT 'Importo/eksporto formos požymis',
	`xf_type_code` VARCHAR(20) NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo kodas' COLLATE 'utf8_bin',
	`xf_type_name` VARCHAR(120) NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo pavadinimas' COLLATE 'utf8_bin',
	`xpty_code` VARCHAR(40) NOT NULL COMMENT 'Apsikeitimo duomenimis formų savybės kodas' COLLATE 'utf8_bin',
	`xpty_name` VARCHAR(120) NOT NULL COMMENT 'Apsikeitimo duomenimis formų savybės pavadinimas' COLLATE 'utf8_bin',
	`enum_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Išvardinimo identifikatorius',
	`enum_code` VARCHAR(40) NULL COMMENT 'Išvardinimo kodas' COLLATE 'utf8_bin',
	`enum_name` VARCHAR(120) NULL COMMENT 'Išvardinimo pavadinimas' COLLATE 'utf8_bin',
	`xpty_default_value` VARCHAR(120) NULL COMMENT 'Apsikeitimo duomenimis formos savybės reikšmė pagal nutylėjimą' COLLATE 'utf8_bin',
	`xpty_nr` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Apsikeitimo duomenimis formos savybės eilės numeris rušiavimui'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_xo_type
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_xo_type` (
	`xo_type_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis operacijų tipo identifikatorius',
	`xo_type_name` VARCHAR(120) NOT NULL COMMENT 'Apsikeitimo duomenimis operacijų tipo pavadinimas' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_xpty
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_xpty` (
	`xpty_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis formų savybės identifikatorius',
	`xpty_code` VARCHAR(40) NOT NULL COMMENT 'Apsikeitimo duomenimis formų savybės kodas' COLLATE 'utf8_bin',
	`xpty_name` VARCHAR(120) NOT NULL COMMENT 'Apsikeitimo duomenimis formų savybės pavadinimas' COLLATE 'utf8_bin',
	`enum_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Išvardinimo identifikatorius',
	`enum_code` VARCHAR(40) NULL COMMENT 'Išvardinimo kodas' COLLATE 'utf8_bin',
	`enum_name` VARCHAR(120) NULL COMMENT 'Išvardinimo pavadinimas' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.st_xs
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `st_xs` (
	`xs_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenų statuso identifikatorius',
	`xs_code` VARCHAR(40) NOT NULL COMMENT 'Apsikeitimo duomenų statuso kodas' COLLATE 'utf8_bin',
	`xs_name` VARCHAR(120) NOT NULL COMMENT 'Apsikeitimo duomenų statuso pavadinimas' COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.ta_triggers0
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `ta_triggers0` (
	`tab_name` VARCHAR(30) NOT NULL COMMENT 'Lentelės pavadinimas' COLLATE 'utf8_bin',
	`operation_type` VARCHAR(1) NOT NULL COLLATE 'utf8mb4_general_ci',
	`trigger_name` VARCHAR(37) NOT NULL COLLATE 'utf8_bin',
	`ddl` TEXT NULL COLLATE 'utf8mb4_general_ci',
	`ind` INT(1) NOT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tg$grc
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tg$grc` (
	`cont_id` INT(10) UNSIGNED NOT NULL,
	`comp_id` INT(10) UNSIGNED NOT NULL,
	`grc_bt` DATETIME NOT NULL,
	`grc_et` DATETIME NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tg$grcj_comp
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tg$grcj_comp` (
	`gr_id` INT(10) UNSIGNED NOT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tg$grcj_cont
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tg$grcj_cont` (
	`gr_id` INT(10) UNSIGNED NOT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tg$grcj_data_comp
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tg$grcj_data_comp` (
	`gr_id` INT(10) UNSIGNED NOT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tg$grcj_data_cont
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tg$grcj_data_cont` (
	`gr_id` INT(10) UNSIGNED NOT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tg$grcj_data_p
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tg$grcj_data_p` (
	`point_id` INT(10) UNSIGNED NOT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tg$grcj_p
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tg$grcj_p` (
	`point_id` INT(10) UNSIGNED NOT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tg$grcj_r
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tg$grcj_r` (
	`gr_id` INT(10) UNSIGNED NULL,
	`point_id` INT(10) UNSIGNED NULL,
	`bt` DATETIME NULL,
	`et` DATETIME NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tg$grc_data
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tg$grc_data` (
	`cont_id` INT(10) UNSIGNED NOT NULL,
	`cont_ms_id` SMALLINT(5) UNSIGNED NOT NULL,
	`cont_dir_id` TINYINT(4) NOT NULL,
	`cont_ec_id` MEDIUMINT(8) UNSIGNED NOT NULL,
	`comp_id` INT(10) UNSIGNED NOT NULL,
	`comp_ms_id` SMALLINT(5) UNSIGNED NOT NULL,
	`comp_dir_id` TINYINT(4) NOT NULL,
	`comp_ec_id` MEDIUMINT(8) UNSIGNED NOT NULL,
	`grc_bt` DATETIME NOT NULL,
	`coef` DOUBLE NOT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tg$grpj_data_g
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tg$grpj_data_g` (
	`gr_id` INT(10) UNSIGNED NOT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tg$grpj_data_p
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tg$grpj_data_p` (
	`point_id` INT(10) UNSIGNED NOT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tg$grpj_g
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tg$grpj_g` (
	`gr_id` INT(10) UNSIGNED NOT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tg$grpj_p
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tg$grpj_p` (
	`point_id` INT(10) UNSIGNED NOT NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tmpl$dids
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tmpl$dids` (
	`di_id` INT(10) UNSIGNED NULL,
	`ds_id` INT(10) UNSIGNED NULL,
	`point_id` INT(10) UNSIGNED NULL,
	`ds_type_id` INT(10) UNSIGNED NULL,
	`sbst_tmpl_id` INT(10) UNSIGNED NULL,
	`src_id` INT(10) UNSIGNED NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tmpl$pladv
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tmpl$pladv` (
	`pl_id` INT(10) UNSIGNED NULL,
	`point_id` INT(10) UNSIGNED NULL,
	`ml_id` INT(10) UNSIGNED NULL,
	`sbst_tmpl_id` INT(10) UNSIGNED NULL,
	`src_id` INT(10) UNSIGNED NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tmpl$seadv
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tmpl$seadv` (
	`se_id` INT(10) UNSIGNED NULL,
	`src_id` INT(10) UNSIGNED NULL,
	`point_id` INT(10) UNSIGNED NULL,
	`ml_id` INT(10) UNSIGNED NULL,
	`se_ab` TINYINT(3) UNSIGNED NULL,
	`se_a` DOUBLE NULL,
	`se_b` DOUBLE NULL,
	`se_h` TINYINT(1) NULL,
	`se_h_per_id` TINYINT(3) UNSIGNED NULL,
	`se_h_depth` MEDIUMINT(8) UNSIGNED NULL,
	`se_h_restore_depth` MEDIUMINT(8) UNSIGNED NULL,
	`se_h_restore_per_id` TINYINT(3) UNSIGNED NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tmpl$sedsadv
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tmpl$sedsadv` (
	`se_id` INT(10) UNSIGNED NULL,
	`src_id` INT(10) UNSIGNED NULL,
	`point_id` INT(10) UNSIGNED NULL,
	`ds_id` INT(10) UNSIGNED NULL,
	`ds_type_id` INT(10) UNSIGNED NULL,
	`se_h` TINYINT(1) NULL,
	`se_h_per_id` TINYINT(3) UNSIGNED NULL,
	`se_h_depth` MEDIUMINT(8) UNSIGNED NULL,
	`se_h_restore_depth` MEDIUMINT(8) UNSIGNED NULL,
	`se_h_restore_per_id` TINYINT(3) UNSIGNED NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tmpl$sep
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tmpl$sep` (
	`se_id` INT(10) UNSIGNED NULL,
	`sep_id` INT(10) UNSIGNED NULL,
	`sp_id` INT(10) UNSIGNED NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tmpl$seprc
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tmpl$seprc` (
	`sep_id` INT(10) UNSIGNED NULL,
	`rc_id` TINYINT(3) UNSIGNED NULL,
	`sch_id` MEDIUMINT(8) UNSIGNED NULL,
	`per_id` TINYINT(3) UNSIGNED NULL,
	`sep_rc_lag` MEDIUMINT(8) UNSIGNED NULL,
	`sep_rc_depth` MEDIUMINT(8) UNSIGNED NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tmpl$srcm
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tmpl$srcm` (
	`src_id` INT(10) UNSIGNED NULL,
	`m` TINYINT(1) NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tmpl$srcm3
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tmpl$srcm3` (
	`src_id` INT(10) UNSIGNED NULL,
	`m` TINYINT(1) NULL,
	`dl_type_id` INT(10) UNSIGNED NULL,
	`tz_id` INT(10) UNSIGNED NULL,
	`src_tz_dst_used` INT(10) UNSIGNED NULL,
	`src_save_statistics` INT(10) UNSIGNED NULL,
	`point_id` INT(10) UNSIGNED NULL,
	`src_tmpl_id` INT(10) UNSIGNED NULL,
	`src_number` VARCHAR(80) NULL COLLATE 'utf8_bin',
	`src_dir_inv` INT(10) UNSIGNED NULL,
	`tsrc_tmpl_id` INT(10) UNSIGNED NULL,
	`src_tmpl_multipoint` INT(10) UNSIGNED NULL,
	`tdl_type_id` INT(10) UNSIGNED NULL,
	`ttz_id` INT(10) UNSIGNED NULL,
	`tsrc_tz_dst_used` INT(10) UNSIGNED NULL,
	`tsrc_save_statistics` INT(10) UNSIGNED NULL,
	`tsrc_dir_inv` INT(10) UNSIGNED NULL,
	`tinherit_src_number` INT(10) UNSIGNED NULL,
	`error_number` INT(10) UNSIGNED NULL,
	`error_msg` VARCHAR(1000) NULL COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.tmpl$src_point
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `tmpl$src_point` (
	`src_id` INT(10) UNSIGNED NULL,
	`point_id` INT(10) UNSIGNED NULL,
	`sbst_tmpl_id` INT(10) UNSIGNED NULL,
	`coef_u_numerator` DOUBLE NULL,
	`coef_u_denominator` DOUBLE NULL,
	`coef_i_numerator` DOUBLE NULL,
	`coef_i_denominator` DOUBLE NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.v_ar$period
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `v_ar$period` (
	`point_id` INT(10) UNSIGNED NOT NULL,
	`bt` DATETIME NOT NULL,
	`et` DATETIME NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.v_ar_map$gr
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `v_ar_map$gr` (
	`ma_id` INT(10) UNSIGNED NULL,
	`ts_id` TINYINT(1) NULL,
	`mt_id` INT(10) UNSIGNED NULL,
	`da` DATE NULL,
	`bt` DATETIME NULL,
	`et` DATETIME NULL,
	`map_id` INT(10) UNSIGNED NULL,
	`verge_id` SMALLINT(5) UNSIGNED NULL,
	`verge_code` VARCHAR(40) NULL COLLATE 'utf8_bin',
	`verge_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`ma_report_exceeding` TINYINT(1) NULL,
	`val` DOUBLE NULL,
	`has_specific_dstatus` TINYINT(1) NULL,
	`ml_id` MEDIUMINT(8) UNSIGNED NULL,
	`ml_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`gr_id` INT(10) UNSIGNED NULL,
	`gmod_id` MEDIUMINT(8) UNSIGNED NULL,
	`gmod_code` VARCHAR(40) NULL COLLATE 'utf8_bin',
	`gmod_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`gprc` TINYINT(3) UNSIGNED NULL,
	`ec_id` MEDIUMINT(8) UNSIGNED NULL,
	`ec_code` VARCHAR(50) NULL COLLATE 'utf8_bin',
	`ec_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`ec_in` TINYINT(1) NULL,
	`ds_id` INT(10) UNSIGNED NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.v_ar_map$point
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `v_ar_map$point` (
	`ma_id` INT(10) UNSIGNED NULL,
	`ts_id` TINYINT(1) NULL,
	`mt_id` INT(10) UNSIGNED NULL,
	`da` DATE NULL,
	`bt` DATETIME NULL,
	`et` DATETIME NULL,
	`map_id` INT(10) UNSIGNED NULL,
	`verge_id` SMALLINT(5) UNSIGNED NULL,
	`verge_code` VARCHAR(40) NULL COLLATE 'utf8_bin',
	`verge_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`ma_report_exceeding` TINYINT(1) NULL,
	`ma_auto_null_act` TINYINT(3) UNSIGNED NULL,
	`ma_auto_ccs` TINYINT(1) NULL,
	`val` DOUBLE NULL,
	`has_specific_dstatus` TINYINT(1) NULL,
	`ml_id` MEDIUMINT(8) UNSIGNED NULL,
	`ml_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`point_id` INT(10) UNSIGNED NULL,
	`ds_id` INT(10) UNSIGNED NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.v_ar_map$sam
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `v_ar_map$sam` (
	`ma_id` INT(10) UNSIGNED NULL,
	`ts_id` TINYINT(1) NULL,
	`mt_id` INT(10) UNSIGNED NULL,
	`da` DATE NULL,
	`bt` DATETIME NULL,
	`et` DATETIME NULL,
	`map_id` INT(10) UNSIGNED NULL,
	`verge_id` SMALLINT(5) UNSIGNED NULL,
	`verge_code` VARCHAR(40) NULL COLLATE 'utf8_bin',
	`verge_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`ma_report_exceeding` TINYINT(1) NULL,
	`val` DOUBLE NULL,
	`has_specific_dstatus` TINYINT(1) NULL,
	`sam_id` INT(10) UNSIGNED NULL,
	`sam_code` VARCHAR(80) NULL COLLATE 'utf8_bin',
	`sam_name` VARCHAR(120) NULL COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.v_ar_map_gr$f
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `v_ar_map_gr$f` (
	`ma_id` INT(10) UNSIGNED NULL,
	`ts_id` TINYINT(1) NULL,
	`mt_id` INT(10) UNSIGNED NULL,
	`gr_id` INT(10) UNSIGNED NULL,
	`gmod_id` MEDIUMINT(8) UNSIGNED NULL,
	`gprc` TINYINT(3) UNSIGNED NULL,
	`mt_ec_id` MEDIUMINT(8) UNSIGNED NULL,
	`mt_ec_in` TINYINT(1) NULL,
	`gmod_a` DOUBLE NULL,
	`gmod_b` DOUBLE NULL,
	`ml_id` MEDIUMINT(8) UNSIGNED NULL,
	`da` DATE NULL,
	`coef` DOUBLE NULL,
	`pl_id` INT(10) UNSIGNED NULL,
	`ec_id` MEDIUMINT(8) UNSIGNED NULL,
	`ec_in` TINYINT(1) NULL,
	`verge_id` SMALLINT(5) UNSIGNED NULL,
	`verge_code` VARCHAR(40) NULL COLLATE 'utf8_bin',
	`verge_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`ma_ab` TINYINT(1) NULL,
	`ma_a_nom` FLOAT NULL,
	`ma_a_denom` FLOAT NULL,
	`ma_b` FLOAT NULL,
	`ma_report_exceeding` TINYINT(1) NULL,
	`ma_lag` DOUBLE NULL,
	`ma_lag_per_id` TINYINT(3) UNSIGNED NULL,
	`map_id` INT(10) UNSIGNED NULL,
	`ml_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`gmod_code` VARCHAR(40) NULL COLLATE 'utf8_bin',
	`gmod_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`ec_code` VARCHAR(50) NULL COLLATE 'utf8_bin',
	`ec_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`orig` DOUBLE NULL,
	`sbst_improvable` TINYINT(1) NULL,
	`sbst_ab` TINYINT(1) NULL,
	`sbst_a` DOUBLE NULL,
	`sbst_b` DOUBLE NULL,
	`sbst_lag` MEDIUMINT(8) UNSIGNED NULL,
	`sbst_per_id` TINYINT(1) NULL,
	`sam_id` INT(10) UNSIGNED NULL,
	`pl2` DOUBLE NULL,
	`byp_state` DOUBLE NULL,
	`bt` DATETIME NULL,
	`et` DATETIME NULL,
	`rbt` DATETIME NULL,
	`sam_v` DOUBLE NULL,
	`imc_bias` DOUBLE NULL,
	`aggs_type_id` DOUBLE NULL,
	`ds_id` INT(10) UNSIGNED NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.v_ar_map_gr$v
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `v_ar_map_gr$v` (
	`ma_id` INT(10) UNSIGNED NULL,
	`ts_id` TINYINT(1) NULL,
	`mt_id` INT(10) UNSIGNED NULL,
	`gr_id` INT(10) UNSIGNED NULL,
	`gmod_id` MEDIUMINT(8) UNSIGNED NULL,
	`gprc` TINYINT(3) UNSIGNED NULL,
	`mt_ec_id` MEDIUMINT(8) UNSIGNED NULL,
	`mt_ec_in` TINYINT(1) NULL,
	`gmod_a` DOUBLE NULL,
	`gmod_b0` DOUBLE NULL,
	`ml_id` MEDIUMINT(8) UNSIGNED NULL,
	`aggs_id` TINYINT(3) UNSIGNED NULL,
	`aggf_id` TINYINT(3) UNSIGNED NULL,
	`md_id` SMALLINT(5) UNSIGNED NULL,
	`tff_id` TINYINT(3) UNSIGNED NULL,
	`dir_id` TINYINT(4) NULL,
	`ms_id` SMALLINT(5) UNSIGNED NULL,
	`per_id` TINYINT(3) UNSIGNED NULL,
	`md_int_value` MEDIUMINT(8) UNSIGNED NULL,
	`verge_id` SMALLINT(5) UNSIGNED NULL,
	`verge_code` VARCHAR(40) NULL COLLATE 'utf8_bin',
	`verge_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`ma_ab` TINYINT(1) NULL,
	`ma_a_nom` FLOAT NULL,
	`ma_a_denom` FLOAT NULL,
	`ma_b` FLOAT NULL,
	`ma_report_exceeding` TINYINT(1) NULL,
	`ma_lag` DOUBLE NULL,
	`ma_lag_per_id` TINYINT(3) UNSIGNED NULL,
	`map_id` INT(10) UNSIGNED NULL,
	`map_bt` DATETIME NULL,
	`map_et` DATETIME NULL,
	`map_h_bound` DATETIME NULL,
	`ml_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`gmod_code` VARCHAR(40) NULL COLLATE 'utf8_bin',
	`gmod_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`gmod_b` DOUBLE NULL,
	`da` DATE NULL,
	`mo` DATE NULL,
	`bt` DATETIME NULL,
	`et` DATETIME NULL,
	`i_nr` MEDIUMINT(8) UNSIGNED NULL,
	`point_ms_id` SMALLINT(5) UNSIGNED NULL,
	`point_dir_id` TINYINT(4) NULL,
	`coef` DOUBLE NULL,
	`ec_id` MEDIUMINT(8) UNSIGNED NULL,
	`ec_in` TINYINT(1) NULL,
	`point_id` INT(10) UNSIGNED NULL,
	`ec_code` VARCHAR(50) NULL COLLATE 'utf8_bin',
	`ec_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`ds_id` INT(10) UNSIGNED NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.v_ar_map_point$f
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `v_ar_map_point$f` (
	`ma_id` INT(10) UNSIGNED NULL,
	`ts_id` TINYINT(1) NULL,
	`mt_id` INT(10) UNSIGNED NULL,
	`ml_id` MEDIUMINT(8) UNSIGNED NULL,
	`ml_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`point_id` INT(10) UNSIGNED NULL,
	`verge_id` SMALLINT(5) UNSIGNED NULL,
	`verge_code` VARCHAR(40) NULL COLLATE 'utf8_bin',
	`verge_name` VARCHAR(120) NULL COLLATE 'utf8_bin',
	`ma_ab` TINYINT(1) NULL,
	`ma_a_nom` FLOAT NULL,
	`ma_a_denom` FLOAT NULL,
	`ma_b` FLOAT NULL,
	`ma_report_exceeding` TINYINT(1) NULL,
	`ma_auto_null_act` TINYINT(3) UNSIGNED NULL,
	`ma_auto_ccs` TINYINT(1) NULL,
	`map_id` INT(10) UNSIGNED NULL,
	`mo` DATE NULL,
	`da` DATE NULL,
	`per_id` TINYINT(3) UNSIGNED NULL,
	`md_int_value` MEDIUMINT(8) UNSIGNED NULL,
	`pl2` INT(10) UNSIGNED NULL,
	`byp_state` TINYINT(1) NULL,
	`bt` DATETIME NULL,
	`et` DATETIME NULL,
	`rbt0` DATETIME NULL,
	`ret0` DATETIME NULL,
	`aggs_type_id` TINYINT(3) UNSIGNED NULL,
	`aggs_id` TINYINT(3) UNSIGNED NULL,
	`bc` MEDIUMINT(8) UNSIGNED NULL,
	`ma_lag` MEDIUMINT(8) UNSIGNED NULL,
	`ma_lag_per_id` TINYINT(3) UNSIGNED NULL,
	`rbt` DATETIME NULL,
	`ret` DATETIME NULL,
	`ds_id` INT(10) UNSIGNED NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.v_plep_updated$f
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `v_plep_updated$f` (
	`pl_id` INT(10) UNSIGNED NOT NULL,
	`plep_bt` DATETIME NOT NULL,
	`plep_et` DATETIME NOT NULL,
	`di_id` INT(10) UNSIGNED NOT NULL,
	`se_id` INT(10) UNSIGNED NOT NULL,
	`sep_id` INT(10) UNSIGNED NOT NULL,
	`point_id` INT(10) UNSIGNED NOT NULL,
	`pl_enabled` TINYINT(1) NOT NULL,
	`point_enabled` TINYINT(1) NOT NULL,
	`ow0` DATETIME NULL,
	`ow` DATETIME NULL,
	`tz_shift` DOUBLE NULL,
	`aggs_id` TINYINT(3) UNSIGNED NOT NULL,
	`per_id` TINYINT(3) UNSIGNED NULL,
	`md_id` SMALLINT(5) UNSIGNED NOT NULL,
	`src_type_internal` TINYINT(1) NOT NULL,
	`sep_h_lag` MEDIUMINT(8) UNSIGNED NULL,
	`sep_h_depth` MEDIUMINT(8) UNSIGNED NULL,
	`sep_h_per_id` TINYINT(1) NULL,
	`sep_h_sch_id` MEDIUMINT(8) UNSIGNED NULL,
	`se_h_depth` MEDIUMINT(8) UNSIGNED NULL,
	`se_h_per_id` TINYINT(3) UNSIGNED NULL,
	`se_h_bound` DATETIME NULL,
	`se_h` TINYINT(1) NOT NULL,
	`se_enabled` TINYINT(1) NOT NULL,
	`di_enabled` TINYINT(1) NOT NULL,
	`sep_enabled` TINYINT(1) NOT NULL,
	`ph_enabled` TINYINT(1) NOT NULL,
	`ph_deleted` TINYINT(1) NOT NULL,
	`dp_deleted` TINYINT(1) NOT NULL,
	`dp_enabled` TINYINT(1) NOT NULL,
	`src_bt` DATETIME NULL,
	`src_et` DATETIME NULL,
	`src_enabled` TINYINT(1) NOT NULL,
	`se_h_restore_depth` MEDIUMINT(8) UNSIGNED NULL,
	`se_h_restore_per_id` TINYINT(3) UNSIGNED NULL,
	`bc` MEDIUMINT(8) UNSIGNED NOT NULL,
	`sbc` DOUBLE NULL,
	`aggs_type_id` TINYINT(3) UNSIGNED NOT NULL,
	`di_bt` DATETIME NULL,
	`di_et` DATETIME NULL,
	`cp_enabled` TINYINT(1) NULL
) ENGINE=MyISAM;

-- Dumping structure for view emcor.v_sep
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `v_sep` (
	`sep_id` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
	`se_id` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų šaltinio elemento identifikatorius',
	`sp_id` INT(10) UNSIGNED NOT NULL COMMENT 'Ryšio kanalo ir duomenų šaltinio sąsajos identifikatorius',
	`sep_b_lag` INT(8) NULL,
	`sep_b_depth` INT(8) NULL,
	`sep_b_per_id` INT(3) NULL,
	`sep_b_sch_id` INT(8) NULL,
	`sep_h_lag` INT(8) NULL,
	`sep_h_depth` INT(8) NULL,
	`sep_h_per_id` INT(3) NULL,
	`sep_h_sch_id` INT(8) NULL,
	`sep_f_lag` INT(8) NULL,
	`sep_f_depth` INT(8) NULL,
	`sep_f_per_id` INT(3) NULL,
	`sep_f_sch_id` INT(8) NULL,
	`sep_t_lag` INT(8) NULL,
	`sep_t_depth` INT(8) NULL,
	`sep_t_per_id` INT(3) NULL,
	`sep_t_sch_id` INT(8) NULL,
	`sep_r_lag` INT(8) NULL,
	`sep_r_depth` INT(8) NULL,
	`sep_r_per_id` INT(3) NULL,
	`sep_r_sch_id` INT(8) NULL,
	`sep_s_lag` INT(8) NULL,
	`sep_s_depth` INT(8) NULL,
	`sep_s_per_id` INT(3) NULL,
	`sep_s_sch_id` INT(8) NULL,
	`ml_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Matavimo linijos identifikatorius',
	`src_id` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
	`ph_type_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.v_sep_dp_sheaf
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `v_sep_dp_sheaf` (
	`sep_id` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
	`se_id` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų šaltinio elemento identifikatorius',
	`sp_id` INT(10) UNSIGNED NOT NULL COMMENT 'Ryšio kanalo ir duomenų šaltinio sąsajos identifikatorius',
	`sep_b_lag` INT(8) NULL,
	`sep_b_depth` INT(8) NULL,
	`sep_b_per_id` INT(3) NULL,
	`sep_b_sch_id` INT(8) NULL,
	`sep_h_lag` INT(8) NULL,
	`sep_h_depth` INT(8) NULL,
	`sep_h_per_id` INT(3) NULL,
	`sep_h_sch_id` INT(8) NULL,
	`sep_f_lag` INT(8) NULL,
	`sep_f_depth` INT(8) NULL,
	`sep_f_per_id` INT(3) NULL,
	`sep_f_sch_id` INT(8) NULL,
	`sep_t_lag` INT(8) NULL,
	`sep_t_depth` INT(8) NULL,
	`sep_t_per_id` INT(3) NULL,
	`sep_t_sch_id` INT(8) NULL,
	`sep_r_lag` INT(8) NULL,
	`sep_r_depth` INT(8) NULL,
	`sep_r_per_id` INT(3) NULL,
	`sep_r_sch_id` INT(8) NULL,
	`sep_s_lag` INT(8) NULL,
	`sep_s_depth` INT(8) NULL,
	`sep_s_per_id` INT(3) NULL,
	`sep_s_sch_id` INT(8) NULL,
	`sheaf_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Duomenų pluošto identifikatorius',
	`src_id` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
	`ph_type_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.v_sep_ds
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `v_sep_ds` (
	`sep_id` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
	`se_id` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų šaltinio elemento identifikatorius',
	`sp_id` INT(10) UNSIGNED NOT NULL COMMENT 'Ryšio kanalo ir duomenų šaltinio sąsajos identifikatorius',
	`sep_b_lag` INT(8) NULL,
	`sep_b_depth` INT(8) NULL,
	`sep_b_per_id` INT(3) NULL,
	`sep_b_sch_id` INT(8) NULL,
	`sep_h_lag` INT(8) NULL,
	`sep_h_depth` INT(8) NULL,
	`sep_h_per_id` INT(3) NULL,
	`sep_h_sch_id` INT(8) NULL,
	`sep_f_lag` INT(8) NULL,
	`sep_f_depth` INT(8) NULL,
	`sep_f_per_id` INT(3) NULL,
	`sep_f_sch_id` INT(8) NULL,
	`sep_t_lag` INT(8) NULL,
	`sep_t_depth` INT(8) NULL,
	`sep_t_per_id` INT(3) NULL,
	`sep_t_sch_id` INT(8) NULL,
	`sep_r_lag` INT(8) NULL,
	`sep_r_depth` INT(8) NULL,
	`sep_r_per_id` INT(3) NULL,
	`sep_r_sch_id` INT(8) NULL,
	`sep_s_lag` INT(8) NULL,
	`sep_s_depth` INT(8) NULL,
	`sep_s_per_id` INT(3) NULL,
	`sep_s_sch_id` INT(8) NULL,
	`ds_type_id` INT(10) UNSIGNED NOT NULL COMMENT 'Apskaitos būsenų signalų tipo identifikatorius',
	`ds_id` INT(10) UNSIGNED NOT NULL COMMENT 'Apskaitos būsenos signalo identifikatorius',
	`src_id` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
	`ph_type_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.v_sep_sheaf
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `v_sep_sheaf` (
	`sep_id` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų šaltinio elemento, nuskaitomo per ryšio kanalą, identifikatorius',
	`se_id` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų šaltinio elemento identifikatorius',
	`sp_id` INT(10) UNSIGNED NOT NULL COMMENT 'Ryšio kanalo ir duomenų šaltinio sąsajos identifikatorius',
	`sep_b_lag` INT(8) NULL,
	`sep_b_depth` INT(8) NULL,
	`sep_b_per_id` INT(3) NULL,
	`sep_b_sch_id` INT(8) NULL,
	`sep_h_lag` INT(8) NULL,
	`sep_h_depth` INT(8) NULL,
	`sep_h_per_id` INT(3) NULL,
	`sep_h_sch_id` INT(8) NULL,
	`sep_f_lag` INT(8) NULL,
	`sep_f_depth` INT(8) NULL,
	`sep_f_per_id` INT(3) NULL,
	`sep_f_sch_id` INT(8) NULL,
	`sep_t_lag` INT(8) NULL,
	`sep_t_depth` INT(8) NULL,
	`sep_t_per_id` INT(3) NULL,
	`sep_t_sch_id` INT(8) NULL,
	`sep_r_lag` INT(8) NULL,
	`sep_r_depth` INT(8) NULL,
	`sep_r_per_id` INT(3) NULL,
	`sep_r_sch_id` INT(8) NULL,
	`sep_s_lag` INT(8) NULL,
	`sep_s_depth` INT(8) NULL,
	`sep_s_per_id` INT(3) NULL,
	`sep_s_sch_id` INT(8) NULL,
	`sheaf_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Duomenų pluošto identifikatorius',
	`src_id` INT(10) UNSIGNED NOT NULL COMMENT 'Duomenų šaltinio identifikatorius',
	`ph_type_id` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Ryšio kanalų tipo identifikatorius'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.v_xfe_pl_data
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `v_xfe_pl_data` (
	`xfe_id` INT(10) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis formos elemento identifikatorius',
	`xo_id` BIGINT(20) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis operacijos identifikatorius',
	`xfe_t` DATETIME NOT NULL COMMENT 'Apsikeitimo duomenimis formos elemento duomenų laikas',
	`xfe_v` TINYINT(3) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis formos elemento reikšmė',
	`improvable` TINYINT(1) NOT NULL COMMENT 'Požymis, ar galimi geresni duomenys',
	`xfe_rt` DATETIME NULL COMMENT 'Apsikeitimo duomenimis formos elemento duomenų nuskaitymo laikas',
	`ml_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Matavimo linijos identifikatorius',
	`point_id` INT(10) UNSIGNED NULL COMMENT 'Matavimo taško identifikatorius',
	`gr_id` INT(10) UNSIGNED NULL COMMENT 'Grupės identifikatorius',
	`xo_time` DATETIME NOT NULL COMMENT 'Apsikeitimo duomenimis operacijos laikas',
	`xf_id` MEDIUMINT(8) UNSIGNED NULL COMMENT 'Apsikeitimo duomenimis formos identifikatorius',
	`xo_type_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis operacijų tipo identifikatorius',
	`xo_bt` DATETIME NOT NULL COMMENT 'Duomenų periodo pradžia',
	`xo_et` DATETIME NULL COMMENT 'Duomenų periodo pabaiga',
	`xo_info` VARCHAR(120) NULL COMMENT 'Apsikeitimo duomenimis operacijos papildoma informacija' COLLATE 'utf8_bin',
	`xo_tech_info` VARCHAR(120) NULL COMMENT 'Apsikeitimo duomenimis operacijos papildoma techninė informacija' COLLATE 'utf8_bin',
	`xo_info2` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`doc_nr` VARCHAR(50) NULL COMMENT 'Dokumento numeris' COLLATE 'utf8_bin',
	`xf_name` VARCHAR(120) NOT NULL COMMENT 'Apsikeitimo duomenimis formos pavadinimas' COLLATE 'utf8_bin',
	`xf_enabled` TINYINT(1) NOT NULL COMMENT 'Apsikeitimo duomenimis formos naudojimo požymis',
	`xfau_id` INT(10) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis formos mazgo identifikatorius',
	`xe_id` INT(10) UNSIGNED NULL COMMENT 'Apsikeitimo duomenimis elemento identifikatorius',
	`xfe_enabled` TINYINT(1) NOT NULL COMMENT 'Apsikeitimo duomenimis formos elemento naudojimo požymis',
	`xfe_info` VARCHAR(250) NULL COMMENT 'Apsikeitimo duomenimis formos elemento informacija' COLLATE 'utf8_bin',
	`xfau_type_id` SMALLINT(5) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis formų mazgų tipo identifikatorius',
	`xfau_enabled` TINYINT(1) NOT NULL COMMENT 'Apsikeitimo duomenimis formos mazgo naudojimo požymis',
	`inherit_cn` TINYINT(1) NOT NULL COMMENT 'Kodo ir pavadinimo paveldėjimo požymis',
	`xfau_code` VARCHAR(80) NULL COMMENT 'Apsikeitimo duomenimis formos mazgo kodas' COLLATE 'utf8_bin',
	`xfau_name` VARCHAR(250) NULL COMMENT 'Apsikeitimo duomenimis formos mazgo pavadinimas' COLLATE 'utf8_bin',
	`xfau_code2` VARCHAR(80) NULL COMMENT 'Apsikeitimo duomenimis formos mazgo antras kodas' COLLATE 'utf8_bin',
	`xfau_name2` VARCHAR(250) NULL COMMENT 'Apsikeitimo duomenimis formos mazgo antras pavadinimas' COLLATE 'utf8_bin',
	`xfa_id` INT(10) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis formos sekcijos identifikatorius',
	`xf_type_id` SMALLINT(5) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis formų tipo identifikatorius',
	`xa_id` INT(10) UNSIGNED NOT NULL COMMENT 'Apsikeitimo duomenimis adresato identifikatorius',
	`rpp_id` MEDIUMINT(8) UNSIGNED NOT NULL COMMENT 'Automatizuotos ataskaitos protokolo identifikatorius',
	`xf_import` TINYINT(1) NOT NULL COMMENT 'Importo/eksporto formos požymis',
	`rp_id` INT(10) UNSIGNED NULL COMMENT 'Ataskaitos identifikatorius',
	`xs_id` TINYINT(3) UNSIGNED NULL COMMENT 'Apsikeitimo duomenų statuso identifikatorius'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.xf_import_61968_data_errors
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `xf_import_61968_data_errors` (
	`mrid` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_sub_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_description` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`item_code` VARCHAR(250) NULL COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.xf_import_80030_data_errors
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `xf_import_80030_data_errors` (
	`au_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_sub_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_description` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`area_inn` VARCHAR(250) NULL COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.xf_import_askp_data_errors
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `xf_import_askp_data_errors` (
	`au_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_sub_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_description` VARCHAR(250) NULL COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.xf_import_doedb_data_errors
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `xf_import_doedb_data_errors` (
	`au_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_sub_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_description` VARCHAR(250) NULL COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.xf_import_eecsv_data_errors
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `xf_import_eecsv_data_errors` (
	`au_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_sub_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_description` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`au_to_code` VARCHAR(250) NULL COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.xf_import_gcsv_data_errors
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `xf_import_gcsv_data_errors` (
	`au_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_sub_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_description` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`au_to_code` VARCHAR(250) NULL COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.xf_import_pcci_data_errors
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `xf_import_pcci_data_errors` (
	`au_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_sub_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_description` VARCHAR(250) NULL COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.xf_import_sng_1517_data_errors
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `xf_import_sng_1517_data_errors` (
	`area_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`area_name` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`au_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_sub_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_description` VARCHAR(250) NULL COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.xf_import_ukre_data_errors
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `xf_import_ukre_data_errors` (
	`au_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_sub_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_description` VARCHAR(250) NULL COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for view emcor.xf_import_xml_data_errors
-- Creating temporary table to overcome VIEW dependency errors
CREATE TABLE `xf_import_xml_data_errors` (
	`area_inn` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_sub_code` VARCHAR(250) NULL COLLATE 'utf8_bin',
	`error_description` VARCHAR(250) NULL COLLATE 'utf8_bin'
) ENGINE=MyISAM;

-- Dumping structure for procedure emcor.ei
DELIMITER //
CREATE DEFINER=`EMCOS`@`%` PROCEDURE `ei`(SLC varchar(21845),par bigint)
BEGIN
EXECUTE IMMEDIATE SLC using par;
END//
DELIMITER ;

-- Dumping structure for procedure emcor.p1
DELIMITER //
CREATE DEFINER=`EMCOS`@`%` PROCEDURE `p1`()
BEGIN
  DECLARE done INT DEFAULT FALSE;
  DECLARE tGR_TYPE_ID mediumint unsigned;
  declare tGR_TYPE_NAME varchar(120);
  DECLARE cur1 CURSOR FOR SELECT gr_type_id, gr_type_name FROM gr_type;
  DECLARE CONTINUE HANDLER FOR NOT FOUND SET done = TRUE;

  OPEN cur1;

  loop1: LOOP
    FETCH cur1 INTO tGR_TYPE_ID,tGR_TYPE_NAME;
    IF done THEN
      LEAVE loop1;
    END IF;
    IF tGR_TYPE_ID < 4 THEN
 select tGR_TYPE_NAME;
    END IF;
  END LOOP;

  CLOSE cur1;

END//
DELIMITER ;

-- Dumping structure for procedure emcor.reg_das
DELIMITER //
CREATE DEFINER=`root`@`localhost` PROCEDURE `reg_das`()
BEGIN
insert into curr_das (das_id)
select das_id from das where das_name=substr(user(),INSTR(user(),'@')+1)
ON DUPLICATE KEY UPDATE
das_id = values(das_id);
END//
DELIMITER ;

-- Dumping structure for function emcor.nextval
DELIMITER //
CREATE DEFINER=`root`@`localhost` FUNCTION `nextval`(`seq_name` varchar(100)) RETURNS bigint(20)
BEGIN
    DECLARE cur_val bigint(20);
 
    SELECT
        sequence_cur_value INTO cur_val
    FROM
        sequence_data
    WHERE
        sequence_name = seq_name
    ;
 
    IF cur_val IS NOT NULL THEN
        UPDATE
            sequence_data
        SET
            sequence_cur_value = IF (
                (sequence_cur_value + sequence_increment) > sequence_max_value,
                IF (
                    sequence_cycle = TRUE,
                    sequence_min_value,
                    NULL
                ),
                sequence_cur_value + sequence_increment
            )
        WHERE
            sequence_name = seq_name
        ;
    END IF;
 
    RETURN cur_val;
END//
DELIMITER ;

-- Dumping structure for trigger emcor.t2_airtrg
SET @OLDTMP_SQL_MODE=@@SQL_MODE, SQL_MODE='STRICT_TRANS_TABLES,NO_ENGINE_SUBSTITUTION';
DELIMITER //
CREATE TRIGGER `t2_airtrg` AFTER INSERT ON `t2` FOR EACH ROW begin 
set @s = '';
-- EXECUTE IMMEDIATE concat('select ',tdesc_col_name,' into @s from ',ttab_name,' where ',tbp_col_name,'=?') using tcol_val;
call ei(concat('select ml_name from ml where ml_id=?'),new.i);
insert into gttt (c1) values (@s);
end//
DELIMITER ;
SET SQL_MODE=@OLDTMP_SQL_MODE;

-- Dumping structure for view emcor.act_360$point
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `act_360$point`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `act_360$point` AS select `t#act_360$point`.`point_id` AS `point_id`,`t#act_360$point`.`cp_t` AS `cp_t`,`t#act_360$point`.`fp_id` AS `fp_id`,`t#act_360$point`.`status` AS `status` from `t#act_360$point` where `t#act_360$point`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.bgao_gttla
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `bgao_gttla`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `bgao_gttla` AS select                           
bgao_id                                                                 
 from `t#bgao_gttla` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.curr_das
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `curr_das`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `curr_das` AS select                             
das_id                                                                  
 from `t#curr_das` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.curr_rodo_das
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `curr_rodo_das`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `curr_rodo_das` AS select                        
rodo_id                                                                 
,das_id                                                                 
 from `t#curr_rodo_das` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.dqp$pldi
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `dqp$pldi`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `dqp$pldi` AS select `t#dqp$pldi`.`point_id` AS `point_id`,`t#dqp$pldi`.`pl_id` AS `pl_id`,`t#dqp$pldi`.`pl_enabled` AS `pl_enabled`,`t#dqp$pldi`.`ml_id` AS `ml_id`,`t#dqp$pldi`.`md_id` AS `md_id`,`t#dqp$pldi`.`aggs_id` AS `aggs_id`,`t#dqp$pldi`.`md_per_id` AS `md_per_id`,`t#dqp$pldi`.`md_int_value` AS `md_int_value`,`t#dqp$pldi`.`aggs_type_id` AS `aggs_type_id`,`t#dqp$pldi`.`di_id` AS `di_id`,`t#dqp$pldi`.`di_enabled` AS `di_enabled`,`t#dqp$pldi`.`bc` AS `bc`,`t#dqp$pldi`.`src_type_internal` AS `src_type_internal`,`t#dqp$pldi`.`mow_shift` AS `mow_shift` from `t#dqp$pldi` where `t#dqp$pldi`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.dqp$sesep
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `dqp$sesep`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `dqp$sesep` AS select `t#dqp$sesep`.`point_id` AS `point_id`,`t#dqp$sesep`.`pl_id` AS `pl_id`,`t#dqp$sesep`.`se_enabled` AS `se_enabled`,`t#dqp$sesep`.`se_h` AS `se_h`,`t#dqp$sesep`.`se_h_per_id` AS `se_h_per_id`,`t#dqp$sesep`.`se_h_depth` AS `se_h_depth`,`t#dqp$sesep`.`se_h_bound` AS `se_h_bound`,`t#dqp$sesep`.`se_h_restore_depth` AS `se_h_restore_depth`,`t#dqp$sesep`.`se_h_restore_per_id` AS `se_h_restore_per_id`,`t#dqp$sesep`.`src_bt` AS `src_bt`,`t#dqp$sesep`.`src_et` AS `src_et`,`t#dqp$sesep`.`src_enabled` AS `src_enabled`,`t#dqp$sesep`.`tz_id` AS `tz_id`,`t#dqp$sesep`.`src_tz_dst_used` AS `src_tz_dst_used`,`t#dqp$sesep`.`src_type_id` AS `src_type_id`,`t#dqp$sesep`.`src_type_internal` AS `src_type_internal`,`t#dqp$sesep`.`dp_enabled` AS `dp_enabled`,`t#dqp$sesep`.`dp_deleted` AS `dp_deleted`,`t#dqp$sesep`.`sep_id` AS `sep_id`,`t#dqp$sesep`.`sep_enabled` AS `sep_enabled`,`t#dqp$sesep`.`sep_h_lag` AS `sep_h_lag`,`t#dqp$sesep`.`sep_h_depth` AS `sep_h_depth`,`t#dqp$sesep`.`sep_h_per_id` AS `sep_h_per_id`,`t#dqp$sesep`.`sep_h_sch_id` AS `sep_h_sch_id`,`t#dqp$sesep`.`ph_enabled` AS `ph_enabled`,`t#dqp$sesep`.`ph_deleted` AS `ph_deleted`,`t#dqp$sesep`.`tzh_shift` AS `tzh_shift`,`t#dqp$sesep`.`ow_shift` AS `ow_shift` from `t#dqp$sesep` where `t#dqp$sesep`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.evla
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `evla`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `evla` AS select                                 
ev_time                                                                 
,ev_id                                                                  
 from `t#evla` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gen_adj$f0
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gen_adj$f0`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gen_adj$f0` AS select `t#gen_adj$f0`.`da` AS `da`,`t#gen_adj$f0`.`bga_id` AS `bga_id`,`t#gen_adj$f0`.`src_name` AS `src_name`,`t#gen_adj$f0`.`ml_id` AS `ml_id`,`t#gen_adj$f0`.`tpl_id` AS `tpl_id`,`t#gen_adj$f0`.`sep_id` AS `sep_id`,`t#gen_adj$f0`.`point_id` AS `point_id`,`t#gen_adj$f0`.`mou_id` AS `mou_id`,`t#gen_adj$f0`.`mou_bt` AS `mou_bt`,`t#gen_adj$f0`.`mou_et` AS `mou_et`,`t#gen_adj$f0`.`meter_id` AS `meter_id`,`t#gen_adj$f0`.`ms_id` AS `ms_id`,`t#gen_adj$f0`.`dir_id` AS `dir_id`,`t#gen_adj$f0`.`tff_id` AS `tff_id`,`t#gen_adj$f0`.`pl_id` AS `pl_id`,`t#gen_adj$f0`.`aggs_type_id` AS `aggs_type_id` from `t#gen_adj$f0` where `t#gen_adj$f0`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.gen_adj$f1
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gen_adj$f1`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gen_adj$f1` AS select `t#gen_adj$f1`.`pl_t1` AS `pl_t1`,`t#gen_adj$f1`.`da` AS `da`,`t#gen_adj$f1`.`bga_id` AS `bga_id`,`t#gen_adj$f1`.`src_name` AS `src_name`,`t#gen_adj$f1`.`ml_id` AS `ml_id`,`t#gen_adj$f1`.`tpl_id` AS `tpl_id`,`t#gen_adj$f1`.`sep_id` AS `sep_id`,`t#gen_adj$f1`.`point_id` AS `point_id`,`t#gen_adj$f1`.`mou_id` AS `mou_id`,`t#gen_adj$f1`.`mou_bt` AS `mou_bt`,`t#gen_adj$f1`.`mou_et` AS `mou_et`,`t#gen_adj$f1`.`meter_id` AS `meter_id`,`t#gen_adj$f1`.`ms_id` AS `ms_id`,`t#gen_adj$f1`.`dir_id` AS `dir_id`,`t#gen_adj$f1`.`tff_id` AS `tff_id`,`t#gen_adj$f1`.`pl_id` AS `pl_id`,`t#gen_adj$f1`.`aggs_type_id` AS `aggs_type_id` from `t#gen_adj$f1` where `t#gen_adj$f1`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.gr_filter
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gr_filter`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gr_filter` AS select                            
gr_filter_visibility                                                    
,gr_filter_oper                                                         
 from `t#gr_filter` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gr_filter_data
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gr_filter_data`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gr_filter_data` AS select                       
gr_id                                                                   
,visibility                                                             
 from `t#gr_filter_data` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gtree_ds
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gtree_ds`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gtree_ds` AS select                             
ds_id                                                                   
 from `t#gtree_ds` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gtree_gr
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gtree_gr`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gtree_gr` AS select                             
gr_id                                                                   
 from `t#gtree_gr` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gtree_m
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gtree_m`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gtree_m` AS select                              
ms_type_id                                                              
,aggs_type_id                                                           
,msf_id                                                                 
,md_id                                                                  
,dir_id                                                                 
,ml_id                                                                  
,sheaf_id                                                               
 from `t#gtree_m` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gtree_point
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gtree_point`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gtree_point` AS select                          
point_id                                                                
 from `t#gtree_point` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gtt5
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gtt5`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gtt5` AS select                                 
point_id                                                                
,withe_id                                                               
,sep_id                                                                 
,src_type_id                                                            
,di_id                                                                  
,dp_id                                                                  
,is_point                                                               
,ind1                                                                   
,ind2                                                                   
,ind3                                                                   
,enr                                                                    
 from `t#gtt5` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gtta
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gtta`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gtta` AS select                                 
`show`                                                                    
 from `t#gtta` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gttd
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gttd`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gttd` AS select                                 
d1                                                                      
 from `t#gttd` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gttf
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gttf`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gttf` AS select                                 
show_generated                                                          
,show_instant                                                           
,mlset_id                                                               
,show_ml_selected                                                       
,show_di_enabled                                                        
,ignore_mcc                                                             
,ignore_icc                                                             
,ignore_act                                                             
,show_point_anyway                                                      
,include_monthly                                                        
 from `t#gttf` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gttn
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gttn`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gttn` AS select                                 
id1                                                                     
,id2                                                                    
,id3                                                                    
,id4                                                                    
,id5                                                                    
,id6                                                                    
,id7                                                                    
,id8                                                                    
,id9                                                                    
,id0                                                                    
,v1                                                                     
,v2                                                                     
,v3                                                                     
,v4                                                                     
,v5                                                                     
,v6                                                                     
,v7                                                                     
,v8                                                                     
,v9                                                                     
,v0                                                                     
,d1                                                                     
,d2                                                                     
,d3                                                                     
,d4                                                                     
,d5                                                                     
,d6                                                                     
,d7                                                                     
,d8                                                                     
,d9                                                                     
,d0                                                                     
,c1                                                                     
,c2                                                                     
,c3                                                                     
,c4                                                                     
,c5                                                                     
,c6                                                                     
,c7                                                                     
,c8                                                                     
,c9                                                                     
,c0                                                                     
,cbig                                                                   
 from `t#gttn` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gttn2
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gttn2`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gttn2` AS select                                
id1                                                                     
,id2                                                                    
,id3                                                                    
,id4                                                                    
,id5                                                                    
,id6                                                                    
,id7                                                                    
,id8                                                                    
,id9                                                                    
,id0                                                                    
,v1                                                                     
,v2                                                                     
,v3                                                                     
,v4                                                                     
,v5                                                                     
,v6                                                                     
,v7                                                                     
,v8                                                                     
,v9                                                                     
,v0                                                                     
,d1                                                                     
,d2                                                                     
,d3                                                                     
,d4                                                                     
,d5                                                                     
,d6                                                                     
,d7                                                                     
,d8                                                                     
,d9                                                                     
,d0                                                                     
,c1                                                                     
,c2                                                                     
,c3                                                                     
,c4                                                                     
,c5                                                                     
,c6                                                                     
,c7                                                                     
,c8                                                                     
,c9                                                                     
,c0                                                                     
,cbig                                                                   
 from `t#gttn2` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gttq
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gttq`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gttq` AS select                                 
id1                                                                     
,id2                                                                    
,id3                                                                    
,id4                                                                    
,id5                                                                    
,id6                                                                    
,id7                                                                    
,id8                                                                    
,id9                                                                    
,id0                                                                    
,v1                                                                     
,v2                                                                     
,v3                                                                     
,v4                                                                     
,v5                                                                     
,v6                                                                     
,v7                                                                     
,v8                                                                     
,v9                                                                     
,v0                                                                     
,d1                                                                     
,d2                                                                     
,d3                                                                     
,d4                                                                     
,d5                                                                     
,d6                                                                     
,d7                                                                     
,d8                                                                     
,d9                                                                     
,d0                                                                     
,c1                                                                     
,c2                                                                     
,c3                                                                     
,c4                                                                     
,c5                                                                     
,c6                                                                     
,c7                                                                     
,c8                                                                     
,c9                                                                     
,c0                                                                     
,cbig                                                                   
 from `t#gttq` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gttr
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gttr`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gttr` AS select                                 
point_id                                                                
,sheaf_id                                                               
,sep_id                                                                 
,src_type_id                                                            
,di_id                                                                  
 from `t#gttr` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gtts
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gtts`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gtts` AS select                                 
id1                                                                     
,id2                                                                    
,id3                                                                    
,id4                                                                    
,id5                                                                    
,id6                                                                    
,id7                                                                    
,id8                                                                    
,id9                                                                    
,id0                                                                    
,v1                                                                     
,v2                                                                     
,v3                                                                     
,v4                                                                     
,v5                                                                     
,v6                                                                     
,v7                                                                     
,v8                                                                     
,v9                                                                     
,v0                                                                     
,d1                                                                     
,d2                                                                     
,d3                                                                     
,d4                                                                     
,d5                                                                     
,d6                                                                     
,d7                                                                     
,d8                                                                     
,d9                                                                     
,d0                                                                     
,c1                                                                     
,c2                                                                     
,c3                                                                     
,c4                                                                     
,c5                                                                     
,c6                                                                     
,c7                                                                     
,c8                                                                     
,c9                                                                     
,c0                                                                     
 from `t#gtts` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gttt
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gttt`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gttt` AS select                                 
id1                                                                     
,id2                                                                    
,id3                                                                    
,id4                                                                    
,id5                                                                    
,id6                                                                    
,id7                                                                    
,id8                                                                    
,id9                                                                    
,id0                                                                    
,v1                                                                     
,v2                                                                     
,v3                                                                     
,v4                                                                     
,v5                                                                     
,v6                                                                     
,v7                                                                     
,v8                                                                     
,v9                                                                     
,v0                                                                     
,d1                                                                     
,d2                                                                     
,d3                                                                     
,d4                                                                     
,d5                                                                     
,d6                                                                     
,d7                                                                     
,d8                                                                     
,d9                                                                     
,d0                                                                     
,c1                                                                     
,c2                                                                     
,c3                                                                     
,c4                                                                     
,c5                                                                     
,c6                                                                     
,c7                                                                     
,c8                                                                     
,c9                                                                     
,c0                                                                     
,cbig                                                                   
 from `t#gttt` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gttw
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gttw`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gttw` AS select                                 
ses_id                                                                  
 from `t#gttw` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.gttx
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `gttx`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `gttx` AS select                                 
id0                                                                     
 from `t#gttx` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.ipty
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `ipty`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `ipty` AS select                                 
spty_id                                                                 
,spty_value                                                             
 from `t#ipty` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.ml_show
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `ml_show`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `ml_show` AS select                              
ml_id                                                                   
 from `t#ml_show` where cid=connection_id() with check option ;

-- Dumping structure for view emcor.st_act_360_result
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_act_360_result`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_act_360_result` AS SELECT point_id,cp_t FROM ACT_360$POINT WHERE status=0 ;

-- Dumping structure for view emcor.st_act_type
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_act_type`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_act_type` AS select
a.ACT_TYPE_ID
,a.ACT_TYPE_NAME
from ACT_TYPE a ;

-- Dumping structure for view emcor.st_curr_user
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_curr_user`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `st_curr_user` AS SELECT USER_ID,(SELECT SES_ID FROM gttw) ses_id from users WHERE dbu = SUBSTRING_INDEX(user(),'@',1) ;

-- Dumping structure for view emcor.st_server_tz
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_server_tz`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_server_tz` AS select
A.TZ_ID
,A.SERVER_TZ_DST_USED
,B.TZ_CODE
,B.TZ_NAME
,B.TZ_WINTER_OFFSET
,B.TZ_WINTER_TZD
,B.TZ_SUMMER_TZD
from SERVER_TZ A
join TZ B on (A.TZ_ID = B.TZ_ID) ;

-- Dumping structure for view emcor.st_src_type_mod_withe#opty
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_src_type_mod_withe#opty`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_src_type_mod_withe#opty` AS select `a`.`src_type_id` AS `src_type_id`,`a`.`src_type_mod_nr` AS `src_type_mod_nr`,`a`.`is_point` AS `is_point`,`a`.`withe_id` AS `withe_id`,`a`.`ind1` AS `ind1`,`a`.`ind2` AS `ind2`,`a`.`ind3` AS `ind3`,`a`.`opty_id` AS `opty_id`,`a`.`opty_value` AS `opty_value`,`b`.`lpty_type_id` AS `lpty_type_id`,`b`.`enum_id` AS `enum_id`,`b`.`opty_code` AS `opty_code`,`b`.`opty_name` AS `opty_name`,`b`.`opty_tm` AS `opty_tm`,`b`.`opty_default` AS `opty_default`,`b`.`opty_nr` AS `opty_nr`,`c`.`enum_code` AS `enum_code`,`c`.`enum_name` AS `enum_name`,`c`.`enum_type_id` AS `enum_type_id`,`d`.`lpty_type_code` AS `lpty_type_code`,`d`.`lpty_type_name` AS `lpty_type_name`,`e`.`dt_id` AS `dt_id`,`e`.`ind1_cnt` AS `ind1_cnt`,`e`.`ind1_code` AS `ind1_code`,`e`.`ind2_cnt` AS `ind2_cnt`,`e`.`ind2_code` AS `ind2_code`,`e`.`ind3_cnt` AS `ind3_cnt`,`e`.`ind3_code` AS `ind3_code`,`e`.`enr_cnt` AS `enr_cnt`,`e`.`readable` AS `readable`,`e`.`writable` AS `writable`,`e`.`omit_value` AS `omit_value`,`f`.`dt_code` AS `dt_code`,`g`.`version_dependent` AS `version_dependent`,`g`.`typecode_dependent` AS `typecode_dependent`,`g`.`src_type_mod_desc` AS `src_type_mod_desc`,`h`.`src_type_code` AS `src_type_code`,`h`.`src_type_name` AS `src_type_name`,`h`.`guid` AS `guid`,`h`.`src_type_internal` AS `src_type_internal`,`h`.`tm_guid` AS `tm_guid`,`h`.`devicetype` AS `devicetype`,`h`.`horizontal_read_mode` AS `horizontal_read_mode` from (((((((`src_type_mod_withe#opty` `a` join `opty` `b` on(`a`.`opty_id` = `b`.`opty_id`)) join `lpty_type` `d` on(`b`.`lpty_type_id` = `d`.`lpty_type_id`)) join `src_type_mod_withe` `e` on(`a`.`src_type_id` = `e`.`src_type_id` and `a`.`src_type_mod_nr` = `e`.`src_type_mod_nr` and `a`.`is_point` = `e`.`is_point` and `a`.`withe_id` = `e`.`withe_id`)) join `dt` `f` on(`e`.`dt_id` = `f`.`dt_id`)) join `src_type_mod` `g` on(`e`.`src_type_id` = `g`.`src_type_id` and `e`.`src_type_mod_nr` = `g`.`src_type_mod_nr`)) join `src_type` `h` on(`g`.`src_type_id` = `h`.`src_type_id`)) left join `enum` `c` on(`b`.`enum_id` = `c`.`enum_id`));

-- Dumping structure for view emcor.st_src_type_mod_withe_opty
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_src_type_mod_withe_opty`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_src_type_mod_withe_opty` AS select
A.SRC_TYPE_ID
,A.SRC_TYPE_MOD_NR
,A.IS_POINT
,A.WITHE_ID
,A.OPTY_ID
,A.RC_IN
,A.OPTY_VALUE
,B.LPTY_TYPE_ID
,B.ENUM_ID
,B.OPTY_CODE
,B.OPTY_NAME
,B.OPTY_TM
,B.OPTY_DEFAULT
,B.OPTY_NR
,C.ENUM_CODE
,C.ENUM_NAME
,C.ENUM_TYPE_ID
,D.LPTY_TYPE_CODE
,D.LPTY_TYPE_NAME
,E.DT_ID
,E.IND1_CNT
,E.IND1_CODE
,E.IND2_CNT
,E.IND2_CODE
,E.IND3_CNT
,E.IND3_CODE
,E.ENR_CNT
,E.READABLE
,E.WRITABLE
,E.OMIT_VALUE
,F.DT_CODE
,G.VERSION_DEPENDENT
,G.TYPECODE_DEPENDENT
,G.SRC_TYPE_MOD_DESC
,H.SRC_TYPE_CODE
,H.SRC_TYPE_NAME
,H.GUID
,H.SRC_TYPE_INTERNAL
,H.TM_GUID
,H.DEVICETYPE
,H.HORIZONTAL_READ_MODE
from SRC_TYPE_MOD_WITHE_OPTY A
join OPTY B on (A.OPTY_ID = B.OPTY_ID)
join LPTY_TYPE D on (B.LPTY_TYPE_ID = D.LPTY_TYPE_ID)
join SRC_TYPE_MOD_WITHE E on (A.SRC_TYPE_ID = E.SRC_TYPE_ID
and A.SRC_TYPE_MOD_NR = E.SRC_TYPE_MOD_NR
and A.IS_POINT = E.IS_POINT
and A.WITHE_ID = E.WITHE_ID)
join DT F on (E.DT_ID = F.DT_ID)
join SRC_TYPE_MOD G on (E.SRC_TYPE_ID = G.SRC_TYPE_ID
and E.SRC_TYPE_MOD_NR = G.SRC_TYPE_MOD_NR)
join SRC_TYPE H on (G.SRC_TYPE_ID = H.SRC_TYPE_ID)
left outer join ENUM C on (B.ENUM_ID = C.ENUM_ID) ;

-- Dumping structure for view emcor.st_src_type_mod_withe_rc#opty
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_src_type_mod_withe_rc#opty`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_src_type_mod_withe_rc#opty` AS select `a`.`src_type_id` AS `src_type_id`,`a`.`src_type_mod_nr` AS `src_type_mod_nr`,`a`.`is_point` AS `is_point`,`a`.`withe_id` AS `withe_id`,`a`.`ind1` AS `ind1`,`a`.`ind2` AS `ind2`,`a`.`ind3` AS `ind3`,`a`.`rc_in` AS `rc_in`,`a`.`opty_id` AS `opty_id`,`a`.`opty_value` AS `opty_value`,`b`.`lpty_type_id` AS `lpty_type_id`,`b`.`enum_id` AS `enum_id`,`b`.`opty_code` AS `opty_code`,`b`.`opty_name` AS `opty_name`,`b`.`opty_tm` AS `opty_tm`,`b`.`opty_default` AS `opty_default`,`b`.`opty_nr` AS `opty_nr`,`c`.`enum_code` AS `enum_code`,`c`.`enum_name` AS `enum_name`,`c`.`enum_type_id` AS `enum_type_id`,`d`.`lpty_type_code` AS `lpty_type_code`,`d`.`lpty_type_name` AS `lpty_type_name`,`e`.`dt_id` AS `dt_id`,`e`.`ind1_cnt` AS `ind1_cnt`,`e`.`ind1_code` AS `ind1_code`,`e`.`ind2_cnt` AS `ind2_cnt`,`e`.`ind2_code` AS `ind2_code`,`e`.`ind3_cnt` AS `ind3_cnt`,`e`.`ind3_code` AS `ind3_code`,`e`.`enr_cnt` AS `enr_cnt`,`e`.`readable` AS `readable`,`e`.`writable` AS `writable`,`e`.`omit_value` AS `omit_value`,`f`.`dt_code` AS `dt_code`,`g`.`version_dependent` AS `version_dependent`,`g`.`typecode_dependent` AS `typecode_dependent`,`g`.`src_type_mod_desc` AS `src_type_mod_desc`,`h`.`src_type_code` AS `src_type_code`,`h`.`src_type_name` AS `src_type_name`,`h`.`guid` AS `guid`,`h`.`src_type_internal` AS `src_type_internal`,`h`.`tm_guid` AS `tm_guid`,`h`.`devicetype` AS `devicetype`,`h`.`horizontal_read_mode` AS `horizontal_read_mode` from (((((((`src_type_mod_withe_rc#opty` `a` join `opty` `b` on(`a`.`opty_id` = `b`.`opty_id`)) join `lpty_type` `d` on(`b`.`lpty_type_id` = `d`.`lpty_type_id`)) join `src_type_mod_withe` `e` on(`a`.`src_type_id` = `e`.`src_type_id` and `a`.`src_type_mod_nr` = `e`.`src_type_mod_nr` and `a`.`is_point` = `e`.`is_point` and `a`.`withe_id` = `e`.`withe_id`)) join `dt` `f` on(`e`.`dt_id` = `f`.`dt_id`)) join `src_type_mod` `g` on(`e`.`src_type_id` = `g`.`src_type_id` and `e`.`src_type_mod_nr` = `g`.`src_type_mod_nr`)) join `src_type` `h` on(`g`.`src_type_id` = `h`.`src_type_id`)) left join `enum` `c` on(`b`.`enum_id` = `c`.`enum_id`));

-- Dumping structure for view emcor.st_src_type_mod_withe_rc_opty
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_src_type_mod_withe_rc_opty`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_src_type_mod_withe_rc_opty` AS select
A.SRC_TYPE_ID
,A.SRC_TYPE_MOD_NR
,A.IS_POINT
,A.WITHE_ID
,A.RC_IN
,A.OPTY_ID
,A.OPTY_VALUE
,B.LPTY_TYPE_ID
,B.ENUM_ID
,B.OPTY_CODE
,B.OPTY_NAME
,B.OPTY_TM
,B.OPTY_DEFAULT
,B.OPTY_NR
,C.ENUM_CODE
,C.ENUM_NAME
,C.ENUM_TYPE_ID
,D.LPTY_TYPE_CODE
,D.LPTY_TYPE_NAME
,E.DT_ID
,E.IND1_CNT
,E.IND1_CODE
,E.IND2_CNT
,E.IND2_CODE
,E.IND3_CNT
,E.IND3_CODE
,E.ENR_CNT
,E.READABLE
,E.WRITABLE
,E.OMIT_VALUE
,F.DT_CODE
,G.VERSION_DEPENDENT
,G.TYPECODE_DEPENDENT
,G.SRC_TYPE_MOD_DESC
,H.SRC_TYPE_CODE
,H.SRC_TYPE_NAME
,H.GUID
,H.SRC_TYPE_INTERNAL
,H.TM_GUID
,H.DEVICETYPE
,H.HORIZONTAL_READ_MODE
from SRC_TYPE_MOD_WITHE_RC_OPTY A
join OPTY B on (A.OPTY_ID = B.OPTY_ID)
join LPTY_TYPE D on (B.LPTY_TYPE_ID = D.LPTY_TYPE_ID)
join SRC_TYPE_MOD_WITHE E on (A.SRC_TYPE_ID = E.SRC_TYPE_ID
and A.SRC_TYPE_MOD_NR = E.SRC_TYPE_MOD_NR
and A.IS_POINT = E.IS_POINT
and A.WITHE_ID = E.WITHE_ID)
join DT F on (E.DT_ID = F.DT_ID)
join SRC_TYPE_MOD G on (E.SRC_TYPE_ID = G.SRC_TYPE_ID
and E.SRC_TYPE_MOD_NR = G.SRC_TYPE_MOD_NR)
join SRC_TYPE H on (G.SRC_TYPE_ID = H.SRC_TYPE_ID)
left outer join ENUM C on (B.ENUM_ID = C.ENUM_ID) ;

-- Dumping structure for view emcor.st_vp
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_vp`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_vp` AS select
A.VP_ID
,A.VP_CODE
,A.VP_NAME
,A.VP_BIAS
,A.VP_SEPARATE_TFF
,A.VP_SMALLEST_INTERVAL
from VP A ;

-- Dumping structure for view emcor.st_vp_data
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_vp_data`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_vp_data` AS select
A.VP_ID
,A.VP_NR
,A.AGGS_TYPE_ID
,A.MS_ID
,A.DIR_ID
,A.AGGF_ID
,A.TFF_ID
,H.AGGF_NAME
,I.AGGS_TYPE_NAME
,J.DIR_CODE
,J.DIR_NAME
,K.MS_CODE
,K.MS_NAME
,K.MS_TYPE_ID
,L.MS_TYPE_NAME
,ifnull(m2.tff_name,m.TFF_NAME) TFF_NAME
,N.VP_CODE
,N.VP_NAME
,N.VP_BIAS
,N.VP_SEPARATE_TFF
,N.VP_SMALLEST_INTERVAL
from VP_DATA A
join AGGS_TYPE I on (A.AGGS_TYPE_ID = I.AGGS_TYPE_ID)
join VP N on (A.VP_ID = N.VP_ID)
left outer join AGGF H on (A.AGGF_ID = H.AGGF_ID)
left outer join DIR J on (A.DIR_ID = J.DIR_ID)
left outer join MS K on (A.MS_ID = K.MS_ID)
left outer join MS_TYPE L on (K.MS_TYPE_ID = L.MS_TYPE_ID)
left outer join TFF M on (A.TFF_ID = M.TFF_ID)
left join tff_selected m2 ON (m.tff_id=m2.tff_id AND m2.tff_enabled=1) ;

-- Dumping structure for view emcor.st_vs
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_vs`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_vs` AS select
A.VS_ID
,A.VS_CODE
,A.VS_NAME
from VS A ;

-- Dumping structure for view emcor.st_withe
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_withe`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_withe` AS select A.WITHE_ID
      ,A.WITHE_CODE
      ,A.WITHE_NAME
      ,A.WITHE_TYPE_ID
      ,A.WITHE_NORMAL_STATE
      ,A.ENUM_ID
      ,A.WITHE_DTYPE_ID
      ,B.ENUM_CODE
      ,B.ENUM_NAME
      ,C.WITHE_DTYPE_CODE
      ,C.WITHE_DTYPE_NAME
      ,D.WITHE_TYPE_CODE
      ,D.WITHE_TYPE_NAME
      ,D.WITHE_CLASS_ID
      ,E.WITHE_CLASS_CODE
      ,E.WITHE_CLASS_NAME
      ,v.EU_ID
      ,v.EU_CODE
      ,v.EU_NAME
  from WITHE       A
  join WITHE_DTYPE C on (A.WITHE_DTYPE_ID = C.WITHE_DTYPE_ID)
  join WITHE_TYPE  D on (A.WITHE_TYPE_ID = D.WITHE_TYPE_ID)
  join WITHE_CLASS E on (D.WITHE_CLASS_ID = E.WITHE_CLASS_ID)
  left join ENUM        B on (A.ENUM_ID = B.ENUM_ID)
  LEFT JOIN EU          v ON ( v.eu_id = a.eu_id) ;

-- Dumping structure for view emcor.st_witheset
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_witheset`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_witheset` AS select
A.WITHESET_ID
,A.WITHESET_CODE
,A.WITHESET_NAME
,A.SRC_TYPE_ID
,a.witheset_journal
,B.SRC_TYPE_CODE
,B.SRC_TYPE_NAME
from WITHESET A
left outer join SRC_TYPE B on (A.SRC_TYPE_ID = B.SRC_TYPE_ID) ;

-- Dumping structure for view emcor.st_witheset_data
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_witheset_data`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_witheset_data` AS SELECT A.WITHESET_ID
      ,A.WITHE_ID
      ,B.WITHE_CODE
      ,B.WITHE_NAME
      ,B.WITHE_TYPE_ID
      ,B.WITHE_NORMAL_STATE
      ,B.ENUM_ID
      ,B.WITHE_DTYPE_ID
      ,D.WITHE_DTYPE_CODE
      ,D.WITHE_DTYPE_NAME
      ,E.WITHE_TYPE_CODE
      ,E.WITHE_TYPE_NAME
      ,E.WITHE_CLASS_ID
      ,F.WITHESET_CODE
      ,F.WITHESET_NAME
      ,f.witheset_journal
      ,F.SRC_TYPE_ID
      ,G.SRC_TYPE_CODE
      ,G.SRC_TYPE_NAME
      ,V.EU_ID
      ,V.EU_CODE
      ,V.EU_NAME
  FROM WITHESET_DATA A
  JOIN WITHE         B ON (A.WITHE_ID = B.WITHE_ID)
  JOIN WITHE_DTYPE   D ON (B.WITHE_DTYPE_ID = D.WITHE_DTYPE_ID)
  JOIN WITHE_TYPE    E ON (B.WITHE_TYPE_ID = E.WITHE_TYPE_ID)
  JOIN WITHESET      F ON (A.WITHESET_ID = F.WITHESET_ID)
  LEFT JOIN SRC_TYPE      G ON (F.SRC_TYPE_ID = G.SRC_TYPE_ID)
  LEFT JOIN EU            V ON ( V.EU_ID = B.EU_ID) ;

-- Dumping structure for view emcor.st_withe_class
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_withe_class`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_withe_class` AS select
A.WITHE_CLASS_ID
,A.WITHE_CLASS_CODE
,A.WITHE_CLASS_NAME
from WITHE_CLASS A ;

-- Dumping structure for view emcor.st_withe_dtype
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_withe_dtype`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_withe_dtype` AS select
A.WITHE_DTYPE_ID
,A.WITHE_DTYPE_CODE
,A.WITHE_DTYPE_NAME
from WITHE_DTYPE A ;

-- Dumping structure for view emcor.st_withe_type
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_withe_type`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_withe_type` AS select
A.WITHE_TYPE_ID
,A.WITHE_TYPE_CODE
,A.WITHE_TYPE_NAME
,A.WITHE_CLASS_ID
,B.WITHE_CLASS_CODE
,B.WITHE_CLASS_NAME
from WITHE_TYPE A
join WITHE_CLASS B on (A.WITHE_CLASS_ID = B.WITHE_CLASS_ID) ;

-- Dumping structure for view emcor.st_xfau_type
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_xfau_type`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_xfau_type` AS select
A.XFAU_TYPE_ID
,A.XFAU_TYPE_NAME
,A.PER_ID
,A.CB_POINT
,A.CB_GR
,A.CB_DS
,B.PER_CODE
,B.PER_NAME
from XFAU_TYPE A
left outer join PER B on (A.PER_ID = B.PER_ID) ;

-- Dumping structure for view emcor.st_xf_type
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_xf_type`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_xf_type` AS SELECT A.XF_TYPE_ID ,
    A.XF_TYPE_CODE ,
    A.XF_TYPE_NAME ,
    A.src_type_id ,
    a.xf_type_delivery ,
    a.per_id ,
    a.RC_FILTER,
    a.ML_FILTER,
    b.per_code ,
    b.per_name,
    a.XFE_USAGE
,c.AGGF_ID
,cin.AGGF_NAME
,c.X_AGGF_ID
,cout.AGGF_NAME as x_AGGF_NAME
,d.in_eu_id
,din.EU_CODE as in_eu_code
,din.EU_NAME as in_eu_name
,d.out_eu_id
,dout.EU_CODE as out_eu_code
,dout.EU_NAME as out_eu_name
FROM XF_TYPE A
LEFT JOIN per b ON (a.per_id = b.per_id)
left join XF_TYPE_AGGF c on (a.xf_type_id=c.xf_type_id)
left join aggf cin on (cin.aggf_id=c.aggf_id)
left join aggf cout on (cout.aggf_id=c.x_aggf_id)
left join XF_TYPE_EU_MAP d on (a.xf_type_id=d.xf_type_id)
left join EU din on (din.eu_id=d.in_eu_id)
left join EU dout on (dout.eu_id=d.out_eu_id) ;

-- Dumping structure for view emcor.st_xf_type_aggf
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_xf_type_aggf`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_xf_type_aggf` AS SELECT c.XF_TYPE_ID
,c.AGGF_ID
,c.X_AGGF_ID
,cin.AGGF_NAME
,cout.AGGF_NAME as x_AGGF_NAME
, A.XF_TYPE_CODE
, A.XF_TYPE_NAME
, A.src_type_id
, a.xf_type_delivery
, a.per_id
, a.RC_FILTER
, a.ML_FILTER
, b.per_code
, b.per_name
, a.XFE_USAGE
FROM XF_TYPE_AGGF c
join XF_TYPE A on (a.xf_type_id=c.xf_type_id)
join aggf cin on (cin.aggf_id=c.aggf_id)
join aggf cout on (cout.aggf_id=c.x_aggf_id)
LEFT JOIN per b ON (a.per_id = b.per_id) ;

-- Dumping structure for view emcor.st_xf_type_eu_map
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_xf_type_eu_map`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_xf_type_eu_map` AS SELECT c.XF_TYPE_ID
,c.in_eu_id
,c.out_eu_id
,din.EU_CODE as in_eu_code
,din.EU_NAME as in_eu_name
,dout.EU_CODE as out_eu_code
,dout.EU_NAME as out_eu_name
, A.XF_TYPE_CODE
, A.XF_TYPE_NAME
, A.src_type_id
, a.xf_type_delivery
, a.per_id
, a.RC_FILTER
, a.ML_FILTER
, b.per_code
, b.per_name
, a.XFE_USAGE
FROM XF_TYPE_EU_MAP c
join XF_TYPE A on (a.xf_type_id=c.xf_type_id)
left join EU din on (din.eu_id=c.in_eu_id)
left join EU dout on (dout.eu_id=c.out_eu_id)
LEFT JOIN per b ON (a.per_id = b.per_id) ;

-- Dumping structure for view emcor.st_xf_type_rpp
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_xf_type_rpp`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_xf_type_rpp` AS select
A.XF_TYPE_ID
,A.RPP_ID
,B.RPP_CODE
,B.RPP_NAME
,B.RPP_ENABLED
,C.XF_TYPE_CODE
,C.XF_TYPE_NAME
from XF_TYPE_RPP A
join RPP B on (A.RPP_ID = B.RPP_ID)
join XF_TYPE C on (A.XF_TYPE_ID = C.XF_TYPE_ID) ;

-- Dumping structure for view emcor.st_xf_type_xe
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_xf_type_xe`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_xf_type_xe` AS select
A.XF_TYPE_ID
,A.XE_ID
,B.XE_CODE
,B.XE_NAME
,B.XE_CODE2
,B.XE_NAME2
,C.XF_TYPE_CODE
,C.XF_TYPE_NAME
from XF_TYPE_XE A
join XE B on (A.XE_ID = B.XE_ID)
join XF_TYPE C on (A.XF_TYPE_ID = C.XF_TYPE_ID) ;

-- Dumping structure for view emcor.st_xf_type_xfau_type
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_xf_type_xfau_type`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_xf_type_xfau_type` AS select
A.XF_TYPE_ID
,A.XFAU_TYPE_ID
,B.XFAU_TYPE_NAME
,B.PER_ID
,B.CB_POINT
,B.CB_GR
,B.CB_DS
,C.PER_CODE
,C.PER_NAME
,D.XF_TYPE_CODE
,D.XF_TYPE_NAME
from XF_TYPE_XFAU_TYPE A
join XFAU_TYPE B on (A.XFAU_TYPE_ID = B.XFAU_TYPE_ID)
join XF_TYPE D on (A.XF_TYPE_ID = D.XF_TYPE_ID)
left outer join PER C on (B.PER_ID = C.PER_ID) ;

-- Dumping structure for view emcor.st_xf_type_xpty
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_xf_type_xpty`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_xf_type_xpty` AS select
A.XF_TYPE_ID
,A.XPTY_ID
,a.xf_import
,B.XF_TYPE_CODE
,B.XF_TYPE_NAME
,C.XPTY_CODE
,C.XPTY_NAME
,D.ENUM_ID
,D.ENUM_CODE
,D.ENUM_NAME
,a.XPTY_DEFAULT_VALUE
,A.XPTY_NR
from XF_TYPE_XPTY A
join XF_TYPE B on (A.XF_TYPE_ID = B.XF_TYPE_ID)
join XPTY C on (A.XPTY_ID = C.XPTY_ID)
left outer join ENUM D on (D.ENUM_ID = IFNULL(A.ENUM_ID,C.ENUM_ID)) ;

-- Dumping structure for view emcor.st_xo_type
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_xo_type`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_xo_type` AS select
A.XO_TYPE_ID
,A.XO_TYPE_NAME
from XO_TYPE A ;

-- Dumping structure for view emcor.st_xpty
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_xpty`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_xpty` AS select
A.XPTY_ID
,A.XPTY_CODE
,A.XPTY_NAME
,A.ENUM_ID
,B.ENUM_CODE
,B.ENUM_NAME
from XPTY A
left outer join ENUM B on (A.ENUM_ID = B.ENUM_ID) ;

-- Dumping structure for view emcor.st_xs
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `st_xs`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `st_xs` AS select
A.XS_ID
,A.XS_CODE
,A.XS_NAME
from XS A ;

-- Dumping structure for view emcor.ta_triggers0
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `ta_triggers0`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `ta_triggers0` AS with e as
(
select t.tab_name,s.operation_type,concat(lower(tab_name),'_a',lower(operation_type),'rtrg') trigger_name,t.tab_id from
tab t
cross join (select 'I' operation_type union all select 'U' union all select 'D') s
where not t.tab_type_id=0
)
SELECT
tab_name,operation_type,trigger_name,
cast(
concat(
rtrim("delimiter //                    "),char(10),
"CREATE OR REPLACE TRIGGER ",trigger_name,char(10),
rtrim(" AFTER"),char(10),
" ",case operation_type when 'I' then 'INSERT' when 'U' then 'UPDATE' when 'D' then 'DELETE' end,char(10),
" ON ",tab_name,char(10),
" FOR EACH ROW",char(10),
rtrim("begin                                                              "),char(10),
rtrim("DECLARE nau MEDIUMINT UNSIGNED;                                    "),char(10),
rtrim("declare bar DATETIME;                                              "),char(10),
rtrim("declare usr MEDIUMINT UNSIGNED;                                    "),char(10),
rtrim("declare ws BIGINT UNSIGNED;                                        "),char(10),
rtrim("declare cut MEDIUMINT UNSIGNED;                                    "),char(10),
rtrim("SELECT NEXTVAL('AU_SEQ'), user_id, ses_id, now() INTO nau, usr, ws, bar FROM st_curr_user;                                                "),char(10),
"SELECT tab_id INTO cut FROM tab WHERE tab_name = '",tab_name,"';",char(10),
"INSERT INTO au (db_time, au_nr, user_id, tab_id, operation_type, ses_id) VALUES (bar,nau,usr,cut,'",operation_type,"',ws);",char(10),
"INSERT INTO gttn (d1,id1,id2,c1,c2,c0) VALUES (bar,nau,cut,'",tab_name,"','",operation_type,"','totoro');",char(10),
 "") as char) ddl
,0 ind
from e ;

-- Dumping structure for view emcor.tg$grc
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tg$grc`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tg$grc` AS select `t#tg$grc`.`cont_id` AS `cont_id`,`t#tg$grc`.`comp_id` AS `comp_id`,`t#tg$grc`.`grc_bt` AS `grc_bt`,`t#tg$grc`.`grc_et` AS `grc_et` from `t#tg$grc` where `t#tg$grc`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tg$grcj_comp
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tg$grcj_comp`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tg$grcj_comp` AS select `t#tg$grcj_comp`.`gr_id` AS `gr_id` from `t#tg$grcj_comp` where `t#tg$grcj_comp`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tg$grcj_cont
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tg$grcj_cont`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tg$grcj_cont` AS select `t#tg$grcj_cont`.`gr_id` AS `gr_id` from `t#tg$grcj_cont` where `t#tg$grcj_cont`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tg$grcj_data_comp
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tg$grcj_data_comp`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tg$grcj_data_comp` AS select `t#tg$grcj_data_comp`.`gr_id` AS `gr_id` from `t#tg$grcj_data_comp` where `t#tg$grcj_data_comp`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tg$grcj_data_cont
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tg$grcj_data_cont`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tg$grcj_data_cont` AS select `t#tg$grcj_data_cont`.`gr_id` AS `gr_id` from `t#tg$grcj_data_cont` where `t#tg$grcj_data_cont`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tg$grcj_data_p
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tg$grcj_data_p`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tg$grcj_data_p` AS select `t#tg$grcj_data_p`.`point_id` AS `point_id` from `t#tg$grcj_data_p` where `t#tg$grcj_data_p`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tg$grcj_p
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tg$grcj_p`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tg$grcj_p` AS select `t#tg$grcj_p`.`point_id` AS `point_id` from `t#tg$grcj_p` where `t#tg$grcj_p`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tg$grcj_r
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tg$grcj_r`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tg$grcj_r` AS select `t#tg$grcj_r`.`gr_id` AS `gr_id`,`t#tg$grcj_r`.`point_id` AS `point_id`,`t#tg$grcj_r`.`bt` AS `bt`,`t#tg$grcj_r`.`et` AS `et` from `t#tg$grcj_r` where `t#tg$grcj_r`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tg$grc_data
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tg$grc_data`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tg$grc_data` AS select `t#tg$grc_data`.`cont_id` AS `cont_id`,`t#tg$grc_data`.`cont_ms_id` AS `cont_ms_id`,`t#tg$grc_data`.`cont_dir_id` AS `cont_dir_id`,`t#tg$grc_data`.`cont_ec_id` AS `cont_ec_id`,`t#tg$grc_data`.`comp_id` AS `comp_id`,`t#tg$grc_data`.`comp_ms_id` AS `comp_ms_id`,`t#tg$grc_data`.`comp_dir_id` AS `comp_dir_id`,`t#tg$grc_data`.`comp_ec_id` AS `comp_ec_id`,`t#tg$grc_data`.`grc_bt` AS `grc_bt`,`t#tg$grc_data`.`coef` AS `coef` from `t#tg$grc_data` where `t#tg$grc_data`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tg$grpj_data_g
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tg$grpj_data_g`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tg$grpj_data_g` AS select `t#tg$grpj_data_g`.`gr_id` AS `gr_id` from `t#tg$grpj_data_g` where `t#tg$grpj_data_g`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tg$grpj_data_p
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tg$grpj_data_p`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tg$grpj_data_p` AS select `t#tg$grpj_data_p`.`point_id` AS `point_id` from `t#tg$grpj_data_p` where `t#tg$grpj_data_p`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tg$grpj_g
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tg$grpj_g`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tg$grpj_g` AS select `t#tg$grpj_g`.`gr_id` AS `gr_id` from `t#tg$grpj_g` where `t#tg$grpj_g`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tg$grpj_p
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tg$grpj_p`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tg$grpj_p` AS select `t#tg$grpj_p`.`point_id` AS `point_id` from `t#tg$grpj_p` where `t#tg$grpj_p`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tmpl$dids
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tmpl$dids`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tmpl$dids` AS select `t#tmpl$dids`.`di_id` AS `di_id`,`t#tmpl$dids`.`ds_id` AS `ds_id`,`t#tmpl$dids`.`point_id` AS `point_id`,`t#tmpl$dids`.`ds_type_id` AS `ds_type_id`,`t#tmpl$dids`.`sbst_tmpl_id` AS `sbst_tmpl_id`,`t#tmpl$dids`.`src_id` AS `src_id` from `t#tmpl$dids` where `t#tmpl$dids`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tmpl$pladv
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tmpl$pladv`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tmpl$pladv` AS select `t#tmpl$pladv`.`pl_id` AS `pl_id`,`t#tmpl$pladv`.`point_id` AS `point_id`,`t#tmpl$pladv`.`ml_id` AS `ml_id`,`t#tmpl$pladv`.`sbst_tmpl_id` AS `sbst_tmpl_id`,`t#tmpl$pladv`.`src_id` AS `src_id` from `t#tmpl$pladv` where `t#tmpl$pladv`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tmpl$seadv
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tmpl$seadv`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tmpl$seadv` AS select `t#tmpl$seadv`.`se_id` AS `se_id`,`t#tmpl$seadv`.`src_id` AS `src_id`,`t#tmpl$seadv`.`point_id` AS `point_id`,`t#tmpl$seadv`.`ml_id` AS `ml_id`,`t#tmpl$seadv`.`se_ab` AS `se_ab`,`t#tmpl$seadv`.`se_a` AS `se_a`,`t#tmpl$seadv`.`se_b` AS `se_b`,`t#tmpl$seadv`.`se_h` AS `se_h`,`t#tmpl$seadv`.`se_h_per_id` AS `se_h_per_id`,`t#tmpl$seadv`.`se_h_depth` AS `se_h_depth`,`t#tmpl$seadv`.`se_h_restore_depth` AS `se_h_restore_depth`,`t#tmpl$seadv`.`se_h_restore_per_id` AS `se_h_restore_per_id` from `t#tmpl$seadv` where `t#tmpl$seadv`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tmpl$sedsadv
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tmpl$sedsadv`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tmpl$sedsadv` AS select `t#tmpl$sedsadv`.`se_id` AS `se_id`,`t#tmpl$sedsadv`.`src_id` AS `src_id`,`t#tmpl$sedsadv`.`point_id` AS `point_id`,`t#tmpl$sedsadv`.`ds_id` AS `ds_id`,`t#tmpl$sedsadv`.`ds_type_id` AS `ds_type_id`,`t#tmpl$sedsadv`.`se_h` AS `se_h`,`t#tmpl$sedsadv`.`se_h_per_id` AS `se_h_per_id`,`t#tmpl$sedsadv`.`se_h_depth` AS `se_h_depth`,`t#tmpl$sedsadv`.`se_h_restore_depth` AS `se_h_restore_depth`,`t#tmpl$sedsadv`.`se_h_restore_per_id` AS `se_h_restore_per_id` from `t#tmpl$sedsadv` where `t#tmpl$sedsadv`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tmpl$sep
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tmpl$sep`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tmpl$sep` AS select `t#tmpl$sep`.`se_id` AS `se_id`,`t#tmpl$sep`.`sep_id` AS `sep_id`,`t#tmpl$sep`.`sp_id` AS `sp_id` from `t#tmpl$sep` where `t#tmpl$sep`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tmpl$seprc
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tmpl$seprc`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tmpl$seprc` AS select `t#tmpl$seprc`.`sep_id` AS `sep_id`,`t#tmpl$seprc`.`rc_id` AS `rc_id`,`t#tmpl$seprc`.`sch_id` AS `sch_id`,`t#tmpl$seprc`.`per_id` AS `per_id`,`t#tmpl$seprc`.`sep_rc_lag` AS `sep_rc_lag`,`t#tmpl$seprc`.`sep_rc_depth` AS `sep_rc_depth` from `t#tmpl$seprc` where `t#tmpl$seprc`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tmpl$srcm
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tmpl$srcm`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tmpl$srcm` AS select `t#tmpl$srcm`.`src_id` AS `src_id`,`t#tmpl$srcm`.`m` AS `m` from `t#tmpl$srcm` where `t#tmpl$srcm`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tmpl$srcm3
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tmpl$srcm3`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tmpl$srcm3` AS select `t#tmpl$srcm3`.`src_id` AS `src_id`,`t#tmpl$srcm3`.`m` AS `m`,`t#tmpl$srcm3`.`dl_type_id` AS `dl_type_id`,`t#tmpl$srcm3`.`tz_id` AS `tz_id`,`t#tmpl$srcm3`.`src_tz_dst_used` AS `src_tz_dst_used`,`t#tmpl$srcm3`.`src_save_statistics` AS `src_save_statistics`,`t#tmpl$srcm3`.`point_id` AS `point_id`,`t#tmpl$srcm3`.`src_tmpl_id` AS `src_tmpl_id`,`t#tmpl$srcm3`.`src_number` AS `src_number`,`t#tmpl$srcm3`.`src_dir_inv` AS `src_dir_inv`,`t#tmpl$srcm3`.`tsrc_tmpl_id` AS `tsrc_tmpl_id`,`t#tmpl$srcm3`.`src_tmpl_multipoint` AS `src_tmpl_multipoint`,`t#tmpl$srcm3`.`tdl_type_id` AS `tdl_type_id`,`t#tmpl$srcm3`.`ttz_id` AS `ttz_id`,`t#tmpl$srcm3`.`tsrc_tz_dst_used` AS `tsrc_tz_dst_used`,`t#tmpl$srcm3`.`tsrc_save_statistics` AS `tsrc_save_statistics`,`t#tmpl$srcm3`.`tsrc_dir_inv` AS `tsrc_dir_inv`,`t#tmpl$srcm3`.`tinherit_src_number` AS `tinherit_src_number`,`t#tmpl$srcm3`.`error_number` AS `error_number`,`t#tmpl$srcm3`.`error_msg` AS `error_msg` from `t#tmpl$srcm3` where `t#tmpl$srcm3`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.tmpl$src_point
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `tmpl$src_point`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `tmpl$src_point` AS select `t#tmpl$src_point`.`src_id` AS `src_id`,`t#tmpl$src_point`.`point_id` AS `point_id`,`t#tmpl$src_point`.`sbst_tmpl_id` AS `sbst_tmpl_id`,`t#tmpl$src_point`.`coef_u_numerator` AS `coef_u_numerator`,`t#tmpl$src_point`.`coef_u_denominator` AS `coef_u_denominator`,`t#tmpl$src_point`.`coef_i_numerator` AS `coef_i_numerator`,`t#tmpl$src_point`.`coef_i_denominator` AS `coef_i_denominator` from `t#tmpl$src_point` where `t#tmpl$src_point`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.v_ar$period
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `v_ar$period`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `v_ar$period` AS select `t#v_ar$period`.`point_id` AS `point_id`,`t#v_ar$period`.`bt` AS `bt`,`t#v_ar$period`.`et` AS `et` from `t#v_ar$period` where `t#v_ar$period`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.v_ar_map$gr
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `v_ar_map$gr`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `v_ar_map$gr` AS select `t#v_ar_map$gr`.`ma_id` AS `ma_id`,`t#v_ar_map$gr`.`ts_id` AS `ts_id`,`t#v_ar_map$gr`.`mt_id` AS `mt_id`,`t#v_ar_map$gr`.`da` AS `da`,`t#v_ar_map$gr`.`bt` AS `bt`,`t#v_ar_map$gr`.`et` AS `et`,`t#v_ar_map$gr`.`map_id` AS `map_id`,`t#v_ar_map$gr`.`verge_id` AS `verge_id`,`t#v_ar_map$gr`.`verge_code` AS `verge_code`,`t#v_ar_map$gr`.`verge_name` AS `verge_name`,`t#v_ar_map$gr`.`ma_report_exceeding` AS `ma_report_exceeding`,`t#v_ar_map$gr`.`val` AS `val`,`t#v_ar_map$gr`.`has_specific_dstatus` AS `has_specific_dstatus`,`t#v_ar_map$gr`.`ml_id` AS `ml_id`,`t#v_ar_map$gr`.`ml_name` AS `ml_name`,`t#v_ar_map$gr`.`gr_id` AS `gr_id`,`t#v_ar_map$gr`.`gmod_id` AS `gmod_id`,`t#v_ar_map$gr`.`gmod_code` AS `gmod_code`,`t#v_ar_map$gr`.`gmod_name` AS `gmod_name`,`t#v_ar_map$gr`.`gprc` AS `gprc`,`t#v_ar_map$gr`.`ec_id` AS `ec_id`,`t#v_ar_map$gr`.`ec_code` AS `ec_code`,`t#v_ar_map$gr`.`ec_name` AS `ec_name`,`t#v_ar_map$gr`.`ec_in` AS `ec_in`,`t#v_ar_map$gr`.`ds_id` AS `ds_id` from `t#v_ar_map$gr` where `t#v_ar_map$gr`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.v_ar_map$point
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `v_ar_map$point`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `v_ar_map$point` AS select `t#v_ar_map$point`.`ma_id` AS `ma_id`,`t#v_ar_map$point`.`ts_id` AS `ts_id`,`t#v_ar_map$point`.`mt_id` AS `mt_id`,`t#v_ar_map$point`.`da` AS `da`,`t#v_ar_map$point`.`bt` AS `bt`,`t#v_ar_map$point`.`et` AS `et`,`t#v_ar_map$point`.`map_id` AS `map_id`,`t#v_ar_map$point`.`verge_id` AS `verge_id`,`t#v_ar_map$point`.`verge_code` AS `verge_code`,`t#v_ar_map$point`.`verge_name` AS `verge_name`,`t#v_ar_map$point`.`ma_report_exceeding` AS `ma_report_exceeding`,`t#v_ar_map$point`.`ma_auto_null_act` AS `ma_auto_null_act`,`t#v_ar_map$point`.`ma_auto_ccs` AS `ma_auto_ccs`,`t#v_ar_map$point`.`val` AS `val`,`t#v_ar_map$point`.`has_specific_dstatus` AS `has_specific_dstatus`,`t#v_ar_map$point`.`ml_id` AS `ml_id`,`t#v_ar_map$point`.`ml_name` AS `ml_name`,`t#v_ar_map$point`.`point_id` AS `point_id`,`t#v_ar_map$point`.`ds_id` AS `ds_id` from `t#v_ar_map$point` where `t#v_ar_map$point`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.v_ar_map$sam
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `v_ar_map$sam`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `v_ar_map$sam` AS select `t#v_ar_map$sam`.`ma_id` AS `ma_id`,`t#v_ar_map$sam`.`ts_id` AS `ts_id`,`t#v_ar_map$sam`.`mt_id` AS `mt_id`,`t#v_ar_map$sam`.`da` AS `da`,`t#v_ar_map$sam`.`bt` AS `bt`,`t#v_ar_map$sam`.`et` AS `et`,`t#v_ar_map$sam`.`map_id` AS `map_id`,`t#v_ar_map$sam`.`verge_id` AS `verge_id`,`t#v_ar_map$sam`.`verge_code` AS `verge_code`,`t#v_ar_map$sam`.`verge_name` AS `verge_name`,`t#v_ar_map$sam`.`ma_report_exceeding` AS `ma_report_exceeding`,`t#v_ar_map$sam`.`val` AS `val`,`t#v_ar_map$sam`.`has_specific_dstatus` AS `has_specific_dstatus`,`t#v_ar_map$sam`.`sam_id` AS `sam_id`,`t#v_ar_map$sam`.`sam_code` AS `sam_code`,`t#v_ar_map$sam`.`sam_name` AS `sam_name` from `t#v_ar_map$sam` where `t#v_ar_map$sam`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.v_ar_map_gr$f
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `v_ar_map_gr$f`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `v_ar_map_gr$f` AS select `t#v_ar_map_gr$f`.`ma_id` AS `ma_id`,`t#v_ar_map_gr$f`.`ts_id` AS `ts_id`,`t#v_ar_map_gr$f`.`mt_id` AS `mt_id`,`t#v_ar_map_gr$f`.`gr_id` AS `gr_id`,`t#v_ar_map_gr$f`.`gmod_id` AS `gmod_id`,`t#v_ar_map_gr$f`.`gprc` AS `gprc`,`t#v_ar_map_gr$f`.`mt_ec_id` AS `mt_ec_id`,`t#v_ar_map_gr$f`.`mt_ec_in` AS `mt_ec_in`,`t#v_ar_map_gr$f`.`gmod_a` AS `gmod_a`,`t#v_ar_map_gr$f`.`gmod_b` AS `gmod_b`,`t#v_ar_map_gr$f`.`ml_id` AS `ml_id`,`t#v_ar_map_gr$f`.`da` AS `da`,`t#v_ar_map_gr$f`.`coef` AS `coef`,`t#v_ar_map_gr$f`.`pl_id` AS `pl_id`,`t#v_ar_map_gr$f`.`ec_id` AS `ec_id`,`t#v_ar_map_gr$f`.`ec_in` AS `ec_in`,`t#v_ar_map_gr$f`.`verge_id` AS `verge_id`,`t#v_ar_map_gr$f`.`verge_code` AS `verge_code`,`t#v_ar_map_gr$f`.`verge_name` AS `verge_name`,`t#v_ar_map_gr$f`.`ma_ab` AS `ma_ab`,`t#v_ar_map_gr$f`.`ma_a_nom` AS `ma_a_nom`,`t#v_ar_map_gr$f`.`ma_a_denom` AS `ma_a_denom`,`t#v_ar_map_gr$f`.`ma_b` AS `ma_b`,`t#v_ar_map_gr$f`.`ma_report_exceeding` AS `ma_report_exceeding`,`t#v_ar_map_gr$f`.`ma_lag` AS `ma_lag`,`t#v_ar_map_gr$f`.`ma_lag_per_id` AS `ma_lag_per_id`,`t#v_ar_map_gr$f`.`map_id` AS `map_id`,`t#v_ar_map_gr$f`.`ml_name` AS `ml_name`,`t#v_ar_map_gr$f`.`gmod_code` AS `gmod_code`,`t#v_ar_map_gr$f`.`gmod_name` AS `gmod_name`,`t#v_ar_map_gr$f`.`ec_code` AS `ec_code`,`t#v_ar_map_gr$f`.`ec_name` AS `ec_name`,`t#v_ar_map_gr$f`.`orig` AS `orig`,`t#v_ar_map_gr$f`.`sbst_improvable` AS `sbst_improvable`,`t#v_ar_map_gr$f`.`sbst_ab` AS `sbst_ab`,`t#v_ar_map_gr$f`.`sbst_a` AS `sbst_a`,`t#v_ar_map_gr$f`.`sbst_b` AS `sbst_b`,`t#v_ar_map_gr$f`.`sbst_lag` AS `sbst_lag`,`t#v_ar_map_gr$f`.`sbst_per_id` AS `sbst_per_id`,`t#v_ar_map_gr$f`.`sam_id` AS `sam_id`,`t#v_ar_map_gr$f`.`pl2` AS `pl2`,`t#v_ar_map_gr$f`.`byp_state` AS `byp_state`,`t#v_ar_map_gr$f`.`bt` AS `bt`,`t#v_ar_map_gr$f`.`et` AS `et`,`t#v_ar_map_gr$f`.`rbt` AS `rbt`,`t#v_ar_map_gr$f`.`sam_v` AS `sam_v`,`t#v_ar_map_gr$f`.`imc_bias` AS `imc_bias`,`t#v_ar_map_gr$f`.`aggs_type_id` AS `aggs_type_id`,`t#v_ar_map_gr$f`.`ds_id` AS `ds_id` from `t#v_ar_map_gr$f` where `t#v_ar_map_gr$f`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.v_ar_map_gr$v
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `v_ar_map_gr$v`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `v_ar_map_gr$v` AS select `t#v_ar_map_gr$v`.`ma_id` AS `ma_id`,`t#v_ar_map_gr$v`.`ts_id` AS `ts_id`,`t#v_ar_map_gr$v`.`mt_id` AS `mt_id`,`t#v_ar_map_gr$v`.`gr_id` AS `gr_id`,`t#v_ar_map_gr$v`.`gmod_id` AS `gmod_id`,`t#v_ar_map_gr$v`.`gprc` AS `gprc`,`t#v_ar_map_gr$v`.`mt_ec_id` AS `mt_ec_id`,`t#v_ar_map_gr$v`.`mt_ec_in` AS `mt_ec_in`,`t#v_ar_map_gr$v`.`gmod_a` AS `gmod_a`,`t#v_ar_map_gr$v`.`gmod_b0` AS `gmod_b0`,`t#v_ar_map_gr$v`.`ml_id` AS `ml_id`,`t#v_ar_map_gr$v`.`aggs_id` AS `aggs_id`,`t#v_ar_map_gr$v`.`aggf_id` AS `aggf_id`,`t#v_ar_map_gr$v`.`md_id` AS `md_id`,`t#v_ar_map_gr$v`.`tff_id` AS `tff_id`,`t#v_ar_map_gr$v`.`dir_id` AS `dir_id`,`t#v_ar_map_gr$v`.`ms_id` AS `ms_id`,`t#v_ar_map_gr$v`.`per_id` AS `per_id`,`t#v_ar_map_gr$v`.`md_int_value` AS `md_int_value`,`t#v_ar_map_gr$v`.`verge_id` AS `verge_id`,`t#v_ar_map_gr$v`.`verge_code` AS `verge_code`,`t#v_ar_map_gr$v`.`verge_name` AS `verge_name`,`t#v_ar_map_gr$v`.`ma_ab` AS `ma_ab`,`t#v_ar_map_gr$v`.`ma_a_nom` AS `ma_a_nom`,`t#v_ar_map_gr$v`.`ma_a_denom` AS `ma_a_denom`,`t#v_ar_map_gr$v`.`ma_b` AS `ma_b`,`t#v_ar_map_gr$v`.`ma_report_exceeding` AS `ma_report_exceeding`,`t#v_ar_map_gr$v`.`ma_lag` AS `ma_lag`,`t#v_ar_map_gr$v`.`ma_lag_per_id` AS `ma_lag_per_id`,`t#v_ar_map_gr$v`.`map_id` AS `map_id`,`t#v_ar_map_gr$v`.`map_bt` AS `map_bt`,`t#v_ar_map_gr$v`.`map_et` AS `map_et`,`t#v_ar_map_gr$v`.`map_h_bound` AS `map_h_bound`,`t#v_ar_map_gr$v`.`ml_name` AS `ml_name`,`t#v_ar_map_gr$v`.`gmod_code` AS `gmod_code`,`t#v_ar_map_gr$v`.`gmod_name` AS `gmod_name`,`t#v_ar_map_gr$v`.`gmod_b` AS `gmod_b`,`t#v_ar_map_gr$v`.`da` AS `da`,`t#v_ar_map_gr$v`.`mo` AS `mo`,`t#v_ar_map_gr$v`.`bt` AS `bt`,`t#v_ar_map_gr$v`.`et` AS `et`,`t#v_ar_map_gr$v`.`i_nr` AS `i_nr`,`t#v_ar_map_gr$v`.`point_ms_id` AS `point_ms_id`,`t#v_ar_map_gr$v`.`point_dir_id` AS `point_dir_id`,`t#v_ar_map_gr$v`.`coef` AS `coef`,`t#v_ar_map_gr$v`.`ec_id` AS `ec_id`,`t#v_ar_map_gr$v`.`ec_in` AS `ec_in`,`t#v_ar_map_gr$v`.`point_id` AS `point_id`,`t#v_ar_map_gr$v`.`ec_code` AS `ec_code`,`t#v_ar_map_gr$v`.`ec_name` AS `ec_name`,`t#v_ar_map_gr$v`.`ds_id` AS `ds_id` from `t#v_ar_map_gr$v` where `t#v_ar_map_gr$v`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.v_ar_map_point$f
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `v_ar_map_point$f`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `v_ar_map_point$f` AS select `t#v_ar_map_point$f`.`ma_id` AS `ma_id`,`t#v_ar_map_point$f`.`ts_id` AS `ts_id`,`t#v_ar_map_point$f`.`mt_id` AS `mt_id`,`t#v_ar_map_point$f`.`ml_id` AS `ml_id`,`t#v_ar_map_point$f`.`ml_name` AS `ml_name`,`t#v_ar_map_point$f`.`point_id` AS `point_id`,`t#v_ar_map_point$f`.`verge_id` AS `verge_id`,`t#v_ar_map_point$f`.`verge_code` AS `verge_code`,`t#v_ar_map_point$f`.`verge_name` AS `verge_name`,`t#v_ar_map_point$f`.`ma_ab` AS `ma_ab`,`t#v_ar_map_point$f`.`ma_a_nom` AS `ma_a_nom`,`t#v_ar_map_point$f`.`ma_a_denom` AS `ma_a_denom`,`t#v_ar_map_point$f`.`ma_b` AS `ma_b`,`t#v_ar_map_point$f`.`ma_report_exceeding` AS `ma_report_exceeding`,`t#v_ar_map_point$f`.`ma_auto_null_act` AS `ma_auto_null_act`,`t#v_ar_map_point$f`.`ma_auto_ccs` AS `ma_auto_ccs`,`t#v_ar_map_point$f`.`map_id` AS `map_id`,`t#v_ar_map_point$f`.`mo` AS `mo`,`t#v_ar_map_point$f`.`da` AS `da`,`t#v_ar_map_point$f`.`per_id` AS `per_id`,`t#v_ar_map_point$f`.`md_int_value` AS `md_int_value`,`t#v_ar_map_point$f`.`pl2` AS `pl2`,`t#v_ar_map_point$f`.`byp_state` AS `byp_state`,`t#v_ar_map_point$f`.`bt` AS `bt`,`t#v_ar_map_point$f`.`et` AS `et`,`t#v_ar_map_point$f`.`rbt0` AS `rbt0`,`t#v_ar_map_point$f`.`ret0` AS `ret0`,`t#v_ar_map_point$f`.`aggs_type_id` AS `aggs_type_id`,`t#v_ar_map_point$f`.`aggs_id` AS `aggs_id`,`t#v_ar_map_point$f`.`bc` AS `bc`,`t#v_ar_map_point$f`.`ma_lag` AS `ma_lag`,`t#v_ar_map_point$f`.`ma_lag_per_id` AS `ma_lag_per_id`,`t#v_ar_map_point$f`.`rbt` AS `rbt`,`t#v_ar_map_point$f`.`ret` AS `ret`,`t#v_ar_map_point$f`.`ds_id` AS `ds_id` from `t#v_ar_map_point$f` where `t#v_ar_map_point$f`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.v_plep_updated$f
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `v_plep_updated$f`;
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `v_plep_updated$f` AS select `t#v_plep_updated$f`.`pl_id` AS `pl_id`,`t#v_plep_updated$f`.`plep_bt` AS `plep_bt`,`t#v_plep_updated$f`.`plep_et` AS `plep_et`,`t#v_plep_updated$f`.`di_id` AS `di_id`,`t#v_plep_updated$f`.`se_id` AS `se_id`,`t#v_plep_updated$f`.`sep_id` AS `sep_id`,`t#v_plep_updated$f`.`point_id` AS `point_id`,`t#v_plep_updated$f`.`pl_enabled` AS `pl_enabled`,`t#v_plep_updated$f`.`point_enabled` AS `point_enabled`,`t#v_plep_updated$f`.`ow0` AS `ow0`,`t#v_plep_updated$f`.`ow` AS `ow`,`t#v_plep_updated$f`.`tz_shift` AS `tz_shift`,`t#v_plep_updated$f`.`aggs_id` AS `aggs_id`,`t#v_plep_updated$f`.`per_id` AS `per_id`,`t#v_plep_updated$f`.`md_id` AS `md_id`,`t#v_plep_updated$f`.`src_type_internal` AS `src_type_internal`,`t#v_plep_updated$f`.`sep_h_lag` AS `sep_h_lag`,`t#v_plep_updated$f`.`sep_h_depth` AS `sep_h_depth`,`t#v_plep_updated$f`.`sep_h_per_id` AS `sep_h_per_id`,`t#v_plep_updated$f`.`sep_h_sch_id` AS `sep_h_sch_id`,`t#v_plep_updated$f`.`se_h_depth` AS `se_h_depth`,`t#v_plep_updated$f`.`se_h_per_id` AS `se_h_per_id`,`t#v_plep_updated$f`.`se_h_bound` AS `se_h_bound`,`t#v_plep_updated$f`.`se_h` AS `se_h`,`t#v_plep_updated$f`.`se_enabled` AS `se_enabled`,`t#v_plep_updated$f`.`di_enabled` AS `di_enabled`,`t#v_plep_updated$f`.`sep_enabled` AS `sep_enabled`,`t#v_plep_updated$f`.`ph_enabled` AS `ph_enabled`,`t#v_plep_updated$f`.`ph_deleted` AS `ph_deleted`,`t#v_plep_updated$f`.`dp_deleted` AS `dp_deleted`,`t#v_plep_updated$f`.`dp_enabled` AS `dp_enabled`,`t#v_plep_updated$f`.`src_bt` AS `src_bt`,`t#v_plep_updated$f`.`src_et` AS `src_et`,`t#v_plep_updated$f`.`src_enabled` AS `src_enabled`,`t#v_plep_updated$f`.`se_h_restore_depth` AS `se_h_restore_depth`,`t#v_plep_updated$f`.`se_h_restore_per_id` AS `se_h_restore_per_id`,`t#v_plep_updated$f`.`bc` AS `bc`,`t#v_plep_updated$f`.`sbc` AS `sbc`,`t#v_plep_updated$f`.`aggs_type_id` AS `aggs_type_id`,`t#v_plep_updated$f`.`di_bt` AS `di_bt`,`t#v_plep_updated$f`.`di_et` AS `di_et`,`t#v_plep_updated$f`.`cp_enabled` AS `cp_enabled` from `t#v_plep_updated$f` where `t#v_plep_updated$f`.`cid` = connection_id() WITH CASCADED CHECK OPTION;

-- Dumping structure for view emcor.v_sep
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `v_sep`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `v_sep` AS SELECT distinct
sep_id,
se_id,
sp_id,
sep_b_lag,
sep_b_depth,
sep_b_per_id,
sep_b_sch_id,
sep_h_lag,
sep_h_depth,
sep_h_per_id,
sep_h_sch_id,
sep_f_lag,
sep_f_depth,
sep_f_per_id,
sep_f_sch_id,
sep_t_lag,
sep_t_depth,
sep_t_per_id,
sep_t_sch_id,
sep_r_lag,
sep_r_depth,
sep_r_per_id,
sep_r_sch_id,
sep_s_lag,
sep_s_depth,
sep_s_per_id,
sep_s_sch_id,
ml_id,
src_id,
ph_type_id
FROM (
SELECT
a.*
/*background*/
,Max(CASE WHEN R.RC_ID= 2                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_B_LAG
,Max(CASE WHEN R.RC_ID= 2                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_B_DEPTH
,Max(CASE WHEN R.RC_ID= 2                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_B_PER_ID
,Max(CASE WHEN R.RC_ID= 2                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_B_SCH_ID
/*holes*/
,Max(CASE WHEN R.RC_ID= 4                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_H_LAG
,Max(CASE WHEN R.RC_ID= 4                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_H_DEPTH
,Max(CASE WHEN R.RC_ID= 4                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_H_PER_ID
,Max(CASE WHEN R.RC_ID= 4                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_H_SCH_ID
/*real time*/
,Max(CASE WHEN R.RC_ID=10                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_F_LAG
,Max(CASE WHEN R.RC_ID=10                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_F_DEPTH
,Max(CASE WHEN R.RC_ID=10                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_F_PER_ID
,Max(CASE WHEN R.RC_ID=10                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_F_SCH_ID
/*WRITE_AUTO or time adjustment*/
,Max(CASE WHEN R.RC_ID= 6                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_T_LAG
,Max(CASE WHEN R.RC_ID= 6                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_T_DEPTH
,Max(CASE WHEN R.RC_ID= 6                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_T_PER_ID
,Max(CASE WHEN R.RC_ID= 6                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_T_SCH_ID
/*recent holes*/
,Max(CASE WHEN R.RC_ID=14                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_R_LAG
,Max(CASE WHEN R.RC_ID=14                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_R_DEPTH
,Max(CASE WHEN R.RC_ID=14                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_R_PER_ID
,Max(CASE WHEN R.RC_ID=14                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_R_SCH_ID
/*server synchronization*/
,Max(CASE WHEN R.RC_ID=11                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_S_LAG
,Max(CASE WHEN R.RC_ID=11                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_S_DEPTH
,Max(CASE WHEN R.RC_ID=11                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_S_PER_ID
,Max(CASE WHEN R.RC_ID=11                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_S_SCH_ID
FROM
(
SELECT
A.SEP_ID
,A.SE_ID
,A.SP_ID
,A.SEP_ENABLED
,G.ML_ID
,L.SRC_ID
,M.PH_TYPE_ID
from sep A
join SE C on (A.SE_ID = C.SE_ID)
join SRC K on (C.SRC_ID = K.SRC_ID)
join SP L on (A.SP_ID = L.SP_ID)
join PH M on (L.PH_ID = M.PH_ID)
join DI D on (C.DI_ID = D.DI_ID)
join PL G on (D.PL_ID = G.PL_ID)
) a
left join SEP_RC R ON (A.SEP_ID = R.SEP_ID AND R.RC_ID IN (2,4,6,10,11,14))
) f ;

-- Dumping structure for view emcor.v_sep_dp_sheaf
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `v_sep_dp_sheaf`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `v_sep_dp_sheaf` AS SELECT distinct
sep_id,
se_id,
sp_id,
sep_b_lag,
sep_b_depth,
sep_b_per_id,
sep_b_sch_id,
sep_h_lag,
sep_h_depth,
sep_h_per_id,
sep_h_sch_id,
sep_f_lag,
sep_f_depth,
sep_f_per_id,
sep_f_sch_id,
sep_t_lag,
sep_t_depth,
sep_t_per_id,
sep_t_sch_id,
sep_r_lag,
sep_r_depth,
sep_r_per_id,
sep_r_sch_id,
sep_s_lag,
sep_s_depth,
sep_s_per_id,
sep_s_sch_id,
sheaf_id,
src_id,
ph_type_id
FROM (
SELECT
a.*
/*background*/
,Max(CASE WHEN R.RC_ID= 2                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_B_LAG
,Max(CASE WHEN R.RC_ID= 2                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_B_DEPTH
,Max(CASE WHEN R.RC_ID= 2                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_B_PER_ID
,Max(CASE WHEN R.RC_ID= 2                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_B_SCH_ID
/*holes*/
,Max(CASE WHEN R.RC_ID= 4                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_H_LAG
,Max(CASE WHEN R.RC_ID= 4                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_H_DEPTH
,Max(CASE WHEN R.RC_ID= 4                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_H_PER_ID
,Max(CASE WHEN R.RC_ID= 4                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_H_SCH_ID
/*real time*/
,Max(CASE WHEN R.RC_ID=10                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_F_LAG
,Max(CASE WHEN R.RC_ID=10                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_F_DEPTH
,Max(CASE WHEN R.RC_ID=10                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_F_PER_ID
,Max(CASE WHEN R.RC_ID=10                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_F_SCH_ID
/*WRITE_AUTO or time adjustment*/
,Max(CASE WHEN R.RC_ID= 6                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_T_LAG
,Max(CASE WHEN R.RC_ID= 6                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_T_DEPTH
,Max(CASE WHEN R.RC_ID= 6                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_T_PER_ID
,Max(CASE WHEN R.RC_ID= 6                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_T_SCH_ID
/*recent holes*/
,Max(CASE WHEN R.RC_ID=14                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_R_LAG
,Max(CASE WHEN R.RC_ID=14                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_R_DEPTH
,Max(CASE WHEN R.RC_ID=14                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_R_PER_ID
,Max(CASE WHEN R.RC_ID=14                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_R_SCH_ID
/*server synchronization*/
,Max(CASE WHEN R.RC_ID=11                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_S_LAG
,Max(CASE WHEN R.RC_ID=11                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_S_DEPTH
,Max(CASE WHEN R.RC_ID=11                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_S_PER_ID
,Max(CASE WHEN R.RC_ID=11                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_S_SCH_ID
FROM
(
SELECT
A.SEP_ID
,A.SE_ID
,A.SP_ID
,A.SEP_ENABLED
,L.SRC_ID
,M.PH_TYPE_ID
,x.SHEAF_ID
from sep A
join SE C on (A.SE_ID = C.SE_ID)
join SRC K on (C.SRC_ID = K.SRC_ID)
join SP L on (A.SP_ID = L.SP_ID)
join PH M on (L.PH_ID = M.PH_ID)
join DI D on (C.DI_ID = D.DI_ID and d.pl_id is null and d.dp_id is not null and d.point_id is null and M.DP_ID=D.DP_ID)
join sheaf x ON (d.sheaf_id=x.sheaf_id )
) a
left join SEP_RC R ON (A.SEP_ID = R.SEP_ID AND R.RC_ID IN (2,4,6,10,11,14))
) f ;

-- Dumping structure for view emcor.v_sep_ds
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `v_sep_ds`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `v_sep_ds` AS SELECT distinct
sep_id,
se_id,
sp_id,
sep_b_lag,
sep_b_depth,
sep_b_per_id,
sep_b_sch_id,
sep_h_lag,
sep_h_depth,
sep_h_per_id,
sep_h_sch_id,
sep_f_lag,
sep_f_depth,
sep_f_per_id,
sep_f_sch_id,
sep_t_lag,
sep_t_depth,
sep_t_per_id,
sep_t_sch_id,
sep_r_lag,
sep_r_depth,
sep_r_per_id,
sep_r_sch_id,
sep_s_lag,
sep_s_depth,
sep_s_per_id,
sep_s_sch_id,
DS_TYPE_id,
DS_ID,
src_id,
ph_type_id
FROM (
SELECT
a.*
/*background*/
,Max(CASE WHEN R.RC_ID= 2                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_B_LAG
,Max(CASE WHEN R.RC_ID= 2                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_B_DEPTH
,Max(CASE WHEN R.RC_ID= 2                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_B_PER_ID
,Max(CASE WHEN R.RC_ID= 2                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_B_SCH_ID
/*holes*/
,Max(CASE WHEN R.RC_ID= 4                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_H_LAG
,Max(CASE WHEN R.RC_ID= 4                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_H_DEPTH
,Max(CASE WHEN R.RC_ID= 4                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_H_PER_ID
,Max(CASE WHEN R.RC_ID= 4                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_H_SCH_ID
/*real time*/
,Max(CASE WHEN R.RC_ID=10                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_F_LAG
,Max(CASE WHEN R.RC_ID=10                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_F_DEPTH
,Max(CASE WHEN R.RC_ID=10                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_F_PER_ID
,Max(CASE WHEN R.RC_ID=10                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_F_SCH_ID
/*WRITE_AUTO or time adjustment*/
,Max(CASE WHEN R.RC_ID= 6                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_T_LAG
,Max(CASE WHEN R.RC_ID= 6                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_T_DEPTH
,Max(CASE WHEN R.RC_ID= 6                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_T_PER_ID
,Max(CASE WHEN R.RC_ID= 6                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_T_SCH_ID
/*recent holes*/
,Max(CASE WHEN R.RC_ID=14                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_R_LAG
,Max(CASE WHEN R.RC_ID=14                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_R_DEPTH
,Max(CASE WHEN R.RC_ID=14                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_R_PER_ID
,Max(CASE WHEN R.RC_ID=14                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_R_SCH_ID
/*server synchronization*/
,Max(CASE WHEN R.RC_ID=11                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_S_LAG
,Max(CASE WHEN R.RC_ID=11                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_S_DEPTH
,Max(CASE WHEN R.RC_ID=11                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_S_PER_ID
,Max(CASE WHEN R.RC_ID=11                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_S_SCH_ID
FROM
(
SELECT 
A.SEP_ID
,A.SE_ID
,A.SP_ID
,A.SEP_ENABLED
,L.SRC_ID
,M.PH_TYPE_ID
,E.DS_ID
,E.DS_TYPE_ID
from sep A
join SE C on (A.SE_ID = C.SE_ID)
join SRC K on (C.SRC_ID = K.SRC_ID)
join SP L on (A.SP_ID = L.SP_ID)
join PH M on (L.PH_ID = M.PH_ID)
join DI D on (C.DI_ID = D.DI_ID and d.pl_id is null and d.dp_id is null and d.point_id is not null AND D.DS_ID IS NOT NULL)
join DS E on (D.DS_ID = E.DS_ID AND D.POINT_ID=E.POINT_ID)
) a
left join SEP_RC R ON (A.SEP_ID = R.SEP_ID AND R.RC_ID IN (2,4,6,10,11,14))
) f ;

-- Dumping structure for view emcor.v_sep_sheaf
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `v_sep_sheaf`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `v_sep_sheaf` AS SELECT distinct
sep_id,
se_id,
sp_id,
sep_b_lag,
sep_b_depth,
sep_b_per_id,
sep_b_sch_id,
sep_h_lag,
sep_h_depth,
sep_h_per_id,
sep_h_sch_id,
sep_f_lag,
sep_f_depth,
sep_f_per_id,
sep_f_sch_id,
sep_t_lag,
sep_t_depth,
sep_t_per_id,
sep_t_sch_id,
sep_r_lag,
sep_r_depth,
sep_r_per_id,
sep_r_sch_id,
sep_s_lag,
sep_s_depth,
sep_s_per_id,
sep_s_sch_id,
sheaf_id,
src_id,
ph_type_id
FROM (SELECT
a.*
/*background*/
,Max(CASE WHEN R.RC_ID= 2                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_B_LAG
,Max(CASE WHEN R.RC_ID= 2                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_B_DEPTH
,Max(CASE WHEN R.RC_ID= 2                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_B_PER_ID
,Max(CASE WHEN R.RC_ID= 2                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_B_SCH_ID
/*holes*/
,Max(CASE WHEN R.RC_ID= 4                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_H_LAG
,Max(CASE WHEN R.RC_ID= 4                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_H_DEPTH
,Max(CASE WHEN R.RC_ID= 4                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_H_PER_ID
,Max(CASE WHEN R.RC_ID= 4                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_H_SCH_ID
/*real time*/
,Max(CASE WHEN R.RC_ID=10                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_F_LAG
,Max(CASE WHEN R.RC_ID=10                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_F_DEPTH
,Max(CASE WHEN R.RC_ID=10                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_F_PER_ID
,Max(CASE WHEN R.RC_ID=10                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_F_SCH_ID
/*WRITE_AUTO or time adjustment*/
,Max(CASE WHEN R.RC_ID= 6                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_T_LAG
,Max(CASE WHEN R.RC_ID= 6                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_T_DEPTH
,Max(CASE WHEN R.RC_ID= 6                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_T_PER_ID
,Max(CASE WHEN R.RC_ID= 6                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_T_SCH_ID
/*recent holes*/
,Max(CASE WHEN R.RC_ID=14                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_R_LAG
,Max(CASE WHEN R.RC_ID=14                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_R_DEPTH
,Max(CASE WHEN R.RC_ID=14                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_R_PER_ID
,Max(CASE WHEN R.RC_ID=14                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_R_SCH_ID
/*server synchronization*/
,Max(CASE WHEN R.RC_ID=11                    THEN R.SEP_RC_LAG                            END) over (partition by a.sp_id,a.se_id) SEP_S_LAG
,Max(CASE WHEN R.RC_ID=11                    THEN R.SEP_RC_DEPTH                          END) over (partition by a.sp_id,a.se_id) SEP_S_DEPTH
,Max(CASE WHEN R.RC_ID=11                    THEN R.PER_ID                                END) over (partition by a.sp_id,a.se_id) SEP_S_PER_ID
,Max(CASE WHEN R.RC_ID=11                    THEN R.SCH_ID                                END) over (partition by a.sp_id,a.se_id) SEP_S_SCH_ID
FROM
(
SELECT
A.SEP_ID
,A.SE_ID
,A.SP_ID
,A.SEP_ENABLED
,L.SRC_ID
,M.PH_TYPE_ID
,x.SHEAF_ID
from sep A
join SE C on (A.SE_ID = C.SE_ID)
join SRC K on (C.SRC_ID = K.SRC_ID)
join SP L on (A.SP_ID = L.SP_ID)
join PH M on (L.PH_ID = M.PH_ID)
join DI D on (C.DI_ID = D.DI_ID and d.pl_id is null and d.dp_id is null and d.point_id is not null)
join sheaf x ON (d.sheaf_id=x.sheaf_id )
) a
left join SEP_RC R ON (A.SEP_ID = R.SEP_ID AND R.RC_ID IN (2,4,6,10,11,14))
) f ;

-- Dumping structure for view emcor.v_xfe_pl_data
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `v_xfe_pl_data`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `v_xfe_pl_data` AS SELECT
  a.XFE_ID,
  a.XO_ID,
  a.XFE_T,
  a.XFE_V,
  a.IMPROVABLE,
  a.XFE_RT
,b.ml_id
,c.point_id
,c.gr_id
,d.XO_TIME
,d.XF_ID
,d.XO_TYPE_ID
,d.XO_BT
,d.XO_ET
,d.xo_info
,d.xo_tech_info
,d.xo_info2
,d.doc_nr
,g.xf_name
,g.xf_enabled
,c.xfau_id
,b.xe_id
,b.xfe_enabled
,b.xfe_info
,c.xfau_type_id
,c.xfau_enabled
,c.inherit_cn
,c.xfau_code
,c.xfau_name
,c.xfau_code2
,c.xfau_name2
,c.xfa_id
,g.xf_type_id
,g.xa_id
,g.rpp_id
,g.xf_import
,g.rp_id
,a.XS_ID
FROM XFE_PL_DATA a
join xfe b on (a.xfe_id=b.xfe_id)
join xfau c on (c.xfau_id = b.xfau_id)
join xo d on (d.xo_id=a.xo_id and d.xo_type_id in (0,1))
join xf g on (d.xf_id=g.xf_id) ;

-- Dumping structure for view emcor.xf_import_61968_data_errors
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `xf_import_61968_data_errors`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `xf_import_61968_data_errors` AS SELECT c1 mRID,
  c2 error_code,
  c4 error_sub_code,
  c3 error_description,
  c5 ITEM_CODE
 FROM gtts ;

-- Dumping structure for view emcor.xf_import_80030_data_errors
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `xf_import_80030_data_errors`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `xf_import_80030_data_errors` AS SELECT c1 au_code,
  c2 error_code,
  c4 error_sub_code,
  c3 error_description,
  c5 area_inn
 FROM gtts ;

-- Dumping structure for view emcor.xf_import_askp_data_errors
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `xf_import_askp_data_errors`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `xf_import_askp_data_errors` AS SELECT c1 au_code,
  c2 error_code,
  c4 error_sub_code,
  c3 error_description
 FROM gtts ;

-- Dumping structure for view emcor.xf_import_doedb_data_errors
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `xf_import_doedb_data_errors`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `xf_import_doedb_data_errors` AS SELECT c1 au_code,
  c2 error_code,
  c4 error_sub_code,
  c3 error_description
 FROM gtts ;

-- Dumping structure for view emcor.xf_import_eecsv_data_errors
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `xf_import_eecsv_data_errors`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `xf_import_eecsv_data_errors` AS SELECT c1 au_code,
  c2 error_code,
  c4 error_sub_code,
  c3 error_description,
  c5 au_to_code
 FROM gtts ;

-- Dumping structure for view emcor.xf_import_gcsv_data_errors
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `xf_import_gcsv_data_errors`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `xf_import_gcsv_data_errors` AS SELECT c1 au_code,
  c2 error_code,
  c4 error_sub_code,
  c3 error_description,
  c5 au_to_code
 FROM gtts ;

-- Dumping structure for view emcor.xf_import_pcci_data_errors
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `xf_import_pcci_data_errors`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `xf_import_pcci_data_errors` AS SELECT c1 au_code,
c2 error_code,
c4 error_sub_code,
c3 error_description
FROM gtts ;

-- Dumping structure for view emcor.xf_import_sng_1517_data_errors
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `xf_import_sng_1517_data_errors`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `xf_import_sng_1517_data_errors` AS SELECT
  c5 area_CODE,
  c6 area_NAME,
  c1 au_code,
  c2 error_code,
  c4 error_sub_code,
  c3 error_description
 FROM gtts ;

-- Dumping structure for view emcor.xf_import_ukre_data_errors
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `xf_import_ukre_data_errors`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `xf_import_ukre_data_errors` AS SELECT c1 au_code,
  c2 error_code,
  c4 error_sub_code,
  c3 error_description
 FROM gtts ;

-- Dumping structure for view emcor.xf_import_xml_data_errors
-- Removing temporary table and create final VIEW structure
DROP TABLE IF EXISTS `xf_import_xml_data_errors`;
CREATE ALGORITHM=UNDEFINED DEFINER=`EMCOS`@`%` SQL SECURITY DEFINER VIEW `xf_import_xml_data_errors` AS SELECT
c1 area_inn,
c2 error_code,
c4 error_sub_code,
c3 error_description
FROM gtts ;

/*!40101 SET SQL_MODE=IFNULL(@OLD_SQL_MODE, '') */;
/*!40014 SET FOREIGN_KEY_CHECKS=IF(@OLD_FOREIGN_KEY_CHECKS IS NULL, 1, @OLD_FOREIGN_KEY_CHECKS) */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
